(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  32989870,     533206]*)
(*NotebookOutlinePosition[  32990705,     533237]*)
(*  CellTagsIndexPosition[  32990630,     533231]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DWT-based texture segmentation: example set #2", "Title"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  ": This notebook assumes that all definitions in ",
  StyleBox["ipcv_definitions.nb (ver. 1.2 or later) ",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  "have been evaluated first. It also assumes that the directory in the ",
  ButtonBox["Set image directory",
    ButtonData:>"dir",
    ButtonStyle->"Hyperlink"],
  " points to an image directory with the following images: ",
  StyleBox["texture5.gif",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  ", ",
  StyleBox["texture6.gif",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  ", ",
  StyleBox["texture7.gif ",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  "and ",
  StyleBox["texture8.gif",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  FontSize->14],

Cell[TextData[{
  StyleBox["Warning",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  ": This notebook was evaluated using externally C-compiled ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " functions to speed up some of the computations, especially the training \
part of the notebook. Since this option is not available for the student \
version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " this notebook performs all computations within ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " natively. It is therefore possible, depending on your platform, that \
computation times  ",
  StyleBox["far exceed",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " those shown."
}], "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Training data generation", "Subsection"],

Cell[BoxData[
    \(\(bandMap\  = \ {{1, 2, 1}, {1, 1, 2}, {1, 2, 2}, {2, 2, 1}, {2, 1, 
            2}, {2, 2, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(GenerateSixBandTrainingData[m_, \ part_, \ 
          lpf_] := \[IndentingNewLine]Module[{m1, m2, b1, 
            b2}, \[IndentingNewLine]m1 = 
            Flatten[Partition[m, {16, 16}, part], 
              1]; \[IndentingNewLine]m2 = \(WaveletTransform2D[#, \ lpf, 
                  2] &\)\  /@ \ m1; \[IndentingNewLine]b1 = 
            Abs[\(ExtractBands[#, 1] &\) /@ \ m2]; \[IndentingNewLine]b2 = 
            Abs[\(ExtractBands[#, 2] &\) /@ \ 
                m2]; \[IndentingNewLine]{\(Flatten[#[\([2, 1]\)]] &\)\  /@ \ 
              b1, \[IndentingNewLine]\(Flatten[#[\([1, 2]\)]] &\)\  /@ \ 
              b1, \[IndentingNewLine]\(Flatten[#[\([2, 2]\)]] &\)\  /@ \ 
              b1, \[IndentingNewLine]\(Flatten[#[\([2, 1]\)]] &\)\  /@ \ 
              b2, \[IndentingNewLine]\(Flatten[#[\([1, 2]\)]] &\)\  /@ \ 
              b2, \[IndentingNewLine]\(Flatten[#[\([2, 2]\)]] &\)\  /@ \ 
              b2}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids", "Subsection"],

Cell[BoxData[
    \(\(VisualizeCentroids[means_, \ 
          opts___] := \[IndentingNewLine]Module[{n, m, 
            g1}, \[IndentingNewLine]n = 
            Sqrt[Length[First[means]]]; \[IndentingNewLine]m = 
            Min[Length[means], 8]; \[IndentingNewLine]g1 = 
            Table[ShowImage[Partition[means[\([i]\)], n], 1, 
                Max[means[\([i]\)]], Min[means[\([i]\)]], 
                DisplayFunction \[Rule] Identity], {i, 1, 
                Length[means]}]; \[IndentingNewLine]Show[
            GraphicsArray[Partition[g1, m]], 
            DisplayFunction \[Rule] $DisplayFunction, 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histogram computation", "Subsection"],

Cell[BoxData[
    \(\(ComputeHistograms[cls_, \ 
          nCodes_:  
            6] := \[IndentingNewLine]\(N[
              CategoryCounts[#, Table[i, {i, 1, 2^nCodes}]]/
                Length[#]] &\)\  /@ \ cls;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification functions", "Subsection"],

Cell[BoxData[
    \(\(ProbabilitiesOneHistogramOne[m_, lpf_, \ centroids_, \ 
          hist_, \ {level_, a_, b_}] := \[IndentingNewLine]Module[{mw, 
            pos}, \[IndentingNewLine]mw = 
            Abs[Flatten[\(ExtractBands[WaveletTransform2D[m, \ lpf, 2], 
                    level]\)[\([a, b]\)]]]; \[IndentingNewLine]pos\  = \ 
            AssignClassOne[mw, 
              centroids]; \[IndentingNewLine]\(\((#[\([pos]\)])\) &\)\  /@ \ 
            hist\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(ProbabilitiesOneHistogram[mp_, lpf_, \ centroids_, \ 
          hist_, \ {level_, a_, b_}] := \[IndentingNewLine]Map[
          ProbabilitiesOneHistogramOne[#, lpf, centroids, 
              hist, {level, a, b}] &, mp, {2}];\)\)], "Input"],

Cell[BoxData[
    \(\(ProbabilitiesAllHistograms[mp_, \ lpf_, \ centroids_, \ hist_, 
          bandMap_] := \[IndentingNewLine]Table[
          ProbabilitiesOneHistogram[mp, lpf, centroids[\([i]\)], 
            hist[\([i]\)], \ bandMap[\([i]\)]], {i, 1, 
            Length[bandMap]}];\)\)], "Input"],

Cell[BoxData[
    \(\(AnalyzeOneImage[img_, \ part_, \ lpf_, \ centroids_, \ hist_, \ 
          bandMap_] := \[IndentingNewLine]Module[{mt, 
            probs}, \[IndentingNewLine]mt = 
            Partition[img, {16, 16}, \ part]; \[IndentingNewLine]probs = 
            ProbabilitiesAllHistograms[mt, lpf, centroids, hist, 
              bandMap]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(ClassifyOnProbabilities[probs_] := \[IndentingNewLine]Map[
          First[First[Position[#, Max[#]]]] &, probs, {2}];\)\)], "Input"],

Cell[BoxData[
    \(\(VisualizeClassification[cls_, \ colors_, \ 
          opts___] := \[IndentingNewLine]Show[
          Graphics[RasterArray[Map[colors[\([#]\)] &, \ cls, \ {2}]]], \ 
          AspectRatio \[Rule] Automatic, opts];\)\)], "Input"],

Cell[BoxData[
    \(\(ClassificationPercentages[cls_, 
          n_] := \[IndentingNewLine]Module[{pct}, \[IndentingNewLine]pct = 
            CategoryCounts[cls // Flatten, Range[n]]; \[IndentingNewLine]100 
               pct/\((Plus\  @@ \ pct)\)\  // \ 
            N\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(VisualizeResults[probs_, \ colors_, 
          opts___] := \[IndentingNewLine]Module[{cls, g1, pct, g2, g2b, 
            pr}, \[IndentingNewLine]cls = 
            ClassifyOnProbabilities[probs]; \[IndentingNewLine]g1 = 
            VisualizeClassification[cls, colors, \ 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]pct = 
            ClassificationPercentages[cls, 
              Length[\(probs // First\) // First]]; \[IndentingNewLine]\ 
          g2 = BarChart[pct, BarStyle \[Rule] colors, 
              BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]pr = 
            FullOptions[g2, PlotRange]; \[IndentingNewLine]g2b = 
            Show[g2, PlotRange \[Rule] {pr // First, {\(-2\), 102}}, \ 
              GridLines \[Rule] {None, Automatic}, \ 
              FrameTicks \[Rule] None, \ 
              Axes \[Rule] False]; \[IndentingNewLine]{pct, 
            Show[GraphicsArray[{{g1}, {g2b}}], opts, 
              DisplayFunction \[Rule] $DisplayFunction]}\[IndentingNewLine]];\
\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Set image directory", "Section",
  CellTags->"dir"],

Cell[BoxData[
    \(If[StringQ[$ImagePath], $path = $ImagePath, \ $path = "\<.\>"]; 
    SetDirectory[$path];\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sample texture images", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(imageList = 
      Table["\<texture\>" <> ToString[i] <> "\<.gif\>", {i, 5, 8}]\)], "Input"],

Cell[BoxData[
    \({"texture5.gif", "texture6.gif", "texture7.gif", 
      "texture8.gif"}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(texImages = ReadImage\  /@ \ imageList;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gImages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction -> Identity] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[gImages, 2]], ImageSize \[Rule] 640, 
        DisplayFunction -> $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 640 640 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
320 string
320 320 8 [320 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
63A24E543D824845984E526B8D5344723835292D5C406D5725624D2153745735432F2F5E
3E495142385C6729775248655B5A206D713A5C482750644B81677E402F88592970574357
6D4253885A54516949797239B07B349A4C41929E6323BF62368E79603E95422489974F4D
53A443259483548E5B3D6F5077553F76774467865CB371756A4A7D8C5864764A628256B2
3A627C41763F54654760C7322065803C84821C50996F3E87A7393A6178478446687A8758
7F865992ADA581A6C57D5C7FAB3C4C6FA05488C06B29779A3F5E49568E45569B4D7FA159
74A74150C28834874A5084895357CE8469C1A66148AB90AE554D8B785558362C5B916840
5B7741216B6E7C445A6B5149A17F3D4C57393D724D95B97539676C78223B635734899C50
3B55964C2E6487783C855E3C55733FAE7D42987B51BBBC684C4E638B38256698
609A4F4A4485434F852D4F7B8750476439424D468B4C696E2D764E30687D6446442F337A
4B4E492C4577702B85503D4E4A462D826E3F513D1B537145956F3A2B4CA46B2C65353A84
86455499545281784B88781A99533FAD53246C9D6821C02E379B986F35C23C187244132E
3E7449207836317260364C37825E29574C4E876F1F955C7D7D334A5A558EA052455456A3
5F55483463705F812D65B245386F703CA38F3B579A57224F966645695C3D7B5E3A5B9158
A5885878995E4B89A1567673984C5B86994C82C6844688A846553E328247598433768557
8C6A366FBD673484645B5F845B61CF8B5274848854AC90A97A47788B7460704576AC7D4A
588E80306F85844E5F6A6E5AB589405F54423F7A4B8AC3775877787D213B654C37989139
3965964425476F713CA58334525939A486479276337C8C4343595A80362D85A5
5688514A374D2C536D30365D674A553B174F494C552C8C772D651B2F5E87765252292662
4B65451418456523861736324607206164386D731C33563B9B9C401C2F78474F7F3C1F38
553879B65A2B5B4C387F813BAD55257C5B2F74883B4AC2522775863434A64B1C804C242A
3779411D71442B5E284A512E776542604E31598A5E895355724C556B536D766B49625599
5B596A505A75717F516AC44231706F3C9C8D3D558D7B3050A26B4266824380795E704A44
91987390958B6B8996466C729E575990854698D693518AAE5074613A70455C7B39828B63
A8643C9DAB3C2D9863686457316ECC9372A1886142C4A58A944E7C956E557B4973A68848
5F8C7B2676967D4F7B706F4C9B89495B6452427B6386C2705973677E213F79553492933F
31A6A2672345742F2D948B30486C3C9C7C4992705E71A94A49946B6B1F379799
665F525541703B467631647E3F327A732F32406055135A6236872A2D5A51415E75553551
2856614136683E19664B2F1B4F34237338253B49292E462F555C653B3C8525295E523955
5E2F4E8B5C4C6F6E4B7286559179339C4D3B8B7D591D8E45278F73312FA51F15869F292E
337052216F4F33703E4955447B6947626F4868936B8B6B74773F4A7D5A797C6F416F57A2
68576E5A607767A16465C24A39789259AF8C3C598985334E996C46768A477E6F65717A50
768C6E91998D6C8DAE6B7B99BF785B8890426BC78454949D478557387B5BA29847837433
A081569CB150296F49545A4F3A5AB67868A5754941D0C98A6B447B8B6C6B544471996A55
A5A46B1E68722E25918A6C3C738A5675966E4E726A8AD49E5B7E646F2570A85D268A8436
347C99542E556C81359E80304D7739984C30887955788346266A938534268896
6A994C3A407D40496D2829727D473A5E32291E456B3D522F256C3D396B5F4441593A3369
434D564046766A28816D3D32402A2672764151583135624B795D6B4169BD5A3861443C55
694770A35E4C668643918A53737935894461B4915E27BD51278F884D39AA2D1666743F31
306A3E40934B306D3A49664D92774F6D6E4B66926E846D727852647156756C704A6E518C
666B83538D78577A5650B85237748F5AA18B365F927530498E3A68B39E49745E6C748A5D
8691869D9A926A8ABE5B6B8FAB664F849F638CD37955A9A0405B5533614C758F4F785143
A46B517E965F348355486E604B6ECE7661A9764A2F86A3987C44755A597F523E628E3631
64724A1E6E49664A5C635A345E653482A5614464546EBA8147777478293C613725846628
2F69762825627B663CA05F225357317A7338989252C46C4930516B794A39A592
619D4E5046934348926C315D6A44404E2F494A498A4658553174363E75795E545F39437D
454C4814459676358F5F3B35412A2E786240505D34447A3F7B5F4C272D72563E60253396
8B427BAF604C86873B91843C4E863280463481836328C05734AC9E6D3CA93E2376583A28
2F644326695F398535456548884C577A644363824675595E665482794A6E6F6066744D8E
58597E537F796B8D554FC0563D938051A98A3F8FC1823245995341708D417A416685885A
827D68B9C7A36A7AAE7B727EB6656CA8B3588ED552318DB5497E5843724D6A864D806657
A56D2E60915C358A574287885979CD8460B3875F41A896A46E4073515669543F64956E41
6E8F4B2C9A586F4F707E564066773849613549656297C6534D97A78C366088572993601F
365972232B4C714C5DAC7424466D37836D34887459CD8F3C334F65772D358291
5E974D5B477D3D579B6D2F7690463D331439365C632E8A593E801E53927A60636E4F4170
434B643D33706D3090203A2B43194B935F394E4112386A427D888544459B523B5C35243F
5B286FB450578A883287805E397C2C6D4E45AAA05028AE3E3F9598605DBB54307C522D3C
55776C3A7B6638832C4C5541A06C546B683D5985597E5C4E6750607740587E6E5561478D
5085774A8B6E5E8A3C47A04359A37D5094992F6AA47C385AA66A497A90447F6D5C657A56
7C71557A868A627FAD79818C91304B7F89468BB272589897618C373A8E4E6564346C765F
909C5480B55338955B3D48575288D09157A2B6845CBFA8B983468A666E8B1F284D945A48
808B31207052283490893834627B3F7A7F173A66707FD3703A605A4E25486C672D8E5D1F
37547C392F54625D376860214967318B6341A96964D091313E6A9175282B8E9B
6A684F534571324178582966383F6A7C3A3941605C2462654D791C2B676C52808F584C6D
2D5D7C41439B4B21773733244F1921683C376761353C583987A48446498E3A588E524E55
622953A96B627F7B3FB69D6C323D236F7A60B8B4122896622A929E1E2B815B2D83A86324
27616359A567327560687229886D687233316A895F6E445D8357706E446FA3725F50328E
698451266C935FB63226A9733F8B642D919A467DB853253670445B9D802F735C61736551
8F8D718C7C65548CC29194B2B0644A81924994C3686A8D923D63522356456975414C5C46
836C619EB6743C894F42594E396DA8834E807F785DCCCEC26E32777865885A3D60A06A4C
7A78412F7B475D4D647B693750662E6876474F586A50C7604B806A6C2E496764388D6634
3A4F87432F5E687240755C2E83862E7A3325727365CE6B17172D4B6C2D27887C
6F744B52477940436F402F697031264C2C2C1B475B425C2846672C3787393247635E5F77
2A4A50274E955D2681533F1E4D35297F562F44563B3447274960673D559C2C3057355E86
60215194697C8E4F2F6D824C426D22625271CBAC4D1C985028928D3E39A15B368873542E
356E783E71773B71533F80628A647C866434587A5A732838624A7C6D23426C5665783376
5065774E487E5F84543E834D4194734376904992B07D37388256446B7F3D5E4B808D4344
9F9C7586C5663F73B1506A92A15B68A7844B99BB587EABA6436D4C204B5487713C475E53
6E564E74AB6F398A5E426F6F5590BB6A50A37E5534948F9C8A3C6379687F543C54875E41
6493713E945C6F475E75754B6884496B6673648C9486C7955388B893354C642A367D6742
3146802A478F95633E6C4E1D576C348865319B7478D3604331567272372A757C
6A9A5144438846459E7C25646C352C5F3B4846597943694A4A78293C8C6E5A566135466C
435457322C5F4A2D98484B3D4B32317A52354F503B485035646A5F33468A51386845344A
5E2F217E566C94853D9A76573A6F295F544CB1966D23C15C68BAA15E42A266297E73324C
678A873A7D58448B5E3A6C4BA172695F6543827752725B4D614A577E3F3F666D61754A7A
56748157506663904F4C623C5AB9AF8572A94078B37E3E579F5D487593457D5E52657351
81705982957160A0B37681998B2A3F7C763F92AB45555C894E7F404B733F585B3A704D4D
69772B599B7136873E4C867D4B8FB87268CDC06A4CACA4AD873A6F767083673258906E4C
6185272E96826F445A85283A7276446D5C275F91937EC4A8528A98962F48638353B47247
2D38974127588066526D5E27614F1F6B6635A56F49B68060396A7A7F322C8096
6091505B476B4A69B1842E74884A4D5A28403B5C5D3E72455670283F664F4F6D693D6380
5154703A3A5F4E329C3F3A34411E3E7D4C3956382A464A2E706B6B3F4D813D386A50564C
673D24676F72867F389F7B61484338745A4EAFA6283BC7723EA08E3138A56A357F873325
2F615F276A3F20574E3B5F2377676D6737366A7E586831617E5366673E6A8C6866644897
637C5B38757152962D558B4037928A5F68854A84B54E3956795A446964468D675E6B5A66
B8955D9B9D383E769A587EA292564890604FA0B35C8E606864805421553F60512D53686B
534C357CA24E50A2494859413F9BAD544665898062D7DBBD8243908670943327568B6359
8E8E5C28855F344490747841647C486471596D5D8775B5A03C7A8B6E2F72AF8649A18827
3F83A6562F5B7A3B67A9772F5F5926705350C2815ED19557467F7B6B3149ABA0
636F515648743A3978602C662F2F475929322C605C33552E657030418033366C7041645B
335B6C3436631B247D44352D5A332C7C2C3D7B563549312B6F836C444B7B29578E5A6141
4F325AA07A716D4E42897A4D4B28154C5A4AC47C27177651349D9E1A208166367A87383B
407A64276545296E3E3C6D48845E5B5A6F45768D627152467D4D61853C416B65625E4779
507D7E549282588D4A4366503D8B762B548E428CA777485F8D5D3B62853F5C375D684C45
77885DA2967077989C5B8CC1AA634FA1403979A65B9569963F624F2D6B499A7C3E5B4B28
4F866296AA502B6E594B5C392379A45D5FA9824C216B818B5B2A66486EB46B2D5D83322B
475B3C2B64384C303B50533E71543D979B6E85687675D4B86B8C95651F4076925261692D
222F71562A5C863F3E56482B8C7531784C36965F78D68027409EBC6F281E5383
626A494F43954C43A78A29778F3E2F612B3334385D56532347612F3B7264434F5C2F5F6D
354955353A5045317B2D44314B2D2B7B433C4A342E4138265F5365414E8C3B2D68547344
4C262560515D636A348A905B57422063453CA8654324B14A47A7912C2D9D5D2F728B4343
448571326E5F356E46426A51935B4E66824E88936B736852864853864A4E6F6A5C5C4F91
4A777F4F6361608F4F5D663F348A7539357F499DAD6A4C6C9C513D7A9046603866677A66
818368B29F8897A8A53D53848A5671B66047A79C407E8F8E4965642F6027527B3C655E4B
395F4B97956D39925A4C68644A6B895F55B3754236A0A26B4E2C6B3E445E563E698A4E31
53522649934D6D37485A5A578C5B2745524677643C4179875B96AC7D2F4A86714E5C6D3D
293D894C2C7DA05F475F41227E4C2E8E6741AA42339B9256375E5B6A3B276A92
699A5157439C4D49A58B2E79904030682739445A754D644670773B4179775367643B5F7F
495D5B354B5E503B8F3D413D512F2D754F3E5B382E332B327152673852964E41765E7A44
5D4E317D554E697F419F86597D67336C413EB3705221A63D4D9C844B3DA4713F80AB3C49
4F7F49318A753C7249648F548C635E7987517B906E8063687A4C769E4F50775173715690
45948F506565477D507465324A9C6E3F347B2F558C6E42648F325A9C99447828405C6A64
8F794D97A07980BAB27469A1873B5797734DB98B315F557542724F52793B6E7138845F4E
3F69276B915A338A485F91603F70A2705CD4CE6446AFB89E5F45946A6172403A7F906537
516727265D55643E42692B468B6B395957378A7A5768899156B2D395304C843D3447492D
2739772B1E5B7B4755AB8C2D7D47174E63409F453FB2684E3E87816A254E98A0
689C4E4F4D84484774242F767E382C6A273A4B686E3B6D43777333567F6F557462356573
45624522465C543EAB224C3C482340764D41482F25524235675044336AAF46456F356582
784E2E7D49426C7740B5682B4D4F23747D52BC774E24B55B3783763744C8701D586C4D50
81925E2D6B4A38803A39634DAB4649675661B47C3F654E938F35455F407B9E4748504D9A
50625127897C4D772F5FA0443072603C597D3E6A9C5A477FA65C33686F4B845E515D6F5E
B0735EB2873139ACB97763A4A56866955451C08A3F8169874470603880486C5C2E887455
41562E797E5525703F4755382D70A3653E9B918959BFA8B478265E6663815A3569976E3B
4C5E492973736D333C7E5E44856A3F604F255E757561A59E348C7D802E48896E546B3D27
3D75A570255669113A575426754D25686742A96041BA603B3C7A74621A23427C
5E835755406E4C64A96723625C3A3C452C5442563A2B67396F3E1B41546C4F7353244D56
43733F24475D4A369B3841395827235B483B5433232F372B60563E273E6E39456F40436D
5C43347E4747574432926D3C5D372B856C40968826449550369A861D1D7B5E2E5D7B204F
6C8068307A40225E34364F3D875D4C60533965795550385972494D7038496258654B3F77
3C65734A8E5A5262426B7A41397C652835763979905B36487A57337B54286C615A6B425D
AD9266BB846E69A9A86D66AAB16E6A966668D2A44E8476696B89632F5A3E6C783C7E7A4E
4A6254928E6235964E5B5B41386B97594AB77E6941C6A06B583467425D79644174885D48
6D654B2E8790645A5F825C468E6C3F706D395959537FD2AC5E95626A217CCA88636E4419
2B41855E2251534E4058512373582C7A3C39896C3FAE691B42A9AB5C31365087
656D4A5441734145896122603A2B545D24343566481D5930A160273B64494486703E5A41
2855532E4A612F2B7C3C2E2F603134672C48705234332D297E7A632A4A8C36678D5C3D91
53273A8565494C4B459C592B584F217460327C5B3C22A1382F969F3226A5672F679C3B3D
5E7771347354326A2B3753458A54495F754B7C81576460738045528151536B5A5B59507B
497C8E4E7A71688D58737044387A6E404980459DAD804151883C53B99B475C2C69747E63
B28C77C4A68B7F88AC8098CDB46B6C954A5AB57742A0A3843D5752286352808C4A826747
596D4D8F9F5961C061516041498FB56F53C3876643C6BB7F58345E45669F614376761D33
50544B4DA08E4A314876553B903E3571773F68442754888A69916848134D854E507F5123
3444694520545C5C4B5459328F62287052348C6C3CB16B4A3259687935395181
67AB4D63439855599A6D2477832C2551262A214F583E631F6D5F2B486A40397A65355463
3F5852355564323F954742435B2F375C233B41492F2E522F5E484C2F4C852D356B5931A2
572A287647385E6745A0622C74692A754D297D5E432CA74662B8995B32AE6C2D658F453E
638D472F8A703C772F49623E8945658373596D734F8B626E714C768D4B506D54747E558E
3D5B714D3D453B705E797B4649A67B436071385C93743B508F51315E7440742D7982756A
B67065BBA6857EA0905056B5AE6787A3636ECF83356BA0824371563C764483914A80713B
75724680A75B4AA65162A5422D599D8851BF767F2E94BFB27F3B6729387A7F47A39C6341
575F26237E7C652F3C77454E976844626E4F6A4D566D96835B84798336527B21367B7854
3F467036348F98585A52471F6B4E2B835B3181492EB4A6743E736560386F7C88
6DAB4D4743744D49733C3E8D822E2C6E29433A573433732F913A2D646E66529B63387582
5958482761805C45A51846424F1E51893A41403A305463436A514A3C6FA74954802A3188
70332C8445416F7B3C8E55204967317F593B46645231A9352B6A735728A56F4051874141
7C8A793B745E328B3F3569488D4E395F654C79513D6C57897439507D424E6E51525A5688
557478506F5452764C86AC402F7D8447638D4471BC84414E935D3F788941794E5A666369
BE7866C59F8E89B27B676DCE8D4F8BA85C98D97941648D564C956031693B795F45C19250
897619629F5A689742466A583F71B8825BCBB36F3887757E763D7C576881413992925C3D
623D412F83765330457A2D2F81704C6B75499A827874A4977CA298793177AA394D5B554B
525586391D4D5754689C6E317241266F51296E5021878F61347063521A3A5979
627B506340714662A25626666A25283E2E54334D322D582097612842544B56A876245A70
4B6C462C4C713F3AA048483B64252A564447565C36385838776231224686404E8A684880
5542408E5D4B5E55409574395551387D6D627F6D402AAD6829907B3721B87E4663901C49
6C7F7C3C9341278D643C5B329F634A502440868C4C5A387D8E4F674930638C636D5A649F
6473703E9265587F41538C6141908B50879A4684B8804B5B9B5668AC7142806377763252
B09C7ACB9A3A89CFB0698DD881417D843077C56C4B769D4F4F8371244A368F7B3D756638
9E825087AC3551A16052651D2168B96B459F817249BCC9B762366A6978A1673D8B813349
7F6E593777763653858C332F696B4D6E72387061435ABAB9B07D6331195881735F5E4F20
5189A46E264851174B68692F67622887542E89642994933C286A63612F4C4A71
6A7C4B613F69374E8D5E27776133496E2B4635616039420E8A5F2F4E5C1A2F638F395639
366459305A7E16308145382352262E5C1539686C503937256278673A47852C609473477E
4226439C584D5D452F787E3C4F672B474B696077492DAE642B91983737C781407DAB4E34
4F6F5B39A0773A745155774591594B6B69426483607C5D6F654D8B8D4348664E8D605387
458491419256387E647A9E464BA97C30727C519AC57533477B343F677638652A68784C47
9F647AD1AD597AB46C4085C499568AA05D8CCF524A86A6853F636B275234877C3D70663D
857F4A75B46C4F603E525D35284E896A48AD7261278FA89D7A3B6136428B72357B781D2F
4E6758376D7E432D3F77462974302D648049936D263B76998FB0C88A2D4F72535360613C
3D45705E1C4053514D615E328058237A382A6952207E9F253BA9AA7835504B72
71A850633B834F4F91642A673427485A2A26154A5C376A30926032647A745A766037556C
5266322B5B6A31418D3A3F3A4E22365B2337405747442A27636D573A548D215D8B70467F
4C25298D4A4D5F7B34776F416B7335886968717C5D2FAA323E7A7A4C3EB25F3655854F35
526B693785763A7139356E4B882D3D685B415D4F3B785C7B5C3159824C44604554656899
5667894E4E4F3F6D4B87A233337D6D3A82773764B07138568A494C7C8B35503A67623D4C
93705FA498699FC99F6186D5965EA9B66A95D06C62C2C8804A65802A51398B7C4BA97745
A78F568AB0814855557994463258A4744CA4605D338879897835664D6A775E3A83934C3E
4D5B5469A484473E4F723523735747546847BE99715D91963D719279284C6347679B9254
554560361B427448465F3F4B9678267C58215C4927668D53203F63773B5D4F5F
72A7516741904E5287533C80651F2C612C3E2C615B307838A3653F8A8C715A8857418785
59643132898244439332492F4222537A394146403E6259455F4C2F3970993B4A814E3EA2
73352D852D4B7E742D6D4425446F3885312F4E8A5A34AD65238C91393CC288496A98643D
5263793D956F3D81614D73478D5B47675F3D5C7F427C5B78624C778F4943665D69566394
5B788B465144465E4690A92E43996E3884895167B67337669947546C7E5977577C715F6B
AF8E96C99B75A8D1AF658ACE5266A8A64985C0523C6E90694C716A4E8F498656335F6647
A460389BA372325D394264573B4F9F6F59BDC78E50B8B1BC724BB87E7D7350419897553D
444B252B6B794E43456A251F775B54554A236B594E598E855C828378274A63262B558856
52464D312E4F89473F5D3331735C286D62286C713169973D234F7255385F4F6B
64894E463C7949527B412562561F2C3D3C5C34603A356F3099372B555F5A4E8A4F28606A
67672122506F44469E3043383D1E345A37454C5E494252415F4A37284C68334F74333074
56342D923D465A6B25777B3E4B5D367E4F55748B4B33B97825877F1B63AA803F6B97506B
A098773B7C5C4D8E5F526F53AB6B49635270A383456B49927A4F8359598D9063665983B1
647D734C9D6B4D62347ABB4D489B75438A7E595CBA705C9C9F4B5C675B34725E7561477E
BA8FA0C08B3E8BA78C4697C87451BEAC5487C657557CB6814C6A6644663C8084417A8E51
A976407D9F6C1C2D3C4F62432B638662418360814CC9ADB4732B6476726A58286D996642
446354406A7E494547651F459F7553595B427E4A48637C795FA2A17D2B5D82425E567864
4C4C5F4F22456D593D744F3E763321724327646B2B4C8D4932577667337A687D
7A9C4A6E3E774C51A3793C807521345C214A2C623E296E3780664957756F48A164347F85
627A3C30566D243F9555654B452A3F663C56856E4D424F49A1763D2A64672E4E7F644087
4B2E33A5546353502B76763F45597C8C3A5182904440BD8227887C2139B27F3C7388472E
46657234725E36744848543E795143542F37626D416C497B6E426E7D404A70505E465E97
6469714B8D6F4C675F8195554B956759A2974E5AB84E3B5CA24C5D687D39684974614C5A
888DA8C47469BDC595679FC7835DB8AB598FD38A719DBF744C686B2F50337F8044757045
AA7A54AA9D6C1E243757654C35598A71549D786839B690A07D396F84767F66296BA8683F
5D885743697D4B5672794421855D4F55724C7D625461AA8873C6C8661D517D5967717A44
505D76792F4D6F3E408B6144936A2D6C5B1D4C62353C9A3D327AA07C21505776
7C8150703D6B4E74AC703C7E572F576B2749427159366133766658546F3857977F347248
3A6E5433597C1C367E5153314A22365D1A345950404533325550432760672A7F94783F81
422E578C515A4B6331627E3D45472F6B47507E972733A1712584803144C17D387FA6664E
617C8739776645935846745C965F3A6153447E763B6F578D713B6C8A4E56875556786E9C
64628153764E476865A3A936429D804480873F51AF714974A34356757D3F5F40745C4163
8291A6B4887EC4C59F6FC6C68269BC913A7FC55D6B99A34C4D6E57344D348B794A705130
945E51C1AD472B3D3B676B292D569586519F6B793BADB9B589386D776A9F7A4789A53C3B
58683F578F7C4F3A5C62412F9B423D5960459181563868784FB8A1782947753680AF9A3A
3B6388643A6E8647347A3F377E883671641C4A6F50379A4F2851717D3A604766
7B494F6A3C54263B7355346014131D3F251C142937274E255D5C4F46524B46977D2E6779
4A5F452E587E4A558947473C3A1C2C482E4C55613F3C4E5B7D6746245E5F243A6E5C3E7E
4929369244524A6A3D6E73395066457E3750939E4334A45A2982883E61B3753275874555
6A805C328D5D56A45B55816DA6694C69554D8564487A61AB65427F72596C77455F686495
54738B4D8D583E5F4598BC2B46A67D448A714167BA77569E93396888655F8941866C4F6E
957893BF756EBDC35E48BB97456AA57F3F89C9528099AB5E4B605751683A8B744D886142
9A3C2FAA894335261E6877432B3C75724BAE71683B9D7CA181408C5D4F7E5836728D4437
4D513B3E57745F4B59623A49986549575C4365696B55908C69BD927929497D5E59568864
40577B4027455352337F40397582387970214B5E3252B35C345F70793E6E4279
7E69404F3E763E507339356E4F1D3A6229502F776422623C80684B544A585196672F7478
5A5F2B2D727540686F414C5553193866395C7D5E3754524EA6833D2A736D354E7D624598
4F283D86364F616B459568305D548379234287933C3B9B4F20868D3347B0874586A15C49
4972883A8361407C4B42556093493D4B334F9252406D497E5941686A45596D4F504F7186
5E7C694B7F4C4B635977A25341A1745EA28D4354B65A547C8E44576F61478A4965594288
A57A8D9C5053C7BD9151BFA16C5BA26D398DD1679DA6A9665665652A5A499052446F5C44
93524AB7914A483523615B3325406E603E8D8E6E4CC09FAE4B2D6B5C6F9376397F9A5237
505E444064705D465B69215CA76C455778506A63635688866AC0A4782A5A9F6F594F6E22
5299A15A334F5F52349F50396D5D2F857522577F591C7348306361542E8E6492
85864955396F4663985E367A5439563B2D5B295C312264337B353A4F5B4E6B9F64265D45
487C262556622B626E3946376017285A2636504F333E2D3F7E62331F5B442C707854407A
572D4F8B3543495A3D787C3A4D456163415D86753A40A86B21889D5254B585428AA65650
50697F349267457E4F4A6A6D966341524337856A4B815F995C486080555674544D385183
5D7A7D5697555168659FA74F3FA472488B853D5AA263647D8D445B6F66618B476D553776
8B91B2AA5560CBBA8F4EC69F835B996B3E94BE748FAAB25960605C334C4188644C655643
9C5161BF8F5180612F616A3E3C5C7659487D5D5243C5A493693669567595613B92913357
917A473E64764E66817B487AAE5F4D5477526A595A80BC8D6FA8AC5E468EA458514A7538
334C675C275264304EA16E38784424884A1742615119892E3178665D1D556A85
94954C763C6736508E583D7F4D2B4148204F3C84572649297154384A563A518E6E2D515F
495540305A6A1D42543E5155491C28593E4745533F484B4E944A2E20613F2647786F4384
4C273B6D3A5239663A8A70393F549D6433669977374B865B1E88B54E56BD884487A95B4F
507D6841A665427345575D678E5E44584537946A537E6A96724F6485595178554F546389
648284517B3F547463AD97233FA9774F93843579A256717C8C476A92686982467F644B7B
8F91A8AC6372C6B189507BAA7251A2693388B7569F9FA441859854304F408264495E4044
A36E5C9D8F30896A2E59621F2D7BA6664A987C654EC5A7A36E35665977B66C41A6A2222B
525E31517680234784743E85B83859866C445B552052846B66B8B55C285B8D564E4F8642
3B737659275E6E512C92483576512E876A1E495D311D8A1F225D7E5C3B60357B
806950763881515F8F56479B6B233F5F2C3F26604D2860329C5922525F4E6192732B5A68
795E4F366B7937595D3F515148235078374A405149694A4C8C503E2D8468345A816E429E
582E3B652752435A4F84603A455EC45D2858A9A04043734B1D89A24D54A852257DA66166
6881412276633C8135716563925171835937AB376F7E6B8B4F769A8B6054654C7B5E5D78
48A3934A6E3F5588569C9B2562C0894C8A5952B0AA5B6B7D56366E785C4F84265C716673
803C99B38C83CE91383D5D9B58519E834583B26F9BA4B0545558362B4B3E9082565C5548
A06647AA9E4F955D2972782D3D4B6948486E546B3DAFD6B67C286E4A568B4832BDA24937
5A73323C658442495B6F228ABB3B3D53483A5D444359965E43828861548CA435666D7B3C
4DA09565446066403AAB632E664F1D69682548605D197046204B4C5938723D7A
7C954A713A8D52626425497656264149517335754B357B389B39388F87494E925C3FA682
70622228919A586184255D4E400B3A6034463C271B4F5C3F8E440F1E88913963602331AF
7C2E3A721B5B7553407951335E4EA956274586733A496636418F954B60B35C347993384D
4E7570359153428A65635D628436384B3D34A74F5470646E4D3D626E5457623A4944487E
565E7E415F4B4968559FAA4134956D4F976D319D9352757087485871673C9357666F6873
876D79795775C59C733DA5924E58A979447BB75D7F9D8B477B7C41394C37805B56845C51
AD3E3A9A964DB27A255A653F4858A655348852602A7F879149367B717D905F40BAA1445D
93893F4E667D3B69927C30628B485168403757565488B38553908B4728586D3A4B4B7525
2C7C987B36505C3425814D2F5C5F27786624466C7F2A923E20444C4F23727E98
88944A6544994B62602E487C4D2541162A51274D102D582B741C1C5977404382531F5C6C
555E231B5A69405B5C334E2B501C39682F4D3E5E424C4643AA6F3D1D6A6232685B332B7C
64273A7F2A3C3C3D4395702F3E3D8F70546298793B4E685B1B6574385BA1784A7794494F
447282399848397D576B518299594C53503DA157586A6EA068587174535F8D5F5C595998
667562378253515C4283AB5745B0514282763DA19F4A4E657F425A6F64429D6475825C7D
8381A88E4886C0AB7858C27A4267A87051A9BF70A0A4753391853D34644272364C763F47
9775579B8B349075315A604B4658A96B3E7D61714BC6B2AE6621618A88B37E47C6993C39
5B7D3E546E73303D69792F497F41476B5E48644C2B5A856F418C9E79326D8E4D4F559A68
53AE76762950666F2E8B592B668736775D2A597A733BBA3A1E3C52593F60387B
6B7A4D363C733F628F4A61864132544D2354286031225D326E4C2059794D499D6D2F6B59
48814F3577612D646F4549315622407221373F533C4A353A7B6D4B2C84543C80746C419C
5F2E51883C4A4030358364373B5176724A88A46C3D618C63308F824962AC7B54748B4A4A
49676F41B5613B714372576182464D52353DA24F54585B88615F6E5A48647C5A64414D7F
6799864D914F73896090A75145B889498A784B90A4525661715178844339764C8E7A4688
8E83B58B3E7FBB9C638BC3913D529335396EBB71B1C19B4D5E773D274334905D4B7F563D
916763A38B4C9B6B3156532B4F7BAF66396F5D6B47D4C5BD8324644C5683874ACAA96E45
708A425A63865E4D7785423B61484F5D6B49614D5576A2913F8AAD793A738F494C537E5F
51A29E5B1C4C6B773085593198872F7E662A437E925188492459956C5A80427B
698850533A7338538648608F58253D4C233531765334673B76562049582F397369296249
2D5458348566294675404F3E5F1E4162374035563746404C9B814C2A85622A61605F3EA1
412B477732423B483F875B34447C65755189A9623552645A379D97446BB375488D964F61
7677543384563A793F725D5C5A3A6D6953348F36726F6B7F3D5F806F4048544561564F70
4768804A7431496E519FA83054B478458C545D9B95485559543A53835A366F32546C4072
7668B8A4638CBE6E3C56B38C4A76B76D367AA35BA2B58D4175763E313E267C43518A4E42
7B2E4CA17D4FB45B357C683E4761985350A399752DA48FA0492261867193654BD0A25848
748D428091956E5078823D548066576671537B424279958A3A7EB473366F8B433E447C37
51B86744226FA876347D382D707F3370893943848F4AA24426295066568A4078
6665516E3D8D474F84426D92692749642D5629644C4250206A541D4053432E7A64255B60
4A514F389666324C73424F4B5C205763354B444F3A5D4B467F6B4339A8782E6B636940A8
66304B6F2D50504441923E35677044773B718B7D375F6E4F4C99844287C0603166893A44
516B6B3D83405084608856817F4A4A6255438F41626280995A53705F5669845D5A3A6689
67746B4170516C5F43A2B25142B34B499C6048B6733F5C65724562805E567E4B6875446D
635EA162428FCD82568EBB4037789F5D418D734E84BC77397D78416D673F8C3761975844
773841845F4781372956412E4C6CA3372C53616149BC95A851246C7970715B43D3984B4D
795D2F514E765250656E283E7B585761413944494F6D9787446A926F2969844031658D40
4A8574401F4B6C6F3778482E758536727D3C43857654B7532F314C685D7D3F84
66715C4A3A63385769354A6845395D3544642C542C40723A6F3D2D5973452E874D32775D
415518286D4F2871742D4F54481A4568396466352C432D378D65283180543A7946383C98
62365A763041493751A06B375A372C6250ABA153497B994E368940316F897B48728F654F
4A707A3C745B3C694287476B75424A5B3850803B504E718658576C5E3B4F715F57395177
626C6E425A45676D4B7A9C5446A961398E6744C07B4949566E435E5D39556646665D3574
7571BE5A2C72B28458ACBF893E7E915077D58F4D87BC7F458D8937375236A447509A6443
7F5F4F94734974413C754E2B4A648638305F593D33BAA194312D876C5D673C31CA6F4553
76834A5A4D7E4B466883333E7F69546461525149487AA7903C65906C226D7F416287AB79
2B906E6D26557B793D9959376A4F3085813F5E9D3E51AD5D3429486F5C7B6191
5D5E4F68357643538752596E392A483B25383763392845246538172B4D30558C62255032
2D4F35286E43175673363A35461C38511B333B462944302F6A6E40377C2D345C4E523384
333E7475414C452B4F8B663755601D5C54A8704D3058593D378352376D9A73446D825D59
49586A3A784E4A7F51846377743D4787725E85314E67988153526F6F4E577161564C677C
60737D46713E6B7954929A4B50A97045986353C781494F486343638B546754425C653572
8374BF674E9EC15E4BCBC8994AB1841B4DBC9F4F8FC75431B18934404933A34954884346
8B4E628B714EA1443774543E49417F56326553443BB49B8D2C1F696A4C61583BCA5F3762
8B7B4758527A584E89853A4D916D58797A5F54533684847E2D58854F4AAB9A3E66749688
2FBE9C67244E722750915E418A501D7156263D7E7064CD442A405E6F19579F9B
5F915379357747538D52609A62344E672C4C2F6F5046632C785618236C474867621F4C58
425752315F3D1B446B2F3D5A481B354F2C4D4D4C2E4C3C32717E47408F5433595157338F
502E60793A4C3B2E83A15835575A224D4BA5A56D3B795B363784583C7E85503F796C4E5E
46435850883946725077649174426787685682357C65916E50758D6B4F585F677D587969
6BA5774194227F7F589E862D71AA734890213893B15A55623E69A0A65A7362438A733E75
657DCB84689EC03639C1A68162C5943E60C87666A8C36025596B263D5944AE5F5E8F2D35
94926B776035854C386A433164819254426950684CBB809E5C2963635B9C6B43C08A3880
A7924583738927609F945571A7366A87716B5F482551825543738F41156279457E979044
2991916B39618F3E256B362D69772C6D8A3E3C826594D677391D4C6343233E6A
6691567A3372454B8A4E619B6034506739583D835F3D732F7F4E121D6045596E5E1C515B
6253432C663A21545E2D48664B1A4756304F4139354A2626687A4948944A36605B573B90
58345280394A4030898B54426C56285A1637897438815332509E4A336D7D3542B18C545E
4B67183D9561425428885F903F2659794F516E1661548B6827526947485A2525504A7746
3155613D7F254A6465BF9D22559B635F985122597843687D2F31497457844620598F467F
292D886F5E9CB63B6BA4A64A5CAF95486FCB65507CA97E4C628F384252338A5373B14C2C
603248916F3E6D27379D491A225E755C35784C5241C6C1B27B275F3D498E69459BAC4152
6D43325F677A433B5F635B768A433B59276A7660467E7B4E2B4974561A685B274F5D6F56
27AF894D203E6D75337247346B67316E81393C8A5275A57435213C5857294D94
888F58763F89444A7A4D7A98533553585C713B795A508A3D8D524A7779414E684C337454
6156285CA34B2D566A333E632D24725F30504E1D43624328643E3E85914A3660312D4D8A
603D5D654066675B818D2F215354334D51988F503885571328596E326391302967704577
677644386B2E575B2F7045945725444D315C6E2A4A3B926A4048514251665F4947346F78
527654326C426369578A813C559553427B63216A72424B55593D5745418C40294F583666
4D5D933F2D90B0679596A87573BFA25089CC926B6FA8925C736C3F6D58458F31498D724A
8B6B5B8678448D37445D492C395F803D319979612159668B562D5D494D69351F6470485E
8F614468687352526E805C558E6B48845A71583F3D977D5B33547A52238E7A305F7A773D
35A3826223385E55518A5B326766335C833F41AB6A75BE522B22335B45298AA1
5A5661463A603E654F25495E374647213943264E1B32572F7D23283A55385688541B473B
586425215B2F276C4D351C492C173C411D43422C34381D1D78542F3F643937553026315B
4C395B6C2B22392A6D8F4A2D452B35584F968A32477C6B2E2E5F463C7A9B5934847A335C
47655A4A7A3D4660456D40745E294E634F517F3652648A755150875740617261544F7976
50707938432B697986B07B3A5C9A5D4E8F672F4F52435260603F55774C8D31495D59345D
7176A5555289B26D94839C718BBE8452A9B6796770A761839A783A5051338145538E5B58
AD8D6F7B63438A4F466E594654659052245158564EBD91AD561E46475D72552B4D693B6A
986B3D64666739699F8041508F644F9D6E735C3234A0A3622E546F3D43948D365A678B7F
2BB982471D4460542E584D318472355D65233E975572A7552A50686333155786
635F546A356334486A367264232A464C3721256D40323C257A493E4933223B6A551D4F3E
3E4D4326652E27595A292C42261A3C4D34473F4642564C266A6D3E5A752E3A6551413764
2B3768793F374C3383825E54644C514A46A47D3736765838438A432E53864238A7935269
4C6A596887464C7C5171547871324E78595F863E546084554A6680534357646856468D67
5171793E4E2965718FAA813F6AA95C589C6D3855614A4D5C64435B853E894C525B804E60
7373974E4792954F8FA5AC6C9FC16D439EAE698992A789764E513360543D7E5D6FB04C49
8E66748C5C4D782E408D4E234B86A56430594F656BD0C3B2882962465F8C773A4385434F
8879396F748E5F578685405B9A3947A773735B2C377D796230506F46207C81367DA29375
2DC1742517465B55314A3C2A62702B617440338B4B688E6E34182B504D173E76
6A8B5E783B7F4247652B58793C3D48514B5F2B7B664568297E5F41454B3D486E4C245F69
5657412D834739786C2F49524028576F3A51402E566949235E4A3C7A854D2D6770593A7C
61316A6D424C5F449082413D52475258527972423B815A3D4791543A5691393277784079
857549557F455E724A764D7A69436A65496C7142695885523B59774A51664D676745976A
67826C4F782972658ABA7E367E98616C9234417A7C49537340567D653E91406F89634A67
5870A85753B1A6406778883F7FA47D54B0AD59635D8D7A825F58306958306F2F5A976955
893E458E584B6B1A3DAF5730455593542B5E4E64449385AF8026706B638868484A934657
8E302C6E797F5E6376422F6C945B3FA13C767860559C6936456E784D1E7B3D2043648678
2DCC8D721C4C5A6137404C37626F3B7882403178497694673317234B501B438A
808067583B6D3E459042749A4543513A4260306C4B4D772A8D3B535D4F3A49653D2B605A
51561C3C963C3373543C48582F1A3F4D2B5938213E4F33225A272B846133356849376374
51306A5A282F4E2E798457444A2C4F6C5D90852E48907B365B8E483F6594562E7C61305A
4D594A63842E5671496639836C324F45387D7D3B4E3770764A5B6044455E60545B3D6E5C
5F5C55775C3B6A496D9C6F36677648618B5B466060333265523F4A413E94394D5D434A74
4F587E3C3D98964E786C945A98B2895EC4A8727C6C876BA59985275B5928694151734D59
81587BB2624B7E2738B743384A5393292772877956BEA1AB41337F5B5F723624538A415F
8B5B44656F7F60759878374D736547A675786E7F5B9C7F6647557049218E914A4D6E9191
36B39784264E4C713A5F5E41552F1D607C36318258A8A75D36131E4E581B4C87
61535A5B3A63334D84407C7D3C5679543B62286B3135561F873434454D425C6B50234F25
4E58282E952B346C4636224F311D3E3D1E463C35504D291F66492F8E431E3A724A2A4A47
292E51613C2F3E39997E556258365359579B6B243E7064354C7F2A32507E3E33716C4375
4C483A6B763F625D51695872743950855B83823E63647453496B85474B525B515E4E7254
6677719D50387E658DA35F34747B5C7C86485D86743F2F6855444D673F8A3A6E6566457A
646A79464EA5A762776C87528FB28176D6A46F81666F54ADCC57266A64276E41586B445C
81528296445D9E4B3BB94A496267853C274F4F5A4ECAA7AC7331674B6B80573E6A733E8E
B35F3A6E73363D92BE8E3F556D68418471856C6B62D2BE6F4C547E3F41CF97475566897D
2F8789511F4E50455F9E6A485F752748733C377E3968AC5C26121A526D216099
7185687040873E45883E7D652B334B3B3C21266E4C323619794332505D34496A4A245C53
50513128822B424C3C2C3F58221A3B3A364A312D3F5C4A256E622E9777422D6958325754
4E2E305D3831493C98752C445E3E522F50A875354C8C582F4F702E35547C3536808B3B78
4B4F428683406B557187538E65426C693A7F7476967F823269A380454E515A626B526F4A
6F7A6A9D3D388B5F95B06A4AB08C5D88803176A37D4C2572547A82563A8B40756E704A94
7470724B4D9AA5506F779353898D3144C09F6E8A6A6E4B898F4E27694126753F4C80546B
7F648989452961462BC23D2967AE8E31325A4B453CCEA9A56B3581508ABA65407A6E2C8B
AC613A776E6B4E546B6F3A52962D359B68796D3128838B5F4953772513999241566B7D2C
1F7B8A59264C5E2434433E5582792C51503065A75D6B6A502B11164E271F82A1
80846B6B659E4658913B83A245486A554D6731855A3A6B2E904C2C55714757685921655E
504F332C7E354D4E4E32486125193C2A375333334168532B725B2DAE7B3F35705024645B
5B3A3769404C73338E6B3E4A5634514E3E645E3D5183542D54792D3550722F607B783582
4853287173376C4352754A82432D546E43804C3C6B756443365473404D583D617A486837
787D5C9C44297B61ACA363245F795D925E2F4E90553623593067945A3B7D307E68733F86
6A7A844E4BA28E5690AF9B4C8CAE746BDA8C749D747C7574704C3669362786394B7A738A
9F6A6E915C4B7C3A28974B352F40614E336357333DD0CC91593486157D9C5C439E70235E
7D3C2C7D6678515A856E344C64382768526E4F3F5A8F5A4E3C5E7C4225AC873C5678894C
273E714B3968884F374232406B882C5F762F407B51888E40382A1E40541C4B6F
7B6E65454B78425582418DA73E4C372B684F35622F556230944C6E8E704146665B2B7868
51472555A44154563F3F49562E3E7D43355444336E724F25641F40A17A3939754E358365
5A3A605B2F4D4D2B895D424E473154496397592053803D469C914137515D304A51643492
5E4E337262386D6A6B694B76592C4B5933737956896D685C52627138485D69536747595B
65796D7A50427D5C9FA2613B89696EB74C31629B54392C624144554D389645A1A77A3378
68A7B67B51A46825517A3E3E94A76E6AD8863F9CB5B28B7E79384577772B813557896E8F
8E398BB6504D6642288456564A455B4835615F3550CDC7A67F347F3D59644350A575386A
7B3431A392895C587F6D4A787F5B42544A7043207B9E4D4B5A8B7B4C29A16B4D8CB2814C
34486719193961523D484B405040428A8239569C49798E4B1B3049685B1D4B81
787B7A6D498D3D4C4F2467843949543D3D572A7144284D256F2B36595B36426E352F5C47
4E5024266533475F4034374F211E493B32522D18444E291E7337249C5C32346427238162
462B6E5C2856432293734C473F34705B689C5B227DAF4D2A53693D5283814C5F505B287B
61522D744331885A634C499766355C4F3A8985585072804C595F3C4B8270566160465E55
6F6C606F494C71428B9C78468C57469B644084B547404B883C50573654872C555D612B59
4266563E5EB8824C92A9633F7AAA7072D9906A9885828C768730448B6C2D7F3957724C89
7D4C6890464969221B744C5D4F515B364E897B4842B38A9C783599676456466FBE7F3F85
A53234666B5F4C89A551253B86534457296D63447EC06A213E5A6A4043BD712F4466582B
386C5C2B23406F37564B464A4F6523597B365E983F89BE3B21121A5466286A90
6B4C695D495D37628833789F425177554F5A3C904F363F3087443063413C548A57264722
556638367D21437A5B3D2A5232284E2434632B22555A3A1D855925A868312D6E512E7327
222F694A335E21206660403E3A1F4B5668B06F2B4B68612F627622394E7C4554516E3481
45442D746A357457676E537765385B4A27686752666255475F693D2C4759566A6D3E7C5F
927139626B537F4C899C5951A77D55A7452D7EA76C312A67317E733D3D7A3278603A6286
54949136419B7233527468407E923973CDA77AC9AE8665775828387263428D384956328A
915594A74B4C672E195024726C57501C3556896152CE9FA16046A05E686B2B4CAA54338B
A86B327F646039496E682D539B54575A4A64593B74CC764B425D6C311D837E41506C5F40
2C4E644E3C6288493C463F68806E255D523D91A2536F964F341A2354301A467A
747C75644C8333456E397D492D5861484B2E2B794B4445197F433759351F26705A31684B
465B32376E334063623E334A342D58292B5F553851532F298B4F28A64D2F4E7E58439E2E
19249543398440267C4E353F4A335836488266345E8C543B8D7E313C566C385B6C7D3B8A
49642A6E5F2D743F5E735E81584E705D357A66636B826A443F504E39514E374B5947602A
5B70475547427A5EBB9B4440888156A7473B6A816E3928521E3C4E53518B36A0786B3855
2C634C4C50A67C447D9E483F8C9D5264B98364CCDA8F68606423688B444A924362442C7E
7745779D354D71461C581E515671693643686C4047D0958C2E346543717D5071A7663973
96633DA48E8759568D55298293434154489F774983DB604184AE6E3C268D7D538FB88B72
464F5B272D878952514C3B485E6227626A2E627A4FA28D45364C5B7C5A1F4A7F
7E7072495C7E3D518E3883953D4F7660556E3D91503C5932954C44706529346C3A376C47
4F411750782D58644B44525D353B6A4138492C245E4B211D633426A2321A234D344C7740
353F982F2D7B3B36AA542E4B4C486353569C54296F9D512A596A35456A6025385182389B
796B37824D3F98617257539F523764553F8F694B397A7F5054582B476260515E5E3B7054
6359447A5F476D4E94985B50925569AE425F877F733829582C4B5255628B296F75664562
4F8F504059B2704187992C306D8F5971C275408FAAA269675E273F856D2D713C71583975
6E1D9EC34D4D6120235D2568524A411E6193853D5ED0C17F5B3E652852664082B9753F82
96253C76737D575D7F45216C88534F3D2A575F5478D9564543546A30278340334C5F7753
3E527D7D3D6C8D6C594F515A677B276E6C2C778245947A4525192357404190A0
6F6C86604C763E55674292A241517F5F6F6B3B8D4F3E5A27732F265F7134526948266449
5E461B35681F64792B383A5B23244C31436E341A5C583D33811F3CA059293D6C52547622
165D7C3B3991152B5E462E432F34544D67A050218E9054376F772554867830435A61246C
4E58369B6B317F606B6D5995613B6E4C2B7067525175755A5351522D3E61586774416854
64582D8064434E3B5D5E5462A553458F3A64BB924052636E2D4C4C326F82478F70425F6B
48854B1537985A40A89C5B3859964C77AF7166B5B3976B6758303B786F37722C435D3F77
724ABDB44F676F1D195C306351574F104B708C4D4AB77977255074455A5B2950A56C3D7B
955C368170865A53837246728D515546446B53495CD15360555879312B7C4845615E7239
426C98853B86754189A8595C5D6C3C976A32837D47ABA655381D2C512120699A
664D694A4F6740697332685D3D838851975753853C44433C9D4720583F44637D41284127
6B652D3A7A1C404C2F241F472524581F313C302B5745252C794B2192322F5A6E4955721B
163F3F1D38841936662D3C764241644B699C4C1D7D823B337F771E3450662E46817C3693
4F363EAB87377D4A6A7B6DA0603E676C48956E5D6B96794C658861353F5C2A7BA651953D
986E418154505263A5812F58B37452AF3676D55B4D373C49234C4625675B30876641465F
40A165455ABB404D9DB962353B734B5992825AB5AC8E6C6B662F44827534823B4880567E
7853C5AF3C79855723592A9694947129626C744258D09251303C524453414065BE533D6D
8E5B3F896E86585A8D5C3C7489515750476762534BCB6B6658638138389A584A647B694B
7FBCA27835B73F155C664F604F1947AE7933786027C4B26B3821334B5C264689
756D7C49507C394B6D38944D253F64578935396E4B44272A7A452150352E4F6844265F59
5D502C3E893E574C482D3B4F2226583764472D2C58643F2C89592263601F34754F577634
2844472144853743652F1C504C465F2356975D248A8242318C88273A554C2A5171792E9E
493336866D34771B74786F982D59897D4DA54F8C798B6D294C664E36434B255665478424
5C69428E255F7E7B9D962345926653AA2445D15158524B4B2B5650377D55328E7D655F5C
3286806172B55C486F7C5432426F3F3F68916197A99389B0943C45877333843D5287507F
936EC8A033979F5D263D1953536B7F4660626C5056CB9B684E386846524A406AC34E3F71
8D593D8C6A7255A3AA6F378782458A6C4267593C3C8F56776156453C6FBA8E55616E3426
437099613CC863365D4F4A655B60368A72346577297C8B4A39282E454F294D94
777980496390405D402589723243543B8B7860956553484792532B49553E556B46275C54
664A2358A550624F4E4E3F5434638A425B4932298A5D38308D402B694D1F3B6D465F873C
3042712F33682A47562F2E604344533B759A5C2A8D86404EBCA33A3F5C442B445F672B99
464543955B345F27645A72821B5378694395426A5683653D485857374339326D4C417339
6E4C3A852D3A736BA6884B4F956A53912E44857A6F62595635787746817A4AAF82626C59
1B725B5178BD557388A166373E511853B8A54E7FAE8E548D7B2D4B806D42763849875AA3
986AC29C19768D4F2C5B356147475C3C68515C1B59C5CF83572F6C4F6D63476CC64F4EA8
AC623F8C6A1D3079AF73388B782B55603E635C273A7C706F5C5D2D1938796D4E6B5E632E
497D6F4874C86939625545938A753CAA6C3D829F44988D563925334E552B588A
A172793B647C426235277073323C4A226B60547551745155945A45656B37526839386B54
643F105B914753492C4035421A275740603D2617585038348215689A52224042257E9868
3740832C36591B4C5A24315D3D4D4E426E755324907D222462732D3E666A395B6E692A9F
5741428E683A63485A49735A38466E623D896B71527B573D54685C42513A448D504D904A
80603B736F5176779E915257A5626292437AA15B5D5C7245309B993F7E5B2DA69A577754
4A9A5B4E87BE44807D8858375A6C2937776E427EBD95827A5B1F43723F925A3649702E68
924EC194225F6A3B34613487524E4F236A4D542548728F8F6226493ABA9F456EBE2E3A84
A1663CA17E5C4C649D67369A8D4E5251385B62232B8B916668636E272E766D4E87A26C3E
55B0413BA98C7B34554E2D626E603C9F39398C9D469D8A31465B867D3D305F77
7666773B597540617B46908E333976606D59413522734A4D7A2E758A793951651E356959
664A12478B30514836483134273E79385135151F5E3E2032813A2F66512350441959753C
254E8C1D394F19506021375D385753479F7F49278C6A4934998823426E68405F7352348A
774D3E9E5359984C5D507D52345075774089737B5EA17C4A54713B3F5D6251794A579D4F
875A4D9A7C69596BB6954D59A130788E4496AA404B9397402056502F744E3992785D804C
498C50429CCB508887752B407587376288422393BD939488551F4696444056336B6D3585
7549C6932B6D60413C713B7D524F5423674B5D4C8B868B79483B3E2F936B3988C54A476E
7E3144717173695A893329A385494C4646927B5229968A89A4A17A2C2D6D2C4651738B56
6EBA8673B2697F3D5B5E3C5E6E6A429664307E904CAF862D26303D623F306298
7A6E8948677B3D697E479085354482616D614F814051432B7A38395A4D2F444F362A5B4E
634D224F993A4F624648283B3249682E45361C2F675136328C38336B462357671F4B6B45
2F51862D3B571D69823B345D2E6268499077542A8570483D967624577F653C5C716A2D9D
615A378C713A7B3C604379734052805448A376844386824F4E7A653F5B5F406C714D7B45
6127447C655E473D767E4056A34D748143A1984349545E4B3568411F775B4EA5564EA06A
4A865344A9BA558B8D965D2C5C8F40679277336BB78C98B473387FA768384F3069634E9E
642FB383255C413A8580406E514A582E819D805D959F92601A58654EB34B2765AC3F5173
775440766C7B6E538F701B8C924A4D543849635A328C555A8177762E3A7E72515269894C
8FC1895FBA5767459E8B40645E5850BD6C38927A4ACBA25F4A2839655D39789F
7263B54465744886784589843754955B6A5D5A8A51544D2F994F486859456D7840314326
6A691E5C962348612F342A562F446C254C563B3B5F3219427E2B3772253B755E184D6148
2575863E32531870602A3058333E4949917F3C4B9B8F543B9B5C1C4181603B6C7B7D34AA
633539907F49753C84678D7741728455397C609D589273436F825846643A3A6C575B6F50
6F3D526E45737B6E8D863169B45A7D69458F8E52506A6D4C417F7237715B4BB16D4D8966
52AD684AA6AD3891B394523368553569A2693586CA616C8C521E4464376358337340459A
643C9F782C7956294746338F817A5C1A5A534D5299C2AD6A3C466052C46C3C6DA74062AD
9D5744947E54649F94702494884D7C6F465B583F498B6479AD9B4F426C7D6B50738B7149
B2C37856C0804C245A5C4492845D388A6550AF73388F9B6D4755A8AD3D296B77
82547D487253427B613F824A3B68833F55274E7549522236854A58814027445A24385D43
5042157A97454435194B2536254D75463D331A307A4526426B285C891E255A5327627926
22575119344C1F836F1C3D66465C3D34766E3D2775592456AC682A4A8A373F52676953C2
9A402D60646A8D30644A9C7421385E5249862C734E975F293D6149709D673650447F8E3C
503E7B8A464E5E69C59E4151A13A8B75486B6D42569E8B434F897135754352A681549848
567D6145AAA03497AD7C53649E873955852D19AACDA98D984243869E54345250A6564A83
5845C3882958543871562A4D3F3746216F5F45296E6C845C364842279B5D3B89B1363F66
6C254F8A9C6059585F24469E8237402D4FA98943257D5A61BDC06D203568377191926C33
8DA33756888876275F4D255973673D8F314F9D9942B4B5674DA2A79C4F2D6B5A
7F5D9841635E3F76694C8F783145893B6D4A43634572492B64263D57673B5353212C574F
4E45154E7E3C493C1943312D153361464D45202365533F5468134A673A1F6624285B694E
4A977E1D2B5C2886893F2B4D31736758848B2967C092353B9443367FAB5C355E69372C5F
6C583D60354876456E3F746B31516132577D638C34887B3D515C2C325660476245496F46
571D4888606C392E4F5F4D4DAB1C55664589732736796A4B40594A31795A4FC24D5C9F57
4C5B4B63CABC5EB2BE773044657337537D4D368A9C7B887D39195676474B434784747B93
4A2C7961346F2F2C806F355C5647482187956A56919B8E351C453B3B8C3219659C474E77
642C3F6865707B698659247A78414E452D4B735227955A5A807A6B233E725451475C7344
AC95493C60577E3C8061395669634E9F673B776D3ECEC240253D3A554E277891
7D508841705056A53D2D6E6334544E32733C4C3326424A308D4C345F743A4B6C4134554F
757C1B4C8036726836254E552338753D6770373A51311C7D6726524F2449904C29507515
1A4048313153237C60422C52294D4E688D432A2A67503842B44C1741755233604F733295
6B483E576056653E8454866B3B4A7353565C65944A91793F4F724643614D466365655146
50324B8E5F7F3C75927F344B90457C6E33875D3A3E7546394154391C625246C55F346958
3B433E358E944195AE6649488091375989543C94A576868F502656944F5073387F737A9C
6470C4582968542C6D632F54574E4B1F5E504E599E9681492E333F3D6E483466942F4E71
5A364681686688A89966246B755B8E5E4F584C402B98608399735F1D4164715E5A647443
CCA84C467C764339887F468F72375FA15D45A461238EB58D4B95526956398C9F
A5619E437D643F55573F86464DAD9B366D455A8B424C31418647345E4F3D707D3C2F342A
50511A46743E413E2541464F1C3F7935343E4647512C224B5C275A5F2B266443305A6431
2F593F234E5522895D2A39623C675477943C2C317E523440BB52314F98523169566B3495
6340484772666B44874C87583A4B6F5E71535F935876653E495E424760404364616D4A44
4F39539E5F72518783853553A0497665296E6D46417A4D404F594E26766553D57A4B8858
41443E3FA09035688182544D99994166B87335999461A2CF6C32598D4E525D3B856775AE
725FC455337D643873593A637F69642C56445550AAA38D473C473E35685B3B6F932A61A1
7C3F46956A3D635E603B5D9E4E335F5F5C8B6F2E4FAF6E7DB185573A807166685C75602D
AE8D455B8B99762F544E29667A4953882153B37140B3C55F52CEBC9B1F206B76
7B55783A725C496836369046274D76325C225469364C23348845336444315B64383B6E4C
7352206A7F515347344C49432652904F504931496C644B74592F857F3830633E60A77F5C
385C41135E6328895A1F548F447139438B6F43357C4E306FB0503453A22F326E837B3591
71314B717862735F7F4B9350587E7B5B745F54A16179624B77733E486B394F7C74675D64
7540517B3D8F5B8293822673933D5F4B2B849B4040783A3654674520705641C8674C694A
4A414F42A7883B66758B4F4EA44D2C477B84398E9859879954345F6E4762463D743D69AA
6D45C351358D703C77372844526B6E3041373D33959CA165474F371964733D709A283B64
581F4B757E7367784B302E6A693B561E275C7E51389B3047A6AC411E506D375483A78343
B36F2D335C678A3C62693D5C6D3B5B6F3C3670612BC6C639294E57833E256973
8662AD3C74684D7642266F513C733F235B344F29234243447E2235806E40726D1733566A
9C4211538C516740213C4E1912327035584F102448422E803F16556833325D1C325D644D
4E955F324D6326896E3E275F41654C5B7B4B3042955A263C6A403156A72720385F663FAC
8A3B3E585C66593875499C5E3146635189593F905B8C642D42664862886149614D7A5244
562D60914F6A3A62A686314A863F524E263E9055407B6F4486B75E206D564BB36F4F6C4F
524B534DB4884D7297B44C52A3883F51566146B4A17A8AAC3D529F893D332D4979596595
3A4CC653356E493B94643045564D4F25413D5E4A926A8B52495C4337544B409DA14E4D7D
53294A765D726F745D42336C5E3A58413A4873633FA75A47808E6021534C383E346D6C43
C99B433A66585E589E833E5F66307FA1483B883F1F95B87741904758212B7089
85508443794F6DAA6038952B375F81254F2B6B6125352A41793429624F37809935322F2B
6C611F67552458602E2958461D3C5C1C5C564547594E3A81612478552E467A4D427D501C
274E4F3163571D5A744B345B26775A75874C164370612A54A7463758A14231575A343A5D
865B5B572A7784486941A477404F34196C6A5375319F7F3E6A51304C6B655158196F7559
48145B8E5085423F55803955832F7C893741A3384A86673847534228653A38AF68608140
6C867554BF8F314C6B8B4A5B8F744165953C1F87826094AC2F236B8439592E3B6E4B6C9D
5A599E5E378326389F6C32475E523E297284705AA483B52D3055563E592C2E63824268AE
7135476D5A4C88C1684A35736950794B3849746057BF6E55A186602A74525B5840724F33
AF9E51518156553F4A66466D5945637A48397F733A93C8743C83565A30204080
9E5AA645814A42824D3BB16C334F8D2A4B1D4D70395238419459305E32244F6F333A5744
66532562683E5142282A544C1D3F66293B3D2B3C4B1A1791561F7A341B41654548895743
3766381D676B2970622F3E712E4C46796B4425334E4F2264AB2A347C8C452F6163634282
85536E7A4C5966556C347A755764615F7B5552935977694E978052506B676C8E72716C84
7F3A428F5E8F586B7E793382982A554D2863A9563E6C533C6E8D461C64613DA1355D8852
5E525462D3944E536A752644904B316BA27435817D5B58723F2462843E6052307D494D81
595C9E38428852367A42447F8E704022524E6B57BD95AB3F3D5565476D6B4C678E254069
7D3949657258669B523B3274494E835F2D4F5A3F79C582619A76343C8D6E744F50AC7D48
AEA82056A09F6D5B533C45B98C49737749408C6B3BAAC76F3A6B596D41253A7F
AE5AAC499B6950845A45AF6E37539033733D67853A4F2A1F79522B587133556C335A7749
64382F786E394D37363A56252A73743A4C321549744C27663B29A44D293A693467956238
4062341568632B856E1E4A7337773278793F2842583E3993A0403A44912F3C62675A4383
8A454B61476F604A65429C564658666289683D8A70995B386774505B6D52436955754F5E
5930575D4374506F8F691F4A8A3E834C253D804263A05C2F77986C216343457E584B5A44
8B825C4AC17F314F78593D66BA8C3C6C93603B928F665D8758276F553A774B3F7A7D5B91
585176323D7C4F387F38284A4D64482862583F44A1919553585E4224797E4475934D4C71
8C424E736E6981AC61422D7C734E61531D44675F7EC6635FAC9659235F4B2D2F3E8C5F3A
B2B25F3964775A644F57345A6C3E6D711A6AC25D3F86C3494A88948440263368
7A618643794E55833137875E344C3A4B84335D5B3E6A612B7A454E7C702F516720415743
6A5B1E5C5D39723D44314F361648612B534019386661317D301F80592F4F72473D675A33
5E794028674420826F3A34572C6E46736E3227638D4E296C943453739B462A5040475A92
905A5A622C837B614C34856E4F5B363C806B4D663F786447864B3B52726155592B716164
4D1D5B7C4461344774782F4F6F306F532C4E772A3B704E356352342D78533C83496F7935
57433E67D0723B3A6D583273A483396EA56A2D99764C65933E3A847A345524697C6E6295
3F4797525089575CAF653E564959323B94765353B87C75366F7F372D87664A8588554F5A
703366A16B6088B0483257AE82506735235C604D82C9466DAF984B25643C53463B853E39
C9C6794D7D7864875B6C466670476E614035726B4775C027244162844A2A3567
9C5894437C414C7C49418A464B7F7F365A335D421C3D2F40602C28423538627A38553E32
78612C764722474C4324573F1D444C1D5055393D563C359A4D21963E244C6B4F3D574C1D
2A57482A5E52368785483767296958A46F472C47525F25728C263E63823F2C54463F4870
9460586B3F7669547956866D4F516F5C7B5D5196759764427C7551487464506A5E815B66
623D6E8E537138668B691F5B6B36843F2753792E3E6F3C3566502A1D685034454E555F3C
71615D69D35C413B7B613D61A28F4171B58A35B77F507C8C35248F8A37512A35565A827E
4D4C6D41537E463E855D41554A604E2C5068675BC58B76324B582A257B2D3F73884E4F52
62294E69695AA5CC592F38967A4B614F2A3C4B4781C96764A1935522605168454E974638
8CA871589F72287967694E7F5B317D8E3C3C86815781A84630545E893E2E417D
AA609B43995E578D4A41A058314E7D3F64276172293B39307E563C485128465526515838
5D5E3364703553463B4A8B3F1C416B39443A2438605B2F9D37258B622F48774B38665E32
4667461F6A63338C7E4A3973396C44877340294E57622B8A943D4A51AC4D28574F55547C
995C757E41785E5D8261765854575C597F4651927C9E564F6E694F4D7565577459804D6B
5D36758C686E4376886522697838833E397796473C665D49685E3D20704F3953586A7149
81626D81D95757379A8E3A4CAA774884B07436BF51327783382BB490437C393D5A475D7A
4E607220597A4A417D503C524B715C3C5A5C5870C4B5915A8682472B986C458BAA574A69
84365E7F53457BA84D2545934950814623493F2F66C5506CB17144348759694560834D37
8AB25461AD7B386C41254D7F7039716B345FA55B2F848533356868702C354C64
B8659942985D5E82494AAB67416D8B417A347F7D29475E39915B374D7149615C25536445
595331636636503F3B4C9A3D193A6B334C351D34657D379B36257E552F4A7142336B5B32
4E61271768693489653D6C6C416933987A3B22505448258A913C555CB04133636B5D5B87
90536B7E3E8756736D547446645D4949773B3F6F839F4D3F75764A516D466478588B4885
65357E73688E586E886A2C897E378851385E6246396E5F3F8991591D796F505562777148
80748589D45A5358A88D4458936A346A9D793DC25646838F4934BA663F6D2A4970616C97
508188237A8E5048863A416D708B425488743C498B63713399AB454BAC75589E9A385587
5827616C815970A032166AA26034623C276841225DB1396BC27F361F5D4368467E8F4F3A
80AB3E5492633684484E4351743B82771855A6915589983C3686928036302956
C06987458C576074324591553E787F3F7F2F7F7722534B3B905039495B456B5429755F41
504447896A3652383545822F1F486035592F15356E75318E253A8D562E4E614252875A2F
597238255D5B3997723E5761468134887032225B585D1F8B86316A94AC38234F573B71A4
9C7B648136A275705057A2644E5C322F7552484344916E356945456995624F512696655E
4C36987B506D266AAA7E266A523A9A683B835E2B3D7B603D574D441D743753565D7B5E29
6B676B64CF4C38739F863C4A908E406DA85034C97F458C8F1D35A97542762E7096657FA0
3F6C98475F65286CA95539494A6B2D5281815C68A6816E2670762F317A2E67B1A14F3E77
5F284E4B876374A67E2F4E9162326E321D5557314FAE1E3E8186471D5C54462E89A27846
92B27373A98149AD8C4E435676427C85303E7A8A5483B4212D51697E3B373168
AC78864161395B843F4B79334F9356608D2E7371216849498B4A305155426B3B275D374E
7C2F31753B376E2F452F802529684B327449194D69612B8839358937357466342E564A1E
52634836714A336E6C36684448654B93883D2F6C635F1F8F561C566C963C24545446767D
84876F6A317657655A589A554D677547744A4D947594723B54573F5876645869538D595C
6234778C5D6833758F67217C4E317C5256AA5C1B58784E3A6952241D924B5344597B4D2A
6C535C56B14653949F864174B5843760A74D30A750429C884A3BAE817E8B2C365948AD77
637E734177873B528556364951694590C08B5E9DBFB1653670742E3E80313E587A4D4195
4F26505051379ACE7528639A6D4371874561592F5CB16665775C3B1D604D353B767B7243
C5D16276B0692285814F474E443997A537497778549C96472B4E606F354C676C
88728544774A607D3A54A2582F5D5D3A5631643C39763C4B5E45436148447D6521533040
5E452E7A4330472A2C2D6335174F50223C3D2C3F403139853638711F29505F2F2D565C36
736C402373604E896E2F6E5065634C9491313461554F298E6333766480342A57513E6467
7F8683703B76475E616A873F48685C4C632A5685828256394B4F4B667D5B577057734E64
623F828761683CAA974847A9792E66295093633741636B4369631E27934A66596A916138
7663683D8B4B41A28C704083B4803C71BA8039BE5247B6944F42BA5C507227306C415970
609580227076505A815D6393A6904D765F606E9AD5AE563F74642B728846485E89334BB7
6234514D59516B8D622151802B619270424C393088924A6085633620755D894C805E382A
A6B13770C29F3A8E54546570602C7B882A55823A1F8A8F532D546D431F626754
B5748D4DA853687C446EB565376B6942682A6D5B21523D6C783F29462D37596028685544
543D5EA562334D323041633E1C59543E452F1B4B6953376F294073332D5B512D36624634
66622D1A605C3C9B4B288350645549AE853D27544E5538AC7C3772627F2C4F7D7B504C58
7757CB863A7749856E636A3571795A486B206D7F728A54606D654C697C5E928F4F6950B0
6D377E5D81905FA8964F217D73316D533B7C664A42684E4396A63B1B865B69694CA8693E
7A664F5DA4584DA4AD4F35589D5A5991A56337C37A4B9A8F3257B17C536B2427603E6C73
457B7E276E5F3F5D774B4545396741615D526379A390573D825D247E794E4A5B9C393D9E
5831647A825384B13D1E779A5C3B6947426C342D9181456CA96F2033885968418E7C492E
84A83178C592379B5730557676377A6F215582874574A53638748A792C3B465C
B17A55507F476D602D58804C3B583D7393397B593B72366B714D5986613A482E387B5343
47212766472D541F423E561C2F6456333D2F1269684338541668753C286238345F7F5439
7768131E61573F9A4D1B66455D5C2E608852285C48223C996C335C678C31214053485F70
6F5CBC5F368A4E62615F8538406B5C5362405D7D6F8442285652445B7245566E49775458
642D73726E7D50A5AF72338E6946A1633C986A45506C945455524C24702D7A795A6D5B4F
A4873F40B87170C69E8C4785A569375CA43E319A5854B882473B8459626435797B477E6D
4F897C2B77703D7D8D3D2B394C4525676F726D8497A34D2B807E3B7C822F61989B524487
63284442745199BB7224598E603E7757334050257A8D29537467351B535639248D906D4B
BFB6477ABB9339A8525B4C5275316D73274E70825278983D223E5B7F33444E6B
9C9A764D7B3E728C40618A50436C3D3362294818336E307825313E53413E4B342C554561
773F35893A4D725152364A351E4D4F365639226C431C54602957691248816730294A4238
7771451A6F31388D693884495F5A5B8D8D293C866A462D9B4E388BAD80302B4553386E62
685CC752319358683964904E426744495537615057896537573C6AA1915E65503D8F6E61
3B3B847A72631B698E59379245378054388153277A928149565A49479D4C666C5EB26735
544F5874B44D30AB8951447DAA764986B27538A36252BB6E424DAD636E67233A57409E76
368D7C397B6E2B58723D3E4D55692B544F57538DB2B34C375576357C7248495691505497
50254D3E67497E826922547C465C9B7049415B297F995C737C643720637F8E2A8F6E4343
9A8B4881A4833AC28B4C54455D2281792652624A497E7639293F59612763615C
788A735199485D83508C792D4C7D544B55579D5A3B7A39825D283D45304E765235441C38
6832377C2827513E421C5341274C31223F4C39714B32593E1B70641D1F5650272F4C2A2B
52582D1F65464B76432C7D3A3D4B5CA46A1D2250533B35993B24426D5522354C583B7C45
5655BB4B2F7F43715C6088464584686C5738687A6E71513750374C799067656148825B5D
563B75746C4A399D994141AA6136744C3D95532E475A573C564F272789477354506F5149
A050354BA4552EA26674497EA55E3C74A27B3F946151B35D365EAD6F6772284A4B46BC6B
4F8C632982793D697D334E676C793C6658465562687B4239687B3894714E596180334A7F
3F2657477B59868D6B236383513E68585A4345368E895052874A242E818A8C27926E6440
96822792B76432AB944B6F5942267D772758663D5AAB593C2F49595518493F3F
AE8D6C56AE4D6A694F80AC58406F4B6F61327C4C444F2C7C61313B4827375B3D366A6557
5D2846923D394A3539366238264258344B523F606F446941207A702E2A5C502E3A54504C
5F56221C664F4C764C2879454F43479470372854513339974C293684541A263B644A8048
5B4598472F703A7C66627C455B7A5B755425646E787E58475C485CA79A6B757A4B7F5E6D
5F4D7E66846D539F95423A9B5E438434439E532F405456405F62253293307B62637B3F4A
BE5C5A76A74037A984844891AF7A4390A44241B68B68CB8D166EA46A7B67316047399B76
599B652FA3824078792A48555C894C67596368837574483B6869246B5842828390495078
393363576F4C7D7C3A1F7896554871405E513D36896D3C6DB76C252955393040BA9E8559
C09C177CB675359961116A9574287D3B226FA55F63754820416687831D61432B
B194685BAF4E6A695683B6584A6F49476A449B544376377466362F723F3A5C353A757054
7E2F3076403E533546335F3825455D4547563D5E7B4B8451288B71342A644E314A67544C
57633C267C593E6E532B704A54445B7F6F3F2C575F2E52A15F2D33856526333F72438A66
72557B5B3C71365B6A668C4750795E704E31617E7D7E493E5D4E60967C638661437C5071
4D5A815E704F42B19E463EAB5555A74E3AA16048476B593D5D5A2F34923A75736B7B4F49
785F727DB75A2D9D8D3F3687B67949AAC6443AAB3058A48F3F3D8246A47941A58550B774
457D693796642B86833F525E5E7B2F6F8A746F8E708C452F8A82386C5613698F8F3E5B81
262A626B564B9D97291D77854947631958655E3A845B13467E68302A6346301E7E7F3264
DABF3692C37B319B623C4F586A2673601E4F8A636C595C261C275571225F4560
A6986379A14B748D608CBB534C704A4B7A3F77345D813B7C66525A7847485A3D2E5B5476
8B333A81285768303525652E326A4E41484F3064763B87411D766A2D2C6A6B233458494D
6D743E26763B5E8958315A3A575E82A0703F3B70633D3798472D5692631F353D52228280
723E8A4D36914B764E709B4F5C5A40656D4C6A223F8B6539501B638F816F703827945E5E
135D9E689A6131758F6342BE384EA35343AA462E7F896C3A534C2039903C775870B96754
9C534775B7773BA09F3D3186AA6C6BBDC37247A86F58B07A434998349094273B4B43B64F
224C5E41C47C22666F4A9B9F9B8F214C69745F938F8C40244B723A6A6B455756683583C2
872D435B28139BC56B21657A4546664950414D4089452C5B78513068B59D7824897D614E
9A9442A3D18E33B36D486C5B601F8C7B2555845A825E573223335A72225D4273
86AB6484593774836D964D35678B3E5E3C498941514F2E9142414D2A2240623C333E2546
6A32739A233246303212582E236516274B5728422D1F9C50247E441055845F1D38531427
475435478A223A5F4D25592C6E5B8C9887152D667A494B98311A205D4A1A3943622D6843
5F3D79442C7B455D3B54824A6C50364B684A6F3D365F52425B3C415C6F76775E3A6B5966
4250795F9276487F943A7ECE7748813265C34C26415648365D5619388A39763B437E7B5C
9D471B3C7D5D25A18C7F3B96842046A9A5794994725BB05F3A5BAD6B82752A634077CE62
86A04534797F3976512F3D51BDAC4C64557F3E9CD8BE5B536458358D5546628B4014529B
612B45495E3D758C672A73642E8AB76D6A46534AA15142686F491742638F74238892856A
D3B03FABCE8A4CDAB64666596127A77D235483629A684C31282A5155187A6E7B
768C588C7C4164797087783C436B3E6C4F3C763A5650246C583C496C333A4E2A55885250
501A447F40454F204A2B5B404C7E3645414725533F2280391F83480E275B473E778B464F
633616277A4564713C1B4432422F8E99562126416746488C5E2F2887432A5C5E673B7646
4D4574523E7847896B69716EAC886A7A7D4A8C785D66436F6D58537D6A7BA473496F6881
5168603DBBBB5F8C8C2849B2665384214CB998524760395AB09740428B3D927E6692635B
9D58418A8F3B45B493893BA28C5257C2948641787461B1473759AF75A273275E4C3F8594
8F974A388B60347965382916827E39875660367F878E704254451A80855461A575375E98
4232514F614CB2955C34957327355E3F60443F7EAF854B616F69213268855C4093947455
D7AA38C9D874229EAC4B6A583D3DC49726519860B9C269342326572926939582
A5B25BBC9E4B70647AA1B44C4C482D9076506D2C8A933D945B4D6990393954153B62544D
8A3343A03F3F47364729471C357C3C52443A2F69673999221F9172273971273246532F60
7E4B293475365E742A256A3C56347E984024323D4E33499B6432298F351E3F5D853D6548
3532965B3E602A9961615E355F715E706C2B7E6747793144745C52723A41AB8F44615786
49676729808C5F969D4D56C06769A54D3DB175465E6648375570514C6C2862955B8F3B33
947D5A8DA121407F84703A9D9C7469C7A28E5C928D63B0634D6BAC729A59295B5545A15C
7F955F43BB813C7C70322A17536A309D645F67998F6C48419167377E5D4998C27E3F5B81
2F3C676B7052BA9221219481393D5F30795E3D378E483089C08B31306633182160724735
D3A1368FBF6224855E36A4853617816F2653A4467F8B5231232E6A4B17576130
99B75482864A724943779C494A6C387C715B7A2A507046A73A8F977C2F2E623631696D4E
822F4AA04039483E53276635337B404E532848817B3BB01231967B284575533144653E67
945E333376416F8F552350404E3C8ACD4B313E3A472584B063405884491B3846594C9378
54426129646041734D89774E6F61648F874C7E5D436B485C5D396E946C6D9D3148695356
34886F5E7A59439C9B455E9B369096413FC43F2C7D7E55344E592D6F8F3E5C5A68A6393C
674D4D99A5373391827245B8AF7266BDA83C63A38C59B23C18709E538F514FA0524DB148
618B413CB9793D7F7C3E342854602FACAC8C69988A905A2D53603B7A3B1F49616D405A7A
53263A657650BB8D5726658145425B1C415362499F5D20526A7E2C356778432774774940
A7D864C1D5712BB0792C747D5F239F2D1D71B36386A640132C4C7C531A657F68
88C75F875F518D677094795B8B94418865609F446E8944A24241755044627E37353B446C
6E27456F254B53363C20722B27671D567D3F3133183D912B1D87402A7C6D3C3448562994
A75830376B2B67824E2762366E394390824380826B284D88432524733C1C3F4559315E3D
613B5C3C54523D55486F47486E5C5067733C66614F4D3D5B49395664676C8F456E4D5255
3561464E78505A938A325A93477B9D3A43984D346E60453951461F6589386C574D945C51
8253338CA34533517A4037A79F6D6CCBAC7F529C87509537246F9D547E5A215E524FB552
84BB4038B43F2F8D624347527F6C2367555366947B69444173643F684A3E47716C3A4F63
502F406A6658B3844B276279453E62456735433F9D3F3E6F6F862B3C777E3B2A75856667
9BD564C1CA5F2A9284337A77462A96471B447F5076C4401920295D2725808374
81BF56887B568A6C73866A3D54703977296C9044623B55A7644EAA4222286C3131603D4A
6F234C762C2C3D21371F581E2A5129454F3B3F595F4F88301E91571A465123343F4F2365
8745253668376C7945265F346134849E4D1D4D4743384A945A2C2091521C3F3F4334773C
5E3162335A6A486F558C4D3F726D5F75723D5B73576D436D6F556A687A62945E7C595E5F
4372595A70658BA2923A65A45087A24846C1624C5B69573A525A346F9236758B53924858
87715B888C22246F656239C09E7171CBAD7D4C8A7A559343357F9F53654C2C5F5257B064
656C5237923D2B664140567B806E317633395A965C552744645C326479474B8C7B415083
5D3046714E7FC790492E5765417D864B763449489C3E43795F832A449B7A3B2A6B40302C
6BC25EA7B5772D755B4082632B2999661E4A823F76B85223252B5F4C1D506C60
ACCA5F9E8F5293698B8E80435B7C35966071893461583BA4577DBD873A2B722B4687574C
6D2159934839431F4630521C345F3A5A50354D6B6B83802324B06A22505D373C597B4289
7F4925406F3363764127623F803D8A8F3D2A605E3F2E6EA05C2A1C9D47336D7655407B43
5555872C517851884C9A4E5D8C846A6778536B684D9C4E978A546868695F95506A658A78
447B625DA8628EAB932D96954387A24E5DCA65455D816F4C696D387B8E3369765689214F
936457968E23267E57633BC38E6994DAB87D49AF8380B35A38868945644C2F6C497CA358
8E876843834932653D426D8BA46D315934374EA79C702F43543F2E956F3E4A90372768A1
4E2C396037677254582C4E5427446B4F6C474280CA77447460532D6CAF722F2861673F43
ACDE8790C97B35785448AD957E2E8C3D2A8A804370A8632A4D5B805C1F526E28
A6A244A680558443848C964351533FBE79824A358A73448A3598BE8433376D1D6C925043
393A9DA44D48422C622943387186395557308099698F6B144DC37B2651534060A18C4E8E
7C5A34646C36677342476F458D4693C65C3A6D743D2D83A258231C833E1A375E513A844F
413A702D4A4E3E593C8D3237717566605F43494A53843B765B3D5A5F3C37623C7B49554E
33703D3D7D4E74B7802D6F75348D783371B85B39617D3B66A077377D564388754F932B6C
C27A6990894348B08F7E3AC5644160BB954C62C8815FA66842A18836534B3368387C9C70
6F88573CB3573269394580AAB37F4355415A2E756B6742455B3A1C75553C659F5B334382
2D3C47444764614B4B274A66313F664C63352A43A7713E726D7E25448F58252260661B1C
95D969A5D0933169341B748962279728134587685D83771A202655231B486663
A4BD5B7F7B528A35324B7740515E2387516F55225A6343802C488A6A333F7B1831614554
4A184F75393F4323413052183C4527594E27686C67AC6C1D258250265E3D19273051308E
82291B4A65325F7F372F5D466B2C719E582D777D58395896572822934D1A3A4E3264C083
733E6F2C5B624E5140A13344746F5D687052373F577E5E9F5139617665475641915E7D41
32844953783D74CA97467F7239B2A3416DB54740708C5D476C5A338A7A32585469AA4755
635F6D9FA43A2B838A534BB8B15663BC902A3494665AAF2A1B829754554255A1556B7544
688A432E54512E73403D718B8A803E7B816D607A6A91344897703A8751197CAB79364176
113350614F656D3E37469E76333B442F7F683C4EA3403CA1B095283668343C768069191F
96B2297E926D2B7142256574562F8D3A1C5162505D7D6425282C572420455855
ACCA64907076BE5F837F6477B9A83C9D5EA39A42564A81BC58887D56859DB12F383640A5
7A2B7562346D73372A4E7425455523818A51745B38CCA84032A33C5E9C5935505A4F259F
9B671F64480F5791683C5E26774F879A5441B5C5583F6785374B589E771B3B50313C626F
673768167B83564634B55D4B5D3779A88F5343356FAB5C9531307D939546601C90688A2E
2B98914F75152C669A49926B17869B437DC210255299694F7F3A0C807A3B50152BAB7E6D
7D4B1A689C522F876F5124B07D5E6BBD976E46705D77933638A3905637331A5F5E7DA032
52835738582D38A144489CAE9867215E667E5D4A1F75392F4F5E3F77623A5C936E384585
32333852535A5E423121525C283B4B293A363146A2452C675A71243E642E13356B632237
B292549CB15E2F9F79395E5D533D9A592255574F757B65302F305D362871925F
60C861AA54479356AB84513C56783F7130757C4A4E3B4F884C856632283F82253836275D
642C7D6B283147283C2F5A1F3F44213F48335147248D5F4838A52A255B64415665531845
53471B654D153C5C4C3A5E173F4B92A7671C597A7D346A7A201517765F1A3B5042457655
633D6C245C64565235814E596942515E6E54392D5F814EA1552C52544657753C6D46965D
36773D649C6E8AA7613A9F833D86583A96AE63365386597FA86B2766683C615640B04979
AE6E5196763F4D96626933BE78658BCEB15F5AA5324E7A4F408F66404C442F7947A7BD66
51833C2C7C41255D3B3D83C2BA7131564C4F3F7D80864C4061634AAE9D536AA5361E5B93
4F323B77407C9D705C2B5863375F8350572F2E58B762467E6D781D4189601A3C66353B73
BB944DADB0531C4F6037614B1B21845321545D205A958A33403D64171C496260
A2964F8F6E648D669AB485465D6957B34F97855570695D9F618F9F753D4A6725585D4256
2E23846E3C4B3A2A4B3335305A5A3B5A55425E7D5CA5635455AA54346B534A7FA46C4074
6047316563245E6452437538564B8788582F7384663AAF9D58201A85402858734855A25B
2F6873347830616D4A712D59735E9E70395950497A582C875E3C75823C4D673A81546549
377E46426E7595C387428C653D9D7743809C5C38686D1B51846C2D624053765E3FAC223A
5C6169AB782D438C786733B73F3061A18D585C786365AB71416D884E3A40347A4078905E
69A455224349308125265F7180853C594E6B346D54755A456843226A843C5CA365393789
4D3444732D3754644A2E56421A3A644C773F2775BD8C43786B582356A664193F642D203A
B94C86C2B46E2A554B2E76612425A041225353505B875E3893AE7E3E2545742B
B2C25D9D7A82A74C69695072AB58338A4298373875596D861D8A96655A876E1A36653E5C
66228777384C53355E40481C2D4B2B5D462163674C9D58194A8A4239712E284665544A82
7121194D5E236A6020386737652A6FA46231809C38269F99574766A44C152D5328669E80
4E3C492896635A4947A13D436C4D8F936A5C312B8B7A4A93314373816C7342309F586439
4394546B6B3177AF9C478F4D459F7B4B97A44461B28C47666E553C994C3C615573B15C6F
6F7D5ABA874443946D5A3DC28F5672B9923B8FB07473A4563489966A51385BB46F809B38
84C261324E3E34944B4466856A7A34605577689B747942486A4836816A4271A9633A389B
3138545B4B524F3C442F5E6F363666698E68444AB07E41939873213E7B5630689B7F324C
BB6741977060358A5136B396452D9E32418A9460828A5E212D3D582F32587944
98C1598B456FAB5E8D6B354469653F682295704051206D8742944526488890243B2B5393
5827893E38746943446A56233F3F2B817F4362485FC99C355B963D64A2684050683249B0
72501F694731A69A473E503C7D3C7DAA3B46B1C16834A17B1B22357F65192D5141597A61
51403F226754564A3A7342476F4769595F5933256D704B8C68445874697C7E5578575A6B
478A5257696594B991438B6F3B9B734F94844036567B49686A2D269951474E1F52AB6475
67454AA5A33D439855412BAB936473AF93396A885E7B9F1B2DB8955E62292F936A828A3B
4C774B2766295DA95A3D476876622988A9A86AA15B8F315FC47947886A46BEC8873C3C93
17408C685D536948244D9E713136522B87823E5EC13946989A792F58931E28635C282D6D
B07350C49929206D61275E51272D9F4620544D317EA2582E3747551237808158
7EAF53A26974AD5E99837E4B8C7D45A33B997B42624D7197619090572A648A2A3A45396D
502481603243483438453627404430494B3B5A395D4F53297187242E6C553C47672A4385
423821693D1E636A3A4A4F365F3782AF2A2152685630B36C3A33298B58172D53326B926B
533E54347D60555E527D464980709A67735D3C327A795294694F6668626B7C5981584E60
568F52537681AAB07943955C43A8584F87725E4B90874D7675682B793C4743346FA64C85
5F6F4E9A68274A986E7638BD80677EA7A2418572519F91351F98735E5225477752898458
8481512B4D222574393B3D30495119444D7D54A46A8F26325463449F6E2C5BB05833549E
39264B622D5B7C652E2A5445234E5F2F65552A6B9E61398D783C1B4584521B54754B1A42
AC5156C1AC68244E5A4587541E269D39378049384F87582B46645E282A4F5032
BAB851A97184AD5899868451857B3A9D46A573406953709A6087956A4767832240565564
4A258C6930504D2F4058392642453B563A264E46894E542D7C8B44467E553F5B884062AB
473E34635A378978465363457E3F9FBC40316F92513DC57A3C40347A32354E60344BA473
3A705C328A3D6C5B5C7A445C846FA16F4A6B573B834E58895C5F79692760765698476E52
4B8027567D66C8B63E489E5644972D4D84805A5EAA683792B1692C702A654D378C842485
8D6E67A5524A849861622FBD533657719137868A3B73884735B7412F4933496A4CA5B267
84983F3669462A82253E63648E63345E476527728572404A6041276C713F98B652313C86
2A366968444659493C4D805C292A4F4B776C2F54A65A45ADB16D1E438734227D6D3A1D51
A97C71C8AB712E515C365A582E2891552F6552394E8D5425476A744F355F6644
B38D58B968878661BEC179507A6C4AA748946F4170496B965D8C99673E703A305B544A70
26308D5737523941435A2929623F376141195D4E7D533C197377384B6D232F5271316797
4B1F2E604239A1741C4F57467B2068A342326C923D31AC74354D4B6B2E111F4634307970
31483F2F8E45543D59853C35584B9771505431399052507242587A613D515C4C984C3F31
5C722E446346B4C273459036508D4351677D4B73AF723E5C665B3A792E49373C996A3570
546462A85B28489868763DBD8D5F61656F3A979D6C8E903C27AC785035325E8E4B79783B
8B9E3B2F5D29349737304E5554562E75747E5792507A314F84503B7C472F849F6C393F95
35264F44474A545F4D3565672E2F593659794062B0763F80966F1E4B84431B77795B2556
96767BC6AC7330616E3F59461B256C483370583A51775F1E3E6D774F34507959
BE954D976697804267646150772C4C8844802947723F905A1F78594254754F1C3D384278
321F7134294F37271F511D153A302F5656284B316177521D744D2651614A2A4B69235870
2A2E2C5A432A69682D4941375D419F992F42909D5535C35B2E4F4C695312264F4F29685C
3C5041318A565F5D5E7C463C846A945F635C3A3989666A865E5E675D4E4E795D8E57455C
5977486A765EB4AB6E44904E4997415B677C585B7F7C4F738030468B4B5B4846BD864895
5A666DA9733152A6413F2EA783585D6462358A876291862E34A67E4C3A30427A5E8B8C6A
8B904142451C2366363E5E59605A2351526B5E974C7C475465624273524C8EB57332438A
2A2F492D454B6B7E4C365F6B3930493A53722C5EA58751A29B72225894651D8279544398
C18160B1844F3FC4A24357452844AA56358381587D8E6832417169413B94A067
B5A2519453908D519780496D9B66506539A262475B2B84916D7C845B427671225267556D
3E409E58354C432D3246231D505741534C2E5E525B556525805B364B6A4D2950642F6B67
3D39306B583B686D344A51487348AE8229345B715834C44C2F4E59654734475D5A2A6C50
384F2B34874A5C4E637F4740866DA46C6655323E8E767A6B5F6E6B60495F7D5F7858455A
5A763F5A7D75C3A75F409B384A84376666655D649476568DA85E4873445C372C9B7042A6
6F3F669D72254EA5516339A595647B9368348DA071BB954A61927953473840866B8C9396
AD825A61612D266F484971676C5224554C55568D5E622A6282553D786C3B7ABE864E5291
443C47415593927E3C3D53573843534E4461337694744E988D553C92C371208F54042C88
BB7B508A8256226776395548252D9962367E59295CAD832F467B621D45967D53
B59B61BB71928569C4C05B4D6762919947A16D5F813C8F936D7E9A6449814C4D8C6D6A5E
15328F633C4C25563F5F2339845D4D523B327746635F54218052324C6655387C76467775
5C3A368A5F396261454F5C517353B58B403B62845C35CB5B3B5663522360668663287F71
5298343A88437A405B5F445B6B61A05C5951263F8E5983585B62685D3B6C7E648D7C8E40
555E339E9A70BB9B487BB3404C6E388D92835561985066CCD157495F5E963D44A76C4CC9
AD6B6A9B5E5992C4656F41C255588B9D5D2A8EA03FB4B47A85805269953B498B4CC3BC7D
A18B5D937A4C2873615C9C96915F305E45525D897A78375889474AB160377DA94A2A86B4
6F38394A217084853D415E351F6C9F6039792A9EB79450908B351B4788511E8F64242151
9C65365E5B6933717D324E544234875D32694C48609B6822437974462E847558
B6695E9A62985A3657884E52562056823F6530728A4094532F8691593E852D184E57615C
28237F4C3E45272725681D1A42434150332A6E41545E2F359169334D3C2D578A753E6A81
312D5C8365315F633F7467518E218CB8623E60853648C49F394B66502B14295F5B2B8459
2255453E803F89474C4E38506654815629555D37821D636552646E5B2773815E7D38533E
546615496C55AE94292C70405169344B5F78535D98432A54713E55435289594CA0461966
726271B339284077665652C4682E50783D23969B448A7631839C552D4D3A3966246A7E4C
808E245B7A4B22712748838894854966455E2C75A8965E608D2C33826644759542175D7B
372A372C425853632A43562E092F60452E661652957650878D671A467C2E19828A663572
94304C876C623C796232723C22336D313775664A5B715D23457C5B3D34908056
C29B509F639E9E5988AC555174586476398D523B622E9E6B2F6191624D9E723157576676
2C339739425C3C2C1655291B55253F654B2D6A42607B4419604E28564E402B735133765C
251D1F514A2A594619375036592D6A80343C60742235B4592F5781644A1E3F63372F9263
33534C528E3F6350606E313B62528C824D4E2E409365775A416F936F3B61455D9557582E
637D475050368795514294255672405A6D483B5D94706F7872327464447A524FB87E3298
66407AA266314692322B4FC9934C6D845A2DA4956DBE91395E505C4D5A292E4936867347
6D9B38547A1F1C69253A5D4F6F58395E4752424772744B4B774D3975523A769C6F377884
2832564B516E6A5E2F4C5343243B3D2C2B483181B1744A8C8F63214A782C1D7E8E663A80
B95A1C2B6B5A3E9A482C6F583A39752567A47746599443448DA74D2F3A946924
AF8B527F5DAA935E909E6872AC697D564AA058505033A08C376F4245528E5F364A325576
263F9B473A4C3531265A2A255E413A443F225A314A5353206E2E265D513C378A3F287E68
442E3A7246338B68444D584666509C7325427C805735C5342A3F7A563226496C5D229B52
2B61364A824B692558603D41473D527162533A317C67765C59655D6549787C5163616244
697146597E739E90385999374E4C449F91634944795C7FA6943958464F822D308D5B42C7
9758779C634574A2454D70D48665A6B4582FA37F5ACCA96872544C5D541D3A613F897923
5A85485E981C2376454077517B40246865615251918D2C3C9E573D734021478B74458375
40254E5854AE8D51234C79523142372D34513C8889537ACCB46A214B7511177B917052A9
BD6C2242671850C8842B47423965A44B377B4874A28E591F3862553A419D6E34
C592529452997C657A5F3F588872875E3E975A53702C9498346F945A4995635885627E4D
25719F4B3949282D1B57211E5A433F49442152407C786220795A3552372A60A985476765
4A2D3F78372C5364474E2D4C8051A1922753796F4B42B94F353F83503963768A6C1EBD51
498A3C537D4E7C3B63573B44554B56635657413F7D2E6C67555E555D2D6B6A525C797C35
68583E91855B7380226C922C3F322B406E733E3D752A7CA8A23A612B5DA0553A9D744D8A
716887C54D2F83A261528CD63C3D6988582AA49A8FDAAB698853432C64291F5536B3A271
7C7F2C92A6561B5D3171C5A8B25A2E52415C3983B6903E3C74313997572E479E392CA3A3
612F525135677967434E6E423A6F67282F4E36887034334D724E20557B291A7B68283A61
B67A25374A3E2C7D582D60381B387B335D90393B7E756A284B7E4F2B56A37E46
C69452AA59AC8671A8A45156694E8C71519D656D8734A796306990564C712B3A6B725754
1947934937521D542E6B193F774D3B4C432B4E36487A463C886E3557331D356960407765
2D5370795438535F43484F3D785199843D4464662462B85D3B428D4A23243F7D6F24B965
355F434D6F5E913E644B5D75594E584F335834357B5C545E565B536633666E4F825B522D
6B512C5A85527587305B922A374534496A6A2F3783667C629236533D44904D3792897297
876F7FB7842762BC60599CCC785485A1712C98A2B2C5AC637957623E55341F562F938F5B
807E3E458C3D1A53233C635B715F34574B5B1B527C8F5750741D27796B384B9120187649
2932564E5C6153523A4A5A3215587033373946B890626094AC3F3D80853B35A58C664773
BB7D2548564D3D87383F9E602D3A481F4071533E5B6C2E5A9C9C41232D87602B
C17488B756AB606884A1495E765D7C69635D4D997835AE77478789523C985344624A6366
2350A15039522D3A20601717514B35502B1B5C454B55311C635731594749396F5A45785F
44225C6E503B573F356249435C3696A55443636B3341AD3F4664926A2E37597B3847CA78
37603D567C5B7632704B2C5269365164526239338160647352555E78477E6A5894706738
70774D62845E80A33D64A03239573A40665D4B6B9B6A7F59862C6A4A4B9468369F8E9287
6A6694BB812B57AA705DBAB182528DAA5A33B4A280BBA250755A6147582B1D824A897A40
A8A55539953C1F6B605E894F72522B57445757636587276EBF642B69513394A87538805F
124395855B5B683A246B6930226568374833267B6D216C9CB04F1D4663141C8195634F73
B66535615C634372392C652D1A3E4C1E5C6B4D4C6C57292F4F7A5F3D39975B33
BE72509153AF81647B9C4B699C768D625D9F59515C329B46256F8753599A454B473B8867
1F4D892B5376432F1F622D1F50394E754228543F4A6C5C27815B2F604A453C543E4EAB62
4131445B493C704A293C4E5B6D2853813E70AD9A4C4CBD1F3038885B2E3E5659431F7371
2A5D3E706F5F532B8756375D594C8E894B594168B1616650478FA9824375417C7C70633B
857553634B44A39239608D36716F323C6838253579556B4536268D6648844B4DC3958188
602E75A97C406BA65645CAB476538C8F452484975AB8763DB6B66248542534A36B93763E
526A412F8C2B54B0605C964F7D4D3883938A6486759D3B48775E316D571C4B8479398478
3F2C6B7259555E4F164B82583D633A18774E338A7050416C9B4C21517044176F98594478
9B20177B8D68358853396F3A366A6D255C5E4864A083632A4571353747B68A64
C884527760B7847081694F8CA0627F24759C655A6339A68E2D59182D488F3942402A5173
21488C4133552F2B1F5D311F521525575E2E4B3F809366247745489C6D4141573A2E6961
512955720E3685653B47153B69466F843440676A3D569B33423F8C4B234B5C4F4C319550
3472226B825E4D176F59385A372A48623F612840814D57433D534C4E3D8059455088661B
6F786297555C6D7331958B284D3F345A5F5A2F2D684B7D56601E654B3F802A4E908B947E
7E6C759E702F62B74434A5A67C67B4A77433877350CEA041556A4A53571C275D4AA98D64
6B854C2D8D241F604D58A2548444244F4D73617B74A25C696D6032676E4A629F8043896F
532B817F55788D893443704B406859276934389271634A5E80503A81802C1957885B67C5
B78C197A832B37946F4BAA431E4B803F51692E438D95632F4786361538807D4E
B7715E9C4D946D85A572416D8D6C884467905558354797762F624E373D9633465B536274
2145985A4552282438612C214B2C383E3D294A1C3561582476142A61583E4A645F4B8F63
5528465A3F3B5657424A434A674A906D404871733F53952E454394352D5E6B785F55A835
2C89456E4E697C3B782A4E7969424042277A483F77285D594753594B2C705B46544A6B31
77553A62687F817E2469973C54492942766F33377A2B6A96902B6B3A60AA7144876185B4
8E6F62B75F3A88C87A4887772437749489328F793DACA15263691C4E85411E503CB8AA70
7993273E8A4526662E57AE98A46433584F724180A19F566C61583E70755060AB51399C8A
643A98832646777438519A332974792A772637A099695464672426577E4B215C732A326A
772D227B75432875382D7C4C31535A296E8E605C7B5E503553804C373A836B3C
C254628B509D475C6F82529B89498F50938268873F4680654E86883B3B6829716D4E6441
2B6D8D51464B1B3335421D385E2F414B2B335F3D47492F398141345A3D4D7D915F439252
41264F544B596A4959594754573A98934C517A6E235B9B3F464590542646544E28637353
32885178686B663C815036627B3E4250438B4752825064454889927A48845D6E7E687844
8989545D5B74AF822D7B9340797C403A6D53558197677E61772D6A4734876C4582655472
5A3F56AF3E2E5CB7633E7487504A909B6A3DBB9049B07157B8AD3E3A603C1D46299DA565
77891E2C7E4223601D3A65668172414F527413375FA56E80A93931755B388CBE50269460
292A7D7F514E71411A6A904D275057349E49318B753B90B1A14623535A292B5F8C4E3971
A7631A697D552C6C66376D282252502C3D6A597C9477407EB89E463543854E1B
CC775B6458B88070773A428A94536F3A8B7F4364415A81422E573941657D2351413D9365
254B663B77813927334E211C4C2452854D3D5C4467623F2A7C4A30623F2C485C573E984A
2822445E415C632D2B543C704F306D853E79A17D3C508C295B6D885E2455525A434E7758
347D2A6A5B64426999543E6B5550765C4379345974407C4539515F5E386F33584E6C5D2B
6C76505F2C4F866533785F357A5B3B39602D354867438853412F85523C875C749983869A
4A4A60B1814072C34443AEA56A3A7E906033BF874FBA804459704148602E5A823D7E8769
9798512A7B2B4C7D435A77517B402C77827B5270668E2C46614D326040296097672FAF72
51338F85564C546C2D5C7E46436338196A302D7972504D5C774222546A341A4C90503874
A96F2489806A32636839613C335455315058478792863A2D4B764B333B70613C
995B5A6A469072627D73407498567937738046451E5B8564405928233767204A37337065
275356303F5136213B58291E4C29273E4C33442D676D523488316994683B4F4D3A5DBE67
5822584A307788513948286E5C567B7B2F697E7B364B8E1E3B3C91571D5A564D4852623D
39892E6B526035397F4840575E494A5837763C56724A64454A6063573E6D4F77426D5E2F
727154543F7B88512A6E56378D4D3D3E4E393F4C5A43854B591F7832336D3F526A70877C
3F3864A7893466C253405D90643A7C897A42A7884BB69B53799C464444152F6B3876663F
766540277C222C684949675379512F4B46865C8461813D7161512F544F4493B87C43C069
573782875C4C5E69265F88644E68482A7E38267B8060656D77421B5763221F4C92635BB1
B170319867582E6D773D614F3B706E2F50453382C069533F598C47393D637F4D
C36D55915399845D7BB14C739F588C3E758B39564455986F3B738638347D1D39515C8277
285689554E54301E4C5220224A27374E452D46404A7450329041336659344D514137764D
3623474D38676E414540387543697D845054757432449237544796591B5C666E6452603A
3D9036735C5C4E5A9346425C67514E412D6F34606B4559474C5860664276588852686837
84825E52577E9061286F64379A673B4A5E5D464F75567E54742A75402E7A6172837B7C81
695B4D9A633857C86F4B77945C387091684C9F8351BB8B537CA9443F3E1A316134785F3E
A766342E78243364243E555E6B583A5A496B638C5D92527D6957284F374376B17E50C463
463A897E5E929574265C8E44406F4C2D944C2C7D9260936D743B2C85814E21496027558F
965D39A23E13318A685D9F4A29767A3E6A742874BE74595780AD703E62A87F38
CC66558E58A3827FA2B34C70A25C9240828E34603C7AA25F42838F433D791945685D8873
28668B50555335225553252A492F3F4B4D2A52445874523293483C6D5B2F475D563C8033
2720495243786A3151423A7837638B6C41597D5E2D47882B574A7F35294E556D414E761D
6E93386845A45A62864455766F554D4C3B7E435F643779664C596A4E529B538444918935
826D58856A8886502C988C41A0383868A08046516C2993B78D2887413B8F62747D678690
4679568E4D4647CF6251748D2D45B69E784DA2415DC99E72BBBB3D665C2E33643DAE8155
A87F214B7F353771176390A0814A2F654E493C93978C3F736760377F694F70AD2242A572
623EA4723258846B275AA83433886E2AA61C359B9B5B869A791D246B805249899247548C
5A1B4F7A774C2E5C13377364346651174E74507ECF5A1F3C6A876A2131693917
C85F7E804E864B698195455B5D63A33E9485396B3C847041628A79474C432382705E7442
408F8C565F452F3E5F3129506E3C474C27495E395848375B9A4A386B4C4A85875B409339
1D4F7A5E40746C30625A407D385D936D3D5E7B5638848E315347882C19534B4135575541
6D7E2C54276A605B7D296D7B5F53583531813E6349216D6347556D433D7A497529576B3C
94423B715185A0312A8D7C47AE2F2E3C6E485B8B46174B786D2891165EA1657077137693
6A575395374B7FCD94559AA1282D6C794D47BC753B9742328EB2313D70474A6334978A4F
B48B26336B294D78213A5075705336604A49195B6F87446A732B22615B3F6AA9746C817B
7056C18B5E5E5D4828879F4D3D683F3CAA3D3578693B9DC3A9481A6668152459784469B3
7330347A746430545A3B704A3874502F4D6B4475CC77403C5076523A409F6B2C
D455597F69BB85748BAB4776864E75388E6F6C92358A7340408D7C537151174B5274903B
225E3A49816C3518525A222544185B773D2F3F3D9A5C2E33783B4E782E27495E4A43A441
2B1E4D643A877022384F366F332D677D3C5E7E5021497E35515975521D5D57242F816643
82793668417D516D813759545764835C4375327C763E73274275737153733F8048603042
9E7861601E64915C2F80464596573E486C1D335C6E4160543F3FA13E397941888F4C6D6A
3C7192A95B3A44B64149809B57346F783B1C917D4E896443567C36505B226F7B558E7523
6E85403E76195F8B4C4D555A644D4987664148825A771D6B6E402D60403E95A690886946
1A66C2916568691C1B6492623C84283DA8583A985E194C5C74371B6565371D5C6B487DC3
843D3D91735E3E87725389453FAE6731717A3376D08453576A9256423CB37A3E
BF5C8B635DA18B9CA9515FAB9F657250AD543E513995833A556024384F611A40223D695D
2D785634404C2B205E6424284E333A42373131224051343A771B476B4C2751561E4A8750
48336052327D8E554B413885456C917F5290BA782B518822405167561C5A52442B454D47
7C6F246E4D642D5A8C3E547E2E3248544279274D603C6F55404C5F765A81457353627134
78705862529C8D4A317E5C359A5752687C5C2F686E529C9A551C7D5240752B477A679571
3E3E408A723945B85F4A707F42366C705D2AAB6263A36D5593AA4860602C28544A9F745F
82682D3D692D5475385361676B1A387F785750915E80258DA943326B3845AEA177887554
3C4CBD6B52BBA9571E4F8845377E533582513F9E9F4C828283331B6B613E2567503399BC
5A2B51914A27345F2A4A823F206045287E822866C495655C7AB06B3561C07E41
BD516D756388578793734566657E7833855B4B59236F7D355592762E4369256E6E776D5C
4F947E4A434B321D675B203248334D4E3F374B294D55363E923A3668572A53733C4D8E39
283955613853614056382852367A8671293F56581F5A7E293955593B376966644272723A
60782C654698715D8443647F5E5E52654A8B3B695D45927E435179716A864D7F5D958D3A
84576F9158C28B364C926C3C98314D66927126635B2A52776B2A9753607D4A608C75AD7C
4E6158B3954D5DCB6B61818D3C426E7C4433B6764D7D3E58927C2D717236436747AC8B5E
A8812C577943887D24618A9A7C52426644474DA18A921A4662573A7E291C547D56839175
4C83D1753C53624E21629B3238854E3D8F4B66BC9C489AAC9A312F82573947805D3684CE
613239706263335B443F774A3775331B5E643046B87D4773B1B0562028894421
C956887A8CB15C638472659F60567B39885B6B8233856744788C673651351F524F6F562C
3C6D634B4D4131266D2D234851284B561C425126543E306E9B3C386945355D8C4859863A
373C566946655E3F6A49386C3977AB683C696F563F8E81364560673C1B52655B41948364
447436642E7D5C576A357368527686504F7A42823C2D77464577973D5A6E597D3E557359
9A54416141A798452D84585BAD4B394F793F24706D4567604B4291385B784A796B2C7569
4B579DB5593766AC5E82B9A5473360875731B4774F7B5D456E522E4240386D743D9F7445
A86B2A284D36A6663A3B52536431479589542C65798130849A3831744D40968F4F77506B
5C69C77E69AD9B4E246A8437216C41537A2F338B572E7A8A8238195E4B33215B3B3DA0C6
5C26378E303176733741753E38B23F225A702D3FB7945C616688372A62AE783C
C356866D67AD5A678360527F716D78619E385675348B38365E85736B83621D50387B8B4A
3E8849526D603A145F4E1D2B381A5D682D383849824C25427B2F396027365F6E39628033
26516153366C642C4E442781355391623A65614B1F5A5E3145715C421E5E6547238C714E
386434713F67427681345A453056606B446D2D5F49357463364C62617F5B4D8754524563
A46D54532D8D8F4739824E3B8F4D404D672C1454563D7F74482D8243475A386855449A45
2635726052365CB7435D8B95453F8FA35D38BD7958A675518A522D475230366F50947A4C
AD662F27453EAE48434D746365524582714B5172537E296772442B7F5639808673858D93
7D3EC85B398B8B662E61824D3C77533E45473CA18B3E747E7A392C9360412E5033226CC6
4724366D4A2F22544242622C36AD542351691723A68E558081883E1D447D6735
C155977E9ABD5A789A955A9F8A69764383446459429E54435F533D3B505B1E443D5F763F
3C8656463C3B40246659182B4531404A212E2D345B441E547A285F6940274A5A3A7F933E
37394E32358467385A39275B33798855449B8A4B2267442A5A7451352569745323945C37
3B702B5F3B54435D6D2D513E3D5354664D77345426327257384C4F587654767E5A5F6E69
98544F3B29C686323D7D4345903F465C6A3833696D3C8E8C4F388C4059593F6C4949AB47
46599956493D67BA68708AA65469CBBA7437CB5287B26866885C2E45633D4D6A43945C5C
AA473032504DBE413785C4CF7B46487E71405076578432805B41288E5A5178702E6F6B88
803DB5705973705C2C596E2133785B3D75366BC28A45677B7E33367A603C2F41313E7BCE
6726354F5A452B6D64425331218E2A194F5C3B38918F48807A794C3261927B34
BC60B76E8D95518BAF8B619987718054A5425A603A965E4565916942555B1D4D536F6938
3A94694941314723635A1B2F472A444E2B313B31493B225A963535603D234A4A26617B59
3E414E4A4E78613C5B353260277D85622B545E59236C4A3643744928264E644823A64A2B
4A6B2E63496947627A2D51444A4F59585E80355923416D4F35495648795B8D655B776C80
944C6F5635C98C3C428C533C8C3B47596E362F72695067744A388F468D8647744D51CB7B
516996473A4094C35C7491953769C78F4C37C45E5888666179505D526243586A44A45F6F
B74E24565249A12C2C3D596270564B7178484AAAB382379C5D344EA25341628250475189
8045854D6586816F2B585D522F62633456323B9F803C5A5F853B1D6E704129444D418DD0
761F347C77473064463E48252F99342250746D3E8B8B458B766F382188B08231
B252A37896AD5466A47E617346898053924E8C764F9D46628A8E603F5E581F5F53636A32
3EA35F47402C5736712D2C5A66313D5025484432463E28859A3336664121515F306E7C53
3F4A67634F8452365D443C681E72A4582D6F773E2D8C533943733D2B254D7B5326945732
3C6A2B5B356736616128533B3353465A59673150373E6645314969667943736E6F5C737B
6B4B504E3ECC8D415D9D5E3A864C47516020237F634B6A803E387C44617140732932A177
5B739B622151AEBA678E8694548AD18E5344C4707998645D785439776F45538078D5A86B
BC7B26463A458D2A3B4D7079593943605C2F315B657E378C54392E7B3247566E52484E55
5640573D6C9074672C546667337566284F595AC58536474F8C46257E65372544424F8ECB
6A1B338B80503B6A4A3942313982573E417F8238808C41938D86402A98B47931
C657B875B5B9597CBA816D97787F7771873B65666B9746366A885241622F3E90435E5622
4B92503E434259234E5218353B2B41461D36273B49351A63732435602E347667327C7B43
2D4653553D76594164474E65407CA45828726B672471403A4078512B2C4C7F584D8E4C37
476F326749502D696D293B262E5B5B586A5A30593C405336426B7461783985806F503F6A
614C572B37D37A34477E41367E4750475D1F21956B4C6570393F8546767E3F70484BAF61
5C689D6956439EAF5F8D73994894D0914F6BBC6F878F4F5472483444532A40414CAC765A
A95F335254528C46485875846841465A553F407D816B278145444092454C5D863C4E4A4D
555A48446EA87F5E234354472D6A44245B605BC29D4032318445277A63342948445085C9
7024478D83574A726B43545947855C3B4F91743A83763882857F6B4AA7B63F28
AE67C45281A3618C934470995E7E5679A44A6B5E66A76546707C4F587F51244D30775C25
3A913B4B5041491B4C541C3C4A2947461D3B2535542D196B68233551421D5C642F80763F
283D445040784E416C373367337899612E7467522678463C537D3E253A5583464367513F
53674A8049554784832A4B3D2E4D634C7053305449435C39344365527A48577661596D3E
734F553D4AD1813D4C7F4F31895D50436F3F32CA6B574E63395F8F447D5A41815E4BA861
3780C86B5046A2A260899D8155A0CF993964B5317EB147538641405551212C5F51AA594D
A041234C48407D333A6C707A544F485B5A484E92716831744D494987393D568939494E55
41603F366BB8794E255E564D30552D2A3D4C55C89B45422970392585512C3C5D2E3E73BD
4E19415B4D395E755E7D885241924F3678AA7D439B8F3F7B7091745DB9BD8239
9B56B062856368A4B56570754A976C6D725A81527BA16E457A65363A67493E61274F522B
53A22D344633471B513F31645C245A5D2A5935426A451F786426515D3E1D5F492D948C34
26393B3D3A8653455927396C38709C483B987B2F23852E334669221D3F5E95536C9F3C35
806C365F3F7C3B695A2C4F494D59453D7D60275D2251714F3138354291556861525B6B2B
6841534347D370394E875458A151584E792B31CC6D498B8E3641753D8956367B3041B770
3B456D4E3257BABA4D61743E3983C38A407AB8655F7F5A4B6E384E7D552546675DC1664C
AB58216245295A2D356E7A8D4F224576643F4A8B707B36A587554394513687913860773E
233D313556C48A3833846B64306A3F3C3E4055C78838897A632A298F3B1B27581C2F84BA
6B375A6F28224F6B3D4553253C984D24747F3147C19D458E77875935C6BC873A
B95EC4608B945559A45982692B6F657D443D7041775F5C6F9E954443601C437E41614219
558B344A50254926552417364228414D164B3C2F3F1F196E732634563B2B754B184C6954
353E4D3D3360483B6B3F3B622E8BA549275A4F212D884B3F417D2B1B354C60459CC76841
74633C4C336C4075421B4F4054543D2F63522E4E1C3F593F27302F387042584B38676727
5E216B5443D3732D81A245376A1E50677D4944D4572E5A853B44602F79603D81343D7452
4A61A65531397DA76482788B508EC98239A2BE5A58875A9BAA5D2B3C65193B4157B47A4D
AE5D19544D2F422E1F59839B583A434D4A1F4DAD9E50215B553F55A94227667A1E536658
3F5624355495815B294C63292C6638345E4461D0882F5052491E369D58305384513B63BC
3D206660543C63543A42592134792A2BA187494AC1835BD2BD8724179CAC7A37
C560B27DC2A6685AA46DB2C3667C607D8E557A40866640387C8A3E37704E3F784B5D381F
457F295A5B3F46194A481F314729454B23473A2D54431773651745361A33776D2B868435
294C6D683F70401F444E3F75274F9B6430796F41246E404C6B82792F4246644160744F48
63627E60435D3C7E511F4136545B524F6B4F355233536C45364942507646A57D4A625A43
58314E363DD46F2750904A3C843A6F506C277AB5795747774872814471684A935E5A857D
655BB8776C528CA770A09F9A5591B9894CADB2655989475C945C42545B1B3C57599E7E4F
AB6F2D644E2D30443257586D57384F494A2A395B84643D61521E4B86543869883B4F5162
4662366A69938C434BBD79441D60582F811546AC8E4A6B90793829903E184473313160B9
5F223E5E4F36724C1D6D7F4A3B761C1C7B7A5269CD642A7FA08A3F17759D8236
905A8B5274855352554283884C626AB585527047A2925C43825A4D66824842604E914C21
467248847734342D5D3E243433348D7D2147385C854019874E2687533B244A5F2281844A
30474C51429B6837402B45794575AD3E4B93895F2A792732404E471F46426D518296593C
4D365761414841BC7D2658334F927152704F6475414B65354D64584179457F7040714442
7A3654333DD082475FA16668B55E705D753477647C5B48582D6C7F42793A6CA2716A7C78
486AB690675A7C925FB1A58E5185A59546D8AF5E56845F806C364B464D1A43656AA46457
B87E2D574540505C33645B704D398DAA635A538185653D97623457894D3F72863B505637
162223336194662E1F59574C25643C3D9055429351309391713E288C552646642B2F67C3
7B2C5385634B6E4C31424C383E742F2896915B6DCF9F459468604D40A2C37829
AC58C2748F994E539D5D8F9E4B643D6B62584C2F66664C3A8464292B6237395630714C1A
4268233D3F2C2A1C452D1C282E2247522E3C2937594D198453185254271B2D4044AF994E
326248252D58472D23274578416783462461563B2A6F2239436E2B134D4777587C7B4A3F
514A7A5B403D2C695D1C5240475E4B395F47455B3040615A41575C325B4F8F7B49505370
7C3A565235B57F45688F376EA15667587D45786F7F664669387B533A696053954B6C786E
42347B4C3353777E5FA79A7F4C84AA883CDFA557687663A875394C39454E6967649F5E69
C583275A2D1C33392D5B60534A305F494C4F5682876432978A484E98425387973F645A34
29291A1B49926D5928926040244E32264F4343C17C487272745E2A9667224F6332307ACE
84346190665D7563654D4C463F8D2F2A9F9B5A97DBA549BCB27E382381D0AE6A
AD69C68C95956074B15790AF4D834A93775D83458C9A4C35909239488A3A41704F955C1C
4F783E63563D2D2A60391C3442405360313B3F485F611D8B6C1E5C711F172E5820566559
355C45593C4648293147417F4C6889452F695A382F6B1A3D466E22377E867B4C7F7A5777
8E57885A4D53397D5C234E4182774B3F5C385954314A5743546164556641887A70534A74
5354824E34CB8A5EA8A96258A5436F7265307A887862618336804B396265589738687C72
5868A046434C849284AB974C6CA5B08A4DE1AD36999A6AB19C5747443D5CBA97569B453F
A76523682C2C4420326676633F3B7F4A35325B7E87563F71684144845742827F3D535A4F
4B2C283655AF936B3FA16A432B4C4439433C37B68A3F7D7A6E4D259F442A52551B47A1C3
6F3A80A9446487684B505921338A4C2FAC812E7FC36B38A8AC81492D55B5C578
9488C4709D5F7191994B736C52B34B7B5F9E9A43AC9747429C8F3F547D357D8657934628
796E3B6352314A2B43253F784D2C51581C4F3849623232A4691B4F5B31346C6938887D67
3787806B353B3C2E624B3C643792AD634157512A5296443A568733174E484D4A8CA94E48
784BA0647C79428F46397153849153326C397646387C65437F9838627248A06A605E3698
4832563538C786396C945388AE294D896B3A9EAF44549B883A8F5869988F529E478AC59F
6970A3483870999F8EB7AD69528C9B4058B6903A628259BFAD4E7B785C244D7F5B967C73
B66C3AA4533F5724588EA9925A408C4732257AC1B1404E604335567E4E61A0744475825F
5B35362A39AD9B7961B390433B6255394E3C40BC8B367E836C4237A65237728B392E6FBD
2C1A527E49483447183F824D3677172184874B8DD33F2375806330253555A53E
A66D8C71B9896B67794EACAA5AA1417D42757F43BA5E5560735F40626F28545B458E3F20
6957478F59332B313831224428317F5C223F28697E30197D441854422535546631898324
1F5C4E504162363632234A5A356CAD4D628D6C2B276D253C5D7F58196353493550675459
64266A60654A208C631F561549676B4C61234D703F54422337585E5653396C6E6A431C9B
6E415931299594476E8F283F804E5C64722E655C5E415D35278E4D3D633D6AA746667654
3578A28B4A4F8F4243678B6A5C9B938B7FA384447569236F925C355D59297A49639C6776
B4412A815E5B995330566F665D49AF84423A4655855B58754C226080486CAC6822466145
5B7C6E5B61A97F3173C98E4724656B3D7F2468B77F4BB3C5853D1D8F3217425C3A3986CC
6321497B565F36573C2B554C3866291F85915B90DA7A3F9E937B392E6E7C8749
9B8E974E8782726340337B895F69399155704D368E77432F4C2B2F47772E622E245B4629
744A254A4D3326324425226424173A51363C1735574820A724126170282E42311C576643
1D683910357845423E104269416CA1172D3E4B32286E152C376F1C186555615458625460
584585457163357D521F614E72523335713A60633D547F4742596A67774F85686D523BA4
633B6F7A3D90863F72A15353905874598547716C64425B4F28754A457246396E5B867B6C
3C5C8256344C895B7F8B9D6E44BE9E8090B1904067765967814B454B2D4AA74B558F375C
9D522B952B355F3035557F5F34326270576051769B374B957A3B597A19428D7B434F591D
38334935669F7B5245B56B503667274A8F5B38B24F19507172581D924323505B1A398BCF
7A284387555D3B60632E52603C713121857B4294D97740987F5A2E1F9B774755
8C729B6699899577924A8B9A669C3AA04B578540928C4C31997A31508F2E61884D804125
8065435D50322D2641261F4C3D334A5129462E49524621A54C1649582830285E376B5930
1A593C503C4A35382D20474F476C782D44403D192B611A313A6C1B2689725C46615A4E8E
5744912F715E2F834526574260511F37763B6C424B73653D3C4C377D674B774869432A8F
395B86542D9678539F99455A88418B8777465E6A58729657276C3C466E4C5198558F7774
537FB549324A8769848EA3604DA2A97694A88349A16B606E9F60415D4318525A6DA9424E
984B329D353F581A3E56895432357749213449819751507370426296585E9E8C454F5E43
53475D455FB093543EC45C4C43573F34484F38BE93475F707B741D7D42284C5F223C8ACF
6E334274506240655B3558483672241F756D4494CF7941926541421570747449
A084BB62875176908049878E73A3368D48739A4894825B578D6E385552317877417E303A
94584F5C4F3A442C362C41773831474D28483158735A22AA52194F582722225F39615843
1D5747574548373A352F4D6055919A3B4A3F421E4A7F26303C85192A4F56504B6256335F
553C912C8C663583353E6A495F4A2E396E326B463857683A3C504B64503F66665F482880
3A474E2E1D845D397F8A45738925626C49338E863649705327884C728F675E8E61AA9885
6B70B26E3D4FA37A8AACA7497BAA8843A3C97A328A5E5766A564446146296D6E6D986685
BF5C34A83F40662B5482B48640377C441A355781943E6C734F3657955C7CA67D4F65735F
6B496B3D70CB9D523EC65D5D484E41543A4236C59139626C72611C75412849711F49A4BA
613B5A89345D686E572C4B1C39823A25894B3AA4C06D3D816A585F1C4E8CD150
A384B080B485514E744A8B546F812E6842A37D3E883E3B396C5D346185206D83486E351C
674A66803C252E352313284B2B475E4F244B2C5875333DAE471952403A44625E37665F35
2F7C63504750273F403766573561923D473F4219355C2D2D3C7B2D195B60495C8E8A4E65
573B9A5074583E94442E6C4F6C52494F773E876846654741678956594A519B69795D2D9F
4E6755422387793D74782287A64886734D33457551536F2627AF3F4B7440769248A19D7D
538FCC6A2B4A6F3F6BA198505ABD88369E60733087313F9DAB4F7569352D6A5D72865078
BF4137A1493D75253F5065735034814E253F9AB1B544615F482F7D71407AAE4F4C846F4F
525C8B3A578B6B453DC3503C6E7854514F483BC58135617259372A83382E6C78213274BF
34489B823A3D2F4C1C276C54337012269C804394A83A3B846F42602F46368A37
9C8A6E5CAC724B473C5FB48E805F4EA646776F57A775423B5B4053738D236A3232713E28
86263558503A20454F1E3254182D55612B33255F893D1D84243474401D1C37532F6F5E22
1B4934374963343C26297A5F547570365D50411B3D6C203D4D73281F61611F486A6C4163
4D3F71316C30218E49335F1B5259524A5426786142634030476F4654443570686C283DA7
556D612B3CA9925078752D697D3975716C564B5A5C4E632D1C984E4B611573915B936C37
1674A469323B633F6781766164C2A96CCA537C3C8438294C843E3152353F7C62949D517A
C346318E2A5EA0333B538E683F3AA167212C616B9156546C5D2C4B5D3E81AD66465B591E
5677996D7A7D5B1B5FBD6A4A3F683E4E633245A773427D9D6D401B6633254C70343F83CA
4835787D464540542F245B4D377C2322767A4AA2B81E228098773A1D575A6733
8597A059A17769674D48657C835426954D652F47956D3D3C59342D56862B6A7C48622F21
8854444F442E2E43311C36502F343F5A2945314B653D24A84423495231315331368C713A
1C5429215A883E46321A6B7162917A225F6A5629426C1A3D4973332D7A774C585D5D408E
52496C21945F3F762D344F2C5B441A455C35765B497C643C43583E7857447E5B8F442D88
427456221E8B715291874069682D868669654E594F7E9A48258D43405F3D748652956C61
507FB8703A40595185837A64A3CBAC69CF5E5A45AE4540508A4B44521E46864D70861A62
A75B309D2336632B4467B07E26226F843C508680AD2F67AA703753712559A9804D595120
40567B638178722D489963494A571F4E655C36AE3D1D6C898C77216C582A4A8B314682CA
5A2E6B9D5B6260735D2762463DAA3B29995145BABD5B2646576C6639514E2215
8B809E5E74508BA46C4E6C7895872B8E43757957A66D3A44906A416B8232618C5A693038
9E534A5149453B473025506A2F403F532B553041582C39A2582A54302B3D6A4D1F4E6633
33854E2F414D295C3E2F616071A27B375340421A536D1A314366152850694D5D795A345C
4B406D2487603E7E254E613A5C4D195669397A3743775E453B4A295357416A4D5652368B
326B763F308C405199893D6F632263656B6545503E47733C218C2B65825982844EACB580
68A2BB694766685E8F7F623E70BE9B6AD2806936985640548C4171712E2E65579B795C96
B5313BA043345E193E749F80422E694A25528E84A7293D69552B5C5D1F59935B678F8E59
707CB05776BB94534CAF5A53514524483E493AC16B324F707E60307B3F3E697A143F8CA6
3E2C62811D455A6966347D363681293495623799A13C43878F77413F9DA8712A
958FA77BB57880856350654E97752A7648AC7C63985968718E62425B4645817457522021
7F3E45422B32352F201742512F3A42412251283A593B26A74F264A492C3A59632F6B5D33
25504C3A4E541A3D3D3564474384822E604C491E5A6C22445D6D362A6161498ABA72476A
436081438A6457863C395D3D5D4D3A5E663678503476683A3C59355C4A366B6B614E2D95
505A5E3D30786B3F8C913F7578509277786A575157447438218C3937764B7A744581827F
6194B742276C7457B0BC915895C16D5BAE906746AE454F718F3D35632D4076549C9165B9
AB443BA44036632B3E57986046397F632133A7BBA94550564528796C3F5BA047445C6C2D
688FA7626566722A41AB59255F73488869354AC17D5399A6542A1D682A295D66254579AB
284378623A4847512B2B71584CA83C278A6348B9AB4523445342563D548C692E
94957690A77F99A0645A8E7FA687378741786E63983F46417F5F535A5237696A655C3227
993F635F35322F3F301D4A4F2B4557552B612E4F543027A54A2D4B3D2D33545E32805938
245340304E542B4F2A246850709F8435736E61224F621C37476A32306461424A806F4375
463E73486B45457C413C5C346D5F426E514E884E44834A5B606A40762B4F8C6C69303CA8
5B69594569AC6A479070459E8052AF9A4D6165575973A3363A893C3B762F7B9A53A89E59
3CA7B9743D796C4B79697C5099CB825C79643B5B904F386C8346477627548B49A5864185
94544ABE32496B295F90BD99473981681F2F88B1A444847342246145296FA176757A7C36
435E873E7FC19D5549AC654B4B472F75753E3BBB5030575C73651A583523475D2A59A1BA
3A1F3E572C5C8480622B50153A9136217E1B2794A556243F59413757C2CE3720
8397895F8981BAA3478DB37AAB4D5C914B602E5E9B505B57453C4A55345A7F32345E292F
9527394D5134263F3D1D4D52173D535F3253263D5330349E374F7451283152533A9F7839
28573321626E324B2436935A64B86E235B4C4D205A5417244C692F426866594C8A553483
5B49683D89673B78334F5730454B1C695F346D304676502B29432764512D573B7B432973
337C652F3F9A3F57AD73327846347A7E626A4A47474B743F2272245D7E31627C4AA4B76F
386DAC604799865EAE73454094B584788B626B4891563E575D3D7F7F29396038AF94699D
A22958AF4D2D55164252746456328651111296D29F303E675439755E2F447944598C783D
364E844B5F64824B57C9542A706F3A73423062CB8E50656C745E21552F2B446F14376CA4
35253957262B405968276B443D7C3A25876D3DA1B057244264633A3E627E681E
738F94758255638A4B525048AB61587757826E5C96486771785848472B4474583C4C222B
784A48502B443D322327564A39564A292B592536461C3A8C3E345124334E7B421E4C643B
345D5632474E3056472B654F66BE72336753401B755B172051491F34424D554C83534364
494C6B4674653865274E5D3B42512D635536694C3F7C592A3765405F5139677271493279
324D6C404BA5423B8C78388D5C5D9677668A64484559723E2975313B874E6756297E9677
4C88B43338BA87539C7E7A509AB67D75BD78695D89674B6D7E484B7D253F84568D7A5DAB
8D3B48A83E2F572B6366966D52398855353F6DB0A34E41562F30706A3A537F5D6B636C3B
3755725F86789B614FCC5A32514E3A7939193DB782446B7932173A76542D436A264D76AA
3329436340484E585F38854C47803928876A41A4AC4A21404F49575298947C24
8F98708CA4877F74549B9B54A27A763D47875F6D7D3F4C729474646F4455695367733722
7D307461263F32351B1C4133294C5E3B2C5D294B512A37893A35502D1B33565B2A5B692B
33494B34767223353F3FAC4746947D438C894C1B584C21335B4736473F59585693644A5C
33728157722E5C703E59474083623471535F904D4260466B7D77456C2F607C7678315397
436E6C4977BB64419D7C42A160838D7825718E6B496E7333609237426F3E7B9E419C7E74
4A8CAD7275CE945AAD8E814EA0BB456FB9A675657751689264495C7B255A9E5B9E5A4EC9
913F4FA3405F6F30746E946D5153A7A325568AC8973D4957593F6F664552897270666D28
2F546E49897F866040D6683B6B573A6E4A4A6CC9773B738D5B2E285E1F2A4B5F225673A2
2C4E876938475452174975453F71244D7A5F3EA7A63C22434C4C5C567D566A47
8E9761699B7E7469404F6B5E8D4D93774772468E9C6050783339576636644E173F512F26
6F1333554F4F1E5C431D4239226E785131443B856E2D3D80376F6C341F39555B2B687141
353C2E103E573541232873576CAF6C1946635E1D643D153B79482B483E46377F936D4153
3B4B685066383D633A5B451E3E5F417441387F4540744F32465E3D5A3C41716C6523377D
4C68561D66B25E3CA74E4AB57C81906C4A715E473C7C6A273A7C3341602144793C8A7133
4BA2AB648DD37D55CCBA8350AAB34839597C606E6022639A5B4A694A275B9A52AA4A428D
7B414E92255B7133686685703634848D506D86D2943882704B4575613A4D8F7E6D667434
3484985D856C71345ADA4F2F6D524B9D5A5272C47754BCC95D352E7E1C41A6782857769C
1B47734F30434C4E5B36734E446734255F5335A3B2343075907B5D426A484B3B
8AA48C84B1715A7B546E996C84529C7A57582167864B497C5747415C3469764A87873725
733F4F5C4C452C483B1C403F263557552C4E2A45592C3D7E23355F461B3C562813317042
3230242253592C40193A7D4E6AB753216E57411E663111184E47214C3C401D696D643D50
44635B5D77543F36335F43394452235C533E703F406F564A4C7349512859796352274076
3E6970445DB94C3F9C4230A64A8B974A61A76D253192633B4A593353854F5C86438D674A
3A69995A9ADA3A2F858C5C5BB1BC6D7C56826F7571565885544F6C672849934EA57B70BF
964F4F932B404D1F625A6A4C4126826823527ED893284E765641744E3A759C66655B7E21
344F73647774703643BC6333524030684F4462C25B3260756043349C2B26445C314E7F9A
314D935C243F445060405C38568835326D272899A7401F3A45403F355F4A5635
789E7F80A6646096536DA1639E86BC7C4F785B709C5B4D909171526A34688C559B90382C
6C354A5D3D3F322B201D403B385163593654415875343E87463E583919335B5A27366339
333C392E6F63323C31407B5B63A0532376573F21642E151E7E35255E5848377F7960527D
3F6F496E96544941376C3F3A495128624D3B6A4D6D746271654859653A7D82516B3A4A6E
337D673D70BA3A53B44C5EC33F607550589E8A532E945D45724F2D5876556A864BA3826F
6B95AC57AACD865BA1924D5EBFB86599A392497E9E6073A87559747F36569F579F6E70C1
9346539F454B632F5851775B4C297E642B526BD8802B554F3E3676411F587968554C692F
3657725D7B878F6C36B888374A5F437A6C485FC58F5297BC8F594890332F57722F49759F
395F9169364C677F654F6F3C53823B48724C2585A74A2B4C5C3421418B8E6237
7A9D64A77E6D899C4F73AB63A58AC07457965B8E7439678B807F8C64246F854E964B2C4A
6D366155294C2F3B1D345A4E4B827E3A50513B697C2D4B733D434F2B183C5D6731386843
776D331F61794B4D38498F5D8DB9712771644C4293481E2F88491F453A473BA1AB683F4E
388A4E467652605A36854C446E6B286A4F587037534C4B59686E445F305E6B4152347078
2F5E5947ACB5384198452F945594746969745C473398532C766D325141338270417A8C72
9EB89651C7BE8753BAAD725BC3B0396D59644A6E72489DB5565D956D3D72815BAB4E46B1
82215E883C5161256D7EAB71613268583F6C63DD78377067462D5C3428547F6151496036
405D785A87A58D552B7C58224E47447D493563BB8B54AAB98F5C7CA855355D6D323E77A6
304FA773243F45663E8083465C9122357356238497273D7173543B295D724B47
7797557889505A4F6E978A679196C54355703C7C7C3D48703F444E6A224754376760293A
51305F6232371E42221A3E2932535F50393B45875E32786C3D465C322B627F6038566A2D
4B401F2978603C4E2046844168B45F389E8E3C35643215216F281C4F3440298366664A4B
346351446A39684B3372454D4451275E4434603859745E405C734D693A6A744C4D3E7681
475D6F4180AE373F924B41A859BF665179885B3D368744427B54306D78495C7B526E7F54
58A77E41C8A0444AAF9C545FD0A9529751514F6E613568863A4570323D818C64AB472DB7
954566882D7E641B474479684C2E525C3E5C5FDB7141747960335F3A39607C465F84843D
3E64783C706B8474366B63246F65497B4337639F8659B1B5935695B571375A75193E7B8B
3565CA8632384260415C745368A532316546237B9B3B2C4747644829566D422F
7BB67399924E5A884F5190667774BA7262885E829E4B478E8D594D742248784A638F333E
50394C482944251F201E47343F5C694E403E2F55492365392A5E702C1B43664926475730
41422228655E3C411A4184487D9A541F5B563134662F1420781A1A50364233A866634345
3A6C4243713F58332E6A457A4F3B1B5643394D2F615F5D435958575F315C5E4F46217886
4D5A644196983142792D479C3EB45A3C837B5E29448D313F89382A74804F5E7A5B6B8B75
71A9804BCA975860A78F4B67D9AE5995536E5F776B54829347578267396C91709B5460A6
812E5B8B274F5F3245457757452E4F61232F4FD06F3D7077473F746C567397514B5E5C2C
518A7A567852675948936C27506045793F2971AC8F59AC9B3D2E99B36D4F918B34346F79
1B349E772F324A6155587A4C5CAA34326048217EA54136505B6C5026546C6B33
6C9C6B9565769A984E54A26EB687C974567760A09F4853949260598024548440668D354D
533A4C4C33512930311D4B4442606D57413E2A5E542F75462B3D572A1B4C61653956512E
575339407B684448324B7258969B5A286B5D3637763D1925792239755A5135B66B467271
37654D4B76364D4838714F7D543E1F5B41424D2C616A4E4A524A5E65285B685653286E6F
4461553F8E9431468830479033B9564A85745D364C9A4440844430857C54778E5C709D73
8DB29D57CAB9847BAFA24170CBAD5379546F53AC9B588BAB50538862446E8678BD6D6FA7
75346F8035664D223A47765D2C297E91356449CA5531706947306D6F53ABA472515E6326
4560665E79667C46297A5C2B56474884322858986E5EBFB37B48C1982938627C2A3E7494
26337B75343E57695167764345B03434755722748136365A4634352758656326
7BA972A88D4C536647567A8AA96CBD6B889851A55C428880674D55734090845D663E3A72
5D3A4A48365A31372E43814F3D5F68516E482B6265429E5D3B3E5A393E806F652F755A23
6C7A3A41616B5F653A4E7960A5A672296C6250619C591C3188201E49383A38B558563B50
2F6531736F30494055925B65514C3784444A47518E784744522D7F802A5A4A757F33726B
5886663B879039729E4B4D8635B9966D7170612B8BA85C3F825457AD7E5A7F8A82A9A277
89B38C64B4A17A84A5AF6957D8A4537A544D2E7C7F4C8E9B44588F6047753D619A7469A7
86217E8E415A4D255C89C07F472A3958305D44B357457A66523371282E725C5B66608640
4050752E659C8F693FA76C32673E39815A3E70A42C4D7F708D55CC856A34527C24489D98
222669552F73A5774C6C693F5EB5362C791B237A87383A6A3F2232407D5A5A2C
739659B68E4F587F476E626580648B30578A45A2783A568367576F602561797089742563
4D37584630523A3F26224D393A7162315A3831602C38795532465120215B60583A815529
48442242593547622D596D387CA368317E7133427946265C72331E52473D39BE675E5050
2D61354E60264C463276494D7C49306C3C5A4D2A695B525966465D5C2D665C5C4E298444
457B5F4CA46B3B797E436C8042A25D3F7F947242587C344E9C37407E5C6D83456D686563
90B56B4782804C8BC7B75859D27D368D9253418C65519D8635629052437F687992565DB0
6C2D725D3A5A4C212C395D6957364456233C41B27F498E7747568A6A6B8863356A827232
455E6964625F667345B959459E6D46574D40999A637477586263D8B16F3C5A7E2331767B
1D55B8783333513D228F7923409D25579A561F6D7B2552BA7B3B25478360562D
6BA1537C775E583E5E867B6F4E6D9E466A4B4498723A6B4330687667286129476D5B2473
304278644742434E342A51112D6C7B406319458C6D338B252B7980322458371742A27D34
4F43155F89645141145587609CB62D2E5F86413E75101254663F215A5A1520978E5F5353
2E915754332A6F733B7A14367674424E186778367014345679465E3A237B7A57471F9077
595C2156BBA3418D671F5C7B4FA55C22574B533681721C378A57497D1B439579936A331E
419B9754877C235C877C4B89DB9B49504963429A495AAD86494587514D88749A994C6CC4
70347E47418A582F40326365494A4C6C3348267966426F5A283978635E6F5E4C52605D2B
5A8A5E6E6562535161B74D23554A6C832A1A7C7D5B8CBC8A3F5DAB5A425883A34E418376
133F9A7A333B55421C5F82404A95153E9252197C671031676B70462A54361A38
71B15CA55C8C93733E617F786D519F457C7F3D978E426E8562545C702E85755A6A702581
68364955384B393D2E2646302B427E436F332E5C593884311C3F582524553D303C885D27
4C3819325B4C4A3E1B437A63A19B50244D66384494421B6A55291D5C4D4E449A6A525059
306C445560294551347A4E545B61326E2B585A39766232446C4A69632F61655347298A62
5F513744A6782B785E31535C37A76F617F5743399183443B85404F9761488C72967A8764
58B38C628E8D658EA37F2367CB8E495D686C4EA273446D8B45415635628C6FA48D3B539F
65318B56265165423E3A6D701F2D6285476A30575945817A4A3E867277915A5656694C1A
405C73668198432946A15C3673242E4D472C896B214950687B7BAA58453148955C5192A9
203CAC7744779B7A3F5E7B3D59A73D2FA7401F84873A31744C373D70A04C3126
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
320 string
320 320 8 [320 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
320 string
320 320 8 [320 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
320 string
320 320 8 [320 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 640},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00002P2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool000oooooo02@0]kNg09>CT`3=
cLd0Kfm_051@D01:BTX0<C4a06ATI00_;bl0IVIV04Y:BP24Q8@0DU9B01lO7`1ADE40:2PX0410@00O
7al05aLG05QHF01IFET0=CDe04i>CP0R8R80;2`/051@D01XJ6P0KFe]06YZJP0I6AT0;2`/05EEE@0m
?Cd0:RXZ051@D00h>3P205IFEP0a02LW9`0U9BD0JFUY03lo?`0l?3`0:BTY03/k>`1IFET0F5QH02DU
9@0h>3P0MGEe05iNGP0R8R80AdM704E5A@10@400>c/k04m?C`0O7al0Fe]K07YjNP1CDe<0<c<c0451
@@0;2`/0;bl_075aL@0Y:BT0B4Q802LW9`0/;2`0N7Qh02l_;`0n?Sh0EEEE03Xj>P15ADD0;2`/04i>
CP0[:b/0MgMg07=cL`28R8P0D51@04i>CP1BDU80>c/k06m_K`0203Lg=`3902PX:01]KFd0EEEE09VI
V@1oOgl0IfMW03dm?@1`L700?Cdm06MWI`1KFe/0IfMW03dm?@1:BTX0H61P034a<@1>CTh0Q8B405MG
E`16ATH0G5aL03Ti>@1CDe<0>3Ph05IFEP1EEED0@d=3051@D01CDe<0Cdm?04=3@`1UIFD0RHV9055A
D@1JFUX0KFe]03`l?01WIfL0=SHf05=CD`26QXH0I6AT0:b/[01SHf<09BDU04Q8B01^KVh0IFEU05YJ
FP23Ph<0Kfm_05YJFP1SHf<092@T06UYJ@24Q8@0EeMG04A4A01_Kfl0EeMG07AdM01fMWH0Bd];07Yj
NP0_;bl0=SHf08J6QP22PX80IfMW069RHP1KFe/0@41006IVIP2<S8`0JFUY05mOG`0V9RH0Cdm?07Qh
N00h>3P0KVi^065QH@1ZJVX0`L7109ZJVP1JFUX0U9BD08J6QP1EEED0G5aL05mOG`0g=cL0Ng]k06EU
I@1WIfL0SXj>05]KF`16ATH0GemO04Q8B02RXZ80IfMW06UYJ@2EUID0@D5105mOG`3=cLd0J6QX03`l
?01<C4`0;Bd]07YjNP1iNGT0Kfm_04A4A00O7al0Shn?05]KF`18B4P0UiNG0:6QX@1fMWH0=cLg04e=
C@1ZJVX0@T92071`L01_Kfl0;bl_09RHV01YJFT0FEUI0;Bd]02<S8`0Cdm?02/[:`1DE5@0J6QX03Xj
>P0l?3`0JVYZ04U9B@1lO7`0Vi^K06e]K@12@T80ADE505EEE@1VIVH0DU9B0492@P1WIfL0J6QX05YJ
FP0n?Sh0Vi^K0:JVYP14A4@0<c<c075aL@1KFe/0FEUI07inOP2TY:@0VYZJ05YJFP17AdL0N7Qh04];
B`2?Shl0V9RH05aLG01GEeL0;Rh^08n?S`1ADE40FUYJ05eMG@0W9bL0?clo06ATI014A4@0IVIV06YZ
JP1fMWH0:RXZ08B4Q01=CDd0;Rh^05EEE@1TI6@0Vi^K08F5Q@1?Cdl0NGUi069RHP1=CDd0Jf][05UI
F@0l?3`0UYJF01cooooo02h0KFe]06UYJ@0g=cL0;2`/02<S8`0M7Ad06a/K02/[:`2;Rh/0GemO02d]
;@0S8b<071`L01hN7P0U9BD0=cLg03hn?P0f=SH0?Shn03De=@2;Rh/0[jn_04a<C00V9RH0820P04i>
CP1YJFT0D51@03Hf=P0X:2P0Kfm_03Lg=`1CDe<0@T9203Hf=P18B4P0ZZZZ08V9R@25QHD0J6QX02HV
9P0T92@08b<S02PX:00b<S80:BTY0P0V9RH03`0h>3P09RHV02@T900Q8B40De=C04Q8B02ATI40Shn?
08b<S01IFET0:BTY03Ph>015ADD06ATI01LG5`0501DE5@1G02HV9P2EUID0MgMg069RHP21PH40J6QX
09BDU01NGUh0:b/[02PX:00a<C40FEUI05eMG@1bLW80KVi^04m?C`1NGUh0<30`04e=C@2EUID0QXJ6
08j>SP1@D500>SXj05aLG024Q8@08b<S020P800L71`07QhN01dM7@0R8R8092@T02l_;`1UIFD0RHV9
0:JVYP2^[Zh0OGem09bLW02i^KT0NWYj05mOG`1KFe/0/k>c0:6QX@1`L700EEEE06MWI`2LW9`0alO7
0:6QX@2DU9@0BDU9030`<00^;Rh0<S8b04Q8B011@D40BTY:05IFEP27QhL0@d=307MgM`1CDe<0Lg=c
08n?S`2KVi/0UiNG09FEU@2ZZZX0Q8B40::RXP1gMgL0F5QH05=CD`20P800/K6a0=OGe`36a/H0_Kfm
09jNWP25QHD0H61P075aL@1cLg<0C4a<0080;Rh^0840;bl_034a<@10@400GUiN04e=C@17AdL0HF5Q
0:^[Z`2a/K40WinO09^KV`2c/k<0OWin04a<C010@400=SHf02PX:00l?3`0ZJVY08:2PP2NWYh0QhN7
08b<S02^[Zh0GUiN09>CT`2DU9@0[Zj^08Z:RP1;Bd/0E5AD0:^[Z`2PX:00Shn?08>3P`1kNg/0V9RH
0;Rh^02CTi<0IVIV0;2`/03Cdm<0VIVI07moO`2m_Kd0b/[:0<30`01bLW80Fe]K07QhN03GemL0XZ:R
07alO02PX:00eMGE0;bl_03?cll0KFe]04M7A`18B4P0PH6109NGU`1bLW80CDe=03lo?`14A4@0E5AD
06e]K@27QhL0XJ6Q0<30`03Ogml0_;bl0:b/[02?Shl0Hf=S06IVIP1jNWX0LG5a05YJFP1lO7`0MWIf
0451@@16ATH0EeMG06e]K@1cLg<0UIFE07IfMP1EEED0IFEU08n?S`2OWil0CTi>04a<C02JVYX0[jn_
0:BTY01lO7`0EEEE0820P02n_[h0CTi>02`/;00U9BD0:BTY03De=@1<C4`0GUiN05=CD`1nOWh0TY:B
07AdM01gMgL0=3@d02`/;00`<300BTY:071`L02TY:@0];Bd096AT@2EUID0WinO07inOP2>SXh0clo?
06UYJ@15ADD00P0o?cl00`10@400>3Phooooo`0@ooooo`003oooool0=02a/K40QhN70;Fe]@1TI6@0
B4Q804];B`0S8b<0HV9R03Ph>01fMWH0I6AT05EEE@1XJ6P0;Bd]04a<C00S8b<0:BTY01HF5P0I6AT0
GemO05IFEP0n?Sh0BTY:034a<@0g=cL0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00m?Cd0
ATI603Hf=P14A4@0HF5Q0451@@0T92@0KFe]0410@00e=CD0Bd];05ADE01IFET0J6QX02d];@0e=CD0
Hf=S06IVIP0/;2`205mOG`0A0410@01:BTX0GemO03<c<`1<C4`0Q8B406][J`0g=cL0Hf=S02<S8`0f
=SH0PH6102l_;`11@D40BDU902d];@28R8P00P0n?Sh0<01YJFT0C4a<04U9B@10@400GemO02d];@1`
L700SHf=08J6QP1CDe<0BDU904a<C00o?cl0NGUi04];B`0l?3`0;2`/05eMG@11@D40X:2P0:f][@1_
Kfl0CDe=06][J`0`<300NGUi05iNGP1ADE40@D5103hn?P1ZJVX0?Shn051@D024Q8@0EUIF03Lg=`1f
MWH0AdM707EeM@0e=CD0GEeM05QHF00l?3`0IfMW07]kN`1gMgL0@T9205QHF080R8R807d0De=C0492
@P0b<S80M7Ad05mOG`16ATH0GEeM04E5A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07Mg
M`1ZJVX0LW9b04M7A`1RHV80N7Qh061PH00k>c/0HV9R07EeM@1@D500IFEU065QH@1jNWX0DU9B03lo
?`24Q8@0KVi^06EUI@1WIfL0FUYJ07EeM@1EEED0V9RH07UiN@1bLW80@41008J6QP2PX:00Lg=c06m_
K`1;Bd/0?3`l0;Zj^P2RXZ80Fe]K08f=S@2HV9P0>3Ph059BDP1YJFT0BTY:075aL@0`<300?Shn06UY
J@1RHV80Cdm?04Q8B00g=cL0LW9b05aLG029RHT0][Jf02DU9@0l?3`0^KVi07moO`0m?Cd0GEeM024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40ADE505aLG01eMGD0FEUI03Lg=`1jNWX0WYjN05YJ
FP1ZJVX0OGem03Hf=P1mOGd0L71`04M7A`2=SHd0IfMW0492@P0T92@0EUIF071`L01[Jf/0BDU9071`
L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1ADE40GEeM06MWI`1BDU80GUiN06IVIP1FEUH0?Shn06YZ
JP1oOgl0Cdm?02`/;00206YZJP0X05eMG@1KFe/0IVIV08V9R@1SHf<0A4A406EUI@0b<S80Q8B407in
OP1dM7@0EEEE02d];@1hN7P0Q8B404e=C@1KFe/0:2PX03Hf=P1`L700?Cdm06][J`1VIVH0QHF503/k
>`24Q8@0LG5a03De=@0];Bd0;bl_0820P01hN7P0EUIF0:VYZ@2NWYh0H61P075aL@1JFUX0<30`09ZJ
VQcooooo00X0Q8B404I6AP0a<C409bLW02<S8`0L71`06QXJ01dM7@2?Shl0NWYj0P0W9bL04`0L71`0
820P024Q8@0];Bd0:b/[03/k>`16ATH0@D5108B4Q02VYZH0RHV904Q8B00U9BD0CTi>06YZJP0m?Cd0
;bl_06i^KP0k>c/00P0[:b/0@@0_;bl0=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD0
92@T02`/;00Y:BT09bLW02TY:@10@400:RXZ028R8P0O7al0>3Ph05IFEP2`/;00Y:BT09NGU`1LG5`0
:RXZ02DU9@12@T80=SHf01LG5`0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@3=cLd0
Xj>S0:^[Z`1dM7@0LG5a05]KF`1CDe<0@T9203dm?@13@d<0AdM704=3@`0g=cL092@T03/k>`1jNWX0
Ogmo08n?S`1RHV80=cLg03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q00809RHV03T0:RXZ02h^;P1fMWH0
VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`1=CDd0OWin08R8R01QHF40?clo04U9B@1/K6`0
X:2P0;>c/`2ATI40?Shn01/K6`0I6AT06a/K02DU9@0[:b/0=cLg02h^;P0m?Cd0CTi>04E5A@1TI6@0
MGEe09>CT`1lO7`0VYZJ0;6a/@32`/80H61P07=cL`1_Kfl0J6QX05iNGP27QhL0cLg=0<30`02[Zj/0
]kNg0;no_`2>SXh0MGEe05QHF00o?cl0=cLg02l_;`0/;2`00P0^;Rh04P0];Bd0@d=306IVIP1?Cdl0
De=C08R8R02ZZZX0NWYj06a/K02>SXh0ZZZZ06e]K@0l?3`0;Bd]030`<02KVi/0LG5a06MWI`80I6AT
02`0=cLg06][J`2VYZH0/k>c0<o?c`21PH40ADE503Xj>P19BDT0P8200:VYZ@2h^;P0];Bd09RHV02[
Zj/0`/;207]kN`1dM7@0T92@09bLW01XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0<G5a@34
a<@0`L710:RXZ03Jf]X0e=CD07moO`0b<S80<30`03<c<`14A4@0JVYZ08f=S@2?Shl0LG5a05aLG080
DE5A00h0W9bL0;jn_P3Bd]80fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P1>CTh0T92@06YZ
JP80GUiN0340EeMG0451@@0f=SH0H61P07alO00l?3`0HV9R0<;2`P1LG5`0RHV90<_;b`1cLg<0RHV9
07AdM01BDU80BTY:06m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400DU9B06YZJP2FUYH0_;bl
05EEE@2PX:00<c<c02`/;00^;Rh0>c/k09RHV02l_;`0V9RH05UIF@1aLG40VIVI06YZJP2OWil0OGem
092@T00c<c<0=SHf03Ph>00d=3@0=cLg017ooooo000?ooooo`1B0::RXP1kNg/0SHf=07AdM01BDU80
KVi^02`/;021PH40?Cdm07emO@1XJ6P0=3@d06][J`0e=CD0BTY:01/K6`0Y:BT07QhN020P801NGUh0
Cdm?0492@P17AdL0>c/k03Xj>P1HF5P0IVIV05IFEP2=SHd0@D5102h^;P0b<S809bLW03dm?@0n?Sh0
;Bd]03Ti>@21PH40DU9B024Q8@1PH600AdM703hn?P1CDe<0H61P05IFEP1ADE409BDU03@d=01]KFd0
GEeM02<S8`1bLW80ADE503Ph>01=CDd0EUIF03<c<`13@d<0SXj>038b<P0];Bd0H61P02PX:00];Bd0
G5aL02LW9`14A4@0F5QH034a<@2CTi<0<S8b04];B`2@T900EEEE04=3@`1?Cdl0>3Ph024Q8@1@D500
LG5a06m_K`80E5AD09`0:RXZ02d];@1ADE40ADE503`l?00c<c<0HF5Q04e=C@1eMGD0Shn?06IVIP1B
DU80Rh^;0451@@1IFET0@4100451@@1KFe/0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y
:BT0NWYj04=3@`1TI6@0@D5102DU9@14A4@0E5AD07]kN`13@d<0C4a<05mOG`24Q8@0DE5A06ATI00h
>3P0A4A403<c<`10@400CDe=04E5A@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0IVIV07EeM@1J
FUX0S8b<05=CD`1`L700PX:204Q8B01HF5P0RXZ:0:6QX@1RHV80<S8b03Xj>P1WIfL0OGem04i>CP2;
Rh/0G5aL04=3@`1`L700Q8B406QXJ01LG5`0/k>c08F5Q@1UIFD0;Bd]05eMG@1cLg<0Ng]k07UiN@2E
UID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO059BDP1oOgl0C4a<08Z:RP1fMWH0D51@06IVIP1T
I6@0DU9B05iNGP0o?cl0LG5a051@D01kNg/0Vi^K04e=C@16ATH0_kno07moO`11@D40QHF502d];@0c
<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80D51@075aL@1[Jf/0NGUi04Y:BP18B4P0RXZ:069RHP1S
Hf<0LG5a04m?C`28R8P0S8b<04];B`2IVIT0M7Ad03De=@0_;bl0Lg=c07emO@1bLW80A4A4071`L01C
De<0F5QH09bLW025QHD0GUiN03`l?01XJ6P0EUIF061PH01RHV8205UIF@0`05MGE`15ADD0Hf=S08>3
P`1IFET0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400NGUi04m?C`1[Jf/0V9RH08N7
Q`1;Bd/0;Bd]06a/K025QHD0EEEE075aL@0c<c<0?3`l07AdM00m?Cd0IFEU06ATI01_Kfl0;Rh^08n?
S`27QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P01MGEd0K6a/02l_;`0L71`0OWin7?oo
ool0901TI6@0?Shn03<c<`0h>3P0;bl_01hN7P0G5aL071`L09RHV02i^KT0@d=302LW9`0M7Ad05QHF
01XJ6P0P8200:BTY02PX:00_;bl0Fe]K08^;R`2GUiL0YJFU0;Bd]01jNWX0Ogmo079bLP0`<300Kfm_
06=SH`0^;Rh092@T020P800Q8B409RHV03<c<`80@T9200L0TY:B0:NWY`2GUiL0De=C03Ph>00W9bL0
92@T00809RHV02<0820P04=3@`0[:b/06a/K01`L700O7al0Ng]k0;no_`3AdM40]KFe0:2PX01`L700
;bl_02/[:`18B4P05QHF01@D500G5aL08B4Q0410@01JFUX0ADE504=3@`21PH40WYjN09bLW02WYjL0
^k^k07EeM@0o?cl07alO02PX:00];Bd0;bl_02d];@0202DU9@0f01lO7`0Q8B40=SHf06m_K`1`L700
LG5a08F5Q@17AdL0>CTi05UIF@2CTi<0GEeM034a<@0/;2`0;bl_03<c<`0k>c/0H61P0:JVYP2PX:00
^k^k0<O7a`2l_;`0_[jn08V9R@1WIfL0GEeM075aL@1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0
Y:BT0;6a/@1XJ6P092@T01TI6@0H61P08B4Q01hN7P0M7Ad07QhN028R8P1EEED092@T03/k>`2BTY80
Ti>C0:FUY@1ADE40KVi^0P2MWId0UP1;Bd/0A4A403Xj>P10@400/k>c0<o?c`36a/H0^;Rh0<71`@2^
[Zh0O7al04a<C00i>CT0=SHf03<c<`0b<S80=CDe03Xj>P0l?3`0>3Ph04U9B@1VIVH0XJ6Q0;Vi^@1^
KVh0YjNW0:JVYP3EeMD0_[jn0;Vi^@31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600R8R805QHF00N
7Qh0;bl_04i>CP0o?cl0^[Zj09bLW01>CTh0?Shn059BDP25QHD0DE5A05iNGP2d];@0TI6A0:6QX@31
`L40b<S80:>SX`2KVi/0VIVI09RHV02d];@0X:2P06MWI`0d=3@0?Cdm04Q8B01SHf<0SHf=0<71`@3W
inL0d];B0;bl_03Bd]80QXJ602l_;`0`<300=3@d03dm?@14A4@0ADE504M7A`1IFET0KFe]079bLP2U
YJD0a/K60;Bd]033`l<0c/k>0:ZZZP1UIFD0A4A4055AD@1YJFT0BTY:03dm?@1;Bd/0N7Qh04a<C00n
?Sh0=SHf0410@019BDT0Bd];06YZJP1eMGD0D51@04m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01K
Fe/0@D5104A4A01oOgl0emOG08R8R015ADD0?Shn034a<@0d=3@0E5AD071`L032`/80b<S80<[:bP2H
V9P0`/;207EeM@1FEUH0Cdm?07]kN`20P800Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22
PX80CDe=03<c<`0f=SH0=cLg03De=A7ooooo000?ooooo`0Q0;fm_@2:RXX0KVi^07alO01FEUH0MWIf
02d];@1lO7`0@D5106m_K`1SHf<0820P05mOG`0m?Cd0ADE501@D500X:2P0:RXZ02LW9`1OGel0CDe=
030`<01@D500E5AD03dm?@1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T0080@T9200`0820P
02TY:@22PX80J6QX020P801DE5@071`L02`/;014A4@0EEEE05QHF01ADE4202LW9`1F05QHF00j>SX0
6ATI06UYJ@1dM7@0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`1KFe/0<c<c02TY:@1OGel0
;bl_055AD@1IFET0;Bd]08V9R@0Q8B40=CDe07=cL`12@T80EUIF05QHF00m?Cd09BDU07=cL`2>SXh0
M7Ad051@D01nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M7Ad0>c/k05mOG`2ATI40XZ:R05IFEP10@400
SHf=04m?C`1QHF40@41003De=@1DE5@0ADE5055AD@0[:b/0<C4a05UIF@22PX80>3Ph061PH00f=SH0
JFUY04E5A@1ADE40EEEE03dm?@18B4P0CDe=06i^KP1:BTX0K6a/05aLG01hN7P0D51@09>CT`15ADD0
Bd];034a<@0l?3`0Jf][06UYJ@2LW9`0Kfm_030`<01GEeL208V9R@1>059BDP1jNWX0Ng]k06IVIP2R
XZ80?Shn08>3P`2TY:@0HF5Q03Lg=`1NGUh0VIVI05]KF`1`L700Fe]K06IVIP26QXH0HV9R0:VYZ@2O
Wil0S8b<07=cL`1nOWh0FEUI05MGE`2o_kl0[Jf]09bLW00k>c/0KVi^05aLG016ATH0EeMG08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0Cdm?04a<C01DE5@0XJ6Q07moO`1JFUX0GUiN04e=C@0o
?cl0DE5A0410@01XJ6P0>CTi079bLP2XZ:P0KFe]04E5A@2LW9`0Q8B4038b<P1]KFd0>CTi02LW9`2<
S8`0FUYJ051@D00j>SX0O7al05EEE@14A4@0IfMW05aLG01gMgL0Bd];04M7A`25QHD0IVIV0P1ZJVX0
B@0h>3P0JVYZ096AT@1BDU80R8R806i^KP10@4008b<S04a<C01NGUh0JVYZ0410@01XJ6P0HF5Q06=S
H`2ATI40K6a/05YJFP0a<C40MGEe05YJFP1EEED0A4A404e=C@1MGEd0BTY:04Q8B01hN7P0LW9b03lo
?`0V9RH0MWIf04a<C01]KFd0PH6105QHF027QhL0P82003Ti>@1hN7P0@T9207alO02>SXh0NWYj03Lg
=`14A4@0Q8B408n?S`1HF5P0Jf][024Q8@0`<300MGEe04M7A`1UIFD0Ng]k06ATI00[:b/0O7al04e=
C@0a<C40>3Ph04Y:BP29RHT0MgMg03Ti>@1ZJVX0OGem0410@01iNGT0FEUI024Q8@1[Jf/07?ooool0
2@2MWId0PX:206YZJP1NGUh0Hf=S06EUI@16ATH0IfMW0<_;b`020<C4a00G05=CD`0[:b/05aLG01PH
600E5AD06QXJ038b<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Hf=P0]KFe061PH01mOGd0Lg=c04Y:
BP0b<S809RHV02@T900P82000P0T92@02@0[:b/0=cLg0410@02<S8`0/K6a07AdM01HF5P0<c<c020P
800201hN7P1502l_;`1LG5`0GemO04I6AP18B4P0IFEU09^KV`2e]KD0UiNG08n?S`26QXH0Ogmo0410
@00P8200DE5A01LG5`0a<C40A4A40410@00b<S80=cLg03Ti>@1?Cdl0E5AD0861P@2QXJ40XZ:R09NG
U`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0N7Qh07AdM01`L700K6a/07AdM03`l?01ZJVX0GemO06QX
J01ZJVX0T92@09NGU`2XZ:P0];Bd09jNWP14A4@0ATI606MWI`1EEED0Bd];055AD@1ZJVX0VIVI0;bl
_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1jNWX0_;bl0;Bd]02c/k<0RXZ:0080TY:B00P0^[Zj0<G5
a@2f][H0Ogmo03/k>`0O7al05aLG01`L70807alO0P0Q8B406010@400;2`/03Lg=`1nOWh0Ti>C0;Rh
^02RXZ80JVYZ075aL@2XZ:P0?clo03Ti>@1TI6@0[:b/0=;BdP2@T900`<300=GEe@2m_Kd0Cdm?07If
MP2@T900De=C03/k>`80?Cdm04`0@d=30492@P0n?Sh0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo
0:2PX02k^k/0QhN705iNGP1cLg<0KFe]09BDU03De=@0YZJV0:2PX029RHT0AdM703/k>`16ATH08R8R
02LW9`0`<300O7al0;:b/P2ATI40ATI604U9B@29RHT0DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5
096AT@34a<@0_Kfm09nOW`2IVIT0OGem04E5A@0/;2`0>SXj0410@01>CTh0MWIf08n?S`3Rh^80i>CT
0<c<c02i^KT0cLg=08>3P`1lO7`0T92@09VIV@2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0WinO
0<C4a02[Zj/0]KFe07]kN`2RXZ80DE5A0P1;Bd/0<01>CTh0>CTi04a<C014A4@0=CDe03Ph>00_;bl0
=cLg0492@P1;Bd/0J6QX06m_K`1oOgl0Q8B406i^KP1OGel0PH610:j^[P3AdM40bLW907MgM`17AdL0
BDU90;Bd]01/K6`0XJ6Q07IfMP13@d<0;2`/030`<020P800_Kfm0<[:bP3Jf]X0fMWI0<;2`P2b/[80
[:b/07inOP1]KFd0LG5a09ZJVP1IFET0>SXj04m?C`1lO7`0IFEU08Z:RP80B4Q800H0EEEE06IVIP0]
;Bd0;bl_03Ph>00d=3@Aooooo`003oooool0EP2KVi/0GEeM065QH@1]KFd0DE5A04Y:BP0W9bL0EUIF
03<c<`1?Cdl0<c<c01@D501>CTh0>CTi04Y:BP0B4Q80<30`038b<P0S8b<0?3`l055AD@0e=CD0>c/k
03hn?P0e=CD0?clo02l_;`0o?cl0RHV903/k>`0e=CD0EeMG04U9B@0Y:BT0>c/k04E5A@0Q8B40NGUi
055AD@0G5aL0FUYJ05mOG`0g=cL0>CTi03Hf=P1TI6@0MgMg04Q8B00X:2P0DE5A04a<C00Q8B40EEEE
08>3P`1;Bd/0DU9B04e=C@0o?cl0>SXj07UiN@1XJ6P0>CTi051@D00W9bL0:RXZ07=cL`17AdL0EUIF
04Y:BP0V9RH0LG5a05IFEP1=CDd0IVIV04m?C`0m?Cd0G5aL06UYJ@0f=SH0QhN709bLW01gMgL0BTY:
061PH016ATH0>SXj0P1KFe/0bP12@T808R8R030`<015ADD0P82009jNWP1/K6`0Bd];092@T010@400
G5aL05YJFP0j>SX0C4a<04M7A`1LG5`0DE5A03/k>`1IFET0Lg=c03hn?P1bLW80DE5A069RHP0g=cL0
De=C06IVIP0g=cL0CTi>05iNGP1VIVH0>SXj05mOG`19BDT0Ng]k04E5A@1XJ6P0=cLg06EUI@17AdL0
>3Ph059BDP1@D500T92@09RHV01JFUX0ADE506a/K01ZJVX0CTi>06EUI@1^KVh0G5aL0;Rh^01/K6`0
P82007AdM02:RXX0?Cdm06QXJ029RHT0JVYZ09NGU`1cLg<0LW9b08>3P`1/K6`0U9BD096AT@2<S8`0
KVi^0861P@1XJ6P0A4A40;jn_P1kNg/0R8R804A4A01nOWh0HV9R096AT@1MGEd0P82004a<C02a/K40
P82006UYJ@1WIfL0Y:BT06EUI@1@D500RHV903@d=02CTi<0SHf=04i>CP1UIFD0P82005EEE@0o?cl0
A4A407=cL`1UIFD0JVYZ0:ZZZP1IFET0@d=307YjNP2DU9@0>3Ph065QH@0h>3P09bLW08f=S@1hN7P0
DU9B04Y:BP1TI6@0MWIf03`l?01HF5P0DU9B06a/K01<C4`0BDU907QhN01CDe<0IFEU07MgM`1<C4`0
HV9R08N7Q`1GEeL0OWin0861P@1ADE40<30`04Y:BP1ADE40IfMW04Y:BP1lO7`0Q8B404m?C`2YZJT0
P82004=3@`0a<C40JFUY05eMG@1KFe/0;Bd]03dm?@1LG5`0EEEE03hn?P1/K6`0N7Qh04i>CP0/;2`0
MGEe075aL@1YJFT0J6QX07EeM@2ATI40@D5102h^;P1cLg<0AdM70820P02IVIT0H61P02d];@0h>3P0
F5QH07emO@1CDe<0MgMg03<c<`13@d<0TY:B0492@P1OGel0EeMG06i^KP19BDT0V9RH07UiN@11@D40
9BDU02h^;P1]KFd0D51@05MGE`23Ph<0Ogmo07EeM@1VIVH0ATI6024Q8@1]KFdLooooo`0T0;:b/P2?
Shl0E5AD04a<C01:BTX0Hf=S08N7Q`2WYjL0FUYJ04M7A`1]KFd0Z:RX0:6QX@1GEeL0;bl_01PH600G
5aL071`L024Q8@0P8200;2`/08F5Q@21PH40G5aL09VIV@3:b/X0WYjN06i^KP15ADD0=cLg034a<@0]
;Bd08R8R020P800N7Qh07AdM0P0N7Qh0;P0P8200:b/[059BDP2QXJ40OGem05=CD`1LG5`0GemO05QH
F01;Bd/0ADE506e]K@1NGUh0DU9B04e=C@1cLg<0S8b<08>3P`1dM7@0Lg=c0;Jf]P28R8P0Q8B40:^[
Z`1IFET0<C4a030`<00g=cL0>3Ph03dm?@0k>c/0;2`/024Q8@1EEED0Lg=c07]kN`2>SXh0MgMg04U9
B@1KFe/0Jf][065QH@1CDe<0@T9202h^;P0T92@2024Q8@0W06MWI`1LG5`0AdM705=CD`18B4P0S8b<
09NGU`2WYjL0WinO06IVIP1?Cdl0G5aL04e=C@12@T80EeMG06YZJP12@T80OGem08j>SP2OWil0YZJV
09JFUP1mOGd0Hf=S03dm?@0f=SH0H61P07moO`1aLG40Cdm?05iNGP1TI6@0S8b<0;Zj^P1cLg<0WIfM
06e]K@0k>c/07alO00<07AdM05X0820P024Q8@0X:2P0HF5Q05mOG`23Ph<0W9bL0:BTY02UYJD0X:2P
07QhN01jNWX0PH6109^KV`1JFUX0>CTi0:2PX021PH40QXJ606IVIP26QXH0D51@02d];@1KFe/0/k>c
07moO`1FEUH0D51@04Q8B00o?cl0>SXj03dm?@1iNGT0/;2`0:BTY01JFUX0GEeM06EUI@1kNg/0WYjN
06a/K00d=3@0<C4a03<c<`1jNWX0TI6A09RHV02EUID0=3@d01lO7`0Q8B40:BTY0451@@1=CDd0HF5Q
08B4Q028R8P0YZJV0;Jf]P2h^;P0IVIV06EUI@11@D40IFEU03@d=019BDT0N7Qh04i>CP2HV9P0X:2P
0=_Kf`3?cll0TI6A0:f][@1HF5P0C4a<05]KF`1aLG40H61P09VIV@2g]kL0g]kN0<?3``22PX80KVi^
0<K6aP2WYjL0AdM702l_;`0Y:BT202d];@1603Lg=`1CDe<0]kNg09NGU`14A4@0OGem07MgM`28R8P0
TI6A07EeM@1=CDd0LW9b06i^KP12@T80<C4a0410@01cLg<0?clo03Xj>P0e=CD0=SHf034a<@0e=CD0
A4A406a/K01ZJVX0LW9b09BDU021PH40TI6A092@T02n_[h0ZJVY09ZJVP2?Shl0VIVI0:>SX`1GEeL0
ATI606ATI02m_Kd0/K6a07alO024Q8@0_[jn0<g=c@3EeMD0gMgM0=OGe`2o_kl0YZJV09nOW`2[Zj/0
[:b/0;Jf]P2b/[80WYjN09BDU02NWYh0^KVi0;^k^`29RHT0<C4a03`l?01GEeL0[Jf]07IfMP1LG5`0
C4a<079bLQ7ooooo000?ooooo`2k07YjNP1LG5`0[jn_09jNWP1@D500L71`03`l?01QHF40B4Q803lo
?`1OGel071`L038b<P0N7Qh0@d=301`L700k>c/09bLW00l?3`0J6QX0Bd];0451@@0n?Sh0=3@d024Q
8@1=CDd0@41005mOG`2VYZH0@D51028R8P11@D40Hf=S03De=@0_;bl0@410028R8P23Ph<0QhN702PX
:01ADE40GemO04=3@`1OGel0>c/k04U9B@1]KFd0GEeM030`<01EEED0P82004e=C@1;Bd/0IFEU038b
<P1=CDd0F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0Lg=c0410@00O7al0J6QX02d];@0b<S80EUIF03Ti
>@1^KVh0<c<c0451@@1hN7P0NGUi0410@01bLW80=SHf01TI6@1OGel0W9bL0820P01CDe<0Ph>304=3
@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1EEED0JFUY08V9R@1`L700A4A40:>SX`1LG5`0A4A404e=
C@0/;2`0JFUY04A4A01ADE40?Cdm03<c<`1;Bd/0SXj>04e=C@1[Jf/0EeMG05aLG01UIFD0@41006YZ
JP17AdL0@d=3059BDP22PX80HF5Q06m_K`15ADD0R8R805ADE01ZJVX0E5AD05EEE@1CDe<0?3`l05EE
E@1[Jf/0Q8B40:>SX`1dM7@0>3Ph05iNGP2EUID0J6QX071`L01/K6`0De=C0<k>cP2@T900Lg=c07Yj
NP2OWil0@D5106EUI@2ZZZX0N7Qh08R8R01WIfL0M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0::R
XP26QXH0GEeM0<S8b01jNWX0Cdm?04E5A@22PX80T92@08j>SP1OGel0M7Ad02TY:@22PX80RXZ:061P
H017AdL0/;2`04U9B@1]KFd0R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D0020410@01U071`
L029RHT0G5aL09jNWP1NGUh07QhN05iNGP2;Rh/0B4Q806e]K@0/;2`06QXJ07=cL`1fMWH0<30`03<c
<`1IFET0G5aL04=3@`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH019BDT0N7Qh06IV
IP0V9RH0@T92061PH01SHf<0?Cdm05mOG`1VIVH0L71`03Lg=`1OGel0J6QX03Ph>02EUID0RXZ:05]K
F`0g=cL0HF5Q04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K04e=C@0Y:BT0KFe]07If
MP1aLG40D51@08J6QP2:RXX0KVi^0451@@2LW9`0LG5a0861P@2EUID0J6QX02XZ:P1ADE40P82009fM
W@1]KFd0VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a<C40L71`06ATI018B4P0:2PX02`/
;01WIfL0G5aL03@d=01PH600?Cdm075aL@1XJ6P0JVYZ03`l?01MGEd07?ooool08P3Ng]h0bLW90;Zj
^P2BTY80PX:204M7A`0n?Sh0FUYJ06a/K00Q8B408R8R02/[:`2DU9@0ZZZZ05ADE01JFUX0DU9B04Y:
BP1JFUX0DE5A0492@P2UYJD0Vi^K06e]K@1[Jf/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV
9P0O7al2020P800Z02LW9`0S8b<071`L01`L700N7Qh0;Rh^0:>SX`2UYJD0X:2P0:RXZ01JFUX0ADE5
051@D023Ph<0N7Qh03/k>`0l?3`0CTi>07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40Y:BT
09RHV01bLW80A4A403Xj>P0Y:BT0820P01`L700O7al0?Shn06IVIP29RHT0W9bL079bLP1IFET0@410
0P0Q8B40400i>CT0CDe=05]KF`1dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj075aL@1bLW80
alO70::RXP1KFe/303hn?P0K03`l?00k>c/0Hf=S05MGE`25QHD0@d=306MWI`1LG5`0MGEe08R8R01i
NGT0UYJF05]KF`12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04M7A`1UIFD0ZJVY04U9B@10
@4009BDU00807AdM03407alO01dM7@0O7al0GemO0;Vi^@2a/K40W9bL096AT@2l_;`0f][J0<71`@2m
_Kd0V9RH08b<S02@T900VYZJ0=7Ad@2YZJT0=SHf03Ph>01dM7@0EEEE03`l?00Z:RX0T92@09RHV01H
F5P0EEEE061PH01]KFd0N7Qh0:BTY02[Zj/0FEUI055AD@1FEUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1:
BTX0=3@d04I6AP2ZZZX0Q8B405eMG@2=SHd0D51@00807QhN00d07alO02<S8`0U9BD0CTi>0;bl_02I
VIT0[Zj^096AT@2h^;P0_;bl0;fm_@2MWId0WinO0080S8b<03L0bLW90=3@d02a/K40ZZZZ0;Rh^02l
_;`0^k^k06UYJ@0b<S80:2PX02@T900W9bL0:b/[06ATI02:RXX0b/[:08f=S@2?Shl0C4a<09bLW01_
Kfl07AdM01`L700N7Qh07alO024Q8@0R8R8092@T09:BTP1gMgL0D51@06MWI`2CTi<0U9BD092@T01g
MgL0;bl_02<S8`0Y:BT0Ng]k08R8R01kNg/0NGUi055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1N
GUh0A4A406UYJ@1ZJVX0XZ:R0080a/K602L0Vi^K0;Bd]01RHV80U9BD0;:b/P2IVIT0IVIV06MWI`27
QhL0alO70=cLg03Ogml0g]kN0<c<c031`L40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin08n?S`2L
W9`0Rh^;04m?C`1MGEd0IVIV07alO01[Jf/0]KFe05iNGP1oOgl0UYJF069RHP1YJFT0WinO0=3@d02K
Vi/04Oooool000oooooo0900MgMg09nOW`3@d=00^;Rh05eMG@1>CTh0:b/[06i^KP1/K6`0EUIF05iN
GP0R8R80CTi>051@D010@4002@T903Ph>016ATH08b<S01/K6`1GEeL0:RXZ03dm?@1MGEd0<c<c04=3
@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0ADE50451@@0_;bl0410@05]KF`1`L700:2PX05MG
E`0a<C409bLW05QHF00l?3`0FEUI05EEE@0E5AD071`L04A4A01OGel0>3Ph03Lg=`1LG5`0@D5104I6
AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1KFe/0De=C020P801RHV80Bd];030`<01UIFD0@d=305MG
E`1cLg<0ADE507QhN01]KFd0@D5107alO01RHV80<c<c07emO@2e]KD0Ph>303Ph>01FEUH0GemO03Hf
=P11@D40@d=303Lg=`0I6AT08B4Q05MGE`1iNGT0XZ:R079bLP0g=cL0WYjN06QXJ00h>3P0GemO0451
@@1jNWX0@D5104U9B@1kNg/0A4A404i>CP2HV9P0Jf][05mOG`1iNGT0HV9R06][J`15ADD0JVYZ05AD
E019BDT0Bd];075aL@1UIFD0Jf][04=3@`28R8P0HF5Q06IVIP1HF5P0B4Q806MWI`15ADD0G5aL07Qh
N01bLW80X:2P07moO`0g=cL0I6AT0:RXZ01YJFT0Jf][06m_K`19BDT0[jn_075aL@1KFe/208N7Q`1;
04m?C`2?Shl0alO7075aL@1nOWh0CDe=07]kN`1mOGd0HV9R06i^KP2@T900>SXj0492@P1hN7P0Ng]k
04Q8B02^[Zh0RXZ:07AdM016ATH0G5aL06=SH`1iNGT0GEeM09>CT`11@D40UiNG08V9R@1:BTX0GEeM
0:RXZ01;Bd/0>3Ph06ATI00j>SX0L71`08J6QP1<C4`0Fe]K08B4Q017AdL0F5QH04=3@`1LG5`0Jf][
04a<C02WYjL0LW9b03Hf=P16ATH0MgMg02l_;`1RHV80EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL
079bLP1DE5@0Jf][04];B`2LW9`0Kfm_04E5A@1WIfL0O7al06i^KP1UIFD0DU9B061PH02@T900I6AT
0080IVIV04<0FUYJ02/[:`0m?Cd0CTi>08>3P`0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5
07=cL`16ATH0E5AD04i>CP16ATH0Jf][07=cL`1EEED0FUYJ05mOG`19BDT0?Shn08F5Q@2GUiL0SHf=
04m?C`2MWId0Vi^K05IFEP0[:b/0Kfm_05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0ADE5
07inOP1BDU80;Rh^06MWI`11@D40<S8b09VIV@1mOGd0BTY:09>CT`1ADE40>SXj04M7A`1ADE40Kfm_
05]KF`1ZJVX0SHf=03hn?P1/K6`0?clo06a/K015ADD0EUIF01cooooo0140d=3@0;fm_@2_[jl0QHF5
05]KF`1ADE40B4Q804I6AP1nOWh0:2PX028R8P0O7al0<C4a0:n_[`2@T900N7Qh079bLP0209:BTP0?
09RHV02`/;00clo?0<g=c@2][Jd0SXj>0:NWY`27QhL0`<3004=3@`0X:2P092@T02HV9P0U9BD0820P
008071`L00<0820P024Q8@0M7Ad00`0M7Ad0S`1DE5@0XJ6Q0:^[Z`2SXj<0MWIf07QhN02RXZ80QhN7
08^;R`1ZJVX0Vi^K0:FUY@2OWil0[Zj^0<30`02ZZZX0YZJV09ZJVP34a<@0f=SH0<_;b`2ATI40B4Q8
03`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1BDU80>SXj0410@01IFET0LW9b05eMG@17AdL09RHV
028R8P0W9bL0=CDe034a<@0g=cL0EEEE09jNWP2@T900;bl_02<S8`1XJ6P0G5aL05]KF`2WYjL0NGUi
02d];@0Z:RX0:2PX02/[:`0`<300=SHf08F5Q@30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B
0:b/[01HF5P0:BTY02l_;`1YJFT0G5aL03Ph>00X:2P09RHV07AdM00n?Sh0B4Q807]kN`1lO7`0?Shn
03Ph>00Z:RX07alO01dM7@0N7Qh08R8R05mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem
06EUI@1YJFT0Kfm_08>3P`37alL0ZJVY03`l?00/;2`0EUIF05]KF`15ADD0?clo07YjNP1:BTX09RHV
02@T900R8R809BDU02PX:01kNg/0CTi>04a<C01@D500PH61061PH02CTi<0/K6a0<K6aP3=cLd0WIfM
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08B4Q028R8P0S8b<09BDU07inOP1`L700Ti>C
0080S8b<0140YJFU08b<S01?Cdl0Xj>S09bLW01VIVH0e=CD0=WIf@2`/;00WIfM0;^k^`2b/[80b<S8
0:JVYP2;Rh/0KVi^02DU9@02020P800;01hN7P18B4P0IVIV0:FUY@21PH40][Jf059BDP20P800GemO
01dM7@0L71`00P0M7Ad0A`0O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80ZJVY08Z:RP2UYJD0RXZ:
02<S8`0L71`07QhN02HV9P1fMWH0fm_K0;:b/P23Ph<0K6a/03Hf=P0_;bl0<c<c04=3@`1<C4`0AdM7
0492@P1IFET0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0clo?0<C4a03Bd]80R8R808J6QP2_[jl0dM7A
0<[:bP35aLD0a<C40=GEe@3De=@0VYZJ06IVIP3De=@0f][J0<30`01ZJVX0=cLg0410@01<C4`0DE5A
06m_K`1:BTX0BDU904Q8B01<C4`0Jf][0<K6aP2RXZ80H61P03dm?@0i>CT0ADE505QHF02b/[80JFUY
017ooooo000?ooooo`0405QHF01bLW80dm?C0;Vi^@80F5QH00H0:BTY04i>CP1=CDd0@D51038b<P0D
51@30451@@1401lO7`0a<C40@41000h>3P0C4a<0KFe]03hn?P0V9RH0>3Ph02TY:@1JFUX0:RXZ04Y:
BP24Q8@0IVIV02PX:01DE5@0Kfm_03hn?P0];Bd0D51@02DU9@1dM7@0HV9R01`L7017AdL0F5QH03<c
<`0k>c/0:BTY06a/K01iNGT0GemO02<S8`0g=cL0EEEE04A4A00/;2`0MGEe05MGE`1?Cdl0@d=306QX
J00R8R80Jf][08>3P`0f=SH0E5AD02`/;00N7Qh0FEUI06EUI@0j>SX0IfMW0410@01PH600QHF504m?
C`1jNWX0Bd];02`/;021PH40IVIV03Ti>@1/K6`0Z:RX08F5Q@1HF5P205UIF@0J04=3@`0o?cl0ADE5
04Q8B00[:b/0;2`/06ATI01_Kfl0TY:B0:>SX`16ATH0VIVI06QXJ00d=3@0H61P04];B`20P800@d=3
04Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL2061PH02a05IFEP1eMGD0H61P051@D018B4P0
HF5Q04=3@`1gMgL0?3`l07alO00/;2`0IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0K6a/05aLG02][Jd0
GEeM03Ph>01SHf<0Ogmo069RHP1JFUX0QhN703`l?02?Shl0GEeM055AD@2GUiL0NGUi03Hf=P1CDe<0
Ogmo06MWI`2@T900EUIF06=SH`1_Kfl0FEUI06=SH`2h^;P0Shn?06MWI`2/[:`0LG5a04I6AP2QXJ40
Zj^[07moO`1>CTh0T92@07IfMP1eMGD0Cdm?08J6QP1<C4`0XZ:R0:2PX01lO7`0Hf=S0;Fe]@1[Jf/0
@d=3061PH00e=CD0HF5Q092@T01EEED0HF5Q08b<S01;Bd/0>c/k04];B`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01/K6`0LG5a01lO7`1QHF40/;2`05iNGP1DE5@0KFe]07EeM@1?Cdl0
Ogmo06IVIP2BTY80DE5A03hn?P1ZJVX0HV9R07AdM02HV9P0CTi>06m_K`2YZJT0O7al07YjNP1eMGD0
HV9R03@d=010@400G5aL08n?S`0m?Cd0K6a/09RHV010@400SHf=09fMW@1VIVH0?Shn08B4Q016ATH0
HF5Q04e=C@0S8b<0A4A405EEE@1[Jf/0FEUI08n?S`1WIfL0;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0
UYJF08V9R@0g=cL0OWin071`L01ZJVX0X:2P08R8R01fMWH0@d=303lo?`2CTi<0G5aL08N7Q`1ZJVX0
>3Ph05IFEP1SHf<0@d=30;6a/@2SXj<0GUiN092@T01UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500
Vi^K04U9B@22PX80?Cdm05UIF@0f=SH0Bd];01cooooo0200d];B0<C4a02MWId0Ogmo061PH01EEED0
D51@06YZJP2DU9@0>3Ph020P800M7Ad092@T09bLW02j^[X0P82007emO@1nOWh0JVYZ065QH@1eMGD0
G5aL08R8R031`L40]KFe08J6QP1^KVh0cLg=08J6QP1WIfL0E5AD03`l?0808b<S04007QhN01/K6`0L
71`07AdM020P800^;Rh07QhN024Q8@1MGEd0Shn?07=cL`2:RXX0@d=303`l?02DU9@0/[:b0<_;b`38
b<P0WYjN07YjNP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX0a<C40<g=c@1nOWh0Q8B404U9B@0V
9RH0@41004M7A`1GEeL0A4A402LW9`17AdL0<c<c034a<@0k>c/0<C4a05YJFP1SHf<0EUIF0410@00V
9RH0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0ADE5065QH@1oOgl0M7Ad02DU9@0W
9bL09BDU0P0S8b<0700X:2P0FEUI0:b/[01cLg<0:RXZ0451@@1:BTX0BDU904I6AP14A4@0PX:2055A
D@0T92@09BDU04M7A`1/K6`0Bd];03hn?P0U9BD0QXJ60492@P0Y:BT0BTY:08j>SP1SHf<0?Shn03Ti
>@0U9BD201dM7@0H01lO7`1SHf<0Vi^K05QHF018B4P0KFe]0:FUY@1CDe<0SHf=07IfMP12@T80>SXj
03dm?@0j>SX0FEUI0;6a/@1lO7`0=3@d0451@@1/K6`0DU9B04U9B@2=SHd0?clo0P0R8R803@0O7al0
92@T024Q8@1TI6@0A4A406ATI023Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@00P1XJ6P08P22PX80
]kNg09nOW`15ADD0Jf][07moO`0^;Rh08R8R030`<00d=3@0E5AD04m?C`16ATH0MWIf071`L01[Jf/0
MWIf08:2PP2:RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3<c<`0SXj>06UYJ@1UIFD0
IfMW07IfMP0l?3`201hN7P0:04A4A01HF5P0Ph>30:f][@31`L40TI6A06=SH`1eMGD07AdM01`L70<0
7AdM00/07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW08R8R02FUYH0Cdm?02@T900201hN7P0i01lO
7`11@D40VIVI055AD@2@T900XZ:R04e=C@0a<C40>SXj05mOG`1RHV80I6AT02DU9@0X:2P0CTi>06=S
H`2IVIT0ADE504];B`2<S8`0d];B0=KFeP32`/80QHF50=GEe@3?cll0/;2`08f=S@33`l<0YZJV096A
T@2l_;`0bLW90;jn_P2YZJT0J6QX07]kN`2l_;`0QhN703Xj>P0h>3P0Bd];05YJFP1QHF40BTY:03dm
?@1HF5P0[Jf]0<W9b@2@T900:b/[02`/;00b<S80?clo04Q8B025QHD0SXj>017ooooo000?ooooo`1l
05ADE012@T80XJ6Q0;bl_01WIfL0Jf][059BDP13@d<0>c/k03Hf=P1^KVh0:2PX0451@@1>CTh0>SXj
02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200;bl_028R8P1=CDd0<S8b06ATI02<S8`0Bd];
01PH600i>CT0JFUY03Hf=P0c<c<0@d=302HV9P1UIFD0Lg=c03lo?`13@d<0KVi^03Hf=P10@400=cLg
05ADE01_Kfl0Q8B403Hf=P0/;2`0D51@04E5A@0T92@0IfMW05MGE`1ADE40ATI60820P00b<S80GemO
09fMW@14A4@0CDe=06UYJ@0K6a/0BDU9079bLP0h>3P0Hf=S03De=@0g=cL0Shn?04e=C@1fMWH0Kfm_
04M7A`1ZJVX0FEUI03Ti>@1UIFD0/k>c08B4Q01JFUX0B4Q803`l?00m?Cd0D51@071`L01RHV80=3@d
02d];@1HF5P0E5AD09>CT`2SXj<0De=C07emO@19BDT0<c<c06IVIP1:BTX0IVIV03@d=01HF5P0NWYj
04A4A01EEED0JVYZ034a<@1RHV80Kfm_05aLG010@400<C4a05mOG`1GEeL0A4A404a<C01SHf<0B4Q8
061PH00k>c/0NGUi05=CD`80F5QH01X0=cLg059BDP0c<c<0BDU906EUI@17AdL0Zj^[0820P011@D40
De=C0820P01=CDd0Bd];08b<S01IFET0V9RH06QXJ015ADD0MWIf07inOP1IFET0JVYZ08F5Q@1KFe/0
Rh^;06YZJP80MGEe08P0DU9B04Q8B02ZZZX0TI6A06=SH`2TY:@0J6QX069RHP2RXZ80WIfM07QhN01E
EED0S8b<07moO`2KVi/0H61P09jNWP1KFe/0UYJF0;fm_@1WIfL0De=C0<?3``1ZJVX0D51@07EeM@14
A4@0GUiN09JFUP1FEUH0GEeM09nOW`1VIVH0A4A404a<C00m?Cd0OGem055AD@25QHD0Q8B404];B`0f
=SH0Ph>306=SH`1UIFD0J6QX030`<01aLG40bLW906QXJ01HF5P0PH6107MgM`1<C4`0>c/k03hn?P1a
LG40@d=304Q8B020P800DU9B03dm?@1NGUh0Fe]K065QH@2DU9@0A4A406YZJP2VYZH0O7al065QH@0m
?Cd0AdM706QXJ00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY055AD@0j>SX0IVIV05mOG`17
AdL0B4Q805IFEP1:BTX0?Cdm071`L01TI6@0>SXj069RHP1fMWH0GUiN05MGE`2<S8`0SXj>08n?S`0m
?Cd0OGem08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0FUYJ08Z:RP1bLW80ATI604U9B@1^
KVh0ATI609^KV`1WIfL0HF5Q07moO`1YJFT0EEEE02/[:`0c<c<0G5aL069RHP0l?3`0UYJF07YjNP23
Ph<0=cLg055AD@0d=3@0DE5A7?ooool0ZP37alL0^;Rh0;>c/`1aLG40EUIF04i>CP1<C4`0Bd];065Q
H@18B4P0820P03dm?@1<C4`0Ph>307emO@1JFUX0Bd];04=3@`1@D500FEUI05YJFP1kNg/0R8R809jN
WP2=SHd0QhN70:RXZ03:b/X0R8R803/k>`11@D40IVIV069RHP15ADD0;Rh^02<S8`0M7Ad071`L03Ph
>01NGUh0;Rh^051@D01:BTX0YjNW07=cL`1mOGd0=cLg02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S05aL
G00b<S80820P01hN7P16ATH0QXJ606e]K@1EEED0NWYj09jNWP34a<@0UiNG07]kN`1GEeL0IFEU04Q8
B00X:2P07alO01/K6`0S8b<0BDU903Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH0:2PX02l_
;`0m?Cd0>3Ph02/[:`0o?cl0]kNg0;:b/P1DE5@0Jf][0;>c/`2n_[h0X:2P03De=@0/;2`09RHV02DU
9@0Z:RX0:BTY05mOG`1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1HF5P08b<S024Q
8@0X:2P0GemO04];B`1>CTh0Hf=S0<c<c02=SHd0;Rh^02<S8`1@D500SXj>04i>CP0h>3P0A4A401dM
7@0L71`092@T05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02h^;P0/;2`0:RXZ02DU
9@0^;Rh0FEUI0;Fe]@1LG5`0<C4a07QhN02LW9`0MWIf0<71`@1MGEd0:RXZ02LW9`0P8200<30`04A4
A01aLG40IfMW06][J`1KFe/0CDe=04=3@`1TI6@0Ti>C09RHV01>CTh0L71`0P12@T806`1GEeL0T92@
06EUI@1QHF40OWin04M7A`0S8b<0@410051@D00l?3`0<S8b02d];@1XJ6P0EeMG04i>CP1kNg/0UYJF
09NGU`14A4@0DU9B0:FUY@3Hf=P0bLW90;no_`3<c<`0d];B08j>SP0205iNGP0N051@D00d=3@0CDe=
07=cL`1QHF40:BTY04U9B@1ADE40T92@0:ZZZP1lO7`0Q8B406a/K02CTi<0@D51024Q8@0L71`07QhN
01`L700Q8B40HF5Q09BDU01YJFT0K6a/07moO`0o?cl0Shn?09:BTP1IFET0820P0P0U9BD0>@0o?cl0
TY:B0:j^[P0e=CD0>c/k04a<C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/09BDU04];B`1_Kfl0
NGUi04=3@`19BDT0QhN70=[JfP3Fe]H0UYJF0=cLg03IfMT0]KFe0:JVYP2m_Kd0`<300;Ng]`2f][H0
W9bL0=7Ad@3Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01ADE40LG5a06e]K@1hN7P0
/K6a09bLW02ATI40ZJVY03Xj>P0b<S80OGem04m?C`1BDU80VIVI0;Vi^@0Aooooo`003oooool0:`1C
De<0A4A405ADE037alL0Q8B406][J`1OGel0?Cdm08N7Q`10@400PH6103@d=014A4@0LW9b03`l?00f
=SH09RHV065QH@0V9RH05ADE051@D011@D407AdM02`/;00];Bd0?3`l03@d=01YJFT0Lg=c05YJFP0P
8200<c<c06ATI00j>SX0?clo0451@@0Z:RX0FUYJ07inOP13@d<0>CTi07QhN00l?3`00P19BDT0m@1M
GEd0C4a<07]kN`0`<3009RHV05EEE@0[:b/06ATI051@D01;Bd/0EUIF051@D01lO7`0=SHf04i>CP2<
S8`0@T9206QXJ023Ph<071`L0410@01iNGT0ADE506a/K011@D40=CDe09JFUP13@d<0OGem07]kN`1E
EED0Jf][061PH00X:2P0?Shn071`L01_Kfl0Bd];04Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c
<c<0Bd];04E5A@1UIFD0QhN704A4A01kNg/0Hf=S034a<@17AdL0=3@d06i^KP0a<C40?3`l05aLG00o
?cl0IFEU08F5Q@1WIfL0I6AT06UYJ@1NGUh0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1S
Hf<0>SXj05YJFP1TI6@0E5AD04a<C00l?3`0K6a/0492@P1MGEd0DE5A03Ti>@2<S8`0OWin04E5A@1J
FUX0VYZJ06e]K@1=CDd0QhN704];B`2JVYX0Ogmo05MGE`23Ph<0J6QX03<c<`1gMgL0TI6A07alO02F
UYH0GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2YZJT0T92@061PH02b/[80VYZJ05mOG`0^
;Rh0L71`08J6QP2JVYX0E5AD08F5Q@0Y:BT0D51@092@T01kNg/0AdM70<c<c01dM7@0?Shn069RHP12
@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD03@d=01CDe<0WYjN069RHP1mOGd0XJ6Q03Ti>@1>
CTh0QHF506MWI`1gMgL09BDU01TI6@10@400YZJV05UIF@11@D40Ogmo07EeM@1[Jf/0De=C05QHF02@
T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0Bd];08J6QP2KVi/0FUYJ0451@@1EEED0GEeM02XZ:P0i
>CT0FUYJ07emO@12@T80ATI607IfMP1KFe/0LW9b0:>SX`23Ph<0>SXj07AdM014A4@0EeMG05EEE@0o
?cl0ADE505=CD`1MGEd0A4A407=cL`1>CTh0>c/k05=CD`1]KFd0HV9R06ATI02ATI40PX:208n?S`1J
FUX0Ng]k08b<S01XJ6P0VIVI07inOP1dM7@0ATI605eMG@28R8P0K6a/07YjNP1fMWH0@D5106MWI`1n
OWh0CDe=08N7Q`1TI6@0DE5A08>3P`2>SXh0Hf=S038b<P0f=SH0Jf][0451@@0S8b<0G5aL08Z:RP1l
O7`0;Rh^04i>CP0K6a/0?3`l01cooooo03P0XJ6Q08J6QP2QXJ40YjNW05EEE@10@400CDe=05ADE01M
GEd0R8R8069RHP1UIFD0EeMG04A4A01FEUH0AdM703Ti>@14A4@0HF5Q08F5Q@1fMWH0Hf=S075aL@1J
FUX0_Kfm0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0C4a<05]KF`1>CTh0;Bd]01dM7@0h
>3P0:b/[04i>CP1@D500FUYJ0;Rh^02j^[X0];Bd08n?S`2QXJ40/k>c08:2PP1/K6`0KVi^04Q8B00R
8R8071`L01/K6`806ATI00/09RHV06MWI`23Ph<0L71`09BDU03;bl/0f=SH0;no_`1hN7P0<c<c01lO
7`0201`L700K01dM7@0F5QH07AdM0492@P0h>3P0=3@d02@T900N7Qh0;Rh^04i>CP1VIVH0?Cdm01hN
7P0e=CD0M7Ad07emO@2XZ:P0/;2`0;^k^`2HV9P0Bd];06a/K024Q8@0P82007emO@1EEED0;Rh^0080
8b<S02009BDU06MWI`1ADE40EUIF08R8R01KFe/0@41003Ph>013@d<0ATI604A4A01LG5`092@T01lO
7`0R8R80OGem0;^k^`2e]KD0T92@09FEU@1oOgl0Rh^;06][J`0_;bl0BTY:09FEU@1;Bd/0?Shn02TY
:@0M7Ad0>SXj05IFEP80^;Rh07H0R8R807=cL`1GEeL0Shn?03@d=00h>3P0820P02l_;`0W9bL09BDU
02LW9`0`<300Kfm_09bLW016ATH0L71`09JFUP2f][H0];Bd09BDU01eMGD0CTi>04e=C@0o?cl0:b/[
06e]K@1BDU80CTi>061PH012@T80@D5106e]K@24Q8@0?3`l02HV9P1ADE40B4Q803`l?00h>3P0Hf=S
07YjNP2<S8`0VYZJ07inOP1KFe/0DE5A0410@00a<C40:RXZ038b<P2HV9P0D51@03/k>`1ADE40PH61
08b<S019BDT0JVYZ0:b/[03Hf=P0b/[:0;:b/P3@d=00`l?307EeM@1VIVH0Cdm?03Hf=P0Y:BT0;Bd]
04E5A@0l?3`0O7al08b<S01WIfL0LG5a05QHF01@D500M7Ad0861P@2_[jl0=CDe04=3@`0Q8B407AdM
01/K6`0P8200Ph>307=cL`1PH600Lg=c08n?S`1RHV80/;2`0;:b/P2EUID0RXZ:09RHV02WYjL0X:2P
09FEU@2e]KD0PH6102d];@0i>CT0BDU90:b/[01eMGD0GemO069RHP1EEED0>c/k034a<@1<C4`0UIFE
07AdM012@T80Bd];0P2l_;`0102DU9@0_;bl0=3@d02XZ:P20:ZZZP0N0;bl_02_[jl0`<300=3@d03?
cll0d=3@0=OGe`2>SXh0;2`/02@T900U9BD0:BTY05mOG`2b/[80SXj>05=CD`1bLW80`L7108b<S01K
Fe/0HF5Q08>3P`37alL0a<C40<W9b@3:b/X0^;Rh0:FUY@2EUID0ZZZZ4Oooool000oooooo04T0Fe]K
04E5A@18B4P0`<3008^;R`1UIFD0JFUY03De=@25QHD0?Shn07MgM`0l?3`0EeMG07]kN`0o?cl0CTi>
024Q8@1PH600;bl_01DE5@13@d<0>SXj01dM7@0`<300:BTY0410@00l?3`0HF5Q07QhN01mOGd0<c<c
03Hf=P1LG5`0Bd];0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph069RHP14A4@0H61P
05QHF01ADE40;Rh^04M7A`1TI6@0A4A401PH601?Cdl08R8R034a<@0o?cl0HV9R03Lg=`14A4@0QHF5
01lO7`0k>c/0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL0:BTY0080FEUI0300?clo
04i>CP1HF5P08b<S02d];@27QhL0O7al04I6AP1HF5P0KVi^03/k>`12@T80AdM703`l?00K6a/0>c/k
06UYJ@1PH600S8b<0;Bd]011@D40Cdm?06i^KP0o?cl0E5AD02TY:@1ZJVX0AdM704A4A012@T809bLW
04];B`1eMGD0P82006a/K01fMWH0Cdm?08j>SP15ADD0JFUY05QHF00o?cl0ADE507UiN@2>SXh0KVi^
04U9B@1]KFd2079bLP1m071`L016ATH0KFe]04Q8B01IFET0NGUi0410@02GUiL0KVi^03<c<`1[Jf/0
V9RH07UiN@18B4P0Lg=c04i>CP1kNg/0Ph>305MGE`21PH40Lg=c05]KF`15ADD0Hf=S07IfMP2?Shl0
FUYJ04i>CP1QHF40K6a/051@D02o_kl0Jf][04a<C02<S8`0QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0
J6QX06ATI020P800Cdm?09bLW01BDU80Jf][0:FUY@1lO7`0=3@d0:j^[P1ZJVX0=3@d055AD@1EEED0
IVIV096AT@1>CTh0A4A406ATI013@d<0G5aL04I6AP0a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200
IfMW03<c<`18B4P0DE5A02XZ:P0g=cL0a<C4038b<P0c<c<0Ng]k03dm?@1;Bd/0Hf=S06a/K01nOWh0
I6AT03hn?P1LG5`0F5QH05aLG02ATI40C4a<04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM7@0Q8B40
@T9207MgM`1;Bd/0ATI6075aL@1`L700OGem0;Bd]01jNWX0;Bd]07=cL`0g=cL0GUiN04=3@`0b<S80
F5QH07IfMP1DE5@0ADE506YZJP1<C4`0@D5106i^KP2SXj<00P1WIfL09P2>SXh0S8b<0861P@0[:b/0
Lg=c07moO`1=CDd0Rh^;071`L00[:b/08R8R0410@01TI6@0E5AD08F5Q@0g=cL071`L04Q8B01YJFT0
>3Ph0820P02PX:00@41005aLG01OGel0DE5A02h^;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01_Kfl0
>CTi08>3P`17AdL0?Shn7?ooool0601WIfL0EUIF06ATI02>SXh0R8R804M7A`0_;bl0B4Q808^;R`2:
RXX0EEEE05QHF00l?3`0?Cdm04=3@`0g=cL0FUYJ071`L01dM7@0OWin08:2PP26QXH0V9RH0;Fe]@80
c<c<00D0[Jf]08:2PP1]KFd0?Cdm03@d=00205aLG00<02HV9P0/;2`0>SXj04=3@`1FEUH0Rh^;08n?
S`1eMGD0Xj>S09JFUP2][Jd0UiNG0P3;bl/05`32`/80c<c<08f=S@0g=cL07AdM01XJ6P0H61P05aLG
01DE5@0I6AT06a/K01DE5@0J6QX0EUIF0::RXP35aLD0bLW90=KFeP2SXj<092@T01dM7@0J6QX05aLG
00806QXJ0P0G5aL01@0K6a/0?3`l03Ti>@0[:b/07alO00809BDU03h0;bl_06=SH`13@d<0:2PX02LW
9`0j>SX0VIVI0:n_[`2BTY80aLG507inOP1PH600GemO04I6AP12@T80C4a<05QHF018B4P0?3`l05YJ
FP1gMgL0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0F5QH01lO7`0R8R80=3@d07If
MP23Ph<0^;Rh0;2`/01^KVh0ATI606=SH`1/K6`0RHV906e]K@1VIVH0U9BD03dm?@0c<c<0=cLg08F5
Q@2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nOW`0`<300;Bd]02LW9`809BDU00/0:b/[
03Xj>P2CTi<0QHF509FEU@39bLT0/K6a07]kN`1<C4`0G5aL07emO@0308n?S`0O0:JVYP1>CTh0BTY:
04E5A@0l?3`0GUiN07MgM`1FEUH092@T02DU9@0b<S80FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/
04I6AP1MGEd0LW9b07UiN@1bLW80LG5a08R8R02TY:@0Z:RX06m_K`1PH600JVYZ08b<S0030:>SX`0R
0<;2`P2e]KD0/[:b09jNWP2CTi<0ZJVY04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0VYZJ
0:NWY`1ZJVX0GUiN06UYJ@2c/k<0^KVi0=SHf01?Cdl0;bl_03De=@0J6QX07AdM02HV9P2VYZH0GemO
04Q8B01cLg<0Xj>S0;Fe]@80/;2`02T0]KFe06ATI01>CTh0BDU904];B`19BDT0L71`0:ZZZP1KFe/0
=CDe07AdM02ATI40=SHf0451@@23Ph<0<c<c02DU9@14A4@0DE5A0;fm_@1`L700CDe=08f=S@2o_kl0
F5QH04M7A`2?Shl0X:2P055AD@1^KVh0SHf=0<W9b@2g]kL0G5aL06=SH`2UYJD0a/K609bLW02g]kL0
<c<c01lO7`0202<S8`0B02PX:011@D40[Zj^0=7Ad@2LW9`0U9BD05ADE01<C4`0@T9205IFEP3<c<`0
f=SH0:n_[`2>SXh0QHF507YjNP2?Shl0YZJV4Oooool000oooooo03D0EEEE04i>CP0n?Sh0XJ6Q08J6
QP1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IFEP11@D40AdM701TI6@1LG5`0@41001LG
5`0l?3`0<c<c01TI6@0a<C40:b/[0492@P0I6AT0<c<c05]KF`1aLG40>c/k030`<00b<S80:RXZ03Lg
=`0l?3`03@d=02PX:01RHV80A4A4028R8P1MGEd09BDU03Ti>@0n?Sh0F5QH05eMG@0i>CT08b<S01dM
7@15ADD0E5AD01dM7@0205iNGP0L03Xj>P0k>c/0EEEE02d];@14A4@0WYjN05ADE00d=3@0H61P01lO
7`0d=3@0QHF50451@@1DE5@0IFEU02PX:02HV9P0EUIF06ATI01iNGT0GemO04];B`1]KFd0AdM703Lg
=`2IVIT0QhN702h^;P80?3`l05h0@d=304M7A`1BDU80BDU9030`<00c<c<0CDe=04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C06e]K@1@D500E5AD07inOP1?Cdl0EEEE07AdM01mOGd0Ng]k
09jNWP1LG5`0MGEe04Q8B01oOgl0J6QX04=3@`16ATH0G5aL03`l?01ZJVX0BDU9061PH01?Cdl0Bd];
06UYJ@17AdL0CDe=03Lg=`0i>CT0JFUY0451@@2XZ:P0OGem03De=@16ATH0ZJVY08B4Q017AdL0NGUi
05eMG@2IVIT0TY:B059BDP22PX80O7al071`L012@T80EEEE061PH02=SHd0RXZ:05YJFP2LW9`0GEeM
03hn?P25QHD0V9RH07QhN02>SXh0CDe=03dm?@25QHD0YZJV0820P01ADE40IfMW071`L022PX80B4Q8
08Z:RP1KFe/0PH610:>SX`1TI6@0?Cdm09RHV01]KFd0=CDe0P1;Bd/0H01JFUX0SHf=06QXJ019BDT0
MgMg0410@01ADE40C4a<038b<P2PX:00KFe]07inOP29RHT0<C4a02@T901OGel0BDU904E5A@13@d<0
=cLg04A4A037alL0FUYJ04E5A@2=SHd0ATI604Y:BP1@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0
=cLg07moO`1KFe/0LG5a07moO`0_;bl0=CDe08:2PP28R8P0EUIF028R8P1;Bd/0H61P034a<@1OGel0
Ph>306e]K@1bLW80_;bl061PH00H61P0OWin03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0
GUiN05ADE00Y:BT0>c/k051@D01TI6@0F5QH07YjNP2b/[80MGEe030`<01EEED0KFe]05MGE`26QXH0
RXZ:06m_K`0l?3`0?clo075aL@11@D40TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE08j>SP1XJ6P0
IFEU075aL@80>SXj00/0DU9B06IVIP1>CTh0@41004A4A02DU9@0MWIf02h^;P1`L700?Cdm03Ti>@0L
ooooo`0c055AD@16ATH0@D5104a<C01kNg/0LG5a07YjNP1_Kfl0I6AT04U9B@0j>SX0QHF503Xj>P0V
9RH0BTY:05]KF`14A4@0=CDe034a<@0c<c<0<C4a03Ti>@1/K6`0cLg=0=7Ad@1[Jf/0SXj>03Ti>@1B
DU80S8b<06MWI`12@T80FEUI06IVIP1EEED0M7Ad08:2PP2:RXX0Shn?07moO`29RHT0TI6A0;Ng]`2b
/[80[:b/09fMW@24Q8@0L71`0:FUY@1^KVh06a/K00805QHF00l06QXJ01/K6`0G5aL05aLG01PH600K
6a/05ADE01TI6@10@400ZZZZ0;:b/P37alL0RXZ:01`L700H61P00P0F5QH0HP0I6AT05aLG01PH600H
61P05aLG01TI6@0e=CD0@T9202DU9@0P82009bLW02<S8`0j>SX0JVYZ05iNGP1dM7@0MGEe08>3P`2J
VYX0LG5a0::RXP1ADE40K6a/09ZJVP1oOgl0LW9b07MgM`2;Rh/0TY:B0:VYZ@3EeMD0Lg=c051@D010
@400<c<c055AD@2EUID0XJ6Q0492@P0h>3P0=SHf059BDP0U9BD0?Cdm07=cL`1>CTh0ADE5061PH021
PH40IVIV04Q8B010@400GUiN051@D01lO7`0[jn_0;Jf]P2o_kl0]kNg0;Rh^03;bl/0a<C40=WIf@3<
c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0NGUi06MWI`0^;Rh0;bl_02TY:@0T92@0:BTY04];B`2c
/k<0Y:BT0;fm_@24Q8@0Jf][061PH01CDe<0EeMG05QHF01GEeL0KVi^0:b/[01OGel0A4A404=3@`1F
EUH0KVi^07QhN00X:2P07QhN0P0P8200C`0n?Sh0Fe]K04I6AP12@T80Fe]K09BDU02>SXh0N7Qh05eM
G@11@D40?Cdm04I6AP1>CTh0Cdm?05=CD`1jNWX0a/K609nOW`12@T80SHf=09jNWP24Q8@0QXJ60<71
`@2a/K40FEUI03lo?`28R8P0Ogmo04E5A@0d=3@0@D5103dm?@0_;bl0?Shn0410@01<C4`0`<300=cL
g038b<P0[:b/0:6QX@2_[jl0e=CD0<_;b`2XZ:P0F5QH03Ti>@0g=cL071`L051@D037alL0@T9205eM
G@1OGel0[Zj^0<_;b`2HV9P0^KVi08j>SP1QHF40G5aL05mOG`11@D40?Cdm04E5A@1TI6@0S8b<09:B
TP2a/K40O7al03/k>`1QHF40b/[:07QhN01gMgL0Rh^;0<C4a039bLT00P2GUiL09`2b/[80Kfm_03@d
=00k>c/0S8b<08j>SP1@D500DU9B03@d=01jNWX0Ogmo03lo?`0j>SX0NGUi0:n_[`1bLW80UiNG08V9
R@0M7Ad07QhN01`L700M7Ad08b<S07UiN@2e]KD0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<30`02l_;`0l?3`0IVIV07alO00Aooooo`003oooool05`1ADE40@d=303dm?@20P800FEUI
04m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C03Xj>P16ATH04a<C03De=@0_;bl04a<C
03@d=00f=SH06ATI00809bLW01h0EUIF03<c<`13@d<0GemO07YjNP0m?Cd0=CDe055AD@0m?Cd09bLW
04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0@d=302TY:@15ADD0Hf=S07QhN016ATH0:2PX
051@D00k>c/051@D04U9B@1EEED204E5A@0Z04M7A`0h>3P0<S8b07]kN`1VIVH0=SHf06MWI`0L71`0
820P06YZJP0g=cL0Cdm?05QHF00Y:BT0Rh^;069RHP1KFe/0MgMg02d];@0g=cL0VIVI065QH@0_;bl0
SXj>0:>SX`1MGEd0ADE503/k>`0/;2`0Cdm?06m_K`1gMgL0EEEE03@d=016ATH0>SXj079bLP2FUYH0
Q8B404Y:BP1[Jf/08B4Q0P1SHf<0E`1:BTX0:2PX03lo?`1VIVH0ADE505=CD`1^KVh0?Cdm04e=C@1i
NGT0F5QH075aL@0b<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Jf][04m?C`1RHV80QhN7065QH@1W
IfL0AdM7075aL@1@D500>SXj061PH00l?3`0[Zj^0:FUY@1:BTX0ADE508n?S`1UIFD0ATI608n?S`1L
G5`0IfMW09JFUP18B4P0Q8B4075aL@1hN7P0=CDe051@D01iNGT0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QXJ605EEE@1PH600MgMg09nOW`1_Kfl0De=C06=SH`1^KVh0XJ6Q05MGE`2?
Shl0PX:206e]K@2a/K40QXJ60492@P27QhL0Shn?05MGE`1cLg<0LG5a04M7A`1aLG40JVYZ05YJFP2P
X:00Lg=c05YJFP0204a<C01@0;Rh^02;Rh/0Ng]k0:f][@11@D40B4Q808J6QP1eMGD0A4A402`/;00N
7Qh08B4Q096AT@1YJFT0@d=308Z:RP17AdL0FEUI03lo?`1BDU80K6a/06][J`0j>SX0CDe=071`L01G
EeL0Hf=S05UIF@1eMGD0Shn?06=SH`0i>CT0IVIV07]kN`19BDT09RHV04=3@`1XJ6P0BTY:03De=@1l
O7`0MGEe05=CD`34a<@0Ng]k0451@@1XJ6P0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01M
GEd0RHV904m?C`0k>c/0J6QX04I6AP0[:b/0A4A409ZJVP23Ph<0De=C05UIF@1_Kfl0;Bd]06i^KP2?
Shl0M7Ad03Hf=P0n?Sh0Hf=S03dm?@1hN7P0GEeM04M7A`0m?Cd204A4A00B06=SH`22PX80KVi^069R
HP2@T900GUiN02TY:@0Z:RX0EEEE03hn?P1GEeL0=CDe0:6QX@2@T900<C4a05EEE@0j>SX0>CTi7?oo
ool0401SHf<0C4a<0451@@0h>3P0ADE508^;R`2/[:`0Rh^;04m?C`1XJ6P0[Zj^0::RXP1DE5@0Bd];
03<c<`0Z:RX3024Q8@0`034a<@1JFUX0KFe]06EUI@1>CTh0]kNg079bLP1]KFd0N7Qh020P800n?Sh0
Ogmo09bLW026QXH0^KVi09NGU`27QhL0TI6A07QhN01DE5@0LW9b07QhN00m?Cd0KVi^079bLP2SXj<0
K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0F5QH05aLG01/K6`0I6AT05QHF01LG5`0E5AD0
5aLG028R8P2DU9@0PH610:NWY`2OWil071`L1@0E5AD02@0I6AT05aLG01HF5P0E5AD061PH02l_;`15
ADD092@T01lO7`0202LW9`1D03/k>`2o_kl0YZJV05EEE@0o?cl0TI6A0820P01NGUh09bLW04E5A@2<
S8`0GEeM03Lg=`0b<S80;bl_03Ti>@16ATH0P82009>CT`0g=cL0:2PX02LW9`0m?Cd0O7al07YjNP2C
Ti<0De=C03Ti>@18B4P0MWIf07MgM`1>CTh0AdM704m?C`0d=3@0=cLg09VIV@1[Jf/0BDU904I6AP1/
K6`0EEEE092@T02BTY80V9RH0;Ng]`2UYJD0Z:RX0;jn_P2f][H0[jn_0;Jf]P2b/[80DE5A03@d=00a
<C40<c<c04A4A01iNGT0QXJ606MWI`0b<S8092@T02LW9`17AdL0UYJF0;Bd]03De=@0_Kfm09FEU@2<
S8`0NWYj06UYJ@1_Kfl0Fe]K04];B`1lO7`0RXZ:09bLW02MWId0`/;207emO@0f=SH07AdM0P0L71`0
1P0M7Ad09BDU03/k>`1XJ6P0De=C07YjNP80UYJF01/0OWin03@d=00m?Cd0820P01hN7P0P82007alO
028R8P1XJ6P0[Zj^0;>c/`0j>SX0UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0OWin
069RHP10@400=cLg04=3@`0l?3`00P0k>c/0>022PX80bLW90:BTY02TY:@0][Jf0:f][@2g]kL0e=CD
04Y:BP1OGel0Z:RX071`L01FEUH0O7al0;Rh^03>c/h0OWin065QH@1ZJVX0a<C40<30`02OWil0KVi^
04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P1IFET0EUIF09fMW@3@d=00FEUI07AdM02d];@0W9bL
08:2PP2?Shl0a/K60;Vi^@2l_;`0aLG50:BTY02XZ:P0<C4a02h^;P14A4@0][Jf08n?S`16ATH07alO
02LW9`1PH600MWIf0P14A4@01P1CDe<0Y:BT07EeM@27QhL0_[jn0451@@807QhN01008B4Q02TY:@24
Q8@0QhN704a<C01NGUh0LW9b08b<S01;Bd/0I6AT0:FUY@1jNWX0:BTY02/[:`0c<c<0ADE50P1?CdlA
ooooo`003oooool0>01DE5@0IVIV04e=C@2=SHd0GEeM05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MG
E`0l?3`0GEeM02DU9@1CDe<0:RXZ04E5A@0d=3@01`L702HV9P11@D408R8R03<c<`0Q8B40?3`l03Ti
>@1:BTX0MWIf08V9R@0Q8B409RHV03Ti>@15ADD0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=c
L`0^;Rh0Hf=S059BDP0b<S80A4A4071`L01>CTh0BTY:06MWI`1PH60092@T03Lg=`0h>3P0@T920P1G
EeL0O`1EEED0<c<c07alO016ATH0;bl_06UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_;bl0R8R8
06=SH`1XJ6P0T92@079bLP0l?3`0UiNG02`/;00O7al0L71`08j>SP18B4P0LG5a05eMG@0b<S809RHV
03hn?P16ATH0BDU903Lg=`1=CDd0@d=3061PH025QHD0HF5Q04Q8B01oOgl0ADE505=CD`10@400DE5A
04];B`18B4P0MGEe05QHF01GEeL0MWIf09JFUP1DE5@0P82005=CD`2<S8`0C4a<07alO016ATH0>3Ph
04=3@`1HF5P0QHF506ATI016ATH0BDU908R8R01FEUH0Bd];03@d=01WIfL0CTi>03dm?@1QHF40>CTi
08F5Q@1`L700BDU903/k>`1oOgl0EeMG034a<@1OGel0FEUI04e=C@2g]kL0J6QX08V9R@24Q8@0Ph>3
03Lg=`1NGUh0SXj>096AT@2:RXX0D51@08n?S`1[Jf/0Bd];08f=S@29RHT0IfMW08b<S01gMgL0MGEe
07moO`2WYjL0Jf][04=3@`1EEED0Rh^;09>CT`1QHF40[Zj^059BDP0d=3@0MGEe08f=S@0l?3`0PX:2
09RHV00f=SH0F5QH05mOG`15ADD0I6AT03Xj>P0c<c<00P1bLW80E`1?Cdl0DE5A038b<P29RHT0PH61
06YZJP2c/k<0@41003@d=02FUYH0Ng]k05ADE01FEUH0?3`l020P802LW9`0IVIV03@d=02BTY80O7al
07MgM`1EEED0LG5a07inOP1_Kfl0<c<c05aLG028R8P0J6QX08:2PP1MGEd0MWIf09JFUP28R8P0D51@
08F5Q@23Ph<0=cLg02<S8`11@D40N7Qh06MWI`0e=CD0LW9b04M7A`0h>3P0Vi^K0:6QX@1<C4`0Lg=c
01/K6`15ADD0Fe]K05eMG@13@d<0Cdm?05IFEP0X:2P0CTi>05eMG@1?Cdl0?3`l06ATI01IFET0IfMW
03dm?@2IVIT0QXJ604e=C@1@D500TY:B061PH01>CTh0Shn?08b<S00m?Cd0?clo05]KF`1HF5P0Ph>3
07EeM@1KFe/0CDe=04];B`1TI6@0L71`08>3P`0206i^KP0>09bLW01cLg<0<c<c034a<@1IFET0EeMG
05mOG`0m?Cd0_;bl09:BTP0f=SH0GEeM059BDP10@40Looooo`0F0410@01<C4`0DU9B04Q8B00o?cl0
J6QX0<30`03Bd]80][Jf0=_Kf`3=cLd0K6a/05MGE`1=CDd0GemO05UIF@0h>3P0DE5A075aL@1[Jf/0
D51@038b<P809BDU01l0YZJV0=CDe01fMWH0Q8B404E5A@0/;2`0=cLg065QH@2`/;00b/[:08j>SP1]
KFd0DU9B03hn?P0i>CT0QXJ60:ZZZP0k>c/0GUiN05mOG`20P800@T9202`/;00a<C40>SXj04=3@`1^
KVh0D51@01`L700G5aL061PH00805QHF018061PH01/K6`0I6AT0>CTi07]kN`2f][H0O7al0:FUY@36
a/H0Cdm?04M7A`0c<c<0:b/[01lO7`0J6QX06ATI01LG5`0E5AD301LG5`0l03<c<`12@T807alO02LW
9`18B4P0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00j>SX0EeMG09RHV02MWId0IFEU03Xj
>P0Y:BT0:2PX02`/;00l?3`0`<3009BDU01iNGT0Ogmo07YjNP2EUID0QHF507QhN02@T900NWYj07em
O@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a07moO`2:RXX0EUIF04Y:BP1`L700Z:RX0;Zj
^P2PX:00VIVI0;fm_@2PX:00a<C40<O7a`2f][H0/K6a0;Zj^P23Ph<0?clo0P0Z:RX03@0e=CD0>SXj
0451@@1MGEd0Ng]k07IfMP1mOGd0XZ:R0<71`@35aLD0T92@08J6QP2ATI400P2g]kL0301GEeL0Bd];
055AD@1TI6@0OGem08>3P`26QXH0MGEe0:BTY01iNGT0820P01`L70807AdM00d07QhN02`/;00`<300
FUYJ06EUI@2ATI40V9RH08^;R`28R8P0<c<c038b<P0P82008b<S008071`L06X07QhN03Ph>01ZJVX0
/;2`06=SH`1aLG40UYJF06][J`0k>c/0?3`l06QXJ01OGel0GUiN075aL@22PX80Q8B404Y:BP0g=cL0
>c/k03Xj>P1:BTX0S8b<0<71`@2KVi/0OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0
/[:b0<c<c031`L40QHF50=;BdP2b/[80GEeM0:2PX030`<00Jf][08>3P`2OWil0CTi>03/k>`1CDe<0
Fe]K04m?C`1PH600JFUY04Y:BP27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02n_[h0
Zj^[0=3@d03Cdm<0`L7105]KF`0[:b/0?Shn0:^[Z`32`/80RXZ:024Q8@0P8200:b/[05YJFP1TI6@0
=cLg04m?C`2;Rh/0][Jf07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e=CD0]KFe05IFEP0j>SX0
AdM70:f][@2`/;00U9BD0:BTY02b/[80UYJF04U9B@1PH600V9RH05mOG`1FEUH0IfMW4Oooool000oo
oooo05D0DU9B08J6QP1SHf<0O7al05mOG`1:BTX0BDU902XZ:P1FEUH0?3`l04];B`0c<c<09BDU05aL
G00i>CT0D51@01PH600Y:BT0ADE501XJ6P0S8b<0B4Q8010@400R8R80:BTY0451@@0Z:RX0;Bd]055A
D@22PX80CTi>02l_;`0k>c/0<30`03lo?`0f=SH0:2PX01`L701_Kfl0F5QH01dM7@1[Jf/0<C4a0410
@00n?Sh0<C4a05UIF@1DE5@0;bl_02DU9@0n?Sh0G5aL02XZ:P0g=cL0;bl_02HV9P0j>SX0A4A403Lg
=`0T92@0Ng]k07AdM00a<C40DU9B02HV9P0O7al0L71`03/k>`0b<S80Hf=S02l_;`20P800EeMG03lo
?`1_Kfl0B4Q803@d=02PX:00GemO034a<@2MWId0^;Rh04m?C`1GEeL0CTi>0080=cLg09L0FUYJ04I6
AP0Y:BT0;bl_05EEE@1@D500L71`09RHV01kNg/0?clo0820P01JFUX0EEEE05mOG`1ADE40ATI604m?
C`1DE5@0ADE504A4A01XJ6P0Ogmo04i>CP20P800HV9R0861P@17AdL0HV9R059BDP14A4@0C4a<05MG
E`1IFET0G5aL06UYJ@1>CTh0NWYj04a<C01nOWh0D51@05EEE@18B4P0=3@d07=cL`18B4P0T92@07in
OP0k>c/0?Cdm0861P@1bLW80>SXj07QhN01NGUh0De=C09FEU@1:BTX0IFEU08^;R`1/K6`0ADE505aL
G01ZJVX0OGem08n?S`13@d<0OGem07YjNP14A4@0PH6109jNWP1/K6`0IVIV07MgM`1FEUH0Kfm_0;Ng
]`2ATI40J6QX0492@P1^KVh0Ti>C04A4A02<S8`0/;2`04m?C`2GUiL0]kNg04i>CP1JFUX0Ti>C059B
DP0o?cl0E5AD04U9B@1jNWX0Ogmo03lo?`1lO7`0Hf=S04M7A`1cLg<0?Cdm09fMW@1HF5P0Cdm?0:b/
[01SHf<0@T9208n?S`1PH600@d=305eMG@12@T807QhN09>CT`23Ph<08B4Q05MGE`1NGUh0I6AT04i>
CP2:RXX0Ogmo07QhN00f=SH0>SXj07inOP1LG5`0SHf=05EEE@1_Kfl0U9BD07IfMP1>CTh0T92@09FE
U@1CDe<07alO03Hf=P1aLG40Jf][0492@P1MGEd0QHF504=3@`1iNGT0Y:BT05YJFP1mOGd0>SXj0080
EUIF0380ATI60492@P1YJFT0GEeM059BDP1NGUh0JVYZ05]KF`11@D40MWIf08:2PP1jNWX0A4A409FE
U@27QhL0BDU905ADE02QXJ40KVi^061PH02TY:@0NGUi03Xj>P1<C4`0I6AT04i>CP25QHD0QXJ604Y:
BP12@T80N7Qh04m?C`1aLG40Y:BT079bLP1JFUX0P82006YZJP0a<C40B4Q806m_K`1ZJVX0A4A402d]
;@1eMGD0IfMW02HV9P1/K6`0AdM702l_;acooooo04X0OGem04=3@`0c<c<0<C4a038b<P1DE5@0NWYj
06IVIP1]KFd0P82005]KF`0a<C407QhN020P801ADE40J6QX069RHP1oOgl0@D5102HV9P0S8b<08R8R
024Q8@0P8200Ogmo06i^KP1hN7P0Ng]k09RHV021PH40Jf][07IfMP2QXJ40/K6a08Z:RP1bLW80LG5a
08V9R@2YZJT0TI6A07UiN@1cLg<0PX:208R8R029RHT0Bd];038b<P0W9bL09BDU02`/;00b<S80ADE5
05ADE00j>SX061PH01/K6`0W9bL0<C4a03/k>`0o?cl0>c/k02d];@1SHf<0YJFU0:BTY03=cLd0YjNW
08:2PP1OGel0@T9203@d=00_;bl0=3@d03hn?P80>c/k03L0=3@d03<c<`0n?Sh0QXJ605QHF012@T80
E5AD05YJFP2e]KD0RXZ:06IVIP1OGel0L71`0;>c/`2IVIT0K6a/07EeM@2a/K40];Bd08j>SP1/K6`0
F5QH04Q8B011@D40NGUi07]kN`0f=SH0>c/k03hn?P1MGEd0K6a/08Z:RP2[Zj/0[:b/0<K6aP32`/80
YJFU09fMW@1nOWh0EeMG038b<P0N7Qh07AdM028R8P0[:b/0<C4a04];B`1LG5`0R8R80<71`@2HV9P0
NGUi08j>SP2^[Zh0bLW90080`<3001`0YjNW0:j^[P2g]kL0MGEe06EUI@1KFe/0De=C04i>CP0h>3P0
=cLg03Xj>P10@400Fe]K0:2PX02HV9P0ZJVY0;no_`21PH40GemO04e=C@1:BTX0F5QH065QH@1RHV80
IVIV06e]K@1dM7@0/k>c0P2g]kL04P2o_kl0J6QX02HV9P0S8b<07QhN020P8010@400Cdm?051@D01?
Cdl0@T9208F5Q@2NWYh0E5AD05EEE@1;Bd/09BDU01lO7`<07AdM06X06a/K030`<01<C4`0Shn?0<c<
c02CTi<0:RXZ02DU9@0X:2P0;bl_0451@@1eMGD0R8R804e=C@1FEUH0[:b/0:>SX`2>SXh0T92@08f=
S@2RXZ80VIVI0;2`/01kNg/0GUiN04U9B@13@d<0EEEE05]KF`1WIfL0RHV90861P@1@D500WIfM0<G5
a@1iNGT0[:b/08N7Q`3;bl/0cLg=0;fm_@1FEUH0Cdm?08N7Q`1/K6`0Kfm_05eMG@1<C4`0@d=305QH
F01GEeL0D51@07moO`2m_Kd0Ti>C0:2PX036a/H0];Bd07IfMP1VIVH0FUYJ06IVIP2DU9@0^k^k0<K6
aP3Kfm/0Xj>S0451@@1]KFd0[Zj^09fMW@29RHT0T92@02/[:`0N7Qh0:BTY06=SH`20P800O7al06EU
I@1;Bd/0NGUi09fMW@1cLg<0Jf][09>CT`2/[:`0IFEU065QH@2WYjL0KVi^04A4A01BDU80Lg=c0;no
_`3EeMD0_kno0:RXZ02f][H0Z:RX05YJFP1LG5`0Ph>306UYJ@1`L700MgMg4Oooool000oooooo0?l0
E5AD065QH@0h>3P0@d=306EUI@1CDe<0KFe]03Hf=P0m?Cd09RHV04=3@`1]KFd0<c<c05UIF@0N7Qh0
De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T9202DU9@0Q8B40:2PX0451@@1<C4`0?Cdm05MGE`22PX80
;bl_02LW9`0o?cl0?Shn02DU9@0W9bL0?Cdm01lO7`22PX80FUYJ02TY:@1SHf<0@41004M7A`1RHV80
<C4a04Y:BP1[Jf/0De=C02@T900n?Sh0AdM701@D500j>SX0CDe=02l_;`0f=SH0Bd];061PH00Y:BT0
KVi^08^;R`11@D40D51@03hn?P0O7al0LW9b05=CD`0[:b/0JVYZ03lo?`1MGEd0Jf][04a<C01QHF40
G5aL04E5A@2LW9`0MWIf03Ph>026QXH0_kno05iNGP1IFET0@41003<c<`0m?Cd0SXj>08:2PP10@400
<c<c05=CD`0a<C40JVYZ09:BTP2KVi/0CDe=07]kN`0S8b<0CDe=07IfMP1GEeL071`L02l_;`1>CTh0
DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0HF5Q0861P@1KFe/0CDe=05ADE00h>3P0F5QH07]kN`21PH40
I6AT03hn?P0m?Cd0O7al05]KF`1]KFd0=cLg051@D01<C4`0@D5105aLG00O7al0KFe]09JFUP1UIFD0
;Rh^05mOG`1]KFd0B4Q805aLG01WIfL0Jf][0<30`01nOWh0E5AD06MWI`2LW9`0@d=3055AD@1YJFT0
DU9B08^;R`1VIVH0QXJ608R8R01aLG40HV9R09bLW02FUYH0Jf][079bLP1TI6@0F5QH0;Zj^P2NWYh0
SHf=04A4A01lO7`0S8b<06ATI01hN7P0`<3005EEE@1jNWX0c<c<05aLG01<C4`0Rh^;05mOG`12@T80
QHF504a<C01=CDd0QHF503/k>`1YJFT0VYZJ05ADE01XJ6P0?Shn096AT@1iNGT0E5AD0;Bd]01nOWh0
C4a<0:BTY02@T900ADE505mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0EEEE02XZ:P1FEUH0
B4Q8079bLP13@d<0?3`l07=cL`15ADD0DE5A05iNGP1FEUH0VIVI075aL@1:BTX0Fe]K05EEE@1gMgL0
?clo02l_;`1IFET0<S8b03<c<`1;Bd/0OGem05UIF@29RHT0Y:BT03dm?@1NGUh0@41006IVIP1`L700
ADE5038b<P19BDT0De=C05EEE@1@D500TY:B04Q8B00Y:BT0BTY:05]KF`12@T80=CDe0;:b/P2/[:`0
02<0G5aL04=3@`22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A403De=@1:BTX0I6AT0492@P0o
?cl0F5QH04E5A@1UIFD0WinO071`L023Ph<0XZ:R05YJFP0Y:BT0:2PX03Xj>P14A4@0E5AD0451@@1o
Ogl0I6AT04A4A01LG5`0?3`l02l_;`0Looooo`0a06IVIP1oOgl0ATI602XZ:P0U9BD0@d=305iNGP2<
S8`0I6AT04M7A`11@D407AdM01/K6`0L71`06a/K01DE5@0L71`092@T02<S8`0Q8B407QhN020P800V
9RH0:BTY06IVIP0[:b/09BDU02XZ:P17AdL0YjNW0;Bd]01VIVH0HV9R0;Bd]01`L700JFUY07AdM01i
NGT0Jf][05eMG@1WIfL0NWYj07EeM@1jNWX0YZJV0861P@1>CTh0@T92038b<P0202/[:`80;bl_00/0
KVi^09bLW01?Cdl0:b/[02DU9@0S8b<071`L028R8P0^;Rh0GEeM0:NWY`020;bl_00809ZJVP1lO7`0
PH610:BTY02_[jl0RHV903/k>`0M7Ad201XJ6P0K01`L700P82009BDU03Ti>@1]KFd0;2`/01hN7P18
B4P0PH61075aL@14A4@0=3@d03Xj>P2_[jl0UiNG03Ti>@1aLG40H61P02XZ:P0W9bL0?clo05EEE@19
BDT0J6QX0<G5a@1XJ6P0<c<c0080:BTY02H0<S8b030`<00l?3`0QHF509jNWP2f][H0^[Zj0;6a/@2K
Vi/0Ogmo07inOP1?Cdl0?clo03Ph>00g=cL0=3@d02XZ:P0U9BD0;Bd]0:^[Z`2][Jd0c/k>0;:b/P24
Q8@0QXJ60;Rh^01DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@1IFET0MGEe06][J`80
Cdm?0940VIVI09:BTP2k^k/0ZZZZ07UiN@1]KFd0>CTi0410@01LG5`0J6QX06UYJ@1=CDd0@D5105QH
F02QXJ40^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0X:2P06MWI`17AdL0@D5106m_
K`2a/K40Q8B403De=@0i>CT0Bd];04=3@`0N7Qh071`L01XJ6P0H61P06ATI01lO7`1BDU80_;bl0;Rh
^02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH0<_;b`29RHT0`L710<_;b`28R8P0K6a/071`
L029RHT0Z:RX0:f][@0b<S80=SHf02`/;00W9bL0<S8b061PH016ATH0:b/[0492@P2;Rh/0CTi>07Ui
N@39bLT0YJFU06][J`3;bl/0fMWI0=7Ad@1`L700Kfm_03Ti>@0k>c/0FUYJ071`L01UIFD0PX:203De
=@0m?Cd0GEeM08^;R`2g]kL0c<c<0<C4a02i^KT0PX:20<71`@1NGUh0<C4a06UYJ@21PH40_[jn0<o?
c`2VYZH0`l?30<K6aP2_[jl0IFEU0410@01EEED0J6QX09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm
?@0c<c<0C4a<08^;R`2>SXh0Ti>C05MGE`1aLG40dM7A0=_Kf`1SHf<0F5QH04a<C01BDU80XJ6Q0:>S
X`2MWId0K6a/06e]K@2j^[X0KFe]02HV9P0_;bl0EEEE03`l?00m?Cd0@T92017ooooo000?ooooo`1G
051@D02HV9P0KVi^04e=C@1RHV80@d=3069RHP13@d<0@T92061PH01;Bd/0T92@03Hf=P1@D500BTY:
05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO034a<@0^;Rh0IFEU04=3@`1UIFD0QHF5
03@d=00Q8B40<C4a03/k>`19BDT0;2`/03De=@0N7Qh0Ogmo06UYJ@0d=3@0Fe]K04e=C@14A4@0N7Qh
03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C40=3@d038b<P0[:b/0>SXj06i^KP1dM7@0;Bd]
06EUI@1TI6@0>3Ph06ATI01@D5007AdM06QXJ00m?Cd0;Bd]07=cL`1BDU80DE5A05QHF01TI6@0O7al
06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07moO`1;Bd/0GemO06][J`0m?Cd07alO0080ADE509/0Bd];
02l_;`1/K6`0=CDe04U9B@1nOWh0R8R8038b<P1kNg/0GEeM04Y:BP1CDe<0E5AD05mOG`13@d<0De=C
04A4A00l?3`0MGEe08j>SP1QHF40LW9b0410@02;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF
05=CD`1GEeL0>3Ph07inOP1MGEd0EUIF04M7A`1JFUX0L71`04Y:BP1WIfL0IFEU07alO028R8P0GemO
03Hf=P1QHF40N7Qh06YZJP1YJFT0QHF506MWI`35aLD0VYZJ05QHF01OGel0ZJVY04Q8B01CDe<0OGem
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU071`L01XJ6P0L71`05]KF`3:b/X0SXj>
06IVIP14A4@0Zj^[0;Bd]01KFe/0KFe]0:6QX@1:BTX0NWYj0<?3``1MGEd0A4A409JFUP1?Cdl0Jf][
07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0GUiN04M7A`2[Zj/0QXJ604a<C02RXZ80Kfm_
02d];@23Ph<0Shn?0410@01?Cdl0<30`01XJ6P20P800TI6A03<c<`2FUYH0XJ6Q07moO`13@d<0IfMW
05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1VIVH0FUYJ0:j^[P2BTY80F5QH071`L01]KFd0RHV9
04Q8B01=CDd0QhN708j>SP0a<C40DU9B06ATI00l?3`0TY:B0:FUY@1lO7`0L71`02<S8`1:BTX0Lg=c
06m_K`1ADE40I6AT05iNGP0203<c<`0/06i^KP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH61
04a<C00i>CT0WinO06a/K01>CTh0K6a/07AdM01KFe/0E5AD06YZJP1KFe/0DU9B071`L01@D500CDe=
07inOP1YJFT0FUYJ0:ZZZP1LG5`0<c<c07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI
0861P@16ATH0F5QH0451@@0a<C4Looooo`0?08R8R01^KVh0PH6103Lg=`0T92@0BDU907]kN`2MWId0
B4Q803hn?P0d=3@071`L02TY:@0S8b<061PH00805ADE00<08B4Q02HV9P0M7Ad00P0M7Ad04@0N7Qh0
Bd];05MGE`0U9BD08B4Q02DU9@0/;2`0T92@0;Fe]@2FUYH0GEeM0:JVYP1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?00h0E5AD06a/K02QXJ40JFUY06EUI@1hN7P0B4Q80492@P1:BTX0@D51034a<@0X:2P0
Bd];0<C4a0809bLW05h0;2`/01lO7`0J6QX08R8R02l_;`1hN7P0Vi^K0;no_`31`L40];Bd0:>SX`29
RHT0N7Qh07moO`2HV9P0[jn_08V9R@15ADD0:b/[02HV9P0Z:RX0;Rh^02PX:019BDT0QHF503De=@1G
EeL0DE5A03@d=00/;2`0<30`06m_K`3IfMT0d];B05QHF01TI6@0HV9R02d];@0L71`07QhN02HV9P0m
?Cd0P8200:BTY01jNWX0LG5a0820P00e=CD0;Rh^02d];@0f=SH0PX:209>CT`2SXj<0TY:B08f=S@2D
U9@0O7al06a/K01QHF40Fe]K051@D01<C4`0G5aL06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12
@T80?Cdm08R8R016ATH0FUYJ04Q8B00g=cL0@41005aLG01bLW80XJ6Q06UYJ@0m?Cd0@d=304m?C`1N
GUh0YjNW092@T02/[:`0bLW908b<S01WIfL0=cLg0P0M7Ad0>00N7Qh0820P03Lg=`2>SXh0dM7A0;Jf
]P2LW9`0YjNW0;2`/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0WIfM079bLP1>CTh0BDU905aL
G02a/K40Y:BT04Y:BP18B4P0KVi^05=CD`1=CDd08B4Q01`L700K6a/06QXJ0492@P2MWId0a/K608Z:
RP1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1]KFd0];Bd0;:b/P2UYJD0UiNG08J6
QP2YZJT0e=CD09:BTP0X:2P0;Rh^0P0Z:RX0600_;bl0C4a<08>3P`25QHD0JFUY079bLP1aLG40KFe]
0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40<C4a02TY:@0e=CD0DU9B07YjNP26QXH0U9BD
07AdM080IfMW03D0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno09^KV`1fMWH0/;2`09nOW`2FUYH0
GemO0;2`/03<c<`0QXJ604M7A`0j>SX0ATI606QXJ036a/H0WYjN07]kN`13@d<0OWin071`L017AdL0
=cLg03De=@1[Jf/0MgMg08j>SP28R8P0V9RH0=7Ad@3Rh^80`l?30:NWY`1CDe<0Hf=S0:>SX`2KVi/0
DE5A04e=C@1[Jf/0bl_;06=SH`0S8b<08R8R02@T900k>c/0=SHf03Ph>00Aooooo`003oooool0O01A
DE40Ti>C06EUI@1>CTh0Lg=c03Xj>P1DE5@0@41003lo?`1cLg<0ADE506MWI`0];Bd0De=C05IFEP1a
LG40AdM703Ph>01MGEd0CTi>01DE5@17AdL0:BTY028R8P11@D40<C4a05IFEP11@D40Ogmo0:FUY@1F
EUH0<S8b03dm?@0k>c/0GEeM02XZ:P0b<S806ATI06MWI`1kNg/0=cLg06=SH`0c<c<0BDU907IfMP0g
=cL0KVi^07]kN`0S8b<08R8R04A4A01YJFT0@D5103`l?00Y:BT08R8R024Q8@12@T80G5aL02PX:01/
K6`0P82003De=@0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP1IFET0;bl_055AD@1=
CDd0>c/k0820P02NWYh0D51@05MGE`2o_kl0FUYJ03/k>`11@D40?Shn03`l?01VIVH0CDe=02/[:`0R
8R80DE5A05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B05QHF01RHV80@d=304Q8B010
@400<30`04m?C`1mOGd0GemO06=SH`1JFUX0R8R807MgM`10@400F5QH061PH01<C4`0DE5A05]KF`1C
De<0OWin04=3@`2ATI4206][J`2N05aLG01FEUH0SHf=05]KF`1kNg/0MWIf07UiN@2<S8`0M7Ad03Lg
=`1jNWX0Ti>C05mOG`1FEUH0JVYZ05UIF@2`/;00R8R805IFEP1VIVH0XZ:R05eMG@2<S8`0WIfM03`l
?025QHD0HF5Q0:j^[P2c/k<0PH6106EUI@2FUYH0Ng]k08n?S`23Ph<0L71`05]KF`39bLT0X:2P04Y:
BP10@400N7Qh09nOW`1RHV80KFe]0:JVYP1UIFD0Kfm_0<[:bP1WIfL0?Shn0:6QX@1MGEd0?clo05]K
F`1ADE40>c/k069RHP0k>c/0GemO08^;R`1>CTh0JFUY04=3@`2?Shl0P820055AD@2h^;P0IfMW04Q8
B01cLg<0Xj>S04m?C`1gMgL0Fe]K01TI6@22PX80]kNg01dM7@19BDT0EEEE06QXJ01EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1:BTX0@T9208j>SP2IVIT0O7al07IfMP2EUID0SHf=020P
800Z:RX0FUYJ07YjNP12@T80Jf][08N7Q`1;Bd/0F5QH0:BTY01NGUh0SHf=0492@P1>CTh0DU9B03lo
?`0^;Rh0NWYj07]kN`1[Jf/0@T9206IVIP0/;2`0=cLg071`L023Ph<0JVYZ034a<@1VIVH0RHV902TY
:@1@D500VIVI075aL@1?Cdl0OWin06IVIP0Y:BT0=3@d03hn?P1FEUH0AdM707EeM@0a<C409BDU06i^
KP1BDU80DE5A0;^k^`25QHD0KFe]09fMW@20P800=cLg04e=C@1SHf<0LG5a05IFEP0h>3P204i>CP04
0410@019BDT0>CTi01/K6acooooo00`0L71`09ZJVP2JVYX0Ti>C04U9B@1[Jf/0_kno07QhN017AdL0
@41002DU9@0L71`2020P800301HF5P0E5AD05ADE00808R8R02h08B4Q01hN7P0M7Ad08R8R06i^KP1?
Cdl09RHV024Q8@0U9BD0?Cdm09bLW029RHT0Cdm?08f=S@2DU9@0CTi>05QHF00o?cl0FUYJ05eMG@1D
E5@0Hf=S08B4Q02a/K40YjNW06MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805iNGP28
R8P0JVYZ034a<@0^;Rh0<S8b0451@@1=CDd0ATI606e]K@2=SHd0c/k>0P2WYjL03@2UYJD0ZZZZ0;fm
_@2FUYH0N7Qh08F5Q@2JVYX0/k>c092@T01_Kfl0ADE504=3@`16ATH00P1DE5@03@1PH600S8b<08:2
PP19BDT0EUIF09:BTP2e]KD0UYJF0:2PX02h^;P0RXZ:05ADE011@D400P0O7al05@0P8200:b/[09ZJ
VP1JFUX0X:2P07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09^KV`28R8P0Zj^[0<C4
a028R8P0FUYJ03dm?@0203<c<`0O04A4A012@T80ATI608:2PP3:b/X0Shn?09VIV@17AdL0@D510410
@020P800Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2CTi<0VYZJ04a<C015ADD0AdM70:FU
Y@2JVYX0^[Zj09NGU`1WIfL0EUIF03Ph>00301dM7@2801lO7`19BDT0QHF505iNGP1ADE40Fe]K059B
DP1MGEd0Ph>30;Bd]02ATI40IFEU0:JVYP3Shn<0f][J0:BTY01>CTh0EEEE06MWI`2OWil0`l?30:VY
Z@2ATI40WinO08n?S`1eMGD0RHV905aLG015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`25QHD0AdM704e=
C@1mOGd0Vi^K0;6a/@2XZ:P0cLg=0;>c/`1gMgL0EUIF0:b/[02TY:@0JVYZ07]kN`1nOWh0MgMg06m_
K`2SXj<0;2`/02XZ:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY09NGU`2`/;00dM7A0>3P
h03IfMT0d];B06][J`2ATI40YjNW0:JVYP1kNg/0;Bd]02XZ:P0`<300?3`l05aLG02`/;00YjNW06MW
I`2n_[h0cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0N7Qh04=3@`1CDe<0X:2P0:NW
Y`2o_kl0RHV907alO01@D500?Cdm08f=S@2l_;`0YZJV03Ti>@1;Bd/0WinO0:BTY00`<300;Bd]02TY
:@16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B021PH40^[Zj0=GEe@3:b/X0Ogmo05MG
E`1kNg/0e]KF07emO@0Z:RX092@T024Q8@0m?Cd0<c<c03Ti>A7ooooo000?ooooo`0[055AD@1UIFD0
=3@d030`<01DE5@0>CTi04I6AP0I6AT08b<S04Y:BP0j>SX0;Bd]01<C4`0V9RH0=CDe07EeM@0M7Ad0
3Ph>03Ti>@0b<S805ADE04I6AP0@41003@d=02<S8`0];Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0
CTi>02h^;P16ATH0:2PX03Xj>P0C4a<0ADE503hn?P0I6AT0C4a<04Q8B00202`/;00<028R8P11@D40
IFEU04];B`0Q8B40<30`05]KF`0K6a/0>CTi065QH@1EEED0;Rh^0P1;Bd/0H00Q8B40DE5A08b<S016
ATH0@d=304];B`0I6AT0Cdm?06ATI00/;2`0CTi>01hN7P0h>3P0HF5Q03lo?`1IFET0Cdm?02<S8`1N
GUh0WYjN05mOG`10@400alO7071`L01IFET0ADE50492@P0o?cl0K6a/06ATI00f=SH0:BTY05eMG@1H
F5P0GemO0:JVYP2k^k/0D51@06e]K@1/K6`0BTY:06UYJ@1VIVH0M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0KFe]0861P@1aLG40EEEE096AT@1iNGT0DU9B04i>CP1NGUh0GEeM096AT@13
@d<0PX:20492@P24Q8@0HV9R04I6AP1`L700=3@d06][J`1UIFD0HV9R08f=S@0k>c/0;Rh^05iNGP1g
MgL0IVIV04A4A01ZJVX0A4A409bLW01hN7P0Bd];065QH@2BTY80ADE5055AD@1]KFd0=SHf07AdM01K
Fe/0HV9R07inOP80JFUY08D0Vi^K071`L01YJFT0TI6A06QXJ01?Cdl0cLg=0<S8b02MWId0ADE50:6Q
X@2f][H0E5AD08R8R02k^k/0Ogmo07]kN`3AdM40L71`02h^;P2DU9@0Ng]k04e=C@1>CTh0;bl_06=S
H`2GUiL0HF5Q07AdM02;Rh/0=3@d08F5Q@1=CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VY
Z@0Z:RX0FEUI03lo?`0n?Sh0Ph>30;^k^`1?Cdl0IfMW06a/K01PH600A4A404i>CP2RXZ80ZJVY05iN
GP0X:2P0Kfm_03`l?01VIVH0KFe]03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]06IV
IP0k>c/092@T03lo?`22PX80F5QH065QH@2_[jl0BDU904a<C01RHV80DE5A05UIF@1ADE40>SXj04A4
A01;Bd/0L71`04E5A@1[Jf/0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0>SXj08>3
P`1XJ6P0EeMG09FEU@2RXZ80KFe]04E5A@0g=cL0B4Q804A4A02VYZH0EUIF03lo?`2@T900Cdm?02HV
9P2>SXh0UiNG05mOG`2NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1KFe/09BDU04=3
@`1ADE40;Bd]01cooooo00d0P82007YjNP1YJFT0IVIV0:FUY@3EeMD0emOG065QH@10@400<30`024Q
8@0L71`08B4Q00805ADE00<05QHF01DE5@0P82000P0M7Ad0I00O7al07AdM03<c<`1[Jf/0C4a<02DU
9@0R8R80;2`/06m_K`1aLG40GemO05MGE`2XZ:P0b<S803Hf=P0W9bL0<30`03`l?01FEUH0?Shn04A4
A017AdL0BTY:05mOG`17AdL0<S8b0410@01;Bd/0DU9B05aLG010@400?Cdm07IfMP1cLg<0FUYJ09RH
V01>CTh0?Cdm04e=C@0a<C407AdM02TY:@1/K6`0W9bL08j>SP1HF5P0KFe]096AT@2o_kl0_[jn0:^[
Z`2YZJT0SHf=0861P@22PX80Ogmo07MgM`2MWId0V9RH07YjNP1bLW80JVYZ0;:b/P2l_;`0PX:2079b
LP2a/K40XZ:R07AdM01CDe<0?clo08R8R031`L40W9bL07YjNP1UIFD0>c/k03<c<`21PH40JFUY04Y:
BP2FUYH0PH610820P02RXZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0OGem05eMG@1UIFD0Shn?06a/
K01UIFD0DU9B03@d=00];Bd203@d=00K03<c<`15ADD0XJ6Q0;Vi^@2`/;00Jf][03Ti>@1PH600[Jf]
06MWI`1OGel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo0861P@0[:b/0820P02@T9028R8P0M7Ad
06IVIP1RHV80J6QX0080BDU908/07alO02PX:00k>c/0De=C051@D00m?Cd0<S8b03<c<`15ADD0B4Q8
05=CD`1/K6`0Ogmo0:n_[`2IVIT0ZJVY0=oOg`33`l<0XJ6Q075aL@2PX:00aLG50:BTY01cLg<0J6QX
051@D015ADD0D51@06EUI@1aLG40Bd];07UiN@2d];@0YjNW0;Jf]P37alL0SXj>0:BTY01HF5P0B4Q8
05eMG@1]KFd0Rh^;0<C4a03<c<`0cLg=0;Bd]02KVi/0a/K60<;2`P1_Kfl0B4Q8030`<00/;2`0=SHf
069RHP18B4P0;Bd]02DU9@0Y:BT0=CDe05UIF@1CDe<0^;Rh0;jn_P3=cLd0^KVi09JFUP30`<00WinO
08f=S@33`l<0NGUi0;6a/@2HV9P0C4a<06][J`2;Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM
09NGU`2c/k<0];Bd0;Vi^@1>CTh0>3Ph05eMG@2i^KT0d];B0:JVYP0b<S80:b/[03Hf=P1JFUX0^[Zj
09JFUP2b/[80][Jf0;^k^`2:RXX0YjNW07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0<C4a
06i^KP36a/H0Shn?0:ZZZP3=cLd0eMGE0=CDe02GUiL0VYZJ0;Bd]03>c/h0cLg=0;6a/@2LW9`0YZJV
0=KFeP2g]kL0Zj^[03Lg=`0];Bd09BDU02h^;P11@D40EeMG017ooooo000?ooooo`0n04m?C`1oOgl0
GEeM04U9B@1QHF40=cLg05eMG@16ATH0<C4a038b<P0X:2P0EEEE03Ph>00S8b<07QhN04A4A00Y:BT0
6ATI03Xj>P0G5aL02`/;02HV9P0Q8B405aLG01TI6@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY0410@00j>SX06ATI0410@00V9RH0F5QH05ADE019BDT0BTY:05UIF@0b<S80JFUY03Hf=P1DE5@0
Fe]K07=cL`0h>3P0>CTi05iNGP1RHV80<30`069RHP1IFET0<C4a04=3@`1gMgL0C4a<04e=C@2CTi<2
04Y:BP2A06IVIP0J6QX0EeMG07IfMP0X:2P0BTY:03Xj>P0_;bl0Jf][03Lg=`1?Cdl0GUiN061PH011
@D40WinO07EeM@10@400bLW908:2PP1DE5@0@d=305YJFP13@d<0I6AT08n?S`1RHV80;Rh^05QHF01A
DE40C4a<09ZJVP2h^;P0GUiN05aLG01^KVh0A4A407UiN@1KFe/0@d=3038b<P1;Bd/0L71`03/k>`1O
Gel0JFUY03Ph>01=CDd0H61P0820P01MGEd0>c/k08B4Q01PH600Cdm?04i>CP1QHF40EEEE08Z:RP11
@D40RHV905eMG@1eMGD0EEEE04E5A@2EUID0CDe=05iNGP1JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/
K6`0@D5104=3@`23Ph<0B4Q80:NWY`1_Kfl0A4A407=cL`2FUYH0KVi^05YJFP1hN7P0>3Ph09VIV@23
Ph<0Ng]k07UiN@0a<C40CTi>09:BTP2MWId0SXj>0:2PX00c<c<0<C4a08b<S02VYZH0GEeM04Y:BP2E
UID0_Kfm069RHP1GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K055AD@11@D40Hf=S03Lg=`0U
9BD0F5QH04I6AP2:RXX0/K6a03Lg=`1ADE40>3Ph08N7Q`2PX:00H61P08V9R@1lO7`0;2`/05mOG`2C
Ti<0BTY:05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800HV9R055AD@0204=3@`0J09NGU`1X
J6P0=3@d069RHP1`L700GUiN07=cL`0h>3P0Shn?0:ZZZP2CTi<0C4a<08Z:RP27QhL0DE5A02l_;`1X
J6P0Ng]k04U9B@17AdL0T92@04i>CP1iNGT0_kno08b<S01KFe/204];B`0`0820P01_Kfl0I6AT05YJ
FP1MGEd0HF5Q03dm?@29RHT0MWIf02LW9`12@T80IVIV05=CD`0[:b/0NGUi0:RXZ01lO7`0?clo08>3
P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i>CT0De=C03Ti>@1bLW80G5aL03Xj>P2@T900QHF505IF
EP2KVi/0M7Ad04E5A@24Q8@0Ogmo03/k>`0V9RH0=3@d07IfMP1kNg/0Hf=S04e=C@1BDU80H61P0P15
ADD00`0c<c?oooooooooo`0Jooooo`09092@T020P800RXZ:09BDU02g]kL0fm_K0=[JfP2BTY80;Bd]
008071`L00<09RHV028R8P0E5AD00P0E5AD0100H61P0;Bd]02<S8`0M7Ad201`L7018065QH@1>CTh0
ATI602<S8`0T92@0=SHf09BDU02;Rh/0QXJ608n?S`28R8P0WinO05MGE`0U9BD092@T03De=@1:BTX0
9RHV02l_;`0k>c/0@41005QHF00l?3`0EUIF069RHP0l?3`0BTY:06MWI`20P800OGem05=CD`1QHF40
Kfm_09BDU02ATI40Ogmo024Q8@0G5aL0>CTi05mOG`1EEED0[jn_08n?S`1PH600EeMG07UiN@2g]kL0
_[jn0:f][@2e]KD0V9RH0:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0<O7a`2JVYX0
Rh^;092@T01KFe/0AdM703Ph>00a<C40;2`/05ADE01iNGT0]kNg0P1lO7`07`1]KFd0R8R80=3@d01j
NWX0CTi>08>3P`2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C01:BTX0FUYJ05ADE01N
GUh0Jf][05UIF@1GEeL0G5aL03Hf=P0_;bl0<C4a02h^;P0o?cl0V9RH0<o?c`36a/H00P1jNWX0I`2X
Z:P0XZ:R0:f][@1QHF40=CDe02/[:`0U9BD092@T02LW9`0g=cL0?clo05=CD`18B4P0820P02@T901V
IVH0NGUi05IFEP1?Cdl0Hf=S04=3@`1hN7P0BTY:0492@P0g=cL0=3@d034a<@0/;2`0;Rh^02/[:`0/
;2`0@41004e=C@21PH40KVi^08b<S02e]KD0dM7A0>;RhP38b<P0_[jn096AT@1jNWX0FUYJ051@D01:
BTX0C4a<09nOW`1ZJVX0HV9R04m?C`0f=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A07=cL`2V
YZH0Kfm_07inOP2/[:`0_kno0;^k^`2g]kL0^[Zj0;Vi^@35aLD0e]KF0=OGe`2OWil0UiNG07AdM01<
C4`0>c/k04e=C@1CDe<0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[:b/07emO@2l
_;`0MGEe05mOG`2j^[X0HF5Q06i^KP1lO7`0ADE503dm?@1;Bd/0PH610:^[Z`1/K6`00P0Z:RX0=P1>
CTh0=cLg06UYJ@1/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00W9bL09RHV02XZ:P0h
>3P0Xj>S07IfMP2=SHd0fMWI0>OWi`3>c/h0OWin06i^KP2WYjL0<30`03Lg=`2OWil0/K6a0<;2`P2Q
XJ40K6a/0;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;jn_P39bLT0[:b/09VIV@2W
YjL0YZJV09FEU@3Jf]X0fMWI0:f][@1JFUX0AdM704Q8B080C4a<4Oooool000oooooo03l0GUiN05mO
G`1YJFT0DU9B06YZJP0`<300B4Q8061PH00S8b<0KFe]03hn?P21PH40Bd];02<S8`0f=SH0CTi>03<c
<`0L71`0=cLg01lO7`0C4a<0<C4a02TY:@0J6QX08R8R02DU9@12@T80=CDe06=SH`25QHD0A4A401`L
700_;bl0?3`l059BDP0Y:BT0;Rh^01lO7`16ATH0IfMW04a<C014A4@0DU9B02d];@1OGel0?Cdm05IF
EP1DE5@0KFe]03/k>`18B4P0HV9R05mOG`0a<C40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820
P013@d<00P1^KVh0S`0I6AT0Cdm?06a/K00a<C40I6AT069RHP0U9BD0M7Ad03Ph>01DE5@0Ph>307=c
L`0m?Cd0Xj>S05=CD`0a<C40UYJF08F5Q@1FEUH0Cdm?051@D00V9RH0C4a<07=cL`1SHf<0<30`04i>
CP1LG5`0Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1@D500Fe]K03`l?011@D40F5QH03Ph
>01/K6`0PH6107IfMP1MGEd0C4a<0820P02@T900ADE507QhN00Z:RX0?Shn06e]K@2?Shl0J6QX03dm
?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE00E5AD0=SHf09jNWP2DU9@0@d=305mO
G`1hN7P051@D02DU9@1MGEd0>SXj09NGU`27QhL0ADE50410@01YJFT0>SXj07YjNP2HV9P092@T06AT
I011@D40Jf][09jNWP1PH600AdM707EeM@15ADD0F5QH08R8R025QHD0E5AD09NGU`30`<00IVIV03`l
?01gMgL0SHf=07=cL`1UIFD0ZZZZ07alO01ZJVX0c/k>0;:b/P0];Bd0C4a<07YjNP0m?Cd0MgMg04M7
A`0U9BD0FEUI055AD@1DE5@0TI6A05mOG`1CDe<0ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@
D02NWYh0De=C09NGU`1hN7P071`L04e=C@3<c<`0?Cdm06MWI`2?Shl0PX:20080GEeM0340CDe=0:BT
Y00l?3`0>3Ph05eMG@1fMWH0IVIV05UIF@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c
<`1dM7@0Shn?04];B`14A4@0Ogmo03@d=01?Cdl0V9RH08R8R01MGEd0D51@03Ti>@1>CTh0F5QH05eM
G@1HF5P0FUYJ069RHP0c<c<0G5aL06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL03`l
?02?Shl0O7al0080EeMG01d0SHf=07IfMP0i>CT0=CDe05IFEP0k>c/0QXJ607EeM@0k>c/0TY:B09jN
WP1YJFT0U9BD06QXJ013@d<0D51@08F5Q@1;Bd/0:BTY02l_;`1hN7P0QXJ606QXJ015ADD0EUIF061P
H00k>c/0A4A403Ti>@0Looooo`0<07=cL`1jNWX0UIFE09NGU`2DU9@0ZJVY0=7Ad@2IVIT0C4a<02<S
8`0H61P07AdM0P0G5aL201DE5@0E02<S8`27QhL0Rh^;05MGE`0f=SH0<30`07YjNP1TI6@0=SHf038b
<P1GEeL0JVYZ07EeM@1cLg<0OWin07QhN01LG5`0BDU909^KV`1WIfL0:BTY0080:b/[01X08B4Q02@T
900h>3P0EUIF05]KF`0Y:BT09RHV03@d=01JFUX0G5aL04Q8B01`L700SHf=061PH00h>3P0<c<c07em
O@1cLg<0PH6103lo?`15ADD0BTY:03hn?P18B4P0HF5Q06ATI080E5AD05D0Hf=S08N7Q`1;Bd/0=3@d
03Lg=`0V9RH092@T03Hf=P1lO7`0YZJV09RHV02JVYX0ZZZZ0:JVYP35aLD0ZZZZ096AT@2:RXX0F5QH
04i>CP1MGEd0LW9b065QH@1>CTh0EUIF03Lg=`1BDU80V9RH071`L01OGel0DU9B08F5Q@2i^KT0RXZ:
06UYJ@2>SXh0ZJVY0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0];Bd0Lg=c05ADE01ADE40FUYJ
04Y:BP1@D500DE5A05QHF00`<3009RHV02h^;P0f=SH0W9bL0=CDe03@d=00];Bd07YjNP1gMgL0IFEU
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX03Lg=`1BDU80@d=303Lg=`1`L700JFUY
04=3@`0o?cl0OGem059BDP13@d<0;Rh^0080:BTY00@0;Bd]02/[:`0Y:BT0:2PX0P0Y:BT03@0/;2`0
A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`33`l<0[jn_0820P01;Bd/00P1ADE400`1IFET0
NWYj06m_K`0204i>CP1403/k>`0f=SH0GemO08J6QP2MWId0Xj>S0<G5a@2o_kl0VIVI0=KFeP3=cLd0
aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0<G5a@3<c<`0SHf=04A4A01GEeL0Ng]k08R8R02VYZH0
/K6a0:>SX`28R8P0O7al07IfMP0j>SX0;bl_069RHP2<S8`0DU9B06m_K`2l_;`0Xj>S0=[JfP1DE5@0
ADE50;>c/`15ADD0@41005eMG@15ADD0=cLg03Ph>00o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800
Fe]K05MGE`1lO7`0>CTi02`/;00b<S80Cdm?05UIF@2LW9`0CTi>028R8P0U9BD202d];@0X09^KV`1g
MgL0GEeM0;Vi^@30`<00X:2P06QXJ01NGUh0/;2`04M7A`1gMgL0>c/k02LW9`0o?cl0IfMW0;2`/01J
FUX0EeMG05eMG@30`<00a<C408N7Q`1JFUX0QhN70:JVYP2OWil0WIfM0:BTY02^[Zh0Lg=c06i^KP31
`L40c/k>09:BTP1cLg<0C4a<03Lg=`0d=3@0>CTi04I6AQ7ooooo000?ooooo`0n07UiN@1cLg<0Q8B4
06EUI@2ATI40?3`l04a<C01OGel08R8R07UiN@10@400NGUi04e=C@0[:b/0CDe=05=CD`16ATH0820P
04Q8B017AdL071`L02XZ:P0l?3`05aLG03Lg=`0^;Rh0Cdm?02l_;`1QHF40R8R8055AD@0V9RH0;bl_
02`/;01JFUX0;2`/03`l?00F5QH0=CDe09VIV@1FEUH0@41004i>CP0j>SX0IFEU03Xj>P19BDT0EeMG
04U9B@0[:b/0EUIF07=cL`1KFe/0;2`/04=3@`0U9BD06QXJ02LW9`1IFET0BTY:051@D024Q8@203hn
?P33065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0BTY:020P800];Bd0GemO05UIF@0c<c<0
WinO059BDP0b<S80Xj>S08>3P`1?Cdl0TI6A07UiN@0m?Cd0BTY:08Z:RP1@D5006QXJ04A4A022PX80
Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0GUiN05IFEP0f=SH0QHF50492@P17AdL0@D5101PH601DE5@0
P820071`L01>CTh09RHV05eMG@2:RXX0@T9207IfMP0Q8B409RHV03dm?@1RHV80F5QH05mOG`0[:b/0
G5aL06UYJ@1XJ6P0Jf][02l_;`26QXH0AdM706QXJ01VIVH0?clo08b<S01:BTX09BDU05ADE027QhL0
HV9R03De=@1BDU8092@T06=SH`24Q8@0KVi^04M7A`1gMgL0Fe]K04A4A020P800=CDe059BDP1YJFT0
CTi>06][J`1`L700E5AD075aL@2IVIT0T92@08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P079bLP1lO7`0a<C407YjNP1TI6@0[Zj^0;Ng]`15ADD0NWYj08J6QP0m?Cd0L71`051@D00^;Rh0
N7Qh06m_K`1OGel0TY:B05IFEP1[Jf/0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0F5QH04e=C@2ATI40
:b/[05MGE`10@40061PH03hn?P38b<P0CDe=04E5A@1]KFd0LW9b05IFEP1[Jf/0DE5A08^;R`1gMgL0
=SHf04=3@`1NGUh0HF5Q06YZJP0/;2`0D51@0:VYZ@2DU9@0FEUI09NGU`2;Rh/0DU9B02@T901:BTX0
S8b<05YJFP10@400Kfm_07MgM`1HF5P0^KVi0:^[Z`1BDU80RXZ:06=SH`1_Kfl0DE5A06MWI`1JFUX0
EEEE07YjNP1CDe<0Lg=c07QhN00b<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04Y:BP2WYjL0
T92@0080Fe]K01d0MgMg06IVIP16ATH0MgMg07alO00n?Sh0Ogmo07EeM@1DE5@0Z:RX0:VYZ@1/K6`0
WinO05eMG@1CDe<0Q8B408R8R01EEED0<c<c03@d=01kNg/0RHV9071`L018B4P0LW9b071`L00n?Sh0
Bd];034a<@0Looooo`0;09BDU02i^KT0WinO09fMW@1EEED0IFEU0;Ng]`2b/[80U9BD05]KF`0I6AT0
0P0E5AD0>@0C4a<05ADE01XJ6P0[:b/0=cLg059BDP1hN7P0RHV90:NWY`2k^k/0dM7A07alO026QXH0
MgMg06QXJ02b/[80[Jf]06][J`1>CTh0A4A403<c<`1KFe/0U9BD05]KF`0/;2`08b<S020P800W9bL0
?clo05QHF01OGel0A4A402DU9@0R8R808B4Q02`/;01QHF40K6a/06EUI@1]KFd0>c/k034a<@0];Bd0
>CTi07alO01YJFT0<S8b02`/;00^;Rh0?Shn01PH600Y:BT0:RXZ038b<P0c<c<0HV9R02HV9P0501DE
5@1701dM7@1FEUH0;bl_03lo?`1ZJVX0VYZJ0=;BdP3GemL0V9RH06UYJ@0o?cl0@D5103lo?`17AdL0
EEEE079bLP1RHV80:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c0<;2`P2RXZ80WIfM05QHF00o?cl0
Kfm_0:6QX@2OWil0_Kfm07IfMP1;Bd/0EeMG02XZ:P1ADE40J6QX055AD@0m?Cd0Cdm?02@T900W9bL0
Bd];06QXJ00T92@0?Shn0861P@3<c<`0`l?309bLW02IVIT0O7al05=CD`2GUiL0I6AT04M7A`1JFUX0
Jf][04=3@`0U9BD0820P024Q8@0U9BD0:RXZ038b<P1@D500X:2P051@D01HF5P00P0l?3`01@1]KFd0
H61P0410@00[:b/0;Bd]0080:BTY03L092@T020P800T92@08B4Q02PX:012@T80Fe]K06EUI@1WIfL0
WIfM0<G5a@2f][H0UYJF0;Bd]033`l<0`<300=OGe`2XZ:P0QhN709:BTP26QXH0@D5104U9B@1;Bd/0
BTY:04m?C`1:BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0ZZZZ0:>SX`3AdM40bLW90;jn_P2a/K40
PX:20820P02>SXh0ZZZZ0=_Kf`2CTi<0R8R804Y:BP0h>3P0>c/k04A4A00m?Cd0IfMW09ZJVP2OWil0
YJFU0080_kno0280^k^k0<c<c01VIVH0E5AD08b<S03Bd]80f=SH0<S8b02k^k/0S8b<0;Zj^P12@T80
?3`l04M7A`1@D500<30`03@d=00g=cL0>c/k03hn?P0h>3P09BDU02PX:01LG5`0De=C04Y:BP1iNGT0
;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l0P0U9BD0:P0X:2P0;bl_0:FUY@1?Cdl0A4A40820P01R
HV80Y:BT07=cL`1HF5P0ZZZZ0861P@0_;bl0;2`/04m?C`2ATI40`l?30;:b/P2_[jl0YZJV0<30`036
a/H0TI6A0<K6aP2HV9P0IfMW07emO@2RXZ80Vi^K09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1O
Gel0ADE505]KF`1UIFD0FUYJ05ADE17ooooo000?ooooo`3o09JFUP1lO7`0M7Ad0492@P1TI6@0=SHf
05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K6`0P8200?clo05]KF`1<C4`03Ph>03<c<`19BDT05ADE
01hN7P17AdL0410@02DU9@0/;2`0EEEE02TY:@0e=CD0EUIF06=SH`0_;bl0<S8b03<c<`1DE5@0;2`/
04e=C@0U9BD0:2PX06MWI`12@T80=CDe061PH01dM7@0R8R802/[:`0n?Sh0Ng]k06i^KP0i>CT0<c<c
04];B`1IFET0:RXZ075aL@1XJ6P0;Rh^034a<@1GEeL05QHF038b<P1fMWH0H61P05ADE018B4P04A4A
05EEE@2=SHd0A4A405=CD`0j>SX061PH05aLG00[:b/0=CDe06YZJP0/;2`09RHV09bLW020P800CTi>
09bLW01bLW80:2PX05QHF01lO7`0F5QH04E5A@2FUYH0GUiN01/K6`0[:b/0M7Ad04E5A@2HV9P0d=3@
06IVIP0[:b/0QXJ605MGE`1hN7P0?Cdm06e]K@0j>SX0IfMW06a/K00j>SX0ATI606IVIP0n?Sh0Cdm?
05YJFP1DE5@0IFEU02l_;`1fMWH0JFUY03De=@14A4@0CTi>02h^;P2>SXh0D51@05aLG01FEUH0AdM7
07emO@0m?Cd0MgMg05IFEP1DE5@0OGem04];B`2g]kL0Cdm?03hn?P19BDT0MWIf06=SH`1JFUX0LW9b
03dm?@1^KVh0OGem03Xj>P1QHF40U9BD07moO`16ATH0R8R80410@01bLW80Vi^K06=SH`1_Kfl0HF5Q
061PH020P800W9bL096AT@24Q8@0EEEE04A4A028R8P0^KVi07moO`0h>3P0OGem04i>CP1YJFT0A4A4
09FEU@1XJ6P0EUIF06MWI`2d];@0<c<c055AD@1^KVh0>c/k05=CD`0k>c/0?Cdm08F5Q@1YJFT0GUiN
09RHV00f=SH0DU9B03hn?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin0492@P1ADE40<S8b
01XJ6P0c<c<0bLW903dm?@1CDe<0QhN706MWI`1:BTX0IFEU05EEE@1oOgl0GemO03Ph>015ADD0Hf=S
051@D01eMGD0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0Cdm?07]kN`1YJFT0?clo
06UYJ@1kNg/0CDe=0;Fe]@2KVi/0JVYZ08J6QP1HF5P0KFe]04U9B@15ADD0OGem09BDU023Ph<0EUIF
075aL@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ000S075aL@0X:2P0Jf][07QhN01FEUH0
HF5Q08N7Q`1LG5`08R8R03<c<`1>CTh0=3@d08R8R01XJ6P0:RXZ05QHF021PH40@D5109RHV01oOgl0
@41004];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08V9R@1NGUh0>3Ph07MgM`0`<300
7?ooool04@18B4P0NGUi071`L02DU9@0MGEe069RHP22PX80Z:RX09:BTP2TY:@0@D51020P800T92@0
7AdM01hN7P0M7Ad092@T00809RHV02`0:2PX03De=@2ATI40];Bd0;Jf]P27QhL0Lg=c06QXJ01CDe<0
];Bd0;Rh^01[Jf/0CTi>04a<C00l?3`0<30`0492@P1lO7`0IVIV02PX:00Q8B409BDU03dm?@1@D500
DU9B05aLG00b<S809bLW02DU9@0O7al08R8R06m_K`2QXJ40/k>c075aL@0];Bd0:BTY03lo?`21PH40
FEUI03Hf=P0W9bL0<S8b03Hf=P806QXJ00D05ADE01PH600V9RH0DU9B02@T900301DE5@805aLG00d0
6ATI07QhN01PH600:2PX01lO7`0];Bd0VYZJ0<30`02OWil0KFe]03/k>`0h>3P0<S8b0080>SXj09D0
@41005=CD`0j>SX0?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1GEeL0CDe=04M7A`1BDU80
RHV906EUI@2TY:@0^KVi09^KV`1EEED0ATI602PX:01iNGT0EUIF03Lg=`0h>3P0?clo020P800U9BD0
MWIf096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306e]K@1BDU80C4a<04Q8B01;Bd/0
Kfm_051@D00`<3009bLW02@T900W9bL0;Bd]03@d=01`L700@T9204Q8B013@d<0=SHf04Y:BP1QHF40
@d=302`/;00];Bd0;2`/02LW9`0U9BD092@T02LW9`0];Bd0@D5104a<C01BDU80Kfm_0:f][@2JVYX0
O7al09ZJVP2PX:00[jn_0;6a/@2GUiL0dm?C0<W9b@2ATI40OWin06IVIP1kNg/0GEeM03/k>`1=CDd0
BDU905IFEP1gMgL0IVIV07AdM01OGel0JVYZ0:JVYP2ZZZX0_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0
][Jf06e]K@1FEUH0/k>c09>CT`1RHV80DU9B04];B`12@T80AdM703/k>`15ADD0LG5a0::RXP1oOgl0
NWYj04Y:BP1WIfL0`l?307YjNP2b/[80b<S80<g=c@2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80
?Shn03/k>`0_;bl0;Bd]034a<@0e=CD0;Bd]0451@@0m?Cd0<S8b07]kN`1DE5@0D51@06m_K`0202/[
:`0a03<c<`1CDe<0Lg=c0=;BdP1IFET08B4Q02<S8`0Y:BT0;Rh^09bLW011@D40?Shn07]kN`1EEED0
Vi^K08j>SP2MWId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ06YZJP3;bl/0b/[:0<o?c`2f][H0
/;2`0:VYZ@2GUiL0U9BD08f=S@2NWYh0^KVi0;Fe]@34a<@0^k^k09FEU@1RHV80I6AT07IfMP0n?Sh0
:RXZ02PX:013@d<0Zj^[0:>SX`0Aooooo`003oooool02035aLD0Ti>C08B4Q01XJ6P0MGEe024Q8@0m
?Cd0DU9B0P0_;bl0SP0G5aL0@D5104A4A00M7Ad08b<S03Hf=P1MGEd0;Bd]03dm?@1JFUX00`<300X:
2P1EEED0=3@d02@T900>3Ph0CDe=05aLG01]KFd0Ng]k0820P00<30`08b<S05=CD`0l?3`04a<C061P
H015ADD0;bl_071`L00W9bL0820P03Ti>@2ATI40[:b/01@D500J6QX0@D5107=cL`1ADE40=CDe05=C
D`0a<C404Q8B04e=C@1SHf<0<S8b03Xj>P1BDU80;Bd]02TY:@1HF5P0EeMG05]KF`1WIfL05QHF02TY
:@1OGel0?Cdm061PH016ATH06ATI05aLG00n?Sh0ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]
K@2CTi<0?Cdm05=CD`1NGUh0=cLg03lo?`2=SHd0UIFE05aLG00g=cL0DU9B02@T901CDe<0X:2P08V9
R@0c<c<0N7Qh030`<01JFUX0BTY:059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9205mO
G`1EEED0S8b<0451@@25QHD0LG5a03hn?P1UIFD0OWin059BDP1mOGd0BDU905YJFP1aLG40Cdm?079b
LP0a<C40MgMg06=SH`1?Cdl0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0EUIF038b
<P1LG5`0Y:BT075aL@11@D40BTY:07YjNP11@D40Ogmo02l_;`1ADE4207=cL`1P07YjNP1[Jf/0@410
051@D022PX80QXJ6071`L01jNWX0JVYZ08:2PP3>c/h0Q8B404=3@`1RHV80CTi>07inOP13@d<0YZJV
07alO01OGel0PX:20<k>cP1ADE40GemO08V9R@0o?cl0B4Q8065QH@0];Bd0O7al07UiN@1KFe/0SXj>
06IVIP1GEeL0BDU902HV9P1hN7P0NWYj09BDU01_Kfl0<S8b0451@@25QHD0CDe=05ADE013@d<0:2PX
034a<@3=cLd0DE5A04];B`2>SXh0LG5a03Ph>01EEED0Ng]k08R8R01oOgl0?Cdm03hn?P1QHF40CTi>
09BDU00l?3`0D51@0:FUY@20P800EEEE0:^[Z`2NWYh0ATI6038b<P1:BTX0QhN704M7A`1MGEd0R8R8
07]kN`18B4P0/[:b08F5Q@1KFe/0LW9b051@D01kNg/0GemO020P8010@400BDU905IFEP11@D40PX:2
071`L00Y:BT0820P0P1EEED09P0Q8B40FUYJ07]kN`1LG5`0>c/k0820P01>CTh0>CTi05eMG@1mOGd0
MGEe02h^;P0`<300CTi>02<S8`26QXH0MGEe04I6AP1UIFD0U9BD02l_;`1bLW80HV9R06ATI01fMWH0
NGUi034a<@0W9bL0@d=307emO@1TI6@0BTY:02`/;01bLW80=SHf038b<P1OGel0<30`7?ooool0;`0m
?Cd0?3`l07inOP1EEED0KFe]06=SH`2EUID0bLW90<S8b02SXj<0WIfM071`L01IFET0C4a<04=3@`0g
=cL0=SHf038b<P0Y:BT0<S8b06UYJ@37alL0XZ:R09VIV@2RXZ80CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`1;Bd/0?3`l02HV9P0g=cL0UiNG07UiN@1=CDd0;bl_03dm?@1;Bd/0D51@06UYJ@0o
?cl092@T00808b<S01009BDU03hn?P1aLG40UiNG0;Ng]`2[Zj/0Ogmo09jNWP2WYjL0JVYZ05mOG`18
B4P0EUIF059BDP0I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF00<05ADE01H05QHF04E5
A@2GUiL0UIFE04Y:BP0V9RH0De=C07moO`1gMgL0MWIf04Q8B012@T80@d=304A4A00o?cl0?3`l04=3
@`1PH600A4A403dm?@18B4P0YjNW0P21PH40:P2?Shl0G5aL0492@P0j>SX0>3Ph09jNWP1XJ6P0AdM7
04U9B@1^KVh0Lg=c08b<S01OGel08R8R06IVIP2a/K40QhN707AdM01nOWh0<S8b024Q8@0j>SX0WinO
05QHF01LG5`0KFe]0:NWY`2`/;00^KVi0;jn_P1DE5@0<30`059BDP17AdL0@T9203Ph>00g=cL0GUiN
06=SH`0e=CD09BDU02<S8`80:BTY00D0EeMG04i>CP10@400JVYZ05YJFP0207YjNP0B0492@P0/;2`0
:2PX02`/;00Z:RX0:2PX02HV9P0/;2`0;Rh^04M7A`1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40
[:b/0P1MGEd03`3Cdm<0e]KF0;^k^`2f][H0?clo02HV9P1NGUh0>3Ph01lO7`0R8R80<30`05EEE@2A
TI40RXZ:08j>SP0209^KV`0K0:n_[`2d];@0UIFE04e=C@1NGUh0PX:2096AT@2HV9P0WYjN04U9B@0l
?3`0WinO0<;2`P1hN7P0De=C051@D01FEUH0CDe=04U9B@0l?3`0OGem0<S8b02d];@0ATI603Hf=P1E
EED0/K6a0080_kno03@0b<S80;fm_@2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y:BT0<30`02/[:`0i
>CT0;Rh^02d];@0e=CD0?3`l03Xj>P1QHF40EEEE09VIV@1KFe/0EeMG05mOG`0X:2P0=SHf07AdM02k
^k/0fMWI0=?Cd`2i^KT0?3`l01lO7`0W9bL0>SXj0:>SX`0h>3P0@D5107EeM@1ADE40Lg=c0;Bd]01Y
JFT0UiNG0;6a/@1VIVH0DU9B04a<C00o?cl0A4A405QHF02WYjL0ZJVY0P2i^KT0502WYjL0Shn?04U9
B@0b<S80<C4a0410@029RHT0`<300;^k^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0^;Rh0<c<c02PX
:01iNGT0@T924Oooool000oooooo0<00[jn_0=3@d02KVi/0FUYJ09nOW`16ATH0>SXj065QH@0g=cL0
F5QH04U9B@1ADE40IVIV02/[:`1@D500?Shn04a<C00/;2`0:BTY04Q8B00W9bL05QHF04Q8B00O7al0
=cLg02DU9@1:BTX0I6AT05IFEP20P800QHF504M7A`0R8R80>3Ph055AD@0j>SX0GEeM038b<P0Q8B40
QhN706EUI@0L71`0<S8b03Ti>@1_Kfl0HF5Q02`/;018B4P0G5aL03Xj>P0f=SH0I6AT06EUI@0];Bd0
Bd];03Lg=`0Y:BT0?3`l05ADE01RHV80=SHf06e]K@1@D500?3`l07moO`0Y:BT0>SXj06UYJ@0f=SH0
>c/k05mOG`0/;2`0CDe=02LW9`0];Bd0EUIF06EUI@0h>3P0N7Qh05iNGP0e=CD0BTY:09NGU`0m?Cd0
GUiN07=cL`17AdL0@d=307MgM`1FEUH0>c/k04E5A@23Ph<0DU9B09fMW@2l_;`0PX:202TY:@21PH40
Hf=S05iNGP0l?3`0Lg=c04Y:BP1BDU80I6AT04i>CP1=CDd0I6AT07IfMP1=CDd0@D5104Y:BP25QHD0
BTY:075aL@15ADD0<C4a03lo?`1BDU80A4A408:2PP1RHV80KFe]08J6QP1ADE40P82004I6AP1_Kfl0
Q8B404m?C`1oOgl0CDe=0<30`01fMWH0CTi>059BDP1YJFT0L71`04a<C022PX80<C4a051@D02a/K40
Vi^K05mOG`1BDU80VIVI03`l?02<S8`0CDe=05UIF@1^KVh0ATI6079bLP2=SHd0Fe]K059BDP2@T900
O7al08N7Q`28R8P0Q8B40;Zj^P3>c/h0UIFE05=CD`1UIFD0QhN708n?S`0o?cl0WYjN06][J`1;Bd/0
V9RH0<c<c01hN7P0EUIF08:2PP18B4P0IfMW06m_K`0c<c<0Ng]k06m_K`1SHf<0Xj>S079bLP1IFET0
EeMG03De=@2>SXh209>CT`0A08b<S018B4P0AdM708N7Q`1LG5`0JFUY04M7A`0V9RH0;2`/0::RXP1`
L700ATI607moO`1nOWh0E5AD03Ti>@1QHF400P1XJ6P0C@0n?Sh0A4A407QhN014A4@0Ng]k03`l?019
BDT0U9BD08>3P`1>CTh0JVYZ061PH01<C4`0=3@d055AD@2EUID0FEUI038b<P1RHV80GemO03De=@2E
UID0YJFU05UIF@1YJFT0BDU905]KF`1HF5P0Fe]K05EEE@1MGEd0IfMW03`l?01MGEd0Rh^;04E5A@0R
8R80HF5Q07EeM@1=CDd0F5QH051@D01/K6`0BDU908B4Q01hN7P0Cdm?04e=C@1dM7@0JFUY02h^;P1?
Cdl0H61P038b<P1ZJVX0E5AD0410@01YJFT0YJFU06=SH`22PX80I6AT05iNGP22PX80NGUi04E5A@0Z
:RX0@D5105QHF01DE5@0BDU9034a<@1mOGd0Lg=c03`l?01CDe<0:2PX01cooooo04H0>SXj038b<P0i
>CT0UiNG09bLW024Q8@0]KFe0:b/[02VYZH0UiNG09fMW@3<c<`0c/k>0:n_[`1jNWX0CTi>04I6AP11
@D40De=C051@D01dM7@0RXZ:0:j^[P1XJ6P0F5QH06QXJ02>SXh0LW9b02l_;`0M7Ad0;Bd]0451@@1R
HV80>3Ph01dM7@0U9BD0820P02/[:`2;Rh/0Y:BT06][J`0];Bd0>c/k04E5A@19BDT0De=C02`/;00K
6a/0:RXZ04];B`1fMWH0WinO0:2PX02][Jd0TI6A075aL@1^KVh0RXZ:08R8R01WIfL0DU9B03hn?P0_
;bl0>CTi03Hf=P0];Bd05ADE01/K6`10@400FUYJ0P0G5aL03@0I6AT061PH024Q8@0X:2P07alO020P
800d=3@0Jf][08J6QP2IVIT0Z:RX06i^KP0U9BD01@0M7Ad0400Q8B40:b/[05=CD`1[Jf/0TI6A07Qh
N01kNg/0=cLg02LW9`0Z:RX0Jf][0410@00b<S80<30`04e=C@2BTY8203Hf=P0:0451@@1FEUH0KVi^
05EEE@2ATI40[Zj^07EeM@1YJFT0M7Ad08B4Q080HF5Q03X0QXJ609BDU01NGUh0AdM705UIF@1^KVh0
GEeM08F5Q@2>SXh0@T9202`/;00X:2P0@410051@D00k>c/0=cLg03De=@0l?3`0DU9B05IFEP0b<S80
:b/[03`l?01dM7@0W9bL08n?S`2h^;P0T92@0820P02FUYH0Lg=c055AD@0l?3`0;Bd]02l_;`0[:b/0
;Rh^03Xj>P19BDT0F5QH06e]K@1nOWh0LG5a07=cL`27QhL0R8R80:^[Z`2h^;P0UYJF08N7Q`3Ogml0
_kno07QhN00e=CD07alO024Q8@1GEeL0>3Ph0`0M7Ad0G`1ADE40LW9b05QHF028R8P0HF5Q05eMG@2B
TY80SHf=092@T00f=SH0:b/[03`l?019BDT0GUiN069RHP1XJ6P0EUIF08f=S@1fMWH0:BTY02LW9`0[
:b/0=cLg05MGE`1oOgl0NGUi08J6QP2a/K40/k>c07inOP2/[:`0/;2`0;^k^`3;bl/0a/K60;>c/`1L
G5`0AdM705aLG01CDe<0BTY:04Q8B024Q8@0FEUI02HV9P0W9bL0>SXj03Lg=`0/;2`0;bl_03De=@0n
?Sh0LG5a09fMW@2BTY80N7Qh0:>SX`2LW9`0YjNW0:b/[02UYJD0YZJV06m_K`1@D500GEeM08n?S`24
Q8@0NGUi0;6a/@2PX:00MgMg079bLP25QHD0DE5A06MWI`2MWId0EeMG09bLW01CDe<0=CDe03@d=00]
;Bd0<S8b03Hf=P1LG5`0Ng]k08^;R`1dM7@0LW9b07]kN`10@400:b/[02TY:@0[:b/0<c<c0080Ph>3
00`0JVYZ05QHF018B4P0=3@d04U9B@16ATH0A4A404i>CP1FEUH0JFUY0451@@0e=CDAooooo`003ooo
ool0>02_[jl0`/;207emO@0g=cL0HV9R03/k>`0n?Sh0?clo01lO7`0e=CD0?Cdm03lo?`0i>CT05ADE
04=3@`0l?3`0B4Q800d=3@0?3`l0A4A402d];@0F5QH0Cdm?014A4@0Q8B40:b/[04i>CP0f=SH071`L
03dm?@1RHV80D51@02@T900j>SX0<S8b034a<@1QHF40<30`01DE5@1MGEd0?Shn00h>3P0e=CD07QhN
06e]K@26QXH06QXJ04=3@`1JFUX0GEeM038b<P16ATH0IVIV01hN7P1GEeL0Hf=S0P0n?Sh0:P13@d<0
:b/[01LG5`1FEUH0IfMW02TY:@1WIfL05aLG02DU9@1WIfL0Cdm?03`l?018B4P05QHF061PH010@400
=cLg06IVIP0k>c/07AdM05QHF02;Rh/0IVIV03hn?P2PX:00:2PX03hn?P1ADE40EUIF04=3@`1aLG40
D51@03/k>`0d=3@0Ogmo05IFEP2?Shl0][Jf08f=S@0h>3P0M7Ad06IVIP80De=C0;`0N7Qh06ATI01?
Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0HF5Q04M7A`1mOGd0Hf=S06EUI@1/K6`0CTi>04M7A`1?
Cdl0D51@08>3P`1hN7P0LW9b0:ZZZP1PH600SHf=06MWI`1KFe/0LG5a04e=C@1fMWH0Bd];0:VYZ@2;
Rh/0@41004=3@`1RHV80DU9B04E5A@1lO7`0@T9205ADE02h^;P0X:2P06ATI01CDe<0NWYj04];B`2k
^k/0JVYZ04=3@`1kNg/0?Cdm096AT@2QXJ40HV9R04Y:BP26QXH0AdM7092@T02:RXX0H61P08V9R@39
bLT0WYjN03hn?P1ZJVX0VIVI06m_K`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf0820P00f
=SH0<c<c03dm?@0i>CT0V9RH06EUI@0n?Sh0KVi^05ADE01eMGD0EEEE02<S8`1aLG40DU9B07QhN02X
Z:P0GEeM04I6AP1^KVh0GemO05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0Ng]k06a/K013
@d<0X:2P075aL@2?Shl0AdM703@d=01cLg<0D51@08J6QP1MGEd0@D5109>CT`2JVYX0LW9b07alO01c
Lg<0FEUI03Ph>00o?cl0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1aLG40WYjN07emO@1T
I6@0GEeM05UIF@1TI6@0SXj>08R8R01SHf<0E5AD08Z:RP1ADE40?clo09NGU`25QHD0Cdm?06UYJ@1A
DE40MgMg02TY:@1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0A4A405iNGP0o?cl0L71`069RHP0V
9RH0@D5108J6QP0Z:RX0MGEe0::RXP1PH600KFe]07=cL`0I6AT0820P04Y:BP1KFe/0LG5a06a/K00^
;Rh0MWIf04Y:BP0c<c<0SXj>03/k>acooooo05L0>3Ph0492@P20P800[:b/0:6QX@2PX:00Y:BT0:2P
X02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1BDU80OWin08b<S02@T900SXj>0<71`@3AdM40KFe]08B4
Q02ATI40EEEE0:j^[P2DU9@0?clo079bLP0e=CD08B4Q02DU9@0G5aL0Cdm?01`L700J6QX05QHF01PH
600`<300SHf=0=7Ad@1oOgl0BDU904i>CP1KFe/0HV9R075aL@1_Kfl0PX:206m_K`1hN7P0R8R80<K6
aP2^[Zh0GemO03Ti>@0h>3P0=SHf04i>CP1QHF40SHf=06][J`17AdL0<C4a03hn?P12@T80?3`l055A
D@1QHF40V9RH06IVIP1dM7@0HF5Q06EUI@2=SHd0AdM704E5A@12@T80ADE505QHF01^KVh0VIVI0<k>
cP2h^;P0Ng]k02/[:`0M7Ad0100L71`0400M7Ad092@T04U9B@1`L700Ph>303lo?`0Z:RX092@T02h^
;P2/[:`0]KFe059BDP18B4P0QhN70;no_`2;Rh/207alO00E079bLP1/K6`0I6AT08f=S@36a/H0DU9B
05YJFP1LG5`09bLW02DU9@0W9bL0FEUI07IfMP1/K6`08R8R02d];@1<C4`0GEeM06IVIP2e]KD0IfMW
00809bLW00@09BDU03Hf=P1CDe<0=cLg0P0d=3@0=P0[:b/0BDU908n?S`1eMGD0S8b<08>3P`28R8P0
XJ6Q0<W9b@2HV9P0K6a/07AdM01ADE40GEeM07UiN@2:RXX0O7al05=CD`13@d<0?3`l05aLG02>SXh0
@d=303hn?P11@D40ADE505mOG`20P800^KVi0;:b/P2UYJD0Vi^K0=KFeP33`l<0<C4a01hN7P0M7Ad0
7alO05UIF@0l?3`07AdM01`L700N7Qh0Kfm_03dm?@0j>SX0UiNG0:NWY`2JVYX0IVIV071`L03=cLd0
MWIf05IFEP80D51@0380E5AD061PH021PH40c<c<09nOW`1PH600:RXZ02LW9`0k>c/0I6AT05EEE@1^
KVh0De=C07AdM02CTi<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0X:2P0=3@d04E5A@1@
D500EEEE03dm?@1ADE40/[:b04M7A`0S8b<0;Bd]0492@P0m?Cd0@D5104];B`1fMWH0_kno0<c<c03L
g=`0emOG0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`80DU9B02`0FUYJ08^;R`3Bd]80P82003Ph
>018B4P0^k^k0:b/[02g]kL0Ph>309jNWP36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e=CD0A4A409RH
V033`l<0WinO07QhN00k>c/0>CTi05ADE00[:b/09bLW02HV9P0e=CD0R8R806e]K@0k>c/0?clo05AD
E00i>CT0D51@04E5A@17AdL0K6a/08>3P`0e=CD0?clo02l_;a7ooooo000?ooooo`1D0<S8b02ZZZX0
L71`059BDP27QhL0:BTY030`<01?Cdl0?clo03Ph>00N7Qh09bLW05iNGP0];Bd0<c<c028R8P0l?3`0
820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV02LW9`0E5AD0?clo05eMG@1@D500K6a/07MgM`0_;bl0
61PH04U9B@0b<S805aLG05MGE`1<C4`07QhN07]kN`13@d<0410@04];B`0N7Qh0@D510:j^[P15ADD0
@D5105MGE`1WIfL0>c/k04A4A01VIVH0:BTY03Ti>@17AdL0>SXj03@d=00k>c/0I6AT02@T901NGUh0
M7Ad02<S8`27QhL0>c/k02l_;`22PX80JFUY03Hf=P1<C4`0;Rh^05=CD`13@d<0?Shn06=SH`1@D500
;bl_03Xj>P2LW9`0IfMW03dm?@2`/;00EEEE0P1=CDd0c01HF5P0;bl_06ATI01DE5@0Hf=S0410@02;
Rh/0J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1JFUX0MGEe05QHF01?Cdl0Jf][08V9R@1<
C4`0G5aL08J6QP1GEeL0M7Ad04A4A01kNg/0EUIF07AdM02DU9@0EeMG059BDP1DE5@0GEeM08V9R@24
Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al05EEE@23Ph<0DU9B09bLW02MWId0;bl_059BDP25
QHD0P82004m?C`1eMGD08b<S02XZ:P1VIVH0Jf][04m?C`1EEED0GEeM03@d=02FUYH0L71`03lo?`2P
X:00:RXZ05=CD`1^KVh0DE5A069RHP2OWil0IVIV09ZJVP0k>c/06a/K06e]K@3Kfm/0_kno0:FUY@2^
[Zh0alO708b<S016ATH0IVIV092@T026QXH0PH610=;BdP2>SXh0>SXj07]kN`11@D40>SXj065QH@0O
7al0HV9R08N7Q`15ADD0Ogmo0861P@1@D500JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1b
LW80O7al069RHP1MGEd0A4A403Ti>@2RXZ80ZJVY05QHF01XJ6P0TY:B05=CD`0_;bl0Jf][06EUI@24
Q8@0@d=30410@01VIVH0<S8b08>3P`1RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00l
?3`0QHF502l_;`1FEUH0O7al08>3P`18B4P0PX:20:n_[`1HF5P0RHV906a/K01GEeL0NWYj04E5A@0o
?cl0DE5A05]KF`17AdL0M7Ad09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?05QHF024
Q8@0S8b<05mOG`1PH600V9RH075aL@0c<c<0>CTi051@D00X:2P0FUYJ07YjNP1NGUh0BTY:0:^[Z`0m
?Cd0IfMW07YjNP1eMGD0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0QHF503Ph>00Y
:BT0OWin05YJFQcooooo01h0DU9B05IFEP1;Bd/0DE5A0;Jf]P2c/k<0Zj^[08n?S`2QXJ40WIfM09JF
UP2a/K40];Bd0<K6aP1<C4`07QhN01lO7`0^;Rh0GEeM0<O7a`36a/H0MgMg075aL@3:b/X0/k>c0<c<
c02l_;`0Lg=c03/k>`0W9bL201DE5@1:01@D5014A4@07AdM01`L700I6AT07AdM03Xj>P2IVIT0e]KF
0=?Cd`2k^k/0WYjN059BDP1NGUh0SHf=09BDU021PH40NWYj0861P@2e]KD0c<c<09ZJVP13@d<0=3@d
02l_;`0i>CT0HV9R02d];@1>CTh0H61P05]KF`1TI6@0@41003Hf=P1DE5@0JFUY059BDP10@400=cLg
06MWI`1@D500FEUI05YJFP1?Cdl0FUYJ05EEE@1JFUX0F5QH06EUI@2ATI40YjNW04Q8B01iNGT0X:2P
051@D00O7al071`L01TI6@0L71`0=SHf07EeM@2ATI40U9BD09jNWP12@T80De=C075aL@2/[:`0YJFU
0:6QX@2`/;00Zj^[0:FUY@2KVi/204=3@`1O05IFEP1YJFT0RHV908N7Q`2i^KT0`/;2096AT@1ZJVX0
=cLg02h^;P0Q8B407alO05eMG@1dM7@0CDe=034a<@0/;2`0=CDe08N7Q`2][Jd0`L7108>3P`0h>3P0
9BDU02HV9P0Y:BT0BDU905=CD`0b<S80=cLg02`/;00a<C40UIFE0;Zj^P2IVIT0N7Qh05QHF01YJFT0
bLW90::RXP11@D40ADE50:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/08V9R@0U9BD0
9bLW03Xj>P1jNWX0YjNW0<K6aP2NWYh0^k^k09JFUP1PH600_;bl0;6a/@0g=cL07AdM01`L700N7Qh0
K6a/05EEE@0O7al07QhN03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JFUP1dM7@0NGUi0=cLg03<c<`0
`L710<;2`P3@d=00e=CD0=3@d03Bd]80h>3P0;jn_P1UIFD0BDU904a<C01>CTh00P1<C4`0C@1jNWX0
DE5A038b<P14A4@0B4Q804A4A01UIFD0Y:BT0<c<c02PX:00TY:B06][J`0_;bl0=SHf0451@@2:RXX0
QHF507alO01PH600PH610:6QX@1@D500:BTY0492@P2RXZ80VYZJ09^KV`2h^;P0/;2`0=_Kf`2[Zj/0
OGem0;Jf]P2a/K40ATI602h^;P0h>3P0EUIF07UiN@1YJFT0FUYJ04i>CP2?Shl0bLW903lo?`0h>3P0
D51@0=7Ad@3<c<`0_[jn0<30`03:b/X0e=CD0;Bd]01`L700H61P06YZJP2:RXX0VYZJ0;no_`2a/K40
Rh^;09JFUP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P0X:2P0=CDe07YjNP1OGel0;Rh^034a<@1?Cdl0
ATI60080C4a<00H0B4Q806ATI01gMgL0<C4a05IFEP0n?ShAooooo`003oooool0[@22PX80YJFU07Yj
NP1=CDd0Ti>C061PH00b<S80EeMG051@D00b<S80AdM702/[:`1_Kfl0<c<c03`l?00P8200@D5101dM
7@0I6AT06a/K01LG5`0C4a<0ATI6030`<00/;2`0:2PX0451@@1<C4`0Bd];06e]K@1XJ6P0>SXj01TI
6@15ADD0:BTY038b<P1LG5`0BTY:01/K6`1_Kfl0@d=3024Q8@1<C4`0E5AD02`/;02EUID0DU9B05IF
EP1ADE40Hf=S03/k>`12@T80IVIV03Ti>@0f=SH0>CTi03@d=00_;bl0?Cdm06YZJP0];Bd0EUIF075a
L@0X:2P0P82003hn?P0^;Rh0Ogmo079bLP0d=3@0C4a<04A4A01BDU80=cLg04I6AP1gMgL0KVi^04a<
C00h>3P0WinO03Ti>@0f=SH0ZJVY05aLG01<C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0@T9207Mg
M`1?Cdl0MWIf0:b/[02h^;P0HV9R061PH016ATH0BTY:065QH@1iNGT0>c/k05mOG`1jNWX0Ng]k04];
B`1iNGT0GEeM02DU9@1PH600C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP0k>c/0H61P03lo
?`1>CTh0M7Ad030`<01EEED0=cLg04a<C022PX80?Cdm04U9B@0/;2`0P82009BDU019BDT0>CTi05QH
F01ZJVX0>c/k09NGU`1eMGD0>c/k09fMW@1LG5`0?Cdm04m?C`1oOgl0C4a<08R8R013@d<0:b/[07mo
O`1BDU80LW9b07]kN`19BDT0?3`l07=cL`1VIVH0ZJVY07alO01LG5`0CDe=0:BTY02n_[h0/k>c0<W9
b@3Hf=P0^[Zj04A4A01VIVH0WIfM0080RHV90440f=SH0::RXP0k>c/0KVi^05aLG01VIVH0OGem02HV
9P1>CTh0PH6104E5A@2FUYH0Ng]k055AD@1QHF40=3@d07IfMP1jNWX0JFUY09JFUP1fMWH0=cLg08f=
S@1kNg/0Fe]K04i>CP0I6AT071`L07EeM@2:RXX0;Bd]05IFEP1eMGD0HV9R03De=@1^KVh0CTi>07]k
N`0X:2P0>SXj07QhN01DE5@0Hf=S01XJ6P0i>CT0W9bL0:2PX01LG5`0Hf=S06m_K`1[Jf/0?3`l05=C
D`2EUID0JVYZ03Xj>P1BDU80Ph>303Lg=`1lO7`0`/;206e]K@1bLW80D51@04Y:BP0206QXJ00`04i>
CP1[Jf/0G5aL03/k>`1HF5P0OGem075aL@0d=3@0OWin0861P@1:BTX0B4Q804Y:BP20P800GEeM09FE
U@2JVYX0=CDe03Lg=`1KFe/0K6a/05ADE01=CDd0I6AT04a<C01OGel0L71`05mOG`1IFET0^[Zj071`
L01mOGd0NWYj05]KF`1aLG40KVi^05QHF00K6a/0:b/[02h^;P1kNg/0<S8b02h^;P2>SXh0O7al03Xj
>P1[Jf/0D51@7?ooool0Y@1>CTh0De=C05MGE`1/K6`0Xj>S0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU
09nOW`2IVIT0W9bL07YjNP1@D500B4Q803Xj>P0U9BD0TY:B0<?3``2JVYX0[:b/0:n_[`2ZZZX0GEeM
05aLG028R8P0UIFE07=cL`0i>CT09BDU01XJ6P1IFET0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800ZZZZ0;Rh^03>c/h0a<C407EeM@18B4P0;bl_02XZ:P1@D500Z:RX09>CT`1_Kfl0>SXj
03dm?@1GEeL0Cdm?034a<@0^;Rh0?clo05YJFP1UIFD0NGUi071`L01EEED0D51@05eMG@1`L700F5QH
04U9B@1?Cdl0CTi>04U9B@1<C4`0DE5A04m?C`1FEUH0LW9b06ATI01/K6`0Rh^;055AD@0Z:RX0AdM7
07emO@1ZJVX0=cLg03`l?01KFe/0EEEE03`l?00m?Cd0De=C079bLP3<c<`0a/K609VIV@1cLg<0D51@
04I6AP23Ph<0XJ6Q0:NWY`21PH40MgMg051@D013@d<0>3Ph03dm?@1MGEd0bl_;0;no_`30`<00Jf][
02d];@0V9RH0:b/[03`l?02CTi<0WIfM075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0De=C
0492@P15ADD0BTY:04=3@`1lO7`0A4A405ADE01/K6`0GEeM0;Bd]02OWil0EeMG04e=C@19BDT0Bd];
0;fm_@3Lg=`0/K6a0:VYZ@2WYjL0ZJVY0;2`/02f][H0/k>c0:>SX`2WYjL0bl_;0>WYj@2MWId0IfMW
08R8R01mOGd0GemO0:6QX@0209fMW@0f0::RXP2LW9`0WYjN0=?Cd`3Hf=P0PH61024Q8@0P8200<S8b
0;Jf]P33`l<0Rh^;07IfMP2[Zj/0][Jf07MgM`1TI6@0E5AD06i^KP1lO7`0ATI60820P02f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3<c<`0BTY:04=3@`18B4P0ADE505mOG`2PX:00KFe]
02DU9@0N7Qh07AdM02PX:014A4@0>3Ph04U9B@2IVIT0I6AT08R8R01SHf<0OGem06i^KP1NGUh0FUYJ
0P1UIFD05`1dM7@0Ti>C0=3@d01^KVh0I6AT07alO02c/k<0XZ:R0<S8b030`<00e]KF0;jn_P1FEUH0
U9BD06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b0080:RXZ02X0Shn?0410@01RHV80
_[jn0=WIf@3EeMD0b<S80;no_`3;bl/0_;bl09ZJVP1MGEd0ATI606EUI@2@T900UiNG0<30`026QXH0
JFUY06m_K`0o?cl0;Bd]030`<00d=3@0@D5102l_;`0V9RH0<c<c071`L01EEED0:BTY02/[:`0k>c/0
KVi^04];B`1=CDd0Fe]K08>3P`2VYZH0Kfm_06EUI@24Q8@Aooooo`003oooool0o`2OWil0PX:207=c
L`1=CDd0T92@079bLP0d=3@0F5QH05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04a<C00V9RH0B4Q802DU
9@0O7al08B4Q02PX:00J6QX0@T9204i>CP0Y:BT0=cLg04=3@`1@D500BTY:06=SH`1aLG40@D51028R
8P0n?Sh09BDU03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0Hf=S03lo?`22PX80DU9B05QH
F01BDU80EUIF03dm?@10@400FEUI03Hf=P0d=3@0?Cdm020P800h>3P0IfMW07MgM`0e=CD0DE5A05YJ
FP0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`1@D5009BDU03`l?01RHV80Hf=S03Lg
=`0f=SH0YZJV03Hf=P0Q8B40PX:202l_;`17AdL0JFUY05EEE@0L71`0?Cdm04a<C01DE5@0BDU908B4
Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph02h^;P1[Jf/0A4A403@d=01=CDd0>c/k02l_
;`1MGEd0Kfm_05IFEP1>CTh0=cLg07IfMP1`L700>SXj069RHP0V9RH0@D51055AD@1@D500Fe]K06i^
KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0De=C06UYJ@1KFe/0RHV907QhN01CDe<0Bd];06i^
KP1[Jf/0ADE507]kN`1aLG40>c/k0;2`/02<S8`0GEeM04m?C`28R8P0BTY:0<O7a`1oOgl0ADE507=c
L`1=CDd0R8R80;2`/01aLG40@d=307YjNP0l?3`0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5
Q@1iNGT0S8b<0451@@1RHV80P82003Xj>P18B4P0/;2`08V9R@10@400FUYJ02l_;`11@D40EUIF024Q
8@0m?Cd0GEeM05=CD`2EUID0PH61059BDP1NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aL
G01RHV80Hf=S07YjNP1;Bd/06QXJ07MgM`2TY:@0@d=305UIF@1UIFD0A4A403Lg=`1lO7`0K6a/07in
OP0n?Sh0=CDe05UIF@0f=SH0O7al061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S03Xj
>P1fMWH0P82004U9B@1YJFT0PH6103Hf=P1?Cdl0Vi^K06e]K@2RXZ80Lg=c04Y:BP1NGUh0@D5104I6
AP1nOWh0Jf][06EUI@1MGEd0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C051@D000501`L700=CDe
05QHF01nOWh0E5AD03/k>`1SHf<0GemO01hN7P0n?Sh0GemO04];B`1PH600IFEU02@T900`<300M7Ad
05iNGP1eMGD0KFe]0P1UIFD03@2KVi/0O7al02h^;P0X:2P09bLW06EUI@1aLG40<C4a075aL@1cLg<0
=SHf07=cL`1PH6007?ooool0B@1FEUH0DE5A051@D01:BTX0I6AT0861P@2PX:00@D5103/k>`1:BTX0
MGEe09nOW`2QXJ40/[:b06=SH`0U9BD08B4Q03<c<`1<C4`0R8R80<c<c02h^;P0[Zj^0<;2`P2;Rh/0
EeMG0451@@0i>CT0?Shn04E5A@1RHV80Jf][06EUI@2ATI40ZJVY06QXJ01/K6`0_Kfm09^KV`1eMGD0
AdM703`l?01BDU80JFUY0:f][@3Cdm<0GemO03dm?@0a<C409bLW02DU9@0l?3`0QhN706UYJ@1RHV80
IFEU04M7A`1jNWX0?Shn02TY:@0W9bL08b<S05EEE@1NGUh0GemO06i^KP1@D500BDU905mOG`28R8P0
?3`l04E5A@11@D400P0o?cl0J00i>CT0>c/k03/k>`16ATH0KVi^05]KF`1UIFD0RXZ:05QHF01EEED0
8R8R02XZ:P22PX80d];B07alO00d=3@08B4Q02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU90410@027QhL0YZJV0<30`01[Jf/0EUIF06YZJP1eMGD0I6AT03De=@1BDU80YJFU0;no_`2CTi<0
R8R804i>CP0j>SX0GemO08:2PP1;Bd/0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0UIFE092@T024Q8@0
EUIF07alO02<S8`0TY:B08B4Q02SXj<0b/[:09bLW01KFe/0SXj>0<O7a`2i^KT0D51@03Xj>P0g=cL0
IVIV0<S8b02;Rh/0Lg=c0861P@1iNGT0NWYj08f=S@2FUYH0YJFU0;6a/@2[Zj/0YjNW0=CDe02d];@0
RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80d=3@0>3Ph033`l<0[jn_07moO`14A4@0
W9bL09VIV@1hN7P0FEUI0P1CDe<06@2BTY80Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0P8200;6a/@2E
UID0MWIf061PH01fMWH0JFUY06][J`1`L700V9RH0:j^[P29RHT0EeMG04I6AP12@T80DU9B09>CT`17
AdL00P0M7Ad0DP0L71`06a/K028R8P0k>c/0=CDe05iNGP1fMWH0Zj^[0;fm_@1OGel0QhN707UiN@1M
GEd0HV9R05]KF`1@D500Fe]K0=?Cd`2h^;P0Ph>30=?Cd`39bLT0aLG50=GEe@3Cdm<0[:b/07]kN`1?
Cdl0NWYj05EEE@0T92@0;2`/04i>CP13@d<07QhN02<S8`1KFe/0Ng]k03Hf=P0k>c/0Z:RX07QhN03;
bl/0b/[:0;6a/@2][Jd0[jn_09RHV02LW9`0N7Qh08B4Q01mOGd0NWYj06YZJP1<C4`0NGUi0;Ng]`2X
Z:P0>3Ph04A4A01eMGD09bLW02DU9@0/;2`0;bl_03dm?@0n?Sh0=CDe07=cL`1GEeL0820P02TY:@0f
=SH0DU9B08V9R@1kNg/0UiNG0:JVYP3EeMD0bLW909bLW02CTi<Aooooo`003oooool0;`34a<@0P820
075aL@1@D500W9bL075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo065QH@0Z:RX0GemO
04M7A`0];Bd0?Cdm0451@@0J6QX0?clo04=3@`0/;2`0?clo04=3@`1TI6@0>c/k05iNGP2FUYH0EeMG
02l_;`0e=CD0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5038b<P0e=CD0@D51038b<P28R8P0B4Q8
0080FEUI09P0ADE503lo?`1YJFT0OGem0492@P0e=CD0De=C02<S8`0N7Qh0=CDe04Y:BP0R8R80F5QH
08R8R00N7Qh0IVIV03Lg=`0W9bL0MWIf05iNGP0U9BD0<c<c02/[:`1=CDd0:BTY03<c<`1IFET0IVIV
01XJ6P0W9bL0VIVI051@D00k>c/0Zj^[02<S8`0c<c<0Cdm?04M7A`0/;2`0EUIF055AD@0g=cL0<30`
06UYJ@1MGEd0Ogmo0:VYZ@2WYjL0BTY:04=3@`1/K6`0@T92059BDP1TI6@0Bd];03lo?`1GEeL0QXJ6
05QHF01PH600Ph>3075aL@1/K6`0B4Q807alO01oOgl0>c/k07IfMP10@400ADE504e=C@1FEUH0I6AT
0820P00k>c/0OWin05]KF`1mOGd0SXj>04];B`2[Zj/0Hf=S071`L01VIVH0PX:206=SH`1?Cdl0DU9B
0:b/[02QXJ40Fe]K08^;R`14A4@0820P096AT@2?Shl0H61P04Y:BP2=SHd0AdM707QhN01VIVH0?clo
06e]K@16ATH0JVYZ08f=S@1_Kfl0@D5106a/K01]KFd0Vi^K07MgM`1cLg<0E5AD04I6AP1EEED0NWYj
0;Vi^@3Bd]80[:b/04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0RXZ:04i>CP14A4@0M7Ad
02`/;00j>SX0RHV903lo?`1oOgl0VYZJ05aLG01jNWX0=SHf06EUI@1cLg<0=CDe0820P02LW9`0E5AD
06MWI`1[Jf/0CDe=06EUI@80;bl_04L0MWIf0:>SX`1OGel0GEeM071`L00n?Sh092@T05mOG`15ADD0
KFe]02h^;P0[:b/0I6AT05ADE01JFUX0IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd0
=3@d07]kN`0e=CD0?Cdm06][J`21PH40GUiN05YJFP2d];@0?3`l05YJFP1_Kfl0ADE506ATI019BDT0
ADE506=SH`1KFe/0LG5a05mOG`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1MGEd0
MgMg08f=S@1CDe<0?Shn06][J`1JFUX08R8R034a<@12@T809BDU06UYJ@1>CTh0?clo03`l?023Ph<0
FEUI07=cL`02071`L00>07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d08J6QP2>SXh0
@d=3071`L01hN7PLooooo`1904];B`0n?Sh0=SHf03Xj>P1mOGd0>SXj05iNGP1DE5@0;bl_02HV9P0Y
:BT0AdM70:j^[P3@d=00J6QX01`L700G5aL06ATI034a<@1hN7P0c/k>0=?Cd`3;bl/0Vi^K05ADE01N
GUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d02DU9@2[Zj/0[Jf]0;:b/P1cLg<0FUYJ03dm?@0o
?cl0AdM705UIF@1kNg/0O7al0<C4a02;Rh/0CTi>03<c<`0/;2`09RHV03De=@1jNWX0D51@03@d=01M
GEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<09BDU04M7A`1aLG40LW9b07EeM@1QHF40EeMG09ZJVP1V
IVH092@T01dM7@0301hN7P25024Q8@0Z:RX0<C4a03lo?`1MGEd0HV9R07IfMP18B4P0H61P02XZ:P0Q
8B40<c<c0;Ng]`15ADD07alO020P800Q8B40:RXZ05EEE@23Ph<0KFe]07EeM@1fMWH0DU9B03Ti>@1]
KFd0Jf][07]kN`1XJ6P0CDe=05UIF@1OGel0G5aL05]KF`1aLG40[Jf]07EeM@2`/;00RXZ:06IVIP2H
V9P0RHV908N7Q`0g=cL0:BTY02l_;`1VIVH0PX:209BDU02RXZ80LW9b071`L01WIfL0GEeM0:6QX@1S
Hf<0FEUI06e]K@2@T900a<C40<;2`P2a/K40_;bl09FEU@2=SHd0];Bd0:RXZ01GEeL0F5QH0=SHf034
a<@0=cLg02LW9`0];Bd0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0b/[:0<S8b02B
TY80Zj^[0:b/[01?Cdl0@D5103`l?01RHV80/K6a0=GEe@3?cll0/K6a09NGU`2OWil0b/[:09RHV012
@T80:BTY02PX:00[:b/0Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`28R8P0DU9B05iNGP1a
LG40Rh^;09RHV02CTi<0Ogmo08R8R02YZJT0[:b/07MgM`0/;2`07AdM024Q8@1PH600DE5A034a<@0M
7Ad0820P01hN7P0201dM7@08020P800e=CD0Jf][0<W9b@3Kfm/0gMgM0:FUY@1iNGT204m?C`1505]K
F`1_Kfl0F5QH05=CD`35aLD0EEEE0:RXZ030`<00a/K60=KFeP36a/H0alO7061PH01GEeL0De=C05mO
G`2;Rh/0ATI602DU9@0/;2`0FEUI07YjNP1=CDd0ATI609fMW@2=SHd0/K6a0=SHf03?cll0a/K60:j^
[P23Ph<0Ng]k07=cL`2;Rh/0HF5Q04Q8B01HF5P0QHF508J6QP2<S8`0XJ6Q0=;BdP3>c/h0WinO02`/
;00e=CD0F5QH03lo?`0U9BD0;2`/03Ph>00];Bd09BDU0492@P1nOWh0L71`020P800Y:BT0<30`03Ph
>02PX:00dm?C0:b/[02f][H0aLG50<71`@2QXJ40QhN7017ooooo000?ooooo`080;Bd]01?Cdl0Kfm_
03`l?01?Cdl0>c/k030`<01DE5@201dM7@1>02/[:`0O7al0Cdm?01`L701:BTX09BDU06i^KP0h>3P0
410@04=3@`11@D406QXJ03dm?@13@d<05ADE02XZ:P0n?Sh0LG5a01DE5@0Y:BT0De=C05QHF00U9BD0
@d=301PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P0492@P0W9bL0?clo01lO7`1;Bd/0
GUiN04a<C00W9bL0;2`/04i>CP0X:2P0:b/[06MWI`1EEED0;Bd]03hn?P1FEUH0<C4a03/k>`2:RXX0
;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd0ADE502l_;`11@D40De=C05mOG`13@d<0
=3@d0;>c/`1aLG40ADE50:FUY@0k>c/0?Shn04Q8B014A4@0<C4a0P1MGEd0b019BDT0?clo07emO@1b
LW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06=SH`1OGel0LG5a04A4A01fMWH0Shn?06=SH`1N
GUh0PH6106e]K@22PX80@T9207AdM01BDU80=cLg075aL@1ADE40A4A404Q8B015ADD0BTY:08B4Q00d
=3@0Jf][03@d=01DE5@0I6AT03Ph>01gMgL0=3@d06UYJ@1JFUX0H61P07alO00n?Sh0:BTY06][J`2D
U9@0Cdm?07EeM@1YJFT0>SXj09RHV02;Rh/0ADE505ADE02=SHd0LG5a08F5Q@1:BTX0>c/k07EeM@27
QhL0L71`09ZJVP1NGUh0Cdm?08f=S@1YJFT0V9RH06QXJ018B4P0<30`07IfMP3Bd]80Zj^[0=3@d03T
i>@0^;Rh04M7A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0J6QX059BDP1[Jf/0IfMW02@T901B
DU80TY:B04a<C02DU9@0UIFE05QHF020P800EUIF08N7Q`1UIFD0=SHf06m_K`2BTY80;Rh^055AD@1j
NWX0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1/K6`0CTi>03`l?01lO7`0EeMG07AdM00h
>3P0:2PX07EeM@1mOGd0KFe]07moO`17AdL0K6a/0:>SX`1OGel0OWin09BDU01fMWH0De=C03@d=01^
KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_06][J`1TI6@0EEEE04I6AP1OGel0D51@05]KF`28
R8P0Fe]K07alO01PH600PH6106=SH`0b<S80ADE507YjNP2;Rh/0JVYZ05aLG01^KVh0J6QX07=cL`2K
Vi/0@T920451@@2BTY80R8R80410@00e=CD0B4Q80451@@1MGEd0HV9R06ATI016ATH0SXj>05MGE`1H
F5P0ZJVY0861P@20P800TY:B06IVIP0a<C407AdM02<S8`1cLg<0PX:203@d=025QHD0QhN703hn?P2F
UYH0RXZ:7?ooool09P12@T80Fe]K07emO@2CTi<0^[Zj05iNGP0_;bl0Hf=S04A4A00[:b/0:2PX03Ti
>@2VYZH0dM7A096AT@0/;2`06ATI02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY019BDT0:RXZ02HV
9P0m?Cd0IfMW06=SH`1FEUH0Bd];06MWI`0c<c<0V9RH09ZJVP0i>CT0;2`/0P1IFET0901PH600De=C
055AD@1@D500IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0EUIF03`l?01[Jf/0NGUi
0:NWY`1nOWh0@D5103Xj>P0b<S80?Cdm05EEE@1mOGd0U9BD096AT@1FEUH0EEEE079bLP2IVIT0DE5A
01dM7@0O7al07QhN024Q8@80:BTY00D0:b/[030`<017AdL0S8b<06YZJP0204a<C00505UIF@0Q8B40
8b<S07moO`1iNGT00P0O7al0S00N7Qh0:b/[075aL@1EEED0GemO07YjNP1OGel0GEeM06QXJ028R8P0
Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0[:b/0:VYZ@1`L700JVYZ071`L02DU9@0
IfMW04A4A011@D40<c<c02HV9P15ADD0TI6A09bLW01MGEd0Cdm?03`l?00g=cL0AdM708n?S`1:BTX0
GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1HF5P0FEUI09jNWP33`l<0d];B0>GUi@3Kfm/0
I6AT02d];@0T92@09RHV03Lg=`1fMWH0IfMW06UYJ@0c<c<0=CDe0451@@1WIfL0VIVI0;>c/`3Ng]h0
e=CD07inOP16ATH0C4a<06QXJ02QXJ40[:b/09nOW`27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0
EUIF020P800a<C40JVYZ0451@@1/K6`0W9bL09>CT`1IFET0Ng]k05eMG@1_Kfl0?Cdm02d];@0a<C40
?Cdm04=3@`1JFUX0RHV90<S8b02][Jd0Ti>C08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`0
8b<S02`/;00U9BD08R8R020P800Y:BT0SHf=08>3P`3Jf]X0dM7A0=;BdP32`/80O7al03Hf=P0Y:BT0
@d=306YZJP2;Rh/0Xj>S04U9B@28R8P0g]kN0=GEe@2n_[h0TY:B0P2JVYX07@0b<S809BDU03Ti>@1:
BTX0Ogmo02<S8`0[:b/0B4Q80;Bd]02KVi/0Q8B40:f][@30`<00Z:RX0=3@d03;bl/0K6a/075aL@1g
MgL0K6a/03hn?P0a<C40G5aL07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080d=3@01T0NGUi03Ph>00^
;Rh0<S8b06e]K@0_;bl0:BTY03Ti>@0c<c<0:2PX07alO035aLD0/[:b059BDP15ADD0FUYJ07MgM`3=
cLd0eMGE0<k>cP2XZ:P0Ti>C059BDP2m_Kd0d];B017ooooo000?ooooo`0K0<?3``1>CTh0EEEE069R
HP1fMWH0EUIF02HV9P11@D40EeMG02d];@0S8b<071`L04m?C`16ATH0>SXj010@400l?3`0DU9B02PX
:01JFUX0<30`01DE5@0U9BD0ADE501`L700^;Rh08R8R0080G5aL0180H61P07MgM`2;Rh/0>CTi030`
<00S8b<0>SXj01/K6`1ADE40=cLg04];B`1:BTX0@D51020P801XJ6P0>SXj075aL@1?Cdl205ADE022
06ATI01QHF40>3Ph05aLG014A4@07QhN069RHP1TI6@0<S8b04E5A@1RHV80FUYJ0492@P1lO7`0;Bd]
075aL@1ZJVX07AdM061PH02ATI40A4A406ATI01HF5P0C4a<0492@P0i>CT0EUIF08B4Q01[Jf/0>CTi
0:ZZZP1lO7`0BDU90::RXP1/K6`0@41003Xj>P17AdL0=cLg059BDP2QXJ40S8b<059BDP1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1NGUh0Bd];05YJFP0/;2`0DE5A07MgM`1GEeL0Cdm?
06m_K`11@D40GUiN0492@P1CDe<0NGUi038b<P23Ph<0Ng]k03De=@11@D40Jf][05UIF@28R8P0>CTi
06EUI@1IFET0IFEU05ADE00i>CT0Lg=c059BDP1LG5`0>CTi05=CD`2OWil0HF5Q03Lg=`1mOGd0Lg=c
028R8P1_Kfl0IVIV02l_;`2=SHd0T92@03/k>`10@400K6a/07=cL`1jNWX0IfMW03dm?@1LG5`0S8b<
06MWI`28R8P0KFe]03lo?`1^KVh0JVYZ0::RXP1gMgL0MWIf03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT
0<S8b01GEeL0GEeM08R8R00e=CD0ATI60:ZZZP2HV9P0Cdm?06a/K080=3@d06d0Fe]K03@d=00d=3@0
FUYJ0451@@1dM7@0W9bL04Q8B01BDU80;2`/04Y:BP1lO7`0Cdm?06YZJP2NWYh0EeMG04M7A`2DU9@0
@T92069RHP1=CDd07AdM04e=C@33`l<0F5QH05eMG@2SXj<0I6AT04];B`2:RXX0F5QH07MgM`1=CDd0
<S8b06QXJ024Q8@0Hf=S06i^KP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`03/k>`1NGUh0
MGEe04E5A@1?Cdl0MgMg03hn?P1MGEd0`L71079bLP1QHF40IFEU051@D01jNWX0LG5a06e]K@22PX80
E5AD06=SH`1XJ6P0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0KFe]069RHP2_[jl0
A4A402XZ:P1KFe/0I6AT061PH00_;bl0Cdm?02h^;P1KFe/0Z:RX08N7Q`1;Bd/0T92@059BDP0k>c/0
Xj>S07moO`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01mOGd0De=C01PH601`L700
Ng]k01cooooo06T0OGem06YZJP1KFe/0G5aL08R8R02[Zj/0NWYj03`l?01PH600=cLg02d];@1[Jf/0
][Jf09fMW@2VYZH0Vi^K09FEU@2DU9@0/k>c0=_Kf`3GemL0clo?0=3@d03;bl/0OGem04=3@`0O7al0
6a/K01lO7`0Y:BT0AdM70861P@1QHF40EeMG05UIF@0l?3`0B4Q804U9B@14A4@0CDe=059BDP1gMgL0
Kfm_079bLP2LW9`0ZJVY0;Ng]`0c<c<07AdM024Q8@0P8200?3`l07]kN`1XJ6P0O7al03De=@0j>SX0
LW9b0<_;b`3GemL0d=3@0:ZZZP2h^;P0c<c<0:RXZ023Ph<0J6QX024Q8@0_;bl0Cdm?07UiN@2HV9P0
;2`/02<S8`0U9BD0;2`/02d];@0f=SH0BDU90820P02UYJD0h^;R08:2PP18B4P0BDU905ADE01=CDd0
<S8b05UIF@2a/K40<C4a020P800M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2<S8`0
QhN706IVIP1EEED00P1TI6@08P1KFe/0ATI602DU9@0e=CD0NGUi09:BTP17AdL0A4A4069RHP2a/K40
Jf][075aL@2FUYH0Ph>306YZJP2CTi<0VIVI096AT@21PH40AdM7034a<@0_;bl0<c<c08:2PP1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02h^;P30<30`00m0=SHf02OWil0Shn?0:n_[`1G
EeL092@T02HV9P0Z:RX0E5AD04Y:BP1@D500:BTY02LW9`0U9BD0=3@d051@D02?Shl0ZJVY0=cLg02F
UYH0Ph>3096AT@2JVYX0FUYJ03/k>`1[Jf/0[jn_09nOW`34a<@0Zj^[09NGU`1mOGd0PX:209ZJVP2;
Rh/0QHF503<c<`0k>c/0M7Ad0;Ng]`29RHT0KFe]0820P01aLG40KFe]0451@@0e=CD0<S8b03Ph>00l
?3`0?clo05EEE@2`/;00`/;20;:b/P2_[jl0YJFU03De=@1EEED0@410030`<00201dM7@0]02HV9P0M
7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^KV`2HV9P0`L710<c<c03?cll0VIVI059BDP19
BDT0Vi^K09jNWP2<S8`0a<C40>3Ph03Hf=P0VIVI07]kN`31`L40alO705IFEP0U9BD0:b/[05]KF`1G
EeL0TI6A061PH01gMgL0UIFE08R8R02KVi/0_[jn0=cLg03:b/X0d=3@0<S8b01aLG40?clo00809BDU
02@092@T02<S8`0];Bd0@T9206ATI01jNWX0PH6109nOW`23Ph<0KVi^09jNWP1dM7@0EEEE02/[:`0`
<300AdM70820P00g=cL0F5QH06a/K02>SXh0alO70<?3``2FUYH0WYjN08V9R@1^KVh0[Jf]0;bl_02j
^[X0c<c<0:b/[01QHF40EEEE0<c<c021PH4Aooooo`003oooool07@3<c<`0EeMG05EEE@1^KVh0OGem
08j>SP0d=3@0CDe=07MgM`0_;bl0BTY:03/k>`1QHF40GemO0492@P0`<300ATI603dm?@0N7Qh0BTY:
030`<00N7Qh07alO03Hf=P0L71`0<c<c03De=@1CDe<0IVIV0080J6QX0;/0SHf=04a<C00b<S80;bl_
03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0De=C03Ph>01jNWX0G5aL059BDP1;Bd/0CDe=
05iNGP0g=cL0LW9b0492@P0L71`0EUIF04M7A`0U9BD0HF5Q07alO01HF5P0>3Ph07=cL`0_;bl0DU9B
071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@1<C4`0=SHf04U9B@1YJFT0TI6A07]kN`0h>3P0VYZJ
055AD@0R8R80N7Qh069RHP0f=SH0=cLg04=3@`0a<C409bLW0451@@1>CTh0>c/k06i^KP1LG5`0@T92
07=cL`2d];@0MWIf02XZ:P1WIfL0Fe]K06EUI@1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX
08B4Q01VIVH0DU9B05mOG`2BTY80?clo07QhN00l?3`0<c<c05ADE01cLg<0GUiN06YZJP0l?3`0Jf][
05QHF01VIVH0NWYj04];B`1oOgl0Cdm?05QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF
07QhN01/K6`0:RXZ08n?S`2XZ:P0MWIf05MGE`1lO7`0Kfm_08b<S01nOWh0@41007=cL`25QHD0G5aL
09:BTP25QHD0C4a<07QhN01gMgL0Ti>C08J6QP28R8P0>SXj03lo?`23Ph<0h>3P0=oOg`3UiND0b<S8
05eMG@1EEED0WIfM08J6QP1nOWh0_[jn07emO@1BDU80MgMg05]KF`11@D40LW9b04M7A`0a<C40Jf][
03/k>`1OGel0WIfM04a<C01FEUH0=SHf05MGE`23Ph<0EUIF061PH02IVIT0@T9204=3@`1oOgl0@410
07moO`1IFET07QhN03lo?`3<c<`0GemO02`/;01XJ6P0LG5a04e=C@1kNg/0Fe]K09FEU@1<C4`0A4A4
07QhN01aLG40HF5Q0080@T9204H0J6QX0:FUY@2BTY80GEeM09JFUP2JVYX0>3Ph069RHP2JVYX0TI6A
055AD@1IFET0MgMg02l_;`1ADE40[Zj^06e]K@1KFe/0GEeM034a<@1EEED0IVIV05eMG@1oOgl0GemO
05eMG@17AdL0S8b<08V9R@14A4@0=CDe07alO01:BTX0@T9204U9B@1bLW80N7Qh05YJFP2IVIT0F5QH
03<c<`1bLW80FEUI05YJFP0];Bd0BTY:04=3@`0k>c/0Ogmo08N7Q`1>CTh0QHF507AdM018B4P0SXj>
06a/K02IVIT0[Jf]06e]K@16ATH06a/K02LW9`1_Kfl0MgMg0492@P1iNGT0OWin04I6AP1bLW80M7Ad
7?ooool0G`1FEUH0D51@04a<C019BDT0ATI605]KF`1fMWH0PX:205YJFP1OGel0KVi^0:VYZ@1LG5`0
I6AT0451@@39bLT0bl_;0=cLg03=cLd0fm_K0<71`@1MGEd0BDU906][J`2VYZH0PH6106QXJ014A4@0
AdM704=3@`1<C4`0I6AT06QXJ01YJFT0Hf=S06MWI`1FEUH0E5AD06MWI`2DU9@0Kfm_05mOG`2CTi<0
B4Q8030`<01RHV80Ogmo07IfMP0M7Ad071`L01dM7@0j>SX0M7Ad03De=@0W9bL0<S8b04=3@`1eMGD0
b/[:08N7Q`1NGUh0C4a<06][J`2MWId0WinO08^;R`1^KVh07QhN01`L700P8200AdM709nOW`2YZJT0
QhN708>3P`2>SXh0SHf=092@T02=SHd0X:2P0;Zj^P3Bd]80b<S805eMG@1GEeL0AdM704i>CP0/;2`0
BDU909^KV`1WIfL07alO01dM7@19BDT0E5AD0080>c/k03/0Bd];0<W9b@2c/k<0Q8B407AdM01KFe/0
ATI603hn?P0k>c/0>3Ph03/k>`0e=CD08b<S02DU9@1<C4`0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0
De=C07emO@38b<P0e=CD08^;R`2FUYH0CTi>07IfMP1/K6`0?Cdm030`<00b<S80HF5Q0<g=c@2YZJT0
NWYj06UYJ@2KVi/0_;bl0=oOg`2MWId0PH610;Jf]P1^KVh0QHF505eMG@2k^k/0MWIf03/k>`1CDe<0
X:2P04=3@`0V9RH0;2`/05eMG@1DE5@0KVi^02LW9`0202HV9P0`02TY:@0o?cl0BTY:07UiN@3=cLd0
dM7A0:BTY01VIVH0<C4a02@T900Y:BT0>c/k0;fm_@2GUiL0WYjN0;^k^`2QXJ40O7al05mOG`1JFUX0
PX:209jNWP1>CTh0QHF508R8R01jNWX0Hf=S06UYJ@28R8P0YjNW07moO`1:BTX0B4Q803`l?00d=3@0
?Cdm05mOG`2QXJ40RXZ:06IVIP2OWil0WYjN0;Vi^@2h^;P0MgMg03Lg=`0Q8B4071`L0P0O7al0500L
71`06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2DU9@0_;bl0:f][@31`L40a<C40<S8b030
`<00clo?0=7Ad@3<c<`0dm?C0P2n_[h01@39bLT0^k^k07emO@29RHT0RXZ:0080:b/[00L0BDU907If
MP37alL0[Jf]08j>SP2RXZ80CDe=0080>CTi00H0^[Zj0<S8b038b<P0]KFe0492@P0j>SX201lO7`0T
02@T900S8b<09BDU02h^;P17AdL0?Shn04m?C`1_Kfl0QXJ604a<C01kNg/0RHV905eMG@0d=3@09bLW
03/k>`24Q8@0]KFe0;Rh^038b<P0];Bd07=cL`1IFET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE
0=[JfP2m_Kd0QXJ60<[:bP23Ph<0D51@4Oooool000oooooo01<0U9BD05=CD`1BDU80FEUI06MWI`1k
Ng/0=CDe04=3@`17AdL0;Rh^04A4A00_;bl0De=C04A4A016ATH0=CDe0410@019BDT05QHF0080=cLg
03X07QhN01PH600e=CD07AdM0451@@0k>c/0EeMG04A4A00o?cl0I6AT06i^KP11@D40>3Ph02/[:`10
@400:BTY038b<P0Q8B40:b/[05aLG01ADE406a/K03Ti>@0`<300IVIV04i>CP15ADD0F5QH05MGE`19
BDT0<c<c06YZJP1<C4`0820P04a<C011@D4092@T0410@01BDU80D51@034a<@1gMgL0GEeM04M7A`1i
NGT06ATI0451@@2FUYH0CTi>05EEE@1QHF40BDU904];B`0c<c<0A4A407QhN010@40092@T0P1oOgl0
d@1OGel0VYZJ05]KF`0h>3P0B4Q8051@D01ADE40>SXj07YjNP1DE5@0>3Ph06i^KP29RHT0EeMG0:ZZ
ZP32`/80Rh^;030`<01XJ6P0EEEE05IFEP15ADD0HF5Q03<c<`1PH600NWYj05YJFP0b<S80BTY:05eM
G@1IFET0D51@04Q8B01`L700;Bd]06YZJP1aLG40>3Ph03hn?P1=CDd0E5AD07MgM`1BDU80Kfm_04=3
@`1>CTh0S8b<04M7A`1gMgL0C4a<06UYJ@1eMGD0?Shn09BDU01QHF40<c<c07AdM02FUYH0JFUY07Mg
M`1EEED0<C4a06i^KP28R8P0NWYj06ATI01^KVh0HV9R06IVIP2FUYH0BDU9051@D01YJFT0@D5108J6
QP2:RXX0B4Q8079bLP1>CTh0O7al08^;R`1NGUh0@T9203dm?@1bLW80hN7Q0=oOg`3Lg=`0XZ:R05eM
G@1PH600]KFe09bLW02?Shl0_Kfm08V9R@12@T80Vi^K06e]K@16ATH0KVi^051@D00l?3`0MgMg04m?
C`1JFUX0XZ:R05]KF`1cLg<0@d=305aLG01mOGd0>3Ph06ATI02PX:00De=C0451@@1gMgL0=SHf06MW
I`10@4007AdM030`<03>c/h0IVIV04U9B@1SHf<0G5aL03lo?`2=SHd0P82009bLW01FEUH0:b/[05aL
G01FEUH0JFUY04e=C@0i>CT0@d=307EeM@1KFe/0B4Q808n?S`1kNg/0=SHf03Ti>@1FEUH0PX:204e=
C@1eMGD0K6a/03/k>`18B4P0_[jn05iNGP1fMWH0PX:204Q8B01HF5P0A4A403/k>`1GEeL0LG5a06IV
IP1HF5P0P82005=CD`0Z:RX0>c/k07YjNP1_Kfl0IFEU05iNGP1/K6`0G5aL05]KF`2CTi<0G5aL03<c
<`1WIfL0F5QH03Xj>P0g=cL0Hf=S05=CD`17AdL0Ng]k06MWI`15ADD0N7Qh08b<S016ATH0TY:B05mO
G`1gMgL0WYjN079bLP13@d<09bLW03hn?P1mOGd0FUYJ034a<@1_Kfl0NGUi03De=@20P800GUiN01co
oooo03D0Bd];0492@P0m?Cd0>3Ph03lo?`1<C4`0GEeM08R8R02g]kL0a/K60<C4a014A4@07AdM03Hf
=P1CDe<0Shn?0<30`02k^k/0[Zj^08f=S@1MGEd0<S8b02TY:@0[:b/0=CDe04m?C`1NGUh0KVi^05QH
F01FEUH0EeMG06a/K01nOWh0;Bd]01lO7`0M7Ad08B4Q02TY:@1IFET0QHF50:>SX`1nOWh0HF5Q03Hf
=P0M7Ad0:b/[059BDP2PX:00NGUi059BDP1QHF40WIfM0;6a/@0204I6AP0=05MGE`0m?Cd0NWYj05MG
E`0];Bd08b<S024Q8@0M7Ad092@T05]KF`1dM7@0Kfm_04M7A`0201`L700602l_;`1UIFD0Xj>S08B4
Q01BDU80Bd];0P1BDU80E`1>CTh0E5AD055AD@1_Kfl0ZJVY0<O7a`2OWil0F5QH03lo?`1?Cdl0C4a<
07YjNP30`<00LG5a07AdM02i^KT0JFUY03Hf=P0a<C40ADE507QhN026QXH0R8R807moO`13@d<0>SXj
04M7A`0c<c<09bLW02@T900W9bL0:b/[02<S8`0c<c<0EUIF04A4A00/;2`0FEUI03dm?@0d=3@0<C4a
04a<C02>SXh0V9RH04e=C@14A4@0ADE506IVIP2TY:@0VYZJ08b<S01RHV80M7Ad0:ZZZP2g]kL0I6AT
05IFEP0l?3`0ATI607moO`23Ph<0[Zj^07]kN`1=CDd0E5AD05QHF01^KVh0Lg=c0492@P0a<C40<30`
07EeM@1RHV80=CDe04];B`1UIFD0N7Qh02LW9`0Y:BT09RHV02<S8`1BDU80A4A404M7A`2PX:00eMGE
055AD@0402@T901E02LW9`24Q8@0fm_K0;6a/@1[Jf/0V9RH0;Fe]@28R8P0Lg=c07inOP3=cLd0W9bL
05YJFP18B4P0D51@055AD@1kNg/0O7al06QXJ01QHF40FUYJ05ADE01=CDd0L71`08f=S@2DU9@0Kfm_
04M7A`0o?cl0P82006m_K`2?Shl0_;bl0:JVYP1PH600>c/k01lO7`0K6a/06QXJ02@T901DE5@0N7Qh
0861P@2RXZ80c/k>07moO`2ZZZX0YjNW07=cL`1^KVh0IfMW06IVIP1`L700TI6A0;bl_03Ng]h0gmoO
0;jn_P2NWYh0Shn?07YjNP1eMGD0RHV907IfMP1SHf<0RHV906UYJ@0c<c<0G5aL075aL@2SXj<0=SHf
02l_;`16ATH0=CDe02LW9`0g=cL0SHf=0<G5a@32`/80/k>c03Hf=P0R8R807QhN020P8002024Q8@0M
02<S8`0U9BD0<c<c03Xj>P0f=SH0Cdm?06IVIP1gMgL0HV9R096AT@1nOWh0Q8B408^;R`2YZJT0a/K6
0;Zj^P2][Jd0XZ:R08^;R`27QhL0U9BD09nOW`2/[:`0][Jf0<30`02o_kl0][Jf0;Vi^@2j^[X00P3?
cll00`2QXJ40O7al07IfMP0Aooooo`003oooool0o`1FEUH0F5QH055AD@1iNGT0JFUY08F5Q@0b<S80
ADE506][J`1:BTX0@D5103Ph>019BDT0Jf][04Q8B00/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/0
6ATI04U9B@0X:2P0>SXj01TI6@0k>c/0KFe]069RHP1WIfL0Ng]k02l_;`0];Bd0F5QH03Ti>@0K6a/0
<c<c03/k>`0b<S80GemO0492@P0J6QX0?3`l0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R0492@P0J6QX0=CDe04E5A@0^;Rh0DE5A04Q8B01fMWH0?3`l06i^KP1IFET0?3`l08f=S@0_;bl0
<S8b08:2PP0k>c/0Fe]K05aLG015ADD0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0M7Ad071`L00g=cL0
GEeM07MgM`1;Bd/0@T9204=3@`0X:2P092@T04e=C@1WIfL0A4A404];B`26QXH0;Rh^07=cL`22PX80
UiNG03`l?01GEeL092@T05UIF@15ADD0B4Q802LW9`0n?Sh0L71`075aL@0^;Rh0BTY:069RHP1=CDd0
IFEU04];B`1]KFd0=cLg05EEE@1fMWH0?clo03`l?01PH600EeMG06m_K`1CDe<0OGem07IfMP1GEeL0
Ph>303hn?P1CDe<0MGEe05YJFP21PH40?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL07UiN@2:RXX0
<S8b0861P@1^KVh0G5aL04U9B@2:RXX0T92@05UIF@26QXH0@410075aL@2BTY80Cdm?06i^KP2FUYH0
C4a<06UYJ@1fMWH0GEeM06UYJ@1TI6@0Hf=S03Lg=`0n?Sh0/k>c09^KV`2RXZ80JFUY02h^;P16ATH0
Q8B40:>SX`1UIFD0^k^k0:6QX@1?Cdl0MGEe07=cL`1ADE40GemO051@D018B4P0SXj>059BDP13@d<0
XZ:R04i>CP1cLg<0EUIF055AD@2LW9`0DU9B05ADE02i^KT0KFe]0451@@2CTi<0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01KFe/0KVi^02d];@0o?cl0CDe=06QXJ01YJFT09BDU071`L010@400
EEEE07AdM017AdL0ATI607moO`0i>CT0?Shn08:2PP20P800I6AT03lo?`1LG5`0GemO02XZ:P1=CDd0
IfMW06UYJ@1:BTX0_;bl05EEE@1JFUX0MWIf04I6AP1BDU80?clo05QHF00m?Cd0KFe]08b<S01UIFD0
LW9b05eMG@19BDT092@T061PH020P800MgMg06a/K0008`27QhL0R8R8059BDP2LW9`0ADE502@T9024
Q8@0SXj>04i>CP0T92@0D51@04Q8B00m?Cd0YJFU08^;R`1DE5@0IVIV07QhN00`<300W9bL08B4Q029
RHT0Zj^[07]kN`0S8b<06ATI02TY:@1DE5@0M7Ad03De=@1LG5`0De=C01DE5@1QHF40K6a/01cooooo
0140KVi^07QhN01gMgL0M7Ad06a/K019BDT0=cLg038b<P0c<c<0F5QH05]KF`2=SHd0QHF508J6QP1i
NGT0d=3@0<g=c@020=GEe@040:>SX`1EEED0:BTY02<S8`80:2PX00`0;bl_02h^;P1FEUH0<C4a02`/
;00W9bL0ATI6051@D00N7Qh06a/K01`L700O7al202<S8`0E02h^;P1IFET0HF5Q02d];@1JFUX0?Shn
02HV9P0Y:BT0Y:BT0=CDe02g]kL0RXZ:07YjNP2l_;`0Shn?0;6a/@1UIFD0EeMG04];B`0W9bL07AdM
008071`L0P0K6a/02P0m?Cd0LG5a02XZ:P1LG5`0CDe=02`/;01HF5P0E5AD061PH01_Kfl201XJ6P0?
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/04m?C`1`L700YZJV0<_;b`2PX:00H61P09jNWP36a/H0Z:RX
0080EeMG00<0Ph>30;Zj^P2OWil00P1iNGT04`20P800MWIf0820P01UIFD0:2PX02TY:@10@400D51@
05QHF015ADD09RHV02XZ:P0o?cl08R8R05MGE`1EEED0?Shn06a/K00T92@00P0P8200:00T92@0@410
06UYJ@0Z:RX0?Cdm08B4Q02XZ:P0PX:207emO@34a<@0b/[:0;Fe]@3>c/h0/[:b08B4Q00Q8B407alO
04=3@`28R8P0SXj>06e]K@12@T80ADE503Lg=`0Z:RX0HF5Q07]kN`1eMGD0<C4a030`<00_;bl0K6a/
09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<205=CD`1J02`/;01DE5@0ZJVY051@D00O7al0
9bLW02/[:`0U9BD0;Bd]08n?S`3Ti>@0g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0emOG0:n_[`2h^;P0
OWin06a/K01VIVH0MGEe0<G5a@1XJ6P0:BTY038b<P10@400F5QH08V9R@2g]kL0][Jf09nOW`1QHF40
ADE506i^KP2KVi/0De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00`<300QhN70:ZZZP2f][H0
_;bl06IVIP1^KVh0LW9b05EEE@26QXH0M7Ad01`L700N7Qh0<C4a030`<00i>CT0De=C0=CDe03Ogml0
d];B079bLP1aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY0492@P1GEeL0BTY:06MWI`0L71`0
8B4Q028R8P0b<S80;Bd]04U9B@2MWId0hN7Q0:2PX029RHT0<S8b0P0M7Ad09@0L71`07AdM01`L700M
7Ad09BDU02LW9`0k>c/0<S8b03lo?`1GEeL0JFUY092@T02l_;`0i>CT0=?Cd`36a/H0TY:B05UIF@1?
Cdl0R8R80<O7a`1UIFD0OWin05MGE`1EEED0GemO08j>SP3=cLd0dM7A0<?3``2i^KT0ZZZZ0:b/[02C
Ti<0/K6a0820P02@T9004Oooool000oooooo01d0LW9b04i>CP1CDe<0MWIf06YZJP23Ph<0;bl_03<c
<`1EEED0?3`l02h^;P0g=cL0@T92075aL@16ATH0@d=3034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF
5P15ADD09RHV03Xj>P0W9bL0>SXj07UiN@02069RHP35096AT@1]KFd0<C4a06IVIP0o?cl0>CTi038b
<P15ADD0<C4a07=cL`1ZJVX0?Shn03Hf=P0/;2`0N7Qh06MWI`0_;bl0DE5A07AdM01SHf<0<c<c07Mg
M`1SHf<0820P030`<00Q8B4061PH03dm?@14A4@0GEeM030`<01XJ6P08b<S028R8P1YJFT0<30`034a
<@1oOgl0;2`/02DU9@1EEED0ATI604m?C`0I6AT0<30`05]KF`17AdL0:2PX07emO@2YZJT0KVi^07Mg
M`28R8P0>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM703<c<`0n?Sh0SXj>05IFEP1mOGd0V9RH0:b/
[00g=cL0Kfm_06i^KP1LG5`0DE5A07YjNP1UIFD0ATI606m_K`1MGEd0=3@d06m_K`2CTi<0GemO04a<
C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0QHF505mOG`1dM7@0;bl_05eMG@28R8P0F5QH06=S
H`0V9RH0BTY:07AdM01FEUH0E5AD03dm?@3<c<`0Shn?051@D01HF5P0KVi^03<c<`1EEED0JVYZ02LW
9`1iNGT0KVi^07alO01FEUH0D51@08R8R01@D500Rh^;03/k>`1HF5P0UiNG04m?C`1WIfL0Kfm_04M7
A`2HV9P0TI6A051@D01nOWh0UYJF09RHV01:BTX0Rh^;0:RXZ02DU9@0QhN709jNWP1bLW80DU9B08b<
S01^KVh0@D5109nOW`2/[:`0K6a/07YjNP1QHF40H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NW
Y`1<C4`0K6a/06MWI`1ADE40WinO07inOP1LG5`0/[:b06UYJ@1ADE40[Jf]03hn?P1nOWh0ADE501lO
7`0P8200_Kfm092@T01;Bd/0LG5a09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV905YJ
FP1aLG40EUIF069RHP2RXZ80R8R804=3@`1_Kfl0LW9b05]KF`1MGEd00P2PX:0205IFEP0;07emO@1Y
JFT0EUIF0;no_`1kNg/0Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<00P0j>SX0;@1]KFd0JVYZ0:^[Z`23
Ph<0FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ08n?S`0n?Sh0`/;204i>CP0I6AT0@T9205EEE@1V
IVH0;bl_05ADE01VIVH0A4A4075aL@1oOgl0Fe]K06a/K02=SHd0>3Ph09RHV01cLg<0T92@0;fm_@1d
M7@0De=C01dM7@0h>3P0A4A4075aL@12@T80Kfm_05iNGP0S8b<0J6QX05eMG@0Looooo`0606QXJ013
@d<0<S8b02LW9`0P82007AdM0P0J6QX02@0E5AD071`L06YZJP1ZJVX0VIVI06=SH`2:RXX0OGem04m?
C`020=CDe00?0;bl_02GUiL0O7al02XZ:P0X:2P0;Bd]02/[:`0m?Cd0A4A402TY:@0W9bL0:BTY04];
B`0O7al071`L00807AdM01H07alO01hN7P0M7Ad08R8R03De=@1ADE40Bd];02XZ:P1^KVh0Kfm_08>3
P`2MWId0VYZJ08:2PP1SHf<0E5AD06MWI`1fMWH0X:2P096AT@1SHf<09bLW0P0Q8B403P0X:2P0;2`/
028R8P0L71`0=SHf08>3P`0W9bL0CTi>071`L01SHf<0Cdm?03hn?P1?Cdl0I6AT1P0L71`0300N7Qh0
7alO034a<@1DE5@0EeMG07MgM`2^[Zh0f][J0=;BdP3;bl/0M7Ad03Hf=P80?3`l04`0E5AD08J6QP2Q
XJ40VYZJ0;Ng]`2[Zj/0^KVi07IfMP0U9BD09RHV02<S8`0T92@08b<S03Ti>@1JFUX0DU9B02LW9`0Y
:BT0ZJVY0:j^[P34a<@0R8R8024Q8@0P82007AdM02<S8`0m?Cd0_Kfm0:^[Z`2LW9`0QXJ605eMG@1I
FET0L71`09FEU@1dM7@0HF5Q09FEU@1kNg/0W9bL05YJFP1[Jf/0M7Ad03lo?`1bLW80HF5Q04I6AP0d
=3@0:RXZ02PX:010@400IfMW09^KV`1HF5P0=SHf02`/;00g=cL0Lg=c0;6a/@2ATI40ZJVY09ZJVP1=
CDd0@d=3079bLP1]KFd09BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300ATI60P3;bl/0
302g]kL0Hf=S059BDP2ATI40`L710;Fe]@37alL0e=CD0<W9b@2e]KD0Vi^K09jNWP80clo?01l0Cdm?
02TY:@0V9RH0<30`0492@P2:RXX0`/;20:6QX@25QHD0_Kfm09^KV`2TY:@0@d=301dM7@0Z:RX0T92@
0:BTY02NWYh0ZZZZ09RHV01`L700I6AT0<30`039bLT0Z:RX05IFEP1_Kfl0MgMg03De=@0Z:RX0C4a<
0080E5AD0180=CDe02TY:@0[:b/0<C4a06i^KP3>c/h0f=SH0<_;b`1MGEd0De=C05IFEP1DE5@0BDU9
04M7A`1IFET0JFUY0::RXP1TI6@205MGE`0?05eMG@0O7al07AdM01lO7`0U9BD0>CTi07alO039bLT0
][Jf0:JVYP1^KVh0Bd];01lO7`0M7Ad071`L00807AdM00X07alO028R8P0R8R8092@T02HV9P0_;bl0
ATI606ATI02f][H0g=cL0P3?cll05P3Fe]H0W9bL0:^[Z`2_[jl0Z:RX09bLW02FUYH0GUiN03/k>`16
ATH0PX:20:RXZ030`<00e=CD0<O7a`2k^k/0alO70;Ng]`26QXH0Xj>S0=GEe@3MgMdAooooo`003ooo
ool08@1kNg/0Cdm?04i>CP1IFET0IfMW09FEU@14A4@0>3Ph059BDP0g=cL0AdM705mOG`17AdL0I6AT
04i>CP1=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00N7Qh0AdM702l_;`0m?Cd0G5aL
03hn?P1cLg<0Vi^K07alO00202l_;`3f038b<P1@D500<C4a02TY:@0C4a<0@41007MgM`0n?Sh09bLW
018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04m?C`0];Bd0?3`l05IFEP0n?Sh0@D51
03Ph>00a<C406a/K08>3P`1gMgL09bLW0820P00m?Cd0:b/[07inOP1`L700;Rh^079bLP16ATH0Lg=c
02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0OWin08J6QP0_;bl0@D5106IVIP1NGUh0@D51
075aL@1?Cdl0=CDe055AD@2LW9`0IfMW0:JVYP2OWil0aLG5034a<@1JFUX0LG5a05EEE@0n?Sh0HF5Q
05iNGP11@D40NGUi05IFEP0b<S80De=C06e]K@1FEUH0@d=303De=@1`L700D51@04I6AP1lO7`0<S8b
03@d=01SHf<0De=C05YJFP1VIVH0DE5A07YjNP1DE5@0MGEe065QH@1?Cdl0K6a/05YJFP1ADE407alO
09:BTP25QHD0EEEE05IFEP1ZJVX0?clo06=SH`1UIFD0;2`/08J6QP2/[:`0RHV905eMG@1PH600Vi^K
0820P02k^k/0F5QH055AD@24Q8@0FEUI06i^KP2>SXh0EEEE06EUI@27QhL0ATI60:VYZ@2SXj<0J6QX
05eMG@1mOGd0TY:B03@d=00i>CT0MGEe05mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0RXZ:
07AdM00Z:RX0EUIF05]KF`0Y:BT0HF5Q04=3@`1UIFD0WinO05MGE`1bLW80>c/k05eMG@2BTY80MgMg
059BDP2a/K40H61P02d];@1hN7P0>SXj0:>SX`2<S8`0>c/k020P8038b<P0[:b/038b<P1ZJVX0Shn?
06i^KP22PX80KVi^09>CT`10@4007alO04a<C029RHT0KFe]04M7A`0N7Qh0=SHf065QH@22PX80?clo
08:2PP2LW9`0<S8b03<c<`1WIfL0TY:B06i^KP1JFUX0MGEe038b<P0g=cL0QhN707alO01^KVh0J6QX
02PX:00a<C40DU9B06UYJ@11@D40<30`05ADE01=CDd0Fe]K065QH@1GEeL08B4Q055AD@1XJ6P0IfMW
071`L01DE5@0Ogmo04m?C`2NWYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0Ogmo08^;R`1CDe<0RHV9
08J6QP1KFe/0T92@0:>SX`19BDT0ZZZZ04a<C01WIfL0ZJVY08b<S01[Jf/0ADE50P1WIfL01`1/K6`0
?Shn06=SH`1cLg<0@D5107EeM@1@D5007?ooool0901:BTX0ADE50492@P0j>SX09RHV01`L700I6AT0
61PH01DE5@0[:b/0OGem092@T020P800aLG50;>c/`0X:2P07AdM0:n_[`2RXZ80PX:20:RXZ01mOGd0
L71`03Ph>00`<3009RHV0492@P0];Bd0:2PX02XZ:P0W9bL06a/K01DE5@0F5QH06a/K01PH60<071`L
02<07AdM02@T901@D500CTi>02h^;P0N7Qh0G5aL0<O7a`2CTi<0Vi^K06EUI@0a<C408b<S01lO7`0o
?cl0E5AD07alO01fMWH0E5AD04I6AP0T92@09RHV028R8P0M7Ad06ATI04=3@`2LW9`0@d=305UIF@1n
OWh0T92@0410@00`<300AdM706m_K`0201`L700301XJ6P0L71`071`L00<071`L01L0820P05QHF01D
E5@0I6AT09bLW03Ph>00dM7A0;Ng]`1DE5@0;Bd]034a<@0l?3`0?Shn04Q8B01lO7`0[Zj^0;fm_@2S
Xj<0][Jf08Z:RP0];Bd09BDU01lO7`03024Q8@0902/[:`0m?Cd0BDU908N7Q`2YZJT0_kno0:RXZ02U
YJD0HV9R00<07alO00T0Hf=S0<C4a021PH40EUIF04i>CP1;Bd/0B4Q807AdM01lO7`00P12@T802P13
@d<0Hf=S0451@@2FUYH0HF5Q03/k>`0U9BD0K6a/05aLG018B4P302@T900f03Ti>@1aLG40NWYj04U9
B@16ATH0HV9R06UYJ@25QHD0VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08f=S@12@T807alO06AT
I01nOWh0RHV902PX:00Y:BT0=SHf04=3@`1hN7P0a<C40:FUY@2WYjL0Fe]K06ATI034a<@0V9RH09JF
UP2c/k<0UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;2`/02PX:00];Bd0IFEU0:j^
[P2i^KT0];Bd0>OWi`36a/H0GUiN0P0M7Ad0>00c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0^[Zj
0<o?c`2NWYh0MGEe09VIV@2][Jd0AdM701`L700R8R80;Bd]02/[:`1jNWX0N7Qh04a<C01TI6@0QhN7
0;fm_@3?cll0fMWI0<S8b01JFUX0@d=30451@@17AdL0EEEE05eMG@1DE5@0F5QH07inOP2GUiL0XJ6Q
092@T01WIfL0=SHf03Lg=`0^;Rh0;bl_05MGE`2TY:@0_;bl08>3P`1/K6`0JVYZ0:b/[01KFe/0C4a<
0410@00k>c/0;Rh^0P0Q8B40800M7Ad0820P01hN7P0V9RH0BDU908^;R`2/[:`0b<S80:ZZZP2m_Kd0
e=CD0;jn_P2UYJD0XZ:R08F5Q@1VIVH0CDe=08B4Q02@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0
Jf][09NGU`3Fe]H0eMGE0<71`@2n_[h0SHf=4Oooool000oooooo00L0FUYJ04M7A`1HF5P0Hf=S04=3
@`1PH600>3Ph0080@41001X07AdM02TY:@1:BTX0@D51038b<P0Y:BT0DE5A038b<P1ZJVX0820P01DE
5@1>CTh0;Rh^01XJ6P1DE5@05aLG034a<@0Y:BT0A4A405EEE@0O7al0BDU907=cL`1UIFD0?Cdm055A
D@80?Shn01D0>CTi05IFEP0T92@0DE5A065QH@0i>CT0G5aL03`l?01^KVh0IFEU030`<01/K6`0TI6A
07alO01@D500C4a<04Y:BP0L71`0<C4a0492@P0k>c/00P11@D40]@1TI6@0=SHf05eMG@20P8009bLW
0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`19BDT0Shn?04U9B@10@400GemO05aLG00e=CD0GUiN
08B4Q01WIfL0QHF509RHV01RHV80=3@d04M7A`1<C4`0BTY:079bLP17AdL0>c/k04=3@`22PX80JVYZ
07moO`2][Jd0_;bl05aLG01PH600IVIV05UIF@1BDU80PX:204e=C@11@D40JVYZ08B4Q019BDT0H61P
07=cL`1MGEd0NWYj04e=C@1iNGT0IFEU04I6AP25QHD0Bd];0410@01LG5`0H61P07MgM`1/K6`0Cdm?
06m_K`11@D40Ti>C06EUI@1<C4`0I6AT07alO02:RXX0ATI60<;2`P1TI6@0CTi>06e]K@2DU9@0I6AT
06=SH`1LG5`06a/K05]KF`1WIfL0KVi^05ADE01UIFD0UIFE04E5A@20P800G5aL04Y:BP1SHf<0:BTY
071`L027QhL0GUiN07IfMP1]KFd0>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0S8b<
04Q8B01PH600Rh^;0:b/[01>CTh0X:2P09ZJVP11@D40IVIV09ZJVP15ADD0L71`02d];@0h>3P0N7Qh
061PH00i>CT0U9BD04M7A`2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01oOgl05aLG
05YJFP2BTY80@d=302@T9035aLD0[jn_04e=C@1GEeL0IFEU04];B`1XJ6P0TI6A09RHV01[Jf/0:BTY
055AD@1[Jf/0Hf=S07]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@1KFe/0TI6A
04U9B@1oOgl0Ph>307YjNP1FEUH0WinO06EUI@2=SHd0VYZJ05mOG`1:BTX00P13@d<0;`19BDT0Fe]K
06m_K`1JFUX0JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0LG5a03Xj>P2YZJT0QXJ6
04m?C`1DE5@0EUIF03`l?00P8200GemO07emO@1;Bd/0WIfM07UiN@0o?cl0Jf][09fMW@16ATH0_kno
08>3P`1`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0G5aL0451@@1FEUH0NWYj038b<P1fMWH0QhN7
01cooooo0200CTi>04U9B@13@d<0>3Ph04=3@`0h>3P0;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c
0<K6aP2j^[X0ADE5020P802LW9`0TI6A059BDP1JFUX0QHF505iNGP1lO7`0ATI604A4A010@400:BTY
02DU9@0R8R809BDU01LG5`8051@D01005ADE01LG5`0H61P06a/K01XJ6P0M7Ad07QhN02l_;`1EEED0
?clo01hN7P0d=3@0PX:204m?C`21PH40K6a/0P1NGUh06P1FEUH0C4a<07]kN`1WIfL0BTY:04m?C`1Q
HF40Jf][04M7A`0V9RH092@T03Hf=P2=SHd0aLG505aLG01=CDd0C4a<06a/K02;Rh/0?Shn04A4A02?
Shl06a/K01TI6@0K6a/06ATI0`0L71`06@0O7al08B4Q0451@@2SXj<0G5aL0;:b/P2j^[X0_[jn05aL
G01/K6`0JFUY0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b07emO@1MGEd0<30`028R
8P0Y:BT00`0O7al05@0U9BD0CTi>05mOG`19BDT0K6a/08j>SP1JFUX0QHF507emO@0j>SX0=SHf0820
P01nOWh0F5QH051@D01BDU80C4a<04U9B@1fMWH0JVYZ03Ph>00203dm?@1104Y:BP1IFET0KVi^04=3
@`0Q8B407alO05eMG@1KFe/0Cdm?01lO7`0M7Ad0820P02PX:01LG5`0Fe]K0451@@0V9RH0>CTi09VI
V@2SXj<0YJFU09JFUP1oOgl0GEeM03hn?P0g=cL0;Rh^055AD@1dM7@0G5aL05IFEP2/[:`0alO708R8
R016ATH0@d=306YZJP2c/k<0Q8B40410@00o?cl0O7al0<G5a@2OWil0HF5Q07AdM02HV9P0LG5a06UY
J@0h>3P0ADE505iNGP1/K6`0SHf=08:2PP1nOWh0A4A40492@P0o?cl0M7Ad08V9R@26QXH0Hf=S0;bl
_025QHD00P0O7al0D01MGEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0=?Cd`30`<00SHf=07Mg
M`1hN7P0MGEe071`L00L71`06a/K01`L700P8200>c/k0861P@34a<@0SHf=07QhN02^[Zh0alO70=?C
d`39bLT0IVIV04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0]KFe08f=S@2][Jd0YZJV07in
OP1UIFD0BDU904e=C@1<C4`0TY:B0<K6aP1kNg/0OGem0:j^[P1cLg<0B4Q80492@P11@D40ADE504U9
B@1>CTh0C4a<04i>CP18B4P0?Shn059BDP2XZ:P0dM7A0=OGe`3Ph>00UYJF0;>c/`1eMGD0?3`l03dm
?@10@400EUIF07YjNP2<S8`0d=3@0=[JfP36a/H0OGem0P1TI6@02@11@D40>CTi0410@01GEeL0d=3@
0=SHf02a/K40X:2P07EeM@0Aooooo`003oooool0MP1VIVH0?clo04A4A01]KFd0FUYJ06m_K`0M7Ad0
;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD02h^;P0l?3`0:RXZ06i^KP0f=SH07AdM03dm?@0O7al0
5aLG04E5A@0d=3@0=CDe01LG5`0V9RH0E5AD04A4A01nOWh0QhN704m?C`0P8200Fe]K03Ti>@0d=3@0
8R8R04=3@`0S8b<0Cdm?05aLG00Q8B40:b/[03Lg=`1JFUX07QhN02<S8`18B4P0Jf][079bLP1@D500
>CTi04Q8B00P8200:b/[03/k>`0`<300<C4a03Hf=P1TI6@0?3`l06ATI02:RXX0;Bd]06a/K01<C4`0
61PH05EEE@1_Kfl0;2`/059BDP0k>c/0RXZ:04=3@`0n?Sh0HF5Q06IVIP0m?Cd0Cdm?07]kN`19BDT0
N7Qh0:n_[`1PH600@T9204=3@`0o?cl0@410055AD@1@D500?Cdm04I6AP1iNGT0DE5A05aLG02IVIT0
_Kfm061PH01HF5P0DU9B06YZJP12@T80L71`03Ti>@1QHF40PH6107=cL`1=CDd0HV9R06][J`1>CTh0
JVYZ051@D01cLg<0>3Ph04m?C`1kNg/204];B`2Z0451@@0W9bL0AdM706IVIP0i>CT0N7Qh02h^;P1>
CTh0DU9B03lo?`1BDU80CDe=06MWI`15ADD0^[Zj096AT@0i>CT0?clo05QHF01LG5`0K6a/09>CT`1E
EED0Ph>309jNWP1_Kfl0F5QH0:f][@2m_Kd0Hf=S0:BTY013@d<0De=C0:n_[`1YJFT0LG5a05mOG`0k
>c/0QHF509BDU00n?Sh0OGem09BDU00O7al09RHV04I6AP2SXj<0Rh^;059BDP28R8P0ATI603De=@1B
DU80QhN705EEE@2>SXh0TY:B05YJFP1XJ6P0SXj>04=3@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2Q
XJ40BDU905eMG@1cLg<0>c/k092@T015ADD0>CTi07EeM@1fMWH0?clo07moO`10@400K6a/06MWI`0f
=SH0B4Q80;^k^`2RXZ80GEeM06MWI`1VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`1I
FET0Fe]K04Y:BP15ADD0QhN705mOG`0i>CT0NGUi08f=S@1/K6`0@d=305]KF`2GUiL0Cdm?05EEE@1O
Gel0Lg=c05YJFP2ZZZX0G5aL05]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R05UIF@1n
OWh0OGem05]KF`0L71`0?Shn071`L01kNg/0IVIV059BDP2JVYX0BTY:0;no_`25QHD0EEEE07MgM`1l
O7`0JFUY03Hf=P1LG5`0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0H61P0861P@2n
_[h0PH6107IfMP0P8200>SXj03dm?@25QHD0Hf=S05EEE@1ZJVX0?Shn06QXJ01eMGDLooooo`0O04Q8
B014A4@0@41003<c<`0^;Rh0=3@d04i>CP23Ph<0De=C03lo?`0e=CD0>3Ph08:2PP1lO7`0Q8B40:>S
X`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX07IfMP1dM7@0@D5102l_;`0O7al071`L01LG
5`0201DE5@04018B4P0E5AD06a/K01`L70806QXJ00/07AdM01XJ6P0N7Qh0=cLg05QHF00S8b<0@D51
06MWI`1PH600DE5A01TI6@0201XJ6P0G024Q8@1PH600YjNW06e]K@1@D500FEUI05eMG@1/K6`0PH61
0:ZZZP27QhL0JFUY07emO@2m_Kd0WIfM07QhN01_Kfl0FEUI07QhN02WYjL0KFe]0<;2`P0R8R801@0L
71`0O@0M7Ad071`L02HV9P1FEUH0U9BD0:2PX036a/H0Y:BT0<;2`P2^[Zh0P82005eMG@1]KFd0Ogmo
08f=S@1XJ6P0CDe=04i>CP1TI6@0_;bl07inOP1_Kfl0JFUY07AdM01?Cdl0;2`/01dM7@0N7Qh07AdM
03Hf=P1_Kfl0G5aL03Xj>P11@D40ZZZZ07]kN`1:BTX0Hf=S0::RXP2VYZH0OGem06IVIP13@d<0A4A4
04I6AP0m?Cd0Hf=S08Z:RP13@d<0<S8b03Ti>@0o?cl0@T9206YZJP1_Kfl0IfMW03De=@0N7Qh0EeMG
05eMG@1CDe<07QhN01lO7`0P82008B4Q04];B`1:BTX0@410028R8P0[:b/0QXJ607QhN020P800M7Ad
06IVIP19BDT0=SHf038b<P0];Bd0?3`l05YJFP1/K6`0NWYj0<;2`P3>c/h0UiNG0;2`/02/[:`0cLg=
09nOW`0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08J6QP1QHF40820P01lO7`0T92@09RHV
02TY:@1?Cdl0GUiN08R8R01gMgL0JVYZ04i>CP2IVIT0Hf=S05QHF00_;bl0IfMW061PH00K6a/0IVIV
0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401L0e]KF07QhN019BDT0?3`l04i>CP1DE5@0EeMG
04E5A@0M7Ad071`L020P800Z:RX0PX:20:^[Z`26QXH0IfMW071`L037alL0dm?C0<C4a02:RXX0BTY:
04E5A@0204M7A`0X04e=C@1QHF40WYjN0=CDe03@d=00G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4
069RHP34a<@0d];B0<g=c@2BTY80NWYj06ATI01<C4`0@d=303lo?`10@400=cLg04E5A@1aLG40VIVI
0:ZZZP2l_;`0U9BD059BDP2CTi<0]kNg0=?Cd`3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L00h0
:2PX09RHV03Cdm<0]KFe0:^[Z`1:BTX0=SHf02TY:@0a<C40>c/k04M7A`2b/[80aLG5075aL@80Ogmo
4Oooool000oooooo00h0N7Qh06e]K@17AdL0M7Ad05UIF@1mOGd0@410034a<@1<C4`0@d=301dM7@19
BDT0?3`l07=cL`80=SHf04D07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@00j>SX0=CDe04=3
@`0Y:BT0G5aL05MGE`1ZJVX0NGUi04a<C00Y:BT0JFUY03Lg=`13@d<09RHV04U9B@0O7al0C4a<05iN
GP0Z:RX0=cLg04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05ADE00];Bd0<30`03Ph
>00b<S80?Shn04Y:BP1ZJVX0@T92065QH@1cLg<0>3Ph08R8R01cLg<07AdM05ADE020P8009bLW06UY
J@1<C4`0Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a<C40Ogmo09jNWP1JFUX00P19BDT0
2`0i>CT08b<S04Q8B020P800DE5A04Y:BP1bLW80?clo03<c<`1=CDd0LW9b0080E5AD06l0FUYJ04Y:
BP0o?cl0Lg=c04m?C`0l?3`0BDU905IFEP12@T80O7al09JFUP1?Cdl0HV9R04Y:BP23Ph<0Hf=S03hn
?P21PH40<c<c04m?C`23Ph<0B4Q805mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0NWYj06=S
H`10@4008b<S08J6QP2PX:00MWIf05EEE@1cLg<0=3@d03Lg=`2?Shl0EEEE075aL@34a<@0CDe=03Lg
=`1>CTh0Ph>306i^KP2QXJ40@T9203@d=01]KFd0IfMW06a/K01LG5`0A4A405=CD`26QXH0DE5A06EU
I@24Q8@0N7Qh071`L02@T900`L7108V9R@1:BTX0S8b<07QhN018B4P0Hf=S08Z:RP1<C4`0QhN70;>c
/`1bLW80L71`09ZJVP0n?Sh0IVIV06EUI@0R8R80Bd];07QhN00j>SX0UYJF06ATI01/K6`0NGUi03<c
<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`2GUiL0@T9206QXJ01cLg<0:2PX02/[:`2/[:`0Q8B405IF
EP27QhL0NGUi05YJFP0m?Cd00P1/K6`07P1OGel0>SXj05iNGP1/K6`0IVIV06e]K@1GEeL0G5aL09^K
V`2<S8`0Bd];07IfMP22PX80F5QH04Y:BP1SHf<0YZJV06i^KP1CDe<0KFe]06ATI01?Cdl0[Zj^09:B
TP1ZJVX0J6QX05]KF`1MGEd0IVIV07]kN`80B4Q802d0EeMG04A4A02EUID0SHf=07]kN`0Q8B40@T92
061PH01SHf<0N7Qh09BDU02ZZZX0B4Q80<;2`P1^KVh0;Bd]051@D01>CTh0JFUY03`l?01DE5@0GEeM
02l_;`1UIFD0OGem069RHP1bLW80XJ6Q059BDP2PX:00HF5Q08Z:RP37alL0V9RH07alO00Z:RX0>3Ph
0410@026QXH0NWYj05]KF`1fMWH0FEUI06UYJ@1ZJVX07?ooool07`0l?3`0>SXj03hn?P0o?cl0;Rh^
02TY:@0m?Cd0NGUi04U9B@0^;Rh0:RXZ079bLP1@D5007alO05IFEP1^KVh0[:b/0=WIf@3MgMd0dM7A
0:j^[P2ATI40Ogmo07QhN02JVYX0TY:B05mOG`0V9RH071`L01HF5P0G5aL0100E5AD05P0G5aL06ATI
01XJ6P0I6AT05aLG01XJ6P0N7Qh09bLW06MWI`0e=CD0Fe]K06][J`1iNGT0:BTY01HF5P0I6AT092@T
02l_;`1:BTX0<C4a02<S8`0[:b/202d];@0E0451@@1@D500KFe]04e=C@0K6a/0;Bd]0861P@2ZZZX0
Ti>C09BDU02>SXh0W9bL0;Vi^@2MWId0f][J06a/K01QHF40FEUI03/k>`0f=SH0:RXZ00809RHV00H0
:2PX02l_;`15ADD0VIVI0;no_`3:b/X20<g=c@0=0=OGe`2l_;`0Ti>C08F5Q@1/K6`0Fe]K08J6QP1i
NGT0N7Qh08:2PP2_[jl0NGUi08f=S@0208Z:RP0406EUI@0j>SX0?clo04i>CP80Hf=S00d0J6QX04A4
A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0/K6a07IfMP1RHV80>3Ph0080;bl_08D0QXJ608>3
P`0g=cL0=3@d034a<@14A4@0DU9B0:JVYP24Q8@0CTi>0861P@28R8P0Z:RX05]KF`22PX80;bl_028R
8P0P82007alO04U9B@1CDe<0G5aL028R8P1CDe<0DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05AD
E01EEED0@d=303`l?01CDe<0RXZ:0;6a/@25QHD0/k>c09ZJVP34a<@0bl_;0;Rh^01gMgL0DE5A07al
O01:BTX0E5AD08N7Q`1TI6@0De=C07QhN018B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MG
E`2:RXX0a/K60<30`02^[Zh0H61P06MWI`0Y:BT0MGEe09NGU`1WIfL0Jf][07moO`1eMGD0KVi^07mo
O`1^KVh0T92@09ZJVP2MWId0a/K603lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<07AdM02<S
8`0m?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1fMWH0UYJF06][J`18B4P0BDU904m?
C`1fMWH0^[Zj0<?3``2n_[h0SHf=075aL@1[Jf/0Rh^;07emO@2:RXX0`/;20;>c/`2^[Zh0N7Qh0;bl
_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;fm_@38b<P0/k>c0080SHf=01d0YJFU09NG
U`2/[:`0/k>c0;Jf]P3Bd]80b<S807]kN`0k>c/08b<S01`L700K6a/06ATI01lO7`1eMGD0Zj^[0;Ng
]`28R8P0<30`02/[:`0Z:RX0=3@d03Ph>019BDT0XJ6Q0;Jf]P1NGUh0O7al06i^KP0Aooooo`003ooo
ool0A`2CTi<0OWin04];B`27QhL0FUYJ092@T01VIVH0?Shn05=CD`1=CDd09bLW05]KF`15ADD0RHV9
0451@@1JFUX0;Rh^07AdM01TI6@0820P05=CD`13@d<08b<S034a<@0g=cL0BDU903/k>`0d=3@0EEEE
05ADE01ZJVX0P82003Xj>P0[:b/0IFEU03Xj>P1CDe<0:b/[04a<C00I6AT0ATI608b<S018B4P0=SHf
02/[:`1ADE40AdM702l_;`1;Bd/0KFe]04e=C@0[:b/0=CDe06UYJ@15ADD0<C4a04A4A00M7Ad0;2`/
03/k>`1HF5P0>CTi05MGE`1;Bd/08b<S05IFEP1MGEd07AdM04=3@`1HF5P06QXJ0080ADE503D0KFe]
01TI6@0_;bl0BTY:04e=C@10@400>SXj09VIV@1DE5@0LG5a09BDU013@d<0CTi>08:2PP2IVIT0?clo
03Hf=P17AdL0?Shn06e]K@2MWId0R8R808Z:RP2a/K40`/;203lo?`1>CTh0Rh^;05QHF00M7Ad0C4a<
08V9R@1CDe<0Fe]K0410@00O7al0ATI6075aL@1VIVH0?3`l024Q8@1EEED0OGem04Q8B024Q8@0;bl_
02XZ:P1JFUX0Bd];05mOG`1TI6@0>CTi071`L00206ATI02I05aLG00g=cL0OGem05IFEP1PH600FEUI
09:BTP2GUiL0M7Ad05aLG022PX80EEEE0451@@29RHT0=cLg061PH03;bl/0SXj>05YJFP1hN7P0Y:BT
08>3P`32`/80RXZ:05ADE01OGel0NGUi06MWI`1hN7P0PH6105mOG`24Q8@0GemO059BDP2<S8`0Shn?
08B4Q02a/K40_;bl07moO`0o?cl0WYjN07alO01;Bd/0PX:20:2PX00l?3`0Q8B409^KV`1ZJVX0Kfm_
09fMW@1=CDd0Ogmo06m_K`0X:2P0@T9207alO00o?cl0YjNW06EUI@1_Kfl0HF5Q03/k>`2CTi<0OGem
059BDP2=SHd0PH61028R8P1gMgL0:2PX07IfMP1nOWh0<c<c02TY:@2WYjL0LG5a04];B`1?Cdl0DU9B
04=3@`0h>3P0P82006ATI01KFe/0;Rh^03dm?@1GEeL0GEeM05=CD`0f=SH0EEEE08J6QP1cLg<0@410
075aL@23Ph<0?Cdm04E5A@1iNGT0QhN705iNGP1>CTh0G5aL05UIF@0k>c/0Jf][06IVIP1OGel0JFUY
03lo?`0m?Cd0@d=305YJFP14A4@0DU9B05QHF01;Bd/0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM7
0451@@19BDT0NWYj04U9B@2SXj<0J6QX03`l?01JFUX0De=C07moO`1>CTh0Bd];051@D00a<C40QXJ6
071`L01IFET0IfMW0:VYZ@1IFET0VYZJ05ADE01oOgl0[jn_09bLW022PX80=cLg0080>3Ph00L0IfMW
03/k>`1_Kfl0Ogmo05eMG@1KFe/0GemO01cooooo0280@d=303@d=00_;bl0>3Ph03Ti>@0S8b<0F5QH
05IFEP0g=cL092@T05QHF01:BTX061PH01/K6`1ADE40DU9B07QhN03>c/h0][Jf0:2PX02JVYX0WIfM
0:b/[039bLT0_[jn07emO@1[Jf/0;Rh^01XJ6P0E5AD05aLG01TI6@0K6a/05QHF0P0E5AD00`0L71`0
6QXJ01`L700201dM7@0o01hN7P0M7Ad0NGUi0:2PX02JVYX0V9RH0<?3``1YJFT071`L03Lg=`0m?Cd0
=cLg02l_;`0E5AD051@D01LG5`0O7al09bLW04];B`14A4@0<c<c04Y:BP0Q8B40EEEE06UYJ@1?Cdl0
JVYZ07MgM`1WIfL0P82008b<S01hN7P0f][J0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0
_kno0:6QX@1GEeL0`<300<[:bP3<c<`0]KFe0:FUY@2i^KT0f][J0=WIf@2i^KT0Y:BT0:JVYP1kNg/0
H61P02<S8`0T92@0H61P0;Fe]@2>SXh0R8R80080PX:201L0Shn?08:2PP1RHV80Ph>308^;R`2RXZ80
JVYZ05MGE`2o_kl0XZ:R09^KV`1JFUX0Ph>30;2`/02l_;`0/k>c08N7Q`1bLW80K6a/096AT@3?cll0
MWIf02/[:`0202l_;`0d03lo?`1ADE40Xj>S08Z:RP1;Bd/0?clo06a/K03?cll0SHf=07YjNP18B4P0
AdM704U9B@0o?cl0HV9R06i^KP2;Rh/0IFEU05IFEP1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00h>3P0:BTY05IFEP1hN7P0JVYZ07YjNP2WYjL0WinO09NGU`30`<00JFUY05eMG@2SXj<0
WIfM04=3@`0/;2`0GUiN07=cL`1ADE40Lg=c05iNGP0L71`07AdM028R8P809BDU0140<30`05iNGP18
B4P0Cdm?0;no_`1QHF40M7Ad06][J`2YZJT0Y:BT0=3@d02k^k/0b<S80::RXP1LG5`0C4a<05UIF@02
07UiN@1306][J`1RHV80@D510:^[Z`2VYZH0O7al06YZJP12@T80>c/k03@d=01/K6`0UYJF04m?C`0Z
:RX0J6QX05iNGP1_Kfl0LG5a04A4A02HV9P0_;bl0;^k^`18B4P0>c/k08F5Q@22PX80KFe]09fMW@2^
[Zh0/K6a07moO`1[Jf/0TY:B09JFUP2<S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08N7Q`1]
KFd0UiNG06e]K@1TI6@0H61P096AT@2k^k/0b<S80;no_`2BTY80Q8B408J6QP2FUYH0VYZJ0;^k^`3;
bl/0f=SH0<W9b@2LW9`0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0@01lO7`1VIVH0J6QX08b<S01^
KVh0;2`/02TY:@0X:2P0<C4a03Lg=`1=CDd0XZ:R0;Rh^01EEED0L71`04=3@a7ooooo000?ooooo`0;
05YJFP1DE5@0DU9B07QhN00f=SH0EeMG04Y:BP0k>c/0EEEE01`L700J6QX00P0k>c/0XP1GEeL08R8R
04i>CP0^;Rh0IVIV03De=@0A4A40BDU904A4A00V9RH0;bl_02LW9`0P8200;Rh^02d];@1IFET08B4Q
01hN7P1@D500Bd];03Hf=P0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P16ATH0@D51
0492@P0f=SH092@T05mOG`21PH40IVIV05MGE`0Q8B40Cdm?02XZ:P19BDT0N7Qh07=cL`0^;Rh0<c<c
04Y:BP0W9bL0Jf][09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b<S80CDe=03hn?P2<S8`0HV9R
03dm?@1SHf<0G5aL018B4P0W9bL0Cdm?079bLP2<S8`0alO7055AD@0U9BD0@T9205=CD`10@400?3`l
05ADE00d=3@0<c<c05ADE01nOWh0E5AD0;Fe]@39bLT0Kfm_03Lg=`1bLW80HV9R04i>CP1MGEd0Lg=c
055AD@1EEED0SXj>071`L01RHV80Lg=c06EUI@2<S8`0B4Q805EEE@2@T900BDU909NGU`1fMWH0AdM7
05iNGP1=CDd0Kfm_08f=S@1<C4`0NGUi05mOG`1`L700Ph>304I6AP1iNGT0IFEU08>3P`1TI6@0T92@
0861P@1FEUH0Fe]K0:ZZZP2=SHd0F5QH096AT@0e=CD0@T920<?3``1lO7`0?clo0820P02PX:00Fe]K
08F5Q@1YJFT0Hf=S0:NWY`1NGUh0AdM706i^KP1TI6@0LG5a0861P@1>CTh0LG5a0:BTY02:RXX0Rh^;
0<K6aP33`l<0R8R802TY:@1gMgL0Cdm?038b<P1TI6@0Ogmo059BDP80Lg=c04@0F5QH075aL@27QhL0
>c/k06][J`1GEeL0@d=307EeM@1GEeL0?3`l08J6QP1CDe<0M7Ad075aL@0d=3@0PX:204M7A`0i>CT0
JFUY08Z:RP1;Bd/0Jf][02TY:@18B4P0IFEU02d];@0[:b/0];Bd075aL@1XJ6P0IVIV05mOG`17AdL0
CDe=08>3P`1MGEd0Hf=S02h^;P12@T80GemO061PH01@D500CDe=04];B`20P800LW9b03<c<`1[Jf/0
M7Ad03Xj>P0n?Sh0DE5A08j>SP1PH600C4a<061PH01NGUh0@d=308J6QP25QHD0BDU90861P@1]KFd0
EeMG04Q8B01=CDd0Cdm?05IFEP80EEEE02/0IFEU07UiN@24Q8@08b<S03lo?`1UIFD0OWin05ADE01A
DE40RHV905UIF@2DU9@0NGUi04a<C01RHV80G5aL061PH010@400AdM705QHF00e=CD0MgMg05EEE@16
ATH0HF5Q09bLW01BDU80WYjN05aLG01@D500T92@09>CT`1FEUH0<30`03<c<`0g=cL0OGem075aL@16
ATH0JVYZ03@d=016ATH0D51@01cooooo03H0Ng]k07=cL`1cLg<0NGUi08R8R02EUID0[Zj^09^KV`2:
RXX0YZJV0;Rh^00Q8B40820P038b<P0M7Ad09bLW06UYJ@1mOGd0];Bd09BDU02NWYh0XZ:R09:BTP24
Q8@0]KFe09RHV02EUID0KFe]03Xj>P0R8R80820P02DU9@0b<S80820P01TI6@0D51@05ADE01/K6`0L
71`06a/K01lO7`0[:b/0F5QH0:^[Z`2g]kL0WYjN0:VYZ@1ZJVX0XZ:R07emO@12@T80>SXj051@D00L
71`301DE5@0:01@D500E5AD06a/K04];B`19BDT0BTY:08>3P`2HV9P0I6AT04a<C080@d=302h0Q8B4
0<O7a`2:RXX0RHV90820P018B4P0RXZ:07]kN`0n?Sh09BDU024Q8@0Z:RX0;Bd]05]KF`2LW9`0_kno
0;Rh^02j^[X0d=3@0;Ng]`2UYJD0]kNg0<71`@3Hf=P0clo?0<S8b011@D40820P051@D00X:2P071`L
028R8P2KVi/0]KFe07IfMP1TI6@0K6a/07EeM@2GUiL0Z:RX08N7Q`21PH40Ph>3079bLP2QXJ40bl_;
0P2PX:00I`2JVYX0Ogmo09BDU02QXJ40`<300=WIf@3:b/X0`/;209:BTP2?Shl0/K6a04M7A`0[:b/0
;Bd]038b<P11@D40Shn?079bLP1IFET0De=C04M7A`2LW9`0^;Rh06=SH`0U9BD07alO02LW9`12@T80
RXZ:0;bl_03De=@0Y:BT06ATI01jNWX0@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0Z:RX0
CTi>051@D014A4@0ADE506=SH`22PX80/K6a08Z:RP2e]KD0Jf][05UIF@1]KFd0/k>c07QhN01CDe<0
>c/k05IFEP1ADE40RHV905ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI60451@@2GUiL0
Kfm_08V9R@2IVIT0Z:RX08J6QP2[Zj/0a<C40=?Cd`2_[jl0JFUY06QXJ01HF5P0GEeM06MWI`1hN7P0
CTi>07YjNP2c/k<0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0^;Rh08b<S01aLG40
0`1ADE406P2i^KT0YZJV09nOW`0/;2`0:RXZ0451@@1OGel0PH61096AT@1SHf<0ADE503Xj>P1BDU80
LW9b0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/06EUI@22PX80Ogmo0P2;Rh/07@3H
f=P0c/k>0:f][@26QXH0QHF507moO`1eMGD0IfMW05MGE`0k>c/0?clo05eMG@2j^[X0aLG508J6QP1B
DU80JFUY06QXJ01mOGd0KVi^05]KF`0_;bl061PH01TI6@1QHF40IfMW0:FUY@1;Bd/0:RXZ0080;Rh^
00P0=cLg03De=@1mOGd0W9bL0<C4a01kNg/0FEUI03Ph>17ooooo000?ooooo`2a06YZJP11@D40?Cdm
075aL@19BDT0GEeM02<S8`0[:b/0Bd];05=CD`0Y:BT08b<S02`/;01YJFT0;Bd]034a<@0G5aL0F5QH
04Y:BP0K6a/0ADE502LW9`0G5aL0<30`0410@00V9RH051@D018B4P1GEeL0AdM70410@020P800@D51
01dM7@1IFET0<C4a03dm?@0?3`l0ATI603De=@14A4@0IfMW02DU9@0Z:RX0GEeM059BDP0N7Qh02`/;
024Q8@11@D40Hf=S06IVIP0W9bL0DE5A01<C4`0N7Qh0@D5104A4A00/;2`0@T9203dm?@0W9bL0=3@d
07AdM00n?Sh0I6AT06][J`0R8R80:2PX06UYJ@0j>SX0Cdm?03`l?01`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF01QHF40/;2`0861P@18B4P0G5aL04Y:BP0l?3`0@41005aLG01HF5P0C4a<
05iNGP2ATI40E5AD0;jn_P35aLD0OGem0492@P1ZJVX0I6AT05iNGP1WIfL0E5AD04i>CP1^KVh0TI6A
06a/K01YJFT0PH61061PH02@T900Cdm?051@D01]KFd0?Cdm096AT@1YJFT0CDe=065QH@0h>3P0CTi>
07YjNP19BDT0TY:B05ADE01MGEd0IFEU03hn?P1eMGD0A4A406MWI`1BDU80S8b<0;:b/P1OGel0?clo
071`L01mOGd0?clo08V9R@1UIFD0@4100<S8b029RHT0?clo065QH@1oOgl0KVi^07inOP1?Cdl0>c/k
08:2PP1_Kfl0CDe=065QH@0^;Rh0?clo06i^KP1;Bd/0=SHf0:NWY`1:BTX0ADE507inOP2LW9`0MGEe
04A4A021PH40Ph>304I6AP1UIFD0Rh^;05aLG01gMgL0LG5a0080Kfm_06l0W9bL0410@01EEED0D51@
02DU9@0h>3P0Hf=S03<c<`23Ph<0Lg=c05aLG02CTi<0=cLg075aL@1hN7P0EUIF075aL@2LW9`0EUIF
06MWI`1DE5@0CTi>07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06a/K01KFe/0IFEU05UIF@2BTY80Cdm?
07alO00o?cl0=SHf079bLP1]KFd0IVIV05iNGP1EEED0RHV907inOP10@400IVIV06][J`1NGUh0CDe=
05=CD`23Ph<0LW9b051@D01WIfL0J6QX03dm?@2?Shl0NGUi0492@P2PX:00NWYj06ATI01<C4`0D51@
05=CD`1iNGT0Lg=c059BDP1TI6@0MgMg06UYJ@0i>CT0GemO09bLW01jNWX0E5AD04a<C01lO7`0De=C
096AT@2?Shl0FEUI065QH@1HF5P0Hf=S03hn?P1RHV80Ph>303dm?@1fMWH0DU9B02HV9P17AdL0PX:2
05EEE@27QhL0Jf][04Y:BP1VIVH0M7Ad051@D00g=cL0BTY:04a<C020P800H61P04];B`1eMGD0<c<c
03lo?`1UIFD07?ooool0<@1YJFT0F5QH059BDP1CDe<0E5AD05aLG01iNGT0EeMG061PH021PH40[:b/
06MWI`0h>3P0<30`01@D501JFUX0Jf][05IFEP2OWil0Jf][04a<C01dM7@0QXJ607EeM@2=SHd0XZ:R
0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00S8b<06QXJ01DE5@0C4a<06ATI01/K6`0j>SX0GUiN
07]kN`1jNWX0OWin08j>SP1QHF40SHf=09:BTP1iNGT00P2ZZZX00`2KVi/0;Bd]01@D500501DE5@03
01LG5`0O7al0GEeM0080]KFe0100TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C023Ph<0ADE5
03Lg=`0/;2`0=SHf06QXJ01cLg<0?3`l0P0X:2P0d022PX80_kno09nOW`2QXJ40V9RH0=KFeP2b/[80
[jn_079bLP1_Kfl0Xj>S0;Jf]P2_[jl0>3Ph01`L700T92@0Fe]K01lO7`0L71`0GemO07=cL`0i>CT0
>SXj03hn?P19BDT0[Zj^0::RXP2ATI40RXZ:05ADE01iNGT0b/[:0<c<c02SXj<0MGEe07alO02j^[X0
[jn_0<G5a@3:b/X0d=3@09nOW`1BDU80@D5103lo?`1^KVh0Ti>C0410@00^;Rh0:b/[0410@02CTi<0
Lg=c04i>CP1fMWH0QHF506=SH`2e]KD0LG5a055AD@1`L700Kfm_06UYJ@2HV9P0fm_K09RHV02e]KD0
Q8B408Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^03`l?01EEED0BTY:02@T900S8b<0
?Shn059BDP2FUYH0[jn_06EUI@0i>CT0=CDe04a<C02][Jd0WYjN05]KF`1ZJVX0O7al09BDU01@D500
CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1EEED0IFEU0:NWY`2b/[80SXj>08b<S02CTi<0
ZZZZ0;Jf]P3:b/X0eMGE06m_K`1@D500CTi>06ATI01PH600LG5a08^;R`2EUID0YjNW08R8R02][Jd0
RHV906a/K01PH600JFUY0861P@2UYJD0N7Qh06m_K`2c/k<0fMWI0=CDe036a/H0^KVi0=3@d02m_Kd0
IFEU0:2PX00/;2`09RHV02h^;P0m?Cd0PH6105EEE@14A4@0?Shn04e=C@20P800IfMW05eMG@1[Jf/0
JVYZ08R8R02=SHd0X:2P05iNGP1[Jf/0HV9R05MGE`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0
J6QX04I6AP0f=SH0<c<c03Hf=P0d=3@0<c<c04i>CP27QhL0/;2`09VIV@27QhL0=CDe04a<C01BDU80
F5QH03Ti>@17AdL0FUYJ06=SH`22PX80JFUY07MgM`2/[:`0@41003De=@0b<S80;2`/02d];@0e=CD0
][Jf09JFUP1@D500De=C0;Fe]@2>SXhAooooo`003oooool09@1]KFd0PH6104];B`2<S8`0DU9B07Yj
NP1YJFT0;Bd]0451@@1YJFT0;bl_03Lg=`0e=CD0JVYZ0492@P1:BTX07alO03Lg=`1YJFT0<30`05QH
F00k>c/08b<S01hN7P0_;bl0;2`/03/k>`0P8200Fe]K05EEE@10@400S8b<04a<C00Y:BT0=cLg02HV
9P0f=SH00P0c<c<0DP0j>SX0?3`l07alO01BDU80<c<c06ATI010@400I6AT04a<C010@400EUIF071`
L01UIFD0<30`069RHP0d=3@0;2`/059BDP19BDT0;Rh^04a<C01ADE40GEeM04e=C@23Ph<0>CTi03@d
=02?Shl0B4Q802LW9`1WIfL0>SXj05YJFP1=CDd0PH6105=CD`0f=SH0IfMW06m_K`13@d<092@T05mO
G`1hN7P0JFUY0<71`@1oOgl0@T9206QXJ01jNWX0B4Q803lo?`1_Kfl0JFUY05=CD`1WIfL0SHf=03lo
?`2`/;00Z:RX07]kN`0i>CT0M7Ad05EEE@0o?cl0G5aL08N7Q`1?Cdl0DE5A065QH@12@T80DE5A08B4
Q01QHF40IVIV03Hf=P1@D500Rh^;0410@027QhL0D51@0410@01TI6@205YJFP1C06YZJP12@T80MGEe
08^;R`1DE5@0EeMG03/k>`1dM7@0Bd];05mOG`1FEUH0DE5A09JFUP1ZJVX0C4a<08B4Q01fMWH0B4Q8
09NGU`1;Bd/0=cLg0:BTY02CTi<0Kfm_06YZJP1oOgl0R8R808J6QP1nOWh0BTY:07moO`1`L700Cdm?
06e]K@2:RXX0GemO07emO@1/K6`0?Shn09RHV02>SXh0LW9b0;Jf]P31`L40QHF504M7A`1fMWH0Rh^;
04i>CP1VIVH0QXJ606=SH`1aLG40TY:B08Z:RP1/K6`0X:2P05MGE`1ZJVX0MWIf03Lg=`1=CDd0MgMg
03Xj>P1kNg/0MWIf05QHF01hN7P0=SHf06e]K@1QHF40DE5A06][J`2;Rh/0@D5106YZJP1SHf<0A4A4
071`L00e=CD0:2PX09BDU01nOWh00P26QXH0DP1]KFd0IVIV03<c<`1cLg<0H61P08b<S019BDT0=CDe
06IVIP1DE5@0Jf][05MGE`1KFe/0Y:BT08:2PP15ADD0KVi^071`L01TI6@0A4A404a<C01nOWh0IFEU
04=3@`1SHf<0MgMg04Y:BP2<S8`0OWin04E5A@2@T900Jf][05ADE01BDU80EEEE04I6AP1EEED0Fe]K
051@D01VIVH0MgMg075aL@0d=3@0>3Ph061PH01RHV80Bd];05]KF`1dM7@0?Cdm04Q8B022PX80?Shn
05]KF`1UIFD0EEEE03<c<`0n?Sh0J6QX02<S8`1TI6@0FUYJ03dm?@1CDe<0Lg=c0410@01lO7`0MWIf
059BDP1gMgL0Lg=c03Xj>P0R8R80;2`/03hn?P1iNGT0K6a/0451@@22PX80<c<c03/k>`1mOGdLoooo
o`0=05ADE01?Cdl0DE5A05YJFP1>CTh0PH6106EUI@1VIVH0ATI603lo?`16ATH0FEUI06QXJ00205UI
F@0@06QXJ012@T80GEeM05aLG00];Bd0;2`/02HV9P0Y:BT0?Cdm08:2PP2TY:@0WinO0:>SX`1oOgl0
JVYZ06m_K`80Jf][01P0HF5Q04i>CP16ATH0@41004i>CP1JFUX0IVIV05eMG@1BDU80E5AD05UIF@2F
UYH0YJFU09fMW@33`l<0RXZ:075aL@2k^k/0PX:201/K6`0D51@04Q8B01<C4`0E5AD401HF5P1U01/K
6`1SHf<0AdM707alO02JVYX0WYjN0861P@1_Kfl0KVi^07IfMP1eMGD0=3@d028R8P0V9RH0;2`/030`
<00_;bl0>CTi055AD@2JVYX0bLW90:b/[02PX:00Shn?07EeM@2GUiL0Z:RX08N7Q`1eMGD0HV9R059B
DP1ADE40Ph>308R8R01fMWH0<C4a01dM7@0m?Cd0B4Q801`L700a<C40KFe]05EEE@15ADD0>c/k03Ti
>@2>SXh0Shn?07=cL`1aLG40O7al07=cL`2;Rh/0HF5Q04A4A00h>3P0=3@d03<c<`1SHf<0T92@0:FU
Y@2/[:`0K6a/06=SH`19BDT0=SHf03Lg=`1TI6@0Z:RX07AdM01GEeL0RHV90<[:bP2n_[h0SXj>09NG
U`2BTY80KFe]09BDU02EUID0HV9R05IFEP1iNGT0VYZJ06m_K`1ZJVX0S8b<08>3P`2?Shl0IFEU04U9
B@1CDe<0IFEU06QXJ011@D408R8R01`L700d=3@0De=C03Hf=P0P82000P0N7Qh0BP0e=CD0BTY:0861
P@1`L700?3`l01dM7@0P8200;2`/03dm?@1/K6`0L71`0410@01SHf<0HV9R04i>CP1LG5`0EEEE065Q
H@0j>SX0?Cdm04I6AP1ADE40De=C055AD@1SHf<0NGUi0:b/[03Fe]H0dm?C0<O7a`39bLT0[jn_08B4
Q02o_kl0C4a<02/[:`0Z:RX0=3@d061PH02<S8`0Vi^K06IVIP1MGEd0De=C08F5Q@2TY:@0EeMG05QH
F01SHf<0Lg=c09FEU@23Ph<0U9BD0=7Ad@3@d=00`/;20:n_[`2l_;`0dm?C0<?3``2YZJT0e]KF09>C
T`1?Cdl0@41004m?C`1iNGT0Ogmo071`L01VIVH0OGem07inOP2<S8`0I6AT0P1UIFD03@2ATI40V9RH
061PH01;Bd/0K6a/05IFEP0o?cl0A4A405=CD`1lO7`0`l?30;^k^`1WIfL00P0];Bd08`0Y:BT0<30`
0451@@0l?3`0>CTi05=CD`1]KFd0SHf=0::RXP1eMGD0@T92051@D01IFET0ATI603lo?`0m?Cd0=cLg
03Xj>P0l?3`0F5QH07MgM`1nOWh0TY:B034a<@0Z:RX09bLW02PX:00f=SH0UIFE09fMW@2BTY80GemO
075aL@1bLW80JFUY017ooooo000?ooooo`1906i^KP27QhL0DE5A0;Vi^@1LG5`0PH6107EeM@0g=cL0
FEUI04m?C`0_;bl0AdM70492@P1fMWH0?Shn05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300
;bl_02PX:00[:b/0@T9202/[:`1]KFd0EeMG02/[:`29RHT0M7Ad03/k>`1:BTX0:b/[03Xj>P17AdL0
;bl_03De=@0M7Ad0LG5a06QXJ00e=CD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0
I6AT04M7A`0g=cL0KVi^05iNGP11@D40BTY:04E5A@0g=cL0Cdm?07UiN@15ADD0:2PX092@T012@T80
<C4a07moO`1RHV80?3`l04M7A`0207=cL`0K03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1QHF40
/k>c06YZJP0m?Cd0AdM705EEE@1ADE40Bd];079bLP17AdL0=SHf04U9B@2ATI40EeMG0<C4a02][Jd0
W9bL04Y:BP1bLW80GEeM0080GemO0;X0R8R805EEE@1<C4`0LG5a0861P@1;Bd/0KVi^06=SH`1/K6`0
FEUI04a<C026QXH0A4A406ATI01nOWh0ADE505=CD`1XJ6P0E5AD05aLG014A4@0LW9b08^;R`1<C4`0
Kfm_0492@P1dM7@0?3`l06MWI`1lO7`0A4A409BDU01ADE40B4Q807YjNP1OGel0B4Q808^;R`0n?Sh0
;Bd]092@T02CTi<0GEeM075aL@25QHD0I6AT09NGU`2ATI40AdM706QXJ01jNWX0FUYJ096AT@24Q8@0
E5AD07YjNP1SHf<0D51@0:2PX02@T900LG5a0:NWY`3<c<`0O7al03hn?P1lO7`0RXZ:04Y:BP1RHV80
Rh^;05=CD`1>CTh0OWin07moO`1DE5@0UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0
IfMW05]KF`1aLG40;Rh^059BDP22PX80EEEE06MWI`1nOWh0Bd];051@D01UIFD0>SXj07EeM@15ADD0
8b<S06m_K`1ADE40SXj>06YZJP1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1NGUh0
IVIV04i>CP1ZJVX0^;Rh07emO@0j>SX0Kfm_05eMG@17AdL0?clo05YJFP24Q8@0NGUi04U9B@1IFET0
KVi^02HV9P1FEUH0M7Ad03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH05iNGP1CDe<0
Lg=c08N7Q`15ADD0>CTi07alO01mOGd0I6AT04=3@`1VIVH0@T9202LW9`1hN7P0HF5Q061PH01]KFd0
K6a/03@d=01CDe<0TY:B059BDP1DE5@0I6AT03<c<`16ATH0P82005aLG023Ph<0KVi^061PH02KVi/0
U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b04a<C029RHT0BDU9030`<01/K6`Looooo`1904Y:BP13
@d<0@D510410@01^KVh0SXj>061PH015ADD0<S8b02<S8`0Y:BT0:RXZ01lO7`0X:2P0V9RH04Q8B011
@D40Shn?03Ti>@0M7Ad08R8R04i>CP0k>c/09bLW05UIF@1LG5`0NWYj071`L01<C4`0De=C06m_K`1g
MgL0EeMG06][J`2=SHd0W9bL09FEU@21PH40Lg=c07]kN`1eMGD0H61P06MWI`1gMgL0`l?309RHV01V
IVH0_[jn06ATI01@D500CTi>07AdM00U9BD0820P01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I
6AT0Cdm?030`<01:BTX0EEEE07UiN@2n_[h0clo?09^KV`1gMgL0>c/k01hN7P0201dM7@0X01hN7P0M
7Ad07QhN028R8P0[:b/0[Zj^08b<S02FUYH0_[jn06MWI`22PX80F5QH02HV9P0g=cL0;bl_0492@P1N
GUh0Cdm?04i>CP1/K6`0Q8B406YZJP0S8b<061PH04e=C@0/;2`06a/K06YZJP0k>c/0B4Q804i>CP1k
Ng/0Z:RX05MGE`17AdL0@41007emO@1fMWH0?Cdm02@T9080:BTY02`08R8R02<S8`0R8R80EUIF08:2
PP2f][H0O7al07YjNP2XZ:P0/K6a08j>SP1YJFT0EeMG0;2`/036a/H0`l?308b<S02TY:@0cLg=0:VY
Z@31`L40`l?30<71`@2WYjL0R8R80;>c/`1nOWh0LG5a06EUI@1RHV80JVYZ0:JVYP2ZZZX0WinO0:VY
Z@2i^KT0^;Rh0;bl_02<S8`0G5aL07alO01fMWH0<c<c01hN7P8071`L05<07QhN03Ti>@1=CDd0RXZ:
06EUI@16ATH092@T02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0BTY:04];B`1kNg/0]KFe
04Y:BP1KFe/0E5AD03lo?`0/;2`09bLW02XZ:P0o?cl0XJ6Q0=_Kf`3Cdm<0bLW90;Rh^028R8P0Y:BT
0;no_`2[Zj/0RXZ:08j>SP2_[jl0bl_;0=[JfP1^KVh0:BTY069RHP0n?Sh0Ogmo0861P@0Z:RX0:BTY
038b<P1KFe/0WinO0;2`/03<c<`0bLW90:n_[`2VYZH0HF5Q06ATI02:RXX0b/[:0<k>cP3?cll0Kfm_
04U9B@11@D40?3`l05YJFP27QhL0OGem05iNGP1<C4`0@d=306e]K@2SXj<0TY:B07QhN02=SHd0?3`l
03Ti>@14A4@0GUiN06e]K@0204I6AP0Z04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0AdM7
05UIF@1RHV80RXZ:0:n_[`2WYjL0`l?305=CD`10@400;bl_02HV9P1ADE4092@T03lo?`1FEUH0UIFE
05MGE`0d=3@0=CDe06i^KP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`1^KVh0>CTi
03Lg=`0j>SX0ATI64Oooool000oooooo05D0FUYJ05EEE@18B4P0Ng]k04Q8B01OGel0@410020P800d
=3@0@d=3024Q8@0T92@0820P06][J`0a<C40CDe=01dM7@0W9bL0H61P024Q8@0j>SX0=3@d01DE5@0V
9RH0;bl_01`L700_;bl05QHF03lo?`1ADE40:BTY06IVIP1/K6`07QhN03/k>`0W9bL0:RXZ024Q8@0P
8200>c/k024Q8@1aLG40De=C01dM7@15ADD0;Bd]05YJFP10@400>SXj0492@P1XJ6P0I6AT03Hf=P1Y
JFT0?Cdm01lO7`16ATH0FEUI0492@P1CDe<0CTi>05QHF00o?cl0Ng]k04M7A`0Y:BT0KFe]04I6AP0J
6QX0Hf=S06EUI@0e=CD0E5AD06MWI`1nOWh0?Shn05EEE@1mOGd0I6AT02XZ:P17AdL0M7Ad059BDP2?
Shl0L71`0080DE5A0</0CTi>05ADE013@d<0NGUi05YJFP17AdL0EEEE09bLW01MGEd0aLG50;Jf]P2M
WId0DE5A071`L01LG5`0KFe]05YJFP1RHV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0E5AD06a/K01W
IfL0D51@06][J`14A4@0CDe=07MgM`1:BTX0CTi>05]KF`1PH600LG5a04U9B@1bLW80O7al04I6AP23
Ph<0?Cdm06e]K@19BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01?Cdl0SXj>05QHF00`
<300NGUi08j>SP1oOgl0GemO06YZJP20P800Ti>C08Z:RP0m?Cd0Cdm?071`L00m?Cd0HF5Q06a/K01>
CTh0KVi^04Q8B01FEUH0WYjN08F5Q@1IFET0TI6A0<G5a@24Q8@0B4Q806][J`2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj05mOG`2j^[X0KVi^05ADE01FEUH0=CDe038b<P1SHf<0?Cdm06IVIP1X
J6P0CTi>079bLP12@T80Cdm?08^;R`1NGUh0J6QX09ZJVP1hN7P0I6AT071`L00i>CT0RXZ:06QXJ00]
;Bd0OWin06IVIP2XZ:P0KVi^06MWI`28R8P0>SXj05ADE01JFUX0U9BD06EUI@0^;Rh0N7Qh06a/K02?
Shl0C4a<04E5A@2?Shl0RXZ:04];B`25QHD0QXJ607alO01@D500>SXj06IVIP1eMGD0Cdm?096AT@2D
U9@0BDU905MGE`1mOGd0@T92096AT@2@T900DU9B04I6AP0k>c/0;bl_069RHP1]KFd0G5aL04a<C01g
MgL0Cdm?02l_;`0m?Cd0PH6107inOP1GEeL0A4A4061PH00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_
Kfl0:b/[02l_;`1ZJVX0ADE504Q8B01LG5`0>c/k04E5A@1/K6`0EUIF07inOP2:RXX0EEEE09:BTP2D
U9@0Cdm?0492@P1=CDd0AdM707YjNP1cLg<0:2PX0:>SX`1JFUX0;bl_08j>SP0Looooo`0907inOP1Q
HF40D51@05EEE@1eMGD0SXj>05IFEP0a<C409BDU0080820P0180<c<c02PX:00M7Ad0O7al07]kN`1d
M7@0bLW903/k>`0N7Qh07alO02HV9P12@T80J6QX07EeM@1=CDd0JVYZ0:RXZ01GEeL202`/;00:03Ph
>01MGEd0Hf=S04a<C01`L700UiNG051@D01?Cdl0BDU90451@@80Cdm?01l0CDe=07YjNP2IVIT0P820
0=3@d02PX:00EUIF04I6AP1GEeL0BDU902@T900M7Ad06QXJ01`L700N7Qh06a/K01`L700K6a/05aLG
03Lg=`1nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`0L71`07AdM00<071`L0P0M7Ad0
;01BDU80Ti>C04Y:BP2=SHd0UIFE07emO@1YJFT0:2PX01hN7P0Q8B40;bl_02PX:01DE5@0De=C051@
D01GEeL0MWIf07UiN@1LG5`06a/K03Lg=`1>CTh08B4Q09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>C
T`1YJFT0De=C08V9R@16ATH092@T020P800S8b<07alO01`L700M7Ad07alO04U9B@1]KFd0^KVi0P3;
bl/0302a/K40QHF505eMG@1jNWX0KFe]0<k>cP2i^KT0Jf][07emO@28R8P0/;2`0<C4a080_kno01D0
Y:BT09nOW`3>c/h0emOG04e=C@0g=cL09BDU01lO7`1?Cdl0W9bL0:6QX@31`L40`/;20:ZZZP1mOGd0
P82008R8R02g]kL0fm_K07UiN@0P82000P0L71`201dM7@0c030`<01KFe/0PX:205YJFP2OWil0E5AD
0492@P11@D40A4A404a<C01QHF40TI6A05]KF`1RHV80IVIV0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R024Q8@0W9bL0EeMG0<g=c@2^[Zh0WYjN0;Rh^01PH600NWYj0<[:bP2MWId0GUiN
05MGE`1;Bd/0J6QX0<K6aP1lO7`092@T05]KF`12@T80QhN707inOP0Y:BT09bLW038b<P1dM7@0>3Ph
0080KVi^04T0WinO0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40AdM704Q8B01OGel0IFEU
08>3P`2<S8`0GemO02/[:`0m?Cd0>CTi05IFEP1aLG40XJ6Q0;Zj^P21PH40:BTY030`<013@d<0GemO
09:BTP1BDU80BDU904];B`1RHV80alO70;Jf]P2k^k/0XZ:R08>3P`1kNg/0QXJ609>CT`2ATI40W9bL
0;Ng]`33`l<0VIVI04M7A`15ADD0<c<c01lO7`0V9RH0?3`l03dm?@1=CDd0clo?08V9R@18B4P0;Bd]
07QhN02ATI40]KFe07EeM@1mOGd0Ph>308Z:RP39bLT0ZJVY0:ZZZP0j>SX0>3Ph04=3@`14A4@0F5QH
017ooooo000?ooooo`3B05eMG@25QHD0C4a<08j>SP1KFe/0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0
:RXZ038b<P1EEED0?clo05=CD`0Y:BT07alO05EEE@0c<c<0=cLg04Y:BP0[:b/08B4Q02PX:00O7al0
@d=303De=@17AdL0BDU903Lg=`1QHF40KFe]02DU9@0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80
Fe]K075aL@0^;Rh0Bd];02l_;`1WIfL0MGEe04m?C`1EEED0Ng]k07emO@18B4P0CTi>051@D00U9BD0
Cdm?04I6AP12@T80EeMG04];B`1TI6@0ATI607=cL`1:BTX0=3@d04U9B@1GEeL0820P071`L01fMWH0
;bl_069RHP1MGEd0OGem03Lg=`1GEeL0P82005]KF`0X:2P0ATI606YZJP12@T80Lg=c07YjNP1LG5`0
DU9B04];B`1DE5@0?Shn08:2PP1kNg/0Bd];05YJFP2;Rh/0D51@0:ZZZP2m_Kd0Y:BT04m?C`1`L700
EEEE06MWI`1DE5@0LG5a04Y:BP1BDU80I6AT06e]K@10@400J6QX05UIF@1bLW80H61P04a<C01YJFT0
?clo06][J`24Q8@0Bd];055AD@1>CTh0A4A405aLG016ATH0De=C08b<S018B4P0R8R8051@D01_Kfl0
?Shn05YJFP1nOWh0?clo09VIV@1cLg<0>c/k059BDP1ZJVX0@T9207UiN@1mOGd0?Shn079bLP2JVYX0
Ph>307emO@1oOgl0MGEe0:FUY@29RHT0=cLg059BDP21PH40Bd];075aL@2:RXX0F5QH08N7Q`2>SXh0
CDe=0:ZZZP1hN7P0Fe]K08:2PP39bLT0SXj>05IFEP1YJFT0MGEe03Ph>01TI6@0WinO08B4Q01NGUh0
Zj^[0861P@15ADD0X:2P06m_K`1<C4`0KFe]03Ti>@18B4P0QXJ605MGE`1WIfL0HF5Q06MWI`26QXH0
@41004U9B@1kNg/0=CDe05]KF`1oOgl0Kfm_07=cL`2DU9@0@T92065QH@14A4@0;Rh^05UIF@1YJFT0
TI6A06MWI`1_Kfl0Ogmo0P0];Bd0CP0d=3@0KVi^065QH@0/;2`0IfMW04Y:BP1BDU80Cdm?0492@P2G
UiL0Lg=c03De=@19BDT0De=C065QH@1ADE40?Cdm06YZJP1aLG40=3@d04E5A@1^KVh0BTY:05=CD`2;
Rh/0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0EUIF06ATI02QXJ40PX:205=CD`0S
8b<0GemO07=cL`1;Bd/0I6AT08^;R`1DE5@0>c/k06][J`1JFUX0CTi>05YJFP1VIVH0Bd];03De=@1k
Ng/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MGE`1hN7P0HF5Q07moO`2?Shl0@410034a<@14
A4@0O7al08^;R`1ZJVX0:RXZ0;Zj^P19BDT0;Bd]08N7Qacooooo03D0A4A40410@00h>3P0;Rh^0410
@01NGUh0F5QH02d];@0Z:RX08b<S024Q8@0];Bd0<C4a02PX:023Ph<0/[:b0;Zj^P2ZZZX0RHV902l_
;`0P82009BDU02XZ:P0Y:BT0MgMg04M7A`1nOWh0^KVi09>CT`1jNWX0=SHf02l_;`0S8b<0Fe]K075a
L@1>CTh0X:2P07IfMP1kNg/0N7Qh075aL@14A4@0;Rh^02`/;01>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf
]P2@T900Hf=S065QH@0202LW9`0401`L700J6QX06a/K01/K6`8071`L02406ATI02l_;`1XJ6P0_kno
09:BTP2ATI40UiNG0<k>cP2j^[X0G5aL02`/;00L71`07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF5
05=CD`14A4@0Lg=c08J6QP2NWYh0?Cdm01lO7`0L71`07AdM02PX:00U9BD0<c<c065QH@1CDe<00P1<
C4`0@01MGEd0MWIf05EEE@1WIfL0VIVI069RHP1UIFD0O7al08j>SP2PX:00OGem05EEE@1RHV80N7Qh
096AT@2a/K40I6AT03Lg=`0Z:RX08B4Q01XJ6P0L71`07QhN02DU9@1VIVH0W9bL09ZJVP1gMgL0[Zj^
0:VYZ@2ZZZX0/K6a0;Bd]02l_;`0e]KF0;fm_@20P800MgMg07YjNP2KVi/0^k^k0<W9b@2f][H0Zj^[
0:2PX027QhL0TI6A07inOP0b<S80<C4a05IFEP1?Cdl0@d=308F5Q@1;Bd/0O7al04M7A`13@d<0?clo
0410@01/K6`0d];B07UiN@0K6a/401dM7@0G02PX:01YJFT0Jf][051@D01WIfL0=CDe02`/;00U9BD0
8R8R02@T900Q8B40Jf][08:2PP1aLG40MWIf09fMW@1`L700Lg=c04=3@`0n?Sh09BDU024Q8@0M7Ad0
0P0N7Qh01@0Q8B40I6AT0;jn_P1/K6`0M7Ad0080H61P00<0TI6A0<k>cP1NGUh00`0V9RH0=P0k>c/0
SXj>09ZJVP0`<300CTi>04=3@`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1^KVh0
J6QX04A4A019BDT0M7Ad0;6a/@3Shn<0dm?C06m_K`0j>SX0?Cdm04=3@`1QHF40Ti>C07]kN`0n?Sh0
9BDU03<c<`0i>CT0Fe]K08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:>SX`2ATI40
QHF50:RXZ03?cll0_;bl0;fm_@1KFe/0BDU9055AD@80EEEE0200DE5A075aL@2QXJ40a/K60:b/[00e
=CD0;Bd]02HV9P0L71`07alO02PX:019BDT0BTY:0;fm_@1=CDd0G5aL051@D027QhL0UiNG04=3@`10
@400FEUI07alO02o_kl0`l?30;Rh^01>CTh0=SHf03hn?P12@T80Jf][0:b/[17ooooo000?ooooo`0C
05IFEP2EUID0C4a<09nOW`1MGEd0LW9b09JFUP0l?3`0?Cdm06UYJ@0j>SX0:b/[04M7A`1RHV80D51@
059BDP0l?3`092@T05YJFP0203@d=00M03`l?00a<C40<C4a02`/;00P8200=CDe030`<01;Bd/0D51@
03Ti>@1CDe<0Kfm_02XZ:P0_;bl0:b/[028R8P16ATH07alO04e=C@0Y:BT0E5AD07UiN@0_;bl0CDe=
038b<P1DE5@0IFEU04E5A@1ADE400P1bLW80J`11@D40CTi>04M7A`0R8R80ADE504e=C@10@400DE5A
05MGE`1UIFD0AdM707UiN@1<C4`0=cLg03Ph>01OGel07QhN071`L021PH40<30`061PH013@d<0Ph>3
04I6AP1VIVH0WIfM06YZJP0b<S80ATI6065QH@0o?cl0E5AD08R8R01IFET0DU9B04Q8B010@400<c<c
05mOG`1VIVH0ADE505iNGP1gMgL0>3Ph08>3P`2KVi/0WIfM04Y:BP1UIFD0H61P06][J`1;Bd/0MgMg
05IFEP1=CDd0JFUY08F5Q@0f=SH0H61P06ATI01ZJVX0L71`04=3@`1YJFT0GEeM04=3@`2>SXh0Bd];
04Y:BP22PX80D51@05mOG`0k>c/0F5QH09RHV01=CDd0Kfm_03Ph>01gMgL0A4A405EEE@21PH40A4A4
09FEU@1fMWH0D51@05EEE@2<S8`0Bd];08Z:RP1gMgL0?clo06e]K@28R8P0?Shn05=CD`1HF5P0J6QX
0<W9b@2TY:@0@41005aLG02:RXX0CTi>07emO@1RHV80ATI60080R8R803P0CTi>0;bl_01MGEd0?3`l
05EEE@2i^KT0SXj>05=CD`1oOgl0RXZ:05EEE@1[Jf/0YjNW06QXJ01QHF40Shn?08J6QP1iNGT0bl_;
075aL@1UIFD0PX:203hn?P0X:2P0L71`055AD@1XJ6P0KFe]04Q8B01PH600<C4a05YJFP2:RXX0FEUI
05]KF`2<S8`0ADE504=3@`1eMGD0>CTi06e]K@1@D500820P05IFEP1:BTX0VYZJ06EUI@23Ph<0L71`
04M7A`0j>SX0D51@07]kN`1>CTh0CDe=07IfMP80FUYJ04L0E5AD04=3@`2OWil0PH6104a<C01UIFD0
IfMW061PH015ADD0BDU907QhN029RHT0BDU905QHF01dM7@0>c/k05mOG`2;Rh/0Cdm?0820P01TI6@0
?Cdm04Y:BP1OGel0Hf=S04i>CP1HF5P0B4Q803Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600
@D5106UYJ@1IFET0Bd];06ATI020P800De=C06QXJ01/K6`0B4Q803`l?01[Jf/0EeMG03Xj>P1cLg<0
HV9R04E5A@1_Kfl0IVIV06i^KP27QhL0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MWI`1QHF40
;bl_0<30`024Q8@0=cLg07QhN00Looooo`0l03@d=00];Bd0:BTY02HV9P0Q8B40BDU907=cL`1FEUH0
ADE503lo?`10@400CDe=04];B`0_;bl0TI6A0:JVYP20P800>c/k061PH02EUID0DU9B030`<00f=SH0
>CTi05ADE01ZJVX0UIFE08B4Q02LW9`0PX:204i>CP1<C4`0GEeM08F5Q@2^[Zh0UIFE0<30`02/[:`0
SHf=07]kN`1bLW80MGEe06IVIP1jNWX0aLG509BDU02KVi/0SHf=05aLG029RHT0VIVI0:NWY`2>SXh0
KVi^02l_;`0W9bL071`L01lO7`0L71`06a/K0P0L71`0300d=3@0QXJ60;bl_02NWYh0Ph>309nOW`2g
]kL0WYjN06i^KP1LG5`0?Cdm01lO7`807AdM00X06QXJ01/K6`0b<S80MgMg04M7A`1QHF40[:b/0:NW
Y`1[Jf/0;Rh^0`0M7Ad202/[:`1@02PX:015ADD0VYZJ06][J`1/K6`0OWin0:NWY`1nOWh0Cdm?04e=
C@2/[:`0EEEE06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0WYjN08V9R@21PH40IFEU0410
@00Z:RX0820P02HV9P0U9BD0SXj>08J6QP1LG5`0DE5A09nOW`3@d=00_;bl0:n_[`2QXJ40_;bl0<o?
c`2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2GUiL0Kfm_08>3P`2l_;`0W9bL05EE
E@0X:2P071`L01lO7`1eMGD0@D51051@D01JFUX092@T02LW9`0S8b<0:2PX08f=S@2JVYX07AdM01XJ
6P0L71`06a/K01`L700c<c<0MgMg08J6QP1DE5@0F5QH02@T900Q8B4201dM7@1e01lO7`1;Bd/0W9bL
0;fm_@2i^KT0QHF506QXJ01?Cdl0PH6107IfMP0f=SH0820P01`L700M7Ad071`L01dM7@0V9RH0PH61
0;no_`1EEED0HV9R02`/;00W9bL0@D5108B4Q01@D5007QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL
04A4A015ADD0?3`l06YZJP0`<300BTY:065QH@0a<C40PX:209FEU@33`l<0QhN709JFUP11@D409BDU
02l_;`14A4@0^;Rh0<K6aP1oOgl0<c<c03@d=010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@410
05EEE@22PX80]kNg06i^KP1ZJVX0LG5a03De=@0[:b/0Bd];0<O7a`3Bd]80V9RH0:VYZ@3:b/X0c/k>
0:j^[P38b<P0ZJVY07moO`2BTY80VIVI0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C00Z:RX09RHV
020P800Q8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;Jf]P1hN7P0Lg=c02LW9`0a<C40EEEE
0<?3``2/[:`0^;Rh05YJFP11@D40?clo075aL@2_[jl0Ogmo017ooooo000?ooooo`1g065QH@2RXZ80
Bd];09NGU`1=CDd0KFe]07alO00j>SX0>CTi04m?C`0b<S80?Shn04m?C`1GEeL0EUIF04M7A`11@D40
71`L05mOG`17AdL0;2`/04Q8B00_;bl0;Bd]03De=@0P82009bLW02DU9@16ATH0EeMG03Ti>@1DE5@0
QhN702@T900_;bl09RHV02TY:@1@D5008B4Q059BDP0/;2`0EeMG0:ZZZP0f=SH0CTi>02h^;P1HF5P0
IfMW04I6AP1KFe/0Jf][05=CD`0l?3`0F5QH06MWI`0d=3@0?Shn05aLG00[:b/0?clo06IVIP1ZJVX0
BTY:08R8R00f=SH0>CTi04A4A01NGUh07QhN065QH@1OGel0=3@d06QXJ00g=cL0MgMg030`<012@T80
RXZ:06i^KP0d=3@0?Shn05aLG01_Kfl0@d=308>3P`1QHF40De=C04E5A@1DE5@0ADE506MWI`1PH600
ADE505iNGP1gMgL0I6AT09NGU`2`/;00XJ6Q04a<C01FEUH0KVi^06IVIP1BDU80Kfm_05=CD`1<C4`0
GEeM08b<S00j>SX0F5QH079bLP1WIfL0L71`0410@01]KFd0IFEU0451@@2@T9000P1ADE40M`1fMWH0
BTY:05MGE`12@T80F5QH08^;R`1:BTX0LW9b04m?C`1DE5@0@T92065QH@1OGel0=SHf08>3P`1cLg<0
B4Q804M7A`2CTi<0;2`/06=SH`1cLg<0A4A406m_K`2LW9`0P82006][J`1UIFD0ATI606m_K`1oOgl0
H61P06YZJP29RHT0?Cdm079bLP1aLG40De=C06m_K`1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`1@D500JVYZ02HV9P1@D500QXJ608R8R01?Cdl0Rh^;06a/K012@T80OGem06m_K`17AdL0
TI6A03<c<`0m?Cd0QXJ603lo?`1bLW80MWIf04a<C01PH600<S8b03Ph>02;Rh/0GUiN05aLG02EUID0
GUiN04U9B@1hN7P0@d=309>CT`1YJFT08R8R065QH@1BDU80ZZZZ05EEE@1QHF40Jf][04=3@`0g=cL0
HV9R0861P@1DE5@0<C4a059BDP1EEED0K6a/038b<P0`<300J6QX07MgM`15ADD0DU9B06ATI01UIFD0
;2`/065QH@1`L700QXJ604];B`1<C4`0MgMg05IFEP0k>c/0Y:BT04i>CP1hN7P0TI6A0080FUYJ0300
DU9B06ATI01=CDd0G5aL04];B`1:BTX0Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1cLg<0
HF5Q05YJFP1]KFd0QhN705IFEP1dM7@0HV9R03`l?00j>SX0PH6104E5A@0n?Sh0Lg=c05UIF@0j>SX0
LG5a05IFEP1eMGD0QhN706][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K04a<C037alL0
MGEe030`<01gMgLLooooo`0704=3@`0b<S80:b/[02PX:00R8R80;bl_04a<C00208N7Q`0307]kN`1o
Ogl0MGEe0080G5aL03h0/K6a07moO`1aLG40BTY:03/k>`1ADE40N7Qh07AdM00`<300H61P06MWI`2[
Zj/0<C4a01dM7@0P8200;2`/02<S8`0Z:RX0BDU908N7Q`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`1CDe<0[:b/04Q8B016ATH0]KFe09:BTP1OGel0J6QX08f=S@2NWYh0LW9b06MWI`1R
HV80De=C03`l?00b<S8092@T01hN7P0L71`0IFEU09bLW026QXH0IFEU0492@P1DE5@0QHF507=cL`1>
CTh0DU9B04];B`1JFUX0C4a<034a<@807QhN06/0Jf][05IFEP1MGEd0R8R80;jn_P2OWil0FUYJ02h^
;P0M7Ad071`L01dM7@0L71`09BDU02/[:`1QHF40a/K60<g=c@2TY:@0WYjN09^KV`1hN7P0@T9204i>
CP29RHT0DU9B05IFEP1PH600HV9R07inOP2;Rh/0NGUi04];B`14A4@0ZJVY05mOG`1DE5@0KVi^08J6
QP1dM7@0@41002/[:`1=CDd0VIVI04Y:BP1aLG40OGem0:NWY`30`<00Ti>C05iNGP1PH600W9bL0<30
`01VIVH0CDe=06UYJ@1VIVH0P82006QXJ028R8P0SXj>0:j^[P1IFET0B4Q805eMG@21PH40bLW902d]
;@0I6AT06a/K01`L701`L700?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0<30`01`L
700K6a/07AdM038b<P1HF5P0ZJVY0:BTY01PH600JVYZ020P800M7Ad07alO03Xj>P1jNWX0O7al06AT
I01GEeL0UIFE09>CT`2>SXh0MGEe0;Fe]@1oOgl0<C4a024Q8@0301`L701V01dM7@0h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`1YJFT071`L020P800N7Qh09bLW03Lg=`2DU9@0ZZZZ09JF
UP1eMGD0>3Ph07moO`1dM7@0TI6A05eMG@26QXH0TY:B08V9R@2=SHd0Zj^[07QhN00`<30092@T02LW
9`0o?cl0[Zj^0;Rh^039bLT0Jf][03De=@0k>c/0@D5104e=C@1fMWH0H61P02/[:`0k>c/0G5aL051@
D02d];@0FEUI03lo?`1;Bd/0Hf=S07IfMP1OGel0SHf=0<;2`P2DU9@0[Zj^0;Ng]`2ZZZX0^KVi0:BT
Y02ZZZX0Y:BT0:RXZ023Ph<0QhN707alO024Q8@0ZZZZ0<30`032`/80QhN7055AD@0l?3`092@T02PX
:011@D40HF5Q06][J`2JVYX0_Kfm06a/K01TI6@0SHf=08Z:RP1/K6`0];Bd0861P@1dM7@0/k>c0=OG
e`3De=@0X:2P07]kN`2LW9`0[Jf]0;Ng]`1OGel0NGUi4Oooool000oooooo0:00EUIF08F5Q@17AdL0
WIfM05YJFP1dM7@0R8R803De=@0i>CT0CDe=02d];@0T92@0?3`l03hn?P0j>SX0?clo04I6AP0P8200
Hf=S03De=@0`<300Fe]K02l_;`0W9bL0?clo01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0
;Rh^030`<00];Bd0820P04Y:BP0J6QX0@T9201HF5P0/;2`0FUYJ02/[:`14A4@0<c<c05IFEP1QHF40
@41005MGE`1/K6`0KFe]06][J`12@T80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP1@D500
O7al0451@@0`<300;bl_04m?C`0L71`0GUiN092@T00c<c<0K6a/02h^;P28R8P0De=C04Y:BP1hN7P0
MWIf03hn?P1;Bd/0Kfm_06UYJ@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0Hf=S06QXJ01<C4`0
KFe]08Z:RP1]KFd0TI6A0<30`02d];@0@T9205MGE`1ZJVX0I6AT02l_;`1kNg/0B4Q8059BDP1_Kfl0
FUYJ03Xj>P1JFUX0IfMW0861P@1IFET0?clo0820P01KFe/0ADE508B4Q015ADD0@D51055AD@16ATH0
J6QX05=CD`1GEeL0Ph>303@d=02DU9@0IfMW04Q8B00g=cL0JFUY08F5Q@14A4@0QhN7061PH00e=CD0
C4a<07moO`0o?cl0IFEU05]KF`0[:b/0@41009:BTP1@D500KFe]0861P@1WIfL0X:2P08f=S@0f=SH0
Rh^;0:f][@0o?cl0Bd];05mOG`11@D40OWin0P0o?cl0<`2_[jl0Cdm?01DE5@0b<S80WinO09VIV@1Q
HF40GEeM08n?S`1;Bd/0AdM708V9R@28R8P0Bd];09BDU01lO7`0H61P0:VYZ@24Q8@0Cdm?08n?S`0_
;bl0820P06YZJP1IFET0Bd];06UYJ@1eMGD0V9RH05IFEP13@d<0QHF503Xj>P1JFUX0TY:B07YjNP1@
D500RHV902h^;P1DE5@0HV9R02DU9@1SHf<0EEEE0:NWY`1TI6@0KVi^08:2PP1GEeL0AdM706e]K@02
0861P@1;04I6AP1MGEd0IFEU08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q055AD@0o
?cl0G5aL08j>SP1CDe<0DE5A0861P@1[Jf/0DE5A08J6QP11@D40N7Qh07moO`1DE5@0KVi^04E5A@1E
EED0Bd];07QhN01=CDd0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207IfMP1HF5P0Jf][05]KF`1V
IVH0QhN708Z:RP1>CTh0KFe]07AdM00^;Rh0B4Q80:>SX`1DE5@0>SXj06MWI`0[:b/0:RXZ07AdM01Z
JVX0Jf][08Z:RP16ATH0Ph>309FEU@1YJFT0?Cdm05UIF@25QHD0QhN7038b<P0V9RH0S8b<07]kN`0Z
:RX0Ph>301cooooo03H0LW9b04e=C@0c<c<09BDU01lO7`0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?
Cdl0HV9R07QhN02XZ:P0QHF5071`L01kNg/0Bd];0451@@1BDU80IfMW0:>SX`2XZ:P0DE5A06MWI`0T
92@071`L01LG5`0P8200<30`04A4A01=CDd0K6a/07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T
92@09bLW02l_;`1mOGd0IfMW03De=@1PH600Xj>S06e]K@1TI6@0QXJ60:j^[P20P80205UIF@1205aL
G01JFUX0EUIF05=CD`1FEUH0Lg=c0;Bd]02DU9@0Rh^;07UiN@1KFe/0MgMg06UYJ@1ZJVX0;2`/05=C
D`1[Jf/0Lg=c07inOP25QHD0KVi^07alO02YZJT0KFe]07AdM02PX:00U9BD07moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300QXJ60:NWY`22PX80Ph>309NGU`1fMWH0FUYJ07inOP35aLD0L71`08>3
P`1>CTh0<S8b02l_;`0h>3P0C4a<059BDP0o?cl0GEeM09BDU02e]KD0Z:RX07AdM014A4@0@d=306e]
K@2DU9@0Q8B40;Ng]`1RHV80;Rh^0P2m_Kd0YP2BTY80KVi^06MWI`1/K6`0IFEU08F5Q@3De=@0Hf=S
03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH09bLW02HV9P0a<C40>c/k0:b/[00X:2P061PH
01HF5P0G5aL0WinO04A4A01NGUh0:RXZ04U9B@0o?cl0;Bd]02/[:`0d=3@0_;bl0;:b/P1kNg/0JVYZ
07alO023Ph<0PH610;fm_@2^[Zh0YjNW075aL@0h>3P0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B
08J6QP1_Kfl0UiNG0;Vi^@3:b/X0R8R804a<C00N7Qh071`L01dM7@0K6a/08b<S05mOG`2PX:00]KFe
071`L00/;2`0:BTY02<S8`0m?Cd0H61P06e]K@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn
06m_K`1DE5@0RHV90=3@d03?cll0KFe]04];B`0f=SH0;2`/03lo?`24Q8@0Fe]K02<S8`0Y:BT0>CTi
07AdM03=cLd0Vi^K06m_K`2GUiL0H61P02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0Ogmo
08J6QP0W9bL0:b/[06i^KP1[Jf/0RXZ:0;bl_03Hf=P0`l?30=3@d033`l<0/[:b0:FUY@2/[:`0/[:b
0<?3``2QXJ40VYZJ0:JVYP1PH600DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=SH`12@T80Bd];
07QhN01fMWH0IFEU0861P@3;bl/0Shn?07inOP24Q8@0Zj^[0=3@d03;bl/0^;Rh0;fm_@3AdM40f=SH
0:FUY@2PX:00B4Q8065QH@33`l<0Ogmo05iNGP2?ShlAooooo`003oooool0C`1SHf<0Ti>C04I6AP1^
KVh0HF5Q0:NWY`2OWil08R8R02d];@1KFe/0CTi>02l_;`11@D40?3`l05eMG@0l?3`0BDU9024Q8@1Q
HF40ADE501`L701KFe/0;bl_020P801ADE409RHV05=CD`0R8R80=SHf05eMG@0j>SX0=cLg06i^KP0S
8b<0ADE503Xj>P0[:b/0>3Ph018B4P1;Bd/0<C4a03<c<`1TI6@08b<S04A4A01@D500F5QH03dm?@0]
;Bd0EeMG06a/K01lO7`0P82004];B`1PH6007AdM0451@@1OGel0C4a<04U9B@14A4@0ADE504A4A01g
MgL0ATI603Xj>P0/;2`0;bl_01DE5@1ADE40Ph>3030`<01NGUh0<30`096AT@1FEUH0BTY:06EUI@1d
M7@00P0d=3@0d@1GEeL0GemO0410@025QHD0DE5A05eMG@1IFET0H61P04A4A01iNGT0O7al02h^;P1;
Bd/0M7Ad051@D01[Jf/0[Zj^0:6QX@1DE5@0AdM704E5A@1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1=CDd0JFUY06m_K`11@D40S8b<034a<@0b<S80OGem05UIF@1DE5@0Bd];03De=@1;
Bd/0BDU904i>CP2KVi/0Fe]K07EeM@1KFe/0Jf][051@D01=CDd0N7Qh04E5A@2<S8`0UiNG059BDP0[
:b/0K6a/034a<@1lO7`0Vi^K05eMG@0l?3`0YjNW02/[:`1:BTX0DU9B05eMG@2KVi/0N7Qh03De=@1@
D500Shn?04e=C@1IFET0L71`02LW9`1IFET0OWin04Y:BP3;bl/0Jf][0492@P1RHV80];Bd09^KV`1`
L700HF5Q08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2MWId0KVi^08Z:RP2@T900De=C08Z:RP1A
DE4061PH05mOG`1GEeL0AdM705iNGP0h>3P0F5QH03Hf=P0e=CD0H61P04U9B@18B4P0MWIf065QH@0o
?cl0VYZJ0451@@1TI6@0CTi>02XZ:P1RHV80Ph>30:ZZZP1cLg<0R8R809>CT`0b<S80:BTY04M7A`10
@400O7al0451@@1=CDd0>3Ph06a/K01YJFT08B4Q04E5A@2TY:@0;bl_0451@@1iNGT0N7Qh05EEE@19
BDT0GemO08R8R00d=3@0HF5Q08f=S@1`L700A4A408f=S@0_;bl0G5aL07moO`1@D500Q8B406MWI`0M
7Ad0<30`05ADE01<C4`0AdM7079bLP1XJ6P0:2PX02l_;`1GEeL0KFe]05EEE@1CDe<0J6QX02LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<S8b07moO`0l?3`0?Shn0820P01LG5`0:RXZ07inOP10
@400GUiN09fMW@1dM7@0[jn_0:6QX@1EEED0<C4a02<S8`13@d<0Lg=c06YZJP0_;bl0];Bd05eMG@0H
61P0Ti>C01cooooo02P0?Cdm06=SH`1^KVh0B4Q802<S8`0T92@0DU9B071`L020P800O7al06IVIP1_
Kfl0T92@07inOP1gMgL0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`2SXj<0LW9b08>3P`15
ADD0<C4a01dM7@0K6a/07QhN04i>CP1eMGD0BTY:03@d=01?Cdl0=cLg06UYJ@0o?cl08B4Q0P0M7Ad0
J00P8200;Bd]04M7A`1oOgl0A4A403`l?01kNg/0ZZZZ0:6QX@2:RXX0EEEE0492@P1BDU80H61P05QH
F01DE5@0FUYJ06QXJ01DE5@0J6QX0;:b/P2m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S
8`0`<300>CTi05ADE01`L700Q8B409fMW@2[Zj/0c<c<0<W9b@27QhL0G5aL04i>CP1;Bd/0OGem02d]
;@0Y:BT0EeMG06i^KP1/K6`0BDU903@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0;Ng
]`1fMWH0>CTi038b<P0Y:BT0<C4a03Ti>@0X:2P0G5aL0<G5a@22PX80@41006MWI`1oOgl0IVIV05YJ
FP1MGEd0`l?30<o?c`17AdL0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0cLg=07Ee
M@0];Bd0ADE5051@D01>CTh0OGem069RHP2ZZZX0MWIf02@T900P8200:2PX02/[:`24Q8@0>CTi0P0G
5aL0M00/;2`0`/;20861P@17AdL0<S8b02HV9P1PH600D51@034a<@22PX80[jn_07MgM`1GEeL0MWIf
0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2NWYh0H61P04A4A00m?Cd0>3Ph03hn?P1DE5@0NWYj
03@d=01:BTX0FUYJ09jNWP2n_[h0/;2`09fMW@25QHD0LW9b07inOP21PH40TY:B0<71`@3;bl/0fMWI
079bLP0`<300:RXZ02HV9P0h>3P0EeMG0:FUY@2KVi/0QXJ606e]K@1hN7P0TY:B0<?3``36a/H0/K6a
07inOP25QHD0VIVI0:>SX`1kNg/0WYjN08:2PP1UIFD0E5AD06IVIP2/[:`0_Kfm09bLW02i^KT0_kno
0<k>cP3IfMT0];Bd02DU9@0X:2P0WYjN04A4A018B4P0MWIf0;fm_@2?Shl0@d=303Hf=P2WYjL0bLW9
0;^k^`29RHT0OGem07moO`1iNGT0W9bL0<[:bP3;bl/0Ti>C0;Jf]P1fMWH0VYZJ09VIV@2XZ:P0aLG5
0;Jf]P2?Shl0AdM704a<C00l?3`0?Cdm055AD@1DE5@0GEeM08j>SP2PX:00[:b/0P2HV9P0602@T900
L71`06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02j^[X0fm_K0<?3``34a<@0a/K60<o?c`2OWil0
RHV906YZJP1jNWX0I6AT0;Zj^P1gMgL0Vi^K06IVIQ7ooooo000?ooooo`0N05aLG028R8P0CDe=07Ee
M@0n?Sh0D51@05aLG00b<S809RHV04=3@`0f=SH0?3`l020P800X:2P0F5QH03lo?`0l?3`030`<05]K
F`0l?3`05ADE06ATI00g=cL0:RXZ055AD@0P8200E5AD038b<P11@D40EEEE0P10@4006P1eMGD0820P
02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh03Hf=P0m?Cd0Bd];03lo?`19BDT0<C4a
04E5A@1PH600PX:207QhN01FEUH0MWIf03/k>`0d=3@0E5AD0P1;Bd/0iP1VIVH0K6a/04I6AP1aLG40
=3@d03`l?01CDe<0CTi>01LG5`0n?Sh0N7Qh01hN7P1:BTX092@T07AdM00i>CT0Cdm?08B4Q01XJ6P0
@T9203Hf=P1eMGD0AdM703lo?`1dM7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0DU9B03Ti>@1:BTX0
KFe]05UIF@1DE5@0UIFE09NGU`1>CTh0D51@06][J`1MGEd0@D51096AT@1fMWH0@T92069RHP1^KVh0
?Shn05iNGP1nOWh0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;01?Cdl0Ph>304M7A`1CDe<0
?Cdm03Xj>P1jNWX0H61P06UYJ@1>CTh0ADE505=CD`1BDU80GEeM03@d=018B4P0KFe]05YJFP0`<300
PX:2030`<01=CDd0Rh^;04=3@`0d=3@0NGUi079bLP1/K6`0DU9B07AdM02FUYH0Shn?05YJFP1MGEd0
YZJV05eMG@1HF5P0QHF506e]K@1mOGd0S8b<04a<C02m_Kd0YjNW092@T01]KFd0`l?30:2PX01CDe<0
KVi^09BDU01MGEd0AdM707MgM`1FEUH0@41007inOP2IVIT0K6a/07IfMP1SHf<0CDe=0;:b/P1SHf<0
7AdM06=SH`1WIfL0AdM707IfMP1=CDd0EeMG038b<P0h>3P0OWin061PH01;Bd/0N7Qh06=SH`0m?Cd0
T92@03lo?`1]KFd0B4Q801PH600k>c/0CTi>09fMW@12@T80K6a/0861P@1CDe<0CTi>09^KV`1eMGD0
[:b/05=CD`1nOWh0D51@07MgM`1NGUh0;Rh^04U9B@2GUiL0DU9B02h^;P1:BTX0FUYJ02l_;`1UIFD0
P82008R8R01JFUX0C4a<075aL@25QHD0@D5109:BTP1@D500ADE507inOP1QHF40UIFE069RHP1PH600
?Cdm05MGE`0l?3`0EUIF09FEU@1fMWH0G5aL02PX:01<C4`0AdM702h^;P1QHF40Vi^K06UYJ@1`L700
P82003Xj>P0e=CD0GemO075aL@1TI6@0A4A4092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500
CDe=08f=S@1TI6@0_Kfm0:ZZZP29RHT0C4a<02l_;`1>CTh0Kfm_07emO@0i>CT0[Zj^079bLP0Z:RX0
Jf][7?ooool08P17AdL0:b/[03Hf=P23Ph<0NGUi05mOG`1RHV80FUYJ05ADE00M7Ad06ATI01LG5`0I
6AT07AdM030`<02TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2TY:@0YZJV04m?C`0^
;Rh0:BTY03lo?`1[Jf/0EEEE0451@@0a<C4202@T901<04U9B@1KFe/0GEeM03dm?@0N7Qh06QXJ01hN
7P0T92@0=3@d06][J`1eMGD0GUiN0:JVYP38b<P0V9RH05YJFP16ATH0<C4a02LW9`0e=CD0?Shn04E5
A@1;Bd/0DE5A06=SH`2l_;`0Xj>S0<O7a`2g]kL0^[Zj07inOP2OWil0[Zj^069RHP0L71`06a/K028R
8P0Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d=01GEeL0Bd];02DU9@0k>c/0UiNG06m_
K`12@T809bLW01hN7P0Q8B409BDU02@T900V9RH092@T02HV9P18B4P0_kno0<30`02TY:@0bl_;09VI
V@1MGEd0?Shn034a<@0Q8B40;Bd]06e]K@2UYJD0Ogmo04m?C`80DU9B03@0EeMG071`L022PX80RXZ:
0;fm_@3=cLd0Shn?0:b/[01YJFT0GUiN03`l?00Q8B407AdM02TY:@13@d<0MgMg0;jn_P2ZZZX0GUiN
03hn?P14A4@0H61P09FEU@1hN7P0P82005aLG00X:2P0820P02HV9P0S8b<0EeMG05UIF@0G5aL0;Rh^
08V9R@14A4@0QHF504m?C`0];Bd0:2PX02@T901HF5P0NGUi0;Fe]@2FUYH0;Rh^061PH039bLT0^KVi
0:ZZZP32`/80Zj^[0P2NWYh0>@2n_[h0Zj^[08F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
Fe]K05MGE`11@D40EUIF0;jn_P33`l<0[:b/05=CD`1BDU80C4a<059BDP2QXJ40e]KF0=[JfP2GUiL0
:b/[02PX:00W9bL0=3@d05iNGP3<c<`0i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0PX:209FEU@2l_;`0
YjNW0<O7a`1aLG40B4Q804U9B@1XJ6P0Q8B40:VYZ@2^[Zh0alO70;jn_P2FUYH0I6AT08>3P`2_[jl0
c/k>0:^[Z`0201dM7@0o08B4Q03EeMD0[jn_09fMW@2QXJ40WYjN0:6QX@2;Rh/0`L7109fMW@1FEUH0
JVYZ09nOW`2PX:00VYZJ08Z:RP29RHT0W9bL04a<C01PH600XZ:R09:BTP1WIfL0GemO0=3@d033`l<0
/;2`08N7Q`1lO7`0H61P03<c<`0h>3P0F5QH061PH01VIVH0Kfm_07IfMP1kNg/0Y:BT0;Fe]@2d];@0
GEeM051@D02ZZZX0FEUI08:2PP37alL0`L710<?3``3=cLd0W9bL07QhN01kNg/0QHF507emO@1OGel0
@410051@D029RHT0`L710<K6aP1JFUX0:RXZ017ooooo000?ooooo`3o05ADE01nOWh0Bd];08^;R`1T
I6@0UYJF08V9R@11@D40<c<c04U9B@0Y:BT06a/K038b<P0[:b/0>CTi020P800l?3`061PH05YJFP0_
;bl05QHF04Q8B00M7Ad0:BTY05=CD`0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=302LW9`0a
<C40=cLg01DE5@12@T8092@T03hn?P0R8R807QhN04E5A@1MGEd0FEUI03Xj>P0V9RH0EEEE03Hf=P1;
Bd/0KVi^05YJFP0f=SH0;bl_05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0Bd];08j>SP16
ATH08R8R03/k>`10@4006QXJ051@D026QXH0;2`/034a<@0Z:RX0P82005MGE`0_;bl0E5AD079bLP0O
7al0;Rh^06e]K@1XJ6P0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn05EEE@1;Bd/08B4Q04M7A`22
PX80O7al04M7A`2XZ:P0^k^k04];B`0a<C40IfMW051@D00];Bd0JVYZ06UYJ@0l?3`0Fe]K051@D00Q
8B40<C4a07MgM`1EEED0?Shn024Q8@1^KVh0NWYj02l_;`1_Kfl0EUIF03/k>`1]KFd0A4A404a<C01D
E5@0ATI609jNWP1bLW80L71`07alO01CDe<0JFUY05EEE@1kNg/0IVIV05iNGP1RHV80CDe=03lo?`22
PX80ADE505aLG02GUiL0@T9203lo?`2KVi/0RHV906IVIP1BDU80JVYZ09jNWP2l_;`0QhN704U9B@2R
XZ80C4a<069RHP1aLG40Jf][07EeM@17AdL0=CDe09>CT`2JVYX0NGUi06UYJ@32`/80XZ:R03Ti>@1:
BTX0LW9b03Ti>@15ADD0RXZ:08V9R@1RHV80N7Qh09fMW@1QHF40RXZ:0820P00m?Cd0J6QX055AD@0O
7al0DU9B04m?C`1LG5`0OWin04U9B@1JFUX09RHV020P801[Jf/0LW9b0492@P1hN7P0LG5a03dm?@2J
VYX0;Bd]069RHP1lO7`0=CDe055AD@1VIVH0YZJV069RHP1VIVH0JVYZ03Lg=`1BDU80^[Zj08^;R`2j
^[X0@D5104Y:BP1]KFd0YJFU05QHF00S8b<0Cdm?075aL@1OGel0>CTi069RHP1QHF40ADE504A4A01>
CTh0LW9b03Ph>01VIVH0N7Qh05EEE@0a<C40WinO05iNGP14A4@0IfMW02l_;`18B4P0KFe]07IfMP0o
?cl0IFEU03Xj>P0^;Rh0G5aL06e]K@1MGEd09bLW04a<C01?Cdl08B4Q000S03hn?P1[Jf/0Hf=S079b
LP25QHD0LG5a03De=@1FEUH0E5AD03`l?012@T80X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eM
G@1XJ6P0SXj>05MGE`2IVIT0U9BD05eMG@0n?Sh0Jf][0:^[Z`2QXJ40J6QX04i>CP2][Jd0Ph>303<c
<`1gMgL07?ooool0801?Cdl0CDe=038b<P0X:2P0PX:2038b<P0Q8B40ATI606IVIP0L71`05QHF01LG
5`0E5AD05QHF01DE5@1HF5P0UiNG04A4A01/K6`0dM7A0<_;b`2@T900OWin0::RXP1eMGD0Shn?06e]
K@1TI6@0OWin05aLG00e=CD0:2PX0P0V9RH01`0T92@08B4Q038b<P1?Cdl0LW9b0492@P0g=cL00P0L
71`0700N7Qh0:BTY04a<C02@T900a/K609>CT`2ZZZX0Vi^K04];B`0j>SX0=3@d02PX:00W9bL0<S8b
030`<00_;bl0@T9204a<C01XJ6P0X:2P09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH201`L
700e020P800U9BD0;2`/02/[:`0^;Rh0FUYJ0;Ng]`1aLG40A4A4059BDP1<C4`09RHV01`L701/K6`0
<C4a01`L700K6a/071`L01hN7P0U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl0<K6aP3?cll0
];Bd0:FUY@1/K6`0Hf=S08B4Q020P800QHF5065QH@0V9RH071`L01dM7@0X:2P0<c<c04=3@`1OGel0
U9BD0<S8b033`l<0`<300<g=c@2/[:`0Bd];04m?C`0c<c<00P0O7al0900Z:RX0LW9b0<G5a@2d];@0
V9RH05mOG`1YJFT0T92@09ZJVP2/[:`0J6QX04a<C00i>CT09bLW02TY:@0X:2P0Bd];07=cL`0e=CD0
Kfm_04Y:BP0_;bl08b<S05UIF@1<C4`0<30`02XZ:P0P8200MGEe0;^k^`1RHV80820P04=3@`3EeMD0
hN7Q0;2`/080Shn?01D0QHF508b<S02UYJD0QhN707IfMP2PX:00_;bl0<[:bP37alL0_kno04Q8B00e
=CD0Cdm?03dm?@0W9bL0>c/k0<g=c@3;bl/0a<C407MgM`0Y:BT00P0X:2P0I@2a/K40/k>c07IfMP33
`l<0BDU902<S8`0W9bL0>c/k07alO02SXj<0JFUY08B4Q02[Zj/0`L710:>SX`1@D500BDU90:f][@2Z
ZZX0g=cL0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0^[Zj09jNWP2YZJT0JFUY07moO`2Q
XJ40_[jn0:b/[00];Bd0?clo09nOW`2ATI40YjNW0;jn_P2PX:00OGem0:n_[`3Hf=P0/K6a08F5Q@1X
J6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0E5AD0ATI609NGU`36a/H0Zj^[09>CT`1Q
HF40=cLg03Ti>@15ADD0Ogmo0:RXZ025QHD0Shn?08Z:RP27QhL0NGUi06i^KP1ZJVX0SHf=09:BTP2E
UID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0<g=c@2h^;P0IVIV051@D017AdL0@T9203lo?`1h
N7P0G5aL06m_K`2;Rh/0[:b/0;jn_P18B4P07AdM017ooooo000?ooooo`0l05ADE01TI6@0@41005UI
F@1NGUh0UIFE09>CT`0R8R808B4Q04E5A@14A4@09bLW020P800S8b<0Hf=S02PX:00j>SX03Ph>0451
@@1BDU809BDU03Ph>00i>CT051@D04a<C00i>CT0EeMG02XZ:P0V9RH0F5QH051@D00^;Rh0B4Q802HV
9P0j>SX0@D5103Ph>00n?Sh05aLG0492@P1:BTX08R8R04Y:BP0/;2`0=CDe065QH@0^;Rh0Bd];01lO
7`0n?Sh0F5QH06UYJ@1bLW80@41006EUI@0O7al092@T04i>CP1DE5@0;Bd]0P16ATH0CP0Y:BT0Hf=S
05MGE`0V9RH0BTY:04e=C@0D51@0<30`06m_K`0d=3@0>SXj01hN7P1LG5`0FEUI02l_;`1VIVH0KVi^
04A4A00Y:BT0DE5A05EEE@1HF5P0UYJF05MGE`1@D500GEeM04m?C`0h>3P0H61P06YZJP0f=SH0<30`
04Q8B01YJFT0<c<c08J6QP2VYZH0Lg=c0492@P1?Cdl0Ng]k06a/K02>SXh0FEUI02/[:`1NGUh0JVYZ
05YJFP13@d<0H61P059BDP1kNg/0AdM708j>SP1bLW80=3@d079bLP1_Kfl0@T9204i>CP0c<c<0BTY:
065QH@11@D40UIFE04M7A`1[Jf/0OWin05ADE018B4P0A4A4075aL@1TI6@0De=C08J6QP1<C4`09bLW
06UYJ@80CTi>08L0UIFE04E5A@0R8R80OWin079bLP1ADE40LG5a06=SH`1]KFd0QhN705iNGP10@400
TY:B05]KF`1HF5P0K6a/05UIF@1bLW80M7Ad04e=C@27QhL0ZZZZ06][J`1HF5P0_kno0:ZZZP1mOGd0
IVIV092@T01BDU80?Shn079bLP2DU9@0LW9b08V9R@2i^KT0EeMG08N7Q`24Q8@0ATI608J6QP1PH600
8b<S061PH01]KFd0>SXj07QhN01?Cdl0JVYZ069RHP0];Bd0MGEe04m?C`0g=cL0O7al08:2PP16ATH0
ZJVY0451@@1CDe<0KVi^02XZ:P18B4P0HV9R09bLW01MGEd0QhN709BDU01NGUh0JVYZ0<k>cP1aLG40
YjNW059BDP1QHF40MgMg08F5Q@1XJ6P0=cLg05aLG02DU9@0NGUi03Ti>@1VIVH0Jf][0410@01GEeL0
JVYZ08:2PP1>CTh0Bd];05=CD`1_Kfl0>3Ph0::RXP1:BTX0Cdm?06m_K`1>CTh0FEUI06=SH`1CDe<0
=CDe06][J`13@d<0DU9B07moO`1`L700<30`02h^;P1HF5P0FEUI02`/;01GEeL0RHV905aLG01BDU80
OWin05aLG00j>SX0Fe]K05mOG`14A4@0=CDe07emO@0`<300=CDe06i^KP1:BTX0:b/[08F5Q@1<C4`0
?Cdm07emO@1KFe/00P2b/[802`1^KVh0CDe=02l_;`1;Bd/0IFEU06QXJ00g=cL0UiNG06e]K@0W9bL0
M7Ad01cooooo02h0Ng]k0861P@28R8P0UiNG0:n_[`2<S8`0L71`06=SH`1FEUH0BDU90451@@0j>SX0
<C4a02TY:@0I6AT061PH05iNGP2:RXX0N7Qh0<g=c@2>SXh0@d=304M7A`1VIVH0Lg=c05UIF@2MWId0
S8b<06ATI01EEED0Cdm?04a<C010@400>SXj02d];@0X:2P0820P02LW9`1?Cdl0Q8B406ATI01KFe/0
FUYJ05eMG@1OGel0W9bL0P2j^[X0I@2HV9P0UIFE0<71`@22PX80D51@02l_;`0X:2P09RHV024Q8@0R
8R80;bl_03/k>`16ATH0AdM708V9R@1mOGd0XJ6Q09VIV@27QhL0NWYj038b<P0[:b/0?clo03Hf=P0J
6QX071`L01hN7P0S8b<0;2`/0410@01QHF40];Bd0;jn_P1bLW80Kfm_05mOG`0k>c/0:RXZ06i^KP1B
DU807alO01`L700K6a/07AdM028R8P0Y:BT0<C4a04U9B@1GEeL0DU9B05eMG@2>SXh0TI6A0<30`02h
^;P0SHf=08F5Q@24Q8@0`L7107YjNP0_;bl07AdM01`L700J6QX071`L01/K6`0L71`08B4Q02PX:015
ADD0XZ:R0:n_[`2<S8`0`l?30;Ng]`17AdL0=SHf02LW9`0N7Qh08b<S03Ph>01kNg/0WinO08B4Q02V
YZH0QXJ607moO`1iNGT0V9RH06e]K@1HF5P0E5AD05YJFP11@D40=SHf0451@@1_Kfl0Ogmo07UiN@0^
;Rh06QXJ00806ATI00X06a/K034a<@0o?cl0D51@05=CD`23Ph<0T92@08f=S@1mOGd0UIFE0P2ZZZX0
5P2MWId0/[:b08>3P`1YJFT0GUiN07QhN02DU9@0Rh^;04m?C`0c<c<0;bl_02/[:`0j>SX0EEEE075a
L@1nOWh0Kfm_07IfMP2XZ:P0/K6a06i^KP21PH420;6a/@1809fMW@27QhL0f=SH09nOW`1@D500O7al
0;:b/P1GEeL0;2`/04=3@`1nOWh0E5AD02XZ:P1>CTh0D51@069RHP1<C4`0M7Ad0:VYZ@2/[:`0b<S8
0=CDe02][Jd0Vi^K06a/K01LG5`0EEEE04e=C@1BDU80KFe]0:2PX02BTY80XJ6Q0=7Ad@33`l<0PH61
07EeM@2i^KT0clo?0:^[Z`1:BTX0>CTi02h^;P0Y:BT0BTY:07alO03?cll0dM7A09:BTP1UIFD0IfMW
08V9R@2XZ:P0WinO09RHV02@T900IVIV02HV9P0E5AD04a<C02LW9`1MGEd0YZJV0;Ng]`1NGUh0>3Ph
01dM7@0K6a/07AdM02<S8`1gMgL0:2PX0P0T92@07@0[:b/0<30`04];B`1aLG40U9BD0;^k^`2d];@0
e]KF0=WIf@39bLT0SXj>0:^[Z`2TY:@0^KVi05eMG@0R8R8092@T02DU9@0c<c<0@D51059BDP22PX80
[jn_09bLW02c/k<0YZJV0820P01jNWX0D51@017ooooo000?ooooo`3o05QHF01hN7P0KVi^05QHF01[
Jf/0QHF50;Rh^01`L700=SHf055AD@1QHF40:b/[04M7A`0k>c/0Jf][028R8P11@D40;Bd]04E5A@1e
MGD0:BTY01/K6`0T92@04a<C04a<C00o?cl0BDU902DU9@0l?3`0HV9R05EEE@0W9bL0<30`02d];@0g
=cL0>CTi03Ph>00d=3@0:RXZ03<c<`0n?Sh0:BTY06m_K`1BDU80AdM705eMG@0_;bl0FUYJ04a<C016
ATH0E5AD07UiN@1MGEd0>SXj06e]K@1@D500:RXZ03`l?00`<3007AdM055AD@1ZJVX0@T9205eMG@0e
=CD08B4Q059BDP1hN7P09BDU02/[:`1`L7005QHF03Ph>00^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1D
E5@0=CDe07IfMP1IFET0E5AD0:RXZ01KFe/0ADE507YjNP1NGUh0=CDe04a<C01>CTh0>c/k03<c<`15
ADD0IVIV03dm?@2a/K40X:2P07QhN00l?3`0LG5a07EeM@1QHF40Q8B408^;R`12@T80Cdm?071`L01Q
HF40@T9206ATI011@D40G5aL04U9B@1NGUh0Ti>C0492@P1]KFd0LG5a04];B`1bLW80H61P05IFEP1>
CTh092@T08R8R027QhL0IVIV055AD@1EEED0M7Ad04i>CP1VIVH08b<S0410@02XZ:P0NGUi03dm?@1h
N7P0ATI603Ph>02<S8`0Jf][038b<P1nOWh0QhN704Q8B01HF5P0K6a/069RHP2NWYh0GemO03Lg=`2=
SHd0M7Ad069RHP1bLW80CTi>05UIF@28R8P0GemO07YjNP2a/K40B4Q803dm?@2_[jl0^[Zj07inOP1j
NWX0Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a0:ZZZP1hN7P0VIVI0820P01DE5@0EUIF08B4Q00Z
:RX0De=C05aLG01<C4`0Vi^K06e]K@1oOgl0@d=302<S8`1eMGD0G5aL04Y:BP2SXj<0RXZ:03lo?`2a
/K40@D5106ATI01eMGD0?Cdm03`l?01=CDd0Xj>S04A4A01=CDd0@T9204e=C@1;Bd/0/[:b07EeM@2H
V9P0?Shn04];B`1JFUX0SHf=05IFEP0U9BD09bLW04e=C@1/K6`0>CTi06i^KP1LG5`0>c/k04=3@`18
B4P0Ogmo06IVIP1DE5@0DE5A06][J`0X:2P0K6a/05mOG`1CDe<0OWin03lo?`1IFET0HF5Q06UYJ@11
@D40EeMG04E5A@0R8R80AdM705MGE`17AdL09bLW0410@01KFe/05aLG000S02l_;`1QHF40J6QX051@
D021PH40N7Qh03lo?`1@D500I6AT061PH014A4@0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0QhN7071`
L01CDe<0PH6105EEE@2k^k/0b<S8092@T01WIfL0@41005YJFP1cLg<0NGUi03Xj>P2ATI40QXJ603/k
>`1fMWH07?ooool07@1jNWX0NGUi09FEU@1XJ6P0Q8B405QHF01gMgL0UiNG0::RXP1YJFT0@D5104=3
@`0m?Cd0;Rh^04U9B@0W9bL0>3Ph0<c<c031`L40d];B0;Jf]P1/K6`0LG5a06e]K@0[:b/0@T920:^[
Z`26QXH0Bd];0080<c<c03@0>SXj04I6AP1BDU80C4a<055AD@1IFET0EUIF06=SH`2YZJT0MWIf06a/
K01ADE40>c/k0451@@2TY:@0];Bd0=7Ad@33`l<0/K6a0<?3``2SXj<0`/;208>3P`0Y:BT0820P02DU
9@1@D500IfMW05EEE@0j>SX09bLW05IFEP0X:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo
?`0j>SX0;Rh^051@D01JFUX0EEEE04U9B@12@T80Jf][092@T02n_[h0T92@0P2;Rh/06@2<S8`0_Kfm
0<W9b@1[Jf/0=CDe020P800K6a/061PH028R8P1=CDd0B4Q80492@P17AdL0OWin055AD@23Ph<0a/K6
0;2`/01fMWH0>SXj034a<@1_Kfl0DE5A02<S8`0K6a/00P0L71`03`0I6AT06a/K01`L700L71`06QXJ
02PX:01`L700Kfm_08R8R02;Rh/0UiNG05mOG`0S8b<07alO03@d=00205aLG0050451@@1ZJVX0I6AT
06=SH`10@4000P0f=SH0?`12@T80K6a/04i>CP1KFe/0CTi>09:BTP24Q8@0Hf=S0410@00l?3`0E5AD
059BDP0G5aL05QHF01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0<S8b01gMgL0NGUi
0492@P0`<300E5AD0410@00d=3@0@41003`l?01@D500HF5Q08f=S@27QhL0KFe]04e=C@1EEED0IfMW
0:JVYP2GUiL0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0b<S80<g=c@3Lg=`0_[jn
08j>SP3Hf=P0_[jn07AdM02FUYH0RXZ:02/[:`0301LG5`0701DE5@0G5aL07QhN05MGE`1CDe<0f][J
0:NWY`0206EUI@0Z0;Fe]@1jNWX0G5aL06MWI`1LG5`0IFEU09FEU@1IFET0MGEe07inOP37alL0aLG5
0<_;b`2_[jl0bl_;0;6a/@0d=3@07AdM01XJ6P0K6a/07QhN065QH@2^[Zh0_;bl0:6QX@1CDe<0IFEU
09bLW02WYjL0XJ6Q08B4Q02KVi/0b<S80;bl_025QHD0F5QH08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ
0P0L71`00`0K6a/08b<S01hN7P02020P800B02LW9`0U9BD08b<S02`/;01LG5`0V9RH0=SHf032`/80
YZJV09BDU01^KVh0`L710=cLg03Ogml0YZJV03De=@0M7Ad071`L100M7Ad0201KFe/0c<c<0=;BdP3<
c<`0d=3@08b<S01DE5@0GEeM4Oooool000oooooo0?l0CTi>05aLG01JFUX0D51@04a<C01IFET0QHF5
059BDP0_;bl0AdM702TY:@0S8b<0A4A403@d=01>CTh09RHV055AD@0o?cl0<C4a05MGE`0G5aL08b<S
03De=@0K6a/0ADE501/K6`13@d<0ATI60451@@1ZJVX0?clo01`L700];Bd0H61P03Lg=`11@D40:b/[
03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn04Q8B012@T80=3@d00h>3P1<C4`0@D510410@01RHV80Lg=c
03lo?`0/;2`0D51@04U9B@0X:2P0?Shn04U9B@0Y:BT0?Shn04Q8B014A4@0LW9b069RHP0Q8B40;2`/
05eMG@0S8b<0:2PX07alO00a<C40;bl_02LW9`1PH600MgMg02`/;01MGEd0N7Qh024Q8@0P8200EUIF
06=SH`1TI6@0`l?302LW9`0_;bl0JFUY07inOP14A4@0FUYJ06MWI`0Z:RX08B4Q06][J`2;Rh/0B4Q8
07]kN`2^[Zh0Ph>3020P801WIfL0JFUY05mOG`1FEUH0Ph>304Y:BP1CDe<0LW9b030`<01:BTX0QXJ6
05MGE`1dM7@0F5QH06UYJ@2YZJT0DU9B075aL@15ADD0BDU9071`L01MGEd0DE5A04I6AP0[:b/0Hf=S
08Z:RP1JFUX0JVYZ06MWI`1XJ6P0CDe=07EeM@21PH40BDU90::RXP1CDe<0@D5107moO`1ZJVX0=cLg
09VIV@1eMGD0<30`04A4A01ZJVX0IVIV09VIV@24Q8@0HV9R0;Jf]P21PH40?3`l09ZJVP19BDT0DU9B
06e]K@1iNGT0JVYZ05MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^06IVIP2DU9@0L71`
051@D02CTi<0/;2`07EeM@1WIfL0YJFU05MGE`1OGel0QXJ605mOG`1FEUH0IVIV03De=@1bLW80N7Qh
03Lg=`1^KVh0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0A4A40:b/[01;Bd/0>c/k
06ATI00c<c<0>SXj04Y:BP2SXj<0G5aL065QH@1CDe<0EeMG06IVIP2e]KD0Ph>309VIV@14A4@0F5QH
06m_K`21PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065QH@10@400@D5104M7A`2<S8`0J6QX
055AD@1DE5@0NGUi04Q8B02=SHd0Bd];04M7A`28R8P0GemO04=3@`18B4P0FEUI04I6AP1MGEd0ATI6
03/k>`1FEUH0GemO034a<@0Q8B40=cLg05]KF`0X:2P002<0BDU906m_K`1iNGT0C4a<08N7Q`1oOgl0
BTY:051@D01XJ6P0CTi>03hn?P1^KVh0DE5A03Xj>P1OGel0EEEE03De=@2IVIT0PX:204e=C@20P800
=SHf06IVIP2SXj<0Shn?05mOG`11@D40FUYJ07AdM018B4P0BTY:0:f][@2CTi<0>SXj06ATI00Loooo
o`0a05aLG01fMWH0JFUY05QHF01hN7P0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80
;bl_09jNWP1eMGD0d];B0>3Ph01kNg/0P8200:FUY@2HV9P0EeMG061PH02i^KT0Y:BT07emO@2NWYh0
^;Rh09:BTP1EEED0?clo04A4A00h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1<C4`0
BDU905]KF`2o_kl0cLg=0=3@d00209>CT`0809:BTP20P800/;2`0:JVYP1oOgl0U9BD06=SH`0a<C42
01/K6`0b01TI6@0b<S809bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0FEUI06i^KP1M
GEd0EUIF04m?C`14A4@0>c/k04=3@`2WYjL0`l?307QhN01`L700JVYZ04e=C@1iNGT0GUiN05mOG`1h
N7P0Hf=S03@d=00W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0BDU90;6a/@3Lg=`0UYJF06MWI`0_
;bl0>c/k04=3@`1=CDd0AdM701hN7P0L71`201XJ6P806a/K02805aLG01/K6`0m?Cd0]KFe05UIF@2h
^;P0T92@08^;R`1nOWh0N7Qh05IFEP1QHF40@T9202d];@0Y:BT0De=C05MGE`1HF5P0>3Ph03@d=00_
;bl0<S8b04m?C`1mOGd0J6QX07IfMP1bLW80Rh^;04=3@`0d=3@0;bl_03Xj>P1YJFT09RHV0`0G5aL2
01PH600802LW9`28R8P0DE5A08R8R01lO7`0/;2`06ATI00a<C42028R8P0S02LW9`1ADE409bLW02/[
:`0m?Cd0ADE50451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0Rh^;03Ph>00b<S80RXZ:06a/
K01GEeL0BTY:04m?C`37alL0aLG504M7A`0g=cL0Hf=S0861P@2ZZZX0hn?S0=oOg`2j^[X0_kno06QX
J00P82000`0G5aL0B`0J6QX05aLG01/K6`16ATH0QXJ60<[:bP2b/[80MGEe0861P@2TY:@0R8R8055A
D@0d=3@08R8R038b<P2IVIT0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RXZ033`l<0>CTi01XJ
6P0L71`07AdM024Q8@1_Kfl0_kno0<;2`P31`L40QXJ608N7Q`1aLG40EeMG04A4A00a<C40;Rh^05EE
E@1nOWh0?clo08n?S`2l_;`0WYjN0:>SX`2>SXh0];Bd05UIF@0h>3P0:BTY020P800V9RH071`L02HV
9P0T92@09BDU02LW9`0S8b<0:RXZ05]KF`3?cll0b<S80:f][@2PX:00TY:B08Z:RP3=cLd0a<C40<o?
c`1_Kfl08R8R01dM7@0301`L700:028R8P0d=3@0W9bL06a/K01eMGD0/K6a0<O7a`2d];@0Q8B4069R
HQ7ooooo000?ooooo`0@07UiN@1LG5`0ADE5055AD@1SHf<0AdM709:BTP0b<S80;Bd]05MGE`1>CTh0
:2PX03hn?P0`<300D51@01HF5P80=cLg08H08b<S04e=C@0R8R80410@02XZ:P0G5aL0BDU903Hf=P0e
=CD0?clo02@T901SHf<0C4a<01lO7`0R8R80EUIF04U9B@1;Bd/0=CDe038b<P0Y:BT0;Rh^038b<P14
A4@0I6AT04I6AP17AdL0HF5Q03hn?P1CDe<0:b/[04a<C021PH40Ogmo07]kN`12@T80IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0U9BD0KVi^06e]K@0_;bl0<S8b05]KF`0A4A4092@T07YjNP1?
Cdl0AdM701DE5@0g=cL0Lg=c038b<P1BDU80Lg=c059BDP0/;2`0AdM706ATI01XJ6P0c<c<07MgM`1:
BTX0Fe]K04];B`1ADE40Bd];075aL@0/;2`061PH03Hf=P1]KFd0>CTi075aL@2`/;00X:2P0451@@1^
KVh0L71`0861P@1`L700Q8B404Q8B01HF5P0GUiN03Hf=P0/;2`0J6QX05IFEP1ZJVX0;2`/05IFEP2K
Vi/0DE5A07AdM01KFe/0?Shn05QHF00l?3`0EEEE05ADE016ATH0LW9b08b<S01DE5@0P82006m_K`1f
MWH0FUYJ08F5Q@1QHF40Cdm?0;Rh^01mOGd0=CDe079bLP1GEeL0:RXZ0820P01fMWH0>3Ph0410@01R
HV80A4A4059BDP1SHf<0@d=309RHV080BTY:08@0XJ6Q06ATI01JFUX0DE5A05MGE`1^KVh0N7Qh04m?
C`1<C4`0/;2`06QXJ01RHV80^KVi0;Rh^01nOWh0KVi^0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aL
G02SXj<0Lg=c06][J`2HV9P0MGEe05=CD`1XJ6P0;bl_034a<@1EEED0<30`09>CT`1LG5`0I6AT07=c
L`0f=SH0Cdm?06YZJP18B4P0LG5a09:BTP1<C4`0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe
]@1UIFD0Kfm_06IVIP1nOWh0CTi>0:2PX01iNGT0WYjN05QHF01BDU80S8b<08F5Q@1XJ6P0GEeM02h^
;P1GEeL0QXJ604U9B@2=SHd0IfMW04Q8B00l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`L700ADE509ZJ
VP1CDe<0CTi>07emO@1]KFd0CDe=059BDP1LG5`0?Cdm05aLG013@d<0=cLg05QHF01KFe/0=CDe02@T
900g=cL0Lg=c02PX:015ADD0KFe]07MgM`18B4P0XZ:R08N7Q`18B4P0DE5A06EUI@15ADD0BTY:0:n_
[`1UIFD0<C4a061PH00c<c<0820P06m_K`1VIVH0AdM706m_K`1OGel0S8b<0:JVYP21PH40G5aL0451
@@1IFET0Jf][06i^KP0c<c<207YjNP0303Ti>@1RHV;ooooo01_ooooo03`0[jn_09NGU`1NGUh0C4a<
08>3P`1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin04I6AP0Z:RX0ADE507QhN02QXJ40a<C4
0;bl_02GUiL0^KVi0<k>cP36a/H0[Jf]061PH01lO7`0IfMW071`L02<S8`0clo?0=gMg@2QXJ40R8R8
09BDU02[Zj/0];Bd0:n_[`35aLD0OGem05MGE`1ZJVX0E5AD04U9B@0c<c<0EEEE0:JVYP2m_Kd0/K6a
04e=C@10@400A4A4075aL@2a/K40a/K60<g=c@3:b/X0C4a<020P800K6a/201`L700O01hN7P0i>CT0
71`L02LW9`1kNg/0Vi^K05EEE@1lO7`0][Jf08J6QP1kNg/0J6QX06=SH`10@400<C4a02`/;00T92@0
KVi^092@T02f][H0Ph>306ATI01@D500Cdm?061PH01_Kfl0FUYJ04i>CP1SHf<0NGUi0861P@0203Ti
>@0T030`<00f=SH0C4a<03`l?01XJ6P0a/K60=GEe@3<c<`0MgMg04I6AP19BDT0<30`0410@01HF5P0
;Rh^01`L700J6QX05QHF01XJ6P0L71`08B4Q02LW9`1SHf<0dM7A0<g=c@2VYZH0`/;20;Bd]02l_;`0
e=CD075aL@0l?3`0:2PX01hN7P0L71`0D51@0P1RHV804P0_;bl0;2`/02l_;`0W9bL0@41007=cL`1o
Ogl0PX:2065QH@2@T900O7al04Q8B00g=cL0<c<c05MGE`1_Kfl05aLG01DE5@805aLG02<06QXJ065Q
H@22PX80E5AD051@D01BDU80SHf=01dM7@0L71`06ATI01/K6`0I6AT0:RXZ04=3@`0X:2P0<30`0451
@@0n?Sh09bLW02TY:@0l?3`0SXj>0;Ng]`0n?Sh0alO70;Rh^00i>CT0:2PX07UiN@1`L700EEEE05eM
G@26QXH0d];B06ATI00201lO7`0a02DU9@15ADD0@D510<S8b03YjNT0j^[Z0=GEe@1jNWX07alO01PH
600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^[Zh0b<S8055AD@0U9BD09RHV05aLG01^KVh07AdM01hN
7P0m?Cd0K6a/05EEE@19BDT0<30`08>3P`3EeMD0dM7A05=CD`0e=CD0SHf=0<71`@1MGEd08R8R01`L
700K6a/0:2PX07YjNP2XZ:P0^k^k0=CDe01iNGT0<30`02TY:@0202h^;P0Z02PX:00W9bL0<S8b069R
HP0X:2P0Jf][0:NWY`1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^0410@00S8b<0=SHf02`/
;00d=3@0@D5105YJFP2DU9@0][Jf0;Zj^P3:b/X0];Bd0;^k^`3=cLd0[:b/09^KV`1mOGd0NWYj038b
<P0J6QX071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01@2OWil0^;Rh09>CT`1_Kfl0O7al
017ooooo000?ooooo`3o06i^KP1MGEd0JVYZ03hn?P1VIVH0C4a<0;>c/`0i>CT07AdM02h^;P16ATH0
=3@d02DU9@0C4a<0GemO028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?03Ti>@1ADE40
;bl_05mOG`0C4a<0>c/k05eMG@0i>CT0<C4a05EEE@0X:2P0@41004Y:BP0e=CD0:b/[034a<@1=CDd0
D51@07MgM`0m?Cd09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=06IVIP1XJ6P0=CDe06IVIP0f=SH0
6ATI0451@@1<C4`0<C4a04i>CP1:BTX0=SHf04i>CP1NGUh0;Bd]02XZ:P1UIFD08b<S01TI6@1TI6@0
BDU9034a<@0V9RH0?3`l07QhN00c<c<0FUYJ07alO01_Kfl0>SXj065QH@1aLG40Hf=S0<?3``29RHT0
Hf=S07inOP1FEUH0FUYJ059BDP2=SHd0BDU902/[:`1FEUH0QHF504I6AP1fMWH0Ti>C0820P00g=cL0
K6a/05]KF`1bLW80H61P0:2PX013@d<0B4Q806ATI01DE5@0DE5A07moO`11@D40GEeM04=3@`1MGEd0
WIfM03lo?`1TI6@0De=C05aLG024Q8@0HV9R04Y:BP1<C4`08B4Q055AD@29RHT0Bd];061PH017AdL0
MWIf05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700HF5Q02DU9@1/K6`0Ogmo0410@00k>c/0
L71`07=cL`1_Kfl0Ng]k04M7A`2YZJT0HV9R0410@01mOGd0Fe]K05MGE`1FEUH0O7al06a/K01oOgl0
GEeM04Y:BP2GUiL0WYjN0861P@34a<@0_kno09FEU@1^KVh0TY:B09ZJVP0m?Cd0EUIF0:j^[P1`L700
EEEE09NGU`1fMWH0HF5Q09fMW@1kNg/0Cdm?06e]K@0i>CT0>c/k05]KF`0`<300TI6A06IVIP1PH600
NGUi03Lg=`1<C4`0K6a/04a<C01UIFD0TY:B04E5A@2NWYh0HV9R04E5A@1WIfL0=SHf03De=@1<C4`0
^;Rh05iNGP1`L700GUiN071`L01GEeL0WYjN0:VYZ@2g]kL0Jf][04U9B@29RHT0Ng]k08B4Q01/K6`0
=3@d05ADE026QXH0FEUI08^;R`1dM7@0F5QH0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0
W9bL07AdM01DE5@0VIVI075aL@1MGEd0De=C06IVIP17AdL0TI6A07AdM00h>3P0EeMG06QXJ00a<C40
<30`04i>CP2<S8`0EEEE000S04Y:BP1[Jf/0DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0V
9RH0L71`0410@00/;2`0SHf=04E5A@0f=SH0OWin05UIF@0l?3`0T92@071`L029RHT0YjNW06a/K011
@D40CDe=09FEU@2KVi/0PX:203/k>`29RHT0O7al03Hf=P1aLG407?ooool02@2VYZH0R8R806MWI`19
BDT0<c<c05MGE`1OGel0>CTi028R8P0201lO7`0?028R8P19BDT0YjNW0:FUY@1eMGD0?Shn01LG5`0n
?Sh0aLG50>3Ph03AdM40b<S80;jn_P2][Jd0Xj>S0080UYJF04h0Vi^K08n?S`2QXJ40`L71061PH01H
F5P0HV9R06m_K`26QXH0`/;20<K6aP1LG5`0Bd];04a<C01lO7`0P82008Z:RP2@T900ADE507emO@2L
W9`0<S8b02`/;00k>c/0E5AD0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX07AdM01XJ6P0j
>SX0;Rh^01hN7P0`<300RXZ:07YjNP1_Kfl0`l?307YjNP1=CDd0C4a<059BDP1aLG40=CDe02<S8`1=
CDd0N7Qh065QH@1/K6`0Cdm?05QHF01QHF40GemO06YZJP2ATI40IfMW07alO01XJ6P0Kfm_0;Rh^02=
SHd0FUYJ04A4A013@d<0DE5A09VIV@36a/H0`<300;Rh^02n_[h0^k^k06=SH`1[Jf/203lo?`2X04M7
A`16ATH07QhN01TI6@0H61P06QXJ024Q8@0Y:BT0HF5Q09jNWP1kNg/0NGUi05]KF`2_[jl0_[jn0<S8
b03:b/X0JVYZ02d];@0O7al071`L020P801BDU80UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410
@01oOgl0PX:20492@P0l?3`0MGEe07inOP1<C4`0?Shn04E5A@1gMgL0:BTY01dM7@0^;Rh0B4Q805EE
E@24Q8@0`l?309RHV027QhL0Y:BT06IVIP0J6QX061PH01LG5`0I6AT05aLG01hN7P0a<C40@T9202TY
:@0j>SX0C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP1@D500Jf][03De=@1FEUH0R8R80451
@@2DU9@0[jn_0=3@d00e=CD07QhN01lO7`0W9bL0=cLg07AdM03?cll0gmoO0=GEe@3Jf]X0`L7103<c
<`0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0;6a/@0_;bl08B4Q028R8P0`<300EeMG02LW
9`1FEUH0CTi>0451@@0l?3`0BTY:04I6AP1YJFT0WinO07AdM01DE5@0;Rh^05iNGP2m_Kd0R8R803Lg
=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Bd];02LW9`0X:2P08R8R01lO7`0L71`07QhN02@T
9017AdL0G5aL09jNWP3?cll0MGEe03Lg=`1BDU80/k>c04M7A`0`<300:RXZ02l_;`0c<c<0?3`l05aL
G01=CDd0GemO07AdM02=SHd0/;2`0:BTY02_[jl0bl_;0=KFeP3Hf=P0dm?C09RHV021PH40Ph>306UY
J@0n?Sh06ATI0P0K6a/0300M7Ad0AdM7092@T01OGel0AdM704=3@`1=CDd0[Jf]0;Jf]P25QHD0HV9R
04a<C17ooooo000?ooooo`3o06a/K01KFe/0SXj>04I6AP24Q8@0ATI60;Ng]`29RHT0@41004E5A@1G
EeL0=cLg0410@00j>SX0HF5Q02/[:`1=CDd0:RXZ01PH601TI6@0?Cdm01LG5`11@D40;2`/03`l?011
@D409RHV04E5A@0U9BD0EeMG06YZJP14A4@0>3Ph05MGE`0c<c<0@T9205IFEP0i>CT0=cLg020P8017
AdL0=SHf08n?S`1TI6@0=cLg051@D00Y:BT0CTi>04e=C@14A4@0JVYZ07]kN`12@T80:2PX06e]K@1?
Cdl0:b/[03lo?`0n?Sh09bLW059BDP1PH600Cdm?06IVIP1RHV808b<S02`/;021PH40@D5102DU9@1d
M7@0Bd];03<c<`0d=3@0Bd];07]kN`0`<300C4a<06a/K015ADD0820P03lo?`1CDe<0BDU909NGU`1@
D500?Cdm08B4Q021PH40B4Q80410@01cLg<0=3@d01dM7@0^;Rh0Hf=S059BDP2;Rh/0W9bL096AT@0X
:2P0Hf=S05iNGP1hN7P0@T9208:2PP1KFe/0A4A405MGE`0k>c/0=3@d06ATI019BDT0EEEE065QH@14
A4@0PX:205QHF01TI6@0FUYJ03`l?01=CDd0GUiN04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1I
FET0Ng]k05mOG`1iNGT0EUIF04I6AP2PX:00EEEE04M7A`1QHF40I6AT02`/;01SHf<0PX:203hn?P0i
>CT0NGUi07alO01jNWX0PH6104U9B@2VYZH0O7al04U9B@25QHD0MGEe05eMG@1YJFT0Rh^;07moO`22
PX80M7Ad04I6AP2GUiL0TY:B07IfMP2j^[X0a<C408b<S01_Kfl0ZZZZ09^KV`11@D40E5AD0:n_[`1Y
JFT0KFe]0<30`01oOgl0FUYJ08f=S@1gMgL0F5QH08J6QP0i>CT0<S8b06MWI`0l?3`0TY:B06MWI`1]
KFd0L71`03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG04Q8B02a/K40OGem03Xj>P1hN7P0=CDe02LW9`1K
Fe/0[Jf]05eMG@2LW9`0WYjN08>3P`0d=3@0B4Q805QHF025QHD0FEUI06=SH`1cLg<0GemO08N7Q`1^
KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0FEUI0410@00m?Cd0GemO0410@011@D40O7al07IfMP0k
>c/0W9bL04];B`18B4P0O7al06][J`15ADD0E5AD05mOG`0g=cL0D51@05EEE@0d=3@0MgMg07]kN`0Q
8B407AdM02/[:`1]KFd0Bd];000S0410@02<S8`0Rh^;04Q8B02;Rh/0NWYj02TY:@1>CTh0L71`05eM
G@14A4@0M7Ad02l_;`0M7Ad0KVi^06MWI`10@400MgMg05]KF`0[:b/0GUiN071`L02ATI40WYjN0:6Q
X@1:BTX09BDU04M7A`1JFUX0L71`03`l?01kNg/0O7al03Ti>@1NGUh07?ooool06P1JFUX0Ng]k092@
T02HV9P0IFEU03De=@0`<300@d=304i>CP0b<S80;bl_0410@01NGUh0NGUi0;no_`0h>3P061PH01DE
5@0[:b/0`<300<C4a03>c/h0alO709RHV00g=cL0;bl_0P0c<c<07014A4@0De=C06i^KP2:RXX0XJ6Q
0492@P0n?Sh0>c/k03lo?`1TI6@0`<3007]kN`11@D40D51@09FEU@2BTY80Xj>S02`/;00J6QX0@d=3
0;no_`24Q8@0>CTi03De=@1OGel0Kfm_09JFUP1oOgl20451@@1G055AD@1^KVh0OGem0820P01?Cdl0
Jf][07EeM@1RHV80BDU908B4Q03De=@0^KVi0<k>cP2@T900P820059BDP0e=CD0>3Ph07YjNP1YJFT0
Ogmo04e=C@1>CTh0=CDe02<S8`0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^08J6QP2HV9P0
ZZZZ0;Ng]`2RXZ80[jn_0:2PX01gMgL0[jn_08Z:RP1_Kfl0YJFU0<O7a`2ATI40ZJVY059BDP1DE5@0
DU9B05UIF@1FEUH0;Bd]024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z:RX09BDU08:2PP31`L40
a/K60<O7a`21PH40@41001hN7P0O7al0EeMG04A4A02BTY80GemO04Q8B013@d<0=SHf03<c<`0e=CD0
?clo05MGE`2RXZ80Hf=S03@d=00c<c<0BTY:0080KVi^00l0>3Ph0492@P2:RXX0Fe]K05EEE@0n?Sh0
9bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40JFUY01PH600I6AT0100F5QH0B@0I6AT0<C4a0492@P0h>3P0
CDe=03`l?00Y:BT0:RXZ03`l?02EUID0WYjN030`<00L71`0>CTi06IVIP1JFUX0/;2`06][J`1jNWX0
_[jn0=WIf@0n?Sh0=3@d03lo?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF06i^KP0J6QX0
5ADE01/K6`0[:b/0=CDe06MWI`3?cll0iNGU0;Bd]00O7al07AdM020P800Z:RX0L71`06a/K010@400
>SXj03<c<`0e=CD0>CTi04Q8B02OWil0Ogmo03Ti>@12@T80:b/[04E5A@2_[jl0UIFE05ADE01RHV80
Ng]k05QHF00/;2`0NGUi06][J`2MWId0AdM702<S8`0N7Qh00P0G5aL0<@0I6AT05ADE01DE5@0I6AT0
=3@d0=KFeP3@d=00W9bL05IFEP1lO7`0YJFU03Xj>P0i>CT0@41003/k>`1?Cdl0Ph>307emO@1YJFT0
FUYJ071`L02EUID0WYjN09ZJVP1lO7`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0De=C07alO01JFUX0
6a/K01`L700R8R80GemO08J6QP1@D500AdM70410@015ADD0EUIF0:b/[02m_Kd0bLW906=SH`1aLG40
4Oooool000oooooo07P0I6AT055AD@25QHD0ADE506IVIP0h>3P0Y:BT08B4Q00l?3`0B4Q804E5A@0/
;2`0ADE505ADE01GEeL08b<S059BDP15ADD09RHV04i>CP0_;bl05ADE02l_;`0T92@0<c<c03De=@0J
6QX0?Cdm02LW9`1CDe<0JFUY03Xj>P0n?Sh0IfMW03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L
71`0De=C059BDP0n?Sh0F5QH0451@@1DE5@0?Cdm04I6AP2GUiL0SHf=05IFEP0^;Rh0K6a/0410@00Z
:RX0Fe]K05ADE014A4@0BDU904e=C@12@T80Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1R
HV80=cLg02LW9`0`<300IfMW03/k>`14A4@0GUiN06e]K@0e=CD0ATI606a/K01:BTX0b<S808^;R`1C
De<0JVYZ04E5A@1[Jf/0BDU907emO@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1d
M7@0IVIV07QhN01BDU80YjNW06e]K@0o?cl0F5QH07=cL`0n?Sh0M7Ad04Y:BP1IFET0P82004U9B@2H
V9P0IfMW06EUI@28R8P305ADE01E04Y:BP17AdL0B4Q8065QH@28R8P0@d=306e]K@1NGUh0QhN705EE
E@1MGEd0CTi>04a<C02JVYX0Hf=S04];B`0n?Sh0KVi^034a<@1bLW80TY:B04=3@`1BDU80PX:207in
OP1ZJVX0MGEe05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0XZ:R08>3P`1dM7@0@T9204Y:
BP2:RXX0SHf=06YZJP2d];@0dM7A05EEE@18B4P0SHf=09ZJVP0l?3`0BDU90:BTY01:BTX0=cLg071`
L01hN7P0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0:RXZ0492@P10@400VYZJ06MWI`20P800Jf][02PX
:01EEED0NGUi05UIF@1@D500[jn_03Ph>02;Rh/0Kfm_03Ti>@2NWYh0K6a/02LW9`0n?Sh0^k^k03/k
>`0204a<C01@06QXJ01:BTX0BDU906MWI`2DU9@0?3`l0410@027QhL0DE5A08>3P`0];Bd0ADE50820
P021PH40CDe=05IFEP1cLg<0=SHf04=3@`1XJ6P0RXZ:06UYJ@16ATH0F5QH05UIF@0R8R80VIVI07If
MP1CDe<0GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04Q8B00P8200BTY:051@D00j>SX0:BTY02d]
;@1YJFT0=SHf024Q8@1IFET0QhN704Y:BP26QXH0QHF504];B`1?Cdl0KFe]05EEE@11@D40[jn_04U9
B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0IVIV05eMG@1QHF40TY:B0:>SX`1XJ6P0;Rh^05MG
E`1WIfL0NWYj04Y:BP22PX80UYJF05IFEP1TI6@Looooo`0N04U9B@1?Cdl0@D5104i>CP1hN7P0S8b<
079bLP1MGEd0WIfM096AT@2?Shl0SHf=06YZJP14A4@0?clo08j>SP0X:2P05ADE05iNGP2ZZZX0LW9b
07moO`2c/k<0M7Ad04m?C`0O7al07AdM028R8P0/;2`0Cdm?0P1;Bd/03@2:RXX0Hf=S03Xj>P0c<c<0
=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<059BDP24Q8@00P0K6a/09`0e=CD0Z:RX04m?C`1`L700
EUIF059BDP1=CDd0>CTi04E5A@1ADE40=cLg03<c<`0e=CD0?clo05QHF01YJFT0Rh^;07YjNP1VIVH0
NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0Ogmo030`<00O7al0820P038b<P2QXJ40HF5Q04U9B@1=CDd0
8B4Q01lO7`0P82007alO02<S8`02024Q8@0?030`<012@T80GemO09>CT`32`/80WinO0:RXZ03Hf=P0
Y:BT04=3@`0g=cL0K6a/05mOG`17AdL0NWYj0080alO705H0clo?0451@@0V9RH08b<S02LW9`18B4P0
@T9203@d=01ADE40O7al06ATI01OGel0HV9R03`l?00R8R8092@T06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03hn?P2ATI40Hf=S04];B`14A4@0<C4a02h^;P0Y:BT0>3Ph07=cL`2MWId0
R8R805aLG011@D40;2`/034a<@1mOGd0UIFE09jNWP2EUID0:RXZ01`L700I6AT06a/K01dM7@0_;bl0
HV9R0;Bd]03Cdm<0WinO02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0AdM704Q8B017AdL0
?clo02LW9`0Y:BT0>SXj09nOW`12@T807QhN01/K6`0M7Ad0=3@d08N7Q`32`/80TI6A08:2PP3=cLd0
hN7Q096AT@21PH40QhN70:6QX@80Ti>C02`0[Zj^0:VYZ@2_[jl0Xj>S0;bl_02h^;P0>3Ph02/[:`11
@D40GEeM09>CT`2>SXh0WinO0<?3``2a/K40@d=302XZ:P0T92@0;bl_07emO@18B4P0@41003<c<`0`
<300;2`/02l_;`1<C4`0XJ6Q04];B`1=CDd0?Shn04Y:BP1BDU80S8b<0<K6aP2:RXX0LW9b055AD@1?
Cdl0>SXj07YjNP1/K6`0N7Qh04Q8B0<06ATI03806QXJ01LG5`0H61P05ADE01HF5P0W9bL0][Jf09ZJ
VP2ATI40PX:208J6QP2[Zj/0I6AT059BDP13@d<0C4a<079bLP2ATI40X:2P04a<C026QXH0PX:207Yj
NP1PH600Fe]K05eMG@1<C4`0c<c<0;no_`3;bl/0`L7102d];@0U9BD0ADE5075aL@0X:2P092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0/k>c07UiN@25QHD0YZJV06MWIa7ooooo000?oooo
o`3o079bLP1@D500SHf=04M7A`2?Shl0?clo07moO`1kNg/0=SHf05aLG01^KVh0A4A403`l?013@d<0
Hf=S02l_;`16ATH0ADE502LW9`0j>SX0BDU9020P800_;bl08R8R03<c<`0j>SX07QhN04a<C00I6AT0
BDU906EUI@1@D500@d=306ATI00U9BD0CDe=05ADE00e=CD0;Bd]01LG5`11@D409BDU05YJFP1ADE40
:BTY04M7A`1ADE40EEEE04];B`0m?Cd0FEUI061PH01JFUX0=SHf07MgM`16ATH05QHF02h^;P13@d<0
A4A4051@D01?Cdl0?clo055AD@1ZJVX0Cdm?020P801RHV80E5AD01XJ6P1ADE40G5aL03<c<`0^;Rh0
<S8b06a/K00n?Sh0@d=306IVIP1dM7@0?3`l04E5A@1YJFT0BDU90<30`02TY:@0EEEE07alO012@T80
K6a/03Xj>P2;Rh/0JFUY03De=@0b<S80JFUY065QH@1ZJVX0X:2P09bLW01NGUh0K6a/05UIF@24Q8@0
E5AD0;6a/@1`L700A4A405=CD`1cLg<0@D5107=cL`16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0
QXJ6051@D017AdL0ADE5055AD@1RHV80AdM705QHF02BTY80@D51096AT@1NGUh0QHF50451@@1bLW80
MGEe04e=C@2>SXh0OWin038b<P15ADD0S8b<04];B`1XJ6P0UYJF055AD@0f=SH0IFEU07UiN@1RHV80
JFUY04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin079bLP1eMGD0IFEU03/k>`25QHD0
S8b<075aL@2_[jl0b/[:09jNWP1jNWX0WYjN09>CT`13@d<0MGEe0<?3``29RHT08B4Q02/[:`1aLG40
Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Rh^;05mOG`2OWil0WIfM06IVIP1ADE40
PH6104I6AP1JFUX0YJFU05EEE@1lO7`0M7Ad02DU9@1`L700HF5Q03<c<`0l?3`0^k^k07UiN@1RHV80
IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2NWYh0GemO09BDU01TI6@0>SXj04i>CP22PX80
F5QH065QH@1bLW80E5AD02h^;P0T92@0Bd];05QHF00m?Cd0GEeM05YJFP1<C4`0RHV906EUI@1FEUH0
FEUI07YjNP0i>CT0@41005QHF012@T80IfMW051@D00c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0
Bd];000S0451@@1eMGD0P82003dm?@1lO7`0UYJF05QHF01IFET0OWin05mOG`0b<S80UIFE06=SH`0j
>SX0IfMW03dm?@0a<C40LW9b07moO`13@d<0G5aL04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1N
GUh0B4Q803Lg=`28R8P0P82005MGE`1QHF407?ooool03@0k>c/0<C4a02LW9`0W9bL0:b/[04Q8B01R
HV80U9BD0<;2`P3:b/X0Ti>C02`/;00H61P00P0G5aL0301>CTh0NGUi04a<C022PX80Ng]k04e=C@0^
;Rh0@d=3096AT@1YJFT0DE5A02d];@807AdM08L0<c<c04=3@`1BDU80DU9B06=SH`0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0l?3`0QXJ602@T900L71`0>c/k08N7Q`0U9BD0A4A407Ui
N@1CDe<0=CDe02`/;00c<c<0=CDe04a<C013@d<0;bl_03hn?P18B4P0@4100492@P1oOgl0E5AD04];
B`14A4@0@T9209RHV02k^k/0VYZJ05UIF@0M7Ad07QhN01dM7@0V9RH0R8R809fMW@1@D500:RXZ01lO
7`0Q8B40<c<c0492@P1JFUX08R8R04=3@`1>CTh09bLW02/[:`2;Rh/0^KVi0;Rh^02QXJ40_Kfm0:BT
Y00i>CT08B4Q02`/;01aLG40?Cdm07YjNP3:b/X0c<c<0;:b/P27QhL0Lg=c07emO@21PH40SXj>07al
O01iNGT0Vi^K061PH01kNg/0HV9R030`<00a<C4071`L04=3@`2c/k<0aLG50;Bd]03<c<`0WinO09NG
U`1dM7@0TY:B08F5Q@1SHf<0Bd];05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Shn?0<[:
bP2SXj<0Vi^K08n?S`1lO7`0P8200<G5a@2f][H0OGem01TI6@0F5QH061PH01dM7@0K6a/071`L05iN
GP2QXJ40_kno09fMW@1kNg/0:BTY01TI6@0E5AD00P0G5aL0<P0F5QH05ADE01`L701=CDd0?clo04i>
CP11@D40;Bd]04=3@`2VYZH0:b/[01XJ6P0K6a/071`L01dM7@1DE5@0QHF506UYJ@2n_[h0f=SH0;jn
_P1jNWX0Fe]K03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^0:^[Z`31`L40Xj>S0<?3
``2JVYX0Cdm?04Q8B01NGUh0^;Rh06i^KP1QHF40EEEE03Ti>@1PH600G5aL02XZ:P0U9BD08b<S0P0X
:2P04`0a<C40HF5Q07]kN`0`<300?Shn04m?C`18B4P0I6AT08B4Q02UYJD0V9RH0<K6aP2^[Zh0XZ:R
08^;R`2k^k/0bLW90<G5a@1gMgL00P0J6QX01`0Q8B405aLG020P800O7al07AdM01lO7`1iNGT00P26
QXH0:P2@T900UYJF09jNWP2a/K40[jn_069RHP1HF5P0CDe=03Xj>P0n?Sh0W9bL0:b/[01SHf<0A4A4
03Xj>P0/;2`0A4A404Y:BP24Q8@0f=SH0=KFeP1dM7@0Ogmo03`l?00Q8B409BDU06a/K01@D500SHf=
079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`L031`L40EUIF02h^;P0f=SH0LW9b0::RXQ7ooooo000?
ooooo`0c06QXJ01:BTX0NGUi03Xj>P1fMWH0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`
<300Bd];02`/;00i>CT0BDU901lO7`1PH600EEEE02LW9`0f=SH07AdM03hn?P1?Cdl092@T04m?C`0]
;Bd0?clo05UIF@1BDU80ADE505]KF`0X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1Q
HF40?clo04m?C`1VIVH0@T9206IVIP1CDe<0Ng]k0080KFe]06T0;2`/079bLP15ADD092@T0410@01A
DE40D51@04I6AP1<C4`0DU9B06=SH`1dM7@0E5AD01dM7@1PH600GemO01dM7@1<C4`0Kfm_03/k>`0^
;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1IFET0Bd];0;jn_P2RXZ80EUIF08:2PP17
AdL0GUiN03Lg=`2YZJT0LW9b0492@P0j>SX0Hf=S04Y:BP0i>CT0TI6A0:VYZ@1aLG40GUiN04=3@`2?
Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5106EUI@0d=3@0MgMg07moO`10@400PH61038b<P1J
FUX0OWin04Q8B00o?cl0AdM703Lg=`1CDe<0Hf=S04=3@`24Q8@0@D5107YjNP16ATH0NGUi04M7A`1>
CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0Ti>C055AD@1]KFd0VIVI075aL@1:BTX0N7Qh08R8R01G
EeL0R8R805]KF`26QXH0N7Qh03Lg=`1/K6`0Ng]k04e=C@2UYJD00P24Q8@0PP2KVi/0P82003lo?`24
Q8@0H61P028R8P1`L700]KFe09:BTP1fMWH0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1I
FET0AdM70::RXP1mOGd0H61P05UIF@0h>3P0CDe=07YjNP0k>c/0Ogmo03Ph>01IFET0Lg=c05MGE`19
BDT0KFe]02/[:`15ADD0T92@05EEE@1XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^07EeM@1]
KFd0Fe]K09nOW`2;Rh/0DE5A07emO@2HV9P0LW9b0410@02HV9P0FEUI09^KV`1mOGd0@T9206EUI@2>
SXh0IVIV06MWI`1`L700EUIF03Lg=`0T92@0BTY:06][J`13@d<0Cdm?05ADE010@400UYJF05aLG01<
C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q071`L00l?3`0D51@06i^KP0/;2`09BDU04E5A@2@
T900GemO0451@@20P800FUYJ028R8P1:BTX0N7Qh04A4A01RHV80R8R806ATI00V9RH0BDU908N7Q`1N
GUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0HV9R03Ph>011@D40Lg=c07inOP1PH600;Rh^05MGE`1L
G5`0Kfm_03hn?P1JFUX0V9RH069RHP1HF5PLooooo`0L03<c<`0Z:RX092@T02<S8`0P820071`L01dM
7@13@d<0R8R80<71`@17AdL06a/K01LG5`0E5AD05QHF01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM
7@0R8R80DE5A06QXJ01bLW80KFe]05UIF@80:b/[0P14A4@0D@0d=3@0I6AT02PX:00S8b<0820P028R
8P0b<S80WYjN08B4Q00[:b/0@d=303Lg=`2>SXh0K6a/04E5A@1kNg/0S8b<04U9B@12@T80<S8b04a<
C00k>c/09BDU02XZ:P0/;2`0:b/[04=3@`17AdL0;2`/02h^;P0c<c<0;Rh^079bLP1CDe<0ADE503De
=@0_;bl0MgMg09jNWP1hN7P0FUYJ01`L700K6a/071`L03@d=01hN7P0S8b<07inOP2DU9@0PX:205QH
F01BDU80>c/k030`<00];Bd0>3Ph05=CD`1LG5`0;Rh^05YJFP1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01/K6`0[Zj^0=3@d03Rh^80d=3@0;Rh^02OWil0Vi^K0;Bd]03AdM40_kno0<k>
cP020:b/[00b05YJFP0e=CD0>3Ph04Q8B01cLg<0TY:B07EeM@13@d<0OWin0;:b/P2k^k/0YJFU05]K
F`23Ph<0WIfM0;Fe]@0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO08n?S`2JVYX0^;Rh06IV
IP1PH600Fe]K071`L02OWil0c/k>0=CDe02h^;P08b<S01HF5P0E5AD061PH01hN7P0n?Sh0LG5a0=7A
d@33`l<0DU9B05ADE01_Kfl0=cLg01PH600G5aL301DE5@0;01PH6011@D40>SXj0410@00j>SX092@T
02LW9`1ADE408R8R01LG5`0K6a/00P0P82008P1@D500R8R808J6QP2j^[X0ZJVY05=CD`14A4@0B4Q8
04Y:BP1CDe<0GemO08^;R`30`<00Shn?04a<C01FEUH0RHV9069RHP3Lg=`0jNWY0;jn_P1<C4`0B4Q8
04E5A@1EEED0_kno07YjNP1[Jf/0QhN70:FUY@2b/[80GEeM02/[:`0O7al201/K6`0E024Q8@13@d<0
Q8B403/k>`0_;bl0:RXZ03Hf=P17AdL0OWin0;2`/02=SHd0EEEE08n?S`3Bd]80_kno0<K6aP3IfMT0
eMGE0:b/[01eMGD06QXJ008061PH03805ADE01LG5`0E5AD07AdM06UYJ@2g]kL0I6AT05mOG`2k^k/0
];Bd09NGU`2VYZH0/k>c09:BTP0X:2P07alO028R8P0Y:BT0[Zj^061PH00e=CD0<30`02d];@10@400
Fe]K0:VYZ@3IfMT0gmoO0<c<c01VIVH0@T9207alO00X:2P08b<S069RHP2;Rh/0G5aL0492@P1>CTh0
EUIF07=cL`1kNg/0?Cdm038b<P1ADE40>c/k02PX:00/;2`0=3@d06i^KQ7ooooo000?ooooo`0L079b
LP19BDT0Ti>C04=3@`22PX80F5QH08Z:RP2?Shl0DE5A03Xj>P1?Cdl0@D5103Ti>@1OGel0GUiN03Lg
=`0i>CT0MWIf04I6AP1?Cdl0FEUI01PH600i>CT0ADE504m?C`19BDT07alO04I6AP80D51@02h0HF5Q
02h^;P0`<300K6a/02TY:@1:BTX0HV9R03Ph>00X:2P0?Shn04m?C`0P8200=SHf079bLP0g=cL0D51@
03hn?P0e=CD0IfMW03`l?01_Kfl0PX:204=3@`0W9bL0HF5Q06i^KP0i>CT0BTY:06e]K@12@T80=CDe
06EUI@1JFUX0K6a/07moO`18B4P071`L069RHP1]KFd09RHV04E5A@1IFET0?Shn05ADE00h>3P0L71`
0P12@T802P1XJ6P0RXZ:04i>CP1>CTh0JVYZ03/k>`2MWId0UiNG04Q8B029RHT206YZJP2I03Hf=P1n
OWh0KVi^03Ph>014A4@0GemO06ATI00k>c/0UiNG0:RXZ01ZJVX0GUiN05aLG024Q8@0>c/k06MWI`1o
Ogl0E5AD05iNGP1JFUX0?3`l075aL@1;Bd/0DU9B05EEE@0i>CT0MGEe071`L01HF5P0MGEe0451@@1O
Gel0IfMW055AD@1LG5`0?Shn04M7A`2?Shl0GemO0861P@16ATH0R8R804e=C@1EEED0Bd];04=3@`1d
M7@0P82004e=C@0g=cL0MgMg03Xj>P1IFET0Ph>306MWI`0m?Cd0I6AT065QH@1CDe<0N7Qh05]KF`1h
N7P0NWYj03lo?`1gMgL0R8R805QHF024Q8@0NWYj06m_K`1mOGd0KVi^0410@01hN7P0Rh^;07IfMP29
RHT0a<C408R8R01OGel0U9BD09:BTP1KFe/0?clo09JFUP1cLg<0?Cdm06][J`26QXH0EeMG0:NWY`1Y
JFT0DE5A06][J`1LG5`0:b/[06IVIP12@T80Rh^;06m_K`21PH40K6a/04I6AP1CDe<0Kfm_055AD@1E
EED0UiNG04E5A@1bLW80Shn?03De=@1YJFT0IFEU02h^;P15ADD0TY:B06i^KP1NGUh0EUIF07alO00d
=3@0B4Q806m_K`2:RXX0T92@04Q8B01iNGT0EUIF09bLW029RHT0@D5106IVIP20P800ATI6059BDP1H
F5P0Lg=c03Lg=`0O7al0?Shn06ATI00e=CD0H61P065QH@1;Bd/0TY:B06][J`1<C4`0KVi^08:2PP1<
C4`0BDU900<0GemO02`0EUIF030`<01<C4`0Kfm_02XZ:P0F5QH07alO05EEE@1[Jf/0E5AD08B4Q02M
WId0AdM705YJFP27QhL0@41005ADE027QhL0D51@02PX:01cLg<0B4Q8065QH@2HV9P0IVIV05ADE01^
KVh0NGUi0410@01/K6`0G5aL03Hf=P1DE5@0MgMg02l_;`0Q8B40D51@06m_K`1aLG40?Shn05EEE@2Y
ZJT0>c/k05QHF1cooooo00H0<30`02/[:`0V9RH092@T01lO7`0K6a/201TI6@0403Lg=`1TI6@0R8R8
03hn?P805QHF00`0B4Q80492@P1:BTX0`<3006e]K@0[:b/0820P01dM7@0O7al07QhN05ADE01BDU82
03`l?00906=SH`1:BTX07AdM01lO7`0Z:RX0I6AT08N7Q`1DE5@0AdM70080CDe=02d0N7Qh0;bl_029
RHT0RXZ:08^;R`2SXj<0U9BD07moO`31`L40];Bd04I6AP0T92@0820P01XJ6P0U9BD0<c<c03Lg=`0h
>3P0;2`/02DU9@0_;bl0?Cdm03Ti>@0a<C40@T920:ZZZP24Q8@0;2`/028R8P0S8b<0Fe]K096AT@1?
Cdl0GEeM01dM7@0H61P0820P06YZJP1GEeL0LW9b05=CD`0c<c<0;Rh^02HV9P0T92@00`0O7al0:@0S
8b<0820P02h^;P1^KVh0Ph>3065QH@1mOGd0UiNG0:ZZZP2CTi<0XZ:R07QhN01`L700QXJ60;2`/02K
Vi/0MgMg05iNGP1eMGD0SXj>07]kN`1YJFT0OWin09:BTP2i^KT0f][J0;^k^`2/[:`0Ph>3059BDP1W
IfL0MWIf09>CT`1NGUh0:b/[02`/;01oOgl0XZ:R07=cL`1GEeL0LG5a0080Shn?06`0XZ:R06MWI`1O
Gel0PH6108Z:RP2CTi<0Y:BT0;^k^`2ZZZX0Kfm_0861P@2a/K40IFEU06IVIP1NGUh0P8200<O7a`2[
Zj/0KVi^069RHP26QXH0PX:2069RHP1@D500KFe]07QhN01mOGd0WYjN0;no_`1hN7P0Bd];03Hf=P0n
?Sh0=3@d02/[:`0L71`05ADE01LG5`0H61P0;2`/05]KF`1cLg<0>SXj02DU9@0^;Rh0CTi>03@d=00L
71`07AdM024Q8@0_;bl0I6AT09VIV@1aLG40alO704I6AP0Q8B40820P024Q8@0P82007QhN028R8P0]
;Bd0BDU909jNWP1SHf<0De=C04i>CP2EUID0c<c<0=kNgP1cLg<0CTi>05]KF`1JFUX0G5aL096AT@2d
];@0^KVi0:^[Z`2OWil0Z:RX0:b/[026QXH0E5AD04M7A`1:BTX0EeMG0:JVYP2WYjL0C4a<02<S8`0V
9RH0?3`l051@D01cLg<0RXZ:0:^[Z`1YJFT0O7al0492@P0/;2`0;Rh^05ADE02;Rh/0DU9B05mOG`0W
9bL202`/;00@02<S8`0K6a/0@41006i^KP21PH40IFEU07]kN`1eMGD0OGem08f=S@2f][H0bl_;08Z:
RP27QhL0LG5a06i^KP80P82000<0cLg=08j>SP2=SHd00P2:RXX06`2>SXh0RXZ:07UiN@2;Rh/0R8R8
07]kN`2:RXX0EUIF07QhN02UYJD0UYJF08F5Q@1VIVH0GUiN09:BTP2NWYh0V9RH07=cL`0f=SH08R8R
01dM7@0P8200<C4a02DU9@0];Bd0<S8b05QHF00Aooooo`003oooool0F`1/K6`0@T9205eMG@13@d<0
O7al02h^;P1fMWH0JVYZ03Ph>00j>SX0@D5102d];@0^;Rh0D51@05ADE00];Bd09BDU055AD@0Z:RX0
Fe]K05YJFP0H61P0:BTY02d];@1;Bd/0K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2<S8`0
9RHV05MGE`1/K6`0F5QH03@d=00o?cl0E5AD04];B`10@400FEUI02LW9`1DE5@0GUiN03hn?P1UIFD0
6QXJ03hn?P1^KVh0IVIV04m?C`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];03Xj>P0n?Sh0
NGUi07]kN`0W9bL0De=C069RHP0[:b/0HV9R0820P012@T80G5aL03`l?01dM7@0KFe]04];B`1IFET0
OGem02XZ:P0b<S80IFEU04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P00P21PH40G`1@D500
>c/k0410@01]KFd0BDU909fMW@2o_kl0Ph>306=SH`1YJFT0Q8B405YJFP1mOGd0Vi^K05iNGP1?Cdl0
Ng]k04];B`1WIfL0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU907moO`1=CDd0BDU905=CD`16ATH0
Kfm_04e=C@0m?Cd0SXj>05eMG@25QHD0H61P092@T019BDT0J6QX06i^KP1NGUh0Hf=S08j>SP0a<C40
;Rh^07YjNP1HF5P0JVYZ07UiN@1LG5`0C4a<075aL@2?Shl0LG5a07YjNP1LG5`0W9bL0;Fe]@1@D500
L71`07emO@0c<c<0N7Qh08N7Q`1nOWh0NWYj05YJFP0n?Sh0HV9R08B4Q020P800KFe]0<30`02IVIT0
Jf][0:2PX02XZ:P0Kfm_03<c<`1aLG40UiNG05QHF01JFUX0Rh^;05EEE@2PX:00Lg=c034a<@10@400
EUIF028R8P1ADE40=cLg0080L71`06@0NWYj06][J`1DE5@0;bl_05EEE@1>CTh0EeMG0:BTY01EEED0
?Cdm09:BTP0g=cL0H61P08J6QP1XJ6P092@T05YJFP1mOGd0G5aL05mOG`2BTY80I6AT04a<C01dM7@0
Kfm_08f=S@0e=CD0NWYj04Y:BP1lO7`0QhN703hn?P1MGEd0MgMg06IVIP1>CTh0BTY:07YjNP0k>c/0
6a/K03De=@26QXH0D51@055AD@1NGUh0KVi^065QH@1WIfL0EeMG06][J`20P800Bd];04=3@`1/K6`0
R8R806MWI`1QHF40@D5105MGE`1eMGD0?3`l01lO7`0Q8B40E5AD06YZJP0h>3P0Ogmo0:JVYP15ADD0
DU9B08n?S`0M7Ad0<30`04Y:BP1HF5P0@D5106EUI@0U9BD08B4Q03lo?`1aLG40MgMg07QhN02HV9P0
<c<c05=CD`1GEeL0@D5107alO02>SXh0EEEE02@T900m?Cd0CTi>075aL@0n?Sh0VIVI0;Zj^P12@T80
?3`l7?ooool0=@0l?3`0;bl_02PX:00T92@07QhN01TI6@0G5aL05QHF01DE5@17AdL0BDU909:BTP1U
IFD09RHV04Y:BP1]KFd0S8b<0<k>cP2^[Zh0Ogmo06][J`1EEED0Cdm?04i>CP1WIfL0KVi^051@D00T
92@08b<S0410@00l?3`061PH01XJ6P1KFe/0c/k>09RHV02ATI40/K6a0<_;b`3EeMD0g=cL0=_Kf`3E
eMD0e]KF0<[:bP2m_Kd0Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00805ADE01/07AdM04m?C`1j
NWX0De=C04Y:BP1RHV80Q8B40:VYZ@35aLD0bl_;0<g=c@2UYJD0@T9201XJ6P1RHV80_kno04m?C`1K
Fe/08R8R01LG5`1@D500I6AT04U9B@1OGel08b<S020P800M7Ad00P0L71`201dM7@0E01XJ6P0L71`0
6a/K020P801ADE40I6AT09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b06UYJ@1;Bd/0
@41003De=@0d=3@0>CTi0080NGUi00D0=3@d03Ph>025QHD0_[jn0<W9b@020:BTY0180;6a/@2LW9`0
AdM702h^;P0c<c<0De=C06MWI`1bLW80_;bl05YJFP0Q8B40<c<c0820P02`/;00_;bl0=?Cd`2TY:@0
PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>069RHP13@d<0Bd];05=CD`1SHf<0SHf=0=7Ad@1WIfL0
@d=303De=@2<S8`0`L710>3Ph038b<P0GUiN03hn?P0l?3`0@d=304I6AP1oOgl0AdM705iNGP15ADD0
:RXZ02PX:00];Bd0:RXZ01XJ6P0G5aL0>CTi0<_;b`3EeMD0@D5102<S8`0X:2P0C4a<02LW9`0P8200
7alO02LW9`1<C4`0]KFe04e=C@2IVIT0Shn?01lO7`0L71`07AdM0P0N7Qh301dM7@0@0451@@28R8P0
BTY:04M7A`1?Cdl0QhN70=;BdP3Kfm/0ZZZZ06QXJ00/;2`06a/K01dM7@1[Jf/0QhN70:j^[P80alO7
04P0]kNg08N7Q`2h^;P0P82004=3@`0V9RH09BDU05QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/
K6`0Vi^K0:f][@0];Bd08R8R01/K6`0J6QX05aLG01XJ6P1EEED0M7Ad04Y:BP0m?Cd09BDU030`<01m
OGd0V9RH09bLW01KFe/0B4Q80861P@2_[jl0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3@`0n
?Sh0:2PX05aLG02m_Kd0Lg=c04i>CP0o?cl0<c<c02HV9P0R8R807alO038b<P1NGUh0SHf=04];B`21
PH40BTY:0:NWY`2EUID0Ph>306QXJ01ZJVX0E5AD03De=@0a<C40=SHf02l_;`0P820201dM7@0502LW
9`0Y:BT0;Bd]03Ph>02OWil04Oooool000oooooo0?l0JVYZ04I6AP1TI6@0<C4a061PH01MGEd0_Kfm
061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P11@D40@41002h^;P1;Bd/0410@02<S8`15ADD09bLW
03<c<`0^;Rh09BDU03hn?P0b<S80;Bd]02h^;P0F5QH0:b/[04Q8B00P8200WYjN010@400P8200>3Ph
04M7A`0U9BD08B4Q03De=@16ATH0?clo05mOG`0K6a/0;Rh^05ADE00_;bl0IfMW02h^;P15ADD0GUiN
065QH@0m?Cd0CTi>08B4Q00a<C40;bl_05YJFP1<C4`0>CTi04Q8B00n?Sh09BDU06m_K`1LG5`092@T
03`l?01XJ6P0:b/[03<c<`1kNg/0@D5104M7A`0b<S80OGem07QhN01CDe<0NWYj07]kN`1HF5P0>SXj
05EEE@0i>CT0WinO0:BTY01NGUh0JVYZ04];B`1JFUX0BDU907alO02?Shl0K6a/04M7A`11@D40KVi^
03Ti>@26QXH0];Bd09>CT`1RHV80?3`l0861P@1IFET0OGem08>3P`1GEeL0QXJ608V9R@1DE5@0G5aL
04=3@`1KFe/0HV9R03`l?01MGEd0C4a<04m?C`1cLg<0@d=304M7A`18B4P0;Rh^04];B`1SHf<0@D51
08:2PP0o?cl0EeMG05mOG`1oOgl0EEEE03dm?@1FEUH0HV9R05EEE@2][Jd0DU9B02PX:01UIFD0Fe]K
04i>CP29RHT0D51@02d];@0h>3P0Kfm_05UIF@1]KFd0>3Ph071`L01lO7`0>3Ph05YJFP22PX80>3Ph
05QHF01cLg<0NGUi09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2VYZH0VYZJ06=SH`2e]KD0Ti>C
04];B`0k>c/0NGUi0:NWY`1TI6@0GemO07UiN@1>CTh0^KVi09RHV014A4@0DE5A06QXJ00P8200F5QH
06EUI@1mOGd0PH61079bLP1gMgL0Jf][03@d=01JFUX0B4Q804E5A@2XZ:P0FEUI03lo?`2IVIT0>SXj
05UIF@1eMGD0FEUI02DU9@1EEED0Jf][05]KF`26QXH0YZJV07=cL`17AdL0Ng]k069RHP2JVYX0>c/k
06e]K@13@d<0OGem08^;R`12@T80I6AT08J6QP1UIFD0ADE5051@D01DE5@0@410024Q8@0];Bd0Ng]k
04Q8B01ADE40AdM704a<C01VIVH0I6AT04m?C`1kNg/0MgMg04=3@`1YJFT0NWYj08F5Q@1LG5`0I6AT
01/K6`0k>c/0H61P05EEE@0m?Cd09RHV079bLP1`L70000<0=3@d051@D01lO7`00P1BDU807P1nOWh0
Hf=S0492@P1oOgl0Hf=S03dm?@2FUYH0F5QH059BDP17AdL0ATI60492@P1NGUh0OWin059BDP1mOGd0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0<C4a04A4A027QhL0>CTi0410@1cooooo
02l0?3`l03@d=00X:2P092@T01hN7P0K6a/05aLG01HF5P0E5AD0;2`/075aL@11@D40XZ:R09nOW`2D
U9@0RHV909fMW@2i^KT0JVYZ059BDP1>CTh0BTY:03dm?@0i>CT0?3`l03hn?P11@D40De=C04E5A@13
@d<0Bd];03Lg=`0N7Qh0=cLg09FEU@0];Bd09RHV03Lg=`1YJFT0];Bd0>;RhP3Ph>00emOG09NGU`25
QHD0OWin03Lg=`0202LW9`0Q07AdM01aLG407alO01hN7P0[:b/0DE5A07MgM`1[Jf/0H61P08:2PP1a
LG40WYjN0:b/[024Q8@0GemO051@D01UIFD0Xj>S0;Zj^P27QhL0Z:RX0<c<c02UYJD0HV9R08b<S00m
?Cd0Ph>3051@D01CDe<0;Rh^01hN7P0M7Ad071`L00806QXJ0P0L71`0A`0M7Ad06QXJ01TI6@0T92@0
Cdm?05aLG01bLW80YJFU08R8R025QHD0WIfM0;Vi^@3De=@0`L710;Bd]02ZZZX0[Jf]09FEU@0i>CT0
:BTY02/[:`0h>3P0RHV909>CT`1eMGD0W9bL06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0
CTi>03@d=01<C4`0DE5A04=3@`1_Kfl0FEUI02`/;01<C4`0bLW90;Zj^P3Cdm<0WYjN07EeM@1FEUH0
EEEE055AD@0];Bd0=3@d0410@01YJFT0WYjN07=cL`1WIfL0ATI604E5A@1UIFD0LG5a05ADE00e=CD0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K00T0De=C065QH@19BDT0JFUY04e=C@0/;2`0
8b<S03Ph>01=CDd00P1iNGT0402h^;P0i^KV0:f][@1TI6@0LW9b09JFUP1nOWh0IfMW06UYJ@27QhL0
a<C40<S8b01nOWh0bl_;06EUI@0L71`201dM7@1901hN7P0M7Ad071`L01dM7@0O7al0CDe=03hn?P0V
9RH0:2PX02h^;P1OGel0YJFU0=?Cd`1EEED0AdM7038b<P0];Bd0;bl_07YjNP1?Cdl0D51@09FEU@3A
dM40dm?C08J6QP2=SHd0^;Rh0492@P0S8b<0820P03lo?`1ADE40Bd];061PH00m?Cd0D51@08f=S@3=
cLd0g=cL0:RXZ00R8R80820P028R8P0j>SX0=SHf02d];@0f=SH0WYjN04m?C`20P800FUYJ08Z:RP34
a<@0/[:b079bLP15ADD0Cdm?05=CD`2e]KD0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<
C4`0EUIF03Xj>P1YJFT0?3`l02PX:00202DU9@8092@T00d07AdM024Q8@0j>SX0DE5A065QH@1=CDd0
H61P08B4Q02n_[h0WYjN05MGE`0h>3P0>c/k0080<30`00X0>c/k03<c<`0L71`071`L01dM7@0T92@0
:2PX03<c<`1LG5`0/;2`4Oooool000oooooo0?l0PX:204I6AP1oOgl0DU9B07EeM@1fMWH0clo?07Ee
M@1ADE40:2PX03lo?`1JFUX08B4Q04=3@`1HF5P0Fe]K02`/;01?Cdl0A4A403Ti>@1bLW80<C4a03@d
=00e=CD0CTi>05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0TI6A02d];@0c<c<0C4a<051@
D00J6QX0;2`/03Xj>P1HF5P0?Shn07UiN@0e=CD0?3`l065QH@0g=cL0LG5a04a<C01TI6@0KVi^06EU
I@0h>3P0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1OGel0:BTY07]kN`1GEeL09RHV04];
B`2;Rh/0?clo03De=@2@T900<c<c06QXJ00k>c/0PX:204e=C@0j>SX0EEEE075aL@1MGEd0>3Ph04m?
C`0S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU061PH02CTi<0HF5Q04E5A@0k>c/0MgMg03`l
?01ZJVX0R8R809FEU@1OGel0De=C07=cL`1QHF40Jf][08>3P`18B4P0@T9206e]K@1<C4`0FUYJ04e=
C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1jNWX0ADE504A4A01BDU80Bd];04Y:BP1TI6@0CTi>08N7
Q`1oOgl0J6QX06m_K`1oOgl0KFe]05ADE01FEUH0GEeM04Q8B02^[Zh0CDe=03`l?01PH600BTY:03lo
?`2ATI40Jf][03Lg=`10@400S8b<069RHP25QHD0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eM
G@1cLg<0GEeM0:VYZ@2=SHd0DE5A05YJFP27QhL0:BTY04a<C01lO7`0TI6A061PH030`<00YJFU0492
@P0K6a/0@410096AT@1OGel0F5QH08R8R00i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IV
IP1aLG40DU9B05ADE02<S8`0K6a/03Xj>P1UIFD0?clo03Lg=`2NWYh0IfMW03Xj>P24Q8@09RHV071`
L02<S8`0EUIF01hN7P1UIFD0DE5A03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2TY:@0:BTY07Yj
NP13@d<0O7al07UiN@19BDT0QHF50:RXZ01jNWX0>c/k06=SH`1BDU80B4Q805ADE01JFUX0Ogmo05=C
D`17AdL0C4a<034a<@1?Cdl0Ogmo06YZJP1iNGT0LG5a018B4P0f=SH0BDU9051@D014A4@0Kfm_03Ph
>00f=SH0Cdm?04E5A@0E5AD08b<S05MGE`1^KVh00100F5QH06QXJ01_Kfl092@T04=3@`1cLg<0EEEE
05ADE02YZJT0T92@02TY:@1GEeL0>SXj02d];@1`L700GemO0P1GEeL04@21PH408b<S04E5A@1kNg/0
HF5Q07QhN02ZZZX0>3Ph01<C4`0I6AT0<C4a06EUI@0o?cl0EeMG0;Ng]`0H61P08R8R01cooooo00L0
@T9203De=@0W9bL08b<S01dM7@0J6QX061PH00805ADE01L092@T08F5Q@1MGEd0Ph>30<C4a02:RXX0
QXJ60<_;b`2GUiL0De=C04A4A00f=SH0>CTi04=3@`0i>CT0:RXZ024Q8@0V9RH0<30`059BDP1UIFD0
DE5A06IVIP0204i>CP0M04m?C`0[:b/0>CTi03lo?`19BDT0JFUY0<30`03Kfm/0a/K607QhN037alL0
ZJVY038b<P0I6AT05ADE02TY:@2IVIT0Zj^[08n?S`1iNGT0FEUI03Xj>P0W9bL071`L02d];@1<C4`0
JFUY09FEU@1GEeL00P0S8b<03`0Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80Vi^K08b<S02RXZ80
WIfM05YJFP18B4P07alO01dM7@0201`L701:01XJ6P0I6AT06ATI01`L700M7Ad06a/K01LG5`0h>3P0
BTY:06=SH`1HF5P0FUYJ07AdM032`/80QXJ607AdM035aLD0[:b/07EeM@2f][H0d=3@0<C4a01TI6@0
B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0E5AD06=SH`2TY:@0[:b/07IfMP2RXZ80_;bl0;no_`11@D40
ADE503Xj>P0U9BD08R8R02d];@0k>c/0L71`07=cL`16ATH0[Jf]0<G5a@3<c<`0RHV904M7A`0`<300
;bl_055AD@1bLW80O7al06UYJ@14A4@0PH6102/[:`1`L700NGUi05MGE`1=CDd0De=C061PH01EEED0
WinO05mOG`2YZJT0Rh^;03@d=00J6QX301DE5@03028R8P2?Shl0B4Q80080FEUI01/0HV9R04Q8B01?
Cdl0RHV904m?C`0];Bd0VIVI0<k>cP3;bl/0TI6A065QH@1dM7@0K6a/05MGE`1^KVh0P82009nOW`2d
];@0bLW90=WIf@1mOGd08B4Q01TI6@0L71`07AdM01XJ6P0P82000P0Q8B407P1:BTX0:RXZ02TY:@0W
9bL0:RXZ05MGE`1hN7P0ZZZZ01hN7P0O7al0;2`/04I6AP20P800E5AD05UIF@1]KFd0Ng]k08b<S02F
UYH0WIfM08J6QP27QhL0UYJF02/[:`0M7Ad0?clo04i>CP1MGEd0Xj>S0:NWY`80bl_;00L0XJ6Q09>C
T`2WYjL0Ph>3061PH01QHF40DU9B0080@d=301P0De=C08B4Q02<S8`0_[jn08J6QP1SHf<0Z:RX09fM
W@2=SHd0GemO061PH02>SXh0L71`07moO`1TI6@0VIVI09ZJVP0h>3P0EEEE0;>c/`3GemL0K6a/02HV
9P0N7Qh203hn?P0G02LW9`0Y:BT09BDU02DU9@0S8b<0820P01hN7P0i>CT0@41006m_K`16ATH0MWIf
05ADE02YZJT0?Shn04Y:BP0e=CD0BDU902l_;`0/;2`0=3@d020P800I6AT00P0L71`01@0Q8B409bLW
03@d=02:RXX0YZJV017ooooo000?ooooo`3o06EUI@13@d<0PX:205MGE`1[Jf/0@d=30:FUY@2EUID0
H61P02h^;P12@T80B4Q802PX:01NGUh0Fe]K02<S8`0R8R80GEeM051@D00g=cL0HF5Q00h>3P0X:2P0
C4a<05IFEP1IFET02`/;01LG5`1QHF40Cdm?069RHP12@T802`/;08:2PP1@D500>CTi05MGE`0_;bl0
820P04m?C`0c<c<0;Bd]01dM7@1cLg<0=CDe03Ti>@15ADD05aLG05]KF`13@d<0J6QX07inOP1=CDd0
7QhN03<c<`1nOWh0B4Q802/[:`1JFUX0BTY:03Xj>P19BDT0C4a<02XZ:P1^KVh0Hf=S02h^;P0d=3@0
NGUi0451@@0_;bl0T92@03dm?@15ADD09bLW07QhN02:RXX0ATI6065QH@1fMWH0KVi^03Lg=`1/K6`0
A4A408V9R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1mOGd0SHf=07alO01:BTX0@T9209bLW01UIFD0
YjNW0;>c/`2XZ:P0K6a/06UYJ@1dM7@0Fe]K06ATI02_[jl0HV9R04m?C`1`L700BDU907IfMP1_Kfl0
CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN7059BDP1JFUX0L71`05EEE@1?Cdl0FEUI03lo?`2HV9P0
T92@05ADE01LG5`0Rh^;06i^KP1@D500C4a<03<c<`1@D500WIfM071`L019BDT0NGUi01lO7`0[:b/0
Jf][08B4Q014A4@0?clo09nOW`0R8R80Bd];051@D020P800[jn_034a<@1FEUH0V9RH05iNGP1PH600
M7Ad03/k>`1[Jf/0RXZ:059BDP1[Jf/0SHf=08b<S02>SXh0Y:BT0:2PX00m?Cd0UIFE0:b/[021PH40
9bLW04A4A01kNg/0>CTi06YZJP2LW9`0ATI607]kN`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0
Jf][055AD@0`<300A4A406YZJP0b<S80M7Ad04A4A00Z:RX0IfMW06QXJ01QHF40W9bL02d];@0j>SX0
JFUY03Hf=P0X:2P0Ogmo06UYJ@15ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;01_Kfl0
@41008Z:RP1fMWH0:2PX02h^;P1ZJVX0H61P03Lg=`22PX80FUYJ038b<P0R8R80<30`05iNGP0i>CT0
I6AT08R8R01ADE40Bd];065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg04Y:BP0P8200
ADE507IfMP1=CDd092@T01`L7013@d<0Fe]K000S028R8P27QhL0WYjN05]KF`19BDT0Lg=c01LG5`0Y
:BT0FEUI071`L01DE5@0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0E5AD079bLP0l
?3`0OGem09JFUP1GEeL0:RXZ02@T9012@T80KVi^04Y:BP1HF5P0]kNg06UYJ@11@D407?ooool01@1H
F5P0G5aL03<c<`0P82007AdM00806QXJ02007AdM02LW9`0f=SH0UIFE09>CT`2YZJT0]KFe09bLW02]
[Jd0WIfM0:BTY01CDe<0?Shn038b<P0^;Rh0:RXZ03De=@0Y:BT0820P02d];@0j>SX0B4Q8051@D02H
V9P0Xj>S09VIV@1eMGD0DE5A05ADE014A4@0<S8b02`/;080N7Qh00L0IFEU07inOP2MWId0Y:BT08j>
SP1XJ6P09bLW00805QHF00L0RHV909BDU010@400@41002PX:00F5QH05aLG00805ADE01T05QHF028R
8P1?Cdl0OGem03hn?P0L71`06ATI038b<P2][Jd0c<c<0<S8b02;Rh/0JFUY071`L02k^k/0e=CD0:JV
YP1iNGT0GemO04];B`15ADD0@410038b<P0N7Qh06ATI00805aLG04@06ATI01LG5`0L71`0DU9B05aL
G01?Cdl0;Bd]03<c<`1?Cdl0O7al09BDU017AdL0L71`06YZJP0a<C40H61P0;6a/@2ATI40MGEe09>C
T`34a<@0_Kfm0:ZZZP2e]KD0TI6A07emO@12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO02d]
;@0J6QX05QHF01DE5@0I6AT0:2PX034a<@1NGUh0Y:BT08B4Q02KVi/0eMGE0;^k^`1XJ6P0Kfm_075a
L@28R8P0GEeM03@d=00[:b/09bLW08Z:RP1PH600>SXj02h^;P0i>CT0CTi>05=CD`2GUiL0K6a/09ZJ
VP1nOWh0RHV907moO`H05ADE00<0<C4a08Z:RP13@d<00P1?Cdl05`1PH600T92@0861P@0a<C40B4Q8
059BDP1IFET0Y:BT0<S8b02VYZH0Jf][05YJFP1HF5P0Fe]K04E5A@26QXH0[jn_0>?Sh`2n_[h0TY:B
04e=C@0V9RH06a/K008071`L00@07AdM01lO7`0f=SH0>SXj0P0W9bL01@0U9BD0;bl_09>CT`2MWId0
Y:BT00807AdM02H06QXJ03`l?01bLW80RXZ:0:NWY`1>CTh0=cLg04e=C@1>CTh0G5aL07IfMP1ZJVX0
UIFE08Z:RP0d=3@0JVYZ0:>SX`39bLT0cLg=0=CDe030`<00EUIF02`/;00l?3`0QXJ6096AT@1;Bd/0
@d=303lo?`13@d<0AdM704I6AP1?Cdl0T92@0<?3``26QXH0CTi>0:FUY@80XJ6Q00d0WinO07EeM@1B
DU80@41006=SH`2<S8`0^k^k08:2PP0o?cl0@d=3071`L02d];@0<S8b00807AdM00<0<c<c04I6AP0U
9BD00P0U9BD06`0R8R808B4Q020P800N7Qh0;Bd]03dm?@1SHf<0IVIV05IFEP1PH600S8b<02/[:`1G
EeL0=SHf0451@@0T92@09RHV02`/;00M7Ad071`L01hN7P0M7Ad08b<S03Hf=P1NGUh0^[Zj0:RXZ00A
ooooo`003oooool0cP1]KFd0@d=306QXJ01LG5`0I6AT038b<P1TI6@0FUYJ055AD@0W9bL0>SXj01lO
7`0I6AT0>3Ph04=3@`0K6a/04Q8B0451@@15ADD0;bl_05aLG00J6QX07AdM02`/;01>CTh0GEeM03Xj
>P0J6QX0BTY:04A4A01aLG40Hf=S02TY:@1eMGD0>c/k03lo?`1QHF40DE5A02PX:01:BTX0;bl_061P
H00a<C40GUiN02PX:017AdL0H61P03Ph>01HF5P092@T051@D021PH40L71`055AD@0h>3P0][Jf02<S
8`0N7Qh0GUiN05aLG01BDU80RXZ:03De=@0K6a/0IVIV07MgM`11@D40<C4a08B4Q00Q8B407QhN08N7
Q`1?Cdl0ATI601/K6`1DE5@0LW9b0410@01VIVH0RHV904M7A`0X:2P0HF5Q0410@01hN7P0clo?03De
=@0i>CT0ATI606ATI01UIFD0Ogmo0;fm_@11@D40>SXj03De=@1aLG40FEUI09nOW`2k^k/0/K6a04=3
@`1YJFT0K6a/04Y:BP16ATH0MWIf05MGE`1CDe<0DE5A03Ph>017AdL0HV9R04A4A01;Bd/0:b/[03dm
?@1SHf<0?Cdm079bLP0X:2P0;Rh^0410@016ATH0DU9B04I6AP0T92@0KFe]075aL@18B4P0EUIF06e]
K@1/K6`0Cdm?06EUI@1TI6@0>CTi07EeM@1QHF40BDU907alO01`L700;bl_06m_K`1WIfL0<S8b04U9
B@2<S8`0G5aL05IFEP0_;bl0JFUY09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP1QHF40Rh^;04Y:
BP0];Bd0AdM707=cL`1]KFd0I6AT0;6a/@2b/[80H61P0:j^[P2k^k/0Lg=c03<c<`1HF5P0U9BD05eM
G@10@400J6QX0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a06][J`24Q8@0CDe=05]K
F`1CDe<0;bl_07AdM01hN7P0@d=30:>SX`1SHf<0:b/[065QH@11@D40IFEU09JFUP0m?Cd061PH0P1N
GUh0DP17AdL0PX:20:2PX01dM7@0<C4a06m_K`1FEUH0S8b<01`L702NWYh0HF5Q06][J`1@D5007alO
04Q8B02XZ:P0Kfm_024Q8@0a<C40KVi^0492@P1<C4`0GUiN096AT@0_;bl0>3Ph04Y:BP16ATH0H61P
09BDU01LG5`0F5QH05aLG00W9bL0Fe]K06][J`1/K6`0@d=305MGE`0E5AD06a/K05ADE01jNWX0GUiN
01lO7`16ATH0E5AD00h>3P16ATH0Q8B405eMG@1FEUH0JFUY04A4A00a<C40Lg=c04e=C@0^;Rh0Ti>C
059BDP1ADE40Hf=S06YZJP1gMgL0JVYZ06EUI@1TI6@0Kfm_079bLP0g=cL0Q8B40;2`/015ADD09bLW
02@T9011@D40Jf][03/k>`29RHT0_kno071`L012@T8Looooo`0L07=cL`1=CDd0Bd];03/k>`0[:b/0
:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k0<S8b02f][H0Xj>S0;>c/`1>CTh0RXZ:065QH@0a<C40
:2PX03Hf=P0`<300:RXZ0410@00P82008R8R02PX:080=SHf01T0N7Qh0;6a/@2:RXX0Vi^K04a<C00e
=CD0:BTY038b<P1XJ6P0Bd];03<c<`1XJ6P0FUYJ05]KF`2SXj<0I6AT04E5A@1DE5@0:BTY01LG5`1j
NWX0D51@01lO7`0T92@06ATI00D05ADE0P0F5QH0>`1RHV80V9RH06YZJP1dM7@0[jn_09^KV`27QhL0
W9bL0=;BdP3<c<`0][Jf07alO02YZJT0c/k>0<C4a01XJ6P0=SHf024Q8@0Y:BT0D51@06IVIP14A4@0
9bLW01XJ6P0I6AT071`L03dm?@1oOgl0LW9b04Q8B00Q8B407alO04M7A`1TI6@0OWin0<K6aP16ATH0
CTi>01`L700^;Rh0CDe=04m?C`0R8R80;Rh^0:^[Z`2CTi<0F5QH071`L00d=3@0<S8b0;:b/P2HV9P0
W9bL0;Bd]02:RXX0T92@08N7Q`1[Jf/0:RXZ00805ADE0P0G5aL07P0P82007AdM02DU9@1TI6@0[:b/
0:RXZ03WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti>@0];Bd0KFe]02<S8`0L71`07AdM
01`L700O7al0<c<c06ATI01UIFD0Ph>305mOG`1UIFD0OGem01HF5P@05ADE06405QHF01DE5@1KFe/0
QHF50451@@12@T80RXZ:0::RXP2?Shl0UIFE07MgM`14A4@0:b/[06ATI02>SXh0`l?30;Ng]`1?Cdl0
B4Q803De=@1_Kfl0alO70=;BdP3Hf=P0UIFE09ZJVP1/K6`0CDe=0451@@0Q8B4071`L01HF5P0V9RH0
Cdm?034a<@0^;Rh0?Shn06=SH`1dM7@0OWin0;^k^`2SXj<0Jf][03De=@0O7al0F5QH04M7A`1DE5@0
LG5a03dm?@0Z:RX0C4a<05=CD`13@d<07alO05QHF01kNg/0XZ:R0;fm_@2JVYX0XZ:R0<o?c`3De=@0
e]KF092@T00N7Qh0;bl_06m_K`2EUID0UYJF06=SH`1?Cdl0ADE503dm?@12@T80BTY:05ADE02WYjL0
_Kfm0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Shn04m?C`2JVYX0UIFE079bLP14A4@0
@T9205aLG02:RXX08B4Q00807AdM00<0:RXZ02/[:`0V9RH00P0U9BD00`0S8b<08B4Q020P800202DU
9@0F03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L021PH40=cLg034a<@0M7Ad08R8R02LW9`0M7Ad0
71`L01hN7P0T92@0?clo08b<S02j^[X0d=3@0<71`A7ooooo000?ooooo`0/06YZJP17AdL0L71`0492
@P1kNg/0HV9R07IfMP21PH40K6a/02XZ:P1>CTh0I6AT03/k>`0h>3P0?Shn04U9B@0_;bl0Bd];03Hf
=P0U9BD0Hf=S03hn?P0h>3P0<c<c03Xj>P1bLW80EeMG01`L700o?cl04a<C03`l?01HF5P0=CDe07Ee
M@0I6AT08B4Q04I6AP1IFET09BDU02PX:00G5aL0EEEE03De=@1OGel201dM7@1404=3@`0m?Cd0De=C
03lo?`17AdL0EEEE065QH@18B4P0?Cdm0:6QX@0^;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D50071`L
07UiN@1dM7@0?Shn03@d=01bLW80@D5101lO7`1iNGT0DE5A04];B`0[:b/0B4Q807AdM016ATH0IfMW
075aL@1RHV80;Rh^05iNGP0o?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ06][J`2e]KD0MWIf
04e=C@11@D40PH6106=SH`1oOgl0_Kfm0;6a/@1QHF40H61P07MgM`1JFUX0GemO08:2PP1DE5@0MWIf
07inOP1]KFd0Fe]K05aLG01IFET205]KF`2I05=CD`1RHV80<C4a07QhN01?Cdl0?3`l04m?C`0[:b/0
Fe]K069RHP12@T80Jf][0492@P0g=cL0K6a/08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028R8P0
9bLW06EUI@1/K6`0=cLg08:2PP20P800A4A403<c<`28R8P0CDe=075aL@1@D500HV9R06EUI@1HF5P0
>CTi09RHV01DE5@0BDU905IFEP1;Bd/0X:2P08Z:RP1EEED0FEUI09^KV`0N7Qh07alO06YZJP2YZJT0
Lg=c0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80NWYj01PH601CDe<0Q8B404=3@`0j>SX0
B4Q803Ph>01QHF40KVi^065QH@1KFe/0;Bd]0:6QX@2@T900<30`071`L00n?Sh04A4A07MgM`2;Rh/0
:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@1JFUX0;bl_051@D01MGEd0OGem04];B`1fMWH0
EeMG08>3P`0m?Cd0Jf][05YJFP1`L700EeMG02PX:00W9bL0GUiN07MgM`10@400A4A4075aL@0K6a/0
7alO03lo?`1WIfL0GemO03dm?@1@D500>c/k0451@@20P800KVi^04];B`1bLW8071`L04I6AP14A4@0
I6AT0410@01ADE408B4Q030`<01JFUX0DU9B01lO7`0P8200BDU905EEE@0c<c<0GEeM07AdM01MGEd0
IfMW07alO01iNGT0ADE506QXJ01ADE40820P05EEE@1ADE40GUiN0080Kfm_01<0FUYJ04U9B@1oOgl0
HV9R07=cL`1RHV80=CDe075aL@2QXJ40FUYJ03@d=00M7Ad0>3Ph06i^KP0h>3P0Xj>S0;2`/01iNGT0
?Cdm01cooooo00`0Ph>305MGE`1LG5`0H61P06YZJP20P800N7Qh07AdM01gMgL0PH6108Z:RP37alL2
0<[:bP0X0=7Ad@2h^;P0D51@07inOP24Q8@0I6AT05eMG@1<C4`0@D5103Hf=P14A4@0;2`/024Q8@0`
<300@41004];B`1ZJVX0O7al06=SH`29RHT0CDe=03hn?P1EEED0I6AT03hn?P16ATH0DU9B03De=@1i
NGT0HV9R04I6AP29RHT0WIfM05QHF019BDT0<30`0820P00c<c<07QhN01LG5`P05ADE03/09RHV0;fm
_@33`l<0QHF504Q8B00i>CT0>3Ph05QHF033`l<0f=SH06m_K`1VIVH0Ti>C0=;BdP2<S8`0Ph>306e]
K@1JFUX0<C4a01hN7P0[:b/0>3Ph04];B`1BDU80DE5A05QHF01jNWX0XJ6Q06m_K`0e=CD08b<S01dM
7@0O7al0BTY:04m?C`2:RXX0G5aL03/k>`0M7Ad07QhN03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8
B01GEeL09BDU024Q8@1WIfL0EUIF061PH02=SHd0IFEU05YJFP1[Jf/0AdM703Hf=P0201DE5@0C01PH
600O7al071`L01PH600L71`0@41006][J`24Q8@0emOG0=7Ad@1hN7P0:BTY020P800V9RH09BDU04A4
A00k>c/0?Shn03@d=00401dM7@0501`L700M7Ad0:BTY07EeM@1[Jf/00P1ADE401028R8P06ATI01DE
5@0F5QH201DE5@0R01HF5P0E5AD07QhN08Z:RP1EEED0Lg=c0:VYZ@27QhL0[:b/0:ZZZP2RXZ80]kNg
065QH@1]KFd0R8R808B4Q02][Jd0alO709RHV02/[:`0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0De=C038b<P0_;bl0DU9B05aLG0<0KFe]0440BDU90410@01IFET0WIfM0;Bd]02g]kL0
CDe=065QH@1BDU80=3@d04m?C`1@D500F5QH038b<P1IFET0M7Ad02@T900I6AT08B4Q07YjNP2c/k<0
YJFU08n?S`29RHT0UYJF08Z:RP1WIfL0R8R802/[:`1<C4`0TI6A0<;2`P3Hf=P0bLW90<71`@2`/;00
Shn?06a/K01?Cdl0De=C0:2PX030`<00dM7A08n?S`2k^k/0fMWI0;fm_@29RHT0EeMG061PH01hN7P0
TY:B0<K6aP18B4P0L71`06MWI`12@T80GEeM09NGU`0O7al07QhN01dM7@0Z:RX071`L02<S8`0302DU
9@0J02<S8`0P82009BDU02PX:00b<S80HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0YZJV04Q8B00a<C40
8B4Q028R8P0V9RH0:BTY02/[:`17AdL0E5AD09nOW`2ZZZX0PX:207emO@33`l<Aooooo`003oooool0
o`1KFe/0B4Q806a/K01;Bd/0CDe=055AD@1UIFD0LW9b02TY:@0J6QX092@T04a<C00j>SX0<30`02TY
:@1JFUX0<C4a03hn?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0R8R80A4A405ADE00L71`0@D510492
@P1CDe<0GemO04];B`1TI6@0<c<c03De=@0o?cl0FEUI02DU9@19BDT08R8R065QH@14A4@0Hf=S03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05ADE01:BTX0Vi^K04A4A00Y:BT0ADE506MW
I`1KFe/0J6QX05MGE`0_;bl0SXj>07inOP1ADE40<S8b08n?S`1GEeL08B4Q07]kN`1=CDd0FEUI02l_
;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0Jf][02<S8`11@D40ZJVY07=cL`2BTY80QXJ608Z:
RP0d=3@0<S8b08B4Q02_[jl0PX:206e]K@2OWil0C4a<051@D02:RXX0X:2P06ATI016ATH0EEEE059B
DP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1cLg<0A4A403Xj>P1=CDd0B4Q805aLG01nOWh0:BTY05aL
G010@400E5AD07UiN@1@D500A4A405]KF`0Y:BT0M7Ad08f=S@1@D500Cdm?08Z:RP2FUYH0CTi>05aL
G00b<S80=SHf08n?S`2@T900D51@07]kN`0c<c<0:BTY06m_K`1iNGT0ATI6038b<P1kNg/0@D5104];
B`1@D500IfMW05eMG@0d=3@071`L06i^KP1]KFd0E5AD07QhN00^;Rh0EEEE06m_K`1ADE40BDU909NG
U`1kNg/0RXZ:0:ZZZP2`/;00NWYj0;jn_P3:b/X0QhN703Ti>@0h>3P0Ogmo07YjNP1:BTX0Q8B40492
@P1]KFd0S8b<069RHP0f=SH0EeMG01TI6@0c<c<0HV9R05UIF@1XJ6P0;Bd]059BDP1YJFT08R8R05MG
E`0n?Sh0:BTY06m_K`1eMGD0;2`/071`L015ADD0@41006=SH`0d=3@05QHF06MWI`1VIVH0DU9B075a
L@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0IfMW04e=C@1aLG40N7Qh061PH00k>c/0RXZ:07Ad
M00d=3@0ATI608B4Q01?Cdl09bLW03`l?01oOgl0IVIV03Xj>P1=CDd0GUiN05=CD`21PH40MWIf04Q8
B01/K6`0@41006QXJ01:BTX0HF5Q030`<01MGEd0>SXj03De=@1XJ6P0IVIV02TY:@0V9RH0Jf][08B4
Q0000`1BDU80HV9R07=cL`0203Xj>P0N06=SH`1`L700@T9205UIF@0k>c/09RHV0820P01DE5@0FEUI
05EEE@1^KVh09RHV01PH601WIfL0MWIf07AdM01aLG40E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3
071`L00o?cl0Cdm?096AT@1SHf<0;Rh^7?ooool0=@1/K6`0IfMW04i>CP19BDT0CDe=04];B`1>CTh0
C4a<04U9B@1NGUh0/K6a0;bl_02n_[h0/;2`0:b/[02OWil0Y:BT0:NWY`2=SHd0Fe]K05aLG01MGEd0
J6QX0820P010@400;bl_03De=@11@D40?Shn04Y:BP1lO7`0M7Ad07MgM`1UIFD0<c<c05IFEP1OGel0
BTY:05eMG@18B4P07QhN01LG5`0X:2P0De=C051@D014A4@0IfMW09VIV@2RXZ80XJ6Q09VIV@0W9bL0
6ATI00T05ADE00h05QHF07emO@2[Zj/0G5aL05iNGP1[Jf/0Shn?0;^k^`3Hf=P0h>3P0;>c/`33`l<0
HV9R06ATI080R8R804d0RXZ:051@D01WIfL0GUiN024Q8@0K6a/07AdM024Q8@0W9bL0Ng]k09bLW036
a/H0N7Qh020P800N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0F5QH06ATI02DU9@12
@T80VYZJ096AT@1ADE40?Shn03lo?`0O7al08R8R04U9B@0W9bL0;Bd]05UIF@1EEED0CDe=05eMG@0h
>3P0?clo01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI0861P@2m_Kd0UYJF04E5A@0^
;Rh071`L024Q8@0U9BD0;2`/03Ti>@1;Bd/08b<S01dM7@0L71`06QXJ01LG5`0L71`07QhN01dM7@1V
IVH0FEUI05eMG@1@D500Rh^;01`L700401DE5@2301HF5P0E5AD05aLG03lo?`31`L40/k>c09JFUP2i
^KT0Vi^K07MgM`2MWId0YJFU051@D01mOGd0IVIV04];B`18B4P0WinO0>7Qh@2RXZ80PH610;Vi^@2h
^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500FUYJ07moO`2QXJ40UiNG096AT@1`L700BDU902XZ:P0g
=cL0A4A404=3@`1mOGd0N7Qh04I6AP1lO7`0_Kfm03`l?00i>CT0?clo04=3@`1VIVH0LG5a0:>SX`1h
N7P08B4Q01TI6@0c<c<0WIfM0<;2`P1TI6@0>3Ph04E5A@1IFET0JFUY05eMG@1TI6@0V9RH0:b/[02V
YZH0_Kfm0<g=c@2BTY80S8b<07inOP2JVYX0a<C40<g=c@3@d=00e]KF0>?Sh`3Hf=P0dM7A0<o?c`3Q
hN40d];B0;bl_02XZ:P0WinO09>CT`2HV9P0^;Rh059BDP1GEeL0PH6104i>CP1VIVH0T92@024Q8@0N
7Qh0820P02LW9`0E5AD07alO028R8P0T92@07alO01`L700M7Ad08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80/K6a051@D01/K6`0OGem07inOP1`L700QHF50;Vi^@2d];@0dM7A09ZJVP1=
CDd0?Shn07IfMP2QXJ404Oooool000oooooo0140EEEE04=3@`1VIVH0I6AT06IVIP1ADE40KFe]08f=
S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C011@D40FUYJ038b<P0203lo?`2/024Q8@1YJFT0:BTY03dm
?@0e=CD0<S8b05]KF`14A4@0820P05iNGP1LG5`0HV9R05eMG@1;Bd/0Jf][04I6AP0e=CD0?Shn061P
H00d=3@0I6AT03<c<`1LG5`0=cLg07YjNP19BDT0;bl_03hn?P0T92@0D51@05QHF01BDU80Ng]k051@
D00c<c<0<S8b08F5Q@1KFe/0:b/[04i>CP1@D500;bl_06e]K@1/K6`0AdM70:j^[P2FUYH0<c<c02PX
:01mOGd0H61P02/[:`2GUiL0AdM705QHF00e=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k096A
T@1IFET0CTi>0=;BdP18B4P0?clo04U9B@1KFe/0KFe]04Q8B021PH40eMGE09NGU`1mOGd0KVi^071`
L024Q8@0d=3@0<k>cP16ATH0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0ATI6079b
LP19BDT0DE5A01TI6@0b<S80N7Qh05=CD`1eMGD0<S8b02@T901:BTX0GemO055AD@1KFe/07alO05]K
F`2:RXX0DU9B05MGE`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1`L700?3`l020P
8016ATH0P82003lo?`0[:b/0Fe]K08^;R`1VIVH0P82007EeM@1JFUX0IFEU03Xj>P27QhL0OGem05IF
EP1YJFT0GEeM08R8R022PX80I6AT04A4A02;Rh/0OWin0:f][@2j^[X0/[:b07IfMP2i^KT0e]KF096A
T@0o?cl0>SXj07moO`1ADE40E5AD08n?S`1=CDd0K6a/07MgM`1RHV80;Rh^06=SH`0S8b<0ADE505AD
E01@D500SXj>05MGE`80IFEU03X092@T05eMG@1?Cdl0Bd];08Z:RP2<S8`0?Shn09:BTP1KFe/0BDU9
07YjNP0`<3006QXJ06YZJP1cLg<0D51@06i^KP14A4@0Jf][03@d=014A4@0GemO07QhN011@D40EeMG
03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y:BT0>CTi06EUI@0f=SH0:2PX03lo?`21PH40Bd];
02h^;P1;Bd/0R8R806ATI02CTi<0Ng]k051@D02_[jl0IFEU07IfMP1>CTh0EUIF02DU9@1hN7P0EUIF
02PX:01=CDd0KVi^0P0V9RH09@1JFUX0OWin06UYJ@1WIfL0NWYj0410@017AdL0GUiN05YJFP0m?Cd0
L71`04i>CP0e=CD0IVIV06QXJ018B4P0D51@08b<S01TI6@0:b/[05ADE01:BTX0DU9B0820P01XJ6P0
OWin0<G5a@1dM7@0DU9B01HF5P0M7Ad0DU9B04E5A@2@T900a<C405QHF00S8b<07?ooool0;P0i>CT0
HF5Q07]kN`2PX:00^;Rh0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07=cL`2VYZH0
Ti>C0<W9b@29RHT0BTY:03Hf=P0a<C40?clo04I6AP1OGel0@41004M7A`0i>CT07AdM01/K6`0[:b/0
IfMW0;jn_P1ADE40J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT061PH02<S8`1>CTh2
04e=C@0705eMG@3@d=00Xj>S055AD@0M7Ad05ADE01@D500201DE5@0401@D500E5AD04a<C014A4@80
5ADE02H0J6QX06e]K@1nOWh0TI6A08^;R`21PH40U9BD0<_;b`2j^[X0FEUI0410@00Y:BT0>3Ph059B
DP2TY:@0TY:B08n?S`1QHF40@d=305mOG`0T92@05ADE01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm06UY
J@0b<S808B4Q01hN7P0f=SH0FUYJ08J6QP2j^[X0=CDe01DE5@805aLG01@06a/K01dM7@1RHV80PH61
04e=C@1@D5008b<S018B4P0D51@0>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0j>SX08R8R
02LW9`808B4Q0P0L71`0200I6AT09RHV06ATI02IVIT0^;Rh08f=S@0e=CD0<30`0P0L71`201lO7`0@
02l_;`1?Cdl08B4Q01lO7`0S8b<07QhN01/K6`0L71`07QhN01dM7@1ADE40Hf=S08J6QP24Q8@0[jn_
02/[:`@05ADE06D04a<C01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08b<S02NWYh0
@410038b<P0i>CT0GUiN04Q8B02=SHd0f][J04a<C00j>SX0GEeM0:BTY02[Zj/0]kNg06=SH`1GEeL0
SXj>06ATI02BTY80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0ADE507MgM`0^;Rh0
;2`/0410@02`/;00`/;20<g=c@1^KVh0CTi>096AT@3Hf=P0fm_K08^;R`1MGEd09bLW06i^KP1SHf<0
TI6A03Lg=`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf0:ZZZP2TY:@0Rh^;07IfMP1ADE40
?clo03/k>`19BDT0IFEU08b<S03<c<`0Vi^K0<C4a02/[:`0U9BD0<c<c02l_;`0WIfM061PH014A4@0
?clo04A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C06i^KP2MWId0:2PX01/K6`0M7Ad06ATI01HF5P0201dM
7@0L024Q8@0M7Ad071`L01`L700P8200Fe]K0;Rh^02<S8`0OGem0=KFeP2d];@0UIFE08b<S02NWYh0
Ph>30:FUY@2IVIT0Xj>S0:FUY@2/[:`0clo?0<O7a`2>SXh0@D51038b<P1IFET0Q8B409nOWa7ooooo
000?ooooo`1S05QHF01<C4`0E5AD04Y:BP1SHf<0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q
8@0g=cL0>c/k020P800B4Q80820P03Xj>P0M7Ad0GemO01XJ6P0L71`0;bl_04=3@`2WYjL0@T9201/K
6`1=CDd0ADE506=SH`1]KFd09BDU03Ti>@1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO
7`0n?Sh0<30`02XZ:P1DE5@0AdM705IFEP10@400IFEU0:RXZ01fMWH0F5QH03/k>`2HV9P0D51@01`L
701KFe/0H61P04=3@`1?Cdl0?3`l02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80HV9R04a<
C01CDe<06ATI02h^;P1UIFD0@41005QHF01kNg/0G5aL02DU9@1>CTh0EEEE06=SH`3Cdm<0Jf][05IF
EP1HF5P0GemO06YZJP0n?Sh0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0MgMg0080bl_;02L0Hf=S08n?
S`1JFUX0Hf=S05IFEP2FUYH0J6QX05UIF@1[Jf/0MWIf05YJFP2<S8`0CDe=055AD@1IFET0AdM707Mg
M`0m?Cd0Fe]K05aLG00l?3`0E5AD05UIF@1=CDd0BTY:02h^;P1FEUH0U9BD05]KF`1eMGD0H61P06YZ
JP10@400Jf][07inOP1<C4`0Ogmo07alO00j>SX00P1SHf<08P13@d<0E5AD09jNWP17AdL0;Bd]059B
DP1mOGd0IfMW07inOP22PX80IFEU08F5Q@1:BTX0QHF508B4Q01=CDd0JFUY04Y:BP21PH40O7al065Q
H@1<C4`0TI6A08f=S@24Q8@0`L710<[:bP13@d<0QHF50<K6aP2GUiL0@41003De=@1_Kfl203Ti>@1`
07inOP1=CDd0HV9R079bLP1IFET0=CDe05aLG00S8b<0?clo069RHP1NGUh0TY:B05YJFP1cLg<0L71`
02d];@1]KFd0Lg=c05eMG@2>SXh0N7Qh04I6AP2PX:00IfMW04M7A`1jNWX0@D5102LW9`2QXJ40X:2P
055AD@1^KVh0@T9206e]K@0a<C40?Shn07]kN`2CTi<0Cdm?059BDP0^;Rh0LW9b075aL@1>CTh0=SHf
07UiN@1fMWH0=SHf065QH@1[Jf/0?clo02DU9@0d=3@0MWIf030`<00e=CD0KVi^07UiN@1NGUh0QhN7
051@D00j>SX0PH61061PH01mOGd0LG5a06a/K00^;Rh0D51@03Ph>00R8R80CTi>079bLP1BDU808B4Q
04Q8B01VIVH0<S8b06UYJ@2=SHd0IVIV05MGE`26QXH0QhN702l_;`11@D40E5AD059BDP1MGEd0N7Qh
059BDP0g=cL0Kfm_07IfMP0m?Cd0IFEU06][J`1TI6@0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI
01lO7`1DE5@08R8R07emO@2TY:@0Ng]k03/k>acooooo02/0;2`/05MGE`3?cll0g=cL0<K6aP2<S8`0
IVIV04];B`0m?Cd0>SXj02h^;P2GUiL0OWin06=SH`1aLG40Shn?0:n_[`3?cll0c/k>09>CT`18B4P0
9BDU01lO7`0N7Qh0>3Ph05ADE00_;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0L71`04I6AP15ADD0
C4a<02XZ:P0P82009BDU03@d=012@T807AdM00805aLG00l07QhN03Lg=`1GEeL0C4a<09:BTP2WYjL0
IVIV051@D00E5AD04A4A01<C4`0A4A4051@D01DE5@0D51@00P0C4a<02`0K6a/0NWYj03Ti>@0[:b/0
?Cdm034a<@0[:b/0A4A40:>SX`1aLG40>SXj008071`L01T06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0
LG5a03dm?@1[Jf/0BTY:05MGE`2>SXh0ZJVY09JFUP1RHV80HF5Q06e]K@1/K6`0J6QX06IVIP2LW9`0
bLW906e]K@2CTi<0KVi^00805aLG01P05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG5`0@4100
4a<C03Ph>00O7al08b<S08j>SP30`<00O7al09FEU@1oOgl0@D5103Ti>@0l?3`08R8R01`L700E5AD2
01LG5`0A024Q8@1XJ6P0alO70<_;b`2BTY80<c<c020P800F5QH06a/K01TI6@0Q8B40@T9203@d=00Y
:BT07AdM01`L700G5aL00P0E5AD0EP0H61P06QXJ03Ti>@28R8P0K6a/07QhN03<c<`0GUiN04M7A`0a
<C406ATI01LG5`0E5AD08R8R05aLG02a/K40U9BD07]kN`2k^k/0VIVI05QHF01LG5`0A4A407moO`0O
7al0820P02@T901:BTX0I6AT0;Vi^@2SXj<0B4Q803hn?P1:BTX0QXJ607alO02GUiL0IVIV04a<C01F
EUH0DU9B06m_K`1eMGD0PH610820P016ATH0?3`l04M7A`19BDT0DU9B055AD@1BDU80FEUI01dM7@0K
6a/0?3`l0::RXP3Cdm<0l?3`0>KViP3=cLd0d=3@0=WIf@2e]KD0Lg=c05iNGP1mOGd0CTi>05MGE`2K
Vi/0=CDe038b<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX05ADE01=CDd0Ng]k03hn?P16
ATH0@d=30P0c<c<06P0o?cl0^[Zj06m_K`2j^[X0U9BD06=SH`1jNWX0Y:BT05mOG`0a<C40;2`/034a
<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0J6QX071`L01TI6@0L71`0<c<c0P0O
7al201dM7@0I02TY:@2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=S@2[Zj/0SXj>0=;B
dP2ZZZX0]KFe0=7Ad@3Kfm/0]KFe06IVIP0e=CD0=SHf05UIF@1bLW80Q8B404E5A@0Aooooo`003ooo
ool07@1BDU80Cdm?05IFEP1NGUh0CTi>05ADE01EEED0K6a/051@D00T92@0=CDe04];B`12@T80<30`
02h^;P1EEED0<S8b02XZ:P0n?Sh071`L05eMG@15ADD09RHV02/[:`0H61P0ADE505eMG@0S8b<0>c/k
0080=3@d05l0DU9B05IFEP0h>3P0C4a<01dM7@0i>CT0DU9B03hn?P11@D40;2`/0492@P19BDT0Fe]K
03@d=00S8b<0<30`05]KF`10@400EeMG0410@01^KVh0J6QX05=CD`0b<S80VIVI05aLG00V9RH0?Cdm
04=3@`0m?Cd0FUYJ055AD@0i>CT0X:2P08F5Q@1ZJVX092@T05iNGP1VIVH08B4Q069RHP1OGel0ADE5
03Ph>00k>c/0PX:202LW9`16ATH0J6QX07MgM`12@T80K6a/05IFEP1BDU80eMGE08^;R`1]KFd0LG5a
059BDP1WIfL0<C4a04E5A@2][Jd0eMGE0>?Sh`2NWYh0Ti>C04M7A`2c/k<0c/k>061PH02DU9@0DU9B
06][J`1EEED0YjNW06QXJ01MGEd0Lg=c07UiN@1GEeL0Rh^;04m?C`1OGel0FUYJ04Q8B01dM7@0>CTi
05iNGP1LG5`0@d=3051@D01JFUX0C4a<065QH@0205ADE01a09ZJVP19BDT0Lg=c0492@P29RHT0AdM7
07AdM027QhL0Bd];08B4Q02TY:@0ADE505eMG@25QHD0BTY:05]KF`2IVIT0CDe=034a<@1iNGT0JVYZ
06UYJ@1ADE40IFEU08f=S@23Ph<0@T9207=cL`21PH40>CTi08:2PP1FEUH0N7Qh07moO`1=CDd0=CDe
08>3P`1jNWX0FEUI0:BTY030`<00KFe]0:VYZ@3Cdm<0OWin04E5A@0i>CT0NGUi08J6QP1;Bd/0QHF5
03lo?`1TI6@0PH6104M7A`0d=3@0De=C02`/;00j>SX0F5QH059BDP2NWYh0FUYJ07moO`1mOGd0<C4a
04m?C`1XJ6P0Cdm?0820P025QHD0?Shn092@T01DE5@0AdM708j>SP1>CTh0820P08B4Q02>SXh0CDe=
06IVIP1NGUh0NWYj04a<C00e=CD0JFUY08n?S`14A4@0EeMG04Y:BP1nOWh0Q8B404Q8B00e=CD0Jf][
06m_K`0^;Rh0LG5a08n?S`15ADD0:RXZ03Lg=`1eMGD0ADE503Ti>@1SHf<0MWIf04i>CP25QHD0H61P
0492@P2@T9000P1LG5`0;`15ADD0I6AT02d];@1WIfL0BDU902@T900n?Sh0Hf=S030`<00V9RH0IFEU
09BDU01YJFT0HV9R06i^KP0X:2P0<30`05MGE`1nOWh0?Shn04i>CP1lO7`092@T07MgM`2FUYH0LG5a
03hn?P1nOWh0>3Ph01hN7P1:BTX0SXj>075aL@25QHD0J6QX04];B`1IFET0OWin05eMG@0K6a/0:b/[
04m?C`1>CTh0BTY:09VIV@1iNGT0FEUI01cooooo0140C4a<06YZJP22PX80HV9R05IFEP0m?Cd0=CDe
030`<00_;bl0:RXZ034a<@1RHV80GUiN0410@00i>CT0JFUY06YZJP020;6a/@0A075aL@1LG5`0IVIV
096AT@2`/;00ZJVY08j>SP1SHf<0?Cdm03<c<`0k>c/0D51@09JFUP37alL0WIfM03<c<`0Z:RX00P0T
92@01P0U9BD0820P020P800T92@071`L01HF5P805ADE00/05QHF01lO7`1>CTh0N7Qh08J6QP2?Shl0
PH6106e]K@1@D500?Cdm0492@P0204M7A`0704i>CP1<C4`0EeMG08n?S`2f][H0@41001lO7`0202DU
9@1l02d];@18B4P0UiNG05]KF`0d=3@06ATI01XJ6P0I6AT071`L01hN7P0c<c<0IfMW051@D016ATH0
GUiN05MGE`1mOGd0ZJVY05iNGP1CDe<0OGem06MWI`1ADE40BDU90492@P1?Cdl0D51@04Q8B01lO7`0
Jf][08F5Q@2WYjL0GemO03<c<`0F5QH05aLG01TI6@0j>SX0EeMG05]KF`0U9BD08B4Q00l?3`0E5AD0
?clo06=SH`2DU9@0Vi^K04i>CP1@D500BDU902TY:@1JFUX0XZ:R09FEU@1mOGd0Fe]K04m?C`0Z:RX0
820P03dm?@1lO7`0emOG0>GUi@3EeMD0WIfM05mOG`0V9RH09bLW02TY:@11@D40<C4a01`L700J6QX0
8R8R02h^;P0P82006QXJ02<S8`0V9RH0:b/[030`<012@T80Shn?0<c<c03MgMd0b<S808j>SP20P800
GEeM04Y:BP1SHf<0S8b<07QhN01bLW80DE5A038b<P1?Cdl0R8R8092@T020P800PH6107EeM@0b<S80
8b<S02HV9P0/;2`0Bd];04i>CP0f=SH0@41001/K6`0T92@0<c<c05QHF01:BTX0F5QH061PH01bLW80
T92@05]KF`1dM7@0GEeM03/k>`<07AdM05P092@T030`<011@D40S8b<07MgM`1IFET071`L02h^;P2C
Ti<0clo?0:2PX026QXH0TI6A09JFUP2?Shl0IVIV05YJFP1_Kfl0OWin092@T02MWId0XJ6Q04Q8B00`
<300=3@d05iNGP2EUID0Y:BT0<?3``2l_;`0/;2`09:BTP0/;2`09BDU03lo?`1CDe<0:b/[03<c<`17
AdL0S8b<08^;R`2c/k<0SHf=0::RXP15ADD0=cLg04A4A01]KFd0A4A403/k>`0^;Rh0:RXZ02`/;00f
=SH0BDU906QXJ01ZJVX0NWYj08Z:RP2XZ:P0HF5Q03<c<`1QHF40CTi>03Hf=P1@D500EeMG05ADE01F
EUH0FEUI07emO@1kNg/0Kfm_08R8R02QXJ40PH6109fMW@2@T900W9bL07]kN`2a/K40UIFE0<W9b@2B
TY80P8200<S8b03:b/X0OGem0P2JVYX01@2:RXX0Ph>3069RHP1EEED0GEeM017ooooo000?ooooo`09
055AD@1LG5`0CTi>08:2PP1IFET0KFe]04a<C01mOGd0Rh^;0080AdM70?l0EEEE04Y:BP0U9BD0@410
06YZJP0n?Sh0;2`/04Y:BP0^;Rh0Fe]K04E5A@0C4a<08B4Q01hN7P1EEED0I6AT02LW9`0d=3@0Bd];
04=3@`1IFET0EUIF02PX:01]KFd0;bl_04a<C01GEeL0ADE502`/;015ADD0BDU905]KF`1?Cdl0C4a<
03`l?00j>SX0Jf][03Lg=`1/K6`0G5aL07moO`1nOWh0Fe]K03<c<`2?Shl0D51@038b<P15ADD0EeMG
038b<P19BDT0NGUi03dm?@39bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q805=CD`18B4P0CTi>
03Lg=`1hN7P06a/K04Y:BP2UYJD0RHV904Q8B01QHF40>3Ph02`/;02i^KT0NGUi079bLP1dM7@0BTY:
08j>SP1=CDd09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0D51@08B4Q00k>c/0MWIf
04a<C02IVIT0Bd];03Xj>P1/K6`0Lg=c04];B`2:RXX0@T9206UYJ@1UIFD0@T9207]kN`1?Cdl0ADE5
06a/K015ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`1]KFd0>SXj08R8R01QHF40F5QH
05YJFP0n?Sh0Kfm_09nOW`1EEED0CTi>06i^KP0_;bl0@T9207YjNP1LG5`0=CDe0:6QX@1lO7`0CTi>
06IVIP1_Kfl0I6AT08^;R`0R8R80JFUY09NGU`1=CDd0LW9b04U9B@1CDe<0Lg=c06MWI`1BDU80YjNW
09RHV01;Bd/0RXZ:0<C4a015ADD0PH610<W9b@2SXj<0Fe]K02d];@1FEUH0DU9B05YJFP2>SXh0J6QX
0492@P1NGUh09RHV010@400V9RH06ATI02d];@1=CDd0N7Qh0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem
08:2PP1EEED0B4Q807inOP1:BTX0]kNg08B4Q00o?cl0Ogmo01hN7P0E5AD0MGEe09BDU01UIFD0GemO
05QHF01bLW806ATI00l?3`0L71`0PX:207YjNP1<C4`05QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_
028R8P19BDT0PH6105UIF@0V9RH09BDU065QH@15ADD071`L02d];@1QHF40CDe=08b<S00g=cL0:BTY
07alO01fMWH0H61P05MGE`1IFET05ADE03dm?@1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S
05QHF01[Jf/0Ng]k092@T01EEED0GEeM06a/K00e=CD0JVYZ09BDU010@40001P0L71`09nOW`1GEeL0
CTi>0:2PX01fMWH0@D5104Y:BP1_Kfl0IVIV0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K6`0^;Rh0
ATI604Q8B023Ph<0_Kfm08V9R@0Z:RXLooooo`0L04];B`15ADD0?clo04m?C`1FEUH0<30`01`L700E
5AD05aLG01DE5@0D51@04a<C01@D5017AdL0@41005UIF@1LG5`0[Jf]0=cLg03De=@0]KFe0:ZZZP2]
[Jd0O7al04i>CP1JFUX0@d=3030`<080<C4a00D09BDU0451@@2WYjL0_Kfm02/[:`0201`L700801TI
6@0M7Ad08R8R028R8P0N7Qh06ATI01HF5P0C4a<301DE5@0I01XJ6P1GEeL0Q8B40:n_[`3AdM40SHf=
05mOG`1?Cdl0ADE50451@@0o?cl0ADE505MGE`1[Jf/0V9RH0<g=c@30`<00FEUI02DU9@0O7al0:2PX
05UIF@2?Shl0H61P02DU9@0301LG5`0A01DE5@0J6QX071`L024Q8@1XJ6P0GUiN03Lg=`1SHf<0Vi^K
0;Ng]`2;Rh/0Fe]K04I6AP14A4@07alO01LG5`0K6a/00P0F5QH0900I6AT0@d=308f=S@1KFe/0IFEU
06e]K@1aLG40JFUY02l_;`0J6QX0@41008b<S01JFUX07alO010@400>3Ph0:RXZ0820P029RHT0OGem
05YJFP1CDe<0:2PX01DE5@0A4A408b<S04i>CP16ATH0UYJF0=;BdP2][Jd0X:2P08n?S`31`L40b/[:
0;fm_@80d];B00H0`L710<c<c02TY:@0AdM704m?C`0a<C4201LG5`0V01HF5P0I6AT061PH03<c<`0d
=3@092@T01PH600L71`07AdM06IVIP3MgMd0hN7Q0;Fe]@2;Rh/0QhN709:BTP37alL0clo?0;:b/P2d
];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@1[Jf/0De=C06EUI@1>CTh08B4Q02PX:00_
;bl0;2`/028R8P0f=SH201HF5P1]024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=S@2HV9P0LG5a07Qh
N00_;bl07QhN02HV9P0k>c/0EEEE08N7Q`2c/k<0c<c<07IfMP1:BTX0CTi>06][J`3Bd]80aLG5092@
T02FUYH0Q8B408R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj^P2m_Kd0M7Ad05aLG02;Rh/0YjNW09FE
U@1nOWh0WYjN0<G5a@34a<@0YJFU0:NWY`1SHf<09RHV028R8P0i>CT0Bd];02d];@0[:b/0JVYZ08J6
QP2<S8`0U9BD08R8R00i>CT0=3@d0410@00i>CT071`L02PX:00h>3P0<c<c03@d=00[:b/0;Bd]0410
@01cLg<0Y:BT0;2`/02m_Kd0]KFe09:BTP0e=CD0<30`0492@P1XJ6P0Lg=c06MWI`1iNGT0VIVI08R8
R01/K6`0MGEe096AT@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`34a<@0/[:b0<W9b@3Cdm<0cLg=0<K6
aP1UIFD0G5aL06MWI`2SXj<0YZJV06e]K@2FUYH0Cdm?079bLP0Aooooo`003oooool0B01BDU80DE5A
05]KF`2@T900FUYJ06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a0451@@1WIfL0=CDe
02PX:01?Cdl0:BTY05eMG@0i>CT05aLG03Ti>@0N7Qh0AdM705MGE`0T92@0BDU905MGE`0k>c/0Bd];
055AD@0[:b/0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0G5aL06UYJ@0b<S80=cLg
04U9B@0l?3`0MGEe05]KF`1dM7@0RHV903<c<`0U9BD0L71`06IVIP0a<C40?Shn05MGE`0W9bL0@d=3
071`L00g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`80DE5A0=P0FEUI03Hf=P1cLg<0
:b/[02h^;P1ZJVX0JFUY030`<01ZJVX0OGem03hn?P3=cLd0KVi^04=3@`1gMgL0GemO08n?S`1?Cdl0
?Cdm07QhN02i^KT0d];B0820P02GUiL0De=C0:6QX@31`L40G5aL092@T01KFe/0MgMg055AD@2>SXh0
O7al04I6AP1FEUH0NGUi04Y:BP2GUiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5105ADE014A4@0
G5aL07]kN`1@D500EEEE03`l?00k>c/0QXJ6065QH@1`L700<S8b05iNGP18B4P0PH610820P01JFUX0
G5aL0;bl_01ADE40GemO08J6QP1KFe/0De=C08f=S@0k>c/0<c<c08V9R@2>SXh0HF5Q06IVIP18B4P0
]kNg0;Rh^01;Bd/0ATI60820P00j>SX0MgMg06][J`1]KFd0IFEU02@T900M7Ad0EEEE08V9R@1YJFT0
VYZJ0=3@d019BDT0JVYZ0<?3``2TY:@0IVIV03Ti>@1KFe/0:b/[038b<P1KFe/0Jf][0451@@1HF5P0
Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P0=3@d09RHV01/K6`0DE5A04Q8B00Z:RX0=3@d0861P@1^KVh0
BDU9096AT@0O7al0R8R808^;R`0i>CT0Ph>303`l?00H61P0LW9b06ATI01RHV80De=C05YJFP1PH600
FEUI02TY:@0[:b/0Kfm_06MWI`1<C4`0Kfm_079bLP28R8P0KFe]03Hf=P1EEED0Q8B406YZJP1RHV80
X:2P07MgM`0Z:RX0;bl_05eMG@26QXH0FUYJ04Y:BP1nOWh0@T92092@T01VIVH0ATI606MWI`1YJFT0
BDU905aLG01UIFD0>SXj05]KF`1@D500<30`04Y:BP1iNGT0@d=302h^;P13@d<0O7al04Y:BP28R8P0
[Zj^09>CT`1BDU80KFe]06i^KP0T92@0=cLg08n?S`0];Bd0PH6108Z:RP19BDT0:b/[06a/K01TI6@0
@T92055AD@1WIfL0D51@08>3P`1hN7P0CTi>04I6AP2CTi<0NWYj01`L700I6AT0<c<c03hn?P1;Bd/0
OGem08>3P`1GEeLLooooo`0809JFUP25QHD0GEeM03<c<`0`<30092@T01dM7@0F5QH201DE5@0T01<C
4`0@41004A4A010@401?Cdl0B4Q806UYJ@2a/K40a<C40<g=c@2l_;`0f][J0;Fe]@1MGEd0IFEU07]k
N`1mOGd0NGUi07AdM01ZJVX0J6QX07]kN`2;Rh/0W9bL08n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN01lO7`0I6AT07AdM0P0G5aL01`0K6a/0CTi>071`L01dM7@0/K6a09bLW01:BTX00P0k
>c/04011@D40;bl_03Lg=`13@d<0>CTi03@d=01GEeL0WIfM09:BTP1UIFD0?Cdm04=3@`1gMgL0SXj>
06IVIP0P820201PH600c01HF5P0E5AD05aLG01XJ6P0I6AT08B4Q08j>SP1BDU80<S8b0::RXP30`<00
Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05ADE01XJ6P0G5aL06QXJ02HV9P17AdL0UYJF06QXJ02;Rh/0
ADE5069RHP1nOWh0RHV90:FUY@2EUID0<S8b01<C4`0@4100;Bd]05UIF@0i>CT0VYZJ05aLG01UIFD0
?3`l01HF5P0E5AD0410@01HF5P16ATH0BTY:034a<@1KFe/0bl_;0080e]KF00`0WinO09FEU@1SHf<0
VIVI0<k>cP2n_[h0][Jf0;Ng]`2f][H0_[jn01/K6`0H61P201DE5@0801HF5P0E5AD0;Bd]020P800I
6AT05aLG01XJ6P0l?3`20<g=c@2:0=WIf@2l_;`0RHV909bLW02[Zj/0[Jf]0<30`03Cdm<0fMWI08f=
S@1FEUH0<C4a03/k>`12@T80@d=304Y:BP1<C4`0DE5A051@D00l?3`0GemO04a<C00V9RH09BDU02l_
;`0Y:BT0?3`l01DE5@0F5QH0:b/[02d];@28R8P0_kno0;Bd]02YZJT0Q8B408:2PP2WYjL0U9BD08:2
PP2:RXX0Xj>S0:j^[P22PX80GemO04m?C`1eMGD0L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1PH600O7al0:2PX02CTi<0RHV908R8R023Ph<0`L710<G5a@2WYjL0NGUi06UYJ@3:b/X0XJ6Q06e]
K@2YZJT0X:2P06a/K01`L700Vi^K08:2PP1GEeL0B4Q803De=@1MGEd0@41003@d=01nOWh0UIFE09>C
T`2b/[80RHV903Xj>P0b<S80AdM703@d=00M7Ad07QhN02`/;00g=cL0<S8b02TY:@0Z:RX0>c/k08j>
SP2n_[h0b<S80=3@d03>c/h0WinO08Z:RP2VYZH0XJ6Q08Z:RP1SHf<0FEUI05eMG@1_Kfl0XZ:R0<_;
b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe0<_;b`33`l<0dM7A0=CDe03GemL0YjNW05iN
GP25QHD0V9RH0;Jf]P2b/[80b<S80;fm_@2XZ:P0S8b<4Oooool000oooooo0?l0D51@0410@00o?cl0
OGem05iNGP0h>3P0:RXZ069RHP1UIFD0>CTi03hn?P1CDe<0820P03De=@13@d<0C4a<00T92@0B4Q80
ATI602PX:01DE5@0?Cdm01<C4`10@400:b/[04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH0
:b/[0820P00m?Cd0C4a<06MWI`16ATH0;bl_03Ph>013@d<0;2`/03De=@1<C4`07alO03Hf=P13@d<0
;2`/0410@00d=3@0JFUY08:2PP15ADD08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1BDU80
820P08^;R`2CTi<0Cdm?02/[:`0j>SX0?clo01`L700f=SH0H61P04U9B@0k>c/0;Bd]05UIF@0m?Cd0
>CTi06UYJ@1dM7@0Bd];04a<C022PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:05=CD`0e=CD0
IfMW0;:b/P20P800<30`06MWI`13@d<0V9RH0<K6aP1GEeL0R8R8061PH01nOWh0<S8b06a/K01iNGT0
EUIF07MgM`1;Bd/0=SHf07emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6AP1<C4`0LG5a03dm?@1?Cdl0
DU9B03Ph>01iNGT0MGEe04M7A`2RXZ808B4Q07YjNP0h>3P0Hf=S01PH600m?Cd0P82006MWI`1FEUH0
_[jn04U9B@12@T80Lg=c06EUI@1GEeL0X:2P0451@@0S8b<0X:2P07MgM`1eMGD0OWin0410@00n?Sh0
O7al06IVIP0j>SX0QHF5024Q8@0o?cl0GUiN05IFEP1iNGT0MgMg0410@01/K6`0TY:B06YZJP2DU9@0
d];B08>3P`2FUYH0g]kN0:>SX`1dM7@0K6a/09nOW`2;Rh/0GEeM07QhN01RHV80NWYj08J6QP1nOWh0
@41004e=C@0g=cL092@T06ATI018B4P0ZZZZ07inOP1FEUH0C4a<05IFEP1:BTX0WIfM07EeM@18B4P0
LG5a0410@02ATI40MWIf03hn?P2UYJD0GEeM024Q8@2EUID0LG5a06ATI01PH600W9bL08f=S@1KFe/0
@4100492@P2:RXX0M7Ad071`L02=SHd0Q8B408b<S01VIVH0=SHf05UIF@2<S8`0KFe]05]KF`2JVYX0
Ng]k02h^;P0m?Cd0IFEU08N7Q`1HF5P0D51@07inOP1EEED0/K6a092@T01LG5`0Kfm_07EeM@1DE5@0
UIFE07emO@1HF5P0JFUY04Y:BP0Q8B40@D5107MgM`1TI6@0<c<c03lo?`2>SXh002<0?clo05=CD`1c
Lg<0P82005=CD`26QXH0T92@05YJFP14A4@0S8b<03Xj>P29RHT0Q8B404=3@`0/;2`0NGUi03Ti>@0]
;Bd0IfMW08Z:RP1YJFT0/k>c07AdM00c<c<0HF5Q0:NWY`22PX80<c<c04i>CP1]KFd0J6QX04A4A027
QhL0RXZ:05EEE@0Looooo`0908Z:RP2MWId0=SHf02DU9@0[:b/08b<S01TI6@0H61P05aLG00805ADE
03004A4A010@400B4Q80EeMG09:BTP2DU9@0I6AT04i>CP1IFET0[Jf]0<[:bP3EeMD0OWin05YJFP1O
Gel0ADE503Ti>@0g=cL0@T9207IfMP37alL0R8R809RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L
71`09BDU02l_;`0Z:RX09bLW03@d=00M7Ad06a/K01`L701=CDd0MGEe06m_K`1nOWh0M7Ad08Z:RP17
AdL0>SXj03Hf=P0T92@201TI6@0<01`L700O7al071`L04Y:BP2FUYH0S8b<09NGU`2`/;00WYjN092@
T01WIfL07QhN0P0E5AD04@0H61P05aLG01DE5@0G5aL06QXJ01TI6@0/;2`0L71`03dm?@1bLW80O7al
08F5Q@0I6AT061PH03`l?00a<C4061PH00805ADE01P071`L01dM7@0E5AD05aLG05EEE@2GUiL0VYZJ
02XZ:P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0X:2P0K6a/0<[:bP2QXJ40N7Qh
01LG5`0E5AD2014A4@0D01@D500g=cL0GUiN06e]K@12@T80GEeM0=KFeP3:b/X0UIFE065QH@0d=3@0
CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL401DE5@0S04I6AP0M7Ad06ATI01XJ6P0_
;bl0Vi^K07=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Vi^@3AdM40S8b<079bLP16
ATH0BDU903<c<`0I6AT07AdM03Ph>00N7Qh0@41005IFEP0m?Cd0EEEE06][J`0`<300;Rh^03<c<`0j
>SX00P0G5aL03P0U9BD08b<S08J6QP3De=@0U9BD09nOW`36a/H0YZJV0<W9b@3:b/X0_;bl08j>SP1N
GUh0@4100P0/;2`04@0e=CD0FEUI0;Ng]`2PX:00S8b<09FEU@2i^KT0Kfm_069RHP1KFe/0HF5Q07]k
N`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm01l0K6a/06IVIP31`L40a/K603Lg=`1<C4`0NGUi04m?
C`0N7Qh08R8R03lo?`22PX80CDe=04E5A@0m?Cd0KVi^06=SH`1ZJVX0V9RH0;6a/@2o_kl0a/K607]k
N`0Y:BT0;Bd]03`l?00d=3@07QhN01dM7@0Q8B40>SXj0080;Rh^02T0<c<c04E5A@1kNg/0`l?30<o?
c`3;bl/0e=CD0;Vi^@25QHD0NGUi06YZJP23Ph<0S8b<09JFUP24Q8@0PH6107QhN01kNg/0UiNG0<C4
a02n_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Rh^80f][J08f=S@2o_kl0e=CD0=7Ad@3;bl/0^;Rh0:6Q
X@30`<00]KFe0<;2`P2n_[h0MWIf061PH00Aooooo`003oooool0R01<C4`0EEEE04Q8B01ZJVX0DU9B
04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW01hN7P1GEeL0;Bd]01/K6`0^;Rh04A4A
0410@01?Cdl05aLG0451@@0I6AT0@41004i>CP0_;bl0D51@03@d=00A4A40<S8b059BDP0O7al0I6AT
01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500CTi>04I6AP0Q8B408b<S05=CD`1=CDd0JVYZ
03Xj>P1<C4`0I6AT0410@00P8200O7al04];B`0Z:RX092@T05MGE`1KFe/0IFEU09>CT`0_;bl0IfMW
0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1GEeL0@D5104m?C`0`<300EeMG02h^;P0j>SX0PH61
08R8R01NGUh0C4a<05eMG@11@D40`L710:RXZ01<C4`0Ng]k03De=@0Z:RX07QhN02d];@1_Kfl0LG5a
03hn?P0d=3@0H61P03<c<`1gMgL0]kNg06i^KP1iNGT0=3@d08^;R`1>CTh0DU9B04U9B@0[:b/0E5AD
06][J`0k>c/0Kfm_020P8015ADD0GEeM03hn?P1MGEd0CDe=02h^;P1QHF40AdM705UIF@1=CDd0<S8b
04a<C01JFUX0?Cdm0:VYZ@1SHf<0MGEe04=3@`1`L700EUIF06YZJP1XJ6P2069RHP2H0<_;b`1/K6`0
ATI608B4Q00f=SH0FEUI09jNWP1cLg<0:b/[0861P@1DE5@0EeMG06i^KP1GEeL0GUiN08R8R01FEUH0
DE5A09>CT`1ZJVX0G5aL06ATI01LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P1PH600
ZJVY0=oOg`2JVYX0?clo03De=@1IFET0LW9b06MWI`2KVi/0EeMG0410@01?Cdl0EeMG04=3@`15ADD0
>c/k04Y:BP2=SHd0BTY:0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/;2`0;Bd]06=SH`0k>c/0
S8b<04a<C00n?Sh0Vi^K055AD@0O7al0WYjN06a/K00_;bl0>CTi05IFEP1dM7@0Bd];04m?C`1JFUX0
Rh^;065QH@14A4@0I6AT096AT@2_[jl0Bd];02/[:`1QHF40RHV906ATI01<C4`0TY:B02/[:`0a<C40
Fe]K07emO@1hN7P0EEEE05ADE01mOGd0<c<c08V9R@1lO7`0DU9B09^KV`2OWil0?Cdm065QH@1LG5`0
9BDU06MWI`1[Jf/0=cLg03Ph>01NGUh0?Shn02XZ:P1UIFD0`l?308V9R@25QHD0Xj>S051@D00e=CD0
GemO08N7Q`1=CDd0OWin0:BTY01bLW80SXj>04m?C`1JFUX0?3`l0;fm_@23Ph<0D51@04=3@`1`L700
DU9B09FEU@1fMWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo05MGE`0k>c/0Lg=c06QXJ00U9BDL
ooooo`07051@D01gMgL0EUIF02DU9@0X:2P09RHV01LG5`0301DE5@804a<C03d05QHF01hN7P1?Cdl0
NWYj06EUI@1:BTX0>SXj04U9B@23Ph<0b/[:0=7Ad@2IVIT0=cLg09ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0Fe]K06=SH`24Q8@0ZJVY061PH019BDT0PH610:FUY@1MGEd0De=C08>3P`1[Jf/0
F5QH0451@@0e=CD0;bl_05mOG`28R8P0Lg=c07MgM`1HF5P0>SXj02TY:@0e=CD0;Rh^03/k>`16ATH0
>3Ph038b<P0Z:RX09RHV030`<01[Jf/0];Bd0;Fe]@29RHT0IFEU09RHV019BDT0<S8b00H05ADE00P0
5aLG01HF5P0G5aL0KVi^055AD@16ATH0IfMW08J6QP805aLG01h09BDU03Ti>@0J6QX071`L01TI6@0M
7Ad07alO01`L700G5aL07AdM07IfMP2f][H0BDU9020P800n?Sh0<C4a06=SH`37alL0WYjN07alO015
ADD0>CTi06EUI@1bLW80MWIf0;Zj^P22PX80;2`/01DE5@0D51@201<C4`0]02@T901eMGD0^KVi09BD
U02SXj<0d];B0<g=c@1nOWh0=cLg04I6AP1ZJVX0SHf=0;Zj^P1cLg<0Hf=S07moO`1`L700YJFU07=c
L`0L71`04a<C01dM7@0k>c/0L71`04Y:BP12@T80ADE5092@T02:RXX0=cLg09bLW01ZJVX0NWYj0;no
_`3Ti>@0_;bl08J6QP2GUiL0VYZJ0<O7a`29RHT0Kfm_04m?C`0H61P05ADE00805aLG03P0=CDe01`L
700I6AT09RHV04U9B@14A4@0IFEU07AdM00c<c<0D51@04];B`0I6AT06a/K01dM7@11@D40S8b<08j>
SP2][Jd0VIVI0=CDe02b/[80`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80;2`/0<K6
aP2j^[X0K6a/08R8R01kNg/0O7al04=3@`0k>c/0H61P07IfMP2ZZZX0/K6a0:ZZZP36a/H0g=cL092@
T023Ph<0YjNW09NGU`1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02@0;Bd]05UIF@0S8b<0?Shn
06QXJ01WIfL0Rh^;07]kN`21PH40T92@0:JVYP38b<P0MWIf03Xj>P0a<C40@41002/[:`0O7al071`L
01TI6@0b<S80E5AD04A4A016ATH0BTY:069RHP2][Jd0^k^k0;Vi^@3>c/h0c<c<0;no_`2?Shl0P820
06QXJ01BDU820492@P0J0451@@1>CTh0Lg=c08j>SP23Ph<0RHV908N7Q`11@D40EUIF0;Fe]@3MgMd0
emOG0=?Cd`2PX:00YZJV0<g=c@2TY:@0Vi^K0:RXZ033`l<0QHF509VIV@2f][H0_Kfm0:^[Z`1IFETA
ooooo`003oooool08`1>CTh0BDU904m?C`2:RXX0EEEE065QH@0n?Sh0QhN708F5Q@0_;bl0<30`04E5
A@11@D40F5QH04I6AP1BDU80:b/[02`/;01FEUH0>c/k055AD@1VIVH05ADE04e=C@0d=3@0?clo04A4
A00G5aL0F5QH06ATI010@400<S8b04Y:BP0f=SH0WIfM0080=cLg02P0B4Q80492@P0[:b/0?Cdm02/[
:`11@D40H61P0820P00W9bL0:b/[034a<@0];Bd0Hf=S03lo?`1@D500Cdm?04E5A@0K6a/0@d=305MG
E`0h>3P09RHV04=3@`0I6AT0:b/[06i^KP10@400?clo0<O7a`0a<C4071`L04a<C01bLW80BTY:02XZ
:P1=CDd0<S8b07inOP0h>3P0Hf=S0P0H61P0b@15ADD0KVi^05QHF01:BTX0@d=302PX:02<S8`0UYJF
05MGE`24Q8@0;bl_02XZ:P0l?3`0PH610<C4a01eMGD0?clo030`<01JFUX09BDU05mOG`2DU9@0HF5Q
07MgM`1QHF40NGUi055AD@17AdL0P82004E5A@1?Cdl0MGEe04M7A`23Ph<0FEUI05MGE`1>CTh0@410
07=cL`1fMWH0@41005iNGP1<C4`0HV9R07moO`1CDe<0I6AT04Y:BP0/;2`0Rh^;07YjNP1^KVh0>3Ph
06e]K@1OGel0O7al06a/K00f=SH0>3Ph09jNWP1ZJVX0BDU908^;R`1ADE40A4A408F5Q@1dM7@0;bl_
0::RXP1bLW80L71`08b<S01XJ6P0SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI065QH@0k>c/0K6a/
07QhN00k>c/0Ng]k0;Bd]021PH40TY:B0=;BdP1TI6@0PH610<K6aP2=SHd0KFe]034a<@1MGEd0KFe]
04a<C028R8P0OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0EUIF0:>SX`1LG5`0A4A4
051@D00b<S80JFUY08^;R`0n?Sh0=CDe05=CD`0m?Cd0UIFE06][J`13@d<0UiNG04E5A@0e=CD0]kNg
0::RXP1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP1;Bd/0@D5105EEE@24Q8@0FUYJ
02`/;01?Cdl0SXj>06YZJP1=CDd0Ti>C05iNGP0^;Rh0?clo051@D01SHf<09RHV05UIF@1iNGT0@D51
0;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1gMgL0<C4a051@D02KVi/0H61P
03<c<`0Z:RX0IVIV04Y:BP1OGel0UiNG08N7Q`1NGUh0QhN708J6QP0i>CT0ADE508f=S@1dM7@0_Kfm
03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0H61P08b<S01oOgl0ADE507MgM`0208:2PP08
01lO7`0S8b<09bLW06EUI@0c<c<0Kfm_08R8R01XJ6PLooooo`0804Q8B01=CDd0Ng]k02/[:`0U9BD0
<30`01LG5`0F5QH201DE5@0R01<C4`0^;Rh0?Shn0492@P0g=cL05aLG01/K6`14A4@0F5QH03/k>`1g
MgL0a<C40:n_[`38b<P0L71`04Q8B01JFUX0Kfm_05YJFP0j>SX0820P02TY:@1]KFd0JVYZ03De=@0h
>3P0GUiN09bLW021PH40WIfM0=?Cd`2?Shl0GUiN03hn?P80<30`01`0>3Ph04E5A@1IFET0Ph>30:NW
Y`2?Shl0P82006m_K`0P82007AdM01XJ6P0K6a/05QHF01@D500M7Ad0D51@05EEE@0c<c<0=cLg05YJ
FP1gMgL0Ti>C09jNWP23Ph<0T92@03`l?00j>SX0:BTY0P0E5AD0>`0H61P05QHF01LG5`0G5aL061PH
01DE5@0i>CT0OWin059BDP1WIfL0NGUi02d];@0G5aL06ATI04I6AP0X:2P06QXJ01HF5P0H61P05aLG
01/K6`0L71`06ATI034a<@3Lg=`0QHF502@T900W9bL0G5aL0:VYZ@2n_[h0alO70;:b/P30`<00W9bL
06m_K`1iNGT0CDe=02`/;00k>c/0IfMW03/k>`0R8R8061PH01<C4`0H61P0VYZJ0;Jf]P2SXj<0XZ:R
0<c<c030`<00Vi^K07moO`2BTY80W9bL09^KV`2UYJD0KVi^0080DU9B07`0MgMg092@T02CTi<0QHF5
04m?C`0i>CT0:BTY02@T900U9BD0;Rh^08:2PP2h^;P0DU9B07IfMP2ZZZX0GemO08Z:RP2a/K40h>3P
0;Fe]@1JFUX0@41005=CD`2a/K40Ph>304U9B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0S8b<061PH
01TI6@0Q8B40C4a<055AD@1SHf<0Ph>30:ZZZP2EUID0=CDe02`/;00l?3`0SHf=05UIF@0k>c/0IFEU
0<o?c`3QhN40[:b/08:2PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH02PX:02^[Zh0a<C4
08J6QP1WIfL0GEeM05=CD`1EEED0OWin09ZJVP2LW9`0WinO09fMW@22PX80Shn?0:FUY@38b<P0Z:RX
0;jn_P1eMGD0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0Fe]K01lO7`0S8b<0RXZ:
09nOW`2WYjL0KVi^02`/;00Y:BT0NGUi0=WIf@2RXZ80GEeM04E5A@0e=CD07AdM01hN7P0L71`06a/K
01dM7@0m?Cd0]kNg0;bl_02YZJT0[jn_0<W9b@32`/80_kno0<?3``2/[:`0GEeM04=3@`0n?Sh0?3`l
0P0o?cl06`15ADD0Bd];06a/K018B4P0:2PX03Xj>P0h>3P0JFUY03<c<`10@400Rh^;0:RXZ026QXH0
Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0O7al0:ZZZP1hN7P0OWin03Ph>00Aoooo
o`003oooool0;`1=CDd0DU9B03hn?P1iNGT0EeMG04e=C@0U9BD0=CDe04Y:BP0h>3P0<30`03lo?`0V
9RH08b<S04A4A01@D500:RXZ00h>3P0h>3P0?Cdm04=3@`1GEeL02`/;03@d=00j>SX0@D5104Q8B00e
=CD0:RXZ04Q8B016ATH0?3`l04];B`0E5AD0G5aL03Lg=`0h>3P0BTY:03lo?`0K6a/0=3@d020P8010
@400?3`l05EEE@0V9RH0;Bd]0080D51@0?40MWIf04M7A`1:BTX0CDe=06IVIP0e=CD0@T9205ADE00i
>CT08B4Q03dm?@1OGel0?3`l075aL@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01T
I6@0?Cdm05iNGP0c<c<0GemO05aLG00^;Rh0GEeM06a/K01VIVH0K6a/09RHV017AdL0^KVi0:BTY01P
H600WYjN04E5A@0g=cL0:2PX05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k06IVIP23
Ph<0LG5a08N7Q`15ADD0Bd];08B4Q01:BTX0EUIF05aLG00d=3@0JVYZ06=SH`1IFET0C4a<03<c<`16
ATH0K6a/03`l?01aLG40>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0SXj>04I6AP2;
Rh/0GUiN07alO01dM7@0SHf=0451@@2d];@0Lg=c04M7A`2SXj<0OWin05MGE`2BTY80GEeM03dm?@2S
Xj<0O7al06EUI@29RHT0E5AD075aL@2/[:`0Y:BT03Ti>@2OWil0Kfm_06i^KP1aLG40AdM707]kN`0l
?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40L71`08b<S03Hf=P0P82006YZJP1OGel0XZ:R0;2`/024
Q8@0Ti>C06i^KP1bLW80U9BD07YjNP18B4P0=cLg04i>CP0`<300Fe]K04A4A02FUYH0T92@05eMG@1^
KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0@4100::RXP20P800BDU90;Zj^P1:BTX0;bl_08N7Q`1U
IFD0>CTi04Q8B02CTi<0S8b<05]KF`0n?Sh0B4Q807QhN01>CTh0GUiN075aL@1SHf<0LG5a04E5A@0f
=SH0P8200;Zj^P13@d<0De=C0820P013@d<0?Shn06a/K01mOGd0PX:204];B`1:BTX0MgMg030`<02X
Z:P0X:2P05MGE`1SHf<0LG5a03Ph>01MGEd0KFe]06YZJP1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l
?3`0:b/[071`L01_Kfl0MGEe07MgM`2BTY80NWYj09jNWP21PH40Lg=c03lo?`2WYjL0NWYj0::RXP0g
=cL0F5QH034a<@20P800Rh^;05ADE018B4P0QhN707alO02MWId0TY:B055AD@26QXH0OGem08J6QP0X
:2P09BDU02LW9`1/K6`0;Bd]07MgM`2SXj<0R8R801cooooo00H0EUIF04A4A01BDU80IfMW02TY:@0f
=SH201LG5`0701DE5@0L71`07QhN04a<C01IFET0<S8b01LG5`0301DE5@0n02DU9@1VIVH0WinO0<K6
aP3<c<`0alO70<W9b@2;Rh/0AdM704=3@`1ZJVX0;2`/01XJ6P0E5AD07AdM05iNGP1?Cdl0CDe=03Ti
>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@1dM7@0E5AD03De=@0U9BD08R8R02LW9`1hN7P0O7al08V9
R@2QXJ40OWin02@T900L71`06QXJ01`L700F5QH04a<C014A4@0e=CD06QXJ01DE5@0N7Qh0:b/[034a
<@1DE5@0QHF50:FUY@2ATI40:BTY024Q8@15ADD0:2PX01PH600E5AD051@D01PH600G5aL201DE5@1D
01/K6`1gMgL0MWIf07AdM01_Kfl0IVIV01`L700U9BD0TY:B07=cL`0Z:RX07AdM01LG5`0H61P06QXJ
01/K6`0h>3P0LG5a0=gMg@32`/80WinO09fMW@2f][H0WYjN0<K6aP3Fe]H0bl_;0:6QX@2<S8`0EUIF
01TI6@0H61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0De=C05EEE@2BTY80^k^k08:2PP1<C4`0[Jf]
0:2PX027QhL0IVIV04M7A`0n?Sh0J6QX08^;R`1^KVh0EeMG051@D01MGEd0TI6A08J6QP2HV9P0/K6a
0410@00j>SX0@d=3055AD@2GUiL0b<S806e]K@1VIVH0GemO0861P@1EEED0;Bd]04A4A02e]KD0LG5a
02<S8`0T92@0;Bd]06EUI@2?Shl0DU9B038b<P0E5AD05QHF0P0E5AD2028R8P1801TI6@0H61P06ATI
02LW9`2RXZ80`<300<G5a@37alL0WinO0<W9b@3?cll0d=3@09bLW00f=SH0<S8b06IVIP2a/K40YjNW
09bLW022PX80JVYZ0:BTY029RHT0MgMg05aLG017AdL0?Cdm03/k>`13@d<0S8b<0<;2`P2/[:`0E5AD
06QXJ01nOWh0Vi^K0861P@12@T809RHV02PX:01LG5`0=3@d06][J`2`/;00`L710:JVYP2JVYX0L71`
061PH023Ph<0QhN706YZJP0e=CD06a/K01PH600L71`09BDU05MGE`0k>c/0EEEE07emO@13@d<0>3Ph
09BDU021PH40Rh^;0=;BdP3QhN40g=cL0;Zj^P2EUID0;Bd]0P0K6a/201`L700D01dM7@0];Bd0BTY:
0451@@1ADE40RXZ:0;Rh^02DU9@0[Jf]0:BTY02NWYh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH
04m?C`0W9bL201`L7003028R8P0_;bl0GUiN0080?Cdm0140JVYZ09>CT`1WIfL0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0@41007IfMP2@T900LG5a0410@00Aooooo`003oooool0L@1B
DU80K6a/04A4A027QhL0IVIV08F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo05=CD`1[
Jf/0GEeM01XJ6P0n?Sh0ATI60451@@1_Kfl09BDU04Q8B010@400A4A4051@D01CDe<0>CTi05UIF@19
BDT0=3@d05ADE00[:b/0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R8P1NGUh0HV9R05QHF00X
:2P0>3Ph06ATI01EEED0Kfm_0492@P1BDU80OGem07=cL`0n?Sh0?Cdm06QXJ00Z:RX0>c/k05MGE`1L
G5`0>c/k05YJFP0Z:RX0ATI609^KV`1^KVh0>c/k04i>CP1WIfL0C4a<03<c<`20P800?Cdm05UIF@0j
>SX0N7Qh04=3@`0j>SX0FUYJ05QHF00[:b/0?3`l07=cL`17AdL0_[jn0:NWY`18B4P0M7Ad07]kN`20
P800AdM7065QH@2ATI40K6a/038b<P1<C4`0I6AT05mOG`1jNWX0b/[:06i^KP1bLW80GEeM09ZJVP1P
H600@4100820P01=CDd0GemO07emO@1;Bd/0LG5a0080I6AT0540FEUI055AD@1GEeL0I6AT03Hf=P26
QXH0ATI604E5A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0QhN703`l?02@T900ATI6069RHP2M
WId0Rh^;04=3@`2VYZH0Jf][065QH@2j^[X0Ph>305YJFP2VYZH0IVIV02h^;P1gMgL0GUiN07UiN@2j
^[X0MGEe05ADE022PX80SXj>04A4A02/[:`0@D51051@D01_Kfl0AdM70:JVYP1hN7P0B4Q8065QH@2N
WYh0>c/k03lo?`31`L40NGUi08V9R@3Ogml0LW9b055AD@0U9BD0AdM708f=S@1_Kfl0QXJ605aLG00o
?cl0C4a<05eMG@19BDT0=3@d03<c<`1BDU80Ogmo04M7A`2HV9P0ATI606i^KP2>SXh0HF5Q03<c<`2F
UYH00P0S8b<0G01UIFD0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S0:FUY@1NGUh0D51@0451@@1]
KFd0B4Q805mOG`0o?cl0De=C07moO`1VIVH0?Shn079bLP1dM7@0MGEe05IFEP0P8200?3`l06YZJP1P
H600?Cdm08:2PP0j>SX07QhN03Ph>00n?Sh0JFUY04];B`1:BTX0Lg=c03De=@2YZJT0QhN705IFEP1I
FET0AdM703Ph>02:RXX0N7Qh07UiN@1;Bd/0JVYZ04E5A@0n?Sh0FEUI06i^KP18B4P09BDU06][J`1e
MGD0UYJF07QhN02ATI40MgMg0;>c/`2TY:@0N7Qh03`l?02/[:`0K6a/07EeM@0k>c/0Hf=S03dm?@1m
OGd0RHV904i>CP1<C4`0TI6A07emO@2;Rh/0N7Qh0451@@2/[:`0XZ:R08f=S@0Y:BT092@T02XZ:P14
A4@0@41009ZJVP2MWId0RXZ:7?ooool0401lO7`0GEeM04U9B@1GEeL0Ogmo08^;R`0e=CD0=cLg02TY
:@0K6a/061PH04Q8B00T92@07AdM01HF5P0D51@301DE5@0[01/K6`2BTY80a/K60;no_`2m_Kd0]kNg
0451@@0K6a/071`L05eMG@2FUYH0GEeM04];B`19BDT0>3Ph06YZJP1BDU80HV9R05IFEP1RHV80`<30
07AdM00e=CD0:RXZ03<c<`11@D40H61P06m_K`20P800Ng]k0;Zj^P2^[Zh0Xj>S07IfMP1IFET0<S8b
01dM7@0L71`07AdM01TI6@0H61P07QhN01lO7`0201DE5@0<02/[:`0P82007alO028R8P1FEUH0YZJV
08f=S@0i>CT061PH01TI6@0g=cL0>CTi0`0G5aL201HF5P805aLG00l0:2PX0:RXZ02:RXX0O7al08:2
PP1XJ6P0E5AD05eMG@18B4P0CDe=04];B`16ATH0B4Q805MGE`1kNg/00P1iNGT07`2FUYH0`l?30=oO
g`3Ti>@0e]KF0<[:bP3Fe]H0b/[:0<c<c02NWYh0BTY:02@T900D51@06a/K028R8P0I6AT05ADE01/K
6`0R8R80FUYJ0:b/[02j^[X0WIfM08R8R037alL0dM7A0<[:bP1_Kfl0<C4a02XZ:P0S8b<00P0V9RH0
7`0H61P0De=C06i^KP1EEED0D51@05IFEP1/K6`0E5AD0<g=c@3AdM40_[jn08b<S02m_Kd0g]kN0=CD
e02FUYH0HF5Q04=3@`1bLW80;Bd]02DU9@0X:2P0T92@06IVIP0l?3`09BDU02HV9P11@D40V9RH07Ee
M@0f=SH00P0G5aL301DE5@0901XJ6P0F5QH05QHF01TI6@1@D500RXZ:0<30`02PX:00T92@0080Vi^K
02/0_Kfm0=_Kf`2h^;P0Cdm?05MGE`25QHD0V9RH05EEE@1IFET0UiNG09ZJVP2=SHd0GUiN05ADE01G
EeL0H61P02LW9`0Z:RX0DE5A07IfMP1gMgL0f=SH09FEU@2<S8`0I6AT02l_;`0L71`06a/K01XJ6P0M
7Ad0B4Q8069RHP1NGUh0KVi^0;2`/02FUYH0D51@07moO`1eMGD0L71`0:ZZZP1WIfL092@T00<06QXJ
01805aLG03lo?`2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=09nOW`2FUYH0R8R8071`L02D
U9@0=SHf01/K6`0G5aL201TI6@0=01hN7P0[:b/0ADE504a<C01=CDd0@D5107UiN@1lO7`0VIVI069R
HP1fMWH0EUIF04=3@`0205QHF00B04];B`0_;bl0820P01`L700M7Ad071`L01/K6`0M7Ad07QhN0410
@00c<c<0>3Ph03`l?02;Rh/0LG5a05MGE`2h^;P0bl_;0P2WYjL02@3AdM40TY:B03De=@0f=SH0@410
069RHP2e]KD0OWin04i>CP0Aooooo`003oooool09`1;Bd/0Fe]K04=3@`1fMWH0@T92061PH015ADD0
AdM704a<C00Q8B40;2`/06UYJ@1ADE40ADE503Ph>01LG5`0@D5101TI6@0R8R80410@03De=@1DE5@0
7alO03lo?`0W9bL0C4a<05eMG@1<C4`0;bl_03hn?P0D51@0;2`/065QH@0Z:RX0Vi^K03Xj>P0J6QX0
?clo05IFEP0203Xj>P0V02l_;`1JFUX0G5aL05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0
F5QH05=CD`10@400C4a<07AdM016ATH071`L02d];@1BDU80>3Ph06MWI`0f=SH07alO05ADE01VIVH0
>3Ph038b<P1IFET0=cLg01/K6`1KFe/0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0d06IVIP15
ADD0EUIF02XZ:P2<S8`0XZ:R05QHF01XJ6P0Bd];06e]K@1>CTh0SXj>09FEU@1[Jf/0<S8b0451@@1G
EeL0>c/k04U9B@2_[jl0Lg=c06QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1ZJVX0P82004a<C01c
Lg<0?Cdm04Y:BP1XJ6P0Cdm?05ADE01[Jf/0=3@d071`L013@d<0FEUI07QhN01MGEd0HF5Q055AD@0i
>CT0YZJV08n?S`21PH40C4a<09NGU`80CTi>09/0NGUi07AdM01JFUX0`<3009jNWP13@d<0WinO03lo
?`1ADE40W9bL07]kN`0a<C40MWIf05iNGP13@d<0H61P05=CD`1ADE40MGEe05aLG011@D40ZJVY07al
O01MGEd0DU9B02<S8`1fMWH0QhN703dm?@1RHV80KVi^06m_K`2?Shl0dm?C06e]K@26QXH0eMGE08n?
S`28R8P0=CDe04m?C`2@T900KVi^08>3P`2:RXX0G5aL05=CD`1VIVH0DE5A02`/;01DE5@09RHV07mo
O`1=CDd0UYJF08V9R@1YJFT0EUIF05EEE@0b<S80MWIf038b<P0o?cl0E5AD03Hf=P1fMWH0HV9R03hn
?P29RHT0ADE502<S8`2UYJD0FUYJ04a<C010@400Q8B404M7A`1BDU80<c<c05ADE01kNg/0GEeM03/k
>`1IFET0IFEU06YZJP1HF5P0;bl_051@D01iNGT0H61P03@d=023Ph<0CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1BDU80^[Zj08F5Q@1VIVH0EUIF04];B`18B4P0Z:RX07=cL`1^KVh0ADE5069R
HP1?Cdl0=cLg05UIF@17AdL0<c<c028R8P1UIFD0L71`08V9R@1dM7@0Fe]K02LW9`1YJFT0Xj>S07Ad
M00_;bl0]kNg04I6AP1VIVH0XZ:R08R8R00m?Cd0L71`07]kN`1>CTh0Fe]K09fMW@1jNWX0Ph>304e=
C@0G5aL0SHf=08n?S`1mOGd092@T02LW9`0_;bl0CTi>01hN7P1HF5P0MWIf06m_K`0Looooo`0=0820
P01ZJVX0DU9B06=SH`25QHD0IFEU06=SH`1ADE40=CDe02<S8`0I6AT08b<S01TI6@0201DE5@@04a<C
01P0410@05aLG02KVi/0M7Ad08J6QP1kNg/09RHV01TI6@0K6a/0820P071`L025QHD0M7Ad08V9R@1Y
JFT0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=C@0f=SH301DE5@0Q01LG5`0[:b/0Ng]k07em
O@2_[jl0[Zj^09NGU`1BDU80B4Q801hN7P0L71`06a/K01PH600M7Ad0:2PX01TI6@0H61P0<c<c08:2
PP0e=CD0<C4a03@d=019BDT0/k>c09nOW`1UIFD09BDU01LG5`0H61P09RHV03Lg=`0S8b<05aLG00@0
5ADE01d05aLG04Q8B02][Jd0XZ:R0:BTY027QhL0:2PX01HF5P0J6QX0;Rh^04I6AP1_Kfl0QhN708Z:
RP22PX80K6a/0492@P0K6a/0F5QH0=gMg@3Kfm/0fMWI0>3Ph03?cll0][Jf08Z:RP22PX80EEEE02HV
9P0201DE5@0301XJ6P0I6AT05aLG00806ATI02h07QhN04i>CP3GemL0eMGE06e]K@1jNWX0V9RH0=OG
e`23Ph<07AdM02TY:@0f=SH05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Q8B40=WI
f@3Bd]80e]KF04i>CP2CTi<0`/;20;Fe]@3?cll0@D5107AdM01SHf<08b<S02HV9P0Y:BT0IfMW06AT
I01bLW80=SHf038b<P0m?Cd0SHf=06e]K@1EEED0:BTY0`0E5AD201HF5P0T01LG5`0K6a/0CTi>08V9
R@1SHf<0?Shn075aL@2QXJ40a/K60=WIf@2l_;`0Zj^[0<c<c02g]kL0OGem08N7Q`1SHf<0Bd];03Hf
=P0j>SX0MGEe06i^KP10@4009bLW02/[:`15ADD0Cdm?03Lg=`17AdL0K6a/06ATI03;bl/0c/k>06IV
IP17AdL08b<S0P0L71`04@0K6a/071`L03Xj>P2RXZ80HV9R04U9B@1=CDd0K6a/07UiN@1FEUH0U9BD
0:j^[P31`L40NGUi01TI6@0H61P06QXJ00805aLG03l09RHV06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ
04m?C`1<C4`0KFe]04A4A00];Bd0CTi>04M7A`0l?3`08B4Q01PH600I6AT061PH038b<P1GEeL0HV9R
04Y:BP15ADD0Hf=S04m?C`1]KFd0S8b<06=SH`1KFe/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ
01dM7@0K6a/071`L01LG5`0K6a/07AdM03<c<`0d=3@0@D5103Xj>P1jNWX0_;bl08J6QP24Q8@0WYjN
08N7Q`3AdM40dm?C0<K6aP1^KVh0?3`l04I6AP1kNg/0UIFE05aLG01?Cdl04Oooool000oooooo0?l0
De=C06EUI@14A4@0XZ:R05aLG01oOgl0@T92069RHP1fMWH0De=C02HV9P11@D40CTi>04a<C01@D500
FEUI03dm?@0L71`0<30`02h^;P0b<S80EUIF024Q8@10@4009bLW03Lg=`1>CTh08b<S038b<P1VIVH0
@T9203@d=01GEeL09BDU09jNWP1]KFd0;Rh^0410@01QHF40=SHf05iNGP0];Bd0FUYJ06EUI@2SXj<0
?3`l03@d=01RHV80ATI608N7Q`1YJFT0@D51071`L016ATH09RHV02DU9@1RHV80D51@034a<@1PH600
=CDe01hN7P1TI6@0IFEU02TY:@1>CTh0PH6104I6AP0[:b/0MGEe079bLP0T92@0JFUY038b<P1oOgl0
Bd];05mOG`16ATH08R8R069RHP1fMWH0Jf][05aLG02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80
SHf=03Ph>01ZJVX0WIfM06e]K@1>CTh0S8b<09RHV01TI6@0NGUi0<G5a@1YJFT0KFe]07alO01RHV80
Hf=S04M7A`23Ph<0CDe=05MGE`1jNWX0CDe=08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0
DU9B02PX:00m?Cd0KFe]05aLG01CDe<0CDe=028R8P23Ph<0Shn?06IVIP0e=CD0Lg=c06ATI01ADE40
MWIf03De=@0`<300N7Qh07moO`14A4@0Vi^K06][J`17AdL0Ogmo08N7Q`0e=CD0NGUi06IVIP1WIfL0
S8b<07EeM@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0FEUI03/k>`2EUID0JFUY03dm?@1IFET0
K6a/05QHF02ZZZX0e=CD06IVIP2JVYX0g]kN06UYJ@1kNg/0=cLg04e=C@2CTi<0MWIf09>CT`2BTY80
HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1IFET0XZ:R09fMW@1`L700PH6107=cL`0c<c<0
O7al055AD@1IFET0HF5Q03`l?01oOgl0NWYj04A4A027QhL0G5aL03<c<`2YZJT0WIfM07MgM`1>CTh0
QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE03De=@1=CDd0DU9B079bLP18B4P0<c<c05]KF`1aLG40
De=C02@T901^KVh0:b/[02XZ:P1?Cdl0B4Q8065QH@0W9bL0=SHf069RHP1BDU80/[:b07]kN`1BDU80
E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0EEEE08N7Q`1SHf<0=cLg04a<C01:BTX0;2`/0451@@2LW9`0
00D0X:2P08R8R01hN7P0LW9b05MGE`0207moO`0L0451@@0[:b/0YjNW03`l?00g=cL0JVYZ06i^KP0f
=SH0MGEe07IfMP0N7Qh0;bl_07emO@1cLg<0YZJV07]kN`1;Bd/0W9bL0::RXP1XJ6P0<S8b04E5A@1>
CTh0HF5Q01dM7@1KFe/0YZJV03Ti>Acooooo0140DE5A05eMG@1@D500FEUI08>3P`1eMGD0IVIV05YJ
FP1;Bd/0AdM701dM7@0C4a<07AdM01LG5`0B4Q804A4A01@D500201<C4`0J01DE5@1;Bd/0QHF506UY
J@1]KFd0Kfm_03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<08B4Q01DE5@0G5aL0FUYJ03Xj
>P0Y:BT0<C4a07emO@2VYZH0E5AD01`L700D51@201DE5@0S01@D500i>CT0Fe]K05mOG`2a/K40a/K6
06ATI01<C4`0ATI6024Q8@0L71`08R8R02`/;00i>CT0;2`/02@T900U9BD0RHV90<o?c`2VYZH0Y:BT
0;Bd]036a/H0`L7107AdM00Y:BT071`L01PH600G5aL06ATI03De=@0[:b/05aLG01DE5@0D51@00P0E
5AD0;`0Q8B40YjNW0;Bd]02k^k/0Zj^[08n?S`1UIFD0Ph>307UiN@1KFe/0K6a/06MWI`1LG5`0=SHf
01dM7@0L71`05ADE01XJ6P2/[:`0cLg=0:^[Z`3@d=00d];B0:2PX01GEeL0P82006a/K00k>c/0>3Ph
02h^;P0X:2P0:b/[02d];@0V9RH08b<S01lO7`14A4@0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al
02TY:@0/;2`04a<C00805ADE024051@D018B4P0M7Ad0HV9R09ZJVP2e]KD0TI6A0<?3``36a/H0W9bL
0;>c/`1/K6`0OGem07AdM01RHV80OWin08F5Q@1=CDd09RHV020P800R8R809BDU03/k>`1kNg/0LG5a
04M7A`0m?Cd0BTY:05]KF`1dM7@0Bd];05ADE00W9bL00`0E5AD09P0H61P0<S8b05mOG`1hN7P0B4Q8
02PX:00U9BD0?Cdm0:f][@3;bl/0e]KF0;Ng]`2[Zj/0bLW90<k>cP3<c<`0M7Ad03/k>`0T92@07alO
02<S8`0o?cl0C4a<03<c<`0J6QX05aLG028R8P0k>c/0HF5Q06EUI@2:RXX0I6AT0:ZZZP1_Kfl0GUiN
03@d=00];Bd071`L0P0M7Ad0700_;bl0MWIf0;Ng]`2ATI40Fe]K03hn?P0^;Rh0GemO05YJFP1[Jf/0
][Jf0;fm_@2>SXh061PH01LG5`0J6QX071`L01XJ6P0M7Ad0?clo01`L700P8200IVIV0<30`01ADE40
Cdm?05UIF@0a<C420492@P0E02h^;P0f=SH0?Shn03Lg=`0o?cl0;bl_03Ph>01KFe/0RHV9061PH013
@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0SHf=05QHF00F5QH05aLG00<061PH00@06ATI01PH600J
6QX061PH0P0I6AT05@0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2_[jl0X:2P05]KF`1lO7`0YZJV0=7A
d@3?cll0Jf][09BDU02FUYH0NWYj07QhN00Y:BT08R8R03Xj>P0Aooooo`003oooool0;@1?Cdl0E5AD
0492@P1bLW80C4a<071`L00a<C40?3`l03lo?`0c<c<09RHV03lo?`0k>c/0<30`03Lg=`1HF5P0=3@d
018B4P0V9RH0:b/[02PX:01[Jf/07QhN03Xj>P0^;Rh0@D5106YZJP16ATH07AdM04E5A@0[:b/0<c<c
06MWI`0/;2`0KVi^05iNGP0O7al0@d=305ADE00Y:BT0BDU902/[:`1FEUH0@D5106MWI`0202d];@3/
06QXJ00m?Cd0Hf=S04I6AP12@T80MgMg06][J`1:BTX0=3@d04U9B@0`<30071`L02d];@0o?cl0=CDe
04];B`0n?Sh0:BTY04Y:BP1kNg/0=CDe01lO7`0o?cl0C4a<02<S8`1]KFd0>CTi05YJFP0j>SX0EEEE
06ATI00/;2`0D51@06=SH`1EEED0>SXj079bLP12@T80Ng]k09BDU016ATH0H61P04];B`1^KVh0F5QH
06IVIP2LW9`0JVYZ03hn?P1<C4`0FUYJ06ATI01iNGT0alO707emO@1VIVH0K6a/04Q8B01_Kfl0B4Q8
09:BTP1CDe<0DE5A07EeM@1KFe/0LW9b075aL@12@T80BDU904A4A01<C4`0KVi^04U9B@1RHV80?clo
03dm?@1HF5P0EEEE04e=C@1GEeL0ADE509JFUP2ATI40Jf][05]KF`2@T900IFEU04m?C`23Ph<0NGUi
04I6AP2IVIT0Ti>C04E5A@2UYJD0TY:B055AD@1hN7P0KFe]0451@@2<S8`0Vi^K05mOG`24Q8@0F5QH
04];B`2>SXh0W9bL06e]K@2FUYH0Fe]K06IVIP1fMWH0B4Q808Z:RP1GEeL0=CDe05aLG02YZJT0RXZ:
09:BTP3De=@0JFUY07IfMP30`<00Rh^;096AT@0o?cl0DU9B07EeM@12@T80RHV90:2PX01RHV80DU9B
065QH@0e=CD0?3`l04a<C00V9RH0MWIf061PH02`/;00Z:RX065QH@2KVi/0GEeM03/k>`2CTi<0I6AT
05]KF`1UIFD0:BTY092@T02IVIT0@D51071`L01VIVH0<c<c07inOP1iNGT0MGEe05=CD`2WYjL0JVYZ
069RHP0W9bL0<C4a05YJFP2;Rh/0>SXj05mOG`0n?Sh0T92@07QhN00e=CD0JVYZ07inOP11@D409bLW
07=cL`18B4P0=3@d051@D013@d<0EEEE01`L700h>3P0J6QX05UIF@2_[jl0KFe]03<c<`1lO7`0X:2P
04e=C@2BTY80SHf=051@D00f=SH0K6a/03Xj>P0];Bd0Cdm?05mOG`0i>CT08R8R05aLG01JFUX0EUIF
07MgM`29RHT0HV9R0820P02OWil0DE5A02TY:@24Q8@0Fe]K03hn?P1fMWH0H61P02`/;01_Kfl0OGem
04A4A01DE5@0RXZ:04E5A@1`L700Ng]k03@d=02:RXX0_kno08N7Q`0T92@202DU9@0504I6AP0Q8B40
M7Ad0:^[Z`1RHV807?ooool07@1LG5`0Bd];04m?C`1]KFd0MgMg07]kN`19BDT0@410051@D016ATH0
:BTY038b<P0M7Ad04A4A01DE5@0C4a<04A4A00h>3P0@41007alO05aLG01ZJVX0Ph>307=cL`1PH600
GUiN01XJ6P0A4A40410@00803`l?02`03Ph>010@400A4A405ADE01<C4`0G5aL0B4Q80820P01NGUh0
F5QH07]kN`2KVi/0Hf=S024Q8@0J6QX051@D01DE5@17AdL0_kno0:ZZZP32`/80Z:RX08Z:RP2PX:00
PX:206EUI@1EEED0FEUI0410@00k>c/0=3@d03hn?P1NGUh0HV9R07alO01FEUH0H61P0861P@2OWil0
Ph>309RHV01]KFd08R8R01TI6@806QXJ00X06a/K03@d=01_Kfl0HV9R04Q8B01@D500Hf=S05IFEP1?
Cdl0_Kfm0P2n_[h0202l_;`0JFUY05aLG01EEED0B4Q804I6AP13@d<0BTY:0P16ATH0801<C4`0:BTY
04i>CP2TY:@0bl_;09nOW`2h^;P0SXj>04E5A@0N7Qh0;Bd]03lo?`1QHF40NGUi08N7Q`1_Kfl0C4a<
04=3@`11@D40BTY:05=CD`2EUID0CDe=06YZJP16ATH08b<S03Hf=P2GUiL0ADE503Hf=P0N7Qh04Q8B
0P0E5AD301@D500Y02<S8`1TI6@0WinO0820P02a/K40IFEU04Q8B019BDT0L71`09NGU`1SHf<0Fe]K
05mOG`2>SXh0<30`01hN7P0I6AT07alO01hN7P0P8200GEeM04e=C@1DE5@0;2`/03Ph>00f=SH0IFEU
06m_K`1?Cdl0DU9B04M7A`0j>SX0?Shn04Q8B01KFe/0>c/k02TY:@0R8R808b<S02LW9`1FEUH00P27
QhL0202CTi<0ZJVY0:n_[`2JVYX0J6QX0:NWY`1:BTX07alO0P0P8200>00U9BD0;Rh^04M7A`0d=3@0
6QXJ01`L700G5aL061PH028R8P1_Kfl0NGUi05QHF01`L700>c/k06=SH`0f=SH0;2`/024Q8@0R8R80
@T9205IFEP1?Cdl0;bl_02h^;P1PH600E5AD04M7A`1BDU80LW9b0<71`@2i^KT0R8R808:2PP1MGEd0
7QhN01PH600M7Ad061PH01lO7`0_;bl0B4Q808Z:RP2FUYH0FUYJ04];B`0j>SX092@T01XJ6P0M7Ad0
;2`/04Q8B01IFET0HV9R04m?C`1UIFD0_;bl0P30`<001`2m_Kd0WYjN0820P024Q8@0_;bl0:^[Z`2V
YZH00P2e]KD0101CDe<0EEEE038b<P0H61P201LG5`0401HF5P0G5aL061PH01XJ6P808B4Q01H07AdM
020P8011@D40@41004A4A01gMgL0UiNG09VIV@29RHT0FUYJ06][J`2b/[80cLg=09ZJVP2<S8`0J6QX
06][J`2;Rh/0B4Q801hN7P0P8200@d=34Oooool000oooooo0700EeMG06MWI`12@T80Zj^[05ADE02B
TY80@T9204=3@`18B4P0LG5a02l_;`1?Cdl0IFEU030`<010@400GUiN04i>CP0O7al0820P024Q8@0Y
:BT0EUIF01hN7P0e=CD06QXJ038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0<C4a065QH@1M
GEd08b<S03Ph>01<C4`0:RXZ03lo?`0X:2P0IfMW04Q8B01gMgL0@D5103Ti>@1GEeL0<S8b06a/K01N
GUh0DU9B07MgM`1/K6`0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`13@d<0CDe=02XZ:P0]
;Bd0KVi^02d];@0Y:BT0EUIF069RHP0Q8B40Fe]K034a<@1DE5@0ADE504I6AP1FEUH0;bl_03/k>`1C
De<0I6AT0492@P1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^02h^;P1@D500U9BD07MgM`11
@D40Fe]K05aLG01DE5@0FEUI0:n_[`2CTi<0F5QH08R8R01BDU80NGUi04I6AP27QhL0GUiN05UIF@1W
IfL0GemO0P1UIFD0@01BDU80K6a/04m?C`1@D500IVIV03De=@26QXH0@T9204Y:BP1?Cdl0AdM704A4
A01YJFT0DE5A06UYJ@1jNWX0JFUY05iNGP1/K6`0Lg=c03<c<`2BTY80YJFU051@D02:RXX0Rh^;02TY
:@2@T900R8R8051@D025QHD0Ti>C059BDP1hN7P0RHV905eMG@2VYZH0K6a/02HV9P1DE5@0OGem04Q8
B023Ph<0ADE505IFEP2CTi<0Bd];08j>SP1lO7`0CTi>04M7A`2e]KD0@d=303hn?P37alL0PH6108:2
PP3AdM40EUIF01hN7P0a<C40M7Ad09nOW`1bLW8208>3P`0G069RHP2HV9P0P82004a<C00^;Rh0GUiN
01`L700d=3@0Bd];08B4Q02GUiL0EUIF0;jn_P1CDe<0<C4a09bLW01dM7@0F5QH0820P013@d<0Lg=c
08b<S00h>3P00P2CTi<0E@0j>SX0U9BD06e]K@1CDe<0:BTY05QHF01OGel0IfMW03hn?P1KFe/0Q8B4
08N7Q`0g=cL0PX:205IFEP2ATI40EEEE02<S8`1SHf<0MGEe05EEE@0a<C40K6a/04I6AP0/;2`0FEUI
06ATI01_Kfl0EEEE0410@01:BTX0;Bd]06i^KP1kNg/0GEeM06IVIP1hN7P0:2PX05UIF@1YJFT0HF5Q
04I6AP1lO7`0HV9R02/[:`1;Bd/0DE5A03Lg=`0a<C40QhN70:j^[P1fMWH0BTY:06=SH`18B4P0ADE5
08B4Q01^KVh0820P07=cL`1LG5`0;bl_0:6QX@2CTi<0ADE5069RHP1`L70061PH038b<P1gMgL0G5aL
07QhN01FEUH0@d=303Lg=`2d];@0HV9R01lO7`0d=3@0;Bd]06UYJ@0I6AT0@T920:n_[`1kNg/07?oo
ool07@0o?cl0A4A405]KF`1@D500UYJF06ATI01KFe/0:2PX01dM7@0c<c<0E5AD03/k>`0F5QH04A4A
01@D500U9BD08R8R01TI6@0e=CD0V9RH0:>SX`1eMGD0^k^k0820P01]KFd0XZ:R06m_K`0W9bL05ADE
00<03Ph>03d03@d=00l?3`0?3`l04Q8B01/K6`1YJFT0RXZ:08:2PP2FUYH0]kNg0<K6aP2@T900WYjN
04m?C`0`<300Ph>30<C4a03Lg=`0_kno07YjNP1?Cdl0Bd];05EEE@1?Cdl0IFEU0861P@1dM7@0GemO
071`L01aLG40/k>c07EeM@1LG5`0HF5Q06i^KP1>CTh0AdM706e]K@2FUYH0/;2`07IfMP2OWil0Bd];
04A4A01GEeL0FEUI05=CD`10@400<c<c02LW9`0g=cL0C4a<05ADE01oOgl0UIFE092@T02DU9@0_[jn
051@D00R8R80>c/k00805aLG02@07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0M7Ad0:6QX@3GemL0d=3@
0<G5a@1BDU807alO01LG5`0I6AT07alO01`L700V9RH0EUIF079bLP0K6a/05ADE01HF5P0E5AD061PH
06ATI00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l?00D51@3014A4@1=01<C4`0D51@0
4Q8B03dm?@1?Cdl0LG5a08N7Q`20P800Q8B407YjNP1bLW80Shn?03@d=00T92@08B4Q02l_;`1[Jf/0
>SXj01LG5`0K6a/0>c/k02HV9P0W9bL0Jf][04E5A@0i>CT06ATI02/[:`1IFET0DU9B07UiN@0o?cl0
MgMg0;>c/`15ADD0Hf=S05aLG00O7al06a/K01`L700J6QX0>3Ph07EeM@1cLg<0LW9b04A4A00h>3P0
Fe]K07YjNP1ADE40MWIf0861P@0R8R806QXJ028R8P0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL0
6QXJ02h^;P1MGEd0Hf=S05ADE01SHf<0;2`/03hn?P1FEUH07AdM0451@@0n?Sh0C4a<02d];@0P8200
0P0Q8B40500];Bd0=CDe02PX:00/;2`0ADE50;Fe]@1LG5`0Cdm?04M7A`1FEUH0E5AD01TI6@0G5aL0
6a/K02TY:@21PH40Xj>S075aL@1DE5@0=SHf0`0L71`0600J6QX07AdM01hN7P0];Bd0MWIf09bLW01M
GEd0@410061PH02m_Kd0Xj>S0;Ng]`31`L40/;2`0:6QX@35aLD0/[:b0:ZZZP24Q8@0JVYZ04];B`0^
;Rh0@d=3038b<P805ADE01`06a/K01DE5@0H61P071`L02<S8`0M7Ad0820P02@T901BDU80B4Q807mo
O`1`L700ATI606MWI`0L71`08R8R04e=C@3:b/X0NWYj05ADE01iNGT0^;Rh08:2PP1<C4`09RHV02<S
8`0_;bl0>3Ph4Oooool000oooooo04<0GEeM061PH013@d<0[jn_05ADE022PX80@d=308j>SP2PX:00
Ogmo03Ph>01=CDd0Fe]K03Ti>@1=CDd0FUYJ04a<C00O7al0<S8b02/[:`0b<S80Fe]K01hN7P0m?Cd0
:RXZ0451@@1BDU80B4Q802XZ:P1SHf<0?3`l03@d=011@D40;bl_06=SH`1eMGD0<S8b03Hf=P1CDe<0
;Bd]03`l?00c<c<0IFEU04e=C@2TY:@0HV9R03lo?`1IFET0>3Ph08N7Q`1fMWH0EeMG0820P01aLG40
F5QH05=CD`1RHV80JVYZ02PX:00_;bl0C4a<04E5A@1UIFD0Kfm_03Hf=P0V9RH0OGem0080820P05L0
@D51075aL@0V9RH0De=C02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>304A4A01NGUh0
71`L05UIF@2>SXh0GUiN07emO@2<S8`0QHF5069RHP1HF5P0YJFU06a/K01=CDd0SHf=08N7Q`1]KFd0
D51@07IfMP1iNGT0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0GEeM05MGE`1FEUH0
@D5107MgM`1EEED0BTY:06a/K01<C4`0H61P04E5A@1GEeL0Jf][06=SH`1DE5@0AdM7024Q8@1PH600
Rh^;05QHF00Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP17AdL0TY:B03Lg=`0Z:RX0
EUIF07EeM@1`L700WIfM0:6QX@0m?Cd0De=C06=SH`0/;2`0HF5Q06MWI`12@T800P2BTY80=@1PH600
EEEE01hN7P16ATH0Ogmo061PH01:BTX0/;2`03Xj>P1UIFD0clo?07=cL`27QhL0c/k>07AdM01eMGD0
:b/[03lo?`1eMGD0I6AT08n?S`2:RXX0EUIF04U9B@1;Bd/0?clo04=3@`15ADD09bLW05MGE`1HF5P0
YjNW04M7A`0n?Sh0/;2`07alO00k>c/0Y:BT034a<@0D51@0EEEE0410@01fMWH0QHF502LW9`1BDU80
IfMW03<c<`2EUID0Y:BT08B4Q01LG5`0RXZ:0080CDe=04d08b<S04Y:BP1YJFT0TY:B03Hf=P1iNGT0
=3@d092@T01kNg/0=3@d04I6AP1]KFd08b<S01LG5`1PH600FUYJ02`/;00`<300;2`/04a<C00f=SH0
HF5Q08V9R@1HF5P0R8R806][J`0h>3P0P8200;>c/`1RHV80KVi^07AdM01GEeL08b<S06IVIP1XJ6P0
;Bd]04U9B@1>CTh0:RXZ01PH6013@d<0JFUY07YjNP1>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF506MWI`0M7Ad0IVIV06=SH`0n?Sh0Ng]k061PH00f=SH0AdM7075aL@1TI6@0YJFU06YZJP1CDe<0
<C4a09ZJVP1mOGd08B4Q04m?C`1LG5`0MWIf01`L700m?Cd0_kno065QH@0Looooo`0O03@d=00Y:BT0
;Rh^08b<S01aLG40GEeM08j>SP0f=SH07AdM01`L700W9bL0GUiN05QHF00/;2`0BDU905aLG01XJ6P0
LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`07moO`2EUID0@41001LG5`0[:b/0410@00h>3P0200d=
3@0600h>3P0?3`l0;Rh^061PH01DE5@0<S8b0P0V9RH02`14A4@0PH610:>SX`2JVYX0cLg=0=;BdP2]
[Jd0`L710=?Cd`2l_;`0GemO0080<S8b02X0Fe]K03hn?P1=CDd0HF5Q04Y:BP0S8b<092@T038b<P2A
TI40EUIF04A4A012@T80CTi>02PX:00l?3`0Jf][075aL@2CTi<0SXj>075aL@2UYJD0Shn?06IVIP1@
D500@410030`<00b<S80?clo05UIF@1eMGD0KVi^09>CT`26QXH0_Kfm0:2PX03<c<`0UIFE02/[:`0G
5aL05ADE01<C4`0F5QH2024Q8@0Q038b<P0V9RH0TI6A08B4Q02[Zj/0WYjN0<[:bP2k^k/0UiNG01hN
7P0>3Ph04a<C01/K6`0S8b<09bLW02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1DE5@08B4Q01/K
6`1_Kfl0:BTY034a<@2_[jl0@T9201hN7P0g=cL05QHF00804a<C01@03Ph>010@400E5AD051@D04A4
A00i>CT0RXZ:06IVIP1QHF40=3@d02HV9P0N7Qh0>c/k01LG5`0N7Qh0820P02TY:@0[:b/0D51@04Y:
BP805aLG0140>c/k03`l?01ZJVX0B4Q805UIF@0L71`0;Bd]06ATI017AdL0BTY:07YjNP2NWYh0[Zj^
06MWI`0n?Sh08B4Q01/K6`0202<S8`0W02`/;01dM7@0PX:2061PH016ATH0=CDe02`/;00d=3@0G5aL
07=cL`2:RXX0]kNg06ATI00b<S80>CTi051@D01JFUX0KFe]05MGE`1@D500@D5104Q8B01BDU80GemO
06UYJ@25QHD0CDe=06m_K`0^;Rh0<30`069RHP0b<S80AdM704=3@`0n?Sh08R8R024Q8@0_;bl07AdM
00809bLW02h07alO028R8P0Y:BT0[Jf]05MGE`0j>SX0G5aL02DU9@1HF5P0Kfm_01XJ6P0I6AT0JFUY
092@T01^KVh0KFe]02HV9P0G5aL061PH01LG5`0H61P05aLG01/K6`0L71`07alO07]kN`2o_kl0E5AD
04I6AP1>CTh0YJFU0;Jf]P2i^KT0`l?30<71`@2j^[X0Xj>S09^KV`27QhL0/k>c09fMW@1aLG40?3`l
034a<@17AdL08B4Q0P0G5aL06`0E5AD06QXJ01`L700N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0
>3Ph04];B`1HF5P071`L02d];@21PH40WYjN05=CD`19BDT0L71`0:FUY@2e]KD0C4a<03Hf=P0`<300
;Rh^03Lg=`0Aooooo`003oooool0M`1HF5P0De=C03Ph>01jNWX0CDe=07AdM00b<S80;Rh^05MGE`1]
KFd0:RXZ04Q8B00b<S806QXJ04a<C01?Cdl04a<C00T92@0k>c/0A4A402d];@1mOGd051@D03@d=01=
CDd0?3`l05eMG@0j>SX061PH04M7A`1IFET0@41003/k>`0U9BD0Lg=c092@T00n?Sh0<C4a05QHF00P
8200ATI603De=@14A4@092@T06IVIP1GEeL0<C4a05MGE`0_;bl0IVIV06ATI01?Cdl0P8200451@@0^
;Rh0BDU9069RHP1aLG40:2PX04Q8B01GEeL09BDU03Hf=P1GEeL0:BTY03Lg=`27QhL0BDU902@T900g
=cL0CDe=02HV9P1TI6@08b<S04M7A`1CDe<0>c/k06a/K00Z:RX0=SHf05MGE`1OGel0A4A408R8R01E
EED0FEUI0:j^[P0T92@0<S8b04E5A@1WIfL0EeMG05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1l
O7`0cLg=07moO`0i>CT0NWYj055AD@1<C4`09RHV06EUI@1<C4`0AdM705aLG00o?cl0KFe]06MWI`1@
D500MWIf01dM7@0d=3@0J6QX0080H61P06d07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1d
M7@0G5aL03lo?`1>CTh0MgMg030`<01eMGD0G5aL03hn?P1gMgL0VYZJ051@D02NWYh0QXJ604E5A@1G
EeL0L71`05QHF01VIVH0Shn?06UYJ@1cLg<0GUiN03Lg=`22PX80V9RH059BDP1>CTh0NGUi07EeM@23
Ph<0C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0GEeM071`L030`<00SHf=092@T00h
>3P0EEEE08j>SP0^;Rh0PH610:>SX`28R8P0Ph>306e]K@0h>3P0E5AD06YZJP0J6QX08b<S05QHF02l
_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1dM7@07alO07QhN02MWId0CDe=06MWI`1P
H6007AdM05eMG@1KFe/0IVIV05=CD`1fMWH0BTY:05eMG@0W9bL0>c/k04Y:BP1^KVh0:b/[06ATI00T
92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU0492@P1FEUH0?3`l0080=3@d03X0CTi>00l?3`0V
9RH0FUYJ06MWI`2@T900OWin02@T901ADE40MWIf06ATI01QHF40G5aL07=cL`15ADD0I6AT06IVIP0b
<S80Bd];05]KF`1XJ6P09BDU04I6AP1NGUh0M7Ad07YjNP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15
ADD0HF5Q02TY:@1oOgl0G5aL02PX:022PX80TI6A05UIF@1:BTX0Jf][03lo?`1bLW80J6QX05eMG@0^
;Rh0SHf=075aL@0N7Qh0820P02DU9@1KFe/071`L03`l?02h^;P0IFEU7?ooool0D@0g=cL0:RXZ02LW
9`1JFUX0IVIV07EeM@2PX:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe059BDP0Z:RX09RHV04U9
B@1]KFd0QhN708b<S02b/[80d=3@0<c<c015ADD0Ph>307AdM00E5AD04Q8B010@400>3Ph03@d=018B
4P0_;bl0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0MWIf06a/K03>c/h0eMGE0:ZZ
ZP34a<@0d];B08j>SP2RXZ80IfMW03Ti>@1XJ6P0Hf=S061PH01RHV80K6a/04=3@`0T92@07QhN05UI
F@0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2MWId0^[Zj09fMW@2IVIT0Vi^K05EE
E@11@D40DU9B05iNGP0205EEE@0>06UYJ@2KVi/0`l?30:JVYP26QXH0];Bd0:j^[P1/K6`0IfMW05AD
E00Y:BT05aLG01DE5@0J6QX201DE5@0=028R8P2TY:@0_[jn05mOG`1KFe/0XZ:R0;no_`2;Rh/0JVYZ
01LG5`0E5AD05aLG024Q8@0202HV9P0B02XZ:P0k>c/0BTY:02d];@0K6a/0;Bd]05MGE`0P82006ATI
05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/;00Q8B404a<C0P0E5AD08`0@41005ADE01LG5`1^KVh0
CDe=09jNWP12@T80=CDe01TI6@0L71`06a/K04Y:BP0e=CD092@T02LW9`0Y:BT0<C4a03Ph>01QHF40
De=C01PH600G5aL0=SHf07AdM01HF5P0ZZZZ09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800
<C4a00<07alO07H08R8R030`<024Q8@0SHf=06UYJ@1CDe<0D51@030`<00[:b/0:BTY03Lg=`1^KVh0
_;bl0<K6aP2XZ:P0UYJF07]kN`1EEED0Bd];05IFEP0n?Sh0@41005aLG014A4@0ATI604A4A01aLG40
_kno06MWI`2k^k/0Vi^K08J6QP2CTi<0^;Rh0:FUY@2=SHd08b<S01XJ6P0L71`07QhN01LG5`0M7Ad0
8B4Q02XZ:P0e=CD0MGEe0>3Ph02d];@0;bl_05eMG@1aLG408b<S06ATI01SHf<0JVYZ0:2PX01iNGT0
I6AT02@T900J6QX05ADE01/K6`0H61P06ATI01PH600G5aL06a/K020P801IFET0b<S80:FUY@2?Shl0
TI6A0;>c/`37alL0]kNg0:b/[02KVi/0J6QX06MWI`1^KVh0QhN706=SH`1fMWH0SXj>06EUI@0d=3@0
>c/k04E5A@0G5aL05QHF01LG5`0I6AT07alO028R8P0P8200:2PX06QXJ02e]KD0UYJF06=SH`17AdL0
P82003Xj>P0V9RH0<c<c08j>SP1LG5`0?clo05ADE01FEUH0W9bL05YJFP2GUiL0Fe]K06ATI01ADE40
FEUI4Oooool000oooooo02L0CDe=06][J`0m?Cd0Rh^;04i>CP2IVIT0ADE504Y:BP10@400O7al030`
<01;Bd/0KVi^03lo?`10@400Bd];03De=@0I6AT07alO01dM7@0F5QH0Fe]K02XZ:P0];Bd09bLW030`
<01[Jf/0DE5A02XZ:P0i>CT0:BTY02d];@1EEED0;Rh^03Ti>@1NGUh0820P0410@01[Jf/00P0e=CD0
T@0P8200Fe]K03Xj>P1cLg<09BDU01lO7`1ADE40BTY:075aL@0b<S80;2`/07=cL`1XJ6P0?clo03<c
<`1:BTX06QXJ01@D500d=3@0CDe=04a<C00l?3`0@T9200h>3P0N7Qh0CDe=04A4A00Y:BT0ADE502TY
:@0@4100ATI603hn?P1;Bd/0=SHf01XJ6P1BDU80@T92038b<P1>CTh0Cdm?02HV9P1OGel0FUYJ05AD
E02b/[80A4A405ADE01MGEd0GUiN03dm?@1^KVh0][Jf08b<S01CDe<0D51@03lo?`1DE5@0MWIf0;bl
_01mOGd0=SHf07MgM`1ADE40IfMW02`/;01FEUH0ADE505YJFP1_Kfl0?3`l0410@01BDU80ADE508N7
Q`0m?Cd0?clo06m_K`15ADD0Hf=S04U9B@12@T80ATI603Lg=`11@D40I6AT03/k>`1<C4`0JFUY069R
HP1JFUX0C4a<08n?S`0e=CD0KFe]08>3P`1@D500Q8B409ZJVP0^;Rh0MgMg0:>SX`1:BTX0HV9R08J6
QP1>CTh0EUIF071`L01SHf<0Ogmo05MGE`0M7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WYjN05QH
F014A4@0N7Qh02<S8`17AdL0Z:RX08J6QP1gMgL0hN7Q06QXJ01NGUh0TY:B07AdM020P800GemO08V9
R@2i^KT0MGEe07UiN@2IVIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0>P1;Bd/0Ph>3096A
T@1IFET0R8R8061PH00`<300WYjN07UiN@1WIfL0Rh^;024Q8@1FEUH0SXj>03`l?01MGEd0NWYj03@d
=01gMgL0I6AT04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02d];@1JFUX0>CTi069R
HP0j>SX0=cLg05UIF@1cLg<0IFEU03De=@16ATH0HV9R04Q8B00h>3P0=3@d06EUI@1]KFd0BTY:04Q8
B01KFe/0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`205aLG00Z055AD@0/;2`0F5QH
07alO01jNWX08B4Q03lo?`1PH600@d=304E5A@2>SXh0SHf=04M7A`2f][H0M7Ad02/[:`19BDT0MWIf
02d];@1lO7`0HV9R04Y:BP1lO7`0NGUi03lo?`1;Bd/0JFUY061PH02GUiL0HF5Q05EEE@0Z:RX0UiNG
06e]K@0W9bL0;Bd]02l_;`1cLg<0:2PX03Ph>02`/;00R8R87?ooool0;@0g=cL0;Bd]02HV9P0X:2P0
J6QX05mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01eMGD0QXJ607emO@2@T900U9BD05=CD`0/;2`0
:BTY034a<@2:RXX0d];B0<?3``27QhL0Ti>C0:f][@0Y:BT09bLW03Hf=P1BDU80D51@04a<C00a<C40
7QhN01lO7`0Q8B407alO01/K6`0N7Qh07AdM01/K6`0L71`0Lg=c0;Jf]P020>3Ph00F0=GEe@2XZ:P0
KVi^0:6QX@2][Jd0`<3008n?S`2TY:@0]kNg08n?S`2=SHd0@d=303/k>`13@d<0=cLg05]KF`1FEUH0
BTY:03hn?P0_;bl0;Rh^01/K6`805ADE03d05aLG08f=S@2o_kl0ZJVY06=SH`2JVYX0cLg=06IVIP0h
>3P0:b/[024Q8@0J6QX0:BTY06m_K`1RHV80NWYj09ZJVP2l_;`0W9bL051@D00S8b<0>c/k05iNGP1T
I6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800WIfM04m?C`1=CDd0^k^k0:VYZ@1nOWh0Kfm_05]KF`0I
6AT06a/K01dM7@0T92@0820P02LW9`0Y:BT0:RXZ04=3@`1;Bd/0N7Qh04E5A@0I6AT05aLG08>3P`2M
WId0/[:b09^KV`33`l<0NWYj05]KF`0P82004A4A0080410@0P0C4a<06P0m?Cd0/k>c09NGU`2a/K40
>CTi04Q8B00m?Cd0:b/[03dm?@0V9RH07QhN02XZ:P0O7al09bLW02HV9P0f=SH0?3`l069RHP1SHf<0
5QHF01DE5@0f=SH0OWin0:f][@2k^k/0LW9b0P1DE5@06`1YJFT0W9bL0::RXP1/K6`0D51@055AD@1;
Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT06ATI00k>c/0<c<c038b<P0d=3@0R8R80=7Ad@2<
S8`0De=C055AD@2:RXX0Ti>C07]kN`0204U9B@0V03lo?`17AdL0<c<c03Lg=`0i>CT0Q8B409ZJVP1^
KVh0YZJV08J6QP1cLg<0Shn?0;Zj^P2GUiL0Q8B408F5Q@1iNGT0PX:208Z:RP2>SXh0TI6A09bLW02h
^;P0d];B0>7Qh@3EeMD0b/[:092@T020P800e=CD09FEU@1FEUH0b/[:0=oOg`2XZ:P0JVYZ03De=@0L
71`201LG5`0301TI6@0F5QH061PH00805aLG00/06ATI038b<P1hN7P0XZ:R0<;2`P3EeMD0^KVi09nO
W`2][Jd0JVYZ04M7A`0203Ph>004038b<P0g=cL0?Shn05EEE@80IFEU0240JVYZ04=3@`0m?Cd0ADE5
038b<P0K6a/06QXJ01/K6`0N7Qh07AdM038b<P1[Jf/0X:2P0:BTY02e]KD0Kfm_08V9R@1hN7P08b<S
02LW9`0j>SX0TI6A04M7A`0j>SX0FEUI05ADE01KFe/0>3Ph08F5Q@1CDe<0?Shn03/k>`0n?Sh04Ooo
ool000oooooo06@0G5aL06a/K010@400Q8B403hn?P1>CTh0>CTi05ADE017AdL0<C4a01lO7`0f=SH0
F5QH03lo?`0V9RH08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b0451@@0b<S80;Rh^01TI6@0a<C40
BTY:02HV9P0_;bl07QhN01TI6@0`<300>CTi04a<C01eMGD03Ph>018B4P0i>CT0?Cdm02d];@0B4Q80
?clo04Y:BP20P800<30`01LG5`0e=CD0>SXj061PH017AdL0:RXZ04i>CP1MGEd0AdM704m?C`1KFe/0
A4A402PX:00];Bd0CDe=05IFEP11@D40>c/k01hN7P0J6QX0GEeM03Ph>00S8b<0EEEE05eMG@0U9BD0
Bd];03@d=01BDU80EeMG02PX:01VIVH0@41002`/;01CDe<0IVIV04=3@`1RHV80>c/k04E5A@2[Zj/0
Lg=c05EEE@1KFe/0JFUY02HV9P1?Cdl0Vi^K08>3P`1>CTh0EeMG0492@P1YJFT0?Shn0P2=SHd0^00o
?cl0OGem04M7A`2SXj<0Cdm?08>3P`0R8R80BTY:07YjNP1MGEd0De=C04i>CP0K6a/0RHV907EeM@1@
D500NGUi034a<@1SHf<0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0JFUY071`L016
ATH0Vi^K051@D01ADE40Lg=c04E5A@1nOWh0WinO03Hf=P1KFe/0KVi^05aLG02IVIT0X:2P06EUI@1[
Jf/0Kfm_06e]K@2g]kL0Ogmo03De=@1PH600LG5a071`L01nOWh0NGUi04E5A@1dM7@0De=C04m?C`2;
Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0O7al07]kN`2/[:`0FEUI03Hf=P0j>SX0JFUY09NGU`1_
Kfl0Ogmo09ZJVP0m?Cd0/K6a07UiN@0j>SX0@T9206EUI@0e=CD0>3Ph04i>CP21PH40Shn?06IVIP1Z
JVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0AdM704];B`2>SXh0;Rh^07YjNP1oOgl0?Shn07QhN01W
IfL0HF5Q038b<P1JFUX0IFEU071`L018B4P0IFEU065QH@2NWYh0=3@d08>3P`1<C4`0Kfm_0451@@0Q
8B40DU9B07alO01VIVH0?Cdm04];B`0n?Sh09BDU03Ti>@1IFET0LW9b071`L01BDU80BTY:03Lg=`2D
U9@0ZJVY06EUI@1IFET0OWin03Xj>P1LG5`0Vi^K08n?S`1FEUH0E5AD061PH00`<300B4Q806YZJP1i
NGT0:2PX03dm?@1gMgL0Ng]k04Y:BP23Ph<0Rh^;04a<C033`l<0P82002h^;P1<C4`0PX:202XZ:P2I
VIT0LW9b05EEE@1oOgl0P82005UIF@1;Bd/0NGUi05iNGP2OWil0CDe=02l_;`10@400TI6A07UiN@0f
=SH0:b/[03De=@1VIVH203De=@030:JVYP2ATI7ooooo01_ooooo03X0>3Ph02TY:@0Y:BT08R8R07Mg
M`1=CDd0^KVi08R8R02ATI40VYZJ08>3P`1nOWh0RHV90;Fe]@2n_[h0[:b/09:BTP1SHf<0JVYZ096A
T@2HV9P0bLW90=oOg`2@T900P8200=OGe`3Kfm/0bLW908Z:RP1DE5@0<30`01/K6`0H61P05aLG01PH
600F5QH06QXJ01TI6@0E5AD061PH01TI6@0J6QX07AdM08f=S@2JVYX0b<S80<O7a`25QHD0Bd];0451
@@1oOgl0a<C40=?Cd`2IVIT0GEeM0::RXP2FUYH0Shn?0P24Q8@0=01_Kfl0EUIF0451@@0h>3P08R8R
01dM7@0S8b<07AdM01`L700E5AD04A4A01LG5`1VIVH0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe
01PH600K6a/06ATI03lo?`1CDe<0Lg=c09NGU`3Kfm/0bLW904E5A@1:BTX05QHF01DE5@0K6a/0;2`/
03lo?`1MGEd0Y:BT0:^[Z`1EEED0CTi>09NGU`1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K
020P800K6a/201dM7@0R024Q8@0R8R808R8R01lO7`0T92@0ATI6055AD@0_;bl0HF5Q0;>c/`2^[Zh0
@410028R8P1RHV80RXZ:065QH@1OGel0<C4a01/K6`0A4A4071`L03lo?`1IFET0GUiN0<;2`P36a/H0
C4a<04A4A01oOgl0OGem05]KF`0J6QX05ADE018B4P808b<S05809BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80`l?307UiN@16ATH0?clo04Y:BP2>SXh0ZZZZ08Z:RP1ADE40CTi>04];B`1F
EUH0Ng]k0:RXZ022PX80MWIf04a<C02ATI40BTY:03De=@13@d<0BDU904=3@`1WIfL0ZJVY0::RXP2D
U9@0L71`065QH@1CDe<0PH6109nOW`2=SHd0UYJF04=3@`0Y:BT09bLW02`/;00h>3P0QXJ608b<S02>
SXh0SHf=08V9R@1[Jf/0ZJVY0=?Cd`39bLT0X:2P0:FUY@2>SXh0Lg=c06IVIP1mOGd0O7al07MgM`1b
LW80O7al0;jn_P3@d=00PX:20;:b/P3<c<`0WinO06EUI@1kNg/0fm_K0>CTi02`/;00<C4a0410@00F
5QH061PH0P0G5aL201DE5@805QHF01D06ATI061PH02CTi<0=SHf07YjNP34a<@0IVIV08^;R`2WYjL0
De=C03De=@0Z:RX0:b/[02XZ:P0_;bl0;Bd]03Hf=P1=CDd0GEeM05IFEP1[Jf/00P1?Cdl06`1hN7P0
?clo03@d=00f=SH0?Shn069RHP1bLW80MGEe0:RXZ02m_Kd0]kNg08n?S`2_[jl0Bd];02@T900^;Rh0
EEEE09VIV@19BDT0B4Q8065QH@1LG5`0A4A403dm?@1TI6@07alO020P800201lO7a7ooooo000?oooo
o`1`06i^KP29RHT0ADE509ZJVP1FEUH0LG5a03Ti>@1OGel0Ng]k05]KF`0[:b/0;Bd]04Y:BP0d=3@0
Cdm?03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c04m?C`0W9bL0BDU905iNGP0a<C40
=CDe04Y:BP1@D500=cLg030`<017AdL0KVi^034a<@0V9RH0B4Q802d];@0g=cL0<C4a04i>CP0o?cl0
T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0CDe=01dM7@1=CDd0M7Ad06MWI`0d=3@0
<S8b05]KF`16ATH0CDe=075aL@0j>SX07alO065QH@0j>SX071`L06ATI022PX80=3@d04M7A`0[:b/0
Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`0n?Sh0FEUI02XZ:P0[:b/0RHV905mOG`1DE5@0
IVIV07moO`1aLG40EEEE0:NWY`1cLg<0DU9B07]kN`1_Kfl0IVIV04U9B@1DE5@0NGUi04E5A@22PX80
>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE05]KF`80M7Ad0140A4A407]kN`1ZJVX0EEEE08V9R@1Z
JVX0H61P05ADE01^KVh0Q8B407EeM@1>CTh0IFEU04A4A01GEeL0VIVI06e]K@0204e=C@1M09RHV01N
GUh0HV9R05YJFP0h>3P0OGem0:6QX@1?Cdl0FEUI04e=C@0e=CD0EUIF07MgM`1eMGD0IFEU06][J`1K
Fe/0H61P069RHP0a<C40C4a<06=SH`19BDT0GemO09NGU`1NGUh0I6AT02l_;`0f=SH0RXZ:07]kN`1:
BTX0ZJVY08>3P`1XJ6P0d];B08Z:RP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF507AdM02?
Shl0EEEE0;:b/P1oOgl0@D5104U9B@1?Cdl0;bl_05IFEP1=CDd0Shn?059BDP0b<S80IFEU07emO@0k
>c/0VYZJ061PH00l?3`0Ng]k061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0K6a/07AdM01I
FET0FUYJ05QHF02BTY80Fe]K07MgM`1VIVH0Y:BT03/k>`22PX80De=C06MWI`15ADD0=CDe04];B`1g
MgL0JFUY0080A4A403h0DU9B04=3@`0U9BD0;2`/05aLG01aLG40DE5A04Q8B015ADD0G5aL08:2PP1L
G5`0EEEE07MgM`0g=cL0@d=306i^KP1iNGT0GUiN05ADE027QhL0AdM7051@D01NGUh0IVIV034a<@1J
FUX0R8R806UYJ@1CDe<0Rh^;04I6AP0g=cL0Shn?06i^KP0m?Cd0De=C08:2PP0/;2`0XZ:R09:BTP1@
D500L71`08>3P`1>CTh0@T9208V9R@1JFUX0YZJV05IFEP14A4@0:2PX07alO01hN7P0>CTi05UIF@1Y
JFT0EEEE024Q8@0_;bl0Ti>C08:2PQcooooo02@0=CDe02XZ:P0Y:BT09BDU09FEU@3=cLd0`<30055A
D@15ADD0JVYZ07YjNP27QhL0d=3@0=CDe02TY:@0L71`08F5Q@2QXJ40`l?30;Rh^030`<00`L710<30
`02e]KD0YjNW08:2PP1/K6`0^KVi06i^KP0j>SX0820P01`L700H61P05aLG01hN7P0M7Ad201`L700L
01/K6`0I6AT06ATI01TI6@0];Bd0M7Ad04];B`36a/H0^;Rh08Z:RP1LG5`0Fe]K075aL@1`L700`/;2
0;Fe]@20P800Ti>C0:>SX`2`/;00bl_;092@T00R8R808b<S038b<P12@T80;Rh^01dM7@807QhN01P0
6a/K01lO7`0Q8B40IFEU0=?Cd`2UYJD0d];B0;Zj^P2OWil0TI6A0:>SX`2b/[80Vi^K0:^[Z`27QhL0
QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0S8b<301DE5@0W01LG5`0];Bd0[jn_07IfMP1a
LG40XZ:R0;Rh^030`<00Kfm_01LG5`0[:b/0Kfm_0;:b/P2RXZ80UIFE06][J`0N7Qh071`L01TI6@0G
5aL071`L020P800];Bd0>SXj08>3P`2=SHd0NGUi0;>c/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`
L700F5QH0410@01=CDd0Cdm?0080I6AT03h0B4Q805=CD`2[Zj/0/K6a08J6QP1<C4`0LW9b08>3P`26
QXH0BTY:01TI6@0G5aL05ADE020P800O7al0:BTY03Ti>@1EEED0Bd];0:>SX`24Q8@0WIfM0:>SX`20
P800S8b<0:^[Z`26QXH0[jn_0<G5a@3?cll0MWIf05eMG@1lO7`0NGUi07=cL`22PX80a/K60;fm_@11
@D40GemO07IfMP0k>c/0?clo024Q8@0[:b/0=cLg08n?S`22PX80?Shn0410@01kNg/0Ph>305UIF@1A
DE40GemO08R8R03EeMD0Q8B404M7A`0X:2P092@T02`/;080PX:202`0[:b/0<O7a`3GemL0c/k>0;jn
_P2g]kL0QHF504M7A`1OGel0JVYZ051@D00/;2`0?Shn04];B`1ADE40NWYj0:BTY02;Rh/0Hf=S0:FU
Y@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00c/k>06UYJ@18B4P05QHF01DE5@0G5aL05ADE01LG
5`0E5AD05aLG01hN7P0f=SH0[jn_069RHP0P8200FEUI0:VYZ@80CTi>00H0E5AD03Xj>P11@D40Bd];
04I6AP0l?3`202`/;00P030`<00m?Cd0Bd];06e]K@1PH600L71`09fMW@36a/H0`L7109^KV`1nOWh0
KVi^06IVIP1nOWh0ZZZZ0:FUY@2OWil0TY:B0;2`/029RHT0>c/k03`l?00j>SX0M7Ad09FEU@1<C4`0
D51@09JFUP1cLg<0Cdm?038b<P1JFUX401`L717ooooo000?ooooo`0;061PH01TI6@0=cLg065QH@1<
C4`0FUYJ024Q8@0O7al0@d=305mOG`0a<C400P0c<c<0o`0=3@d0CTi>03Ph>01;Bd/07alO03Lg=`1K
Fe/0<c<c04E5A@0];Bd0=3@d07UiN@0X:2P0BDU905iNGP0<30`0=SHf07UiN@1ADE40>c/k03@d=01L
G5`0UiNG04Q8B00];Bd0ADE501DE5@0Z:RX0@T9204=3@`0H61P0FEUI06YZJP0f=SH0>CTi03Lg=`16
ATH0LG5a03Xj>P1eMGD0DE5A01dM7@0Z:RX0?clo04e=C@0/;2`0?clo07emO@0^;Rh0;bl_06MWI`18
B4P09BDU07alO01?Cdl05ADE03Hf=P1KFe/0=cLg06EUI@0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G
5aL0>CTi06][J`13@d<0OWin07AdM00j>SX0WIfM04U9B@0h>3P0C4a<05eMG@1[Jf/0IVIV0;Vi^@1K
Fe/0=SHf03/k>`0o?cl0Jf][08:2PP2SXj<0UiNG03Xj>P28R8P0De=C06MWI`0`<300HV9R05aLG01:
BTX0J6QX03Ph>019BDT0GemO051@D02<S8`0B4Q8034a<@1aLG40JFUY05IFEP0f=SH0?Shn04A4A01A
DE40AdM705QHF012@T80AdM707inOP1UIFD0EUIF03hn?P1nOWh0EUIF06=SH`1QHF40AdM705aLG02O
Wil0CTi>04M7A`1jNWX0BDU906UYJ@2:RXX0KVi^06EUI@1cLg<0Ph>308f=S@2ATI40>SXj04m?C`1L
G5`0LW9b0451@@2TY:@0GEeM07inOP1]KFd0FEUI09FEU@2;Rh/0Cdm?09nOW`2HV9P0MgMg0:f][@28
R8P0U9BD0;6a/@2RXZ80XJ6Q0451@@1MGEd0WinO0820P01`L700WinO05MGE`2ATI40DE5A03Lg=`14
A4@0L71`03De=@0a<C40B4Q8079bLP0k>c/0CDe=0492@P1oOgl0>SXj08j>SP2@T900L71`0:b/[01/
K6`0De=C0;Rh^01KFe/0M7Ad07]kN`10@400I6AT07alO021PH40Hf=S06a/K01EEED0X:2P06ATI01c
Lg<0Fe]K0:6QX@0k>c/0Ng]k06ATI01RHV80AdM703dm?@1BDU80OGem06IVIP0h>3P0A4A4065QH@1:
BTX0:b/[03De=@1VIVH0QXJ605MGE`17AdL0CDe=065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin061PH01eMGD0Ph>304E5A@1EEED0IFEU03Ti>@0T92@0>3Ph06YZJP1EEED0Kfm_09RHV01f
MWH0?3`l0:BTY01GEeL0<S8b05QHF01aLG4071`L075aL@005P1FEUH0?Shn08>3P`2>SXh0FUYJ03Xj
>P28R8P0Bd];0;Fe]@2?Shl0Hf=S02`/;021PH40NGUi03<c<`0M7Ad0:b/[05iNGP0_;bl05QHF07]k
N`1NGUhLooooo`0C0451@@18B4P0GemO06IVIP1oOgl0dM7A0;jn_P2UYJD0Hf=S05YJFP23Ph<0O7al
0;bl_03>c/h0[:b/08B4Q02HV9P0U9BD07moO`0207UiN@0:05UIF@1VIVH0/;2`08Z:RP13@d<0=3@d
079bLP10@400Fe]K02d];@807QhN01H06QXJ03dm?@18B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0
^;Rh06m_K`2YZJT0gMgM0=?Cd`2;Rh/0AdM703Ph>01?Cdl0NWYj0;:b/P0j>SX0=CDe0P0/;2`0=00b
<S80@d=308b<S01FEUH08b<S034a<@0o?cl0C4a<03Ti>@0e=CD0B4Q804=3@`1QHF40Vi^K0:ZZZP2k
^k/0W9bL07IfMP20P800Shn?0:ZZZP2[Zj/0b<S80<;2`P1nOWh0I6AT05UIF@0n?Sh0?Cdm0410@013
@d<0Ng]k08V9R@1ADE409RHV01<C4`0D51@05ADE01HF5P1BDU80@T9202DU9@0T92@0B4Q806][J`1N
GUh0M7Ad01LG5`0I6AT0Cdm?09fMW@3IfMT20;Jf]P0m05]KF`1<C4`0A4A404A4A017AdL0CTi>05AD
E01FEUH0Hf=S05eMG@2[Zj/0MGEe06m_K`2TY:@0Cdm?01/K6`0I6AT071`L04Q8B01UIFD0OWin05UI
F@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@25QHD0NGUi05IFEP1eMGD0Cdm?03Ti>@15ADD0BDU902h^
;P0F5QH06a/K05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@0NGUi07YjNP24Q8@0MgMg079b
LP2k^k/0^KVi0<c<c037alL0L71`0451@@17AdL0Hf=S08N7Q`020<S8b00b08^;R`1RHV80;2`/030`
<011@D406a/K02DU9@1fMWH0Ph>305QHF012@T80ADE507EeM@22PX80LG5a03Ph>00k>c/0>CTi0;:b
/P2l_;`0Shn?06a/K00n?Sh0;2`/08J6QP1NGUh0S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>305IF
EP1:BTX0C4a<05]KF`1YJFT0F5QH06e]K@2>SXh0X:2P065QH@14A4@0P8200=WIf@3AdM40WYjN0;Bd
]03Ph>020<_;b`070:2PX02a/K40[:b/096AT@1@D5009BDU01LG5`0201DE5@0B01HF5P0f=SH0Vi^K
0=?Cd`2RXZ809BDU03Hf=P1^KVh0Ph>305IFEP1HF5P0E5AD03<c<`0b<S80:2PX02XZ:P0`<300=CDe
0P0l?3`08`0U9BD0?clo06YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00/K6a0:JVYP2e]KD0
T92@06EUI@1aLG40[Jf]0861P@1^KVh0G5aL04];B`1:BTX0VYZJ08R8R01NGUh0Kfm_055AD@1QHF40
>c/k03Hf=P1CDe<0820P01/K6`0L71`07AdM017ooooo000?ooooo`0P05=CD`1iNGT0@D5106a/K01E
EED0QhN7059BDP13@d<0KVi^07]kN`0j>SX0;Rh^05UIF@0h>3P0=SHf034a<@1=CDd07AdM01@D5019
BDT09bLW0451@@0/;2`07QhN05UIF@0Q8B40>SXj06UYJ@0h>3P09BDU05=CD`0o?cl204=3@`3o02d]
;@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A03dm?@1KFe/0@D5101`L700n?Sh0DU9B04i>
CP1IFET08B4Q05ADE01IFET0@D510492@P1LG5`0<C4a01PH600Y:BT0DE5A05UIF@11@D40C4a<01PH
600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0@d=304I6AP10@400Bd];024Q8@1?Cdl0FEUI02PX
:01:BTX0JVYZ02PX:01<C4`0M7Ad03/k>`2OWil0IFEU04e=C@1JFUX0DU9B06e]K@22PX80[Jf]08N7
Q`1WIfL0C4a<04I6AP26QXH0UiNG0<_;b`2XZ:P0@D5108Z:RP1KFe/0J6QX061PH02;Rh/0IfMW04e=
C@1MGEd0K6a/05EEE@1fMWH0J6QX096AT@24Q8@0BDU90820P01iNGT0EEEE06=SH`1CDe<0CTi>06IV
IP18B4P0Cdm?04Y:BP1=CDd0MGEe06QXJ01BDU80?clo09>CT`15ADD0GemO06i^KP1GEeL0IFEU0;2`
/01BDU80@41007inOP1<C4`0H61P08Z:RP1aLG40Ph>307IfMP1iNGT0Xj>S09VIV@15ADD0BTY:07Ee
M@24Q8@0DU9B0:j^[P1YJFT0Ogmo071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0UIFE07al
O01LG5`0QXJ609VIV@2:RXX0?clo05IFEP2DU9@0@41007UiN@2GUiL0FEUI09fMW@1NGUh0@d=30410
@01hN7P0>SXj03Lg=`19BDT0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0RHV906=SH`1:BTX0UIFE05AD
E01[Jf/0^k^k059BDP1dM7@0N7Qh034a<@1YJFT0W9bL0820P01HF5P0NGUi05eMG@2DU9@0>SXj06YZ
JP1bLW80XZ:R0492@P24Q8@0G5aL07AdM01_Kfl0BDU905=CD`1jNWX0KVi^04Q8B01:BTX0LW9b06=S
H`0];Bd0=CDe06MWI`24Q8@0I6AT06UYJ@1>CTh0IVIV0:RXZ01bLW80FUYJ0;2`/01BDU80AdM709bL
W025QHD0>SXj04];B`1LG5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204M7A`1EEED0RHV907Ad
M016ATH0[Zj^07alO00^;Rh0>3Ph06][J`0[:b/0W9bL075aL@0K6a/0GemO0861P@1QHF40?Shn092@
T00m?Cd0OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/0J6QX04=3@`1<C4`0Rh^;0040
PX:27?ooool0<@1hN7P0JVYZ05IFEP16ATH0?Cdm06i^KP2YZJT0dm?C0<o?c`2a/K40WinO06a/K02f
][H0T92@07UiN@13@d<0@T9203dm?@14A4@0Hf=S08>3P`1TI6@0<c<c02/[:`1<C4`09RHV0410@01E
EED0L71`07=cL`1jNWX0IfMW059BDP1QHF40IVIV04m?C`14A4@0>CTi034a<@0];Bd08b<S020P801?
Cdl0U9BD0<O7a`1gMgL0YZJV06EUI@1;Bd/00P0`<300;`1GEeL0M7Ad01dM7@0F5QH06ATI01/K6`0O
7al07AdM02h^;P1/K6`0G5aL04M7A`1EEED0Ogmo06MWI`19BDT0E5AD08V9R@2GUiL0L71`05IFEP1U
IFD0_Kfm08F5Q@1fMWH0L71`04i>CP1=CDd0ZZZZ0<71`@2OWil0?Cdm04e=C@0S8b<07AdM01hN7P0]
;Bd0ADE5071`L01VIVH0@d=301lO7`0E5AD061PH0492@P11@D408B4Q00<07AdM0140CDe=0451@@1d
M7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80Ogmo0:VYZ@1_Kfl0IFEU075aL@1ZJVX0HV9R07EeM@02
06UYJ@040:f][@2EUID0J6QX07alO080TI6A01T0EEEE02HV9P0O7al07QhN065QH@2PX:00[jn_0:>S
X`2GUiL0OGem08^;R`2LW9`0XZ:R07YjNP0k>c/0=SHf06ATI01DE5@0:b/[024Q8@0];Bd0@41003dm
?@0`<300K6a/0080H61P0640Bd];05mOG`2LW9`0[Jf]08j>SP1jNWX0KVi^02h^;P0S8b<0;bl_06a/
K01TI6@0MGEe09BDU00a<C406ATI02l_;`13@d<0C4a<08j>SP2d];@0[jn_03dm?@0V9RH0;Bd]04Y:
BP0/;2`0EUIF07IfMP15ADD0:RXZ02DU9@0Y:BT0<S8b06=SH`1`L700?clo02XZ:P0f=SH0Kfm_069R
HP2SXj<0][Jf0:f][@2YZJT0XZ:R09FEU@2g]kL0alO707alO01SHf<0QHF507IfMP24Q8@0UYJF0:j^
[P2PX:00VYZJ09JFUP2^[Zh0cLg=0=;BdP1<C4`0820P03@d=02i^KT0/;2`09NGU`2`/;00][Jf0=WI
f@3Hf=P0[:b/09:BTP1UIFD0];Bd07]kN`2LW9`0V9RH08b<S011@D40:RXZ03Lg=`26QXH0<30`06IV
IP1]KFd071`L04A4A01_Kfl0MgMg06UYJ@1^KVh0GEeM03Ti>@0o?cl0>CTi0080:2PX02H09bLW020P
800U9BD07alO03Lg=`1_Kfl0Ng]k0::RXP33`l<0^KVi0;:b/P23Ph<0W9bL0::RXP3;bl/0^k^k05YJ
FP1EEED0[Zj^06UYJ@15ADD0Hf=S08N7Q`2`/;00b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3
@`12@T80DU9B02`/;00H61P06ATI01dM7A7ooooo000?ooooo`1J06m_K`20P800BTY:05YJFP1:BTX0
GemO059BDP1OGel0EeMG06e]K@0h>3P0=cLg06=SH`1DE5@0<C4a02@T901HF5P0=3@d01PH600^;Rh0
5ADE030`<017AdL09RHV03lo?`0O7al0;2`/05EEE@18B4P09RHV03dm?@0U9BD0;2`/04A4A00c<c<0
KVi^03lo?`0P8200?clo065QH@0i>CT0:b/[03dm?@1DE5@0GUiN04];B`0b<S80:RXZ04i>CP10@400
MWIf0451@@1`L700LW9b04i>CP13@d<0GemO06=SH`10@400;2`/05IFEP1cLg<0E5AD04a<C012@T80
7AdM05]KF`1@D500820P02l_;`18B4P0;2`/051@D00o?cl0AdM705UIF@0^;Rh0EeMG059BDP0S8b<0
@41006=SH`13@d<0EEEE05mOG`0d=3@0QhN7079bLP1FEUH0Hf=S0P1TI6@00`1FEUH0Xj>S07IfMP02
05MGE`3104U9B@1[Jf/0J6QX0:JVYP2QXJ40AdM708>3P`1EEED0M7Ad05eMG@21PH40Hf=S05ADE01i
NGT0Kfm_059BDP1OGel0?Shn08^;R`25QHD0BTY:07alO01SHf<0CTi>065QH@1>CTh0DU9B05EEE@0l
?3`0EUIF04a<C01CDe<0Ti>C065QH@1LG5`0@d=309JFUP16ATH0IFEU07QhN01OGel0IFEU0;Zj^P1@
D500Bd];07YjNP13@d<0HV9R0820P01DE5@0QHF50820P01`L700cLg=08R8R015ADD0FUYJ0820P01/
K6`0DU9B09jNWP1GEeL0Ph>3071`L01^KVh0VYZJ05mOG`19BDT0S8b<061PH016ATH0LG5a08f=S@1K
Fe/0M7Ad06IVIP1>CTh0ADE506=SH`2>SXh0Jf][07QhN01`L700CDe=096AT@1KFe/0;bl_03Hf=P1U
IFD0=cLg03/k>`17AdL0KFe]05eMG@1;Bd/0>c/k05]KF`0_;bl0OWin05mOG`0o?cl0Vi^K03lo?`17
AdL0WYjN04A4A01ZJVX0IfMW02`/;015ADD0JFUY04Y:BP0n?Sh0Ng]k079bLP23Ph<0@d=306QXJ01D
E5@0WIfM03@d=020P800A4A404=3@`1DE5@0:b/[05EEE@1gMgL0Cdm?03/k>`1>CTh0MGEe03Xj>P0b
<S80ADE506MWI`1LG5`0B4Q804i>CP1<C4`0G5aL09RHV01ZJVX0ADE509>CT`1SHf<0?Shn0861P@1`
L700Hf=S06a/K01kNg/0>3Ph04Q8B01KFe/0CDe=034a<@14A4@0Ph>306YZJP1XJ6P0Lg=c06EUI@0n
?Sh0SXj>07]kN`0^;Rh0Bd];07UiN@0f=SH0S8b<07alO01KFe/0JVYZ07AdM01VIVH0@D5108J6QP1B
DU80S8b<08J6QP1DE5@0;bl_07alO01[Jf/0@T9202d];@0m?Cd0GEeM03Lg=`0U9BD0PX:20861P@0L
ooooo`0S04];B`18B4P0?clo02DU9@0M7Ad071`L03Xj>P1_Kfl0ZJVY08V9R@1lO7`0T92@08V9R@1=
CDd0<30`02PX:00S8b<08B4Q028R8P11@D40QXJ608R8R00M7Ad04a<C01TI6@0i>CT0ADE506=SH`2a
/K40TY:B092@T02;Rh/0K6a/04U9B@0o?cl00P16ATH05@10@400@T92061PH01ZJVX0W9bL0;Ng]`3L
g=`0/;2`03/k>`0`<300TY:B05UIF@0`<300:BTY03<c<`1BDU806ATI01HF5P0C4a<051@D01DE5@02
01XJ6P1l01lO7`0i>CT0Ph>307inOP1kNg/0M7Ad09jNWP29RHT0E5AD03hn?P0d=3@0:RXZ02DU9@0]
;Bd0Bd];06e]K@1NGUh0@41002l_;`1^KVh0NGUi06YZJP0m?Cd0<S8b02h^;P0Q8B4092@T020P800U
9BD0@T9206IVIP1JFUX0HF5Q0492@P0e=CD0:RXZ028R8P0K6a/0820P028R8P0S8b<0AdM704];B`0g
=cL0Rh^;05MGE`0a<C40=SHf0:^[Z`3Bd]80`l?30<o?c`20P800MWIf07AdM01eMGD0M7Ad07moO`2J
VYX0];Bd09FEU@1BDU80EEEE0451@@0R8R80=cLg08B4Q02>SXh0?3`l0451@@1QHF40`<300:>SX`1o
Ogl0N7Qh06IVIP1@D500Bd];05UIF@0l?3`05aLG01PH600[:b/0ATI604A4A00_;bl09BDU030`<010
@400IVIV04a<C00c<c<0:b/[03Hf=P1RHV80_[jn0<_;b`2=SHd0SXj>07IfMP1=CDd08R8R01`L700M
7Ad0;Bd]03De=@1IFET0TY:B03dm?@0/;2`0<c<c05]KF`2TY:@0]KFe0861P@1HF5P0<S8b02PX:010
@400Z:RX079bLP0n?Sh08B4Q02<S8`<0820P00@0;Rh^059BDP1^KVh0MGEe0P1=CDd0>@1eMGD0MWIf
09jNWP2UYJD0Z:RX0:f][@39bLT0a<C406e]K@1YJFT0DE5A069RHP1WIfL0:b/[01`L700Q8B40:RXZ
03<c<`16ATH0F5QH069RHP2SXj<0=SHf01HF5P1aLG40PX:208B4Q00];Bd0:RXZ051@D034a<@0dm?C
04=3@`0^;Rh0B4Q80:FUY@1;Bd/0<C4a03Hf=P1>CTh0N7Qh09RHV03<c<`0ATI601dM7@1IFET0De=C
03Lg=`1QHF40EeMG03/k>`2RXZ80Ogmo04A4A00d=3@09RHV028R8P0201lO7`<07QhN02<08R8R03`l
?01`L700WYjN09nOW`1dM7@0UYJF0<30`02/[:`0OWin08j>SP2WYjL0_Kfm09NGU`2l_;`0UiNG02l_
;`0c<c<0>c/k06e]K@1lO7`0GEeM09VIV@1UIFD0?clo020P800O7al09RHV05mOG`22PX80QhN708b<
S01NGUh0G5aL061PH00Aooooo`003oooool0^`20P800PH6105EEE@1DE5@0G5aL06YZJP1TI6@0MgMg
075aL@2QXJ40IfMW04Y:BP1PH600JFUY03De=@0Z:RX0F5QH03lo?`0I6AT0>c/k03Ti>@11@D40CTi>
020P801DE5@0?Cdm030`<01<C4`0CDe=02TY:@1LG5`0CTi>030`<00o?cl0=3@d08j>SP1cLg<0:2PX
03dm?@1]KFd0=3@d03hn?P0i>CT0GEeM065QH@2EUID0?Shn03De=@1IFET0A4A409ZJVP14A4@0Ogmo
079bLP0o?cl0D51@06m_K`1^KVh0DU9B02TY:@1BDU80D51@04i>CP2BTY80FUYJ01lO7`1DE5@0F5QH
02<S8`18B4P0IfMW038b<P18B4P0=cLg059BDP1RHV80=3@d04I6AP1<C4`09RHV04A4A01WIfL0A4A4
06][J`1lO7`0=3@d08j>SP20P800>SXj07EeM@2BTY80Ng]k06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a
07IfMP1LG5`0cLg=0;Bd]019BDT0UYJF05MGE`1ZJVX0@41005EEE@1ZJVX0ATI605MGE`1EEED0LW9b
08V9R@1TI6@0Rh^;07EeM@17AdL0Rh^;08B4Q01:BTX0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q8
03hn?P2@T900IVIV05UIF@0l?3`0Ph>307EeM@1aLG40FUYJ038b<P1;Bd/0Xj>S065QH@0l?3`0MGEe
04Q8B01>CTh0RXZ:0410@01bLW80M7Ad05eMG@3?cll0QXJ605MGE`0m?Cd0Jf][07YjNP1GEeL0SXj>
05UIF@1hN7P0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0UiNG04Q8B020P800QhN7
08V9R@19BDT0De=C09VIV@26QXH0X:2P0:RXZ013@d<0N7Qh06m_K`15ADD0>c/k05IFEP0e=CD00P1Y
JFT0I@1`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2`/;00NGUi05=CD`31`L40De=C
06e]K@1nOWh0Cdm?04Y:BP2<S8`0M7Ad04e=C@1VIVH0GemO08J6QP16ATH0QhN7065QH@2^[Zh0=3@d
05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU05]KF`1]KFd0@T9202LW9`0c<c<0EEEE
06MWI`1BDU80Q8B405QHF016ATH0M7Ad04a<C00k>c/0T92@0861P@1<C4`0NGUi079bLP1oOgl0De=C
08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1PH600;Bd]04E5A@1MGEd0Lg=c04a<C029RHT0DU9B
01TI6@0`<300Kfm_03Ph>02FUYH0EeMG04m?C`26QXH0[:b/096AT@19BDT0VYZJ05]KF`1nOWh0Rh^;
06MWI`0f=SH0QHF505eMG@0_;bl05QHF020P801UIFD0=CDe02d];@2>SXh0IFEU01cooooo02@0=SHf
03Ph>00[:b/07AdM01lO7`0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P800C4a<04A4A
010@400>3Ph0410@01<C4`0B4Q80H61P08F5Q@0P82004Q8B010@400];Bd0V9RH09VIV@2n_[h0UYJF
0:RXZ02TY:@0Bd];02/[:`0P820201/K6`0M02TY:@0k>c/0;Rh^08R8R01_Kfl0SXj>0;>c/`30`<00
MgMg0:FUY@2CTi<0E5AD02`/;00k>c/0Fe]K01HF5P0I6AT03Ph>010@400C4a<05ADE01dM7@0J6QX0
7AdM05UIF@1PH600I6AT09NGU`1^KVh00P18B4P06P0e=CD09RHV01/K6`0F5QH05ADE01LG5`0W9bL0
CDe=04a<C00b<S80JFUY06a/K00i>CT0Bd];06ATI01BDU8071`L01TI6@0M7Ad09BDU02XZ:P15ADD0
FEUI07emO@1MGEd0=cLg0`0M7Ad0200N7Qh09RHV02h^;P0l?3`0FEUI0410@01ZJVX0<C4a0P0M7Ad0
8@1HF5P0J6QX06e]K@30`<00Ogmo06a/K01EEED0Bd];04E5A@1?Cdl0GEeM04];B`2ZZZX0;bl_01DE
5@0G5aL092@T02XZ:P0j>SX0Ogmo0492@P0c<c<0C4a<04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q
8@0X:2P0BDU901TI6@0301DE5@0301`L700a<C40:BTY0080:BTY06h0Kfm_05ADE01VIVH0Ogmo09bL
W03;bl/0i>CT0<c<c01nOWh0Bd];02TY:@0k>c/0Ogmo03<c<`0F5QH0;bl_02LW9`0[:b/0NGUi0:j^
[P1`L700WIfM0;:b/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@1FEUH0/[:b05UIF@0R8R807alO020P
800R8R80:BTY01/K6`0F5QH0BDU904Q8B026QXH0Y:BT04=3@`0h>3P0De=C03`l?00`<300@4100:VY
Z@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k01/K6`0M7Ad06a/K01dM7@0I6AT07QhN01lO
7`0a<C40Ph>308J6QP2SXj<0^;Rh06][J`0O7al07AdM02HV9P2QXJ40c/k>07alO00j>SX0HV9R0<o?
c`1aLG408b<S02XZ:P0/;2`08B4Q02LW9`1FEUH0M7Ad01lO7`2BTY80=CDe05MGE`1<C4`0:2PX08:2
PP2l_;`0bl_;05YJFP0J6QX07QhN024Q8@0S8b<07QhN01dM7@0N7Qh071`L02h^;P1fMWH0ZJVY096A
T@80V9RH01d0F5QH05=CD`2/[:`0PX:20492@P2=SHd0gMgM0=SHf032`/80a<C408J6QP10@400<C4a
06=SH`0a<C40CTi>08>3P`0R8R80ADE505]KF`0/;2`0>3Ph06i^KP25QHD0Z:RX08>3P`1cLg<0M7Ad
07moO`0Aooooo`003oooool01P1XJ6P0NWYj03lo?`17AdL0Bd];06ATI080>CTi01P0BTY:075aL@1>
CTh0?clo05aLG00i>CT0A4A402HV9P1:BTX0:2PX01lO7`1<C4`0=cLg04A4A01IFET07alO05]KF`0f
=SH0ADE506a/K00f=SH06a/K04M7A`0l?3`2038b<P3N01lO7`1JFUX0EUIF02XZ:P15ADD0ATI601lO
7`0h>3P0=CDe02d];@0h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q01aLG40>CTi03<c
<`12@T80E5AD03/k>`0i>CT0JFUY06MWI`1=CDd0De=C04E5A@0S8b<0LG5a06i^KP0X:2P0:b/[04i>
CP0g=cL0FUYJ04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^03Lg=`1DE5@0M7Ad03Ti
>@2:RXX0XJ6Q04A4A01JFUX0G5aL06][J`1]KFd0eMGE08F5Q@1SHf<0?clo03Ti>@20P800Vi^K0;no
_`2h^;P0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0HF5Q055AD@1UIFD0EeMG08^;
R`28R8P0?clo07QhN025QHD0CTi>06i^KP14A4@0AdM7071`L01NGUh0D51@06=SH`15ADD0Shn?06AT
I024Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI60;fm_@1NGUh0B4Q806MWI`0g=cL0ATI607in
OP14A4@0WinO08F5Q@18B4P0alO707moO`1MGEd0IFEU08R8R02FUYH0FEUI0820P01;Bd/0Q8B407Mg
M`1IFET0[Zj^08F5Q@1SHf<0][Jf09VIV@1eMGD0?Shn09>CT`1>CTh0L71`08n?S`28R8P0BTY:06AT
I02NWYh0A4A4075aL@1kNg/0BTY:08n?S`21PH40CDe=05IFEP1YJFT0=3@d038b<P19BDT0Lg=c06e]
K@0`<300I6AT065QH@11@D40PH6106i^KP0X:2P0MGEe03/k>`19BDT0WinO051@D01>CTh0L71`03Xj
>P1PH600R8R808f=S@1UIFD0L71`06YZJP2=SHd0@T9207]kN`1iNGT0XZ:R04U9B@1RHV80Bd];0451
@@1JFUX0BTY:04a<C01IFET0LG5a05aLG00j>SX0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A404a<
C01EEED0@D5107EeM@1dM7@0EEEE09VIV@1:BTX0<30`08b<S01gMgL0OWin05MGE`1]KFd0820P04A4
A01UIFD0DE5A02l_;`0/;2`0EEEE0P1PH6005`12@T80LW9b05QHF01iNGT0FUYJ03<c<`0^;Rh0Lg=c
03`l?02>SXh0EUIF03dm?@1HF5P0OWin079bLP10@400Ti>C04=3@`1WIfL0JFUY04I6AP0k>c/0Q8B4
0080BDU900L06ATI02HV9P1fMWH0@d=302TY:@2@T900RHV901cooooo01<0=3@d03Hf=P0[:b/092@T
02XZ:P0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80De=C01DE5@0C4a<03@d=01<C4`0@41004A4A
0080410@00l05aLG09JFUP1aLG4051@D010@400O7al0Q8B40820P02_[jl0EeMG061PH01;Bd/05ADE
01<C4`0D51@00P0E5AD0400G5aL05QHF01LG5`0N7Qh0=CDe05=CD`1DE5@0T92@0<k>cP3QhN40aLG5
06IVIP1=CDd0BDU907alO00H61P200h>3P07014A4@0C4a<05ADE01LG5`0J6QX0<c<c06IVIP020::R
XP06092@T01HF5P0@D510410@00Q8B405QHF100E5AD0900R8R80<30`03Hf=P1ADE40IVIV069RHP0n
?Sh0=3@d06EUI@2UYJD0CDe=03Lg=`0e=CD0?clo05UIF@1SHf<0Shn?0:6QX@1fMWH0H61P04a<C00l
?3`0=3@d03Ti>@0f=SH0ADE506ATI01PH600B4Q806YZJP0_;bl071`L0492@P17AdL09RHV03@d=080
VYZJ01`0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:^[Z`13@d<051@D01<C4`0G5aL0=CDe04I6
AP1TI6@0_kno0:n_[`1cLg<0HF5Q03Lg=`0K6a/071`L024Q8@0L71`05aLG01TI6@13@d<09BDU0P0G
5aL0@@0E5AD071`L03De=@0o?cl0D51@06=SH`2LW9`0WIfM09RHV01nOWh0Zj^[0;2`/02EUID0ZZZZ
06i^KP0T92@07AdM01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^KVh0>CTi01DE5@0Q8B40Jf][
0:2PX03:b/X0iNGU0>3Ph02j^[X0YZJV0;Jf]P1oOgl0Zj^[079bLP1oOgl0Lg=c06MWI`1PH6007alO
01LG5`0];Bd0AdM708^;R`1OGel0>CTi01dM7@0n?Sh0AdM702/[:`0Y:BT0Jf][0<o?c`2<S8`0KFe]
04Q8B012@T80LG5a08n?S`1LG5`071`L00807alO100L71`08`0V9RH0F5QH0<G5a@1_Kfl0e=CD08Z:
RP0S8b<06a/K04Q8B02IVIT0@d=304M7A`1YJFT0Fe]K055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf
=P0e=CD0S8b<09RHV02h^;P0C4a<04];B`1IFET0U9BD07UiN@22PX80^k^k09NGU`1ZJVX0<30`0080
71`L00X09bLW01hN7P0O7al0=CDe07UiN@2@T900Vi^K09VIV@1jNWX0ADE50P0c<c<06`1CDe<0RHV9
05UIF@2m_Kd0bLW908^;R`1bLW80OGem0;2`/02^[Zh0R8R807inOP0o?cl0QXJ60:BTY00/;2`08B4Q
061PH02HV9P0QHF504Y:BP1MGEd0Q8B403@d=00/;2`0<c<c04M7A`0Aooooo`003oooool0F01XJ6P0
IFEU05eMG@17AdL0CTi>05MGE`1QHF40F5QH05eMG@2?Shl0FEUI04E5A@25QHD0GUiN02PX:00U9BD0
FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P8013@d<06ATI02HV9P17AdL0D51@020P800e=CD0
6ATI02DU9@1BDU8071`L05YJFP12@T808R8R04M7A`1ZJVX0>c/k02@T900i>CT0EeMG03`l?01RHV80
:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06YZJP1BDU80EUIF06i^KP1YJFT0>SXj02@T9015ADD0
L71`05MGE`1SHf<0?Cdm01LG5`0o?cl0FUYJ02@T900^;Rh0CDe=020P8012@T80Fe]K05=CD`1?Cdl0
820P03hn?P1KFe/0=3@d03dm?@1CDe<0?clo06MWI`22PX80ATI608Z:RP2f][H206][J`0X06YZJP1<
C4`0EEEE0:ZZZP24Q8@0Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0[jn_04=3@`1oOgl0M7Ad08B4Q01c
Lg<0Bd];08:2PP1@D500Hf=S07EeM@1LG5`0KFe]0820P027QhL0WinO04Y:BP1iNGT0Ng]k05=CD`1[
Jf/0ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP80J6QX09h0@T920861P@0i>CT0F5QH06m_
K`1JFUX0ATI60;jn_P14A4@0?Shn06e]K@0f=SH0Bd];0820P00h>3P0LW9b0861P@11@D40/K6a08B4
Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0Xj>S07QhN01CDe<0Xj>S05MGE`18B4P0Q8B406e]
K@15ADD0@41009^KV`1DE5@0QhN70:VYZ@1/K6`0@D5107inOP2NWYh0PX:209^KV`1eMGD0<c<c08Z:
RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1=CDd0Q8B4079bLP10@400G5aL03hn?P0Z:RX0Cdm?055A
D@0W9bL0W9bL05UIF@0m?Cd0TI6A0451@@1FEUH0K6a/030`<010@400IVIV075aL@1QHF40Fe]K06e]
K@25QHD0Hf=S07]kN`1LG5`0WYjN04m?C`1EEED0EeMG04Y:BP1YJFT0GemO0451@@1?Cdl0LG5a06][
J`0n?Sh0WYjN06IVIP0[:b/0=CDe04a<C029RHT0Hf=S061PH01gMgL0BTY:0;6a/@2MWId0Jf][09JF
UP1DE5@0=3@d08>3P`1mOGd0LW9b05YJFP29RHT0Fe]K0451@@1LG5`0C4a<03<c<`0V9RH0GEeM07em
O@1iNGT0De=C08B4Q01JFUX0SXj>08R8R00l?3`0=3@d06UYJ@0e=CD0U9BD05IFEP1NGUh0K6a/092@
T01eMGD0?Cdm08B4Q011@D40IfMW07QhN01TI6@0F5QH0;:b/P1VIVH0ATI601HF5P0T92@0G5aL034a
<@1>CTh0WYjN092@T1cooooo0180<30`03Lg=`0`<3009BDU04E5A@0j>SX09RHV01dM7@19BDT0W9bL
06UYJ@2i^KT0RHV902/[:`0B4Q803Ph>01<C4`0@4102014A4@0T00h>3P0A4A40:b/[0:6QX@0_;bl0
4A4A02DU9@1YJFT0S8b<08B4Q01hN7P0>c/k03lo?`0B4Q80410@01DE5@0B4Q8051@D01DE5@0C4a<0
410@01LG5`0Y:BT0C4a<06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32`/80_;bl03dm?@0G5aL0
3Ph>0P0D51@02`0A4A404a<C03@d=01CDe<0I6AT07=cL`2?Shl0Kfm_04Y:BP1;Bd/092@T00L05ADE
08D09BDU02<S8`0c<c<0Fe]K06UYJ@10@400?3`l03lo?`2?Shl0OWin04U9B@16ATH0De=C07MgM`2A
TI40][Jf0<S8b02KVi/0IVIV03/k>`19BDT0FEUI06IVIP1dM7@0QHF509bLW01hN7P0AdM706YZJP0/
;2`0?Shn06MWI`12@T8092@T02XZ:P1fMWH08b<S02d];@0Y:BT092@T03dm?@1UIFD0@T9201XJ6P1W
IfL0PH6102LW9`0C4a<051@D065QH@1nOWh0[jn_0<30`01UIFD0I6AT0:f][@1YJFT06a/K028R8P0d
=3@09RHV02TY:@0K6a/0;2`/05=CD`0L71`05QHF01DE5@0H61P0=SHf051@D01mOGd0QXJ609^KV`1k
Ng/0Shn?0:FUY@1jNWX0D51@07MgM`2_[jl0S8b<02l_;`0I6AT071`L01HF5P0K6a/061PH02TY:@0/
;2`0:b/[071`L00L71`05ADE01LG5`0R8R80KVi^05eMG@2PX:00Ph>304e=C@12@T80EUIF059BDP2Z
ZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh07alO02DU9@19BDT0W9bL04e=C@13@d<07AdM03Ti>@1S
Hf<0?Cdm0451@@1QHF40alO70:6QX@0o?cl0>c/k03<c<`13@d<0GUiN08^;R`0f=SH061PH0080820P
04l08b<S01dM7@0S8b<0<S8b05]KF`2XZ:P0LW9b06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>
CTh0KFe]05MGE`0];Bd0<c<c04I6AP1GEeL0@D5102HV9P0e=CD0ADE507moO`3QhN40h>3P0=CDe02b
/[80RXZ:05]KF`1;Bd/0TY:B09>CT`17AdL0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02A
TI40XZ:R07EeM@1nOWh0>c/k028R8P0c<c<0FEUI02TY:@0T92@0XJ6Q0:2PX01WIfL0EUIF065QH@15
ADD0JFUY08F5Q@2XZ:P0`/;20:BTY03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`1T
I6@08B4Q02/[:`1:BTX0L71`017ooooo000?ooooo`3o08Z:RP1bLW80LG5a04i>CP1YJFT0@41005IF
EP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;Rh^01`L701EEED0BDU901LG5`0/;2`07AdM02d]
;@1QHF407AdM0410@00M7Ad0:RXZ04U9B@1JFUX092@T03<c<`0^;Rh0:b/[04m?C`0I6AT0AdM706][
J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1WIfL0?Cdm08>3P`1;Bd/0<c<c05MGE`14A4@0N7Qh055A
D@1_Kfl0Fe]K03lo?`0f=SH0ATI6061PH01?Cdl08b<S04A4A01?Cdl0ADE5092@T01FEUH08b<S0451
@@1GEeL0:2PX05EEE@1eMGD0=3@d03lo?`19BDT0EEEE07=cL`1>CTh0<C4a06UYJ@0i>CT0B4Q805mO
G`1DE5@0JFUY05MGE`0_;bl0Kfm_09FEU@1CDe<0KFe]07AdM01hN7P0Hf=S0=7Ad@1ZJVX0>3Ph06i^
KP20P800V9RH04M7A`2DU9@0XZ:R03Xj>P1bLW80?clo07inOP1cLg<0BTY:06IVIP1@D500QXJ606e]
K@1HF5P0JFUY05MGE`1_Kfl0TY:B04Y:BP1fMWH0G5aL04];B`1MGEd0ADE506a/K01dM7@0>c/k04e=
C@1MGEd0AdM70:ZZZP1LG5`0@T9203Ti>@2:RXX0Kfm_05IFEP1BDU80B4Q8069RHP32`/80H61P03@d
=01`L700<C4a05YJFP2:RXX0@d=308>3P`1nOWh0A4A40:BTY02?Shl0KVi^03Lg=`1FEUH0MGEe04U9
B@29RHT0EUIF07=cL`1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2CTi<0IFEU08V9
R@2?Shl0NWYj04U9B@1RHV80Shn?07moO`2LW9`0LG5a03Lg=`2<S8`0EeMG030`<00k>c/0D51@03Xj
>P1fMWH0IFEU05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO0:b/[01RHV80=SHf08B4
Q012@T80Lg=c07IfMP0j>SX0?Cdm06YZJP1jNWX0CTi>06i^KP23Ph<0VIVI06ATI01oOgl0G5aL096A
T@18B4P0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo06MWI`1SHf<0?Cdm08V9R@0d=3@0<c<c05MG
E`1/K6`0Ng]k05=CD`1ADE40CTi>03Lg=`2VYZH0QhN705YJFP2@T900PX:206ATI01eMGD0N7Qh07Ui
N@1SHf<0Rh^;05UIF@17AdL0O7al079bLP13@d<0<C4a000S07IfMP1kNg/0Rh^;08f=S@1CDe<0>3Ph
08j>SP2:RXX0?Cdm03`l?01cLg<0>c/k0:BTY02`/;00IVIV06=SH`2>SXh0K6a/03Lg=`27QhL0I6AT
06QXJ02/[:`0IfMW0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05MGE`0f=SH09RHV07EeM@21PH407?oo
ool0400d=3@0Cdm?07=cL`12@T80>c/k02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q
01dM7@0A4A4201<C4`0c010@400>3Ph03`l?014A4@0C4a<0>SXj07AdM00D51@0@41006m_K`2l_;`0
HF5Q07UiN@0m?Cd0@41001@D500A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1QHF40
T92@08B4Q01bLW80OWin0=kNgP3Ti>@0d=3@0<C4a02KVi/0K6a/069RHP0j>SX0;Rh^01`L700F5QH0
5ADE0451@@2;Rh/0SXj>05YJFP2][Jd0TI6A05EEE@12@T805aLG00804a<C00<05ADE018B4P0C4a<0
0P0E5AD0E@0I6AT06a/K01`L701?Cdl0[Jf]065QH@1XJ6P0UIFE0;6a/@1dM7@0ATI604M7A`0n?Sh0
BTY:07=cL`2>SXh0ZJVY0;Zj^P2JVYX0ADE502/[:`0`<300=cLg0451@@12@T80ATI605eMG@2;Rh/0
]KFe0861P@1lO7`0D51@03Lg=`0[:b/0;bl_07alO00I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0
<C4a05mOG`1SHf<0QHF501lO7`0H61P0ADE5075aL@1^KVh0M7Ad0:NWY`1iNGT0BTY:06EUI@0f=SH0
@41004M7A`14A4@0:2PX034a<@0P8200IFEU01lO7`0J6QX07AdM03Lg=`1CDe<0EEEE061PH01ADE40
UYJF09bLW02:RXX0IVIV059BDP1<C4`0;Bd]04e=C@1GEeL0Kfm_01XJ6P0K6a/00P0L71`01P0G5aL0
71`L03@d=00d=3@0Lg=c01LG5`805ADE01007alO096AT@0n?Sh0?clo06e]K@19BDT0B4Q805YJFP1O
Gel0Ng]k03@d=00N7Qh061PH01XJ6P0K6a/06QXJ0P0N7Qh03P1OGel0PH6104=3@`13@d<0<S8b05]K
F`1XJ6P0?Cdm02/[:`1RHV80e]KF09fMW@14A4@0;Rh^0P0d=3@00`1;Bd/0RHV906YZJP0201TI6@0O
038b<P0f=SH0>CTi0492@P17AdL0I6AT09RHV026QXH09bLW02DU9@0b<S80LG5a08R8R02[Zj/0V9RH
0;>c/`1BDU80?3`l04Q8B00k>c/0>SXj04e=C@1;Bd/0DE5A03@d=00a<C40SHf=0>;RhP3Lg=`0TI6A
07IfMP020451@@0304e=C@2n_[h0ZZZZ0080:BTY00H0>c/k06IVIP2JVYX0[Zj^08R8R01aLG420;Ng
]`0R07QhN02IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM0:JVYP2DU9@0CTi>04m?C`1GEeL0
HF5Q03Ph>015ADD0LW9b07inOP3<c<`0PX:203De=@0g=cL0Cdm?06MWI`1eMGD0XZ:R0;>c/`33`l<0
HF5Q04A4A01RHV80GUiN07alO17ooooo000?ooooo`1^07UiN@1XJ6P0AdM703lo?`1DE5@0?Shn059B
DP0i>CT0ATI606a/K01?Cdl0;Rh^055AD@15ADD0E5AD02PX:01=CDd0@D5101dM7@11@D40:2PX024Q
8@1DE5@06QXJ04];B`0_;bl0;Bd]0451@@14A4@09bLW05IFEP0f=SH0:b/[03/k>`0K6a/0HF5Q07mo
O`0a<C406a/K06IVIP0];Bd0DU9B03Lg=`1EEED0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@
D01UIFD0K6a/06=SH`10@400C4a<07=cL`1:BTX07QhN0451@@1[Jf/0G5aL06EUI@1[Jf/09RHV0492
@P1XJ6P0=SHf02`/;01KFe/0Bd];0410@01@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007Ee
M@1<C4`0O7al06][J`0h>3P0OWin09fMW@0c<c<0GEeM06i^KP1RHV80JFUY0=SHf01/K6`0CTi>030`
<00h>3P0N7Qh051@D02m_Kd0Z:RX0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;Bd/205QHF00O
06EUI@1lO7`0GemO06UYJ@1gMgL0>3Ph07YjNP26QXH0DE5A0492@P0`<300DU9B06=SH`1ADE40De=C
04i>CP0e=CD0OWin069RHP14A4@0=3@d07MgM`1[Jf/0IFEU05QHF01?Cdl0>SXj09jNWP1MGEd0=CDe
07]kN`0203dm?@1906m_K`0o?cl0OWin06][J`1BDU80Hf=S06EUI@1SHf<0>CTi05QHF00m?Cd0A4A4
08>3P`1ZJVX0MgMg034a<@0f=SH0VIVI07inOP1@D500WIfM08N7Q`1ZJVX0FEUI08>3P`16ATH0QXJ6
09VIV@1oOgl0BTY:075aL@2BTY80F5QH08j>SP24Q8@0?Shn08R8R01^KVh0<c<c03hn?P1?Cdl0=cLg
030`<01?Cdl0IFEU07QhN00[:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0S8b<05mOG`11@D40V9RH
04Q8B014A4@0IVIV04E5A@1?Cdl0UiNG09fMW@1IFET0Cdm?05iNGP1gMgL0J6QX07inOP1ZJVX0TI6A
03Lg=`0204E5A@1603/k>`1LG5`0=3@d038b<P13@d<0Kfm_05EEE@0k>c/0LW9b01XJ6P0N7Qh0<30`
0410@01WIfL0<C4a04M7A`1;Bd/0=cLg0;Vi^@26QXH0AdM708F5Q@2FUYH0MGEe07UiN@1gMgL0CTi>
08:2PP25QHD0DU9B04I6AP1dM7@0EUIF02l_;`0];Bd0Cdm?05QHF029RHT0VIVI08B4Q01LG5`0VIVI
07MgM`0j>SX0ATI606m_K`0e=CD0NWYj096AT@1BDU80IFEU0:NWY`1LG5`09bLW07YjNP1/K6`0A4A4
07inOP26QXH0Ti>C0;^k^`1[Jf/0?Cdm01dM7@0];Bd0G5aL03hn?P0Z:RX0Q8B4079bLQcooooo01@0
K6a/06][J`1@D500EEEE02h^;P0S8b<0C4a<0492@P0G5aL06a/K06QXJ01PH600EeMG05QHF00l?3`0
5ADE014A4@0C4a<04A4A00h>3P80410@00D04a<C01LG5`1cLg<0C4a<0861P@0209^KV`0703De=@0b
<S80M7Ad08J6QP1EEED0=CDe03Lg=`0203dm?@0D03lo?`12@T80ADE504Q8B016ATH0CDe=05YJFP1a
LG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0[jn_08:2PP1IFET0C4a<04i>CP1CDe<205MGE`09055A
D@26QXH0ZJVY0<C4a03AdM40_[jn09bLW00T92@05ADE008051@D0`0C4a<0E`0E5AD04a<C01DE5@0I
6AT0:b/[09bLW02<S8`0];Bd08^;R`2HV9P0YjNW05QHF00h>3P0<c<c04=3@`1BDU80CTi>07AdM02U
YJD0WIfM07inOP2FUYH0Q8B403hn?P0N7Qh0820P024Q8@0_;bl0H61P0;Bd]032`/80Xj>S09JFUP23
Ph<0UIFE08B4Q01eMGD0[jn_05MGE`0c<c<0BTY:04m?C`0N7Qh092@T02<S8`0];Bd0DU9B04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM09FEU@0/;2`0<30`061PH013@d<0<30`03hn?P1?
Cdl0:b/[02@T901aLG40Xj>S08V9R@2DU9@0MgMg0820P02QXJ40Vi^K06i^KP2c/k<0c/k>065QH@0Z
:RX061PH01TI6@0K6a/06QXJ02h^;P1SHf<0>c/k01TI6@0201`L700601dM7@0J6QX0?clo04I6AP2A
TI405aLG0P0E5AD0M`0M7Ad0IfMW02`/;00l?3`0I6AT03`l?013@d<0EeMG07=cL`1PH600BDU90410
@00f=SH0;Bd]02`/;00];Bd08B4Q034a<@2GUiL0J6QX04];B`1lO7`0EUIF04Q8B01]KFd0@D5104i>
CP2l_;`0eMGE0<;2`P1YJFT0;Rh^02`/;00^;Rh0@41004M7A`2EUID0Ph>3061PH025QHD0Q8B406MW
I`1/K6`0Hf=S08n?S`2l_;`0GEeM01lO7`0T92@0CTi>09nOW`2:RXX0LG5a08:2PP1;Bd/05aLG01XJ
6P1FEUH0JVYZ03Ph>010@400C4a<04M7A`1RHV80ATI60861P@3=cLd0_Kfm09jNWP1DE5@0C4a<069R
HP1`L700TY:B07MgM`1=CDd0;bl_01lO7`0R8R80>c/k07QhN034a<@0aLG50;2`/024Q8@0Ng]k09>C
T`13@d<0:2PX02<S8`0M7Ad06QXJ01dM7@14A4@0YZJV0<_;b`2VYZH0UYJF08^;R`1FEUH0B4Q804Y:
BP1GEeL0IfMW09RHV00o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2;Rh/0N7Qh06MW
I`1YJFT0?3`l017ooooo000?ooooo`3o06UYJ@1_Kfl0OGem03lo?`1KFe/0>c/k07alO022PX80NGUi
0:JVYP1fMWH0;2`/04e=C@15ADD0<C4a028R8P13@d<06a/K01XJ6P11@D40?Shn02d];@1OGel051@D
04I6AP0R8R80CTi>06YZJP1NGUh08b<S03`l?00k>c/09BDU055AD@0F5QH0<c<c06][J`0/;2`05QHF
04i>CP0U9BD0?Cdm02XZ:P0k>c/0;bl_05]KF`0k>c/0<C4a05=CD`0j>SX0I6AT03lo?`1eMGD0PH61
05eMG@18B4P0CTi>059BDP0`<3007AdM06MWI`1iNGT0HF5Q071`L01>CTh07QhN05EEE@21PH40ATI6
034a<@1:BTX0:b/[055AD@1[Jf/0Bd];05YJFP10@400?3`l07alO00d=3@0>SXj065QH@0k>c/0QHF5
0820P00h>3P0JVYZ0:f][@0n?Sh0GemO05ADE01IFET0IFEU0=OGe`1_Kfl0IFEU04Q8B012@T80MgMg
06m_K`3>c/h0W9bL02<S8`1KFe/0G5aL04e=C@1<C4`0?3`l05aLG017AdL0GEeM05YJFP1:BTX0EUIF
04e=C@1<C4`0U9BD04=3@`1/K6`0SHf=059BDP1VIVH0ATI604e=C@1SHf<0Bd];05EEE@1VIVH0ATI6
0:JVYP1aLG40IfMW059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0Cdm?03@d=01`L700=cLg
04I6AP1oOgl0@41006i^KP1HF5P0D51@05QHF01fMWH0KVi^03Hf=P1BDU80I6AT04A4A01cLg<0IfMW
07AdM01GEeL0@4100::RXP1XJ6P0Bd];09ZJVP2?Shl0KFe]061PH02GUiL0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@2DU9@0Vi^K03hn?P1dM7@0Shn?03lo?`1EEED0J6QX03dm?@0d=3@0Fe]K
06YZJP1mOGd0?clo05EEE@1HF5P0<c<c03Ti>@1XJ6P0?Shn0;fm_@1HF5P0>c/k07AdM01GEeL0B4Q8
07MgM`0m?Cd0;Bd]04m?C`1nOWh0K6a/05iNGP1nOWh0UIFE061PH01gMgL0VIVI0:RXZ01@D500@T92
04M7A`0l?3`0LW9b04I6AP0f=SH0DE5A08:2PP0l?3`0AdM706ATI00V9RH0:2PX0492@P19BDT0FEUI
01dM7@1QHF40IfMW02TY:@2KVi/0[Jf]03Lg=`1^KVh0PX:204M7A`1]KFd0Lg=c05QHF01JFUX0O7al
03Lg=`1?Cdl0PX:207alO016ATH0:2PX000S069RHP0k>c/0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0
@D5104i>CP1bLW8071`L06IVIP22PX80Jf][04I6AP21PH40ATI601lO7`1aLG40MgMg055AD@2d];@0
PH61069RHP2CTi<0HF5Q05EEE@0h>3P0?Shn06YZJP0e=CD0=3@d09FEU@27QhL07?ooool0A`2_[jl0
EEEE04A4A00e=CD0:b/[05IFEP0d=3@05QHF01@D500`<300Lg=c01lO7`0o?cl0ADE504m?C`0O7al0
4a<C01DE5@0C4a<04Q8B01@D500>3Ph04a<C018B4P0e=CD0UIFE0:JVYP2SXj<0IfMW028R8P0^;Rh0
R8R809bLW01RHV80@T92034a<@0X:2P07AdM01/K6`0U9BD0?Shn02DU9@0M7Ad0CDe=03Lg=`0T92@0
BTY:0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];08^;R`30`<00KFe]04Q8B012@T80Bd];055AD@1UIFD0
OWin0;Fe]@2;Rh/0Ogmo0=3@d02NWYh071`L014A4@0E5AD04A4A00804a<C05406a/K01TI6@0I6AT0
5ADE05eMG@2g]kL0`/;20::RXP1PH600QXJ60<k>cP3AdM40WYjN07inOP1KFe/0EEEE04a<C017AdL0
UiNG09ZJVP1bLW80M7Ad06YZJP1YJFT0W9bL06IVIP19BDT0AdM7079bLP20P800][Jf0<G5a@3:b/X0
U9BD07emO@28R8P0OWin08Z:RP0e=CD0G5aL08f=S@1<C4`05aLG01<C4`0A4A40410@01TI6@0f=SH0
>3Ph02DU9@1nOWh0DU9B01lO7`1GEeL0X:2P0;Ng]`3?cll0[jn_03dm?@0Z:RX092@T05QHF012@T80
:b/[03Ti>@10@4008b<S061PH03;bl/0T92@08N7Q`1;Bd/0H61P09jNWP1iNGT0QXJ609ZJVP2YZJT0
Ng]k01LG5`0D51@00`0G5aL02`0K6a/0<c<c05eMG@0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0
/[:b00804a<C00h05ADE01LG5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@1CDe<0P82003Ph>00X:2P0
9bLW02`/;080;bl_00P0=CDe03`l?01?Cdl0X:2P09NGU`20P800JFUY04=3@`80=SHf05h0TI6A0:2P
X02:RXX0WIfM0;6a/@35aLD0V9RH02l_;`0X:2P0=3@d02TY:@23Ph<0VYZJ03dm?@0d=3@0>c/k061P
H02IVIT0dM7A0:RXZ02e]KD0>CTi02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG01DE
5@0G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0<30`031`L40cLg=08F5Q@19BDT0OWin0:FU
Y@1SHf<0;2`/01lO7`1?Cdl0A4A403Ph>00m?Cd0Fe]K08^;R`2VYZH0]kNg0;Rh^01[Jf/0CDe=051@
D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0Lg=c04];B`0a<C40=CDe04=3@`19BDT0U9BD075a
L@1@D500>c/k06][J`1BDU80Hf=S06][J`2=SHd0IFEU04Q8B02TY:@0ZZZZ04A4A01;Bd/0LG5a051@
D00Z:RX06QXJ4Oooool000oooooo0=h0L71`05EEE@1^KVh0>SXj04A4A00Y:BT0Cdm?06][J`1]KFd0
U9BD05UIF@0h>3P0M7Ad0820P019BDT0=3@d06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0
@T92028R8P0U9BD0<C4a05EEE@0X:2P0BDU9028R8P0Y:BT0HF5Q01/K6`0`<300H61P02<S8`0M7Ad0
Hf=S03Ph>00];Bd0=SHf069RHP0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1IFET0
DU9B0492@P1?Cdl0IVIV01/K6`0G5aL0@D5105YJFP16ATH0Lg=c04E5A@0M7Ad0>c/k05mOG`0W9bL0
9RHV04E5A@0V9RH0<30`04];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@03dm?@1SHf<0
RHV903De=@1BDU80`l?306MWI`1^KVh0FEUI05YJFP1[Jf/0clo?08b<S01/K6`0CDe=04M7A`1jNWX0
HF5Q0<71`@1nOWh0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0NWYj06=SH`1bLW80
Kfm_04I6AP2PX:00Cdm?06i^KP2=SHd0De=C08:2PP1?Cdl0De=C07EeM@1OGel0F5QH07]kN`1?Cdl0
Ti>C07emO@1RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D510:^[Z`18B4P0>CTi07EeM@0n?Sh0
ADE506][J`0h>3P0QhN709BDU01OGel0>3Ph07moO`1`L700>c/k05QHF01MGEd0BDU908R8R01cLg<0
RHV907IfMP0n?Sh0Vi^K071`L01>CTh0RXZ:08f=S@1VIVH0MgMg0:6QX@24Q8@0SXj>0:ZZZP2?Shl0
FEUI07AdM02YZJT0T92@09>CT`27QhL0A4A407emO@2LW9`0>SXj02h^;P1@D500>SXj02d];@1EEED0
G5aL06i^KP12@T80DU9B05iNGP13@d<0>SXj06i^KP15ADD0Y:BT08>3P`17AdL0R8R805QHF01>CTh0
VIVI05ADE00`<300F5QH07EeM@18B4P0FEUI0861P@2FUYH0IVIV06][J`1/K6`0OWin0451@@1KFe/0
ADE502h^;P1FEUH203Hf=P1206UYJ@2CTi<0KVi^04U9B@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_
;bl0?clo05=CD`0T92@0QHF50;:b/P11@D40HF5Q071`L016ATH0HF5Q06e]K@1CDe<0Ph>308n?S`1C
De<0?clo061PH01FEUH0:b/[034a<@1@D500CTi>06m_K`2ZZZX0QHF505ADE02<S8`0GemO03<c<`0g
=cL0IfMW03Hf=P1bLW80PX:207IfMP1DE5@0V9RH05ADE00/;2`0F5QH05UIF@0Z:RX0Q8B409VIV@1m
OGd0alO707IfMP0o?cl06ATI02XZ:P1KFe/0:2PX02<S8`1NGUh0KVi^7?ooool0502ATI40Ng]k06m_
K`1DE5@0I6AT03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0>SXj04I6AP1BDU808B4Q01<C
4`0A4A404a<C0P0>3Ph02@0@41003Ph>03<c<`3;bl/0ZJVY0:6QX@17AdL07QhN03Hf=P0204Y:BP03
02<S8`0E5AD04a<C00804a<C01<05ADE01LG5`0I6AT06ATI01/K6`0U9BD0Jf][05MGE`0/;2`0/k>c
0:JVYP1`L700Lg=c065QH@1PH600K6a/08J6QP1OGel0F5QH00<0FUYJ01<0KVi^06UYJ@1cLg<0W9bL
0:f][@2a/K40RXZ:05=CD`0g=cL0?Cdm0492@P0o?cl0>3Ph03dm?@0h>3P0=CDe02l_;`0e=CD0GemO
0080[Zj^03l0A4A4069RHP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03Ph>01DE5@0ADE5
03Ti>@16ATH0Ng]k07YjNP2PX:00RHV909jNWP2TY:@0_Kfm0<o?c`31`L40_Kfm0:2PX02:RXX0Ti>C
0;Jf]P1;Bd/0Fe]K04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@0820P06=SH`0g=cL0Ti>C
08F5Q@1KFe/0Ng]k06i^KP23Ph<0UYJF07QhN01fMWH0EEEE02/[:`0W9bL0GemO0451@@0c<c<07AdM
02XZ:P1>CTh0A4A402h^;P0d=3@00P1KFe/02020P800VYZJ09NGU`1FEUH0:BTY04U9B@1?Cdl08R8R
0P0E5AD201HF5P0801dM7@1ADE40@41001TI6@0Q8B409BDU02`/;01<C4`20<[:bP0>04Q8B00M7Ad0
>3Ph02`/;00^;Rh092@T02LW9`1<C4`0?clo02DU9@1OGel0X:2P05]KF`1SHf<206MWI`0I05eMG@1J
FUX0LG5a08R8R02/[:`0c/k>07inOP15ADD0@D5102`/;00R8R80:BTY0:>SX`2<S8`0Cdm?0410@02L
W9`0ZZZZ0;Fe]@1gMgL0:BTY020P800K6a/0PH6104Q8B00201LG5`0?01DE5@0R8R80EeMG09NGU`24
Q8@0Y:BT03<c<`1^KVh0NWYj03/k>`0d=3@0IVIV01lO7`0b<S808b<S00<05ADE00l05aLG0410@025
QHD0@41003/k>`0m?Cd0Zj^[0=OGe`3>c/h0fm_K0;Fe]@2o_kl0cLg=06ATI00S8b<00P0L71`0;00U
9BD0ATI606UYJ@24Q8@0WYjN08n?S`2VYZH0/k>c096AT@12@T8071`L02TY:@0a<C40>3Ph01/K6`0N
7Qh0=CDe06e]K@1NGUh0Jf][01dM7@0Y:BT0:2PX03/k>`1UIFD0YZJV09NGU`0n?Sh0<C4a04=3@`12
@T80DU9B07AdM02d];@0OGem071`L01mOGd0Jf][0:>SX`2BTY80Ti>C096AT@2BTY80PH614Oooool0
00oooooo0?H0VIVI05eMG@2BTY80>SXj06UYJ@0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0c<c<05ADE04];B`1LG5`08b<S034a<@0d=3@09BDU06i^KP0[:b/0@41004E5A@0h>3P0?Cdm
06YZJP0[:b/0>c/k03<c<`0i>CT0G5aL01/K6`0X:2P0FEUI020P800E5AD0BDU902l_;`0T92@08B4Q
059BDP0i>CT0Kfm_04i>CP0_;bl0@41003Xj>P1OGel0J6QX059BDP1_Kfl0J6QX03lo?`1IFET0KFe]
05UIF@0_;bl0?clo07MgM`1FEUH0GEeM03lo?`0V9RH0@D51069RHP0U9BD09bLW04E5A@0W9bL0<S8b
05=CD`0j>SX0EeMG06MWI`0W9bL0Ogmo03<c<`0h>3P0FEUI04m?C`1TI6@0PX:203Ph>00o?cl0`<30
06MWI`24Q8@0Lg=c06EUI@1HF5P0a/K606=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`2NWYh0?3`l
07YjNP1GEeL0C4a<07=cL`1LG5`0NGUi04E5A@1cLg<0NGUi05aLG01gMgL0LG5a04a<C02IVIT0C4a<
06IVIP1iNGT0EEEE06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM05UIF@1<C4`0@D51
08:2PP1`L700EEEE06m_K`1FEUH0DU9B0;^k^`1KFe/0?Cdm071`L00`<300D51@07QhN012@T80JFUY
07]kN`1=CDd0@D51096AT@1BDU80ADE506YZJP1BDU80Bd];09NGU`1OGel0LG5a05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08>3P`1QHF40OGem0;Jf]P1[Jf/0=SHf05mOG`26QXH0N7Qh
08Z:RP1cLg<0<C4a069RHP1oOgl0<c<c038b<P1=CDd0>c/k04U9B@1^KVh0I6AT07IfMP0f=SH0FUYJ
051@D014A4@0=CDe05QHF00e=CD0WinO06QXJ010@400S8b<05ADE00n?Sh0Kfm_05eMG@0_;bl0FEUI
07]kN`1[Jf/0A4A4071`L02GUiL0N7Qh07MgM`20P800TY:B05eMG@0m?Cd0GEeM04Q8B01VIVH0HV9R
02/[:`1>CTh0SHf=0861P@1CDe<0KFe]0492@P0U9BD0;Rh^04=3@`1XJ6P0:b/[04m?C`1WIfL0<C4a
08B4Q036a/H0BDU904e=C@29RHT0J6QX06e]K@1_Kfl205EEE@0Z07]kN`1JFUX0A4A406][J`2:RXX0
EEEE01dM7@13@d<0<C4a05MGE`2XZ:P0PH61055AD@2=SHd0J6QX04I6AP0h>3P0LW9b0410@01KFe/0
RHV904m?C`0e=CD0Lg=c05ADE00[:b/0GEeM06IVIP0d=3@0ZZZZ096AT@1_Kfl0bl_;06i^KP1MGEd0
7AdM024Q8@1FEUH0<30`02LW9`1lO7`0M7Ad7?ooool0502][Jd0I6AT04m?C`1CDe<0L71`03/k>`1>
CTh0Fe]K05UIF@1?Cdl0I6AT059BDP0R8R804a<C03Ph>01<C4`0FEUI01TI6@0B4Q80410@0P0A4A42
00h>3P0:07alO03EeMD0a<C40;Fe]@2ATI40?Cdm06IVIP0/;2`0:b/[01@D5080410@00D04A4A01@D
500J6QX06a/K01XJ6P0301LG5`0L01lO7`18B4P0VIVI0<O7a`1NGUh0;Rh^03hn?P1mOGd0SXj>06EU
I@0a<C4061PH01XJ6P0Q8B40;Rh^03Xj>P1TI6@0IfMW0:BTY02NWYh0bLW905EEE@0W9bL0OGem038b
<P0N7Qh06ATI01HF5PL05ADE00X0?clo04Y:BP1RHV80C4a<0<G5a@2BTY80NGUi01lO7`0K6a/061PH
0P0E5AD0@@0C4a<061PH09RHV01ZJVX0F5QH05ADE02MWId0/;2`0;no_`2DU9@0UiNG0:j^[P2k^k/0
bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/02h^;P1QHF40<30`01/K6`0L71`09bLW03lo?`14A4@0
9bLW01dM7@2UYJD0UiNG0:b/[02VYZH0F5QH069RHP1NGUh0IFEU03Hf=P1>CTh0A4A405ADE01PH600
?3`l02DU9@1`L700AdM7030`<01>CTh0Ogmo05aLG01FEUH0De=C096AT@2KVi/0HV9R04A4A01CDe<0
8R8R01DE5@0H61P092@T06IVIP1TI6@0:RXZ00805ADE00/06ATI03@d=01dM7@0>c/k03Ti>@0g=cL0
FUYJ0:BTY03Fe]H0Y:BT05mOG`0207QhN00E0410@00Y:BT08R8R02@T9016ATH0[:b/08B4Q031`L40
clo?07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0MWIf0;>c/`2/[:`0@d=30080:BTY00H0
92@T08N7Q`2HV9P0FEUI01lO7`0b<S820;no_`0H0;Zj^P32`/80/;2`08>3P`0f=SH0K6a/0492@P0K
6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf07YjNP1CDe<07AdM01DE5@0N7Qh0B4Q802/[:`0M
7Ad0<S8b100E5AD03P0F5QH0BTY:08f=S@14A4@0<S8b07UiN@39bLT0Zj^[096AT@3@d=00cLg=06IV
IP0M7Ad05ADE0P0K6a/0;00P8200;Rh^0410@01iNGT0WYjN05=CD`1PH600RXZ:06UYJ@0/;2`061PH
01`L700K6a/0=cLg0492@P0a<C40D51@07]kN`1XJ6P0GEeM02`/;00b<S80@410051@D01oOgl0TY:B
09NGU`1<C4`0<C4a055AD@0h>3P0CDe=075aL@2[Zj/0RXZ:06ATI00Q8B409bLW08j>SP1gMgL0=SHf
038b<P0c<c<0H61P4Oooool000oooooo02P0Shn?05ADE02CTi<0>3Ph07IfMP0g=cL0SXj>0492@P1[
Jf/0UYJF06m_K`0c<c<0AdM706EUI@0n?Sh0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U
9BD0>c/k03@d=00m?Cd0@41005]KF`0^;Rh0>c/k04E5A@1BDU80E5AD01TI6@0Y:BT0DU9B03dm?@0G
5aL0D51@0P0l?3`01P0g=cL0GEeM04Q8B02@T900Jf][03`l?080B4Q800l0EeMG07AdM01@D500HF5Q
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm06][J`1OGel00P0g=cL0]P1fMWH0?Shn
03De=@1RHV80EeMG038b<P1RHV80@41006i^KP1jNWX0:2PX07AdM00[:b/0=CDe07=cL`1HF5P0IfMW
08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P01VIVH0RXZ:0=CDe01IFET0ATI606ATI01eMGD0TI6A
05mOG`2e]KD0WIfM03@d=01lO7`0H61P04I6AP1EEED0D51@07]kN`0d=3@0B4Q805=CD`1QHF40QXJ6
05iNGP0g=cL0Kfm_03hn?P1XJ6P0RXZ:04e=C@1>CTh0=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe
06QXJ01gMgL0BDU904];B`1]KFd0PH6105ADE01FEUH0AdM703Ph>028R8P0BTY:030`<01/K6`0;bl_
0410@01^KVh0DE5A07EeM@1iNGT0HV9R028R8P1]KFd0Lg=c03@d=01CDe<0EUIF04=3@`20P800MgMg
07emO@1PH600=SHf08V9R@1oOgl0De=C08Z:RP1eMGD0IVIV07moO`2EUID0DE5A05]KF`2d];@0IfMW
04U9B@1HF5P0UiNG07]kN`27QhL0SHf=04];B`1mOGd0W9bL04=3@`0_;bl0Bd];0410@00`<300G5aL
05YJFP1kNg/0;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609nOW`1RHV80@T9208>3P`1LG5`0@410
06m_K`1BDU80?Shn07inOP27QhL0FUYJ03Lg=`1VIVH0LW9b05eMG@1TI6@0SXj>08b<S01UIFD0=CDe
05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0@d=306MWI`1_Kfl0;Rh^03De=@18B4P0J6QX
02@T900l?3`0Fe]K03lo?`1HF5P0WIfM0492@P0n?Sh0L71`04Q8B01WIfL0M7Ad06IVIP1ZJVX0Ph>3
0P1MGEd09`2?Shl0UYJF05EEE@0R8R80?Shn038b<P11@D40_Kfm08:2PP1PH600O7al06e]K@0n?Sh0
Bd];08Z:RP13@d<0C4a<08b<S01XJ6P0?clo092@T01aLG40>3Ph05MGE`1SHf<0@T9209RHV026QXH0
J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0BDU9034a<@0^;Rh0LG5a08N7Q`0Looooo`0V0:JVYP1cLg<0
JFUY096AT@1fMWH0WYjN065QH@0d=3@08R8R01`L700H61P08b<S04A4A00g=cL07QhN04M7A`0o?cl0
DU9B01LG5`0?3`l03Ph>01<C4`0U9BD0De=C09VIV@1fMWH0MgMg0:ZZZP2RXZ80VIVI04a<C012@T80
6ATI01@D500A4A403`l?010@400G5aL201DE5@0?01LG5`0H61P05QHF01PH600I6AT06QXJ051@D03:
b/X0Fe]K02XZ:P0d=3@0GEeM06i^KP1SHf<0:RXZ00805QHF00l07alO02XZ:P0f=SH0E5AD079bLP37
alL0/k>c06a/K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD00`0D51@401DE5@0701HF5P0O7al0
>3Ph07=cL`2VYZH0I6AT03hn?P0501DE5@0J01<C4`0W9bL0Fe]K03<c<`0[:b/0=3@d09>CT`1YJFT0
SHf=05QHF01`L700Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH07QhN05iNGP0d=3@0
8B4Q01TI6@0M7Ad201/K6`0P02h^;P1IFET0WinO0:FUY@2/[:`0^;Rh05YJFP1ADE40@T9202HV9P0J
6QX08R8R03Ti>@14A4@0Bd];05EEE@14A4@0C4a<0:>SX`1HF5P0HV9R092@T01CDe<0PH6109nOW`1b
LW80<30`01LG5`0e=CD0EEEE01DE5@0C4a<201DE5@0?028R8P1]KFd0P820034a<@0M7Ad06ATI02h^
;P1YJFT0Xj>S08Z:RP23Ph<0/k>c0;fm_@1fMWH0Ph>30080IVIV03T0WYjN09bLW01oOgl0EeMG03lo
?`25QHD0gmoO0<K6aP2=SHd0fMWI04U9B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0>3Ph07al
O02GUiL0NWYj03@d=00b<S80RHV909NGU`1EEED05aLG01HF5P1iNGT0DE5A06UYJ@2PX:00];Bd09NG
U`2=SHd0aLG50;Jf]P2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@2i^KT08R8R01TI
6@0F5QH06QXJ05ADE017AdL06QXJ0410@00G5aL00`0E5AD07P0C4a<05ADE03lo?`2XZ:P0F5QH07Ad
M02a/K40UYJF0<W9b@2g]kL0ZJVY07inOP14A4@06a/K01XJ6P0K6a/0<c<c06UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01XJ6P0I6AT05aLG028R8P80EEEE00`0Rh^;06a/K02a/K40<C4a
06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH206QXJ00>034a<@13@d<0MgMg0:6QX@2BTY80
=SHf01`L700V9RH0Kfm_02DU9@0G5aL06ATI02<S8`1]KFdAooooo`003oooool0P`2;Rh/0D51@07Mg
M`0m?Cd0IVIV04A4A02LW9`0?Cdm04i>CP20P800Fe]K038b<P15ADD0BTY:03`l?00[:b/0ATI603dm
?@0O7al0<S8b028R8P0L71`0JVYZ02XZ:P0e=CD08B4Q03dm?@16ATH0F5QH02DU9@12@T80=CDe02l_
;`1ADE406QXJ038b<P1KFe/0=SHf020P800o?cl0<C4a02h^;P0U9BD0ADE503Xj>P1JFUX0?clo02h^
;P16ATH0BTY:03Xj>P1KFe/0@D5106EUI@1EEED0=SHf05=CD`1EEED0:BTY028R8P14A4@0I6AT03lo
?`1:BTX0DU9B030`<00k>c/0KFe]030`<00N7Qh0>SXj0410@00f=SH0IVIV02d];@1>CTh0DU9B02@T
901[Jf/0=cLg030`<01GEeL0CTi>05eMG@23Ph<0D51@02<S8`23Ph<0IFEU06YZJP1NGUh0EEEE096A
T@3Jf]X0S8b<06=SH`1?Cdl0BTY:07QhN01ZJVX0clo?09^KV`0g=cL0LW9b07emO@1<C4`0FEUI05IF
EP1nOWh0@41005EEE@1ZJVX0Bd];07=cL`1fMWH0=SHf08^;R`1DE5@0FUYJ07inOP1BDU80Fe]K04Q8
B01>CTh0MWIf05YJFP1?Cdl0KVi^04U9B@1]KFd0Ng]k0080Lg=c05`0MgMg0861P@1KFe/0H61P05UI
F@0m?Cd0T92@059BDP0h>3P0QHF50451@@1=CDd0L71`05YJFP1dM7@0U9BD06=SH`0Z:RX0AdM705UI
F@0c<c<0FUYJ061PH00o?cl0SXj>071`L01gMgL0M7Ad03Lg=`2=SHd0K6a/05EEE@2EUID0NWYj07Ad
M024Q8@0Y:BT05YJFP19BDT0dM7A08b<S01UIFD0GEeM09RHV01fMWH0NGUi08Z:RP18B4P0RHV90:b/
[01DE5@0:RXZ05QHF013@d<0<C4a05mOG`1ZJVX0L71`034a<@11@D40H61P02l_;`0l?3`0CTi>04=3
@`2JVYX0?Shn03@d=027QhL0IVIV0451@@27QhL0@D5102HV9P1>CTh0Fe]K04e=C@19BDT0QXJ607mo
O`1/K6`0JFUY08j>SP1lO7`0EUIF04Q8B01_Kfl0@d=306i^KP1GEeL0=cLg05QHF080PX:201@0G5aL
05iNGP1LG5`0?Cdm04];B`1CDe<0Ph>304m?C`11@D40GemO030`<01KFe/0[Zj^06YZJP0l?3`0Rh^;
05iNGP1_Kfl0PH6106a/K080LG5a00/0Cdm?03Ti>@1HF5P0SHf=05MGE`0P8200?Cdm04E5A@0i>CT0
_;bl09BDU00206EUI@0J08f=S@1HF5P0?clo075aL@16ATH0>3Ph08j>SP1lO7`0AdM708b<S01PH600
=cLg05YJFP2DU9@0F5QH09:BTP1jNWX0Fe]K0<S8b02^[Zh0LG5a02PX:00[:b/0HF5Q04E5A@0a<C42
0820P1cooooo01`0_;bl05iNGP14A4@0>CTi06=SH`2>SXh0<30`01`L700H61P05QHF01@D500A4A40
4Q8B01TI6@0a<C40?clo05YJFP1PH600LG5a04E5A@0b<S80>CTi03`l?00h>3P0=SHf020P801RHV80
U9BD0P2OWil01023Ph<0QhN703Lg=`0H61P201@D5003018B4P0E5AD05ADE00805ADE0`0F5QH07@0E
5AD06QXJ07=cL`1FEUH0>CTi01PH600F5QH07alO03@d=01nOWh0UiNG06UYJ@1FEUH0IFEU05]KF`19
BDT0?Cdm05EEE@1@D500LW9b09jNWP1fMWH0`/;20:^[Z`0j>SX06ATI01@D500E5AD051@D00@05ADE
0P0D51@02@0C4a<0820P03@d=02PX:00Z:RX09fMW@0l?3`05QHF01@D500201<C4`0W01@D500L71`0
Fe]K02/[:`0N7Qh08B4Q03dm?@1dM7@0?Shn08Z:RP1:BTX0:RXZ0410@01NGUh0Jf][07QhN02>SXh0
Jf][04M7A`1<C4`0FUYJ03Hf=P0K6a/05aLG02XZ:P0d=3@0:2PX02<S8`0Q8B407alO069RHP1]KFd0
GUiN07inOP2WYjL0HV9R06YZJP1;Bd/0=cLg0080=3@d01<0@41004Q8B012@T80C4a<055AD@1VIVH0
YJFU0;fm_@2l_;`0^k^k07moO`18B4P0:b/[01TI6@0M7Ad08R8R03hn?P0S8b<051@D00<04a<C0200
5ADE02HV9P16ATH0IVIV069RHP0];Bd0=cLg069RHP2YZJT0f][J0=;BdP2RXZ80I6AT02l_;`0e=CD0
C4a<092@T02JVYX0SHf=09:BTP2c/k<0eMGE0=oOg`2o_kl0DU9B06EUI@1hN7P0T92@08J6QP1KFe/0
?3`l03@d=080<S8b00D0;Rh^03hn?P1gMgL0WIfM08>3P`020;Bd]00Q06e]K@0o?cl09RHV028R8P0n
?Sh0>SXj038b<P0W9bL0?clo08:2PP32`/80Vi^K0:ZZZP2c/k<0YZJV08V9R@25QHD0P82005]KF`1b
LW80c/k>0<G5a@2a/K40MgMg08J6QP2:RXX0S8b<09:BTP36a/H0]kNg05MGE`1BDU80<S8b00<05ADE
01X04a<C01@D500G5aL0J6QX0=;BdP3<c<`0gMgM0<O7a`2FUYH0FUYJ03<c<`0g=cL0BDU9065QH@1M
GEd0JVYZ061PH00b<S80:RXZ02@T900j>SX0GUiN075aL@1fMWH0BTY:03@d=0806QXJ0200:BTY03@d
=01NGUh0Shn?09^KV`2GUiL0Bd];065QH@2OWil0MGEe04I6AP0e=CD0;bl_02h^;P0`<300?Cdm092@
T02ZZZX0QXJ608Z:RP2b/[80IFEU05]KF`1DE5@0820P04U9B@1BDU805aLG01HF5P0H61P07QhN06UY
JA7ooooo000?ooooo`0>0;Ng]`1>CTh0UiNG03`l?025QHD0KVi^0:FUY@17AdL0GEeM08f=S@27QhL0
@41003`l?01?Cdl203Ph>00U0492@P1PH600:BTY02`/;00V9RH07QhN06EUI@0`<300;Rh^038b<P0d
=3@0=SHf06IVIP0a<C40?Shn03/k>`0n?Sh0BDU9028R8P0P8200@D5103hn?P0U9BD0>CTi04U9B@0X
:2P08b<S05aLG019BDT0G5aL04];B`0h>3P0A4A405iNGP13@d<0JFUY04Y:BP0206QXJ00@03<c<`1M
GEd0J6QX04Q8B00f=SH0?3`l06i^KP0g=cL0K6a/05=CD`0X:2P0:RXZ06e]K@0f=SH0<S8b051@D080
:BTY0700FUYJ02DU9@1@D500EeMG024Q8@1VIVH09BDU034a<@1LG5`0DU9B055AD@2>SXh0GemO02XZ
:P1eMGD0PH6105iNGP1bLW80IVIV08R8R03EeMD0PH61055AD@1/K6`0QXJ609ZJVP1KFe/0a/K60:ZZ
ZP14A4@0Lg=c06ATI01QHF40Ogmo06EUI@1oOgl0ATI6065QH@1/K6`0CDe=07inOP1NGUh0?Cdm08j>
SP1IFET0GemO08V9R@1>CTh0I6AT0492@P1=CDd0MWIf04i>CP1ADE40NGUi04A4A02>SXh0EeMG06EU
I@1JFUX0NWYj071`L01CDe<0DE5A03De=@18B4P0ZJVY05eMG@0[:b/0L71`02PX:01UIFD0KVi^069R
HP1EEED0Jf][05eMG@0h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01cLg<0I6AT03hn
?P2CTi<0Ogmo05MGE`2;Rh/0FEUI06IVIP2YZJT0XZ:R03/k>`15ADD0^;Rh0:JVYP1RHV80PX:20<;2
`P1[Jf/0KFe]08>3P`0l?3`0NGUi08V9R@13@d<0820P0P13@d<0>`1?Cdl0IFEU05IFEP22PX808R8R
051@D01gMgL0>CTi02TY:@15ADD08B4Q08:2PP1<C4`0>SXj07YjNP19BDT0EeMG08^;R`1=CDd08B4Q
05=CD`1EEED0:BTY0492@P1jNWX0IVIV06][J`1OGel0W9bL08N7Q`1NGUh0=SHf06IVIP1;Bd/0K6a/
06IVIP11@D40CTi>079bLP1oOgl0F5QH05UIF@1OGel0:b/[034a<@10@400Kfm_03`l?00Z:RX0CDe=
02PX:01BDU80Rh^;05ADE010@400JVYZ0451@@1[Jf/0NGUi0080LG5a02X0OWin06][J`0i>CT0CTi>
08R8R01CDe<07alO03hn?P19BDT0=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1_Kfl0BTY:
03Lg=`2a/K40T92@051@D01oOgl0Fe]K02XZ:P1hN7P0X:2P06IVIP34a<@0Hf=S03Xj>P2`/;00TI6A
05iNGP0Z:RX0;bl_04];B`0A4A40=cLg07]kN`1lO7`Looooo`0<079bLP1TI6@0?clo03/k>`2>SXh0
IVIV05ADE00l?3`05aLG01<C4`0E5AD051@D0P0C4a<05`0F5QH0Ph>308f=S@2;Rh/0MWIf0;Bd]01j
NWX0?3`l02`/;00];Bd08R8R05YJFP2m_Kd0cLg=0<[:bP1mOGd0?3`l06=SH`2<S8`0@D5101TI6@0E
5AD04Q8B00D05ADE0P0D51@0;@0E5AD0?Shn06MWI`0l?3`0:b/[01PH600D51@04a<C01LG5`1@D500
EUIF07IfMP0`<3007alO01`L700J6QX05QHF01/K6`19BDT09bLW04M7A`1gMgL0^;Rh0;bl_01hN7P0
DU9B01PH600E5AD04a<C01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026QXH0Q8B40;Zj^P2o_kl0
^[Zj08^;R`0a<C407QhN01LG5`0201DE5@0E04U9B@0m?Cd071`L024Q8@0M7Ad0?Cdm071`L01?Cdl0
AdM704Q8B012@T80ATI6061PH02DU9@0TY:B09ZJVP27QhL0?Shn02XZ:P0h>3P0?Shn0080410@00d0
4a<C01HF5P0];Bd0>3Ph03De=@0m?Cd0NGUi09BDU01ZJVX0R8R803Xj>P1KFe/0A4A4008051@D01<0
4a<C018B4P0E5AD07AdM02PX:00P8200:RXZ024Q8@0^;Rh0f=SH0<O7a`20P8007alO01HF5P0E5AD0
6QXJ02`/;01?Cdl0?3`l00H05ADE08@04a<C01hN7P0W9bL0GEeM09>CT`1LG5`0`/;20=KFeP3:b/X0
eMGE06IVIP1DE5@0GemO07UiN@1kNg/0MWIf079bLP1dM7@0[Jf]0<;2`P1fMWH0_kno0<30`01MGEd0
7alO01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l07moO`2SXj<0^KVi0;Bd]02FUYH0
R8R805eMG@0K6a/08R8R05mOG`14A4@0<C4a02/[:`0T92@07AdM055AD@2^[Zh0QXJ607moO`1[Jf/0
FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0FUYJ04e=C@1;Bd/0MWIf09:BTP2LW9`0
OGem06QXJ01fMWH0RXZ:03<c<`0P8200;Bd]03Lg=`1<C4`0>CTi0<K6aP3Jf]X0clo?0>CTi02j^[X0
CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0e=CD08b<S020P800L71`07alO028R8P1NGUh0
Ph>303/k>`0g=cL05QHF01/K6`0k>c/0KVi^09BDU02[Zj/0^[Zj09NGU`2QXJ40MWIf03De=@1=CDd0
KVi^04=3@`0U9BD0:2PX02XZ:P1OGel0Zj^[07AdM013@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0
[:b/02l_;`0F5QH201DE5@0301XJ6P1<C4cooooo013ooooo000?ooooo`2e09^KV`1<C4`0MgMg03Lg
=`1bLW80R8R80;Bd]00l?3`0Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0?Shn04M7A`11@D40I6AT034a
<@0W9bL0;bl_01lO7`1VIVH0<S8b030`<00k>c/0?Shn03`l?01PH6004a<C03lo?`1?Cdl0?Shn0492
@P0O7al0;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1>CTh0EEEE075aL@1WIfL0?Shn04=3
@`17AdL0@T9208N7Q`0n?Sh0NWYj04a<C00U9BD0ATI605]KF`0o?cl09bLW04E5A@1YJFT0Cdm?04];
B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02h^;P1IFET092@T065QH@1VIVH0820P06IV
IP0h>3P0:BTY05QHF01@D500BDU908n?S`19BDT08R8R05IFEP1ZJVX0D51@05mOG`1SHf<0QHF50=WI
f@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0Zj^[0410@01bLW80KFe]04Y:BP1OGel0GEeM09FE
U@1GEeL0DE5A04Q8B01GEeL0VIVI08b<S015ADD0OGem0410@01WIfL0SHf=05ADE01GEeL0<c<c06YZ
JP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1KFe/0F5QH04E5A@1kNg/0S8b<05QHF01CDe<0@T9203@d
=02>SXh0FUYJ02d];@24Q8@0>SXj03hn?P1]KFd0Hf=S05UIF@1cLg<0Jf][05EEE@1YJFT0KVi^02XZ
:P1FEUH0BTY:03Ph>021PH40N7Qh06UYJ@1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075a
L@2ATI40CDe=02/[:`2OWil0XZ:R04E5A@1PH600X:2P07YjNP1cLg<0Shn?06ATI00209JFUP1E06AT
I00T92@0@D51051@D00];Bd0HV9R051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<08F5
Q@12@T80?Cdm07AdM01YJFT0?Shn06QXJ010@4008b<S051@D01FEUH0@41004U9B@1ZJVX0Cdm?05YJ
FP1LG5`0[Jf]07AdM01HF5P0=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900HF5Q04];
B`1UIFD0@41003Hf=P12@T80MgMg05MGE`0Y:BT0GUiN03@d=01NGUh0U9BD07alO01ADE40Jf][07Mg
M`1]KFd0OGem079bLP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU808B4Q04i>CP1<C4`0=3@d09BD
U01gMgL05aLG04i>CP2IVIT0K6a/03dm?@1TI6@0<c<c02HV9P0207UiN@0D04Y:BP1fMWH0DE5A01@D
501EEED0RXZ:07AdM035aLD0P82004E5A@2_[jl0WIfM05iNGP0W9bL0<c<c04];B`0g=cL0:BTY06m_
K`28R8PLooooo`0;05]KF`1<C4`0Fe]K0;6a/@1mOGd0GemO030`<00i>CT0>c/k02DU9@0H61P00P0E
5AD05`0C4a<05ADE05mOG`1/K6`0E5AD09BDU02WYjL0U9BD0;bl_02LW9`0QHF508>3P`2KVi/0c<c<
0;fm_@2g]kL0][Jf05=CD`0b<S80Fe]K04U9B@0M7Ad05QHF00T05ADE00l0FEUI065QH@0g=cL0;2`/
01DE5@0C4a<0410@02HV9P1?Cdl0>SXj04M7A`0V9RH071`L01XJ6P0I6AT00P0L71`0@P0S8b<0:2PX
01lO7`19BDT0UiNG0:6QX@2;Rh/0K6a/05IFEP0M7Ad061PH02DU9@0_;bl0@41005ADE01HF5P0EEEE
0492@P0];Bd06a/K071`L02h^;P0alO708j>SP1oOgl0FUYJ06ATI012@T809BDU05MGE`0W9bL08B4Q
02d];@0/;2`0GEeM04m?C`0e=CD071`L01DE5@10@400Lg=c08R8R02][Jd0/;2`08:2PP1]KFd0JVYZ
061PH01YJFT0U9BD03dm?@12@T80=3@d034a<@13@d<0J6QX05mOG`12@T80IfMW0:j^[P2[Zj/0X:2P
04i>CP1SHf<05aLG014A4@805ADE04D051@D01<C4`0C4a<06a/K02d];@0R8R809bLW02/[:`2g]kL0
N7Qh069RHP0e=CD06a/K01DE5@0K6a/0:BTY05MGE`0a<C4051@D01LG5`0E5AD05QHF01DE5@0A4A40
4Q8B01TI6@0P8200;Bd]08>3P`36a/H0TY:B08f=S@1TI6@0][Jf092@T01VIVH0PX:2096AT@24Q8@0
Hf=S0:2PX02_[jl0[:b/09NGU`2h^;P0b/[:0<g=c@0[:b/05aLG01XJ6P1=CDd0De=C04U9B@2>SXh0
bLW90;^k^`1_Kfl0DU9B08j>SP33`l<0Ti>C09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@0k>c/0
0P0/;2`04P0Q8B409BDU04a<C02BTY80GemO06a/K01:BTX0@41003/k>`1NGUh0cLg=0<O7a`1YJFT0
<c<c02PX:00/;2`0?3`l06UYJ@80Q8B40440De=C034a<@0i>CT0EeMG06][J`1aLG40Z:RX05]KF`14
A4@0?Shn06i^KP32`/80ZZZZ09BDU02n_[h0d=3@0;6a/@2XZ:P08B4Q01DE5@0T92@0De=C04E5A@11
@D40MgMg05mOG`0_;bl07AdM01`L700M7Ad06a/K02DU9@1gMgL0GUiN03dm?@0G5aL07alO04=3@`1g
MgL0^k^k0<71`@2?Shl0aLG50<C4a00f=SH0820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07QhN02>
SXh0DE5A02TY:@0b<S80Hf=S05iNGP1?Cdl0XZ:R0=CDe03=cLd0EEEE01TI6@0201DE5@0301HF5P0d
=3Cooooo013ooooo000?ooooo`0H09NGU`1;Bd/0LG5a03lo?`1GEeL0JFUY0:VYZ@13@d<0DE5A05eM
G@1=CDd0=CDe06ATI01SHf<0<c<c04A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024Q8@0AdM70P0S
8b<0P00o?cl0HF5Q071`L00i>CT09bLW03@d=00U9BD0Cdm?02@T900J6QX0EUIF04M7A`0k>c/0BTY:
03Lg=`0^;Rh0;Bd]059BDP17AdL0DE5A04a<C017AdL0IVIV06EUI@0m?Cd0HV9R030`<01bLW80IfMW
03Hf=P10@400E5AD03@d=00[:b/0=cLg06MWI`1<C4`0Bd];06ATI00h>3P0820P07AdM01GEeL0820P
030`<016ATH0>SXj06UYJ@0n?Sh0D51@04I6AP0M7Ad0JVYZ05eMG@0];Bd0DE5A04Y:BP1DE5@0R8R8
06e]K@0V9RH0HF5Q07AdM01OGel0IfMW05ADE01JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH
0<O7a`2o_kl0>3Ph07QhN01[Jf/0Bd];04m?C`19BDT0PX:206IVIP1FEUH0Cdm?04=3@`1[Jf/0Ng]k
03hn?P1dM7@0@T92051@D01kNg/0DE5A05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/
05MGE`1ZJVX0F5QH06MWI`1nOWh0FUYJ05aLG01ADE40?Shn09BDU01JFUX0<C4a07moO`15ADD0De=C
079bLP1iNGT0EUIF06IVIP1?Cdl0C4a<05IFEP1NGUh0:RXZ0P1DE5@02P0j>SX0P820075aL@1UIFD0
KVi^03dm?@2<S8`0QhN705EEE@22PX82079bLP1Y07QhN02DU9@0E5AD03hn?P2/[:`0]KFe06EUI@1R
HV80Y:BT08f=S@2:RXX0`L7106m_K`2RXZ80VYZJ07UiN@0U9BD0@D5105YJFP0[:b/0Jf][051@D020
P800?3`l04Y:BP1dM7@0=3@d02h^;P1?Cdl0FUYJ07]kN`1]KFd0Bd];07]kN`1mOGd0?clo06MWI`1C
De<0=cLg08J6QP2EUID0NGUi059BDP24Q8@0F5QH06ATI01BDU80c/k>0:b/[01^KVh0=CDe04m?C`10
@400NGUi07moO`1PH600CDe=06i^KP2?Shl0FUYJ04I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a
<C40JVYZ02d];@1WIfL0Ogmo07alO01BDU80L71`05UIF@1PH600RXZ:06QXJ02LW9`0UYJF075aL@0a
<C40@D5106a/K00X:2P09bLW06IVIP1@D500;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1i
NGT0IFEU030`<02/[:`0Ng]k04Y:BP1XJ6P0JFUY0080MgMg00l0XJ6Q07alO03EeMD0XZ:R04Q8B02F
UYH0Zj^[05MGE`1@D500De=C075aL@1HF5P0;Bd]07alO02IVIT07?ooool0<P2HV9P0^KVi0=?Cd`2e
]KD0PX:206m_K`0l?3`0;Rh^02l_;`0e=CD0:b/[01DE5@0>3Ph03`l?02TY:@0U9BD06ATI01`L7018
B4P0P82008j>SP2ATI40YjNW0;2`/01VIVH0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R8P29
RHT0FUYJ04a<C00i>CT0;bl_02LW9`0L71`05aLG01<C4`0D51@05ADE024Q8@1KFe/0CTi>03<c<`0Q
8B4061PH0P0E5AD06`17AdL0@T9202TY:@0m?Cd0:b/[01LG5`0F5QH05aLG02l_;`0O7al051@D014A
4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF061PH01>CTh0?Shn03<c<`0P820061PH01HF
5P0201DE5@0B01/K6`1BDU80/[:b09bLW02KVi/0QHF509NGU`25QHD0MWIf09bLW020P800ATI603Ti
>@0f=SH0>SXj0492@P0M7Ad06ATI0P0E5AD06@0e=CD0L71`08^;R`2JVYX0]kNg08V9R@1bLW80_[jn
09NGU`2SXj<0SXj>065QH@1OGel0FUYJ07EeM@1]KFd0P82009NGU`2ZZZX0XZ:R0:j^[P2n_[h0aLG5
09FEU@0a<C400P0E5AD0XP0A4A405ADE018B4P0@41004A4A01DE5@0S8b<0A4A402LW9`0[:b/0WYjN
07YjNP27QhL0ZJVY071`L01BDU80?clo06IVIP1/K6`0:RXZ01DE5@0G5aL05ADE01LG5`0E5AD04a<C
01DE5@0F5QH07AdM02PX:01bLW80T92@05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b
08J6QP1NGUh0Cdm?04=3@`0^;Rh0VIVI0;fm_@35aLD0?Shn01/K6`0Q8B40:b/[03<c<`0o?cl0EUIF
08:2PP2d];@0U9BD038b<P2?Shl0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0YJFU
0;Ng]`2QXJ40MGEe06=SH`29RHT0X:2P096AT@0f=SH07AdM02/[:`0d=3@0=CDe0:^[Z`1cLg<0;Bd]
02TY:@0V9RH0;2`/030`<01?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0LG5a08R8R02EUID0alO7
09JFUP2@T900b<S80:FUY@1gMgL0TI6A07YjNP38b<P0]kNg09bLW021PH409BDU01DE5@0T92@0@D51
06m_K`2WYjL0Rh^;02/[:`0L71`06a/K01PH600L71`07QhN051@D01RHV80>c/k01TI6@0^;Rh0Bd];
08F5Q@2l_;`0UiNG08J6QP1/K6`0Shn?01hN7P0M7Ad08B4Q01dM7@0Z:RX0;Rh^04=3@`1OGel0F5QH
09:BTP13@d<0:RXZ03@d=015ADD0LW9b05UIF@2n_[h0eMGE0<c<c037alL0D51@01<C4`0E5AD06a/K
02PX:17ooooo000?ooooo`0g0;Vi^@1<C4`0RHV904=3@`1YJFT0LG5a0;fm_@19BDT0GemO069RHP1[
Jf/0;bl_0451@@1WIfL0<30`02TY:@19BDT0F5QH02d];@0O7al092@T01HF5P1]KFd0BDU902TY:@0M
7Ad07QhN02l_;`1OGel0>c/k02<S8`0[:b/061PH04=3@`0c<c<071`L04m?C`0k>c/09bLW03Ph>011
@D408R8R01dM7@1@D500CDe=05YJFP0e=CD0=cLg04M7A`1UIFD0?clo05EEE@0h>3P0IVIV06i^KP02
03`l?01T04m?C`1>CTh0@T9203Ph>01NGUh0@D5104A4A01ADE40:BTY01`L701]KFd0ADE5020P800]
;Bd0B4Q802TY:@1?Cdl0:BTY04m?C`1=CDd0820P05UIF@1HF5P09bLW05EEE@19BDT0?3`l07IfMP1Y
JFT0:RXZ06ATI01jNWX0Kfm_06a/K01BDU80AdM70<c<c02MWId0JVYZ03`l?01IFET0OWin06ATI02P
X:00];Bd0451@@1MGEd0LG5a04a<C01KFe/0EUIF0820P01/K6`0De=C04e=C@1<C4`0Ogmo08f=S@12
@T80NGUi05]KF`1FEUH0O7al059BDP1?Cdl0?Cdm059BDP1lO7`0IFEU03lo?`1NGUh0CDe=07EeM@1H
F5P0M7Ad06EUI@1VIVH0O7al06=SH`1HF5P0;bl_030`<01iNGT0BTY:02l_;`1jNWX0>SXj04E5A@1k
Ng/0MGEe069RHP2FUYH0FUYJ04M7A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`80PH610640J6QX08B4
Q00e=CD0IfMW069RHP1GEeL0UiNG092@T01TI6@0MWIf09JFUP11@D40=cLg07moO`2VYZH0I6AT06IV
IP2PX:00KVi^04I6AP2;Rh/0DU9B09nOW`2<S8`0G5aL038b<P1VIVH0I6AT02DU9@1BDU80UIFE08n?
S`0g=cL0CTi>065QH@0/;2`0FEUI06MWI`1@D500H61P05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0KFe]07moO`1SHf<0CTi>092@T01eMGD0CDe=01TI6@13@d<0IFEU08B4Q00n?Sh0Cdm?01PH
601QHF40RHV905EEE@1>CTh0Hf=S06e]K@19BDT0Ogmo08f=S@1ADE40=cLg04A4A01UIFD0<30`03dm
?@1iNGT0;Bd]07MgM`1kNg/0Cdm?04M7A`25QHD0GEeM05IFEP2@T900FEUI0:^[Z`2PX:00L71`02DU
9@0o?cl0IfMW02/[:`0N7Qh0?Shn0080=3@d0200N7Qh0820P01NGUh0JVYZ0:j^[P0e=CD0:RXZ07=c
L`1/K6`0<c<c0;2`/01MGEd0?3`l07alO01iNGT0UIFE08b<S029RHT0R8R80=3@d02IVIT0@41009^K
V`2][Jd0ADE502LW9`10@400LG5a055AD@0i>CT0Ph>30820P1cooooo0100C4a<0;bl_02UYJD0IFEU
071`L01[Jf/0CDe=03hn?P0/;2`09BDU038b<P1@D500DU9B03Hf=P0Q8B405aLG0P0E5AD0>@0H61P0
GemO0;Ng]`2TY:@0YJFU0:^[Z`2=SHd0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1ZJVX0
FEUI05ADE01;Bd/0C4a<051@D01FEUH0CTi>03Xj>P0U9BD04Q8B04];B`1@D500?Cdm02`/;00U9BD0
61PH01DE5@0V9RH0IVIV02l_;`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B405ADE01<C4`0D51@0
5ADE01LG5`24Q8@0DE5A08J6QP2OWil0EUIF0;2`/01TI6@05ADE01@D500301DE5@804a<C02l05aLG
03Ti>@1gMgL0;Rh^02d];@15ADD0F5QH07IfMP22PX80/[:b0<k>cP2m_Kd0Rh^;051@D01KFe/0Bd];
020P800Y:BT0820P01TI6@0V9RH0=SHf03/k>`1kNg/0LW9b07moO`2=SHd0/;2`0;Ng]`2IVIT0MGEe
05ADE01=CDd0BTY:03Hf=P1?Cdl0EUIF06UYJ@1gMgL0UYJF0<71`@2QXJ40T92@0:FUY@31`L406a/K
01@D500301DE5@0B00h>3P0A4A404a<C01<C4`0E5AD0ATI605mOG`0_;bl0YjNW08j>SP2EUID0Kfm_
07MgM`24Q8@0U9BD0;jn_P2_[jl0:b/[1@0E5AD0:`0D51@05ADE01HF5P0M7Ad09BDU061PH01]KFd0
C4a<03dm?@0o?cl0V9RH0<G5a@2MWId0TY:B08j>SP0b<S807AdM01TI6@0N7Qh0?Cdm05ADE01/K6`0
XZ:R0<30`02YZJT0>3Ph02PX:00O7al08b<S02@T900Z:RX0?Cdm06IVIP2BTY80H61P07UiN@1lO7`0
WIfM04i>CP1:BTX0UIFE0=?Cd`3QhN400P3Zj^X0G03YjNT0mOGe0?3`l03`l?00i^KV09jNWP2=SHd0
TI6A028R8P0L71`08B4Q034a<@0e=CD0Y:BT0492@P0W9bL09BDU02TY:@0W9bL0<30`05EEE@0`<300
CTi>065QH@1KFe/0O7al05EEE@1:BTX0ATI607alO02a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0
XJ6Q08N7Q`1]KFd0/K6a08b<S026QXH09BDU01LG5`0O7al09bLW03lo?`1VIVH08B4Q01dM7@0L71`0
6ATI01`L700O7al0J6QX08>3P`1BDU809RHV055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7A`1ZJVX0
7QhN01`L700N7Qh07AdM028R8P0k>c/0FEUI04=3@`1[Jf/0X:2P0451@@0^;Rh0<c<c0492@P1TI6@0
W9bL0:j^[P2MWId0G5aL06IVIP26QXH0CDe=01/K6`0E5AD07alO4Oooool000oooooo00@0YjNW04];
B`22PX80@D510P1aLG40M036a/H0Cdm?05MGE`1>CTh0QHF504a<C00k>c/0De=C02h^;P0a<C40=3@d
04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0N7Qh08b<S02/[:`0_;bl0I6AT03hn?P0P8200;bl_
02h^;P0k>c/0>3Ph01dM7@10@400FEUI03Hf=P0Y:BT0D51@02DU9@0d=3@0DE5A04a<C01PH600A4A4
03@d=01;Bd/0MgMg03lo?`1:BTX0A4A406i^KP1dM7@0?clo030`<01>CTh0E5AD04M7A`0d=3@0HV9R
05=CD`1=CDd0Cdm?02<S8`0L71`0MgMg055AD@0W9bL0;2`/03lo?`0^;Rh0Fe]K03Xj>P1ADE40E5AD
020P801BDU80EUIF02DU9@1CDe<0BDU903Xj>P1kNg/0K6a/03`l?01fMWH0Vi^K075aL@1fMWH0FEUI
03`l?032`/80aLG508V9R@0l?3`0H61P08R8R01;Bd/0RXZ:0<_;b`1OGel0F5QH06ATI01CDe<0UiNG
05UIF@2>SXh0HF5Q06YZJP1:BTX0@T9206UYJ@2@T900CTi>0::RXP1]KFd0H61P09:BTP1?Cdl0NGUi
0P1FEUH0YP25QHD0A4A404=3@`1kNg/0ATI606i^KP1CDe<0QXJ605aLG01GEeL0Jf][055AD@20P800
@d=303Hf=P28R8P0Fe]K05=CD`2IVIT0Cdm?04a<C025QHD0Bd];03Ph>01EEED0HF5Q04a<C01EEED0
DE5A024Q8@0n?Sh0IfMW03Xj>P2:RXX0Hf=S069RHP25QHD0<S8b07alO00U9BD0:2PX05ADE01lO7`0
M7Ad06IVIP2TY:@0NGUi03Ti>@1EEED0`l?307AdM01ZJVX0XJ6Q08^;R`1cLg<0Z:RX065QH@2BTY80
[:b/07AdM00O7al0?3`l03hn?P0O7al0E5AD04a<C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0
?3`l06=SH`1eMGD0BTY:071`L01VIVH0=3@d08f=S@1@D5009bLW05IFEP1PH600=CDe03hn?P28R8P0
SXj>07QhN018B4P0K6a/05iNGP1PH600EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0
<30`055AD@1hN7P0@D5104U9B@1HF5P0Ogmo034a<@0Q8B40DE5A04=3@`2?Shl0Vi^K04a<C00[:b/0
JFUY08:2PP1IFET0[jn_055AD@1RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P14A4@0
9RHV05iNGP2CTi<0N7Qh06a/K02i^KT0PH610451@@1_Kfl0H61P02/[:`2m_Kd0Kfm_03Lg=`1PH600
IFEU08F5Q@2:RXX0T92@06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe05IFEP0Y:BT0
CDe=0:2PX027QhLLooooo`0806m_K`2DU9@0De=C04];B`1:BTX0;Bd]02<S8`0c<c<20492@P0a03@d
=00i>CT0P82005EEE@0J6QX04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6AP15ADD0WYjN0<71
`@2GUiL0d];B08f=S@1EEED0Z:RX0::RXP2/[:`0MWIf02/[:`0c<c<0>c/k04I6AP1@D500BDU904M7
A`12@T80GUiN05UIF@2>SXh0ATI602<S8`0V9RH0:RXZ01PH600L71`0JVYZ05UIF@0P82007AdM079b
LP0`<3005aLG01DE5@0201@D500=01DE5@0C4a<05ADE01@D500_;bl0];Bd065QH@1HF5P0X:2P06][
J`1aLG40Fe]K01LG5`0201DE5@0701LG5`0I6AT08B4Q03Hf=P1cLg<0W9bL05QHF00201DE5@0Z01/K
6`0[:b/0@T9207EeM@36a/H0P82007QhN02QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph
>01@D500Fe]K05iNGP21PH40Q8B40:f][@2n_[h0`L7108b<S00b<S80=CDe05=CD`1]KFd0D51@04a<
C01IFET0TY:B09FEU@2@T900UYJF092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05@0D51@04A4A
010@400C4a<04A4A01DE5@1ADE40d=3@09bLW03GemL0`/;20::RXP0g=cL0:b/[03Xj>P1^KVh0]kNg
09RHV01:BTX0:BTY01LG5`0301DE5@0=01@D500E5AD061PH01dM7@0/;2`0N7Qh05EEE@1?Cdl0Bd];
05iNGP2OWil0YZJV03`l?00206][J`0301/K6`0J6QX05QHF00806QXJ05d0F5QH05mOG`1XJ6P0];Bd
096AT@1VIVH0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0RXZ:04I6AP1/K6`0FUYJ
05mOG`2HV9P0cLg=0=oOg`3oool0mOGe0?3`l03Zj^X0l_;b0<c<c02_[jl0QHF507moO`1]KFd07QhN
01TI6@0M7Ad0;2`/0492@P2MWId0=CDe02@T900[:b/0:2PX02TY:@10@4008b<S01hN7P0V9RH0RHV9
0<S8b02][Jd0PH6107AdM01oOgl0QHF50;no_`36a/H0dm?C08n?S`1]KFd0@D51061PH01DE5@0=cLg
075aL@1fMWH0/[:b0861P@2CTi<0=CDe01LG5`0O7al0:2PX06IVIP0];Bd09RHV02/[:`0U9BD0>CTi
05UIF@2YZJT0W9bL06=SH`1eMGD0Fe]K08n?S`2n_[h0Hf=S05EEE@1TI6@0ADE5069RHP0U9BD00P0M
7Ad05P0O7al0BTY:04m?C`0a<C40?3`l09BDU02n_[h0CTi>03@d=012@T80E5AD09fMW@2[Zj/0^;Rh
061PH01:BTX0Bd];04m?C`1cLg<0MGEe03<c<`0L71`Aooooo`003oooool06P2`/;00CTi>06YZJP0k
>c/0Lg=c06YZJP38b<P0EeMG06i^KP1KFe/0RXZ:05MGE`0g=cL0Bd];034a<@16ATH0>SXj05UIF@0`
<30092@T04A4A00Y:BT0Kfm_05=CD`0X:2P0=SHf0P0h>3P0o`1RHV80?Shn02<S8`15ADD0=3@d03Ti
>@0f=SH08R8R04a<C01PH600=cLg02PX:01KFe/0:RXZ03lo?`1ADE40D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0JFUY07moO`1>CTh0;2`/051@D01EEED0Bd];02l_;`1VIVH0K6a/065Q
H@1SHf<0=cLg01`L7020P800L71`02/[:`0d=3@0De=C03hn?P1JFUX0;Bd]06a/K01`L7008B4Q04A4
A01MGEd0;bl_071`L01LG5`0>c/k07MgM`0V9RH0:RXZ08F5Q@2IVIT0GemO08:2PP17AdL07QhN07al
O01jNWX0JVYZ03Hf=P1EEED0KFe]038b<P1ADE40W9bL04m?C`1DE5@0ADE503@d=01XJ6P0CTi>08N7
Q`0V9RH0?Shn05=CD`0i>CT0H61P06YZJP18B4P0Shn?061PH01JFUX0Rh^;034a<@1KFe/0Bd];05UI
F@1cLg<0=SHf02`/;01IFET0?Shn06=SH`0j>SX0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b
<P28R8P0GEeM02h^;P1VIVH0ATI604m?C`2HV9P0M7Ad05eMG@2;Rh/0Jf][05=CD`1SHf<0Lg=c030`
<018B4P0EEEE03dm?@2:RXX0Ph>3059BDP1dM7@0;2`/06][J`1QHF40@41006EUI@1TI6@0MgMg06][
J`2XZ:P0Ng]k03`l?016ATH0^[Zj07EeM@1oOgl0_[jn0:BTY01eMGD0[:b/051@D01oOgl0SHf=06m_
K`0Y:BT0CDe=05]KF`0[:b/0IfMW05UIF@21PH40=SHf05EEE@26QXH0De=C02/[:`1IFET0?Cdm05MG
E`1aLG40CDe=07YjNP1QHF409BDU059BDP1>CTh0:RXZ055AD@1JFUX0GUiN04Y:BP2DU9@0Kfm_07Ad
M01ADE40XJ6Q075aL@1QHF40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80Cdm?051@
D018B4P09bLW03<c<`14A4@0L71`05aLG00Z:RX0GUiN02`/;01eMGD0OWin06m_K`0f=SH0JFUY06][
J`15ADD0RHV906i^KP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX08B4Q04U9B@0n?Sh0:2PX05UI
F@2DU9@0B4Q80451@@2OWil0H61P0410@01XJ6P0?3`l02PX:02NWYh0OWin04=3@`21PH40L71`07=c
L`2EUID0TI6A061PH03@d=00K6a/04I6AP1iNGT0YJFU04U9B@001`1BDU80JFUY05iNGP0Z:RX0<c<c
0861P@26QXH07?ooool04P2VYZH0I6AT05=CD`1?Cdl0@D5102/[:`0V9RH0:2PX02HV9P0R8R80>3Ph
06ATI02EUID0RXZ:03Hf=P0W9bL0C4a<05UIF@80CDe=03H0<S8b02XZ:P0V9RH08B4Q05UIF@0^;Rh0
5ADE02PX:02DU9@0_;bl07AdM02HV9P0ZJVY09jNWP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0
BTY:04Q8B01YJFT0];Bd07AdM01KFe/0E5AD06QXJ01@D500I6AT07inOP0d=3@0>3Ph055AD@26QXH0
ATI601HF5P0E5AD0410@018B4P0@41004Q8B01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0
VYZJ0:JVYP1`L70207MgM`0S07UiN@2<S8`0WIfM0;bl_03?cll0g=cL04e=C@0G5aL04A4A01LG5`1F
EUH0Ph>308b<S02h^;P0WIfM04Y:BP1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=CD`1:
BTX071`L01DE5@0G5aL0R8R80;Jf]P31`L40V9RH07EeM@1EEED00P1BDU808P0o?cl0=SHf02l_;`0R
8R808b<S02HV9P0X:2P0SHf=092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D500E5AD04a<C00l?3`0@
41004A4A01DE5@0e=CD0G5aL03lo?`1kNg/0e=CD0=;BdP38b<P0QXJ60451@@1FEUH0V9RH0<O7a`2W
YjL204E5A@0303De=@0Z:RX07AdM00@05ADE00`08B4Q03<c<`1aLG40EeMG065QH@20P800Ng]k0:ZZ
ZP2NWYh0K6a/03/k>`0E5AD201XJ6P1G01HF5P0G5aL08b<S05MGE`1@D500@d=30:2PX01dM7@0SHf=
03De=@0S8b<0<30`059BDP1IFET0@T9203/k>`0h>3P0=CDe05iNGP0[:b/0B4Q808j>SP2:RXX0R8R8
0<C4a03De=@0bLW90<G5a@38b<P0clo?0=?Cd`2?Shl0Ogmo04Q8B025QHD0MWIf02<S8`0I6AT092@T
03Ph>01IFET0T92@03`l?00Z:RX0:BTY02h^;P0/;2`0?Cdm01dM7@0N7Qh08R8R04e=C@2HV9P0D51@
03lo?`0n?Sh0FUYJ055AD@1ZJVX0ZZZZ0;Ng]`0c<c<0820P04M7A`1[Jf/0@41002LW9`1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@1LG5`0Jf][07]kN`2BTY80Ogmo06QXJ02SXj<0V9RH
0::RXP1[Jf/0UYJF0080YjNW01l0W9bL038b<P1XJ6P0JFUY0451@@1OGel0>CTi01/K6`0O7al0B4Q8
04e=C@0n?Sh0ADE508J6QP1_Kfl0Ti>C06][J`1/K6`0];Bd0<O7a`30`<00b/[:0;jn_P1fMWH0KFe]
059BDP1TI6@0>SXj04];B`1hN7P0Rh^;017ooooo000?ooooo`0X0:RXZ01BDU80FEUI02/[:`1?Cdl0
De=C09^KV`0];Bd0EEEE06][J`1cLg<0Bd];034a<@0h>3P0;Rh^05MGE`0i>CT0DE5A024Q8@0o?cl0
JFUY03Ti>@1]KFd0EUIF02l_;`1OGel0?clo0451@@1WIfL05aLG02DU9@1JFUX0@d=303<c<`0T92@0
;Rh^05mOG`1RHV80:b/[0410@080<C4a0?@0=SHf03<c<`0W9bL0GEeM07=cL`0V9RH0@41005YJFP0/
;2`0JVYZ03dm?@1MGEd0E5AD034a<@16ATH0M7Ad05aLG019BDT09bLW05mOG`0[:b/0GemO07YjNP0m
?Cd06a/K07AdM00n?Sh0?Cdm05iNGP1TI6@0@d=305QHF00Q8B40IVIV06m_K`0U9BD0?3`l04E5A@0P
8200AdM704m?C`17AdL0N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06IVIP10@400R8R808N7Q`1T
I6@0;Rh^059BDP1SHf<0DU9B08j>SP2i^KT0=3@d05EEE@1VIVH0CTi>05YJFP15ADD0SHf=04];B`18
B4P0BTY:02d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0ATI605MGE`1=CDd0Kfm_09BDU01Q
HF40?3`l061PH00l?3`0MGEe05=CD`1VIVH0A4A406YZJP24Q8@0HV9R06][J`12@T80>3Ph08B4Q01T
I6@0>CTi092@T01>CTh0@T9207QhN01TI6@0E5AD0:2PX01BDU80IFEU07inOP1mOGd0=cLg04a<C01=
CDd0@T9208b<S029RHT0FUYJ08J6QP0a<C40KFe]07QhN013@d<0GEeM05aLG01KFe/0JVYZ09fMW@1/
K6`0>SXj03hn?P2f][H0>CTi05IFEP2HV9P0P82006][J`2`/;00NGUi0861P@2IVIT0Rh^;02XZ:P1=
CDd0JFUY028R8P1UIFD0C4a<08j>SP0a<C40BTY:06a/K01FEUH0:b/[05iNGP1LG5`0IVIV07IfMP17
AdL0I6AT07alO00g=cL0KFe]05iNGP0U9BD0EEEE05YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_
[jl0P82007AdM00^;Rh0EUIF04a<C01UIFD0KVi^06QXJ00f=SH0DE5A09FEU@1KFe/0DE5A05eMG@15
ADD0:b/[0492@P1gMgL0@d=302TY:@1]KFd0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2F
UYH0GUiN09JFUP1nOWh0MWIf03Ti>@13@d<0Jf][051@D00c<c<0J6QX04M7A`0g=cL0Ng]k09fMW@1]
KFd0DE5A0:NWY`0Z:RX0=CDe08V9R@1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T9207emO@1l
O7`0QhN70<O7a`2<S8`0@d=307emO@2GUiL0@T9202DU9@0k>c/0G5aL0P0g=cL00`2JVYX0LW9boooo
o`0Kooooo`0I0::RXP1;Bd/0ADE505MGE`16ATH09BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0UiNG07YjNP1FEUH0@D5103@d=00f=SH0:BTY02HV9P0W9bL07QhN04Y:BP0301<C4`0K01TI
6@19BDT0_;bl0:>SX`28R8P0UIFE09ZJVP0k>c/07alO01`L700O7al08R8R02d];@0b<S80=cLg07Ee
M@1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@17AdL08R8R00807AdM02d05QHF01@D
500D51@05ADE01<C4`0I6AT0GEeM06=SH`0Y:BT07QhN05=CD`1?Cdl0Shn?0=GEe@2b/[80MGEe05UI
F@1DE5@0IFEU06][J`1SHf<0NWYj0:n_[`36a/H0d];B09JFUP0R8R8051@D01DE5@0R8R80?3`l08N7
Q`3AdM40hn?S08N7Q`2EUID0Ti>C04M7A`1DE5@0JVYZ0:RXZ02@T900EEEE028R8P0D51@00`0E5AD0
601SHf<0EUIF08b<S01cLg<0UiNG071`L015ADD0<c<c02l_;`0];Bd0:BTY02@T900O7al08b<S04e=
C@2=SHd0TI6A05UIF@1MGEd0CDe=08F5Q@14A4@05ADE014A4@<04a<C01006QXJ04U9B@1=CDd0:2PX
05aLG02d];@0TY:B0;Vi^@3=cLd0XZ:R0;^k^`3@d=00`L7109JFUP1^KVh0E5AD0P0j>SX04@0];Bd0
=3@d04=3@`0k>c/09RHV01@D500Q8B40DU9B0861P@1OGel0R8R809:BTP1RHV80`L7105UIF@1`L700
8b<S00805ADE00l051@D01HF5P0G5aL06a/K04=3@`1GEeL0AdM708n?S`1dM7@0J6QX0:FUY@0n?Sh0
EeMG0451@@0U9BD00P0G5aL09P0F5QH05aLG05ADE015ADD0C4a<08J6QP28R8P0][Jf09bLW039bLT0
UYJF07MgM`2EUID0SHf=08B4Q02EUID0[:b/07AdM02i^KT0/k>c04];B`0R8R808B4Q02XZ:P1nOWh0
GEeM04E5A@0c<c<092@T02HV9P0n?Sh0=SHf01hN7P0M7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40@00/
;2`0?Cdm0410@01cLg<0K6a/01`L700S8b<0IFEU03@d=00T92@08b<S030`<01WIfL0SHf=0861P@1b
LW80G5aL0:f][@1nOWh0;Bd]06][J`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02Y
ZJT0emOG0=?Cd`1WIfL0=SHf071`L01CDe<0<S8b05YJFP1:BTX0820P04a<C01=CDd0>SXj04E5A@2D
U9@0H61P02l_;`27QhL0SXj>08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU04i>CP1T
I6@0Cdm?04];B`1WIfLAooooo`003oooool05P2FUYH0DE5A071`L00o?cl0EEEE059BDP2VYZH0GemO
04i>CP1HF5P0LG5a04];B`0e=CD0>SXj01XJ6P10@400<C4a04a<C00I6AT05QHF0492@P0N7Qh206EU
I@0C02HV9P15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^03De=@17AdL071`L03/k>`0m?Cd0
6a/K04];B`19BDT08R8R02TY:@0203De=@0i051@D01FEUH071`L03Lg=`1XJ6P0?Shn06YZJP17AdL0
F5QH06UYJ@0c<c<0:2PX03Xj>P1:BTX0>SXj03De=@1WIfL0BDU905iNGP1=CDd092@T01XJ6P1QHF40
@T9202h^;P0Z:RX0ATI603Ti>@1RHV80;Bd]04a<C01EEED09bLW03hn?P1LG5`0<c<c06EUI@12@T80
?Shn06i^KP1PH600@d=306e]K@20P800?Cdm0861P@1QHF40?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0
L71`05YJFP2FUYH0`<300080?clo06/0Kfm_04e=C@1CDe<0?clo06EUI@1IFET0A4A4059BDP0_;bl0
MgMg08j>SP1>CTh0Q8B404a<C01ADE40VIVI05MGE`1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0
AdM707inOP1DE5@0Ogmo05UIF@1DE5@0PX:206QXJ01nOWh0CTi>02XZ:P1iNGT0@d=303@d=02DU9@0
FEUI0492@P27QhL0Ng]k05eMG@2d];@0GUiN04];B`1JFUX0Fe]K03<c<`11@D40BDU9034a<@2@T900
RXZ:05]KF`1QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2?Shl0@D5104Q8B023Ph<0
c<c<07UiN@1PH600UiNG08>3P`1_Kfl0^KVi07QhN01jNWX0W9bL09^KV`0c<c<0Cdm?07AdM00M7Ad0
IFEU04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^05eMG@1jNWX0<c<c06m_K`20P800
<S8b071`L01YJFT0:RXZ06e]K@1kNg/0L71`04Q8B00205eMG@1=07MgM`0m?Cd0LW9b06YZJP1YJFT0
<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40Bd];079bLP25QHD0De=C02h^;P17AdL0
OWin06ATI00`<300IVIV03Lg=`1^KVh0U9BD055AD@11@D40P82005IFEP1ADE40SXj>05=CD`2OWil0
R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5A@0T92@08b<S05iNGP2OWil0IFEU05YJFP2m_Kd0
@d=302DU9@1DE5@0BTY:05MGE`3Bd]80Y:BT03/k>`14A4@0IVIV06=SH`28R8P0JFUY03/k>`2GUiL0
CDe=0410@02OWil0UiNG05aLG00V9RH0=SHf05EEE@11@D40Ng]k0;Jf]P1gMgL07?ooool06`3:b/X0
X:2P092@T02>SXh0E5AD03Xj>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109nOW`0l?3`0
9RHV02PX:00o?cl0>SXj02/[:`0Y:BT06a/K01HF5P15ADD0410@014A4@0201DE5@0:01HF5P1@D500
TY:B0;6a/@2GUiL0V9RH0:JVYP1WIfL0?Cdm030`<080;Bd]0180:BTY038b<P2OWil0J6QX08:2PP1d
M7@0U9BD0;Jf]P1nOWh0Fe]K07emO@2DU9@0Xj>S08J6QP1VIVH0?3`l03De=@0L71`301DE5@0=04i>
CP1QHF4092@T01HF5P0E5AD0820P09fMW@2VYZH0]KFe0;:b/P2PX:00Ph>307alO00307QhN00G09^K
V`36a/H0_kno07]kN`2OWil0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`0>?Sh`3MgMd0`<300:RX
Z01OGel0Fe]K0451@@13@d<0KFe]02HV9P0D51@00`0E5AD0200R8R80Lg=c0410@01`L700A4A404];
B`0W9bL09BDU0P0Z:RX0=@0`<300>c/k038b<P13@d<0IFEU05YJFP1VIVH0DE5A05QHF01EEED0LW9b
06QXJ02JVYX0;Bd]01TI6@0E5AD04A4A03Hf=P15ADD0>CTi02<S8`15ADD0UIFE05EEE@1BDU80^[Zj
0<g=c@2/[:`0UiNG0<[:bP1eMGD0<30`01/K6`0O7al0>CTi04Q8B00Y:BT071`L01/K6`0Q8B40:b/[
03Ti>@1TI6@0/[:b0:VYZ@2<S8`0U9BD07UiN@1UIFD0Y:BT06=SH`1@D5005ADE008051@D00h0410@
01<C4`0H61P071`L028R8P1OGel0C4a<09bLW02[Zj/0AdM7075aL@2a/K40;bl_01DE5@804a<C0`0E
5AD0IP1KFe/0<C4a02TY:@1OGel0TY:B0;:b/P2GUiL0b<S8096AT@1eMGD0MgMg04A4A00m?Cd0FEUI
0:f][@3:b/X0dM7A0:^[Z`23Ph<0MWIf02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
02XZ:P0M7Ad06a/K02<S8`1KFe/0NGUi03Lg=`0];Bd06QXJ01PH601CDe<0;Bd]07AdM013@d<08R8R
03lo?`13@d<08R8R01lO7`0S8b<09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:0:>SX`2o_kl0TY:B
0;fm_@2YZJT0XJ6Q06IVIP0/;2`08B4Q02XZ:P0l?3`0E5AD0<;2`P3QhN40c<c<03hn?P0j>SX0TY:B
04Q8B00[:b/0AdM705QHF01NGUh0Bd];03De=@1KFe/0QhN705UIF@27QhL0Ti>C06MWI`2CTi<0MGEe
08V9R@2^[Zh0e=CD0;Vi^@2o_kl0@D5103Ti>@0S8b<08R8R0861P@2WYjL0YJFU0;bl_17ooooo000?
ooooo`3T0:j^[P1FEUH0NGUi0492@P1>CTh0?Shn06IVIP1FEUH0FUYJ06UYJ@1nOWh0ATI604=3@`1T
I6@0>3Ph05ADE00c<c<0E5AD02PX:00S8b<0>CTi01TI6@1QHF40Fe]K02PX:00h>3P09bLW03dm?@1L
G5`0BDU901`L700c<c<08B4Q04M7A`1:BTX08b<S0410@00n?Sh05ADE04Y:BP1>CTh09RHV02LW9`19
BDT0?Shn05mOG`19BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0HV9R07QhN01:BTX0;2`/04U9B@1N
GUh0Cdm?01TI6@1:BTX0De=C07MgM`1BDU806a/K01TI6@1YJFT0E5AD03Hf=P0b<S80@D5103De=@1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01:BTX092@T06IVIP1gMgL0E5AD06][J`2R
XZ80Hf=S09VIV@1EEED0;Rh^06IVIP2EUID0KFe]02@T9010@400GemO065QH@2<S8`0`<3005IFEP12
@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI605YJFP0^;Rh0F5QH08j>SP1GEeL0QXJ606=SH`13
@d<0QHF505iNGP1bLW80CTi>05aLG01kNg/0IFEU03lo?`1NGUh0@d=307QhN01BDU80U9BD05MGE`1?
Cdl0QHF504I6AP1oOgl0EEEE03Xj>P1dM7@0EEEE04I6AP2MWId0G5aL0492@P2:RXX0FUYJ04=3@`2S
Xj<0Jf][04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti>@1`L700Rh^;05iNGP1_Kfl0=CDe06][J`18
B4P0<S8b0451@@1;Bd/0HV9R06QXJ02WYjL0De=C034a<@19BDT0WinO07MgM`1PH600S8b<09VIV@2:
RXX0d=3@07AdM01XJ6P0V9RH0:2PX011@D40NWYj071`L00O7al0EUIF069RHP2OWil0>c/k055AD@1Z
JVX0E5AD02h^;P1LG5`0H61P06=SH`1lO7`0C4a<06MWI`26QXH0;Rh^09JFUP1aLG40=CDe06IVIP1g
MgL0JVYZ04M7A`2YZJT0P82006m_K`1:BTX0T92@06EUI@1XJ6P0C4a<07UiN@1OGel0D51@05iNGP0]
;Bd0ADE506m_K`2?Shl0CTi>0P1LG5`0?00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@1EEED08R8R07Ad
M02GUiL0N7Qh03Lg=`1/K6`0C4a<04i>CP2?Shl0O7al09BDU027QhL0<c<c01/K6`0g=cL0J6QX05aL
G00L71`0Bd];03Xj>P0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe05UIF@1VIVH0=3@d09nO
W`23Ph<0Cdm?06m_K`1`L700KVi^0:6QX@25QHD0@T9209FEU@16ATH0;bl_075aL@2>SXh0D51@02HV
9P0c<c<0D51@024Q8@0h>3P0KFe]06=SHacooooo01@0d];B0=3@d02_[jl0QhN705UIF@1?Cdl0@D51
02`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`24Q8@0B4Q804I6AP12@T80EUIF03hn?P80?Cdm00<0
7QhN024Q8@16ATH00P0A4A401P0E5AD04a<C01<C4`0f=SH0>c/k05iNGP80XZ:R01d0_;bl0=WIf@2f
][H0X:2P09NGU`2SXj<0^KVi0=KFeP3GemL0][Jf08R8R02OWil0]kNg09nOW`2TY:@0WIfM07IfMP12
@T80>SXj055AD@1cLg<0VIVI09nOW`22PX80F5QH03Xj>P1PH600BTY:02@T900201DE5@0B01LG5`0_
;bl0V9RH0:j^[P2FUYH0S8b<06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1J
FUX0GemO0P1_Kfl02`1ADE40CDe=09fMW@3?cll0f][J0=oOg`1lO7`0De=C06QXJ024Q8@0U9BD0080
QXJ600d0G5aL04a<C018B4P0Bd];04e=C@2<S8`0/[:b06=SH`1_Kfl0ADE504Y:BP0E5AD061PH0080
5ADE02@05aLG02PX:01iNGT0QHF505]KF`0e=CD0=3@d01LG5`0J6QX0A4A403/k>`1[Jf/0YZJV0:BT
Y01KFe/0A4A403Xj>P0e=CD0:2PX02DU9@12@T80SHf=04a<C01?Cdl0CTi>0:f][@2j^[X0/;2`0;Jf
]P2m_Kd0J6QX01/K6`0G5aL06ATI01`L700Y:BT204e=C@1B03/k>`0P82007AdM030`<01RHV80Z:RX
0:f][@32`/80PH61061PH02DU9@0Y:BT04Y:BP0J6QX04Q8B01<C4`0E5AD051@D010@400A4A405aLG
01dM7@1dM7@0BDU90<g=c@2i^KT0UiNG08Z:RP23Ph<0@D5102/[:`0S8b<07alO024Q8@0];Bd0DE5A
0:n_[`1YJFT0?Cdm06=SH`16ATH0Ng]k06EUI@2YZJT0T92@04M7A`0l?3`0Fe]K08j>SP37alL0bl_;
0:2PX02GUiL0@T9204a<C02FUYH0]KFe0:BTY02FUYH0;2`/01lO7`0L71`0;bl_07EeM@2RXZ80>CTi
01lO7`0M7Ad0:b/[069RHP1ZJVX0<S8b01lO7`0b<S80IVIV08R8R01iNGT0MWIf03/k>`0G5aL0@d=3
028R8P808B4Q00l092@T024Q8@0/;2`0EUIF08n?S`1TI6@0YjNW0:JVYP1[Jf/0W9bL0<S8b02b/[80
[Zj^07=cL`1TI6@00P15ADD09@18B4P0?Shn0492@P2CTi<0gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0
Kfm_04E5A@21PH40TI6A08>3P`2VYZH0eMGE08j>SP25QHD0D51@02l_;`0L71`0HF5Q0:2PX02][Jd0
[Zj^09jNWP2TY:@0EeMG04];B`1@D500@d=3069RHP2CTi<0WIfM0<[:bP3Cdm<04Oooool000oooooo
0;@0Zj^[05EEE@1VIVH0?clo05eMG@14A4@0Kfm_07IfMP1@D500OGem08V9R@1@D500=3@d061PH00i
>CT0CTi>02/[:`1FEUH0:BTY02DU9@13@d<07QhN065QH@1]KFd0=3@d04Q8B00V9RH0;Rh^05ADE00c
<c<08R8R03dm?@0V9RH0>CTi03dm?@0P8200@d=305IFEP0O7al0DU9B065QH@0S8b<0@D5104A4A00f
=SH0MgMg06e]K@0W9bL0;2`/05iNGP0m?Cd0Fe]K05eMG@1=CDd0K6a/04M7A`0d=3@0H61P05aLG01H
F5P07QhN059BDP1CDe<0Kfm_06MWI`16ATH05QHF06i^KP1_Kfl0?3`l04E5A@1YJFT0Bd];0861P@0c
<c<0@41004e=C@0^;Rh0=3@d05UIF@0X:2P0IFEU06MWI`0[:b/0L71`061PH012@T80Ng]k09VIV@1J
FUX0W9bL07inOP1ADE40BTY:0:JVYP1>CTh0=SHf065QH@1jNWX0FEUI06=SH`2h^;P0BDU904e=C@26
QXH0Bd];06YZJP0d=3@0QHF505]KF`10@400GUiN03Hf=P1]KFd0Q8B404Y:BP25QHD0?3`l03Hf=P2:
RXX0F5QH05iNGP0f=SH0G5aL09>CT`1`L700Bd];071`L00c<c<0LW9b05QHF01lO7`0Hf=S05=CD`2M
WId0KFe]07]kN`13@d<0;Bd]07QhN01TI6@0=3@d08Z:RP1;Bd/0?Cdm092@T01mOGd0@d=30<;2`P1W
IfL0FUYJ07moO`1JFUX0?Cdm04U9B@1EEED0?clo07UiN@29RHT0GUiN079bLP0i>CT0Q8B408:2PP1I
FET0E5AD07MgM`11@D40F5QH09RHV01EEED0=3@d04a<C02FUYH0F5QH05UIF@2ATI40U9BD06e]K@2h
^;P205aLG003096AT@2IVIT0>c/k0080FEUI06L0;bl_05aLG013@d<0Q8B402LW9`1;Bd/0MGEe06m_
K`0_;bl0KVi^04];B`1ADE40UiNG05MGE`1OGel0RHV902TY:@1ZJVX0MWIf03/k>`1hN7P0PX:205IF
EP0d=3@0L71`06UYJ@1aLG40@T9208Z:RP1MGEd0GUiN02`/;01YJFT0Jf][05YJFP1eMGD0HV9R03@d
=016ATH0OGem04Q8B01VIVH0M7Ad0492@P0U9BD0?Shn07EeM@1JFUX0@T9206e]K@0`<300GEeM08n?
S`1iNGT0>CTi07IfMP1DE5@0BDU907]kN`1[Jf/0Xj>S08Z:RP1cLg<0<c<c04=3@`1bLW80I6AT024Q
8@1UIFD0E5AD02/[:`1PH600Ti>C06][J`1JFUX0`/;208>3P`0g=cL0DU9B07EeM@0k>c/0Lg=c0;>c
/`1MGEd0KVi^079bLP1`L700Q8B4079bLP0m?Cd0PH6106IVIP0m?Cd0T92@096AT@12@T809BDU03Ph
>01VIVH0>SXj03hn?P2m_Kd0Rh^;01cooooo05T0Ph>307EeM@1`L700VIVI079bLP1SHf<0EUIF05UI
F@1SHf<0IFEU05aLG01RHV80OWin09bLW02b/[80K6a/03lo?`0d=3@0ADE503/k>`0h>3P0<30`034a
<@1FEUH0:b/[01<C4`0H61P08B4Q01hN7P0L71`0<c<c04M7A`0];Bd0EeMG0<o?c`3GemL0a/K60:BT
Y01mOGd0GEeM06ATI01dM7@0QHF50<g=c@3Jf]X0_[jn08F5Q@1BDU80CDe=06IVIP2OWil0QHF503/k
>`0X:2P092@T030`<016ATH0Cdm?03dm?@1<C4`0I6AT08Z:RP1=CDd0ADE503Hf=P0];Bd0>3Ph05MG
E`1ADE40?clo05QHF01iNGT0Cdm?04i>CP12@T80BDU9034a<@0U9BD08b<S02@T901?Cdl0TY:B06YZ
JP12@T80?Shn03Ti>@0m?Cd0=cLg08F5Q@020<k>cP0:092@T02KVi/0QHF506UYJ@1:BTX0E5AD04m?
C`1UIFD0Fe]K03/k>`80<c<c00T0?3`l05IFEP2<S8`0^;Rh09nOW`2MWId0MgMg030`<00G5aL00P0E
5AD0100D51@06ATI0451@@0e=CD203Ph>00;01dM7@0E5AD05aLG02LW9`1@D500;bl_06i^KP2BTY80
IVIV09bLW02@T9000P21PH407@2MWId0YJFU05YJFP1BDU80H61P09>CT`1CDe<0EUIF05eMG@2_[jl0
RXZ:06][J`1VIVH0CDe=02`/;00N7Qh071`L01hN7P0Y:BT0?3`l03Xj>P1GEeL0KVi^0861P@39bLT0
`l?30<o?c`2=SHd0RXZ:0080W9bL00D0MWIf04m?C`13@d<0:2PX01dM7@0201@D5004014A4@0@4100
6ATI05=CD`80Q8B40P1IFET205aLG01505eMG@1IFET0EUIF059BDP1DE5@0EUIF05=CD`1gMgL0Z:RX
0<K6aP2^[Zh0Ogmo04m?C`1NGUh0G5aL08J6QP1jNWX0Ph>309jNWP2ATI40LG5a06IVIP10@400EeMG
07inOP1<C4`0BTY:07UiN@37alL0YJFU08>3P`1PH600AdM703dm?@0W9bL08b<S04M7A`1UIFD0BDU9
04=3@`2:RXX0WIfM06a/K01XJ6P0CDe=03De=@0^;Rh0IVIV0;Rh^026QXH08b<S01PH600Q8B40820P
02<S8`0V9RH0>c/k0492@P0W9bL09RHV071`L02/[:`0_Kfm0:BTY02KVi/0];Bd0=7Ad@1iNGT0AdM7
0080@D5102H0A4A405UIF@1[Jf/0UYJF0:VYZ@3Bd]80Xj>S08V9R@2/[:`0V9RH0:ZZZP30`<00a/K6
0<;2`P2WYjL0YZJV07UiN@0c<c<0;Rh^03`l?01CDe<0KVi^06UYJ@1VIVH0Zj^[0:BTY02RXZ80/;2`
0;jn_P2DU9@0IfMW07=cL`1]KFd0Rh^;092@T01jNWX0GEeM05MGEa7ooooo000?ooooo`3o08Z:RP15
ADD0M7Ad04Y:BP15ADD0>CTi06QXJ01OGel0=SHf04E5A@1BDU80=SHf038b<P2:RXX0@D5104A4A00a
<C40OGem034a<@0d=3@0CTi>02l_;`2IVIT0QHF503Lg=`13@d<0;2`/06IVIP21PH40ADE501XJ6P0a
<C40820P059BDP0O7al09BDU05aLG01CDe<08B4Q065QH@1XJ6P07QhN038b<P12@T8071`L061PH01H
F5P09BDU05iNGP1lO7`0Bd];059BDP15ADD0G5aL07QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01V
IVH0IfMW06YZJP1>CTh0=3@d028R8P1^KVh0MgMg02h^;P0b<S80B4Q802h^;P1`L700GUiN04A4A00m
?Cd051@D02h^;P1]KFd0>CTi05aLG014A4@09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`1M
GEd0EEEE034a<@2YZJT0FEUI02DU9@0Z:RX0@41004];B`1ZJVX0/K6a04M7A`0_;bl0EEEE0492@P1A
DE40=SHf05UIF@1ADE40>CTi05UIF@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_05iNGP1R
HV80EeMG0451@@26QXH0OGem04a<C01MGEd0?Shn06EUI@1LG5`0Hf=S05aLG01JFUX0UiNG06i^KP1o
Ogl0D51@03Ph>01cLg<0BTY:0410@02YZJT0DU9B03De=@1jNWX0Kfm_05MGE`3;bl/0GUiN030`<018
B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:205QHF01VIVH0<C4a08R8R01iNGT0>CTi05EEE@1Q
HF40HV9R05EEE@2OWil0D51@03Lg=`0k>c/0QhN708Z:RP18B4P0I6AT08Z:RP1RHV80`L7107moO`1D
E5@0LG5a0861P@10@400QXJ606EUI@0X:2P0CDe=03/k>`1mOGd0<30`05=CD`1[Jf/0Kfm_02XZ:P1A
DE40BDU9079bLP2HV9P0FEUI05ADE02VYZH0BDU906IVIP1TI6@0;Bd]05]KF`1IFET0G5aL0492@P2E
UID0E5AD07=cL`0^;Rh0H61P059BDP1]KFd0>CTi05YJFP0f=SH0ADE5059BDP1?Cdl0<C4a0451@@1j
NWX0BTY:05iNGP2EUID0CTi>02/[:`16ATH0MGEe04e=C@0X:2P0IfMW03<c<`1ZJVX0OGem069RHP1D
E5@0T92@059BDP0o?cl0Jf][06IVIP2n_[h0/;2`07inOP0j>SX0Bd];06=SH`0m?Cd06QXJ000S04a<
C01GEeL0:BTY06EUI@1lO7`0D51@05ADE02n_[h0N7Qh03hn?P1]KFd0QXJ604=3@`2;Rh/0T92@05mO
G`13@d<0O7al09RHV01iNGT0MWIf069RHP2EUID0NWYj03Xj>P2DU9@0VYZJ03`l?00W9bL0BTY:06MW
I`0m?Cd0?Shn08>3P`2HV9P07?ooool06@2^[Zh0OWin05eMG@1OGel0C4a<04m?C`1iNGT0I6AT07em
O@20P800XZ:R0=[JfP2e]KD0TI6A0:NWY`1]KFd0M7Ad07inOP22PX80CDe=04E5A@19BDT0P82009BD
U00/;2`00P0c<c<03P1?Cdl0>3Ph030`<00o?cl0M7Ad03Xj>P1EEED0Ogmo08R8R035aLD0SXj>024Q
8@0B4Q806ATI0P0K6a/06@1_Kfl0_kno06ATI01;Bd/0KFe]07moO`27QhL0a<C40=7Ad@2[Zj/0KVi^
06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0EEEE069RHP23Ph<0]KFe0=kNgP2GUiL00P0a
<C40:`1fMWH0AdM7020P800G5aL071`L02HV9P0o?cl0@D5101lO7`0E5AD05aLG04M7A`1dM7@0Fe]K
04i>CP0o?cl0:2PX020P802KVi/0`/;20;^k^`0a<C40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`
09^KV`1RHV80DU9B04Y:BP17AdL0<30`02@T9025QHD0Shn?06QXJ01_Kfl0EEEE03dm?@0_;bl00P0Y
:BT01@0a<C40<30`03Lg=`0h>3P05QHF00<05ADE02L0:2PX03De=@0G5aL0=CDe0:VYZ@27QhL0S8b<
0:RXZ02ZZZX0];Bd0<71`@2/[:`0TY:B09jNWP2CTi<0U9BD01TI6@0N7Qh0FUYJ07IfMP1ZJVX07alO
02DU9@10@400MGEe07IfMP0d=3@0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0SHf=
0:j^[P0S8b<00P0O7al0OP0/;2`0:2PX03<c<`0h>3P0FUYJ05iNGP1BDU80@D5103<c<`0`<300ATI6
07]kN`0i>CT0A4A402@T900h>3P0P82006YZJP14A4@0=3@d02LW9`0];Bd0<C4a03@d=01WIfL0Ng]k
08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0IVIV06e]K@1IFET0JVYZ05mOG`1?Cdl0CTi>
05]KF`2GUiL0A4A404Y:BP2UYJD0FUYJ0;Ng]`0U9BD06ATI01DE5@0G5aL08R8R01dM7@0d=3@0MgMg
0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1UIFD0Xj>S0<k>cP2VYZH0V9RH055AD@0g=cL0:RXZ
01hN7P0[:b/0;2`/01`L700K6a/07QhN04A4A01jNWX0>CTi05IFEP2CTi<0aLG509BDU022PX807AdM
01HF5P0I6AT071`L024Q8@0S8b<0@d=306i^KP2e]KD0];Bd0:FUY@27QhL0Kfm_08f=S@2_[jl0_[jn
0=OGe`3?cll0RXZ:06EUI@1BDU80H61P06EUI@1XJ6P0PX:207=cL`25QHD0O7al0=;BdP3EeMD0]kNg
0:BTY01/K6`07alO03De=@0g=cL0EEEE03De=@0/;2`0<30`03De=A7ooooo000?ooooo`0=09>CT`1J
FUX0IFEU05QHF01RHV80?3`l04Q8B01jNWX0ADE504U9B@1;Bd/0<30`01/K6`0303Hf=P3o01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd0B4Q803lo?`0I6AT09RHV04A4A00n?Sh06a/K02`/;00A
4A40>3Ph04Q8B00M7Ad0@41004I6AP0C4a<0=cLg05IFEP0Q8B407QhN03Ph>00b<S80KFe]055AD@0L
71`08R8R04A4A00o?cl0@4100451@@0_;bl0F5QH05EEE@0a<C40CDe=06IVIP1@D5005aLG03Ti>@1R
HV80L71`04];B`18B4P03`l?04e=C@1OGel0=cLg03Hf=P1bLW80@41005UIF@0[:b/0<c<c0410@00b
<S809RHV05QHF00W9bL0DE5A04i>CP0F5QH0CTi>07]kN`0g=cL0DU9B08f=S@1_Kfl0UYJF06IVIP1J
FUX0>CTi0<71`@28R8P0=cLg03hn?P1FEUH0A4A406][J`2/[:`0E5AD03Ph>01SHf<0ATI605aLG00g
=cL0IFEU03hn?P0e=CD0GUiN02PX:01DE5@0QHF5065QH@1bLW80JFUY034a<@1hN7P0KVi^09RHV01L
G5`0Cdm?08n?S`1/K6`0ATI605iNGP0l?3`0KVi^05YJFP1cLg<0EeMG06IVIP2EUID0FEUI0820P01F
EUH0>c/k08:2PP1BDU808b<S07IfMP1JFUX0>3Ph0861P@1CDe<0=3@d07YjNP1YJFT0>SXj05iNGP13
@d<0BTY:05mOG`1aLG40@T9204=3@`1nOWh0GEeM08F5Q@1;Bd/0Q8B407AdM01WIfL0O7al0451@@17
AdL0FEUI0:BTY00j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A06][J`31`L40RHV905EEE@1Y
JFT0R8R804A4A012@T80D51@02<S8`1FEUH0CDe=09JFUP11@D40Bd];092@T01OGel0=3@d071`L01=
CDd0LW9b0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40KVi^05EEE@13@d<0:b/[08R8R01m
OGd0QHF504E5A@2NWYh0Fe]K07UiN@0f=SH0GemO08B4Q01FEUH0IVIV05YJFP0d=3@0ATI608N7Q`1F
EUH0GEeM07AdM00n?Sh09RHV0410@01gMgL0LG5a0492@P1gMgL0:BTY05MGE`1bLW80EEEE02l_;`1Q
HF40CDe=03/k>`1VIVH0B4Q809:BTP1lO7`0NWYj03@d=010@400L71`061PH00M7Ad0CTi>04Y:BP0c
<c<0PH6107EeM@1?Cdl0Bd];0;jn_P1aLG40<C4a04Y:BP1kNg/0>SXj0:f][@1dM7@0B4Q8000C03De
=@22PX80QhN706ATI01DE5@0>c/k06e]K@1/K6`0?3`l09^KV`26QXH0ATI602@T900c<c<0EeMG03<c
<`0e=CD0^;Rh08:2PP0Looooo`0e07IfMP1^KVh0L71`079bLP1lO7`0F5QH04=3@`1eMGD0PH610::R
XP2MWId0];Bd09:BTP0b<S80;Rh^08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C061P
H01QHF40Bd];0451@@17AdL0<c<c02@T900i>CT0G5aL07alO01:BTX0>c/k092@T011@D405QHF01`L
700D51@03Ph>00d=3@0B4Q80IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD00P0G5aL0
;`1:BTX0<30`028R8P0Q8B40Bd];01HF5P0G5aL0820P02LW9`0a<C40De=C0;fm_@2DU9@0;2`/03hn
?P1EEED0:b/[01TI6@0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU9@1NGUh0SHf=06i^
KP1kNg/0U9BD092@T031`L40R8R807QhN00h>3P09BDU071`L037alL0`<3008Z:RP1[Jf/0IVIV07Mg
M`0l?3`07QhN00<06ATI03T071`L02@T901UIFD0GEeM07inOP33`l<0QXJ606e]K@1ZJVX0L71`08f=
S@2?Shl0TI6A05]KF`0F5QH061PH01DE5@0G5aL08R8R030`<00G5aL0>c/k05QHF00U9BD0GUiN06=S
H`2UYJD0emOG09bLW021PH40Fe]K03De=@0^;Rh0NGUi02XZ:P0J6QX0JVYZ05iNGP1GEeL07QhN024Q
8@0M7Ad07alO03/k>`1mOGd0?clo024Q8@0L71`0;Rh^0:VYZ@1nOWh0NWYj09FEU@2ATI40NGUi0:n_
[`0P82000P0L71`03P0R8R80;Bd]02TY:@0J6QX05ADE02HV9P0_;bl0>SXj065QH@2LW9`0a<C409NG
U`0K6a/08R8R0P0S8b<05P16ATH0VYZJ08:2PP0l?3`0=CDe034a<@0g=cL0HF5Q06m_K`1cLg<0PX:2
07IfMP2[Zj/0]kNg0<_;b`2ZZZX0K6a/034a<@1=CDd0W9bL0<c<c03QhN420=[JfP090<71`@2BTY80
Zj^[07inOP21PH40X:2P03hn?P1aLG409RHV00805ADE00L05aLG01TI6@1<C4`0Cdm?07UiN@2QXJ40
Kfm_0080_kno0480YJFU069RHP1_Kfl0T92@09:BTP2NWYh0VYZJ05ADE01fMWH0MgMg02TY:@0O7al0
9RHV01XJ6P0K6a/07AdM02@T901GEeL0Cdm?02HV9P0[:b/0?3`l0;Fe]@2VYZH0TY:B04I6AP0H61P0
6QXJ01TI6@0K6a/071`L04m?C`1kNg/0d];B0<g=c@1RHV805aLG01PH600J6QX0;Bd]05EEE@2EUID0
YjNW092@T02EUID0R8R806MWI`1GEeL0AdM704E5A@10@400Cdm?08:2PP2d];@0PX:204A4A012@T80
K6a/01LG5`0H61P071`L03Xj>P1SHf<0De=C03Ph>00i>CTAooooo`003oooool02P2XZ:P0KVi^06EU
I@1DE5@0KVi^0451@@19BDT0SXj>04I6AP15ADD206][J`3C02/[:`16ATH0>c/k065QH@0[:b/0HV9R
03Ph>00W9bL0Cdm?03<c<`1DE5@0FEUI03Xj>P1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q
0451@@1=CDd07QhN03dm?@1IFET0=SHf03Lg=`1OGel08b<S03Ph>00n?Sh0A4A406EUI@1RHV80@410
03Ti>@19BDT0@d=303dm?@1fMWH0ATI606=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0J6QX
07EeM@0l?3`0CTi>014A4@1GEeL0Ogmo04U9B@1EEED0Lg=c04];B`1JFUX09BDU034a<@16ATH0<30`
02d];@1KFe/0:2PX04A4A01HF5P06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1TI6@0>CTi
01dM7@2:RXX0JFUY034a<@0i>CT0HV9R03dm?@1@D500[Zj^069RHP0f=SH0CTi>03<c<`1XJ6P0=cLg
06=SH`0i>CT0:2PX06EUI@0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e=CD0Q8B404E5A@1KFe/0EeMG
04E5A@2>SXh0ATI604M7A`1dM7@0>3Ph061PH01:BTX0Ng]k05iNGP1RHV80WinO05MGE`1[Jf/0@T92
03Ph>02>SXh0FUYJ02TY:@2<S8`0Bd];03/k>`20P800JFUY03Ph>02d];@0Kfm_04Q8B01TI6@0@T92
02l_;`0k>c/0EEEE04I6AP0e=CD0R8R805mOG`1gMgL0DE5A06a/K01UIFD0Jf][0:>SX`0j>SX0CTi>
05ADE02VYZH0F5QH03`l?00/;2`0QXJ607emO@1=CDd0Ogmo0:NWY`1bLW80alO706YZJP1GEeL0S8b<
08:2PP1CDe<0FEUI04];B`0V9RH0?clo0451@@1bLW80BTY:03De=@2OWil0BTY:024Q8@1OGel0IfMW
069RHP1bLW80D51@03dm?@2;Rh/0@D5106MWI`28R8P0>3Ph06m_K`19BDT0?Shn02<S8`1`L700E5AD
07YjNP0l?3`0VYZJ05aLG01aLG40@T9207EeM@1oOgl0HV9R06UYJ@020451@@1106a/K02CTi<0G5aL
05]KF`1iNGT0@T9203De=@1FEUH0R8R806YZJP1:BTX0K6a/038b<P1CDe<0Ph>308j>SP10@400Kfm_
069RHP1<C4`0DU9B05UIF@2c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9B@0m?Cd08R8R
06][J`29RHT0L71`04E5A@32`/80TI6A0410@01KFe/0NGUi03Ph>02[Zj/0Hf=S05]KF`12@T80Ogmo
08^;R`1HF5P0J6QX03`l?01`L700A4A4034a<@2GUiL0NWYj055AD@0S8b<0<30`05QHF00P8200?Shn
0<K6aP2HV9P07?ooool0=@1>CTh0BDU904a<C01>CTh0ADE506QXJ02;Rh/0]kNg0:FUY@1]KFd0Hf=S
079bLP29RHT0B4Q8024Q8@11@D40IfMW05IFEP1aLG40@D510492@P1<C4`0VYZJ07YjNP17AdL09bLW
01`L700M7Ad0;2`/01`L700A4A407QhN04e=C@26QXH0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b
01<C4`0@41003`l?04U9B@1@D5006QXJ01/K6`0G5aL07QhN07AdM00o?cl0:BTY00805ADE00L06ATI
03<c<`0d=3@0=SHf02HV9P0G5aL05ADE00805aLG00P06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/
01DE5@804A4A00<05ADE01HF5P0F5QH00P0E5AD05`0S8b<0Fe]K05ADE01TI6@0D51@04=3@`0g=cL0
:BTY03lo?`25QHD0DU9B06EUI@1<C4`0;2`/06ATI028R8P0>CTi02`/;00Y:BT0:b/[04M7A`0G5aL0
5QHF00805ADE05`05QHF01DE5@0E5AD0<c<c04a<C01cLg<0[jn_09>CT`1IFET0C4a<05YJFP1hN7P0
G5aL02HV9P0_;bl0E5AD01lO7`0E5AD05aLG01/K6`0U9BD061PH051@D00d=3@061PH02h^;P0j>SX0
FEUI0;fm_@2CTi<0EUIF04];B`0c<c<09RHV04Q8B01QHF40<C4a0492@P1IFET0CTi>01hN7P0I6AT0
61PH01XJ6P0K6a/0<S8b09:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0;Bd]02FUYH0
:BTY02HV9P0M7Ad07alO02DU9@0[:b/08b<S01XJ6P0G5aL061PH01dM7@0g=cL0Jf][0<?3``2[Zj/0
@41001lO7`0W9bL08b<S03De=@1QHF40B4Q802HV9P0Y:BT09bLW05=CD`1^KVh0RHV907EeM@1BDU80
Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00l09bLW0:ZZZP2b/[80/[:b0;jn_P2o_kl0_;bl0<30`037
alL0d];B0<K6aP2g]kL0@T9208Z:RP0`<3000`0E5AD05P0H61P0ADE509^KV`2OWil0/K6a0:j^[P3=
cLd0c<c<08^;R`1eMGD0QhN70410@00M7Ad08R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01dM7@0J
6QX201/K6`0b02d];@1SHf<0;Bd]020P800X:2P0;bl_06ATI02<S8`0/;2`092@T00l?3`071`L02@T
9011@D40J6QX0:n_[`2][Jd0Q8B408b<S01:BTX05aLG01/K6`0G5aL071`L02l_;`1dM7@0[jn_09NG
U`1LG5`0<S8b02TY:@0Q8B4071`L024Q8@0T92@0C4a<0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d
=00I6AT05aLG02@T900/;2`0AdM707EeM@1=CDdAooooo`003oooool0=@2<S8`0I6AT05eMG@0l?3`0
F5QH03/k>`1:BTX0LW9b05IFEP22PX80S8b<06YZJP0Y:BT0@41003hn?P1XJ6P0:b/[05iNGP11@D40
<S8b05MGE`0c<c<0C4a<059BDP0j>SX0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P8011@D40
Cdm?028R8P1:BTX0JFUY03hn?P0c<c<0Hf=S02@T9013@d<0@41004Q8B01bLW80TY:B03Xj>P0`<300
BTY:02`/;01?Cdl0Ogmo0080CDe=0>/0=3@d03Ti>@1PH600IfMW05aLG00W9bL0>SXj04m?C`1HF5P0
I6AT069RHP0F5QH0@d=306=SH`0S8b<0?clo06MWI`17AdL0EeMG02l_;`0m?Cd0Hf=S03dm?@0Z:RX0
Fe]K034a<@1RHV80KFe]01TI6@1>CTh0H61P0410@01cLg<0Shn?05iNGP2IVIT0M7Ad069RHP0Q8B40
RHV906][J`0n?Sh0E5AD06ATI010@400J6QX09:BTP1>CTh0=3@d05ADE013@d<0EeMG03Xj>P1VIVH0
H61P038b<P1NGUh0<C4a061PH02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1LG5`0KFe]05=CD`18B4P0
UiNG06QXJ01EEED0GEeM030`<01EEED0De=C069RHP1;Bd/0>c/k08>3P`1UIFD0K6a/03De=@0/;2`0
OWin061PH00];Bd0Shn?05UIF@0d=3@0Ogmo08:2PP10@400ZZZZ06MWI`1BDU80PX:205QHF016ATH0
?clo05IFEP14A4@0=SHf07moO`1TI6@0MWIf055AD@1]KFd0MGEe07alO02k^k/0GEeM04I6AP1WIfL0
Y:BT05mOG`0o?cl0=3@d08B4Q01_Kfl0?Shn04e=C@28R8P0JVYZ0<C4a02>SXh0GUiN06QXJ01_Kfl0
H61P05aLG01:BTX0;Bd]059BDP0o?cl0L71`030`<00Y:BT0QHF504m?C`0U9BD0GemO055AD@1NGUh0
]kNg06e]K@0i>CT0VIVI03`l?01<C4`0J6QX03lo?`1aLG40ADE505QHF00b<S80P82005YJFP23Ph<0
ADE509^KV`1IFET0KVi^02LW9`1MGEd0JVYZ069RHP1_Kfl0ATI602PX:01FEUH0P82004U9B@1>CTh0
NWYj03/k>`0S8b<0>CTi06EUI@1YJFT0ADE506a/K00U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0
:b/[06QXJ01MGEd0alO70;6a/@1lO7`09BDU03dm?@1QHF40JVYZ02TY:@1DE5@0FEUI02<S8`1BDU80
PH6103`l?01:BTX0Zj^[09BDU011@D40EEEE075aL@0R8R80Ogmo05ADE01?Cdl0ATI6079bLP1?Cdl0
L71`08^;R`10@400Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1^KVh0;2`/02l_;`2RXZ80
Rh^;01cooooo03P0@d=303<c<`15ADD0;bl_02XZ:P0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0
EeMG06YZJP0V9RH04a<C04Q8B017AdL0P82004m?C`12@T80Fe]K0:^[Z`1DE5@07QhN010@400G5aL0
5QHF01<C4`0=3@d0410@01lO7`1KFe/0GemO05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00d=3@0W9bL0W9bL04U9B@0L71`05aLG01/K6`1EEED0HV9R02XZ:P0E5AD051@D01XJ6P805ADE
00d05QHF01DE5@0E5AD04A4A01PH600I6AT071`L01dM7@14A4@0PH610410@01HF5P08B4Q00804a<C
00<04A4A01@D500A4A400P0A4A4201DE5@0E010@400H61P0@D5104E5A@0Z:RX0<S8b02<S8`0G5aL0
FUYJ03`l?01<C4`0QhN707=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d];@0`<3005QHF00805ADE02X0
4a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1LG5`0D51@07alO02b/[80Ogmo03Ti>@0Q8B40
7QhN02l_;`1MGEd09RHV01LG5`0K6a/0:BTY01XJ6P1ADE407AdM01LG5`0Q8B40820P0451@@2RXZ80
K6a/02LW9`0b<S80Bd];05EEE@11@D40LW9b061PH00_;bl0<c<c05YJFP0Y:BT301/K6`0e01XJ6P0L
71`09BDU07=cL`3IfMT0_Kfm0492@P0L71`09RHV02LW9`0a<C40[Jf]0:6QX@1@D500;2`/02<S8`0O
7al092@T02h^;P0];Bd0820P01XJ6P0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]04i>CP0Y
:BT0<c<c069RHP0G5aL051@D024Q8@1CDe<0OGem06m_K`1oOgl0VYZJ0:^[Z`1^KVh09BDU03Ph>02L
W9`092@T02DU9@0_;bl0BTY:04M7A`0g=cL00P0f=SH0E`0h>3P0@D5105UIF@25QHD0O7al04I6AP1H
F5P0DE5A09^KV`1:BTX06ATI01DE5@0G5aL092@T061PH028R8P0ZJVY0;Rh^02n_[h0d];B0;no_`2T
Y:@0FEUI02LW9`0N7Qh07alO01`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0K6a/05QHF01XJ6P0O
7al0BDU906=SH`0O7al07AdM02PX:00/;2`0BDU902l_;`2ATI40e]KF0;Fe]@1NGUh0H61P07AdM01^
KVh0Shn?0820P01/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX07alO092@T01UIFD0EUIF01`L700J
6QX06a/K01TI6@0J6QX07AdM024Q8@1?Cdl0][Jf061PH013@d<0>CTi03Ph>01=CDd0IFEU01DE5@0K
6a/0:RXZ02DU9@0Y:BT0@D51051@D00Aooooo`003oooool0o`2@T900MGEe05eMG@1PH600GemO03dm
?@1DE5@0Fe]K03<c<`13@d<0FEUI05EEE@0R8R80@d=302`/;01QHF40:2PX05IFEP0S8b<0=cLg065Q
H@12@T80CTi>04];B`0/;2`0E5AD03Hf=P1FEUH0FEUI02TY:@0N7Qh0?3`l01hN7P1=CDd06QXJ02DU
9@1_Kfl0KFe]03hn?P0i>CT0GemO02LW9`16ATH0;2`/01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b
<P0d=3@0KFe]04U9B@1WIfL0Cdm?02/[:`0a<C40C4a<04U9B@0d=3@0ATI605YJFP1DE5@0=3@d04Y:
BP0E5AD0=cLg071`L00m?Cd0=SHf07inOP17AdL0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0E5AD01lO7`1VIVH0FUYJ02`/;01GEeL0OGem05EEE@2=SHd0L71`06MWI`0O7al0Q8B4061P
H00[:b/0=cLg05]KF`17AdL0KFe]0:2PX01GEeL0<30`05YJFP12@T80Cdm?02/[:`1?Cdl0HV9R02d]
;@1IFET0;bl_03lo?`1oOgl0GUiN06=SH`1XJ6P0Bd];08N7Q`1GEeL0Kfm_05UIF@0e=CD0K6a/06IV
IP1UIFD0IfMW05EEE@1QHF40BDU906e]K@1NGUh0@d=309FEU@1_Kfl0LW9b04a<C010@400RHV9059B
DP0];Bd0QHF505YJFP0g=cL0P82006m_K`0m?Cd0/k>c07EeM@10@400F5QH04U9B@0l?3`0?Shn05AD
E01=CDd0?Cdm092@T01XJ6P0KFe]055AD@1mOGd0MWIf06YZJP2n_[h0KFe]04U9B@1GEeL0V9RH05EE
E@0g=cL0=SHf0861P@2@T900Bd];059BDP2CTi<0KFe]0<W9b@2HV9P0HV9R06YZJP1aLG40L71`069R
HP16ATH0<S8b06i^KP0o?cl0Lg=c03<c<`0^;Rh0S8b<06MWI`0d=3@0IfMW04E5A@0j>SX0VIVI05YJ
FP0j>SX0OGem04e=C@1GEeL0IVIV03lo?`1gMgL0CTi>05ADE00_;bl0MWIf05]KF`1kNg/0CTi>09ZJ
VP1ADE40N7Qh02LW9`1SHf<0MWIf06IVIP1dM7@0Hf=S030`<01PH600PH610410@01]KFd0VIVI05YJ
FP0W9bL0>c/k06YZJP0b<S80;Rh^08B4Q00b<S80Cdm?06m_K`1SHf<0A4A408F5Q@17AdL09BDU05=C
D`0o?cl0T92@06MWI`1XJ6P0:BTY0451@@1GEeL0=CDe020P80008`1EEED0FUYJ02`/;01SHf<0K6a/
03lo?`0g=cL0T92@06EUI@0e=CD0LW9b07inOP0c<c<0MgMg06IVIP18B4P0CDe=08B4Q01`L700F5QH
06MWI`1fMWH0YJFU06IVIP0j>SX0VIVI0:f][@0f=SH0:2PX03Lg=`1/K6`0=CDe024Q8@2d];@0OWin
01cooooo01T0?3`l030`<00j>SX09RHV01hN7P0I6AT0<30`04Y:BP17AdL0GEeM08F5Q@1EEED0ATI6
06a/K00b<S805ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn0=?Cd`1JFUX06QXJ00805ADE01X03@d=
00h>3P0=3@d04A4A04A4A01NGUh07alO03Ti>@0e=CD0Q8B403Hf=P0A4A404a<C018B4P0?3`l0410@
00h>3P0L71`0TI6A08V9R@0S8b<06a/K01TI6@0c<c<0TI6A03dm?@<04A4A01004a<C01@D500D51@0
4a<C01@D500C4a<08B4Q01HF5P0L71`07AdM051@D01TI6@0DE5A04Q8B00M7Ad05ADE0P0@41005@0D
51@05ADE01DE5@0A4A405QHF014A4@0@41003@d=02TY:@1?Cdl0<S8b01dM7@0N7Qh05ADE05EEE@10
@4009RHV09FEU@36a/H0GUiN02@T900201hN7P0302XZ:P0d=3@0:RXZ00P05ADE02L0ADE503Xj>P1[
Jf/0OGem04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80>c/k07AdM01UIFD0<C4a04A4A00Y
:BT0@T9201/K6`0F5QH07alO024Q8@0/;2`0RHV906ATI00T92@07AdM01XJ6P0P8200@T9207IfMP1A
DE40;2`/02LW9`1>CTh0FEUI01dM7@0L71`00P0M7Ad01@0N7Qh07AdM03Hf=P3;bl/0R8R800806ATI
02d09bLW030`<00f=SH0X:2P05aLG01CDe<0Fe]K03Ti>@1<C4`0Fe]K04a<C01MGEd0BTY:030`<00V
9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf04A4A00f=SH0De=C08Z:RP1FEUH0JVYZ06IVIP13
@d<09RHV06YZJP1OGel0IfMW04=3@`2CTi<0O7al06QXJ02VYZH0A4A404I6AP1jNWX0A4A401LG5`0N
7Qh00`0M7Ad05P0Q8B40;bl_04I6AP1UIFD0=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1K
Fe/0CDe=06=SH`2EUID0^[Zj08b<S02g]kL0^;Rh061PH00d=3@2028R8P80?Cdm02P0XZ:R05QHF01I
FET0Hf=S03@d=00j>SX07alO01LG5`0I6AT0:2PX05IFEP0j>SX071`L01hN7P0U9BD0>CTi034a<@0V
9RH0EeMG0=GEe@1fMWH07alO01/K6`0R8R80;bl_06UYJ@1kNg/0De=C04m?C`1`L700D51@04e=C@0n
?Sh08R8R02l_;`1QHF40C4a<05mOG`0P82005QHF0P0E5AD04P0K6a/07AdM02DU9@1jNWX0S8b<04Y:
BP0c<c<0<30`03<c<`12@T80KVi^01XJ6P0P8200:2PX024Q8@0T92@0:BTY055ADA7ooooo000?oooo
o`3409>CT`1bLW80H61P05ADE01LG5`0?clo04M7A`23Ph<0?Shn05UIF@1EEED0@D5103<c<`1]KFd0
@41005UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`03Ph>01PH6009BDU03`l?01ADE40
BTY:01TI6@0[:b/05ADE03Ti>@16ATH07AdM0451@@1HF5P0:b/[04A4A01gMgL0<S8b03Ti>@13@d<0
CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0?Cdm065QH@1TI6@0<C4a03@d=01JFUX0
;bl_02<S8`16ATH0G5aL06UYJ@0g=cL0>SXj01XJ6P14A4@0OGem03`l?00];Bd0Jf][03<c<`19BDT0
D51@0451@@15ADD05QHF03De=@1OGel0>3Ph04Y:BP1@D5005QHF03lo?`1[Jf/0?Shn06ATI023Ph<0
CDe=096AT@1XJ6P0Hf=S02d];@2[Zj/0QhN703Ph>00n?Sh0EeMG03<c<`1?Cdl0[Jf]059BDP0`<300
IfMW04M7A`1KFe/0@D5106UYJ@1bLW80>CTi05mOG`0o?cl0ATI608F5Q@1OGel0Jf][071`L01SHf<0
ZZZZ051@D01]KFd0IfMW04M7A`1^KVh0LG5a06ATI01ZJVX0G5aL04m?C`1GEeL0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0@d=302`/;020P800DU9B03<c<`1kNg/0MGEe03Hf=P2UYJD0
NWYj04m?C`1`L700@T9203Lg=`10@400F5QH04U9B@11@D40RHV906QXJ01aLG40@T9205mOG`1DE5@0
EUIF0;Fe]@27QhL0F5QH05YJFP2@T900@D5103dm?@1dM7@0YJFU0:JVYP1BDU80E5AD092@T01[Jf/0
e=CD0:b/[01YJFT0V9RH09ZJVP1^KVh0TI6A07=cL`0d=3@0GEeM04A4A01gMgL0Hf=S02h^;P29RHT0
EEEE034a<@80Ng]k00H0GemO0:>SX`1@D500EUIF09BDU01NGUh205=CD`0503Ti>@29RHT0Q8B406QX
J00b<S800P1/K6`0C@1TI6@0BDU90;Fe]@2JVYX0Ng]k02h^;P1FEUH0B4Q8061PH02ATI40GemO030`
<01SHf<0P82004I6AP15ADD0Rh^;05YJFP0o?cl0EEEE07]kN`1bLW80@D5106e]K@0k>c/0JFUY08f=
S@1TI6@0;Rh^069RHP1XJ6P0@T9205aLG01HF5P0ZJVY06QXJ01TI6@0>SXj05mOG`1hN7P0F5QH01/K
6`0l?3`0<30`02<S8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80BDU906a/K00/;2`0GUiN05mO
G`0o?cl09BDU07MgM`1dM7@0HF5Q04];B`0i>CT0M7Ad0492@P0f=SH0WinO06][J`1HF5P08R8R02`/
;01NGUh092@T01lO7`2UYJD0V9RH01cooooo03P0=SHf03<c<`0g=cL09BDU01dM7@0I6AT092@T051@
D00n?Sh0=CDe03Hf=P2DU9@0@T9207alO01>CTh08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0KVi^05iNGP0o?cl0;bl_02PX:00N7Qh0;2`/069RHP0W9bL051@D01/K6`0/;2`0PX:203dm
?@0K6a/061PH018B4P0D51@03Ph>010@400I6AT0IVIV0:ZZZP0k>c/05aLG01XJ6P1PH600b/[:06YZ
JP0I6AT0410@01<C4`804A4A00D04a<C01@D500E5AD05ADE02TY:@0201XJ6P0:01`L701^KVh0S8b<
07MgM`0c<c<05aLG01DE5@0B4Q804A4A010@40@05ADE00L04A4A010@400>3Ph05QHF05UIF@0i>CT0
7AdM00806QXJ00h0EEEE0492@P0`<300IFEU08Z:RP0M7Ad06ATI01/K6`0P8200:b/[030`<00Y:BT0
5ADE01HF5PH05ADE00/0?clo03hn?P1ADE40<30`03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`02
02LW9`0?04A4A01TI6@0Shn?09bLW01oOgl0<S8b01LG5`0E5AD07AdM02DU9@0Q8B40Ph>308b<S00^
;Rh061PH008071`L02h07QhN03@d=01=CDd0;bl_01lO7`0];Bd0ZJVY05]KF`0P820061PH01/K6`0Q
8B407alO0451@@2?Shl0KVi^01dM7@0E5AD09BDU03@d=01;Bd/0Jf][09ZJVP0n?Sh0;Bd]04A4A01J
FUX0V9RH0:JVYP2MWId0aLG505mOG`0U9BD0:b/[03dm?@2NWYh0g=cL0>;RhP3?cll0OWin04Q8B01n
OWh0GUiN07AdM01jNWX0=SHf0P0G5aL0=00H61P0Kfm_05ADE01kNg/092@T02DU9@1/K6`0_[jn0:n_
[`1IFET0@4100451@@0N7Qh06QXJ01`L700M7Ad08b<S02LW9`0X:2P0;bl_04E5A@38b<P0VIVI0861
P@25QHD0dM7A0>;RhP2f][H0W9bL06][J`19BDT0DE5A06i^KP1PH600^[Zj08n?S`1IFET0SXj>09fM
W@1mOGd0BDU9059BDP20P800W9bL0;jn_P1WIfL0E5AD07AdM02>SXh0DU9B04M7A`0Z:RX202d];@0<
06ATI00Q8B408B4Q02<S8`0d=3@0Ng]k03`l?00];Bd0Ng]k09VIV@0^;Rh06QXJ0P0K6a/09014A4@0
K6a/06a/K00m?Cd0=SHf05QHF01TI6@0;Bd]03`l?01ZJVX0YjNW04i>CP0j>SX0MWIf04e=C@0Q8B40
:b/[03Xj>P1MGEd0QXJ60:ZZZP3Fe]H0/k>c03dm?@0Z:RX0>SXj03<c<`0g=cL0N7Qh034a<@0S8b<0
8R8R01dM7@0O7al0:b/[07=cLa7ooooo000?ooooo`1/08f=S@1FEUH0DU9B05]KF`1WIfL0?Shn04];
B`2?Shl0A4A404i>CP1NGUh0C4a<028R8P16ATH0?Shn03Hf=P0R8R80DU9B05=CD`0V9RH0EUIF04A4
A00m?Cd0JVYZ038b<P1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG0492@P1DE5@08B4Q0410
@01_Kfl0CDe=02LW9`1bLW80=3@d03lo?`0i>CT0GUiN05ADE01PH600<S8b028R8P0n?Sh0EEEE03Hf
=P2:RXX0Cdm?05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0HF5Q05MGE`0^;Rh0C4a<01lO
7`0^;Rh0NWYj04i>CP0M7Ad0MGEe0492@P0k>c/0;bl_02h^;P0l?3`0;Bd]03@d=01NGUh0<c<c051@
D01LG5`05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1`L700ATI601`L701YJFT0FUYJ03De
=@15ADD0Hf=S0451@@19BDT0^k^k07=cL`0l?3`0LW9b03<c<`23Ph<0DE5A0P1YJFT03`0e=CD0Lg=c
0410@016ATH0R8R804m?C`28R8P0JVYZ05aLG038b<P0FEUI08:2PP1/K6`0A4A4079bLP0206][J`2S
08b<S01NGUh0ADE5055AD@2KVi/0MgMg03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP1GEeL0<c<c
09^KV`1jNWX0>SXj096AT@1gMgL0@4100:FUY@22PX80H61P096AT@1JFUX0>SXj05]KF`24Q8@0HV9R
03De=@2;Rh/0JVYZ08>3P`1;Bd/0FUYJ04m?C`0i>CT0YZJV0:ZZZP22PX80G5aL0;2`/01NGUh0=CDe
03Lg=`1oOgl0N7Qh05MGE`22PX80ZZZZ059BDP2f][H0MGEe04I6AP1bLW80H61P04=3@`16ATH0De=C
03Hf=P1@D500C4a<08^;R`1iNGT0<C4a08n?S`1;Bd/09BDU05eMG@1KFe/0HF5Q0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0Jf][04I6AP1QHF40;Rh^079bLP1nOWh0Ph>30410@01/K6`0Cdm?
07AdM01EEED0O7al04A4A00o?cl0GEeM03Ti>@13@d<0TI6A09:BTP1HF5P0AdM707YjNP0Q8B40=SHf
04A4A01[Jf/0LG5a0410@01[Jf/06ATI05QHF02GUiL0RHV903/k>`1cLg<0L71`030`<01oOgl0Lg=c
0:b/[02ATI40ADE502XZ:P12@T80HV9R065QH@0M7Ad0?3`l03hn?P0R8R80DU9B08:2PP1@D500<30`
06e]K@1cLg<0ATI605ADE01hN7P0=SHf03hn?P1CDe<0CDe=02d];@2=SHd0S8b<05QHF01LG5`0ADE5
08^;R`1<C4`0>3Ph0:FUY@23Ph<0HV9R02LW9`0a<C40GUiN02XZ:P0[:b/0X:2P09NGU`0Looooo`0Q
03Lg=`10@400<C4a02<S8`0L71`05aLG02XZ:P0`<300N7Qh05=CD`0/;2`0aLG50<[:bP34a<@0XZ:R
075aL@1PH600b<S80<k>cP36a/H0e=CD0;bl_012@T80LW9b055AD@1SHf<0LG5a06a/K02?Shl0S8b<
0;^k^`1mOGd05aLG00805ADE01T0;Rh^08B4Q018B4P071`L01TI6@0K6a/0>c/k01LG5`0B4Q807QhN
05IFEP2g]kL0AdM703hn?P2ATI40c/k>0=oOg`3Hf=P0Vi^K05mOG`0a<C4071`L01<C4`0E5AD051@D
00804a<C00`0:2PX03Lg=`0O7al0:RXZ092@T02/[:`0Lg=c02/[:`0G5aL04a<C014A4@0C4a<301DE
5@0301HF5P0A4A40410@0080410@00@04a<C05aLG015ADD09BDU0P0K6a/01@1GEeL0E5AD02/[:`1`
L700MgMg00<071`L00@07AdM02<S8`0d=3@0;2`/1`0E5AD01@0L71`0ADE504U9B@1?Cdl0<S8b0080
6a/K00D0>SXj05]KF`0Z:RX0:BTY03Hf=P0203@d=01/03lo?`1TI6@0EeMG07inOP2i^KT0ATI601XJ
6P0G5aL0=CDe02h^;P0S8b<0RHV90<[:bP1mOGd09BDU01PH600J6QX06a/K02LW9`0n?Sh0B4Q8024Q
8@0T92@0P8200<c<c02:RXX0@D5101lO7`0N7Qh08b<S06e]K@1`L700NWYj04=3@`0I6AT08B4Q03<c
<`1aLG40@D51079bLP0k>c/0=3@d038b<P0/;2`0=cLg071`L02RXZ80`<3007QhN010@400BTY:0:JV
YP3<c<`0a<C409BDU02VYZH0bl_;08n?S`2@T900O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BD
U01/K6`0DU9B04E5A@0/;2`09RHV0:BTY02k^k/0U9BD03De=@0_;bl06QXJ01/K6`0M7Ad09RHV03@d
=01FEUH0CDe=071`L028R8P0`l?3065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206=S
H`14A4@0LW9b0<_;b`16ATH05aLG075aL@3Cdm<0`<300;2`/01lO7`0@4100P0l?3`0<01?Cdl0MGEe
09JFUP30`<00^;Rh0;fm_@2UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0EeMG
09NGU`1LG5`05ADE01TI6@0K6a/0<S8b04m?C`1lO7`0D51@02LW9`0Y:BT0@41007QhN01=CDd0:RXZ
03/k>`1CDe<0GEeM02/[:`2@T900f][J0<30`03:b/X0c/k>0<C4a039bLT0[Zj^0:f][@1iNGT0?clo
04=3@`80?clo00T0@d=306EUI@1QHF407AdM01`L700O7al0=SHf059BDP2a/K404Oooool000oooooo
0?80YjNW08:2PP1BDU80?Cdm06IVIP0n?Sh0?Cdm05eMG@19BDT0Lg=c08>3P`1cLg<092@T03lo?`1<
C4`0J6QX04E5A@1CDe<0DU9B030`<01TI6@0De=C0492@P1LG5`0?3`l069RHP14A4@0>SXj04I6AP0T
92@0:BTY04a<C00R8R80@T92055AD@0U9BD0?Cdm06a/K01EEED0;Bd]075aL@0/;2`0=SHf03`l?01]
KFd0D51@05mOG`1CDe<0ADE504U9B@1YJFT0<30`09ZJVP1BDU80DE5A06][J`15ADD0<c<c06EUI@1g
MgL0;bl_03hn?P1TI6@0EeMG04A4A01aLG40<S8b02l_;`2;Rh/0Hf=S01dM7@27QhL0GEeM04i>CP16
ATH0A4A4069RHP0i>CT0=CDe065QH@0^;Rh0De=C065QH@0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[
Jf/0TI6A07AdM01^KVh092@T07emO@1UIFD0>3Ph04];B`1QHF40?Cdm02h^;P2?Shl0EEEE02/[:`1>
CTh08b<S059BDP0e=CD0L71`07AdM00Y:BT0CTi>04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3C
dm<0A4A405QHF01QHF40GemO09JFUP1TI6@0C4a<05eMG@12@T80De=C05IFEP1eMGD0De=C04U9B@2C
Ti<0Lg=c06UYJ@15ADD0;bl_09NGU`1VIVH09RHV07]kN`1MGEd0=SHf08F5Q@22PX80;2`/08B4Q01H
F5P0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0De=C09RHV01ADE40QXJ607emO@1?
Cdl0VYZJ0;Ng]`14A4@0ADE50:FUY@25QHD0CDe=03De=@1dM7@0RHV9051@D01HF5P0PH6105UIF@34
a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`1gMgL0>c/k05mOG`12@T80=CDe0:2PX01V
IVH0<30`06EUI@1JFUX0=SHf08F5Q@1WIfL092@T079bLP0j>SX0ATI605mOG`19BDT0MgMg04M7A`1`
L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0DE5A07QhN00X:2P0Hf=S05mOG`1GEeL0JVYZ06EUI@0_
;bl0Jf][09RHV01JFUX0@D5106a/K00i>CT0;Rh^03lo?`1ZJVX0MgMg03lo?`1VIVH0?Cdm04i>CP1g
MgL0KVi^02TY:@80GemO02h0<30`06QXJ018B4P0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R
8P0g=cL0@D5102HV9P1=CDd0LW9b04Y:BP0c<c<0O7al061PH01;Bd/0DE5A06ATI013@d<0>SXj07Ui
N@1WIfL0EUIF0:RXZ027QhL0GEeM07UiN@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1BDU804Q8B030`<01_Kfl0SXj>7?ooool09`12@T80B4Q802d];@0R8R807QhN01/K6`10@400?clo
069RHP2XZ:P0bl_;0=KFeP2EUID0Y:BT0:2PX02f][H0eMGE0=WIf@2c/k<0eMGE0=oOg`2CTi<08b<S
04m?C`0W9bL07AdM01XJ6P0I6AT09BDU01TI6@1?Cdl0YjNW05YJFP0G5aL05ADE01/K6`2;Rh/0Cdm?
01/K6`0201DE5@0<01PH600K6a/061PH01dM7@1aLG40]KFe0<g=c@37alL0c/k>0=;BdP3De=@0d];B
0P30`<00502j^[X0WIfM07inOP1YJFT0CTi>03<c<`0b<S80Jf][0:JVYP1?Cdl0C4a<0:BTY024Q8@0
F5QH024Q8@0C4a<05ADE018B4P0C4a<051@D0`0E5AD300l?3`0C00h>3P0?3`l0>SXj06i^KP0S8b<0
820P01LG5`1YJFT0Jf][04];B`2j^[X0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0501DE
5@0h01<C4`0E5AD05aLG06][J`2DU9@0M7Ad034a<@0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0
Bd];05=CD`1YJFT0TY:B0:BTY02j^[X0a/K607YjNP1=CDd0CTi>08>3P`1UIFD0HF5Q0;>c/`2PX:00
Xj>S07MgM`0f=SH071`L01LG5`0N7Qh0:BTY05UIF@0/;2`07alO071`L01CDe<0ATI60820P02?Shl0
?Cdm02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo03/k>`1MGEd201DE5@1J02HV9P1=
CDd0?clo03lo?`1@D500Jf][09bLW02;Rh/0_;bl0861P@1ADE40[jn_09>CT`2JVYX0WYjN0;Zj^P2c
/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@2=SHd0>CTi02<S8`0L71`0@T9208n?S`2M
WId0De=C05UIF@1UIFD06ATI01/K6`0J6QX07AdM04M7A`1?Cdl0ADE50410@01LG5`0TY:B0;Zj^P37
alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<07UiN@2ATI40MgMg0:b/[00Y:BT07AdM08B4Q01K
Fe/0<S8b030`<00h>3P0JVYZ06e]K@1LG5`0AdM706UYJ@2b/[80Vi^K06UYJ@1IFET0R8R808n?S`1G
EeL0VIVI06a/K010@400RXZ:05QHF00Z:RX0Bd];08f=S@2QXJ40ADE501/K6`0G5aL0;2`/0P19BDT0
8`1bLW80?3`l01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0ATI604A4A02g]kL0e]KF0;Jf
]P2WYjL0ZJVY09fMW@24Q8@0Ph>307emO@1eMGD0J6QX03dm?@0N7Qh0;2`/0451@@1BDU80SHf=02`/
;00d=3@0B4Q8059BDP1dM7@0VIVI017ooooo000?ooooo`1J07AdM01OGel0D51@059BDP1;Bd/0=SHf
04a<C01YJFT0ATI603Lg=`1HF5P0HF5Q034a<@1YJFT0>c/k04M7A`0e=CD0HF5Q03Lg=`0R8R80Fe]K
05EEE@1;Bd/0IfMW02PX:00o?cl0;Rh^038b<P1<C4`0;Rh^01HF5P0d=3@0:b/[04E5A@0c<c<07alO
03Ph>01LG5`0=CDe02`/;01gMgL08B4Q03Ph>00c<c<0>c/k04e=C@1VIVH0?clo03`l?01VIVH0BTY:
02PX:01dM7@0BDU906a/K01IFET0=CDe03Ph>029RHT0DE5A034a<@1EEED0E5AD04=3@`0d=3@0H61P
02PX:00m?Cd0SHf=04a<C00J6QX0Ng]k04M7A`1YJFT0GEeM04Q8B012@T80:BTY03dm?@1hN7P0=3@d
04=3@`1ZJVX07AdM065QH@1iNGT0@T9206a/K02<S8`0C4a<0P1lO7`0B@1[Jf/07alO07moO`1PH600
<C4a05UIF@1VIVH0@41004A4A02g]kL0I6AT02l_;`1TI6@0=CDe051@D00e=CD0BTY:07AdM00i>CT0
DE5A0410@01>CTh0Ng]k05aLG01VIVH0Hf=S07AdM034a<@0EeMG059BDP1@D500Cdm?05YJFP1eMGD0
D51@05YJFP0j>SX0@41005IFEP1/K6`0GEeM04m?C`2<S8`0KVi^05iNGP0i>CT0:2PX08>3P`1CDe<0
9RHV07inOP1kNg/0?Shn09>CT`20P800?Cdm08V9R@27QhL0DU9B079bLP1KFe/0@T9204];B`1CDe<0
D51@038b<P28R8P0J6QX07=cL`12@T80EUIF05mOG`1BDU800P2FUYH0N`1IFET0DU9B08V9R@2ATI40
F5QH04e=C@28R8P0VYZJ05EEE@1MGEd0QXJ6059BDP2o_kl0YZJV06YZJP2:RXX0N7Qh061PH01<C4`0
EUIF034a<@1QHF40B4Q8075aL@1FEUH0>SXj0861P@1PH600=3@d075aL@1NGUh0GEeM09:BTP1OGel0
<S8b07YjNP1EEED0HV9R075aL@0i>CT0OGem07]kN`1iNGT0?Shn06QXJ01aLG40P82003dm?@25QHD0
PH6107moO`0f=SH0GemO05eMG@1>CTh0JFUY06m_K`0h>3P0Jf][09JFUP1RHV80A4A408V9R@1PH600
<S8b0492@P1hN7P0MWIf04E5A@1gMgL0DU9B05iNGP2<S8`0IfMW03Xj>P1/K6`0Ng]k04Q8B020P800
CTi>0:NWY`2@T900Hf=S03@d=014A4@0EeMG04e=C@0V9RH0BDU905eMG@0T92@0@41006][J`0l?3`0
<c<c06e]K@2;Rh/0Bd];065QH@1ZJVX092@T04U9B@2PX:00I6AT03Hf=P2TY:@0GUiN04a<C01YJFT0
F5QH09BDU01<C4`0?clo0:f][@2RXZ80E5AD02TY:@0j>SX0KVi^03Ti>@0P8200GEeM08j>SP0Loooo
o`0o05eMG@1nOWh0AdM702/[:`0Q8B407alO02l_;`0T92@08R8R05IFEP2MWId0RXZ:09JFUP22PX80
EUIF06i^KP32`/80MWIf06YZJP1bLW80QHF50:f][@1WIfL0>SXj03hn?P0X:2P09BDU030`<00d=3@0
820P01/K6`17AdL0SXj>05IFEP0G5aL0?clo0<[:bP2=SHd08R8R01PH600G5aL05ADE020P801:BTX0
JFUY0:n_[`2][Jd0bLW90<[:bP2CTi<0HF5Q03lo?`0a<C40<c<c03hn?P10@400C4a<05QHF01QHF40
I6AT07AdM01lO7`0SHf=0080X:2P05<0clo?0=7Ad@2[Zj/0O7al05=CD`0F5QH04A4A010@400C4a<0
410@01@D500P820051@D00l?3`0@41004Q8B010@400A4A40:b/[0;Ng]`1SHf<0?Cdm03`l?02DU9@0
WinO0:BTY03?cll0bLW906e]K@1:BTX0?clo03/k>`17AdL0Fe]K065QH@0J6QX051@D01LG5`0H61P0
8R8R03<c<`1IFET0Lg=c0;Bd]035aLD0ZJVY05]KF`0k>c/07alO01XJ6P1/K6`0?Shn02HV9P0X:2P0
;Rh^03Ti>@15ADD0LW9b09jNWP2RXZ80]KFe0<30`02FUYH0GemO03Ti>@2BTY80S8b<03De=@0Q8B40
=SHf05UIF@1bLW80EEEE0492@P0/;2`0:2PX0451@@1JFUX0F5QH07moO`1^KVh0AdM706EUI@020861
P@0n0;Zj^P2IVIT0TI6A09ZJVP36a/H0[Jf]0;2`/03EeMD0PX:203<c<`1BDU805ADE01LG5`0E5AD0
5aLG03Lg=`2JVYX0Ogmo04U9B@1ZJVX0][Jf05ADE010@400ATI605=CD`2TY:@0YZJV0;Jf]P2/[:`0
UiNG07inOP1ADE40;Rh^02LW9`0_;bl0=cLg04e=C@31`L40bl_;07moO`1?Cdl0B4Q8059BDP1SHf<0
Vi^K03hn?P0h>3P0=SHf01TI6@0H61P06ATI028R8P0Y:BT0=CDe04I6AP1BDU80MGEe0::RXP3;bl/0
S8b<07QhN025QHD20=SHf00N0=GEe@3;bl/0clo?0<_;b`0a<C407AdM09NGU`1JFUX0KFe]04E5A@0]
;Bd071`L01TI6@0H61P05QHF01`L700l?3`0YjNW0;Vi^@2JVYX0V9RH07UiN@1NGUh0IVIV08N7Q`2:
RXX0Ti>C0<;2`P2PX:00?clo0P0N7Qh0;01BDU80YjNW06ATI00j>SX0@4100451@@0k>c/0;Rh^05]K
F`1iNGT092@T01`L700K6a/07AdM02TY:@1_Kfl0SHf=05aLG00j>SX0FEUI0:ZZZP2^[Zh0NWYj04I6
AP0k>c/0?3`l02l_;`0U9BD08b<S04=3@`1KFe/0Lg=c06QXJ00j>SX0A4A405]KF`28R8P0WYjN07Yj
NP1HF5P0De=C04M7A`0b<S80:b/[4Oooool000oooooo0:80IVIV08^;R`1BDU80I6AT05aLG018B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP15ADD0820P02HV9P1`L700FUYJ02LW9`1JFUX0
@T9203De=@1]KFd0:BTY03Xj>P0Y:BT08b<S03Xj>P0];Bd05ADE03Lg=`0n?Sh0@41006=SH`0Y:BT0
;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R034a<@1LG5`0DE5A05UIF@0a<C40;Bd]03De=@19BDT0
820P07AdM01ADE40CDe=061PH01<C4`0;bl_09bLW01QHF40<C4a0410@01]KFd0B4Q8038b<P15ADD0
;Bd]02HV9P26QXH0LG5a01hN7P1PH600CDe=059BDP0`<300@T9203`l?013@d<0<c<c07moO`0k>c/0
@41006][J`0X:2P0JVYZ07QhN013@d<0LW9b08b<S01gMgL0OWin05UIF@11@D40:b/[0820P01cLg<0
=SHf05IFEP1GEeL0<C4a02d];@2_[jl0EeMG03Hf=P1UIFD0:2PX055AD@0k>c/0DU9B08:2PP10@400
IFEU05IFEP1GEeL0Rh^;06QXJ01fMWH0RXZ:07MgM`2l_;`0FUYJ06UYJ@1dM7@0I6AT05]KF`1dM7@0
FEUI071`L012@T80EUIF06YZJP29RHT0N7Qh06IVIP2UYJD0Lg=c08:2PP1[Jf/0?3`l08>3P`1DE5@0
?Cdm09FEU@2DU9@0?Cdm092@T01bLW80@d=308R8R024Q8@0B4Q806YZJP11@D40>c/k07inOP2OWil0
G5aL02/[:`1iNGT0Ng]k08N7Q`1GEeL2059BDP0W03Ph>020P800WinO0820P01>CTh0NGUi08B4Q01H
F5P0=cLg06MWI`2MWId0G5aL061PH026QXH0IVIV0<;2`P2HV9P0Jf][06i^KP1hN7P0MGEe02/[:`10
@4007QhN03hn?P0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1^KVh0Ti>C05IFEP0]
;Bd0Lg=c0080CTi>05D0Ng]k04M7A`1XJ6P0ATI6069RHP19BDT0Kfm_07MgM`23Ph<0De=C06QXJ01<
C4`0Kfm_02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1SHf<0Q8B403lo?`1cLg<0RHV904m?C`0_
;bl0ADE506][J`11@D40<C4a05eMG@16ATH0GemO09:BTP1;Bd/08R8R05aLG01bLW80=CDe07moO`1B
DU80WIfM07YjNP1DE5@0?Shn05mOG`1mOGd0IfMW01lO7`0k>c/0B4Q802XZ:P1aLG40OGem05ADE00k
>c/0UIFE08B4Q00V9RH0ADE507emO@19BDT0>c/k08:2PP17AdL07alO05mOG`1gMgL0C4a<06IVIP0i
>CT0U9BD0451@@0o?cl0`/;209RHV01OGel07alO028R8P1PH600>SXj02DU9@1TI6@0UYJF01cooooo
01l0S8b<06EUI@2:RXX0>c/k020P800b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600X
:2P0JFUY05iNGP0f=SH07QhN01HF5P0I6AT0C4a<08R8R02ZZZX0aLG509FEU@1oOgl0SXj>0820P00k
>c/09RHV0080D51@00@0X:2P09:BTP37alL0bLW90P2`/;00301OGel09bLW01TI6@0P8200S8b<0:NW
Y`1EEED0GUiN07emO@2m_Kd0W9bL04A4A080@T9200L0?Shn03Lg=`0O7al06QXJ01LG5`0E5AD04Q8B
00805ADE0140:2PX04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg04A4A00e=CD0<30`
04A4A02QXJ40Fe]K05ADE002010@40804Q8B0280ADE506EUI@2?Shl0QHF509JFUP3IfMT0eMGE09ZJ
VP2m_Kd0TY:B0;Bd]01VIVH0JFUY04i>CP0U9BD0LW9b0<g=c@2@T900N7Qh08>3P`2;Rh/0QhN706=S
H`1=CDd0NWYj05MGE`2MWId0Vi^K07alO01PH600@D5104A4A01`L70071`L0`0E5AD05`0F5QH09RHV
03hn?P2HV9P0I6AT09JFUP2h^;P0YJFU0=3@d039bLT0WinO0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/
06YZJP17AdL0G5aL06UYJ@2NWYh0BDU90080[Jf]0140OGem08f=S@1lO7`0NGUi08B4Q03;bl/0HF5Q
0451@@1bLW80SHf=02l_;`0k>c/0De=C07EeM@1@D500J6QX01dM7@0301DE5@1b034a<@13@d<07AdM
01XJ6P1LG5`0LW9b02TY:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01BDU80WinO055AD@0i>CT0P820
08N7Q`1?Cdl0De=C09^KV`3EeMD0Shn?024Q8@0g=cL0Ti>C06e]K@1`L700`<30055AD@17AdL0:2PX
01LG5`0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06e]K@0h>3P0ATI605eMG@1_Kfl0`<30
0<c<c03Fe]H0g]kN0=WIf@2TY:@0DE5A04i>CP1QHF40U9BD02d];@0T92@08b<S01DE5@0F5QH05aLG
01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0J6QX065QH@27QhL0YJFU0<30`02m_Kd0Z:RX
09JFUP1;Bd/0<c<c09jNWP1jNWX07AdM03<c<`2OWil0C4a<02XZ:P0o?cl0Z:RX0:>SX`0U9BD05QHF
01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2ZZZX0Z:RX06][J`0n?Sh0;Bd]01lO7`0K6a/08B4Q
020P800M7Ad09RHV05eMG@14A4@0JFUY0`2^[Zh0202TY:@0RHV9059BDP0Q8B407AdM01hN7P0U9BD0
;bl_4Oooool000oooooo02<0IFEU08b<S01DE5@0KVi^065QH@1?Cdl0@T9207UiN@0k>c/0De=C06YZ
JP1nOWh0=cLg059BDP18B4P0A4A405mOG`2EUID0H61P02l_;`1LG5`0I6AT03dm?@1aLG40:2PX04E5
A@1EEED0=SHf03hn?P0M7Ad051@D03hn?P1SHf<0B4Q8079bLP0203De=@2f06MWI`1UIFD0:b/[05iN
GP0U9BD0;Rh^03Lg=`1[Jf/0@T9205QHF00l?3`0B4Q804];B`1LG5`0:RXZ08R8R01PH600Cdm?05QH
F01?Cdl0?Shn0:RXZ01ADE40;bl_03hn?P1]KFd0A4A40492@P1GEeL0=cLg02TY:@2HV9P0OGem024Q
8@1OGel0EEEE05UIF@15ADD0>3Ph04I6AP0_;bl0?3`l07AdM00a<C40>SXj05iNGP0K6a/0M7Ad079b
LP1;Bd/0P8200:6QX@1bLW80H61P05ADE01NGUh09BDU06=SH`18B4P092@T05=CD`1MGEd09RHV01`L
7022PX80NWYj04A4A01]KFd092@T05]KF`1GEeL0A4A407QhN00c<c<0IfMW04I6AP1CDe<0QXJ603De
=@1dM7@0O7al065QH@1lO7`0B4Q805eMG@1RHV80DE5A04m?C`1/K6`0A4A405=CD`1ADE40FEUI05=C
D`1fMWH0KVi^04E5A@2=SHd0?Cdm04i>CP1IFET0?3`l08:2PP1?Cdl08R8R06i^KP1jNWX0=cLg075a
L@1`L700>c/k06a/K01UIFD0=cLg05YJFP1BDU80:BTY03`l?01EEED0BTY:02<S8`1NGUh0A4A4075a
L@1;Bd/0DU9B07AdM01GEeL0M7Ad079bLP1dM7@0IVIV08f=S@2JVYX0MWIf0492@P1XJ6P0Ti>C05YJ
FP20P800ZJVY07EeM@30`<00_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0j>SX0A4A405eM
G@17AdL09bLW04E5A@1FEUH0:b/[05iNGP19BDT0JFUY0:n_[`1]KFd0=CDe07UiN@1<C4`0JVYZ0:FU
Y@1FEUH0PH61051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_07MgM`0U9BD207IfMP15
055AD@1UIFD0?Cdm030`<028R8P0U9BD059BDP1=CDd0NGUi028R8P1<C4`0Kfm_09NGU`1lO7`0BDU9
06IVIP0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1QHF40_Kfm0:ZZZP1FEUH07AdM
03Ti>@1FEUH0EEEE02<S8`14A4@0@T9201TI6@0i>CT0I6AT018B4P0M7Ad0E5AD08^;R`1FEUH0DU9B
08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D5108F5Q@0l?3`0WIfM03Xj>P0];Bd0U9BD
09nOW`1VIVH09BDU02LW9`1QHF405aLG02h^;P2>SXh0U9BD01cooooo01X0Cdm?06e]K@1DE5@0S8b<
03De=@15ADD0EUIF07IfMP1<C4`0;Bd]04=3@`0S8b<05aLG01DE5@0L71`05ADE02h^;P0i>CT08R8R
01LG5`0F5QH05ADE04e=C@27QhL0emOG0>WYj@80mOGe01/0hn?S0:RXZ01nOWh0NWYj05eMG@2a/K40
a/K607emO@14A4@0B4Q80492@P2>SXh0`L710:>SX`32`/80b<S808b<S022PX80ADE5038b<P14A4@0
];Bd04a<C00M7Ad0820P028R8P0X:2P00P0N7Qh0?00G5aL04a<C01<C4`0A4A405ADE01PH601^KVh0
Xj>S07QhN01=CDd0_kno0<?3``2d];@0RHV906i^KP1OGel0K6a/0:6QX@3;bl/0e]KF06IVIP1IFET0
7alO02DU9@0e=CD0Fe]K09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0PX:203hn?P1NGUh0
Z:RX06i^KP1RHV80UIFE0;Bd]02n_[h0YZJV071`L01<C4`0Bd];04M7A`1JFUX0O7al0:j^[P13@d<0
Vi^K08Z:RP1=CDd0QHF508J6QP2>SXh0NWYj02@T90805ADE05@05aLG01TI6@0g=cL0@d=3096AT@1T
I6@0JVYZ04a<C01CDe<0Xj>S0=CDe01hN7P0XJ6Q07moO`0^;Rh071`L01TI6@0L71`08B4Q06i^KP1i
NGT0WYjN0;6a/@2UYJD0[Zj^0;fm_@26QXH0YJFU08R8R01bLW80Bd];0:JVYP35aLD0OWin08b<S00_
;bl05QHF01dM7@0V9RH0HF5Q06][J`2@T900Ogmo02/[:`0G5aL06QXJ04e=C@0d=3@06QXJ01DE5@1a
LG40Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:05aLG01>CTh0Hf=S096AT@12@T80<S8b0:FUY@3K
fm/0f=SH0=cLg03?cll0TI6A04a<C02OWil0Ogmo06ATI02i^KT0i>CT08n?S`1FEUH0AdM702l_;`1D
E5@0@d=306i^KP1WIfL208>3P`03069RHP1fMWH0?3`l00808R8R00l09bLW03Ti>@2UYJD0/[:b0:BT
Y02^[Zh0Q8B409JFUP38b<P0NGUi04=3@`2g]kL0;Rh^01lO7`0N7Qh00P0F5QH0:@0H61P0B4Q8061P
H01/K6`0H61P03De=@0m?Cd0Hf=S0410@01QHF40CDe=05EEE@1DE5@0Lg=c0:j^[P2SXj<0^k^k0=SH
f03EeMD0c/k>08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B05iNGP0J6QX061PH01TI
6@0H61P0:b/[02`/;013@d<0UiNG0;:b/P26QXH0<30`00807AdM00<08R8R02h^;P0O7al00P0M7Ad0
3`0O7al0=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al071`L020P800Q8B40:2PX059B
DP0Aooooo`003oooool07`24Q8@0SXj>05=CD`1@D500EEEE0492@P10@400Cdm?034a<@1_Kfl0Ph>3
07=cL`0k>c/0Bd];04a<C01JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UYJ@0h>3P0IfMW
05MGE`10@400?Shn03<c<`0N7Qh00P1NGUh0o`11@D40FUYJ03Hf=P1?Cdl0OWin06UYJ@0Z:RX0HV9R
03Lg=`1;Bd/0?clo06IVIP15ADD0R8R805MGE`1IFET0Bd];04e=C@0Q8B40HF5Q04];B`1TI6@0AdM7
030`<00R8R80L71`04i>CP0_;bl0<S8b04];B`0d=3@0EEEE05QHF00_;bl0:b/[08b<S015ADD09BDU
06][J`1>CTh0FUYJ0492@P13@d<0K6a/03Xj>P0l?3`0Lg=c020P8019BDT0J6QX02DU9@1MGEd0EeMG
02DU9@1VIVH0U9BD07MgM`1JFUX0HF5Q079bLP0Y:BT0P82005EEE@0`<300Kfm_07IfMP1ADE40BDU9
09RHV01cLg<0<c<c07EeM@0l?3`0CDe=04a<C00h>3P0NWYj03lo?`1=CDd0DU9B051@D02DU9@0IVIV
04a<C022PX80GEeM07inOP1NGUh0Fe]K061PH01@D500GEeM07alO01`L700N7Qh04m?C`1TI6@0J6QX
0861P@1KFe/0?Shn08R8R01bLW80EUIF03Hf=P0X:2P0LW9b05YJFP0_;bl0NWYj071`L00o?cl0VYZJ
08Z:RP17AdL0Lg=c071`L01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01/K6`0LW9b
065QH@1eMGD0Ph>306a/K01kNg/0TY:B06QXJ00j>SX0UYJF08b<S01OGel0ADE506EUI@26QXH0=CDe
03lo?`1[Jf/0BDU90<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^05mOG`10@400GemO
05YJFP0l?3`0MWIf06m_K`0e=CD0LW9b061PH00`<300TI6A06a/K00d=3@0SXj>03`l?00e=CD0MGEe
06=SH`26QXH0YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k08b<S02j^[X0RXZ:01lO7`1:BTX0Kfm_
05]KF`2FUYH0:b/[01`L7015ADD0JFUY0451@@1lO7`0Rh^;03De=@0R8R80>3Ph061PH01EEED0C4a<
08N7Q`0];Bd0<30`05YJFP1GEeL0BDU907UiN@26QXH09BDU075aL@1?Cdl0][Jf0<C4a023Ph<0>c/k
03dm?@1BDU80AdM7020P801DE5@0MWIf02<S8`18B4P0O7al04=3@`0/;2`0GEeM08J6QP1DE5@0EeMG
06e]K@0C4a<0<S8b0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX06i^KP1WIfL0`/;2065QH@0b<S80Vi^K
09bLW01<C4`0?Shn04=3@`1YJFT0:2PX02d];@0106UYJ@40QXJ67?ooool02`2MWId0P820071`L01K
Fe/0RHV90;:b/P2YZJT0F5QH05EEE@1ADE40:BTY00<05ADE02/092@T01lO7`1HF5P0XJ6Q06a/K00n
?Sh0<c<c02@T900F5QH0Cdm?0;jn_P3^k^h0mOGe0>OWi`3?cll0`l?30:BTY02DU9@0PH610:6QX@2/
[:`0;2`/01TI6@0G5aL08b<S034a<@11@D40d];B0>7Qh@3IfMT0clo?08:2PP0];Bd08R8R01LG5`1e
MGD0Shn?02LW9`0J6QX061PH01DE5@0L71`06a/K00805ADE01h05aLG01DE5@0G5aL0:BTY034a<@0j
>SX0O7al0=GEe@35aLD0Zj^[0<30`02e]KD0Zj^[07inOP1iNGT0TI6A0:>SX`2][Jd0VIVI061PH01Y
JFT0G5aL04];B`0k>c/0Hf=S09VIV@2][Jd0UIFE0<C4a02m_Kd20=_Kf`2X08:2PP0e=CD0<30`05UI
F@2XZ:P0P820092@T03Bd]80Bd];02DU9@0j>SX0ATI604M7A`0j>SX0;Bd]0410@01YJFT0J6QX0<C4
a01VIVH0=3@d04i>CP1WIfL0]kNg08:2PP0_;bl07alO01LG5`0J6QX092@T03hn?P1>CTh0HF5Q08Z:
RP1aLG409RHV01TI6@0f=SH0YZJV06QXJ00m?Cd0WYjN07emO@0/;2`09BDU01hN7P0Q8B4092@T07em
O@2YZJT0]kNg0=[JfP3Fe]H0U9BD06UYJ@1>CTh0?3`l030`<00h>3P0D51@0<71`@3?cll0V9RH01dM
7@0O7al0BDU905UIF@16ATH0UIFE0<G5a@25QHD0Ng]k07QhN02SXj<0QhN702HV9P0G5aL05ADE06IV
IP0h>3P08R8R05EEE@1cLg<0;Bd]01TI6@0G5aL07AdM0451@@1:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE01bLW80][Jf0:BTY01GEeL0MgMg0=GEe@2c/k<0];Bd0;jn_P2/[:`0U9BD0:ZZ
ZP3>c/h0MGEe07moO`22PX80EEEE07UiN@19BDT07AdM01lO7`0P82009RHV03<c<`1hN7P0e]KF08V9
R@1`L700AdM70:j^[P2VYZH0]kNg08:2PP2?Shl0Jf][0492@P0[:b/051@D01DE5@0e=CD0FUYJ05=C
D`1ADE40>3Ph04a<C013@d<0820P01LG5`0m?Cd0UYJF06EUI@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a
/@36a/H0YZJV0;^k^`1XJ6P0<30`06ATI028R8P0ZJVY065QH@0Y:BT0;Rh^06e]K@1^KVh09BDU0P0J
6QX01`0Q8B40<30`03lo?`1eMGD0WIfM030`<00N7Qh00P0M7Ad0500O7al0=cLg02l_;`0N7Qh07AdM
01hN7P0V9RH0Jf][05eMG@1VIVH0Rh^;07]kN`16ATH0PX:201/K6`0L71`08R8R02PX:013@d<0S8b<
4Oooool000oooooo0680HF5Q05UIF@1DE5@0D51@04E5A@0a<C40Cdm?08N7Q`16ATH0BTY:04];B`1N
GUh0;2`/04U9B@0/;2`0FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Bd]051@D01B
DU80>CTi04];B`1EEED061PH03Xj>P19BDT0?Shn02TY:@0H61P0=SHf06=SH`1LG5`08b<S06i^KP0K
6a/0?Cdm03De=@0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01GEeL0Kfm_06QXJ01P
H600=cLg07]kN`1PH600?Shn03dm?@1_Kfl0ATI60492@P0k>c/07AdM02<S8`1kNg/0DE5A024Q8@1@
D500@D5106e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T9206ATI00N7Qh0HF5Q09ZJVP1<
C4`0M7Ad09fMW@0o?cl0>SXj0492@P0g=cL0:BTY09jNWP20P8007QhN03<c<`80E5AD0;h0A4A40:NW
Y`1cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1BDU809bLW04M7A`1[Jf/0Hf=S04m?
C`10@400?Cdm07=cL`1JFUX0I6AT03Xj>P15ADD0G5aL06UYJ@1UIFD0P82002HV9P1IFET0HV9R07mo
O`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0];Bd0IfMW04i>CP0X:2P0SXj>07YjNP0^;Rh0IfMW07Qh
N00e=CD0N7Qh08B4Q00W9bL0Bd];05MGE`0`<300KFe]0:f][@1BDU80<S8b051@D01fMWH0PH61034a
<@1EEED0IFEU05EEE@1XJ6P0T92@05YJFP1LG5`0VIVI07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo
?`1]KFd0@D5108^;R`2OWil0L71`061PH025QHD0D51@03Hf=P1UIFD09BDU03De=@12@T80Ng]k08:2
PP0Z:RX0ATI6059BDP0O7al0LG5a06][J`1UIFD0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI
6@1ZJVX0C4a<06m_K`1NGUh0BTY:08F5Q@21PH40;Rh^03@d=00l?3`0Q8B403Lg=`1BDU80@d=303Ti
>@2DU9@0J6QX034a<@1>CTh0PH6102h^;P19BDT0Kfm_04];B`0U9BD0ADE506][J`0/;2`07AdM08B4
Q01MGEd0C4a<09ZJVP1EEED07alO07=cL`20P800@d=308>3P`19BDT0OWin09bLW01gMgL0>CTi055A
D@1YJFT0>3Ph01@D500a<C40?Cdm01DE5@1@D500YZJV092@T00f=SH0J6QX05=CD`0F5QH0Kfm_08n?
S`0m?Cd0:b/[08Z:RP1RHV80:b/[06MWI`1XJ6P0E5AD05=CD`1EEED0/K6a071`L00j>SX0WinO09bL
W00C4a<061PH04I6AP29RHT0?3`l028R8P1EEED0NWYj7?ooool02`2b/[80XZ:R09ZJVP23Ph<0Zj^[
09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE01L07AdM04];B`1?Cdl0EeMG04I6AP0k>c/0F5QH
06IVIP1OGel0@D51034a<@2j^[X0gMgM0=oOg`39bLT0OWin051@D00b<S809BDU038b<P10@400UiNG
05YJFP0301DE5@0m01LG5`0i>CT0dM7A0>7Qh@3@d=00ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<
0:RXZ01kNg/0MgMg07AdM01[Jf/0IFEU05EEE@0a<C40820P01LG5`0I6AT0820P01/K6`0I6AT0:RXZ
0<;2`P3;bl/0UIFE0=CDe03Hf=P0clo?08V9R@1ADE40BDU904e=C@1XJ6P0NGUi0820P013@d<08B4Q
01`L700V9RH0@T9204I6AP2LW9`0UIFE0:BTY02n_[h0e]KF0<k>cP1nOWh0Lg=c07EeM@1YJFT0L71`
0;^k^`1WIfL0OWin05aLG00201`L702@01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0V9RH
07alO01TI6@0QXJ60<W9b@1nOWh0HF5Q02@T900V9RH0=SHf0410@01OGel0KVi^05]KF`20P800E5AD
02/[:`0J6QX06ATI0451@@2<S8`0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0Fe]K05iNGP1dM7@0RHV9
08J6QP3AdM40dm?C0<C4a02=SHd0GemO05QHF01EEED0Bd];05]KF`25QHD0YJFU0;Bd]01ZJVX0?3`l
04Y:BP1TI6@0O7al09RHV02UYJD0IVIV03Hf=P12@T80LW9b0::RXP0j>SX05ADE01HF5P1;Bd/0>3Ph
06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0N7Qh0ADE508:2PP1QHF40T92@02d];@1TI6@0RXZ:
02d];@0V9RH0Cdm?09BDU01`L700IVIV0<C4a02UYJD0DE5A04Q8B01EEED0>SXj03hn?P23Ph<0_[jn
0=WIf@2^[Zh0DE5A07EeM@1HF5P071`L01dM7@0Q8B409bLW034a<@1YJFT0bLW90;2`/02[Zj/0H61P
09VIV@24Q8@0_Kfm0=SHf01ADE40;Rh^03/k>`1GEeL0Jf][05IFEP0i>CT0F5QH05ADE01HF5P0ADE5
04U9B@0S8b<071`L01HF5P0E5AD0820P04];B`0k>c/0alO70:j^[P2k^k/0^;Rh07YjNP0g=cL0A4A4
0P1VIVH04`30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN03lo?`1WIfL0N7Qh06MWI`17AdL0
B4Q806EUI@27QhL0X:2P09bLW00O7al00P0L71`0100N7Qh07AdM02LW9`0j>SX301dM7@0>02@T901K
Fe/0SHf=08R8R02JVYX0FEUI02DU9@1LG5`0>3Ph01dM7@0S8b<0<S8b07emO@1iNGTAooooo`003ooo
ool0@01YJFT0GUiN04Y:BP1IFET0Fe]K03/k>`0];Bd0IfMW0451@@1NGUh0IfMW03dm?@0`<300JFUY
04i>CP0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP16ATH0K6a/02/[:`0^;Rh0De=C
05eMG@0T92@0@D5102d];@0g=cL0B4Q802<S8`0n?Sh0KFe]03@d=00];Bd0J6QX02/[:`0k>c/0@d=3
06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0L71`03<c<`1KFe/0D51@04=3@`11@D40K6a/
03Lg=`0U9BD0Cdm?06ATI00m?Cd204];B`0>01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02HV9P1QHF40
EeMG04E5A@1?Cdl06QXJ03Ph>027QhL203`l?01506e]K@0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2A
TI40E5AD03dm?@0G5aL07AdM07=cL`1fMWH0?3`l051@D01_Kfl0<c<c03De=@2d];@0SHf=04I6AP1_
Kfl0:BTY06YZJP1IFET0=cLg08B4Q00d=3@0LG5a05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]
KFd0AdM708:2PP1bLW80DE5A05MGE`1PH600?Cdm09FEU@1QHF40Ng]k05MGE`2@T900P820059BDP2[
Zj/0820P04U9B@1/K6`0AdM7075aL@1DE5@09BDU07]kN`29RHT0?Cdm07]kN`1lO7`06QXJ05EEE@2;
Rh/0?Shn0080LG5a08T06ATI03Xj>P1XJ6P0KFe]02HV9P1?Cdl0Ph>30::RXP1YJFT0DU9B069RHP10
@400F5QH0;^k^`28R8P0KVi^0:6QX@1bLW805aLG0451@@1lO7`0Xj>S06IVIP16ATH0VYZJ06YZJP2G
UiL0WIfM06IVIP1fMWH0[Jf]079bLP0U9BD0E5AD03@d=010@400<S8b08:2PP2IVIT0Cdm?04U9B@1D
E5@07alO065QH@1^KVh0L71`0<S8b01FEUH09BDU0861P@1]KFd0F5QH09BDU010@400NGUi05MGE`20
P800@T9207IfMP2BTY80PH610492@P2@T900Jf][07MgM`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/
;2`0DU9B07inOP1DE5@0D51@071`L00b<S809RHV04U9B@1UIFD0IfMW04E5A@1OGel0Fe]K05=CD`2l
_;`0HV9R02/[:`1LG5`0O7al03`l?01lO7`0IfMW0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L
71`0>c/k03lo?`0H61P0=3@d06a/K01EEED0<30`06=SH`1`L700?clo03Ph>01NGUh0Cdm?02d];@2S
Xj<0>CTi028R8P1oOgl0JVYZ07=cL`1TI6@0<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200FEUI03hn?P0Z:RX0JVYZ08V9R@0Looooo`0A04Y:BP2HV9P0[jn_07QhN02l_;`0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80?Shn04E5A@0^;Rh00`0U9BD08`0R8R80<c<c04e=C@1n
OWh0clo?0=oOg`3:b/X0];Bd02LW9`0K6a/071`L01LG5`0Q8B40:2PX04I6AP1fMWH07alO01DE5@0C
4a<04Q8B02LW9`39bLT0^;Rh0;bl_02@T900K6a/05EEE@0@41003@d=030`<01ADE40=cLg02`/;00m
?Cd0?Shn00<0;Bd]02/0;Rh^02l_;`0W9bL0;Bd]03<c<`0X:2P0;bl_07IfMP2m_Kd0YjNW05aLG03F
e]H0gmoO08R8R01JFUX0F5QH05]KF`17AdL0=CDe04e=C@1aLG40[:b/0:FUY@1SHf<0=3@d03lo?`1P
H600E5AD06a/K038b<P0XZ:R08b<S02HV9P0R8R803Ti>@2>SXh0I6AT05YJFP20P800[Jf]05IFEP1Q
HF4092@T00807AdM02<071`L01lO7`0R8R80Hf=S0;Rh^035aLD0[Zj^0:ZZZP24Q8@0]KFe0<o?c`3R
h^80T92@09JFUP1hN7P0JFUY0;6a/@27QhL0NGUi08>3P`1hN7P0C4a<059BDP0l?3`07alO01/K6`0j
>SX0WinO04e=C@0e=CD0KVi^0<k>cP2b/[80YJFU07AdM00206QXJ00Q07MgM`3Cdm<0dM7A0::RXP2]
[Jd0UYJF08:2PP28R8P0RHV904M7A`0[:b/0<S8b0:FUY@23Ph<0UIFE04a<C01?Cdl0D51@06=SH`2^
[Zh0Jf][08J6QP1YJFT0L71`06QXJ01DE5@0H61P04I6AP0U9BD0QhN706i^KP0];Bd07QhN00805aLG
0`0E5AD201LG5`0E03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@0Q8B40@4100:2PX021PH40]KFe
0:n_[`1IFET0Bd];0451@@0a<C409RHV03Hf=P14A4@0ATI60080[Jf]01l0Hf=S04=3@`0L71`07alO
02HV9P0/;2`0=cLg08N7Q`2NWYh0<S8b01TI6@1JFUX0RXZ:06ATI03?cll0][Jf0<O7a`11@D408B4Q
01hN7P0S8b<09RHV04e=C@2b/[80E5AD04i>CP1OGel0>3Ph01TI6@0E5AD05QHF00805ADE02006a/K
03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0:NWY`2RXZ80`l?30=[JfP1^KVh0DU9B
02<S8`0V9RH08R8R02<S8`0m?Cd0U9BD07]kN`1UIFD0Kfm_07MgM`1^KVh0SXj>0:JVYP3:b/X0@d=3
01hN7P807alO01@07AdM01`L700c<c<0<30`01hN7P0S8b<0:2PX0861P@39bLT0_kno08R8R00_;bl0
;Rh^034a<@1oOgl08b<S03<c<`1HF5P0Rh^;02l_;a7ooooo000?ooooo`1:07IfMP2DU9@0DU9B03hn
?P1DE5@0@T920410@01JFUX0=CDe09BDU02`/;00Kfm_02h^;P0h>3P0ADE504m?C`0[:b/0EEEE03hn
?P0V9RH0Fe]K05IFEP0`<300FEUI03hn?P29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K03Lg
=`1EEED09bLW04Q8B01aLG40@410020P801@D5007AdM02LW9`0T92@0ADE503Hf=P1mOGd0AdM702l_
;`0i>CT0EeMG02TY:@1fMWH0F5QH04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0JFUY03Xj
>P17AdL0Fe]K03Lg=`0Q8B40N7Qh06m_K`0b<S80IfMW04Q8B01QHF4204];B`1=06EUI@0W9bL0>c/k
08f=S@0];Bd0=3@d07YjNP0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo0820P01SHf<0:2PX
06i^KP14A4@09bLW04m?C`1^KVh0:BTY02HV9P1ZJVX0TY:B04M7A`1hN7P04Q8B04a<C01RHV80>c/k
06i^KP0C4a<0GEeM05iNGP12@T80MgMg01DE5@1GEeL0Vi^K079bLP1kNg/0>c/k04I6AP1^KVh0C4a<
05mOG`1GEeL0:b/[05]KF`1^KVh0Ti>C05aLG01IFET0JVYZ05aLG02b/[80L71`04Y:BP1ADE40BTY:
08b<S01IFET06QXJ05QHF01fMWH0ADE508n?S`2KVi/0BDU906UYJ@1bLW80ATI606UYJ@1kNg/00P14
A4@0Q`1JFUX0BTY:04m?C`1hN7P0De=C08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2
0;2`/02EUID0D51@03Xj>P1PH600Rh^;04Q8B01aLG40XJ6Q071`L02KVi/0YjNW05UIF@11@D40FEUI
065QH@0];Bd0G5aL03`l?01NGUh0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0E5AD
0;Rh^028R8P0<c<c08F5Q@13@d<0E5AD07QhN01[Jf/0OGem061PH021PH40FUYJ0451@@1DE5@0G5aL
04Q8B02CTi<0IfMW0861P@0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1@D500EEEE
071`L00i>CT0ADE508V9R@2VYZH0PX:204e=C@1[Jf/092@T05YJFP2FUYH0P82005eMG@1VIVH0KFe]
01/K6`1dM7@0QHF50;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0>c/k055AD@0U9BD0?Cdm
075aL@0_;bl09RHV0861P@1jNWX0E5AD05=CD`1/K6`09bLW03@d=02h^;P0De=C01hN7P1jNWX0De=C
06QXJ027QhL0>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0Bd];02<S8`0Y:BT0FUYJ03Lg=`0Y:BT0Hf=S
08>3P`0Looooo`0B04];B`1dM7@0UYJF0:VYZ@3<c<`0TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG
04M7A`0^;Rh08R8R020P800M7Ad06ATI0P0M7Ad03@0L71`07AdM02HV9P1=CDd0^k^k0<o?c`3>c/h0
a<C4071`L01CDe<0HF5Q0492@P0L71`00P0U9BD06@19BDT0B4Q801LG5`0G5aL061PH0451@@3:b/X0
Shn?0<;2`P2j^[X0L71`020P800A4A4051@D0451@@0D51@03Ph>014A4@0D51@05ADE010@400B4Q80
4a<C018B4P0A4A400P0B4Q80AP0G5aL06a/K02/[:`1MGEd0[:b/05=CD`1VIVH0`/;20;:b/P0f=SH0
:2PX03dm?@1>CTh0C4a<04A4A010@400GEeM09JFUP3De=@0_kno065QH@1=CDd0?clo07EeM@2QXJ40
ATI601XJ6P0k>c/0HF5Q0:VYZ@2JVYX0=CDe02@T900F5QH05aLG05ADE02UYJD0M7Ad04i>CP0P8200
7AdM01/K6`0R8R80I6AT0;Fe]@2d];@0JVYZ05aLG01JFUX0Ph>30820P01hN7P0XZ:R0;Rh^030`<00
alO709BDU036a/H0NGUi06a/K02HV9P0Z:RX04Y:BP12@T80QHF505UIF@0_;bl0=cLg0820P02TY:@2
05UIF@0V0<g=c@1fMWH0>3Ph03dm?@16ATH0>c/k0410@02n_[h0alO70:f][@2f][H0ZZZZ08f=S@1B
DU80ADE5020P800^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL071`L01XJ6P1QHF40Ph>306m_K`1`
L700HF5Q0492@P0o?cl0@D5104e=C@2KVi/0VIVI03Xj>P0K6a/701DE5@0`01@D500G5aL0;bl_09^K
V`2SXj<0W9bL05UIF@11@D40DE5A03Ph>02c/k<0dm?C0<K6aP1QHF40Lg=c08V9R@2CTi<0QHF5079b
LP1@D500XJ6Q09jNWP1dM7@0K6a/04m?C`0L71`07AdM028R8P0/;2`0@4100:6QX@1ZJVX071`L01DE
5@0F5QH061PH07=cL`1fMWH0^k^k0;Bd]03IfMT0WYjN05ADE00n?Sh0@T9204a<C01OGel0_;bl0P1P
H600:00S8b<06ATI01DE5@0E5AD061PH01LG5`0I6AT071`L04Q8B02?Shl0FEUI07MgM`24Q8@0/[:b
0;Jf]P1hN7P0O7al0<c<c037alL0bLW90<S8b02g]kL0Cdm?02LW9`0Z:RX0=cLg05IFEP1>CTh0;Rh^
034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe035aLD0WIfM02XZ:P0N7Qh201dM7@0C02<S8`0T92@0
@d=302PX:00W9bL0EEEE0:VYZ@38b<P0a/K60:2PX01CDe<0=cLg03<c<`1TI6@0@41005IFEP2TY:@0
B4Q802PX:00Aooooo`003oooool0@01TI6@0PX:2059BDP1FEUH0EEEE03lo?`17AdL0Hf=S02HV9P0n
?Sh0EUIF06MWI`0c<c<0@41002TY:@1MGEd0>c/k06][J`0R8R8051@D05QHF01cLg<0?3`l079bLP0P
8200GemO07AdM00e=CD0?clo04Y:BP0B4Q80@41005ADE012@T806a/K014A4@1;Bd/0Ph>307AdM00Y
:BT0JFUY01PH6017AdL0=3@d03Xj>P0n?Sh0UIFE07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj05mOG`1Z
JVX0BDU901XJ6P0O7al0J6QX07AdM00k>c/0<30`04I6AP0i>CT206m_K`3P03lo?`0W9bL0QHF506EU
I@0c<c<0Q8B405MGE`1^KVh0EeMG03`l?01kNg/0Cdm?04M7A`2DU9@051@D02/[:`1cLg<0ATI604];
B`2FUYH0;Bd]05MGE`2RXZ80JFUY04Q8B01FEUH0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492
@P1EEED0/[:b06YZJP0l?3`0T92@04E5A@1:BTX0ATI603Xj>P2IVIT0E5AD04U9B@0f=SH0H61P09>C
T`1PH600De=C051@D01KFe/0[:b/06EUI@1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b05MG
E`1gMgL0GUiN0492@P0h>3P0MgMg071`L01FEUH0?Cdm01`L701lO7`0MGEe02`/;01_Kfl0LG5a024Q
8@24Q8@0UYJF03/k>`1VIVH0Kfm_02`/;01:BTX0B4Q804A4A01;Bd/0HV9R03Hf=P0M7Ad0EEEE06e]
K@25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@2NWYh0VIVI06e]K@0g=cL0GEeM08J6
QP1DE5@0<30`06m_K`1UIFD0QHF509ZJVP1eMGD0FEUI071`L020P800=CDe055AD@0U9BD0IVIV0410
@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH04M7A`21PH40J6QX03<c<`1nOWh0DU9B04e=
C@1ZJVX0HV9R071`L01aLG40NGUi08>3P`1KFe/0LG5a07AdM01WIfL0YZJV06EUI@29RHT0:BTY05EE
E@1hN7P0EEEE08:2PP13@d<0>CTi08f=S@2UYJD0GemO05EEE@1cLg<0:BTY01lO7`13@d<0JFUY06m_
K`1:BTX0IFEU05MGE`17AdL0RXZ:08R8R01TI6@0L71`06UYJ@0T92@0E5AD04e=C@2RXZ80PH6104Q8
B00o?cl0EUIF069RHP1JFUX07alO055AD@1[Jf/09RHV04M7A`21PH40Hf=S02XZ:P1YJFT0RXZ:055A
D@18B4P0J6QX0451@@0U9BD0W9bL069RHP0O7al0NGUi0410@01UIFD0Ogmo03Ph>02ZZZX0CTi>02LW
9`1cLg<0TY:B03Ph>00N7Qh09RHV05]KF`18B4P09RHV06MWI`2@T90Looooo`80FEUI01X0LG5a07in
OP2k^k/0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@4009RHV02PX:00W9bL0;Bd]028R
8P0I6AT05aLG01dM7@0P8200Ng]k0:6QX@30`<00eMGE0<S8b080HV9R01@0NGUi08b<S01BDU806ATI
03Ph>01@D500WYjN06][J`1MGEd0LG5a08R8R031`L40UYJF0<K6aP2i^KT0VIVI06YZJP1ADE40NWYj
03/k>`803Ph>00@04A4A01@D500D51@03Ph>0P0A4A4200h>3P0<00d=3@0>3Ph03`l?00h>3P0@4100
4A4A05MGE`0S8b<0@T9209bLW023Ph<04Q8B0P0@4100HP0E5AD06ATI01dM7@0C4a<03`l?02DU9@1P
H600QXJ60;Fe]@2SXj<0V9RH079bLP0W9bL04Q8B014A4@0C4a<06a/K06i^KP1kNg/0JVYZ04M7A`0N
7Qh05ADE01TI6@1VIVH0Zj^[08j>SP0j>SX0=3@d05=CD`2MWId0c<c<0<C4a01EEED0?Cdm0451@@16
ATH0NGUi07emO@1ZJVX0Q8B408R8R02][Jd0X:2P09fMW@31`L40Q8B404I6AP0h>3P0Bd];07alO02=
SHd0TI6A07]kN`1cLg<0HF5Q07emO@3De=@0P82009FEU@2YZJT0FEUI05=CD`0k>c/08B4Q01XJ6P1?
Cdl0`<3004Y:BP1[Jf/0_Kfm07YjNP1^KVh0SXj>07UiN@1GEeL0Cdm?03<c<`0e=CD0De=C04U9B@1L
G5`0MgMg02HV9P0Q8B40>CTi04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0]kNg09BDU01N
GUh07QhN2@0E5AD07P0W9bL0BDU909VIV@2j^[X0_kno0=KFeP3YjNT0d];B0>7Qh@3AdM40dm?C09RH
V01VIVH0@d=303Ph>00f=SH0?Cdm08^;R`3Jf]X0^[Zj04A4A00R8R80@d=303@d=00R8R80:2PX03Hf
=P2NWYh0Cdm?01LG5`<05ADE00l05QHF030`<03Cdm<0dM7A0<k>cP2g]kL0FUYJ069RHP1[Jf/0LG5a
06m_K`1mOGd0SXj>0:VYZ@0`<3000P0E5AD06P0F5QH06ATI01LG5`0J6QX05ADE02DU9@1UIFD0MgMg
07emO@1jNWX0M7Ad09jNWP1EEED0ADE506e]K@28R8P0b/[:0:ZZZP2XZ:P0TY:B06i^KP0W9bL0AdM7
06m_K`1CDe<0:b/[0P0W9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00I0<71`@2KVi/0KFe]01dM7@0N
7Qh0820P02<S8`0T92@0B4Q806QXJ01_Kfl0]KFe0:JVYP2UYJD0d];B0<K6aP2OWil0UiNG09FEU@2J
VYX0YjNW0:>SX`2IVIT09bLW05mOG`0Aooooo`003oooool09@1QHF40IfMW05IFEP1^KVh0De=C02HV
9P0o?cl0OGem04M7A`1FEUH0K6a/075aL@13@d<0FUYJ04Q8B01:BTX0>c/k05UIF@1>CTh0:BTY0451
@@1VIVH0=cLg06a/K00d=3@0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP17AdL0BDU901dM
7@0^;Rh00P1WIfL01`0Y:BT0Ng]k00l?3`17AdL0>3Ph02l_;`0V9RH00P1DE5@0X00_;bl0AdM706QX
J00a<C40Kfm_05=CD`1bLW80J6QX06MWI`1FEUH0EeMG05aLG014A4@0ADE5059BDP0R8R80;Rh^069R
HP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1:BTX0Ng]k065QH@0i>CT0CDe=02l_;`1TI6@0XJ6Q04e=
C@0a<C40Kfm_02DU9@18B4P0SXj>05ADE01SHf<0YJFU08>3P`2DU9@0CDe=075aL@0X:2P0JFUY055A
D@0I6AT0>SXj061PH01KFe/0GEeM0;2`/01bLW807QhN07UiN@1?Cdl0?clo02`/;00M7Ad0JFUY04E5
A@1;Bd/0=CDe034a<@1RHV80LW9b04Q8B01OGel0=CDe04=3@`1BDU80FEUI04=3@`0[:b/0Bd];06IV
IP1>CTh0GUiN04I6AP1FEUH0HV9R05UIF@1`L700EeMG06MWI`1RHV80GUiN03@d=00K6a/0B4Q805QH
F00[:b/0Kfm_0820P00_;bl0Kfm_09JFUP10@400BTY:08F5Q@0d=3@0EUIF06a/K01<C4`0AdM706][
J`1JFUX0;2`/06EUI@1mOGd0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0QHF509FE
U@1^KVh0=SHf06=SH`2OWil0I6AT03Ti>@1lO7`0GemO08j>SP2c/k<0Kfm_05]KF`1bLW80QXJ603/k
>`1BDU80=CDe0410@00g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1UIFD0[Zj^05]K
F`0d=3@0Ogmo04a<C01ADE40QHF504U9B@1ZJVX207moO`1@08F5Q@1WIfL0LW9b06ATI019BDT0VYZJ
0:JVYP28R8P0?3`l05QHF01FEUH0AdM707emO@1FEUH0;Rh^05IFEP27QhL0Fe]K05IFEP2:RXX0EeMG
02TY:@1;Bd/0Hf=S05=CD`1?Cdl0Ph>3079bLP1RHV80L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH
06YZJP2g]kL0];Bd07YjNP0o?cl0Hf=S07emO@1JFUX07AdM03/k>`1UIFD0;Bd]05]KF`2MWId0Ng]k
034a<@1_Kfl0RXZ:04a<C01JFUX0QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80Ogmo
05QHF02j^[X0O7al02h^;P1DE5@0YZJV02l_;`0R8R80=CDe06][J`0h>3P08R8R055AD@20P80Loooo
o`0N0492@P0g=cL0>c/k03dm?@27QhL0EeMG08b<S02l_;`0/[:b0;^k^`3?cll0RHV904i>CP15ADD0
9bLW02DU9@0W9bL0;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50;6a/@2c/k<0_;bl07]kN`0f=SH0
@d=30P1PH6005@1?Cdl0<c<c05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;no_`37
alL0JVYZ01/K6`0M7Ad0:RXZ05ADE00M7Ad03Ph>010@4002014A4@0600h>3P0@410051@D010@400=
3@d03Ph>0P0?3`l02P0>3Ph0410@02DU9@13@d<06ATI04=3@`2ATI40Lg=c01<C4`0?3`l200h>3P0=
010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2UYJD0f=SH092@T00E5AD04A4A01@D5002010@401B
01<C4`0^;Rh0GEeM01PH6018B4P0KVi^02d];@0F5QH0A4A406ATI02o_kl0J6QX075aL@2NWYh0/k>c
09:BTP2CTi<0GemO04i>CP1:BTX0?3`l01lO7`0d=3@0D51@079bLP1/K6`0PH6108n?S`3Fe]H0bLW9
09JFUP0d=3@0<C4a02/[:`1LG5`0[Jf]05aLG00c<c<0@D5104i>CP2FUYH0a<C40;bl_01jNWX0U9BD
08R8R01SHf<08R8R01hN7P0V9RH0LG5a0:6QX@1oOgl0@D510820P01GEeL0;bl_0451@@2ATI40][Jf
01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01OGel0<C4a03Ph>00d=3@0?Shn09ZJVP24Q8@0Cdm?
07EeM@2`/;00e=CD0;no_`1oOgl0H61P01/K6`<05ADE00@051@D01DE5@0E5AD05QHF0P0E5AD07`0I
6AT0Cdm?0:6QX@3Fe]H0i>CT0>GUi@3GemL0i^KV0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D
51@05ADE02d];@2/[:`0TY:B03<c<`0P8200:b/[05mOG`0g=cL0:BTY06m_K`1@D5005aLG01DE5@0G
5aL00P0E5AD0400G5aL09bLW0;^k^`2o_kl0_[jn04m?C`19BDT0Cdm?03hn?P17AdL0Cdm?05aLG01S
Hf<0SXj>05MGE`0M7Ad301DE5@0:01LG5`0E5AD05ADE01hN7P1MGEd0JFUY08>3P`20P800SXj>08>3
P`80@T9202d0>3Ph05EEE@2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0j>SX0D51@
05EEE@1aLG40Kfm_06e]K@3?cll0f=SH0=KFeP2d];@0QHF50;Fe]@1LG5`08b<S02LW9`0b<S80EEEE
05MGE`1?Cdl0Xj>S0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26QXH0WIfM0<O7a`3AdM40OWin
06e]K@22PX804Oooool000oooooo00/0I6AT04E5A@17AdL0GUiN05]KF`0n?Sh0?3`l08R8R013@d<0
E5AD05QHF00202PX:03b07MgM`1JFUX0Bd];03lo?`1gMgL0LG5a03Hf=P1:BTX0FUYJ03dm?@2GUiL0
>3Ph05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P8200BTY:05iNGP0^;Rh0?Cdm07YjNP0Z:RX0
7QhN08J6QP0g=cL0?Cdm04I6AP1_Kfl0=CDe07=cL`12@T80=SHf07emO@27QhL0@41006IVIP0d=3@0
Fe]K08F5Q@1SHf<0C4a<06UYJ@0l?3`05aLG051@D01]KFd0?clo04M7A`1^KVh0;bl_03dm?@1fMWH0
LW9b03<c<`23Ph<04a<C05IFEP1aLG40CDe=055AD@0U9BD0:BTY079bLP1@D500=cLg06m_K`0R8R80
<C4a09RHV01CDe<0Fe]K0:6QX@23Ph<0Ti>C05iNGP18B4P0;Bd]07alO01QHF406ATI04];B`1XJ6P0
>3Ph03/k>`2j^[X0>3Ph02<S8`1UIFD0;Rh^04Y:BP0j>SX0;bl_08F5Q@1<C4`0DE5A03dm?@11@D40
PH6107AdM014A4@0RXZ:06=SH`1WIfL0GEeM055AD@1eMGD0CTi>06UYJ@1gMgL0D51@059BDP12@T80
DE5A06a/K01PH600KVi^065QH@2>SXh0Kfm_06EUI@19BDT0>SXj05UIF@1YJFT0;bl_07QhN02BTY80
A4A407alO02UYJD0A4A405EEE@2BTY80@41006m_K`29RHT0?clo05MGE`2NWYh0M7Ad03Ph>01]KFd0
Kfm_06QXJ01dM7@0EUIF05QHF01TI6@0CTi>09RHV02GUiL0MgMg09ZJVP2QXJ40FEUI055AD@27QhL0
VIVI05MGE`1_Kfl0][Jf06QXJ01jNWX0ZZZZ05=CD`1/K6`0X:2P08^;R`0o?cl0GUiN03Ph>017AdL0
=SHf05ADE027QhL0GemO055AD@1SHf<0;2`/06e]K@1aLG40LW9b0<G5a@1LG5`0<c<c08R8R01CDe<0
DU9B0:ZZZP1GEeL0HF5Q07EeM@21PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN079bLP14A4@0
OGem04Q8B013@d<0W9bL07alO01;Bd/0PX:20:6QX@19BDT0GemO06i^KP0W9bL0A4A407=cL`1oOgl0
IfMW05UIF@1ZJVX0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80MWIf09nOW`2LW9`0
JFUY01hN7P1?Cdl0KFe]05mOG`0N7Qh203/k>`0Q024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P0?Cdm06i^KP1GEeL0<30`09jNWP0i>CT06ATI06IVIP1]KFd0AdM708b<S00a<C40WIfM08>3P`0U
9BD0AdM708Z:RP1JFUX0:b/[01lO7`1?Cdl0<c<c02PX:01>CTh0R8R801cooooo00P0=cLg02d];@0Y
:BT0@D5107]kN`0];Bd09RHV05aLG080IVIV00H0TI6A0451@@0P82004Q8B00l?3`0P8205014A4@0A
01@D500a<C40X:2P05=CD`1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S8b<07alO030`<01NGUh0I6AT
0451@@0i>CT00P0_;bl08`0];Bd0W9bL0:j^[P2MWId0_;bl04e=C@0S8b<06ATI01@D500O7al0=cLg
018B4P0>3Ph03`l?01<C4`0=3@d03`l?00h>3P0@41003Ph>010@400?3`l03Ph>00d=3@0>3Ph07alO
0410@00K6a/0@41008n?S`1kNg/061PH00h>3P0C4a<04A4A00<0410@00/03@d=00h>3P0>3Ph0>CTi
06ATI02SXj<0E5AD014A4@0@41003Ph>014A4@0200h>3P0k020P801LG5`05aLG01DE5@0];Bd0MGEe
04i>CP0h>3P0A4A4061PH03Hf=P0_;bl09ZJVP18B4P0A4A405ADE01LG5`07QhN01TI6@0K6a/05QHF
03/k>`1/K6`0L71`0;:b/P2l_;`0]kNg0=;BdP3=cLd0PH6104I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07IfMP2TY:@0a/K60;Rh^028R8P0M7Ad07IfMP1PH600@D5103<c<`1OGel0Bd];
06ATI02LW9`0KFe]05YJFP0S8b<08B4Q030`<029RHT00P0G5aL0500E5AD061PH02`/;01iNGT0Lg=c
07alO01DE5@0EeMG05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno07MgM`13@d<0ADE5
100E5AD08@0C4a<05ADE01DE5@0E5AD05aLG04=3@`25QHD0_kno0<g=c@3De=@0/;2`04Q8B02QXJ40
g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0:2PX06ATI01OGel0>c/k02DU9@0X:2P0
Bd];07inOP11@D40LW9b01HF5P0501DE5@0B01LG5`0h>3P0/K6a0;bl_02IVIT0MGEe04U9B@1BDU80
SHf=07EeM@1HF5P0=CDe02TY:@1HF5P0JFUY03dm?@0E5AD04a<C100E5AD0=P0K6a/0B4Q806IVIP1o
Ogl0N7Qh08B4Q01SHf<0@d=303Ti>@0R8R80ADE509>CT`1QHF40`/;20:j^[P2XZ:P0`/;206ATI01R
HV80IFEU09:BTP1bLW80DE5A034a<@0c<c<0[Zj^0;no_`2`/;00[:b/096AT@2d];@0/[:b0=;BdP2T
Y:@0WIfM0;Vi^@2o_kl0UIFE09BDU02CTi<0f=SH0;^k^`3:b/X0NWYj02/[:`0V9RH0<30`03Ph>01M
GEd0Z:RX0;Zj^P37alL0K6a/055ADA7ooooo000?ooooo`0A065QH@1aLG40Bd];05=CD`1PH600@d=3
04Y:BP28R8P0?Cdm051@D01[Jf/0IFEU03Hf=P14A4@0@d=303Xj>P0`<3000P1<C4`0_P0X:2P0ATI6
0451@@0T92@0FEUI02PX:00l?3`0GEeM038b<P0o?cl0DU9B01dM7@0k>c/0:BTY03<c<`1EEED0;Rh^
03hn?P1XJ6P0DU9B02<S8`1TI6@08b<S03Ph>012@T80JVYZ03Hf=P2<S8`0?Cdm01dM7@0o?cl0I6AT
03Xj>P1KFe/0CTi>06UYJ@1bLW80D51@0451@@1eMGD0H61P0410@00`<300DE5A030`<018B4P0Fe]K
02XZ:P0g=cL0RHV907EeM@0`<300MgMg04E5A@23Ph<0JFUY03`l?01OGel0C4a<04=3@`2TY:@0C4a<
03De=@1fMWH0@D5104E5A@2[Zj/0@T92055AD@2b/[80NWYj06m_K`1mOGd0Fe]K02@T901hN7P0B4Q8
01XJ6P1MGEd0PX:204U9B@16ATH0/;2`04A4A00Y:BT0M7Ad04=3@`1EEED0@41002/[:`22PX80De=C
05MGE`0o?cl0BDU909>CT`1eMGD0CDe=07YjNP1CDe<0MWIf05mOG`1SHf<0Jf][0410@01XJ6P0OGem
055AD@1KFe/0AdM704Q8B01kNg/0JFUY055AD@0o?cl0QHF506m_K`1KFe/0BTY:02l_;`1IFET0KVi^
02XZ:P1cLg<0NWYj03/k>`1cLg<0WYjN03Ph>01FEUH0Lg=c03@d=01BDU80O7al059BDP1:BTX0KVi^
04Q8B00h>3P0MGEe079bLP1iNGT0FEUI06ATI01oOgl0GUiN04Q8B02WYjL0TY:B05ADE02LW9`0YJFU
071`L00j>SX0HF5Q0:JVYP1KFe/0>c/k071`L01/K6`0R8R80:j^[P1VIVH0C4a<05iNGP1lO7`0;Bd]
04Y:BP0b<S80EeMG03<c<`1BDU80P82003Xj>P1EEED0GUiN03@d=01WIfL0HF5Q03/k>`2UYJD0KVi^
030`<028R8P0De=C04E5A@22PX80F5QH061PH023Ph<207UiN@0L06ATI01cLg<0NWYj04e=C@2MWId0
O7al08N7Q`0`<300GemO06EUI@1>CTh0QXJ604];B`0_;bl0EeMG08b<S01EEED0CDe=05mOG`0b<S80
:b/[04U9B@17AdL0HF5Q05ADE01RHV80DU9B0451@@80NWYj0340B4Q808Z:RP25QHD09RHV04Y:BP18
B4P0VYZJ07UiN@1<C4`0>SXj04];B`1NGUh0Hf=S020P8018B4P0IfMW03<c<`1GEeL0L71`05QHF00Y
:BT0M7Ad065QH@15ADD0De=C08B4Q01?Cdl0:b/[0;2`/01eMGD0:b/[07MgM`1VIVH0?Cdm0::RXP1A
DE40ZJVY08V9R@0U9BD0B4Q808n?S`1IFET0>3Ph04M7A`1SHf<0>SXj02d];@1XJ6P0SHf=01cooooo
00d0<c<c02XZ:P0/;2`0HF5Q0<C4a02HV9P0D51@03lo?`1CDe<0BTY:069RHP0W9bL05QHF00803@d=
00<04a<C00h>3P0<30`00P0>3Ph02P0@41003Ph>01@D501FEUH0>3Ph07MgM`0_;bl0ADE501HF5P0?
3`l200h>3P0:00l?3`0D51@0>CTi01lO7`0G5aL07AdM020P800N7Qh08b<S05mOG`80/[:b00/0XJ6Q
0::RXP20P800HF5Q04i>CP0h>3P0:2PX02LW9`0E5AD03Ph>00l?3`0300h>3P0400l?3`0>3Ph03`l?
014A4@803Ph>00P0410@00l?3`0l?3`0=SHf061PH02f][H0WIfM034a<@@03`l?04d0410@00h>3P0=
3@d04A4A00h>3P0U9BD0B4Q805UIF@1KFe/04Q8B010@400A4A40410@00h>3P0?3`l071`L030`<00f
=SH04A4A01<C4`0J6QX0DE5A0;:b/P2_[jl0aLG50=;BdP2TY:@0CDe=03De=@0X:2P06a/K020P800Y
:BT09bLW01TI6@0V9RH0;bl_02d];@0/;2`0?clo08F5Q@1^KVh0PX:208N7Q`1jNWX0@T9204i>CP1;
Bd/0Hf=S055AD@1<C4`0D51@05aLG01aLG40RHV90:b/[02f][H0UiNG08N7Q`1]KFd0IVIV03Ph>00J
6QX06ATI03Ti>@18B4P0@D5105]KF`2DU9@0Q8B402h^;P0X:2P0:RXZ069RHP0R8R805aLG01`L7002
01/K6`0C01dM7@0`<300FUYJ08j>SP20P800S8b<0:RXZ01oOgl0GEeM04I6AP15ADD0OWin09^KV`2F
UYH0O7al04];B`14A4@0@T9201hN7P0301DE5@0O01HF5P0S8b<0<c<c03Ti>@18B4P0MgMg08J6QP30
`<00a<C408>3P`1>CTh0X:2P0;jn_P3<c<`0alO7061PH01:BTX0DU9B05=CD`1IFET0FUYJ079bLP28
R8P0IFEU05MGE`0k>c/0:b/[03Lg=`1OGel0[:b/03Ph>00301@D500A01DE5@0F5QH06QXJ02/[:`1b
LW80QXJ60:b/[02IVIT0U9BD0410@017AdL0OGem03Hf=P0T92@08b<S020P800_;bl00P1VIVH00`1?
Cdl0=3@d01hN7P0301DE5@0f02LW9`13@d<0C4a<05]KF`1VIVH0F5QH03Hf=P1OGel0FUYJ04E5A@1c
Lg<0Z:RX0:j^[P38b<P0`L710<30`02KVi/0EUIF06ATI01JFUX0>CTi020P800X:2P0Kfm_09^KV`1k
Ng/0BDU904I6AP22PX80P8200:ZZZP2f][H0eMGE0=CDe03?cll0cLg=0<[:bP2c/k<0Shn?0;>c/`3N
g]h0f=SH0;no_`1^KVh0LG5a06][J`2<S8`0/;2`09VIV@3:b/X0g=cL0=gMg@2MWId0V9RH4Oooool0
00oooooo0>X0GemO04m?C`19BDT0C4a<05MGE`0g=cL0>c/k08B4Q014A4@0EeMG05QHF00Z:RX0=cLg
07inOP1:BTX0BDU903<c<`1MGEd0DU9B02@T901IFET0BDU903<c<`1jNWX0<30`03hn?P0f=SH0;Bd]
061PH01QHF40820P0451@@0R8R80@d=3055AD@0N7Qh0;bl_069RHP0`<3006QXJ07AdM00Q8B40;Rh^
04U9B@0a<C40;Bd]09^KV`0i>CT0;2`/061PH01OGel0<30`055AD@0f=SH0KVi^07IfMP1FEUH0ATI6
05eMG@1GEeL0820P02l_;`1DE5@0;2`/03Lg=`14A4@04Q8B028R8P1IFET0GemO02DU9@1`L70092@T
04m?C`1=CDd0<c<c04Y:BP0W9bL09RHV0861P@1ADE40>c/k07=cL`0I6AT0<30`07alO012@T80@410
0:b/[01jNWX0Hf=S08V9R@1NGUh0:2PX08n?S`2@T900;bl_04a<C029RHT0De=C0410@032`/80DE5A
03@d=01cLg<0C4a<04E5A@1<C4`0=3@d08J6QP1^KVh0DU9B051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FUYJ05QHF020P800A4A406EUI@1XJ6P0DE5A04e=C@1<C4`0DU9B07moO`1IFET0IFEU
04E5A@1lO7`0EEEE075aL@15ADD0>SXj04M7A`1MGEd08B4Q061PH02:RXX0BTY:075aL@2LW9`0?3`l
05=CD`2IVIT0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80QXJ606QXJ01kNg/0IfMW
05iNGP12@T80CTi>0:j^[P21PH40Ph>30::RXP2SXj<0EUIF05]KF`2;Rh/0Zj^[071`L00o?cl0NGUi
06][J`1ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE503dm?@1BDU80>3Ph059BDP2EUID0H61P
05=CD`1LG5`0=3@d06=SH`1VIVH0MgMg0:VYZ@1JFUX0<C4a06YZJP12@T80EEEE08n?S`13@d<0EUIF
08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^04I6AP2g]kL0alO708J6QP16ATH0H61P04Q8B013@d<0Shn?
05eMG@0k>c/0G5aL092@T01LG5`0JFUY08N7Q`1>CTh0=SHf05EEE@1:BTX205]KF`0J08:2PP2<S8`0
F5QH05]KF`28R8P0F5QH08:2PP2?Shl0@T9205]KF`15ADD0Xj>S0;^k^`1QHF40AdM704U9B@1IFET0
?Cdm01TI6@1XJ6P0M7Ad03De=@1JFUX0GEeM03Lg=`0Q8B4205]KF`0J03Ti>@1NGUh0K6a/05QHF00V
9RH0/;2`071`L00_;bl0J6QX06UYJ@0c<c<0GUiN03Ti>@2BTY80MgMg03Lg=`15ADD0TI6A05aLG00O
7al06QXJ04];B`0e=CD061PH04Q8B023Ph<Looooo`0=03/k>`0o?cl0AdM706ATI01gMgL0IFEU09BD
U02g]kL0P82006m_K`1bLW80=SHf014A4@0200d=3@0L00`<300=3@d04A4A00l?3`0A4A4051@D01lO
7`0a<C40IFEU09ZJVP2a/K40ZZZZ07emO@10@4007AdM014A4@0>3Ph0410@02TY:@0F5QH05ADE01<C
4`0?3`l0410@014A4@0D51@0<C4a08N7Q`80[Zj^01d0XZ:R069RHP1BDU80E5AD05MGE`1DE5@0@410
03Ph>00N7Qh03@d=00h>3P0B4Q806ATI024Q8@0T92@0820P01XJ6P0C4a<03@d=014A4@0@4100?Shn
08j>SP2HV9P0QhN707inOP1lO7`0BTY:01<C4`0200h>3P09010@400>3Ph03Ph>00h>3P0=3@d07alO
03Xj>P0`<300G5aL0080410@01403Ph>00d=3@0>3Ph03@d=01DE5@0K6a/0EEEE01LG5`0C4a<0410@
01<C4`2<S8`0h^;R0>[ZjP3=cLd0Z:RX02HV9P0401DE5@1D01LG5`0L71`0=SHf030`<00U9BD09bLW
02XZ:P0b<S80HV9R02PX:01<C4`0T92@09JFUP1IFET0DE5A06IVIP1nOWh0Ng]k07inOP1/K6`0De=C
03/k>`0o?cl0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`0G5aL0<S8b04I6AP0d=3@0>3Ph
065QH@2c/k<0VIVI079bLP1OGel0MgMg05YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0<W9b@2XZ:P0MGEe06IVIP1RHV80QXJ609^KV`3IfMT0RHV901hN7P17AdL0Lg=c071`L01ADE40EUIF
024Q8@0K6a/0=CDe04M7A`0f=SH09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW07alO00k>c/0QXJ6
0;Fe]@2i^KT0RXZ:0`0E5AD07P0I6AT092@T03De=@1]KFd0/;2`0;bl_02][Jd0Shn?04m?C`1aLG40
][Jf08^;R`1;Bd/05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0TI6A0;>c/`2RXZ80/;2`07YjNP14A4@0
5aLG01/K6`0b<S80Ph>30410@0<092@T03h0;2`/06i^KP1EEED0ADE505=CD`1>CTh0<C4a02<S8`1>
CTh0B4Q80451@@18B4P0FEUI04U9B@21PH40H61P03De=@0a<C40=SHf07AdM01;Bd/0KFe]0820P02M
WId0gmoO0;bl_01^KVh0>c/k02HV9P0[:b/0[:b/07MgM`0k>c/0:BTY020P800V9RH0Fe]K059BDP2V
YZH0]kNg0;^k^`3Bd]80c/k>0=3@d03?cll0g=cL0<O7a`34a<@0^;Rh08f=S@2<S8`0E5AD09FEU@1b
LW80B4Q807alO02h^;P0`l?30<[:bP2o_kl0UYJF05MGEa7ooooo000?ooooo`0P05iNGP26QXH0BTY:
05QHF01XJ6P0EEEE04M7A`2EUID0FEUI05EEE@1@D500KFe]0492@P10@400BTY:03Hf=P0Q8B40;Rh^
0410@00W9bL0A4A403Ti>@0N7Qh0HV9R02l_;`0c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD203Hf
=P3706ATI00a<C40>3Ph06IVIP1NGUh07QhN05eMG@0G5aL0?Cdm04E5A@1<C4`0@4100;Vi^@1ADE40
<S8b03De=@1?Cdl0ATI603`l?01;Bd/0JVYZ06][J`1BDU80Bd];05YJFP1`L700BTY:02@T901RHV80
<c<c03Xj>P1=CDd0>3Ph0492@P2DU9@0Q8B402PX:01cLg<0>c/k05]KF`0i>CT0=3@d04e=C@0o?cl0
:b/[09JFUP17AdL0>c/k065QH@0d=3@0=CDe0:f][@1CDe<0>SXj0:f][@2<S8`0B4Q807emO@10@400
7AdM07MgM`18B4P09bLW04m?C`2FUYH0E5AD01LG5`2CTi<0EUIF03@d=01iNGT0?Shn06ATI01DE5@0
;2`/07UiN@1LG5`0Fe]K059BDP13@d<0WYjN08F5Q@1IFET0S8b<05aLG01GEeL0FUYJ05EEE@2:RXX0
DE5A06e]K@1bLW80EEEE05=CD`1;Bd/0M7Ad0820P01nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0
ATI604A4A01XJ6P07alO05eMG@2?Shl0BTY:07emO@2JVYX0=3@d05iNGP2CTi<0?Shn05YJFP24Q8@0
GEeM059BDP2@T900Cdm?03<c<`24Q8@0Ph>306a/K01hN7P0K6a/05ADE01KFe/0G5aL0;no_`2/[:`0
QXJ609FEU@2LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B407MgM`21PH40[Zj^06a/K01?Cdl0
S8b<0:b/[013@d<0DU9B03/k>`1<C4`0=SHf05=CD`2@T900GEeM04Y:BP1CDe<0:BTY06=SH`1aLG40
QhN70;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500BDU907QhN01`L700JFUY0861P@1]KFd0
HV9R03Lg=`1hN7P0JVYZ07QhN014A4@0JFUY03De=@17AdL0UYJF069RHP0g=cL0GEeM07emO@0/;2`0
CTi>06UYJ@0f=SH0=cLg05ADE00204E5A@0g030`<01ZJVX0PX:205]KF`1TI6@0Q8B403@d=01eMGD0
YjNW051@D01aLG40FEUI07moO`22PX80JVYZ04Q8B01IFET0IVIV061PH00N7Qh0=SHf05IFEP0k>c/0
TY:B08n?S`1eMGD0:2PX06m_K`12@T806ATI05iNGP27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0
SHf=05=CD`1[Jf/0HF5Q09bLW029RHT0>SXj065QH@2^[Zh0HF5Q02d];@0P8200Cdm?03<c<`0M7Ad0
DE5A08V9R@0Looooo`0=04U9B@0l?3`0=3@d02LW9`0l?3`0Cdm?04U9B@1PH600V9RH0;bl_02OWil0
:RXZ014A4@0300d=3@0401<C4`1JFUX0GUiN04];B`80?Shn00d0@41006e]K@1jNWX0A4A405QHF01]
KFd0MGEe07IfMP1]KFd0Hf=S06EUI@15ADD04a<C0080410@01L04A4A00h>3P0A4A406a/K06ATI015
ADD0J6QX0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04E5A@0R8R803Ph>01DE5@0K
6a/07AdM020P800202TY:@0?03hn?P0];Bd0:b/[06=SH`1mOGd0Ng]k05UIF@1cLg<0FUYJ05ADE01@
D500H61P02<S8`0@41003Ph>0080410@00P03Ph>018B4P0c<c<0<C4a02DU9@1HF5P04a<C00h>3P80
410@0P0>3Ph02`0E5AD07AdM04M7A`0c<c<05ADE01HF5P17AdL0^KVi0=_Kf`3WinL0]KFe0080Kfm_
00<08B4Q01DE5@0C4a<00P0E5AD0E00G5aL0:b/[0451@@0K6a/092@T02/[:`0b<S80Hf=S0451@@1[
Jf/0F5QH065QH@1nOWh0BDU9059BDP19BDT0QHF509RHV02>SXh0TI6A08^;R`2<S8`0JVYZ07MgM`1>
CTh0DE5A05=CD`1KFe/0Jf][04m?C`0m?Cd0;bl_07EeM@0k>c/0>3Ph06][J`1iNGT0>SXj03lo?`1H
F5P0PX:2092@T01lO7`0Ogmo06=SH`1LG5`0K6a/06i^KP1TI6@0RXZ:0=GEe@3Hf=P0b<S80<30`02>
SXh0MgMg059BDP27QhL0YjNW05MGE`0^;Rh0F5QH05EEE@1YJFT0Lg=c0:2PX01MGEd0>SXj02h^;P0_
;bl0RHV907QhN01XJ6P0OWin04A4A00U9BD0<c<c069RHP2PX:00QHF505]KF`1[Jf/0N7Qh01LG5`D0
5ADE02h0?clo04m?C`1cLg<0P8200:n_[`3>c/h0ZZZZ03Hf=P0O7al0EeMG03De=@19BDT0BTY:05aL
G01iNGT0R8R80;Bd]03>c/h0emOG08B4Q027QhL0D51@01/K6`0T92@0<C4a096AT@2l_;`0LW9b03lo
?`0Y:BT09RHV04e=C@1nOWh0BTY:04M7A`1;Bd/0HV9R09:BTP1eMGD0=SHf0451@@1UIFD0VIVI07Ui
N@19BDT07alO0P0K6a/01@0N7Qh0FUYJ04a<C01nOWh0WIfM0080_Kfm02D0[Jf]0<71`@2c/k<0T92@
0;Vi^@1jNWX0=CDe02`/;00R8R807alO03De=@0f=SH0DU9B0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD
0<g=c@3EeMD0a/K608:2PP1]KFd0?Cdm03hn?P1IFET0>CTi07inOP1oOgl0KFe]0;no_`2i^KT0ZZZZ
04Y:BP15ADD0HV9R017ooooo000?ooooo`1<06ATI02EUID0CDe=04A4A01MGEd0B4Q804Y:BP20P800
ADE5092@T02OWil0Shn?051@D018B4P0FUYJ03/k>`16ATH0BTY:03Hf=P0S8b<0BDU905aLG00g=cL0
KFe]028R8P0a<C40K6a/03`l?01BDU80A4A401PH600i>CT0Bd];0410@01NGUh0=cLg03Ti>@1XJ6P0
I6AT02/[:`1KFe/05aLG0492@P1;Bd/0C4a<04U9B@2n_[h0GUiN04I6AP17AdL0FEUI055AD@0g=cL0
Cdm?075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0G5aL03<c<`0l?3`0GEeM04a<C01>CTh0
XJ6Q08>3P`0V9RH0Rh^;04Q8B01eMGD0E5AD03Ti>@80DE5A0380:BTY09fMW@1GEeL0>SXj06a/K01G
EeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:07YjNP1TI6@0<30`08N7Q`0n?Sh07AdM03lo?`1h
N7P0C4a<01/K6`1oOgl0FUYJ04a<C02IVIT0<c<c04];B`1JFUX0<30`07QhN00[:b/0Ng]k06MWI`18
B4P0/K6a05YJFP1;Bd/0TY:B05iNGP1TI6@0GUiN08N7Q`2@T900DE5A06m_K`22PX80CTi>06MWI`80
GemO0:00KVi^06MWI`1ZJVX0De=C08j>SP1GEeL0IVIV05eMG@1HF5P0Bd];07=cL`0`<300QXJ609JF
UP1<C4`0IfMW09>CT`0U9BD0LG5a092@T00b<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2
PP1ZJVX0UiNG08:2PP1TI6@0H61P04M7A`0m?Cd0VIVI08F5Q@1bLW80PH610:FUY@1NGUh0>CTi06][
J`2UYJD0Cdm?05aLG02LW9`0Ph>308Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l05UI
F@14A4@0L71`09JFUP1FEUH0@d=305YJFP0c<c<0Lg=c08>3P`1`L700_[jn05]KF`0c<c<0RHV906a/
K015ADD0QHF5051@D01HF5P0S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80RXZ:04E5
A@1VIVH0>3Ph03lo?`1oOgl0H61P03Ph>01IFET0QHF505ADE01CDe<0HF5Q03dm?@18B4P0MgMg04a<
C01mOGd0BDU905mOG`2;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP0k>c/0UIFE08B4
Q017AdL0=CDe06e]K@2:RXX0Kfm_020P800h>3P0?Shn01hN7P10@400GUiN05=CD`0_;bl0U9BD06=S
H`1?Cdl0?Cdm069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i>CT0DE5A0861P@1^KVh0`<300:2P
X00c<c<0@T9209BDU01SHf<0>SXj02LW9`1=CDd09BDU02HV9P1hN7P0TI6A7?ooool08P0h>3P0<30`
02`/;00U9BD07alO04Y:BP2EUID0P820071`L02=SHd0TY:B02d];@0C4a<03@d=00P8200C4a<03`l?
01`L700V9RH0<S8b03De=@0m?Cd0Jf][0;Bd]01ZJVX0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn
07inOP1[Jf/201<C4`0F00h>3P0@41004A4A01@D501CDe<0>3Ph01dM7@0k>c/0De=C01LG5`0U9BD0
CTi>08^;R`1lO7`0BTY:05UIF@1ADE40@D5103lo?`19BDT0<S8b01dM7@@06ATI00X0;Rh^07QhN020
P800HF5Q059BDP1JFUX0FEUI06UYJ@2c/k<0L71`0P0[:b/0101>CTh0DE5A03@d=00F5QH2010@4006
01/K6`1?Cdl092@T01hN7P1:BTX061PH0P0>3Ph04P0B4Q803Ph>00h>3P0M7Ad0CTi>04E5A@2FUYH0
NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0_kno06i^KP1ADE40L71`03`l?08051@D05L05ADE01@D500S
8b<0?Shn01TI6@0E5AD05aLG03De=@21PH40EEEE04I6AP0_;bl0<C4a05EEE@0F5QH08b<S059BDP1X
J6P0G5aL05UIF@1QHF40Ng]k0;Bd]01cLg<07AdM01<C4`0J6QX0A4A405mOG`1iNGT0MWIf055AD@1a
LG40_kno09BDU022PX80^k^k04U9B@0X:2P0;Rh^03Ti>@2FUYH0W9bL08j>SP1YJFT0Jf][05YJFP14
A4@0@41004E5A@1QHF40c/k>09^KV`21PH40Bd];02HV9P0P82008b<S02XZ:P1YJFT0[jn_069RHP1D
E5@0Hf=S06MWI`1BDU80Ti>C08R8R00W9bL0=3@d06IVIP2BTY80L71`079bLP0h>3P0=3@d03De=@0m
?Cd0C4a<0:6QX@1gMgL0?Shn06EUI@1BDU805ADE01@D500C4a<00`0E5AD02P1CDe<0Fe]K04E5A@16
ATH0B4Q806a/K01iNGT0:2PX02`/;01@D50207IfMP1@07moO`14A4@0>SXj04m?C`2m_Kd0YZJV07mo
O`1^KVh0_Kfm0:b/[01]KFd0OGem08F5Q@1gMgL0LW9b08^;R`2LW9`0RXZ:05iNGP1QHF40Xj>S08>3
P`1_Kfl0Ng]k08J6QP1mOGd0Ti>C04m?C`1`L700U9BD06][J`1oOgl09bLW01/K6`0J6QX06a/K02DU
9@1bLW80Kfm_0:j^[P31`L40W9bL08:2PP20P800Lg=c079bLP2EUID0bl_;03@d=00Y:BT08R8R01dM
7@0Q8B40ADE502d];@1WIfL0[Zj^0:FUY@2][Jd0b<S80<?3``38b<P0]kNg0;jn_P2<S8`08B4Q03De
=@1ZJVX0De=C069RHP1dM7@0L71`05UIF@12@T80Ti>C0;Fe]@1eMGD0<C4a03@d=01<C4`Aooooo`00
3oooool0M01dM7@0QhN7051@D01CDe<0I6AT04e=C@19BDT0T92@04Y:BP15ADD0D51@06e]K@18B4P0
@d=305YJFP0n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d06QXJ00S8b<0<C4a05eMG@10@400
C4a<04];B`0M7Ad0E5AD05=CD`0m?Cd0@41001`L701BDU80MgMg05EEE@0U9BD0F5QH01lO7`1>CTh0
EEEE06ATI014A4@0/K6a06YZJP11@D40A4A4069RHP1FEUH0DE5A05IFEP1mOGd0JFUY02/[:`0V9RH0
Cdm?07AdM015ADD0ATI604e=C@0U9BD0CDe=06ATI018B4P0E5AD0:BTY01ZJVX0820P09^KV`1BDU80
R8R806MWI`0n?Sh0N7Qh06YZJP0/;2`0/k>c0410@01;Bd/0RXZ:05YJFP0m?Cd0_kno051@D00e=CD0
YjNW07MgM`17AdL0TI6A05ADE00X:2P0Rh^;0410@00F5QH0A4A407QhN01<C4`07AdM06ATI00l?3`0
A4A4065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1CDe<0<30`055AD@2HV9P0L71`0P1;Bd/0[00Y
:BT0LW9b05MGE`1?Cdl0I6AT0410@02>SXh0U9BD05=CD`1?Cdl0BDU907EeM@2CTi<0MGEe03dm?@0j
>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0OGem02TY:@1HF5P0M7Ad0410@025QHD0Shn?02d];@1b
LW80S8b<03Ph>01mOGd0LG5a06MWI`19BDT0O7al0451@@0e=CD0QXJ607moO`1/K6`0NGUi061PH01L
G5`0D51@065QH@2`/;00XJ6Q0861P@22PX80]KFe08j>SP16ATH0OGem0:6QX@19BDT0=SHf05aLG01Q
HF40UIFE0<[:bP1gMgL0?Shn05QHF028R8P0<c<c04];B`0g=cL0SHf=03Xj>P1EEED0QHF504a<C01^
KVh0LW9b03Ti>@1@D500MGEe03<c<`34a<@0PH610492@P2MWId0BDU9055AD@2g]kL0E5AD05eMG@2=
SHd0RHV903Lg=`1WIfL0IFEU08j>SP1ADE40_Kfm096AT@2<S8`0B4Q8096AT@1SHf<0EUIF08^;R`1R
HV80?clo0820P02XZ:P0HF5Q05=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0Hf=S08b<S016
ATH0Xj>S08^;R`1?Cdl0HF5Q09RHV00L71`0MGEe06YZJP2VYZH0R8R805EEE@0j>SX0ADE5051@D01C
De<0;2`/06a/K01dM7@092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP17AdL0HF5Q03Hf=P0Y
:BT0OGem069RHP0b<S80DE5A05IFEP13@d<0Kfm_051@D03EeMD0YZJV06YZJP1HF5P0[Jf]03Ti>@0h
>3P0F5QH06MWI`11@D4071`L0492@P1jNWXLooooo`0=038b<P0/;2`09RHV02DU9@0N7Qh0Bd];0<[:
bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0202d];@0;02`/;00K6a/0;Bd]03Ph>00o?cl0D51@065Q
H@1JFUX0GemO08R8R01`L7000P1XJ6P04P0`<30092@T02TY:@18B4P0ATI605eMG@0g=cL04Q8B010@
400D51@05ADE04M7A`19BDT08B4Q01LG5`0X:2P0ADE5014A4@803Ph>02H061PH059BDP1jNWX0DE5A
04M7A`1BDU80E5AD055AD@1MGEd0Fe]K0451@@0R8R806ATI02TY:@1eMGD0K6a/06EUI@1LG5`0<c<c
03`l?01fMWH0FEUI09^KV`1cLg<0BDU902PX:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg
01lO7`0K6a/0@d=302/[:`<03Ph>02/03`l?00h>3P0P8200;Bd]09VIV@2^[Zh0GemO04M7A`1nOWh0
MgMg0:JVYP2/[:`0[Zj^06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02TY:@0M7Ad0
5ADE01hN7P1dM7@0^k^k09^KV`1gMgL0Jf][07YjNP1XJ6P0>c/k03<c<`1]KFd0=cLg04Q8B00a<C40
>3Ph03dm?@1_Kfl0:BTY00805ADE01<04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0Q8B40451@@1kNg/0
P82005iNGP29RHT0T92@08j>SP2HV9P0Z:RX09jNWP2;Rh/0KFe]0080KVi^02L0Ng]k0861P@1fMWH0
YjNW0:2PX02EUID0K6a/03Lg=`0R8R807AdM03De=@0/;2`09BDU08f=S@2][Jd0LW9b05MGE`1>CTh0
O7al07YjNP1dM7@0S8b<09BDU01[Jf/0S8b<05aLG011@D40E5AD05]KF`1TI6@0F5QH069RHP2e]KD0
L71`02/[:`1[Jf/0I6AT01TI6@0E5AD00P0G5aL0@00Y:BT0>3Ph04=3@`20P800K6a/05YJFP1FEUH0
?clo05iNGP0U9BD06a/K04];B`2VYZH0TY:B08J6QP1gMgL0TY:B0<71`@3Bd]80Jf][06UYJ@1^KVh0
UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016ATH0H61P08J6QP2GUiL0E5AD079bLP2GUiL0
alO70<_;b`2g]kL0b<S809nOW`2=SHd0L71`0820P02:RXX0I6AT03Xj>P0Q8B408b<S03Ph>02YZJT0
Rh^;09RHV02PX:00K6a/0;>c/`1^KVh0>3Ph03Ti>@1;Bd/0Z:RX05=CD`0Z:RX201`L700L04U9B@0c
<c<0BTY:069RHP2XZ:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0Q8B40>c/k0<?3``2K
Vi/0Kfm_0:f][@30`<00WYjN05IFEP2n_[h0Z:RX03/k>`0b<S80>c/k03Hf=Q7ooooo000?ooooo`1U
06EUI@1DE5@0C4a<05ADE01FEUH0?Cdm05UIF@2RXZ80EeMG05IFEP1WIfL0Ph>304=3@`0l?3`0=SHf
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ03De=@0o?cl0DU9B03<c<`1;Bd/0E5AD
02DU9@0l?3`0DE5A04E5A@1TI6@0=SHf03<c<`1MGEd0DU9B02<S8`1/K6`06a/K04a<C01NGUh0E5AD
03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80D51@08j>SP1YJFT0AdM703hn?P1?Cdl0QHF5
02PX:00^;Rh0F5QH03<c<`0];Bd0F5QH03dm?@1DE5@0Zj^[06a/K00K6a/0QhN703dm?@1gMgL0Hf=S
03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1jNWX0;bl_02XZ:P24Q8@0De=C03Ti>@2YZJT0SHf=
04Y:BP25QHD0ATI602/[:`2ATI40KVi^01dM7@11@D40NWYj08B4Q00l?3`00P1cLg<0402MWId0Vi^K
04A4A01OGel0J6QX02/[:`1SHf<0DU9B06e]K@1@D500=SHf08b<S01jNWX0D51@08J6QP1FEUH205MG
E`2Y06a/K01lO7`0?Shn05aLG01eMGD0F5QH07UiN@14A4@0ADE507AdM02JVYX0LW9b04M7A`2NWYh0
;Rh^05ADE01bLW80A4A403dm?@1^KVh0:b/[075aL@1YJFT08B4Q09bLW02ZZZX0@T9207MgM`1aLG40
92@T06YZJP21PH40IFEU05]KF`2@T900@d=302d];@1bLW80TI6A07moO`1?Cdl0JFUY09ZJVP1^KVh0
J6QX0:JVYP2BTY80Jf][092@T031`L40MgMg06EUI@2HV9P0]kNg079bLP0g=cL0FEUI065QH@1`L700
X:2P06m_K`10@400BTY:09BDU016ATH0J6QX05ADE01FEUH0Bd];06i^KP2FUYH0=SHf06a/K026QXH0
>SXj05EEE@1UIFD0BDU90:>SX`1YJFT0@d=30:^[Z`0i>CT0<30`05iNGP1OGel0Fe]K08n?S`1hN7P0
B4Q807]kN`1MGEd0MWIf04U9B@2f][H0TI6A07=cL`0e=CD0D51@04E5A@18B4P0Vi^K05]KF`0`<300
Cdm?08^;R`1NGUh0L71`06][J`0j>SX0:RXZ03lo?`1ADE40GUiN04e=C@2TY:@0?Shn024Q8@2CTi<0
Shn?059BDP1cLg<0VIVI030`<01JFUX0BDU909>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0
?Shn05YJFP0V9RH0D51@07moO`1YJFT0=3@d092@T02:RXX0KVi^04i>CP1^KVh0Lg=c03Xj>P2CTi<0
De=C01lO7`1FEUH0HV9R04E5A@1QHF40@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200
I6AT03hn?P0M7Ad0C4a<09RHV00Looooo`0`03@d=00Z:RX09BDU02LW9`19BDT0GUiN0492@P1UIFD0
YZJV09BDU01UIFD0H61P06a/K02<S8`0IfMW02XZ:P0H61P09BDU034a<@0_;bl092@T01dM7@0N7Qh0
<c<c03dm?@1hN7P0Vi^K08^;R`1IFET0<C4a02l_;`1KFe/0@T92038b<P2DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG01DE5@0N7Qh0E5AD014A4@0@41004Q8B0P0>3Ph08P0S8b<0IfMW06UYJ@1G
EeL0<30`04Q8B01XJ6P0K6a/06i^KP1fMWH0SXj>09:BTP1bLW80EUIF05=CD`1BDU80Lg=c07IfMP2P
X:00G5aL07emO@1JFUX0Fe]K04E5A@1;Bd/0EEEE0451@@0c<c<0<C4a03De=@0o?cl0U9BD03<c<`0E
5AD203Ti>@0L010@400>3Ph03@d=00d=3@0?3`l08B4Q01hN7P1oOgl0QHF504i>CP2;Rh/0KVi^05=C
D`1`L700^k^k071`L01/K6`0CTi>06MWI`1NGUh0IVIV07IfMP1`L700Ng]k0;Fe]@16ATH0;2`/03Lg
=`80R8R804@0CDe=07EeM@1/K6`0Hf=S05QHF00U9BD0<c<c05QHF01cLg<0F5QH04i>CP1<C4`0>c/k
038b<P1ADE40O7al03/k>`0D51@04A4A01DE5@0Q8B40@d=308^;R`2QXJ40CTi>01XJ6P0H61P0:b/[
08J6QP2ZZZX0_Kfm09VIV@1WIfL0L71`06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX
04a<C01eMGD0IfMW03dm?@0W9bL0820P04E5A@0b<S80:BTY03Lg=`2VYZH0S8b<0820P01fMWH0WIfM
07QhN01=CDd0S8b<0:j^[P23Ph<0I6AT051@D012@T808R8R01LG5`805ADE02@06QXJ04i>CP1aLG40
;bl_04Y:BP1GEeL07alO01/K6`0/;2`0>CTi030`<00M7Ad08R8R02h^;P1BDU80G5aL04=3@`0d=3@0
De=C04e=C@0G5aL0EeMG096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P82009ZJVP1VIVH0
820P01dM7@0P820201hN7P12020P800U9BD09bLW02PX:01cLg<0Ph>307emO@1jNWX0KVi^0820P02J
VYX0YjNW0;Vi^@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40JFUY061PH01iNGT0`/;20<?3``3@
d=00WIfM0:BTY028R8P0Rh^;069RHP0o?cl0>c/k0861P@29RHT0>SXj030`<01FEUH0CTi>02d];@0^
;Rh0ATI60:JVYP2][Jd0Z:RX0;6a/@2EUID0OWin05YJFP1HF5P0R8R803Xj>P2BTY80Hf=S05iNGP1/
K6`0PX:20:j^[P2c/k<0a/K60<C4a02KVi/0;Bd]034a<@0/;2`0:2PX4Oooool000oooooo08P0JFUY
075aL@17AdL0D51@06UYJ@17AdL0@d=307alO017AdL0FUYJ05QHF00l?3`0@T920820P01VIVH0ATI6
03Lg=`1MGEd0K6a/02XZ:P18B4P0DE5A02<S8`29RHT0D51@03@d=00^;Rh02@T9028R8P1GEeL0>CTi
0410@00g=cL06ATI06ATI00e=CD0>3Ph07MgM`0e=CD04a<C055AD@0W9bL0@T9206=SH`0];Bd08R8R
08^;R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0g=cL0I6AT0410@00d=3@0?Shn04e=C@20P800?Cdm
02TY:@1UIFD0<S8b03Ti>@1BDU80;Bd]03@d=01lO7`0K6a/01hN7P2DU9@0?Cdm04e=C@0f=SH0@410
04Y:BP1CDe<08B4Q09BDU01BDU80=CDe07UiN@1HF5P0<c<c09jNWP1PH600?Cdm0:NWY`2OWil0CTi>
092@T00b<S808b<S08n?S`27QhL0;Rh^04M7A`23Ph<0D51@01hN7P1NGUh0UYJF0:6QX@30`<00;bl_
03Ph>01MGEd0;bl_06QXJ00P8200GemO06ATI00h>3P0Ph>303Lg=`0W9bL0OWin05UIF@1FEUH0@T92
06UYJ@28R8P0DE5A079bLP1`L700:BTY04e=C@1RHV80DU9B065QH@1hN7P0KVi^05=CD`23Ph<0CTi>
0P1GEeL0A01;Bd/0@41007UiN@0b<S80PH6108N7Q`0i>CT0IVIV08V9R@0d=3@0Ph>309BDU00Q8B40
KVi^06ATI00^;Rh0Hf=S09bLW022PX80;Rh^06EUI@1_Kfl0]kNg05=CD`0m?Cd0Ph>308F5Q@1TI6@0
ZJVY0;^k^`24Q8@0NGUi09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0L71`08J6QP31`L40
Q8B40410@00m?Cd0QHF503<c<`11@D40?3`l04U9B@0b<S80PH6109RHV01;Bd/0G5aL06MWI`0T92@0
KFe]08F5Q@1bLW80V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad0P1=CDd0DP2TY:@0Shn?05IFEP24
Q8@0Fe]K07QhN00m?Cd0WinO0;>c/`2ATI40>3Ph065QH@10@400CTi>0:2PX020P800>SXj04a<C023
Ph<0>SXj059BDP1YJFT0AdM702l_;`1>CTh0KFe]04];B`0];Bd0IVIV06m_K`0j>SX0W9bL06=SH`0^
;Rh0EeMG07AdM01@D500GemO05iNGP1dM7@0VIVI06QXJ019BDT0CTi>065QH@1aLG409RHV03Lg=`1:
BTX0<C4a06][J`1_Kfl0F5QH03<c<`1cLg<0N7Qh030`<01ADE40LG5a04e=C@0b<S80Rh^;06=SH`0b
<S80CDe=06YZJP1DE5@0QHF504E5A@2=SHd0V9RH03De=@1mOGd0/[:b05iNGP0/;2`08R8R05aLG013
@d<0<30`06EUI@2EUIDLooooo`0B03<c<`0d=3@0B4Q806EUI@18B4P0=cLg04I6AP1>CTh0HF5Q08B4
Q023Ph<0MWIf0:>SX`2b/[80Rh^;03hn?P0[:b/06a/K0P0E5AD0400C4a<05ADE01DE5@0E5AD05aLG
02@T901TI6@0Kfm_05EEE@17AdL0:BTY03hn?P11@D40:b/[04e=C@2[Zj/2059BDP0808:2PP0k>c/0
7AdM01HF5P0G5aL061PH05=CD`0B4Q82010@400l01<C4`0>3Ph03Ph>00l?3`19BDT0X:2P07MgM`1H
F5P0K6a/08F5Q@2/[:`0b/[:0=CDe035aLD0TI6A06EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b
<S806ATI04E5A@1UIFD0EeMG03lo?`0j>SX0DU9B05mOG`1?Cdl07QhN051@D01?Cdl07AdM03Lg=`1^
KVh05aLG01TI6@0T92@0<S8b03Ph>015ADD0Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S061PH02E
UID0<C4a02l_;`1CDe<0BDU904=3@`1VIVH0NWYj0P2RXZ80B02NWYh0Q8B408^;R`23Ph<0LG5a04I6
AP1FEUH0CDe=069RHP1NGUh0<C4a02XZ:P0M7Ad0820P0451@@1bLW80NWYj06a/K019BDT0;2`/07Qh
N019BDT0De=C061PH01<C4`08b<S01DE5@0f=SH0];Bd0:RXZ01ZJVX0=3@d03hn?P0i>CT0De=C0;jn
_P2e]KD0T92@0451@@1FEUH0BDU906=SH`1@D500;bl_01dM7@0L71`08B4Q06m_K`1dM7@0<C4a05YJ
FP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0;Rh^05IFEP2JVYX0Xj>S09FEU@2BTY80R8R803hn
?P2PX:00V9RH08J6QP0Z:RX05aLG01@D50805ADE01L051@D01DE5@0G5aL0;2`/06][J`13@d<0>SXj
061PH017AdL0<S8b02<S8`0P82008R8R024Q8@0U9BD09RHV02d];@0f=SH0@d=304E5A@0m?Cd0J6QX
030`<002079bLP0f07=cL`24Q8@0;Bd]03@d=00o?cl0CTi>09RHV030`<00d];B0492@P0L71`07AdM
01XJ6P0I6AT061PH01`L700N7Qh0:b/[05IFEP18B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl
0;>c/`22PX80Vi^K04a<C01ADE40G5aL06][J`1jNWX0WinO0:JVYP2d];@0^k^k0=GEe@3GemL0[:b/
04U9B@1TI6@0HV9R08>3P`2>SXh0I6AT05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60P0_;bl06@1ADE40
_kno0:n_[`2BTY80d=3@0>3Ph02f][H0Hf=S06EUI@2VYZH0Q8B40492@P0e=CD0>SXj04M7A`1cLg<0
Jf][0:FUY@3>c/h0c<c<0:VYZ@0_;bl0:2PX02d];@17AdL04Oooool000oooooo02/0O7al09ZJVP1<
C4`0@T9205eMG@18B4P0BTY:06][J`0`<300O7al09RHV01dM7@0<30`02h^;P16ATH0Fe]K024Q8@0_
;bl0GemO03<c<`1@D500FEUI014A4@1ADE40@D5104e=C@1NGUh0:2PX020P800o?cl06ATI04Y:BP1T
I6@0:b/[05IFEP0W9bL0?clo0820P01TI6@07alO05iNGP0O7al0@T920080Bd];01/0=cLg09BDU01Y
JFT0=cLg03lo?`0n?Sh0@d=306EUI@1@D500IFEU04e=C@0f=SH0?3`l05mOG`21PH40=SHf02PX:01Q
HF404a<C024Q8@1UIFD0?Shn03<c<`22PX80LG5a024Q8@1kNg/00P1BDU80=@1DE5@0ADE5061PH01O
Gel08b<S09RHV01MGEd0ADE509ZJVP1YJFT0:b/[08>3P`0g=cL0?Cdm08B4Q02:RXX0BDU906m_K`0f
=SH08B4Q0820P01?Cdl07AdM0492@P1lO7`0MGEe02<S8`1DE5@0WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0DU9B061PH00h>3P0KFe]07EeM@1IFET0UiNG05eMG@1LG5`0?clo04M7A`1a
LG40DE5A06i^KP1ZJVX0C4a<0080FUYJ0:40G5aL0861P@1`L700LW9b04];B`2;Rh/0JVYZ071`L01F
EUH0?Shn04Q8B01bLW808b<S06YZJP1aLG40=3@d05EEE@1lO7`07QhN06UYJ@1jNWX071`L051@D01]
KFd0E5AD04I6AP1XJ6P0I6AT03Lg=`1_Kfl0De=C07IfMP21PH40GemO07emO@1CDe<0<S8b07=cL`27
QhL0Ti>C08>3P`2QXJ40G5aL04e=C@1UIFD0/;2`061PH019BDT0LG5a07MgM`29RHT0ZZZZ08:2PP1;
Bd/0Ogmo08n?S`12@T80EEEE05ADE00o?cl0=cLg05aLG024Q8@0BTY:05EEE@1[Jf/09RHV04A4A01i
NGT0Kfm_0;:b/P1>CTh0>SXj0:NWY`1kNg/0A4A407EeM@1<C4`0;2`/09jNWP2SXj<0E5AD09RHV02[
Zj/0TI6A03Ti>@1dM7@0Hf=S08F5Q@18B4P0O7al0820P01bLW80UiNG07alO016ATH0EEEE09JFUP1N
GUh0E5AD06i^KP1=CDd0>SXj071`L024Q8@0QXJ604e=C@1gMgL0=cLg04I6AP2d];@0RXZ:04Y:BP1Z
JVX0R8R805eMG@1eMGD0IfMW08n?S`2VYZH0GUiN03De=@1SHf<0Q8B406m_K`0U9BD0>c/k04M7A`0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV04A4A01GEeL0@d=303dm?@2ZZZX0PX:203Ph>01Y
JFT0?clo020P801QHF40=3@d092@T02FUYH0@d=305iNGP2NWYh0Cdm?02l_;`0Y:BT0De=C01hN7P0E
5AD0E5AD08>3P`0Looooo`0@065QH@1dM7@0Fe]K03hn?P0o?cl0=SHf02DU9@0I6AT061PH03Xj>P18
B4P0=cLg08N7Q`2l_;`0ZZZZ030`<0806ATI00@05ADE01LG5`0E5AD051@D0P0H61P04P0a<C40B4Q8
06QXJ014A4@0BDU905EEE@1@D500F5QH04i>CP0j>SX09bLW05=CD`3Bd]80bl_;04a<C00T92@05aLG
014A4@805ADE00<0D51@01TI6@0>3Ph00P0=3@d03P0@41003Ph>00d=3@0E5AD0S8b<07inOP0e=CD0
<c<c04E5A@1]KFd0a<C408J6QP1lO7`0>3Ph0P0E5AD0E`0@41009BDU05mOG`0^;Rh09BDU04e=C@0T
92@08B4Q03Hf=P1JFUX0IVIV04I6AP0^;Rh08R8R02TY:@0W9bL0:RXZ05EEE@1jNWX0Vi^K0<k>cP1d
M7@0HV9R05YJFP1=CDd0C4a<04e=C@1eMGD0TY:B08V9R@1VIVH0Bd];04M7A`1LG5`0Fe]K07emO@0c
<c<07QhN01`L700k>c/0E5AD055AD@1WIfL0O7al09VIV@2j^[X0a/K609^KV`2CTi<0CTi>03@d=013
@d<0QHF506EUI@0/;2`09RHV02d];@0G5aL05QHF02h^;P1QHF40MgMg07AdM01[Jf/0P82004=3@`14
A4@0=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP21PH40ADE5034a<@0V9RH0ADE50:6QX@22
PX80TY:B06QXJ012@T80DU9B04a<C002034a<@0I02l_;`0M7Ad071`L04a<C027QhL09bLW071`L02e
]KD0`l?30:6QX@1QHF40D51@03lo?`15ADD0@T9202@T900_;bl0JFUY0:NWY`2?Shl0cLg=0;fm_@2/
[:`0TI6A03Ph>00701DE5@0=01HF5P0Q8B40GEeM05iNGP1DE5@0MWIf05EEE@0R8R808B4Q02DU9@0Z
:RX09RHV01dM7@0201LG5`1201TI6@17AdL0?Cdm03<c<`0h>3P0/k>c09FEU@2WYjL0V9RH09nOW`0o
?cl0A4A404Q8B01=CDd0W9bL0;Rh^02CTi<0N7Qh05UIF@0T92@05aLG01TI6@0K6a/08b<S04A4A01O
Gel0>SXj02XZ:P0S8b<092@T02/[:`0h>3P0UIFE0<c<c02o_kl0[jn_09VIV@3@d=00Shn?09nOW`2C
Ti<0RHV9079bLP1KFe/0EUIF09JFUP1KFe/0T92@0<?3``2YZJT0SHf=05EEE@22PX80XJ6Q0;Vi^@2n
_[h0[:b/0=;BdP3>c/h0Y:BT0:>SX`2?Shl0QhN708b<S02?Shl0GEeM0P1XJ6P05@30`<00OWin08j>
SP2QXJ40YjNW0<S8b01bLW80BTY:0410@016ATH0C4a<065QH@1>CTh0^[Zj0=[JfP3Kfm/0b<S806AT
I015ADD0DE5A07alO00Aooooo`003oooool0o`1PH600Rh^;04a<C00k>c/0DE5A04Q8B015ADD0Jf][
01hN7P0^;Rh0BDU906YZJP0m?Cd0<S8b020P801@D500@D5103/k>`15ADD051@D07EeM@24Q8@0?3`l
069RHP0R8R80=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0^;Rh0B4Q800@4100K6a/0EEEE
06=SH`0V9RH0MgMg014A4@15ADD0AdM701lO7`0D51@0NGUi08F5Q@19BDT0CTi>03lo?`0?3`l0BDU9
05IFEP1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S05ADE00S8b<0>3Ph06QXJ00a<C40=cLg
0820P01;Bd/06QXJ071`L01ADE40EUIF061PH00X:2P0KFe]06ATI00R8R80P82003De=@0`<300Kfm_
05=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0NWYj04I6AP0];Bd0V9RH04Q8B00R8R80Cdm?
08:2PP1dM7@0=CDe04A4A02f][H0R8R805mOG`0j>SX0D51@05YJFP0Y:BT0HF5Q05aLG01GEeL0GemO
03dm?@29RHT0TI6A06=SH`2UYJD0HF5Q055AD@1HF5P0J6QX08R8R019BDT0EEEE07AdM01TI6@0LW9b
06UYJ@1@D500RXZ:07moO`1_Kfl0<c<c07moO`1IFET0LG5a055AD@0h>3P0Bd];075aL@0V9RH0K6a/
07]kN`0a<C40EeMG092@T00l?3`0RXZ:07emO@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph
06UYJ@2ATI40N7Qh07emO@1JFUX0Ph>307AdM01[Jf/0XJ6Q09NGU`1UIFD0PX:209NGU`1[Jf/0AdM7
05mOG`2KVi/0>c/k05EEE@2=SHd0K6a/08:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0EEEE
0492@P18B4P0KFe]09>CT`1HF5P0Cdm?079bLP0j>SX0B4Q806a/K014A4@0[jn_06IVIP0l?3`0Zj^[
04m?C`1BDU80Ogmo06QXJ018B4P0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0Cdm?0;Zj^P26QXH0Ph>3
02@T901ZJVX0R8R807AdM02IVIT0EUIF03<c<`1bLW80Y:BT05aLG01HF5P0IFEU01LG5`0O7al0=CDe
07IfMP20P800CDe=079bLP1MGEd0A4A409BDU01XJ6P0?Shn061PH01bLW807QhN051@D01QHF40QhN7
0;bl_02@T900<C4a051@D01PH600KVi^02/[:`008`1FEUH0JFUY02TY:@18B4P0QHF506IVIP0g=cL0
Z:RX09nOW`1eMGD0ATI605MGE`0J6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_07MgM`0o?cl0
]KFe0:2PX01jNWX0QXJ60;fm_@1gMgL0=CDe02/[:`1MGEd0C4a<02`/;01<C4`0T92@01cooooo00P0
Jf][04a<C01:BTX0>SXj02<S8`0L71`06QXJ01LG5`805ADE00L07AdM06UYJ@2GUiL0Y:BT07inOP1i
NGT0@d=30080<C4a01`0D51@04i>CP0i>CT0?Cdm04e=C@1VIVH0EUIF06EUI@1?Cdl09BDU02TY:@16
ATH0GEeM079bLP1<C4`0=SHf02l_;`31`L40cLg=04I6AP0I6AT05ADE014A4@0@41005aLG05QHF01=
CDd04a<C0P0>3Ph04`0?3`l04a<C00l?3`0G5aL0NWYj09:BTP1nOWh0MgMg07moO`2WYjL0LG5a07Qh
N027QhL0BTY:018B4P0E5AD08b<S06IVIP0_;bl00P0>3Ph0>@0Q8B40@41001`L700G5aL04a<C02DU
9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@27QhL0ZZZZ0:2PX032`/80MWIf05=CD`1HF5P0DU9B03Lg
=`0Y:BT0GUiN08B4Q02PX:00QhN705QHF00o?cl0;Bd]02`/;01/K6`061PH01dM7@0P82009bLW03Ph
>01ZJVX0EEEE04=3@`14A4@0NWYj0<;2`P2a/K40IfMW04];B`1?Cdl0FEUI03hn?P13@d<0AdM702@T
900X:2P0<30`01/K6`0G5aL0@41006QXJ00208b<S00504m?C`0J6QX0<c<c03/k>`0l?3`00P0b<S80
:`1UIFD0a/K607UiN@1iNGT0VYZJ06a/K01TI6@0?Shn07MgM`2<S8`0P82008>3P`26QXH0DU9B06][
J`0`<3007alO01dM7@0U9BD0<c<c034a<@1OGel0MGEe02h^;P1eMGD0WYjN0;no_`34a<@0Ti>C0:>S
X`27QhL0U9BD08n?S`1OGel0M7Ad06m_K`12@T80@D5105QHF02`/;00XJ6Q05IFEP0T92@00P0E5AD0
0`0C4a<051@D01DE5@0301DE5@1W01`L7018B4P0CDe=04I6AP1_Kfl0XZ:R055AD@0l?3`0<c<c038b
<P0];Bd08R8R01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0JFUY0:j^[P2g]kL0_kno06m_
K`1/K6`0GEeM07moO`2GUiL0_kno06e]K@1?Cdl0BDU906=SH`1JFUX0<30`02XZ:P1UIFD0GUiN02h^
;P0R8R80<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX02TY:@0d];B0=OGe`2MWId0BTY:02l_
;`0h>3P0A4A405ADE01JFUX0KVi^02@T900Z:RX0Hf=S05]KF`39bLT0][Jf0:BTY02>SXh0O7al0820
P02FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo096AT@1?Cdl0FEUI096AT@1RHV80@T9203Lg
=`1JFUX0V9RH0<K6aP2SXj<0GUiN06ATI01;Bd/0CDe=06ATI02OWil0fMWI0=[JfP35aLD0_kno0<30
`02LW9`0ZZZZ05]KF`0Aooooo`003oooool02@1QHF40VYZJ04e=C@1KFe/0JFUY04U9B@1=CDd0XJ6Q
055AD@02059BDP0Z08B4Q013@d<0=CDe03dm?@0l?3`0@D5103Xj>P18B4P0410@0492@P1^KVh0>CTi
061PH00];Bd0:BTY04a<C00e=CD07QhN03Ti>@0[:b/0<S8b06ATI00e=CD0C4a<02XZ:P0R8R80Fe]K
05mOG`0U9BD0N7Qh01TI6@16ATH0@D5104e=C@0j>SX0NWYj07MgM`18B4P0CTi>04Y:BP14A4@0EEEE
0P1;Bd/0<`1HF5P0C4a<024Q8@0`<300MGEe04=3@`0Z:RX0F5QH02XZ:P0e=CD0Cdm?02h^;P0e=CD0
MgMg06e]K@0d=3@0FEUI04a<C01HF5P0@D5103De=@1FEUH0HV9R02@T9022PX80FUYJ04U9B@27QhL0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P25QHD0CDe=02`/;02?Shl0@D51024Q8@16ATH0
LG5a06e]K@0d=3@0ATI60;Bd]00m?Cd0IFEU04m?C`0204i>CP2f024Q8@1gMgL0GEeM05IFEP0k>c/0
?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi05mOG`1XJ6P0Ph>304Q8B01ZJVX0SXj>06EUI@1hN7P0
G5aL061PH026QXH0NGUi059BDP0a<C40T92@07moO`1VIVH0FUYJ020P801QHF40S8b<03Ti>@1WIfL0
O7al03Hf=P2<S8`0XJ6Q0410@027QhL0M7Ad03<c<`1`L700MgMg069RHP18B4P0IVIV04];B`14A4@0
IFEU08B4Q022PX80KFe]05MGE`2WYjL0NGUi061PH02KVi/0PH6107YjNP1oOgl0XZ:R06=SH`17AdL0
KFe]0;Bd]018B4P0>SXj06IVIP1NGUh0RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40
IVIV04M7A`1VIVH0S8b<03@d=016ATH0SHf=0492@P14A4@0NWYj03Xj>P2e]KD0EUIF034a<@2FUYH0
Cdm?04e=C@1nOWh0Fe]K04a<C030`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`27QhL0
>SXj05aLG01`L700KVi^09>CT`1]KFd0<30`04U9B@28R8P0E5AD04Q8B01UIFD0BTY:02h^;P17AdL0
OGem07]kN`16ATH0Lg=c05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM05IFEP22PX80
emOG09fMW@1BDU80EEEE06IVIP12@T807alO065QH@1_Kfl09RHV04i>CP1ZJVX0<S8b01`L701cLg<0
QhN706m_K`1:BTX0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0Jf][02TY:@21PH40
YjNW06EUI@2XZ:P0aLG506UYJ@0i>CT0<S8b05eMG@1BDU80:b/[055AD@2LW9`Looooo`0707EeM@18
B4P0<S8b02TY:@0P82006ATI01LG5`0201DE5@0k01<C4`0@4100<S8b09VIV@2PX:00T92@07=cL`0m
?Cd0<30`02l_;`0/;2`09RHV01dM7@0H61P06ATI02`/;00N7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y
:BT0Fe]K06i^KP1`L700S8b<0<S8b03Lg=`0YZJV06=SH`0k>c/0:BTY02PX:00h>3P0JFUY07moO`1M
GEd0B4Q803<c<`0O7al0410@01@D500Y:BT0FEUI01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;
Bd/0De=C02HV9P1MGEd0Kfm_02PX:00>3Ph00`0=3@d0G@0l?3`0;bl_01@D500C4a<03Ph>00d=3@0L
71`0A4A407QhN020P800N7Qh0:^[Z`2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<06e]K@1I
FET0EEEE07moO`22PX80KFe]03/k>`0L71`0:2PX08V9R@0I6AT051@D01DE5@0[:b/07AdM02DU9@1N
GUh0Jf][055AD@2EUID0`l?308>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0@T9201`L700Y
:BT0@41003Lg=`0X:2P0NWYj08n?S`1YJFT0De=C020P800F5QH06ATI02@T900m?Cd0@d=308^;R`2a
/K40Z:RX03`l?02n_[h0emOG0:^[Z`24Q8@0XJ6Q09FEU@2=SHd0QHF506i^KP1hN7P0Fe]K03Ph>00c
<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0Hf=S05aLG01cLg<0SXj>09bLW00204E5A@0=0451@@0h
>3P0ATI60410@00h>3P0>CTi04M7A`1FEUH0=CDe07]kN`2PX:00De=C028R8P0301<C4`D05ADE00d0
6a/K061PH01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?Shl0PH61061PH00o?cl0;Bd]00809RHV05P0
6ATI01`L701KFe/0Q8B40;Rh^01mOGd0dM7A0>c/k03EeMD0Kfm_05YJFP17AdL0GEeM0::RXP1oOgl0
L71`055AD@1?Cdl0Bd];05QHF02GUiL0`/;208>3P`0P820071`L02@T900[:b/07QhN024Q8@0U9BD0
=cLg05]KF`2PX:00QHF50:j^[P1^KVh0^;Rh065QH@0j>SX0B4Q804];B`1?Cdl0JFUY07alO011@D40
8R8R01/K6`0a<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0F5QH07alO01WIfL0PH6108f=S@28R8P0
Cdm?0451@@1QHF40Rh^;05eMG@1dM7@0UIFE05aLG01@D500>SXj0410@01_Kfl0VYZJ08Z:RP2h^;P0
/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0<C4a035aLD0e]KF0=SHf02>SXh09bLW4Oooool000oo
oooo0;`0IFEU06QXJ01:BTX0DU9B05]KF`0b<S80@T9207MgM`19BDT0FUYJ04i>CP1@D500<C4a04E5
A@1DE5@0?Shn03`l?016ATH0Hf=S03De=@1=CDd0NGUi03<c<`1VIVH0?clo03De=@1ADE407QhN02@T
901:BTX0>CTi03@d=01>CTh09RHV059BDP0l?3`09BDU06m_K`1ADE406ATI06m_K`0d=3@0>c/k03Ph
>01[Jf/0?Cdm07MgM`1MGEd0<S8b05UIF@14A4@0>CTi05aLG00l?3`0Cdm?06][J`1^KVh0;2`/03Hf
=P1nOWh0:b/[02HV9P1OGel0ADE504m?C`1HF5P0820P04Y:BP22PX80K6a/055AD@18B4P0BDU906EU
I@1?Cdl0@T9206EUI@13@d<0:2PX07AdM01CDe<0>SXj09nOW`1<C4`092@T09>CT`13@d<0=3@d0:>S
X`2RXZ80BDU906UYJ@0o?cl09BDU0820P01hN7P0;Rh^02d];@1GEeL0JVYZ03`l?01UIFD0NGUi03Xj
>P1LG5`0<c<c04Q8B01KFe/0:2PX06IVIP12@T80DU9B05aLG00`<300G5aL079bLP1:BTX0PX:203Lg
=`1DE5@0DE5A07AdM01`L700?3`l05EEE@1gMgL0>CTi06QXJ01SHf<0E5AD06m_K`28R8P0NGUi04A4
A02>SXh0ATI605UIF@1_Kfl0E5AD04M7A`25QHD0=cLg07MgM`21PH40;Rh^06EUI@29RHT0?clo08:2
PP20P800=cLg07QhN01XJ6P0Cdm?05IFEP2>SXh0J6QX02h^;P1EEED0HV9R0:2PX01JFUX0D51@0:6Q
X@1mOGd0GemO09NGU`2IVIT0PH6108f=S@2RXZ80@d=30451@@1cLg<0/[:b06UYJ@1QHF40Ph>3071`
L01XJ6P0[Jf]07IfMP16ATH0RXZ:09BDU00n?Sh0FEUI03dm?@80@d=306@0LW9b09RHV01?Cdl0C4a<
08b<S00X:2P0C4a<07EeM@1XJ6P0_[jn04i>CP0/;2`0Ti>C06EUI@1FEUH0PH6105ADE01]KFd0e]KF
0:BTY01MGEd0T92@05IFEP1hN7P0>3Ph08j>SP1jNWX0QHF503dm?@1ZJVX0G5aL05=CD`2:RXX0Q8B4
04m?C`1GEeL0Xj>S04Q8B01@D500QXJ6075aL@0a<C40BDU908b<S01?Cdl0=CDe07]kN`1MGEd0EeMG
0;2`/01KFe/0=SHf061PH01`L700GemO05IFEP1RHV80MgMg0;Fe]@28R8P0@d=3061PH026QXH0LW9b
02DU9@0d=3@0Cdm?02TY:@1BDU80JVYZ06m_K`0a<C40R8R8069RHP18B4P0GemO079bLP1/K6`0>3Ph
07moO`1PH600ATI60;:b/P1ZJVX0?3`l08^;R`0h>3P0Lg=c0:j^[P13@d<0YJFU0<71`@1dM7@0=cLg
0451@@1YJFT0@T9203/k>`1[Jf/0W9bL7?ooool02@2=SHd0@T9203`l?00f=SH09RHV01dM7@0G5aL0
5QHF01DE5@0201<C4`0>02HV9P2=SHd0VYZJ07YjNP1FEUH0BTY:028R8P0@41003`l?014A4@0>3Ph0
4A4A01@D500F5QH301LG5`0`01lO7`0^;Rh0>3Ph02PX:00S8b<0BDU90:2PX037alL0eMGE0;fm_@29
RHT0J6QX059BDP1FEUH0HF5Q061PH01NGUh0A4A403lo?`0n?Sh0?Cdm03hn?P1?Cdl0H61P09bLW01?
Cdl09BDU02<S8`0a<C40EUIF08F5Q@1KFe/0Kfm_06=SH`1fMWH0^[Zj0;no_`20P8006a/K018B4P0?
3`l03@d=00`<300N7Qh0LG5a04U9B@0R8R805QHF0P0C4a<0G00J6QX0<S8b08>3P`2g]kL0^k^k0:f]
[@1NGUh0H61P05mOG`1hN7P0K6a/01`L700A4A40>SXj02TY:@0N7Qh0;Bd]06ATI01GEeL0E5AD0492
@P1UIFD0?Shn03@d=00f=SH0A4A405EEE@1=CDd0@d=30492@P2<S8`0QHF507alO02m_Kd0Y:BT05YJ
FP0j>SX0<30`02HV9P0O7al06a/K01DE5@0Q8B40>c/k05=CD`1ZJVX0Ogmo04M7A`0];Bd0?clo06m_
K`20P800I6AT0451@@0l?3`0>3Ph04M7A`1YJFT0a/K60:JVYP2m_Kd0ZJVY0;:b/P26QXH0NGUi0820
P02a/K40WYjN059BDP11@D40A4A407=cL`2JVYX0O7al08F5Q@1aLG40L71`07=cL`22PX80/K6a0<O7
a`2:RXX0F5QH05UIF@1LG5`0]KFe069RHP19BDT09bLW01hN7P0J6QX07AdM0P0O7al0A00Q8B40<S8b
04Y:BP2TY:@0W9bL09:BTP18B4P0=cLg01LG5`0H61P08R8R02LW9`0Z:RX0:b/[034a<@0j>SX0G5aL
079bLP1aLG40RXZ:0:j^[P0k>c/071`L028R8P0[:b/0?3`l04i>CP1GEeL0GemO06UYJ@1kNg/0KVi^
09RHV02m_Kd0YJFU0:ZZZP2e]KD0fm_K0=WIf@2MWId0F5QH04Q8B015ADD0:RXZ034a<@1PH600BTY:
069RHP1iNGT0L71`079bLP1cLg<0LW9b03Ti>@0L71`06QXJ01hN7P0T92@0>CTi04E5A@0i>CT0JFUY
05ADE01GEeL0TI6A061PH02RXZ80GUiN0P1PH600<00e=CD0:BTY02/[:`15ADD0;Bd]03Hf=P0W9bL0
8R8R06a/K01nOWh0F5QH03hn?P14A4@0Bd];05]KF`1PH600J6QX08B4Q01VIVH0H61P06a/K01jNWX0
IfMW07EeM@1dM7@0Ph>305QHF00l?3`0BDU905mOG`1kNg/0Shn?075aL@1BDU80CDe=08F5Q@2SXj<0
aLG508R8R01jNWX0OWin071`L01:BTX0GemO08>3P`2d];@0NWYj06m_Ka7ooooo000?ooooo`0S06EU
I@2MWId0C4a<04M7A`1RHV80AdM704A4A01gMgL0=CDe06YZJP1aLG40NWYj03`l?00[:b/0CDe=0410
@00O7al08b<S065QH@0f=SH0DE5A06=SH`0I6AT0EeMG03Ti>@1;Bd/0JVYZ04A4A00G5aL0?Cdm02d]
;@0l?3`0Kfm_03Xj>P1FEUH00P0g=cL08`1bLW80EEEE02LW9`1aLG40:b/[0492@P10@400H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800B4Q804U9B@1HF5P0=SHf02XZ:P1DE5@0UiNG05]K
F`0U9BD0>CTi03<c<`1/K6`0Ng]k038b<P0];Bd0R8R804e=C@0e=CD0BDU90080IFEU04l0G5aL028R
8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1hN7P0GUiN02d];@35aLD0@d=301dM7@1gMgL0RXZ:05]K
F`1LG5`07AdM01@D501`L700ATI602/[:`0a<C40B4Q806e]K@0J6QX0CDe=06UYJ@1;Bd/0KFe]02XZ
:P0k>c/0NGUi04Y:BP2DU9@0>3Ph04I6AP1iNGT0@T9207EeM@1ADE407alO08^;R`1NGUh0J6QX02d]
;@1FEUH0SHf=04A4A01@D500Jf][01PH600k>c/0O7al05aLG01_Kfl0E5AD05iNGP16ATH0VYZJ065Q
H@1>CTh0Fe]K03`l?01nOWh0RHV9020P801KFe/0P82003De=@1LG5`0QHF502PX:00i>CT0NWYj04e=
C@2BTY80Rh^;0080>SXj08L0F5QH05eMG@19BDT0R8R804a<C01jNWX0RHV9055AD@2NWYh0LG5a04M7
A`26QXH0NGUi06a/K01iNGT0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG01QHF40Ph>30;jn
_P21PH40C4a<069RHP2IVIT0ADE505IFEP0o?cl0JVYZ04];B`1EEED0Ph>303dm?@1IFET0T92@0451
@@17AdL0OWin03<c<`2@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03`l?038b<P0UIFE06IV
IP2h^;P0[Zj^075aL@13@d<0[Zj^07moO`26QXH0ADE50:BTY01aLG40I6AT07YjNP22PX80G5aL09FE
U@2c/k<0KVi^05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0IfMW03<c<`1YJFT0[jn_08B4
Q010@400H61P05eMG@0P8200=SHf0451@@2ATI40`<3007UiN@1OGel0DU9B06e]K@1jNWX0:BTY03hn
?P1OGel08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QHF01CDe<0Rh^;02h^;P0Y:BT0XJ6Q08^;
R`1GEeL0_[jn03hn?P0Q8B40Cdm?02h^;P1UIFD0^;Rh05iNGP29RHT0bl_;065QH@0g=cL0JFUY0861
P@0O7al06a/K04];B`2CTi<07?ooool0502>SXh0Hf=S03dm?@0i>CT0=SHf02PX:00R8R8061PH01DE
5@0C4a<07QhN0492@P15ADD0WIfM08B4Q01[Jf/0F5QH04A4A00[:b/04A4A0P0>3Ph01@0E5AD05QHF
01DE5@0E5AD061PH00805ADE08X05QHF01PH600m?Cd0=CDe0:^[Z`2j^[X0Shn?0<71`@2XZ:P0UIFE
06][J`1GEeL0C4a<05aLG01QHF40JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0=CDe
020P800L71`0Bd];03dm?@2IVIT0Bd];03<c<`0L71`0HF5Q0:b/[028R8P0/;2`0;Fe]@2@T900F5QH
034a<@0H61P04A4A07MgM`2n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Kfm/0`/;2
03<c<`0B4Q804a<C01PH6010@4003`l?00h>3P14A4@0Ph>304i>CP1?Cdl0MgMg0:RXZ02VYZH0bLW9
0:VYZ@0k>c/05QHF01DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad0:n_[`23Ph<051@D
018B4P0I6AT0=CDe034a<@0X:2P0:RXZ03Ph>01>CTh0MWIf09JFUP2h^;P0<C4a01lO7`0Y:BT0Hf=S
0<O7a`2RXZ80>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe0;no_`1lO7`0W9bL092@T012@T80>3Ph
03<c<`1LG5`0DU9B02@T901QHF40_kno0;6a/@1UIFD0BDU903Xj>P0k>c/0ATI604E5A@1VIVH0Ogmo
0;Vi^@1nOWh0GEeM05iNGP1ZJVX0?clo071`L01=CDd2020P800@024Q8@0[:b/07alO01lO7`0_;bl0
J6QX0<[:bP2[Zj/0_Kfm08B4Q01BDU80>3Ph02HV9P0J6QX06a/K01`L708061PH00T05aLG02DU9@2P
X:00[jn_0:f][@32`/80:b/[01PH600A4A400P0F5QH07P0B4Q804a<C01DE5@0E5AD0:b/[07YjNP3>
c/h0d=3@0:NWY`1LG5`0;Bd]05aLG01aLG40f][J079bLP0o?cl0:b/[01lO7`0`<300KVi^08f=S@1a
LG40ATI604i>CP0m?Cd0?Shn03/k>`15ADD0GemO01dM7@805ADE02l06ATI03Ph>01oOgl0YZJV08J6
QP2e]KD0A4A4030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX034a<@0b<S80@D5104M7
A`1OGel0T92@06UYJ@0i>CT0DE5A075aL@2UYJD0[:b/0:ZZZP1/K6`0Hf=S07YjNP1GEeL0Lg=c051@
D01_Kfl0RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700BTY:04I6AP02069RHP050;fm
_@2WYjL0R8R803<c<`0/;2`00P0];Bd0101CDe<0W9bL0451@@1LG5`Aooooo`003oooool08@1JFUX0
QhN705=CD`12@T80@d=30410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820P01<C4`0=3@d02XZ:P1WIfL0
EEEE03hn?P1YJFT0<C4a07alO025QHD0ATI6079bLP0Y:BT0?Shn06m_K`1PH6007alO03Ti>@0Z:RX0
7alO05MGE`0203hn?P0S00h>3P0D51@0EEEE079bLP0Y:BT0MGEe018B4P1;Bd/0DU9B01<C4`0@4100
O7al07emO@1;Bd/0Jf][04Y:BP0>3Ph0F5QH05=CD`1eMGD0MgMg03/k>`0G5aL0:BTY06YZJP11@D40
DU9B05MGE`0S8b<0?3`l05iNGP0_;bl0@41008F5Q@0m?Cd00P0V9RH0[01KFe/0Jf][05ADE00Y:BT0
Jf][06i^KP0`<300U9BD04m?C`0Z:RX0M7Ad028R8P0S8b<0U9BD05YJFP0T92@0UIFE0;Jf]P1OGel0
QhN703De=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];04i>CP1IFET0>c/k07QhN01BDU80
=CDe04U9B@0T92@0KFe]06QXJ019BDT0?Cdm03<c<`1JFUX0KFe]04e=C@29RHT0?Cdm0861P@1PH600
I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0OGem06YZJP1IFET0=cLg096AT@1?Cdl0
FUYJ05UIF@0_;bl0ADE507EeM@0d=3@0K6a/07MgM`11@D40UiNG09ZJVP0o?cl0B4Q80820P00];Bd0
Lg=c08Z:RP1/K6`0AdM705aLG01MGEd0<30`04];B`1WIfL0K6a/06e]K@1:BTX0[Jf]09FEU@1UIFD0
UYJF08R8R01gMgL0QhN70<30`01<C4`0AdM7061PH02XZ:P0Cdm?04Y:BP1_Kfl0IFEU08V9R@3@d=00
X:2P06MWI`1bLW80WinO05]KF`1]KFd0?Cdm04U9B@1:BTX0EEEE08>3P`0h>3P0DU9B08^;R`17AdL0
C4a<075aL@1MGEd0_;bl05QHF00b<S80Rh^;04M7A`1=CDd0HF5Q04a<C01=CDd0bLW9079bLP10@400
H61P05UIF@1QHF40?clo0;6a/@2<S8`0KFe]02PX:01RHV80Fe]K05MGE`1bLW80?clo034a<@1VIVH0
VIVI05UIF@1CDe<0JVYZ03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06a/K010@400FEUI0:RXZ01cLg<0
<S8b05YJFP1GEeL203dm?@0/04A4A02=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1]
KFd0=3@d08J6QP2RXZ80@d=301/K6`1@D500Ogmo034a<@1WIfL0YZJV04];B`0M7Ad0Hf=S03`l?00]
;Bd0O7al07MgM`0f=SH0O7al03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ05=CD`0i
>CT0;2`/05UIF@2EUIDLooooo`1307YjNP2:RXX0@d=303/k>`0`<300:BTY02PX:00S8b<06ATI01hN
7P0m?Cd0;Rh^03lo?`0g=cL0EUIF05mOG`1RHV80Bd];04M7A`0E5AD03@d=00h>3P0D51@05ADE018B
4P0@410051@D01TI6@0k>c/0@41004=3@`1<C4`0Hf=S0<;2`P1IFET0?Cdm08>3P`3AdM40`l?3069R
HP1<C4`0Fe]K04A4A00d=3@0>CTi04A4A01QHF40RXZ:0;6a/@3:b/X0emOG0=SHf030`<008R8R01DE
5@0[:b/0FEUI09:BTP3De=@0_;bl061PH00];Bd0IFEU03De=@0Q8B40:2PX05IFEP0206e]K@1006][
J`1RHV80F5QH09nOW`2m_Kd0TY:B08F5Q@22PX80Ph>307inOP1kNg/0LW9b07EeM@2@T900Zj^[09fM
W@0m?Cd05ADE01/K6`0n?Sh05QHF034a<@1TI6@0Ogmo08b<S029RHT0X:2P0<;2`P2PX:00Q8B406e]
K@1SHf<0FEUI03<c<`0S8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09jNWP2`/;00>3Ph038b
<P11@D40BDU905UIF@1JFUX0GUiN0451@@0R8R807AdM03<c<`2@T900P82007UiN@1XJ6P0Y:BT08Z:
RP1dM7@06QXJ01PH60805ADE03<071`L05IFEP2i^KT0/K6a0:2PX02e]KD0KFe]02<S8`0G5aL05ADE
01TI6@1=CDd0SXj>08R8R027QhL0[jn_06YZJP0e=CD0;bl_02`/;012@T80=SHf03Xj>P1:BTX0YJFU
0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01TI6@0L71`07QhN02PX:016ATH0R8R8
0=?Cd`3:b/X0X:2P05aLG015ADD0820P01LG5`0I6AT07AdM01TI6@0G5aL00P0J6QX01`0K6a/0M7Ad
0;>c/`2[Zj/0`<3002h^;P0O7al01@0E5AD0:`0F5QH05ADE01TI6@13@d<0YZJV08f=S@1lO7`0<C4a
01dM7@0a<C40BDU90<S8b01cLg<0Ogmo08n?S`28R8P0PH6108F5Q@1IFET0Bd];028R8P0S8b<0@d=3
04U9B@0/;2`0:b/[02`/;013@d<05aLG02PX:01HF5P0LG5a06][J`1nOWh0a/K60<o?c`0d=3@0:BTY
04a<C01GEeL092@T02h^;P0m?Cd00P0N7Qh0;@0O7al0?3`l03Lg=`16ATH0QXJ607inOP3@d=00`<30
07moO`2DU9@0VYZJ08R8R01nOWh0FEUI04A4A00i>CT0AdM707EeM@2<S8`0K6a/08^;R`1QHF40<S8b
02PX:00[:b/0<C4a03Ti>@16ATH0FUYJ06a/K00k>c/0FEUI06MWI`29RHT0NGUi09FEU@1ZJVX0<30`
02d];@0Y:BT0:b/[03dm?@1nOWh0<C4a06EUI@0Aooooo`003oooool0_@1JFUX0F5QH0492@P15ADD0
@41003Hf=P1MGEd0MWIf03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW03<c<`0o?cl0@T9203lo?`0j>SX0
20P8069RHP20P800@4100820P00^;Rh0=cLg06IVIP1JFUX0AdM705EEE@0j>SX0;Rh^05ADE01<C4`0
FEUI0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0EEEE04I6AP0J6QX0Hf=S03Ph>00];Bd0
BDU904A4A00Y:BT0D51@030`<01;Bd/0Cdm?05aLG00h>3P0;bl_075aL@0Q8B407alO05ADE016ATH0
EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1@D500YJFU07MgM`0j>SX0MWIf0410@00Y:BT0
UYJF06IVIP0`<300JFUY065QH@0Q8B40_;bl061PH00W9bL0R8R809BDU016ATH0G5aL04e=C@0R8R80
RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q05IFEP13@d<0:RXZ06][J`0o?cl0?Shn04Y:BP0`<300
O7al061PH012@T80E5AD02d];@1KFe/0R8R8065QH@29RHT0DE5A05QHF01?Cdl0GUiN07alO00n?Sh0
ATI606i^KP1UIFD0EEEE04];B`1FEUH0QhN7079bLP1YJFT0Bd];09JFUP1/K6`0Hf=S06QXJ01DE5@0
GemO08R8R00a<C40JFUY08>3P`0c<c<0IVIV08n?S`10@400DU9B08V9R@0b<S80MgMg09:BTP1^KVh0
AdM706ATI01MGEd0?Cdm06m_K`1ADE40K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0
T92@0:j^[P1HF5P0E5AD06e]K@2i^KT0KVi^05]KF`21PH40D51@06ATI02ZZZX0WYjN055AD@1dM7@0
Ti>C02l_;`1]KFd0EeMG05YJFP0205eMG@1S08V9R@1ADE40JFUY0:JVYP1IFET0Rh^;08R8R01mOGd0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B01;Bd/0bl_;08b<S01LG5`0Q8B406e]K@1OGel0
@4100;Zj^P2l_;`0OGem03lo?`1WIfL0BDU905aLG01gMgL0De=C04e=C@1XJ6P0XJ6Q05ADE01/K6`0
N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=309fMW@1DE5@0IFEU0<C4a01fMWH0>3Ph07AdM026QXH0
F5QH04A4A01UIFD0Kfm_0=CDe02/[:`0Fe]K06i^KP26QXH0F5QH01TI6@0a<C40=cLg024Q8@1FEUH0
OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0@41006][J`1/K6`0;Bd]07alO01JFUX0:b/[04a<C01WIfL0
=3@d08:2PP19BDT0RHV905QHF00d=3@0NWYj0:b/[01>CTh0@T9203hn?P1^KVh0?Cdm02HV9P1TI6@0
UIFE01cooooo02L0MGEe08n?S`1BDU80=CDe02XZ:P0T92@09BDU02XZ:P19BDT0EEEE04I6AP0h>3P0
6QXJ018B4P0`<300@T9206=SH`1VIVH0CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph05aLG01TI6@0N7Qh0
:BTY03@d=00a<C40;Bd]07moO`32`/80M7Ad02TY:@0h>3P0J6QX0;Vi^@2@T9000P2ATI408`1QHF40
>CTi01hN7P0M7Ad09BDU04];B`1BDU80DE5A065QH@1_Kfl0[:b/0<O7a`2PX:00N7Qh08F5Q@1mOGd0
OWin08J6QP2j^[X0W9bL09^KV`2DU9@0?3`l02TY:@0M7Ad07QhN03@d=01ADE40@d=302`/;00U9BD0
S8b<03Ph>00T92@0<S8b0080>CTi00h0>SXj03dm?@1;Bd/0U9BD08:2PP0h>3P0LG5a0;Ng]`29RHT0
G5aL06ATI01EEED0Fe]K03De=@80=SHf01L0AdM705aLG01UIFD0RXZ:06UYJ@1UIFD0;2`/02TY:@17
AdL0K6a/075aL@1]KFd0E5AD04i>CP2UYJD0Ng]k04a<C01VIVH0g=cL0:f][@1_Kfl0ATI603Ti>@02
0492@P0=03dm?@0b<S807QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi0;2`/02:RXX0QXJ601`L7002
01LG5`1101`L700Y:BT0Lg=c0;Fe]@2XZ:P0[Jf]0::RXP0h>3P0Fe]K04A4A00V9RH05aLG01/K6`1j
NWX0A4A4051@D02CTi<0[Jf]04Y:BP11@D40=SHf02PX:00U9BD0:RXZ03De=@1SHf<0YjNW0:JVYP39
bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80?clo02/[:`0V9RH0>c/k07UiN@2XZ:P0YJFU0=GEe@3?
cll0Q8B406][J`1=CDd0@41003@d=00S8b<06QXJ01/K6`0L71`061PH02@T901OGel0RHV908n?S`36
a/H0ATI602TY:@0V9RH061PH01DE5@0B4Q800P0E5AD0600G5aL0820P02/[:`2LW9`0UYJF0;Ng]`10
@40071`L02LW9`1LG5`0K6a/01lO7`0Q8B40:BTY05IFEP25QHD0EUIF06][J`1@D5008B4Q01/K6`0Q
8B40ATI6059BDP809RHV03l0D51@05MGE`1QHF40F5QH08>3P`2f][H0^[Zj0:b/[03=cLd0?clo02/[
:`10@400GemO02PX:00Q8B40?clo03De=@0L71`0820P05ADE012@T80K6a/0:2PX02c/k<0clo?0<O7
a`1^KVh0NWYj08f=S@21PH40QhN703Ph>00X:2P0<30`03Hf=P0l?3`0[jn_0;jn_P1eMGD0MgMg05YJ
FP0e=CD0<C4a03<c<`0j>SX0?Shn04m?C`1kNg/0BDU905ADE02=SHd0Q8B405ADE00k>c/0EeMG03/k
>`0m?Cd0@41003/k>`0i>CT0MWIf0451@@1`L7004Oooool000oooooo04D0HV9R09NGU`1=CDd0EUIF
05MGE`13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3@`1;Bd/0=cLg03`l?01bLW80M7Ad
030`<01FEUH0BDU902l_;`1^KVh0>SXj05=CD`0o?cl0820P01XJ6P0g=cL0;bl_02h^;P1>CTh09BDU
04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EEE@0m?Cd0>CTi03Xj>P1CDe<06a/K06a/K01>CTh0=cLg
051@D00e=CD08R8R04i>CP12@T80OWin07AdM01mOGd0@T92038b<P1nOWh0ADE502DU9@1TI6@0D51@
05aLG01XJ6P0:BTY03Hf=P1MGEd00P1GEeL06P11@D40>3Ph05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c
09^KV`1ZJVX0<30`06][J`1VIVH08R8R0;jn_P1WIfL0:BTY08Z:RP1bLW80Fe]K06EUI@0f=SH07alO
08J6QP1>CTh0BDU90P0i>CT0M024Q8@0GemO05MGE`1HF5P0@d=307=cL`0/;2`0?Shn04M7A`0b<S80
O7al05eMG@14A4@0EEEE03Hf=P1_Kfl0W9bL06YZJP25QHD0J6QX06a/K01FEUH0F5QH08b<S01@D500
Fe]K06m_K`1`L700FUYJ061PH01GEeL0RXZ:079bLP1kNg/0CDe=08F5Q@1:BTX0E5AD08Z:RP1TI6@0
GEeM08>3P`0j>SX0S8b<08R8R00i>CT0OWin08F5Q@17AdL0L71`09FEU@0`<300H61P08J6QP0_;bl0
GEeM0:j^[P2;Rh/0@41007=cL`1EEED0GemO09VIV@1KFe/0PH6108J6QP1NGUh0WinO08>3P`2>SXh0
R8R80:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0PX:207moO`35aLD0Ph>305MGE`2<S8`0
[Jf]03/k>`1>CTh0C4a<05ADE01;Bd/0RHV909fMW@1BDU80M7Ad08J6QP0Z:RX0GemO09ZJVP1nOWh0
_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0Ogmo07UiN@18B4P0YZJV07emO@1JFUX0WYjN065QH@1OGel0
:BTY0P1mOGd0B@2>SXh0ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80<S8b04m?C`1c
Lg<0CDe=03hn?P27QhL0SHf=05YJFP0f=SH0H61P03dm?@1aLG40d=3@05eMG@0C4a<0Bd];06MWI`1K
Fe/0GEeM06i^KP1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1DE5@09bLW08N7Q`2S
Xj<0K6a/03dm?@1LG5`0S8b<051@D01>CTh0TY:B08B4Q00o?cl0OWin071`L00k>c/0Cdm?07YjNP0c
<c<0RXZ:04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM707]kN`0n?Sh0;2`/06IVIP2I
VIT07?ooool0301TI6@0Ph>30;Vi^@1[Jf/0?Shn02h^;P0e=CD0Fe]K07UiN@1@D500@D5101LG5`80
4A4A00h04Q8B0492@P0a<C40MGEe06UYJ@1OGel0<S8b01<C4`0A4A4051@D01PH600E5AD07QhN01lO
7`809BDU0;H0D51@0:BTY02CTi<0LG5a03/k>`1[Jf/0IVIV06QXJ00E5AD05aLG02PX:01PH600O7al
05UIF@0S8b<08B4Q02l_;`0e=CD0<c<c03lo?`0h>3P0EEEE0<O7a`2i^KT0GEeM04a<C00j>SX0?Shn
04U9B@1KFe/0XJ6Q08>3P`2GUiL0L71`06][J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300LG5a
03/k>`14A4@0@T9204Q8B017AdL0A4A404=3@`17AdL0LW9b08J6QP1?Cdl09bLW059BDP2SXj<0fm_K
0:2PX01kNg/07alO01`L700_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0Fe]K
06=SH`1MGEd0Hf=S09ZJVP26QXH0S8b<0;2`/02FUYH0^k^k0=KFeP23Ph<0PH6104e=C@0n?Sh0?3`l
03lo?`1DE5@0HF5Q02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Bd]00S8b<07AdM
02@T901HF5P0KVi^09FEU@2CTi<0[Jf]0:NWY`1fMWH07AdM02/[:`19BDT0=cLg01hN7P0O7al0H61P
05]KF`10@400Ph>309BDU01:BTX0D51@05aLG01UIFD0FUYJ06IVIP1DE5@0CTi>0:ZZZP3=cLd0_kno
0<30`01gMgL0ADE5024Q8@0B4Q805aLG06UYJ@0j>SX0;Bd]07inOP2LW9`0MGEe09RHV03EeMD0`<30
04];B`0d=3@0EeMG06i^KP1hN7P0MWIf06e]K@1EEED0=3@d020P800[:b/0J6QX0410@02e]KD0e=CD
0;^k^`1XJ6P0:b/[03hn?P0S8b<06QXJ01lO7`0/;2`0<c<c04a<C02DU9@0gmoO0<g=c@1DE5@0?Cdm
02/[:`0Q8B40JVYZ02/[:`8071`L024092@T03Lg=`1iNGT0FEUI05=CD`1TI6@0:2PX02<S8`0K6a/0
9BDU07EeM@2;Rh/0P8200:2PX02?Shl0P8200:2PX01hN7P0CTi>0410@01EEED0][Jf05MGE`0Y:BT0
>3Ph07IfMP0V9RH071`L02LW9`16ATH0:RXZ02h^;P1mOGd00P2<S8`07P2PX:00][Jf0;jn_P3Fe]H0
WYjN08F5Q@2NWYh0]KFe0<K6aP1HF5P09BDU02LW9`0];Bd0?3`l0:VYZ@2SXj<0QHF508Z:RP2=SHd0
`<300:6QX@21PH40NGUi07inOP2PX:00/;2`05QHF01/K6`0WYjN05UIF@80;2`/00T0Ph>305iNGP13
@d<0@D5104I6AP1RHV80U9BD04i>CP1cLg<04Oooool000oooooo01h0Hf=S0::RXP1>CTh0E5AD061P
H018B4P0ADE509RHV01>CTh0DU9B06][J`2=SHd0De=C04A4A01EEED0=CDe02TY:@0];Bd0G5aL0410
@01]KFd0EeMG02DU9@1RHV80=cLg05=CD`1dM7@0EeMG03De=@13@d<202l_;`3o05iNGP14A4@0DE5A
0492@P0h>3P0G5aL06MWI`0Y:BT0MgMg059BDP18B4P0H61P05YJFP0P8200KFe]075aL@0j>SX0G5aL
04Q8B00W9bL0D51@05QHF021PH40IfMW07inOP10@400;bl_08R8R01IFET0:BTY06ATI013@d<0EeMG
06e]K@12@T80De=C08R8R01JFUX0E5AD055AD@1IFET0NGUi079bLP0i>CT0/;2`07]kN`0d=3@0VYZJ
04a<C011@D40V9RH06=SH`0S8b<0_kno069RHP0f=SH0SXj>07UiN@1PH600JVYZ0492@P0T92@0RHV9
09NGU`1?Cdl0CDe=05=CD`2TY:@0@d=305eMG@23Ph<0E5AD08j>SP1KFe/0?Cdm06m_K`1@D500MgMg
05EEE@1KFe/0MgMg04A4A01WIfL0QXJ605aLG02c/k<0LG5a07EeM@1JFUX0OGem08b<S01HF5P0I6AT
07IfMP1:BTX0HV9R08:2PP1FEUH0MWIf069RHP1lO7`0@D5107IfMP0o?cl0E5AD06EUI@17AdL0H61P
07emO@0P8200IFEU0820P00l?3`0Q8B408:2PP0L71`0D51@08B4Q00n?Sh0QhN70:NWY`0i>CT0>SXj
065QH@1hN7P0AdM708B4Q01GEeL0NWYj08N7Q`1HF5P0Ogmo08J6QP1IFET0TY:B0:f][@2UYJD0U9BD
0<G5a@1mOGd0G5aL07moO`2[Zj/0?3`l04a<C01_Kfl0NWYj08R8R030`<00Jf][02TY:@1gMgL0VYZJ
03lo?`1NGUh0BDU9079bLP15ADD0EUIF09^KV`1=CDd0Ogmo0:6QX@1IFET0M7Ad0:NWY`19BDT0`/;2
08R8R00d=3@0QhN704Y:BP1@D500Q8B408V9R@1EEED0c/k>08B4Q01YJFT0`L710:JVYP1QHF40B4Q8
0:^[Z`2@T900PX:204e=C@2;Rh/0N7Qh05EEE@1HF5P0=SHf02`/;01KFe/0TI6A05ADE01KFe/0MgMg
0451@@0Q8B40Jf][06i^KP1lO7`0A4A406=SH`1ADE40BDU90:6QX@1oOgl0?Cdm04a<C01GEeL0>CTi
03dm?@1PH600UIFE0;Vi^@1eMGD0>CTi06MWI`1/K6`0N7Qh028R8P0k>c/0GEeM03@d=029RHT0W9bL
051@D00k>c/0EEEE09JFUP1<C4`0BDU908N7Q`1hN7P0?3`l08F5Q@1NGUh0?3`l05EEE@1cLg<0?clo
09JFUP12@T80V9RH07]kN`1ADE40^k^k0;bl_01XJ6P0C4a<04i>CP1gMgL0>3Ph000302DU9@1VIVH0
V9RH01cooooo00/0Fe]K0:>SX`2o_kl0Hf=S06ATI01YJFT0MWIf0:VYZ@1nOWh0Ng]k02/[:`0201DE
5@0I010@400>3Ph0:b/[04E5A@0k>c/0MWIf08B4Q020P800;Bd]02l_;`0^;Rh0;Bd]02DU9@0O7al0
71`L024Q8@0i>CT0YZJV07YjNP1>CTh0?Shn01<C4`0S8b<0R8R8038b<P0301DE5@1m01lO7`0F5QH0
BDU908J6QP1NGUh0;Rh^02@T900W9bL0;Bd]03Ti>@0h>3P0WIfM096AT@0X:2P071`L01dM7@0_;bl0
ATI6059BDP2`/;00_Kfm06][J`0^;Rh0=cLg0410@00e=CD0=cLg04M7A`19BDT0H61P0:BTY028R8P0
=3@d03hn?P11@D40<c<c02h^;P0b<S80<c<c04Y:BP2ATI40RHV905MGE`1;Bd/0;2`/04];B`3>c/h0
IVIV06QXJ00U9BD0410@00h>3P0?3`l08b<S05aLG02MWId0ZZZZ071`L02g]kL0Ti>C04E5A@0i>CT0
>3Ph05EEE@14A4@0EeMG08Z:RP3Fe]H0cLg=07]kN`0l?3`0MgMg09BDU015ADD0Jf][03`l?00e=CD0
?clo04U9B@1hN7P0De=C03Ti>@1>CTh0aLG506i^KP27QhL0[Jf]0;Vi^@2_[jl0f][J08N7Q`1oOgl0
WYjN0<71`@1NGUh0YjNW08J6QP1GEeL0C4a<055AD@0_;bl06QXJ01dM7@1<C4`0?Cdm03Xj>P1lO7`0
N7Qh04=3@`2IVIT0:BTY01LG5`0H61P05aLG01HF5P0E5AD07AdM03/k>`1oOgl0d=3@0=?Cd`3Bd]80
QHF506=SH`26QXH00P24Q8@0H`21PH40QhN70;Bd]02b/[80ZZZZ05aLG01cLg<0KVi^0=7Ad@21PH40
>CTi02HV9P0L71`08B4Q03De=@1=CDd0J6QX08F5Q@2CTi<0W9bL09>CT`24Q8@092@T0:FUY@3MgMd0
f][J0<S8b022PX80QXJ606][J`1]KFd0LW9b07alO023Ph<0Q8B409NGU`3Bd]80/k>c05IFEP0U9BD0
=CDe059BDP1YJFT0820P01lO7`0M7Ad0:2PX04Q8B01]KFd0Fe]K03@d=021PH40A4A403@d=00N7Qh0
820P04U9B@3<c<`0]kNg0<_;b`3Fe]H0d];B04];B`1HF5P071`L01XJ6P0/;2`0OGem07]kN`0V9RH0
<c<c07EeM@0d=3@061PH01dM7@0Y:BT0R8R806YZJP1fMWH0RHV908R8R02[Zj/0ZZZZ0:BTY03?cll0
Zj^[0:VYZ@2XZ:P0TI6A0820P01ZJVX0A4A402h^;P0b<S80Cdm?0<O7a`2d];@0ZZZZ05eMG@02051@
D00E06YZJP28R8P0V9RH09:BTP2:RXX0YZJV07inOP2UYJD0MgMg04A4A00_;bl0Hf=S04M7A`0o?cl0
IFEU04I6AP1@D500IFEU08B4Q014A4@0B4Q8017ooooo000?ooooo`3o061PH02JVYX0Cdm?04Y:BP1U
IFD0@d=304m?C`25QHD0;Bd]04m?C`1kNg/0QhN7051@D017AdL0Cdm?0492@P1=CDd0ATI608^;R`1<
C4`0JFUY06i^KP0];Bd0MWIf03lo?`1XJ6P0OGem06ATI016ATH0A4A402l_;`0c<c<0NWYj04e=C@19
BDT0;2`/04E5A@1gMgL0L71`02/[:`25QHD0D51@03dm?@1<C4`0ATI602d];@22PX80KVi^03lo?`1A
DE40?Cdm01/K6`1CDe<0Fe]K09FEU@1_Kfl0>SXj02/[:`1<C4`0Y:BT06][J`0/;2`0CDe=03Xj>P24
Q8@0QXJ604E5A@1DE5@0VIVI05ADE01BDU80PH61069RHP28R8P0N7Qh01XJ6P2IVIT0De=C03lo?`2]
[Jd0De=C02@T9025QHD0J6QX024Q8@30`<00;Rh^03Lg=`2KVi/0V9RH06m_K`1lO7`0?3`l01PH601b
LW80A4A401<C4`0^;Rh0?Shn07AdM019BDT0C4a<03Hf=P0a<C40LW9b061PH00f=SH0C4a<03Lg=`22
PX80GUiN0410@01<C4`0CTi>08N7Q`1_Kfl07alO09FEU@1LG5`0OGem05QHF01:BTX0FUYJ05EEE@2>
SXh0X:2P059BDP15ADD0E5AD05IFEP21PH40EEEE04Q8B00d=3@0Hf=S071`L01OGel0PH6102d];@1U
IFD0O7al03Ph>01_Kfl0L71`03`l?02SXj<0Shn?03/k>`1GEeL0NGUi028R8P1?Cdl0UYJF06IVIP15
ADD0JFUY05aLG00m?Cd0Ng]k04a<C01KFe/0TI6A05QHF02UYJD0R8R805QHF01hN7P0VIVI05iNGP1Z
JVX0XJ6Q05IFEP1fMWH0Lg=c09RHV01<C4`0Fe]K08J6QP1cLg<0PX:20<K6aP24Q8@0ATI608R8R02X
Z:P0ATI605EEE@0n?Sh0FUYJ04M7A`1IFET0Q8B403<c<`1fMWH0QHF505MGE`2<S8`0JVYZ05=CD`2m
_Kd0IfMW03@d=024Q8@0I6AT05]KF`1OGel0Q8B405iNGP3?cll0Rh^;059BDP1dM7@0Q8B408R8R01D
E5@0[:b/092@T02BTY80AdM707QhN02;Rh/0M7Ad061PH01`L700ADE507IfMP2/[:`0I6AT05QHF02>
SXh0P820030`<01_Kfl0QHF508B4Q01>CTh0IFEU06i^KP1JFUX0]KFe08V9R@10@400GemO05ADE012
@T80?clo06=SH`2:RXX0`l?307MgM`1HF5P0MgMg07QhN01mOGd08B4Q000503/k>`1IFET0=cLg09RH
V02ATI400P0i>CT0501UIFD0UYJF04A4A00f=SH0Kfm_075aL@0l?3`0YJFU08>3P`0d=3@0DU9B05UI
F@0i>CT0UIFE04M7A`2BTY80MWIf03<c<`1lO7`0S8b<0P13@d<01P1IFET0KFe]03Hf=P0];Bd0QHF5
0:FUYAcooooo00d0/K6a0:ZZZP1fMWH0DU9B02DU9@0Q8B40<S8b092@T02CTi<0Lg=c024Q8@0I6AT0
4Q8B00803Ph>00T03@d=03Ti>@10@400F5QH09JFUP2QXJ40BTY:0451@@0i>CT00P0j>SX03@0m?Cd0
CTi>06QXJ02][Jd0UYJF04M7A`10@400<c<c01<C4`0];Bd0MWIf01/K6`0A4A400P0E5AD05P0M7Ad0
5QHF018B4P0O7al0BTY:06UYJ@1BDU80<S8b02XZ:P0^;Rh0;bl_09FEU@2:RXX06QXJ01`L700O7al0
9bLW038b<P13@d<0Ti>C0=GEe@2=SHd201lO7`08020P800X:2P09BDU028R8P0d=3@0:2PX06a/K01d
M7@202XZ:P0T01lO7`0Z:RX0AdM7061PH01HF5P0=SHf02<S8`1MGEd0IFEU05IFEP1OGel0KFe]0;Bd
]02TY:@0R8R805YJFP0O7al0;Rh^05QHF01MGEd0AdM706e]K@1KFe/0OGem0;Vi^@2IVIT0Bd];05EE
E@1gMgL0UIFE06YZJP1UIFD0Bd];0:BTY020P800Q8B40P0P82001@1ZJVX0Shn?05iNGP2UYJD0MWIf
0080JFUY0280Vi^K069RHP15ADD0V9RH0=GEe@26QXH0Xj>S0<_;b`32`/80_[jn0<c<c032`/80b/[:
0=;BdP2WYjL0UYJF05iNGP0`<30071`L01/K6`0l?3`0Bd];01lO7`0G5aL07AdM059BDP2MWId0V9RH
08j>SP1GEeL0N7Qh01PH600J6QX05aLG1@0E5AD0B@0d=3@0d];B0;2`/01bLW80_kno059BDP0Q8B40
820P02PX:00g=cL0HF5Q0<?3``2k^k/0K6a/05eMG@0h>3P0B4Q80=cLg01kNg/09bLW03Hf=P0L71`0
8B4Q01`L700M7Ad092@T03Ti>@1<C4`0M7Ad0<?3``30`<00TY:B0;Jf]P3Ng]h0_Kfm0;>c/`2h^;P0
R8R806][J`16ATH0=3@d030`<00Y:BT0:RXZ02`/;02FUYH0_Kfm05=CD`0e=CD0;2`/06MWI`0o?cl0
>c/k0492@P1GEeL0AdM7038b<P0`<300I6AT04M7A`1fMWH0G5aL05IFEP0n?Sh0ATI608N7Q`2_[jl0
Zj^[075aL@1[Jf/0^KVi065QH@0I6AT00P0E5AD08@0L71`0@T9207EeM@1@D500;bl_06i^KP1QHF40
71`L02<S8`19BDT0M7Ad08>3P`2<S8`0YZJV0:VYZ@33`l<0[Zj^09nOW`2[Zj/0PX:209BDU02BTY80
/k>c08j>SP1eMGD0PH6106UYJ@2CTi<0_[jn0=oOg`3Jf]X0`L7106IVIP0205UIF@0E05eMG@1GEeL0
HF5Q07=cL`2DU9@0^KVi0;^k^`2o_kl0J6QX055AD@1SHf<0<S8b01dM7@0S8b<09RHV069RHP1hN7P0
U9BD08:2PP1KFe/07AdM017ooooo000?ooooo`0L05IFEP28R8P0DE5A04Y:BP12@T80;2`/05=CD`1]
KFd0<30`03Hf=P1MGEd0IfMW04Y:BP1EEED0:BTY04m?C`19BDT0C4a<05EEE@0/;2`0S8b<07MgM`0]
;Bd0IFEU02DU9@1NGUh0QhN707IfMP80DU9B0?l0:BTY02HV9P1RHV80F5QH04E5A@0D51@061PH04E5
A@1UIFD08b<S08J6QP0G5aL0=SHf03`l?0071`L0820P065QH@1TI6@0>3Ph06e]K@1cLg<071`L03<c
<`19BDT0Vi^K09bLW010@40071`L02l_;`1hN7P0AdM704m?C`1NGUh07alO03Ph>01EEED0>3Ph07Ui
N@2f][H0FUYJ02/[:`1KFe/0@T9207moO`21PH40>c/k0:f][@1EEED09BDU07alO01KFe/0;bl_07in
OP0k>c/0BTY:0<;2`P1BDU809bLW07EeM@26QXH0=3@d06e]K@1;Bd/071`L0820P01<C4`092@T02XZ
:P0g=cL0NGUi0451@@17AdL0A4A402/[:`1NGUh0:2PX04Y:BP1ADE40;Rh^07MgM`1UIFD0DE5A04i>
CP0a<C40FEUI08Z:RP1NGUh0RHV905=CD`1EEED0GemO05EEE@1[Jf/0De=C06e]K@1fMWH0Jf][04U9
B@1RHV80EEEE07YjNP1IFET0JVYZ051@D01JFUX0MGEe075aL@1oOgl0DE5A06YZJP23Ph<0<C4a071`
L01_Kfl0?3`l09bLW02=SHd0?Cdm05EEE@24Q8@0<30`051@D02RXZ80Jf][0492@P1VIVH0PX:204=3
@`20P800K6a/071`L01:BTX0A4A4096AT@2HV9P0Lg=c092@T02EUID0Rh^;07YjNP2FUYH0ATI606a/
K01bLW80WYjN05MGE`1IFET0T92@06IVIP2HV9P0e]KF09>CT`1ADE40RXZ:0:j^[P1@D500M7Ad065Q
H@1EEED0ADE505aLG01kNg/0>CTi08:2PP2;Rh/0Hf=S0:RXZ01TI6@0KFe]0:^[Z`0l?3`0;Bd]09RH
V01SHf<0J6QX06ATI01GEeL0D51@0<c<c02CTi<0LW9b0:6QX@28R8P0HF5Q0492@P34a<@0YJFU08n?
S`1>CTh0O7al09FEU@1^KVh0EEEE07]kN`19BDT0Lg=c0:JVYP1XJ6P0GemO08b<S01kNg/09RHV07If
MP2FUYH0OGem04m?C`1fMWH0Kfm_04a<C02KVi/0RHV904U9B@1KFe/0I6AT059BDP12@T80Kfm_08J6
QP32`/80L71`05UIF@1cLg<0IfMW07inOP0Q8B40?clo06MWI`0d=3@0TY:B09>CT`0o?cl0<C4a0:JV
YP2RXZ80IfMW03@d=01dM7@0;bl_02d];@2DU9@0Rh^;030`<018B4P0K6a/03`l?02<S8`0BDU909:B
TP1`L700GUiN075aL@2YZJT0BTY:04U9B@2DU9@000D0Jf][01lO7`0g=cL0UiNG09VIV@0Looooo`0G
0:f][@2WYjL0HV9R07]kN`1ADE40HV9R0:ZZZP24Q8@0FUYJ0:JVYP1=CDd0AdM702LW9`0E5AD0410@
00d=3@0?3`l0Kfm_06UYJ@10@400FUYJ018B4P0=3@d00`0>3Ph0H@0@41004a<C01lO7`2<S8`0J6QX
03`l?00];Bd0<c<c01dM7@1VIVH0Cdm?01LG5`0@41004a<C014A4@0J6QX07AdM018B4P0>3Ph04a<C
02@T901HF5P0Ng]k06IVIP0d=3@0;Rh^07moO`2:RXX07AdM01HF5P0Q8B409bLW02TY:@1:BTX0MWIf
0=CDe03<c<`0PH6104i>CP0d=3@08b<S01hN7P0O7al0<c<c03lo?`23Ph<0Ogmo034a<@0g=cL0AdM7
05EEE@15ADD07alO01HF5P0G5aL05ADE020P801TI6@0EeMG06a/K01>CTh0UYJF08^;R`1LG5`0:b/[
08N7Q`1EEED0;Bd]01hN7P0M7Ad0:2PX020P801@D500];Bd0:FUY@1[Jf/0KVi^092@T038b<P0`L71
06MWI`1BDU80L71`02LW9`19BDT0?Shn01TI6@0h>3P0TI6A0;fm_@2f][H0Ti>C05iNGP1JFUX0I6AT
075aL@2CTi<00P3>c/h06`2?Shl0RXZ:09FEU@2b/[80[jn_075aL@1KFe/0Ph>30:BTY02h^;P0bl_;
034a<@0G5aL051@D01TI6@0Q8B40C4a<04E5A@0M7Ad05ADE03Xj>P2f][H0VIVI09FEU@1lO7`0>3Ph
01HF5P0201DE5@804a<C0`0E5AD05`0`<300Ng]k06MWI`27QhL0[Jf]07alO01^KVh0DE5A03Lg=`16
ATH0=cLg0861P@2e]KD0GemO038b<P18B4P0[:b/0=kNgP2HV9P06QXJ03@d=00X:2P09RHV00807AdM
00h09RHV03Ph>01=CDd0D51@0:^[Z`2o_kl0f=SH0>[ZjP3YjNT0V9RH0:^[Z`1eMGD0J6QX06][J`<0
LW9b01l0R8R809BDU02l_;`0fMWI0=kNgP2:RXX0De=C06EUI@0a<C408b<S04E5A@1fMWH0LW9b02HV
9P0X:2P0:b/[075aL@1nOWh0Cdm?04i>CP1lO7`0RHV9096AT@2^[Zh0S8b<04U9B@1CDe<0FUYJ04a<
C02:RXX0:2PX00805ADE02X061PH02XZ:P1cLg<0MWIf03lo?`17AdL0`L7108^;R`2:RXX0PH6107=c
L`2d];@0GUiN0492@P1kNg/0/;2`04a<C01nOWh0DU9B03hn?P1;Bd/0DU9B03Xj>P0g=cL0D51@04e=
C@1kNg/0gmoO0=CDe02SXj<0^[Zj0=SHf034a<@0VYZJ04Y:BP0Q8B406a/K020P800S8b<0<C4a06i^
KP2EUID20:JVYP0<05MGE`0O7al07alO01hN7P0S8b<0820P02LW9`2BTY80b/[:0=3@d02_[jl0EeMG
4Oooool000oooooo0?l0IVIV05mOG`1BDU80EEEE05UIF@0k>c/0ATI607IfMP0a<C40I6AT07inOP0o
?cl0<S8b07YjNP1ADE40<S8b0410@01PH600EEEE01<C4`1JFUX0HV9R03Hf=P27QhL0;2`/05YJFP1A
DE40@D5105iNGP1eMGD0EEEE03De=@1ADE40?clo065QH@11@D40=SHf06QXJ00n?Sh06ATI06IVIP1;
Bd/0;bl_03De=@0d=3@08b<S07=cL`0h>3P09BDU03/k>`19BDT0:BTY02h^;P0k>c/0EEEE05aLG01U
IFD0>c/k03`l?025QHD09BDU02TY:@1HF5P0>CTi05EEE@1NGUh0;bl_04i>CP2;Rh/0G5aL04a<C01_
Kfl0GEeM079bLP26QXH0EEEE096AT@1iNGT0<c<c09bLW01=CDd0>c/k08B4Q01IFET07AdM08j>SP15
ADD09bLW08n?S`1cLg<0<C4a06YZJP0O7al05ADE08J6QP2OWil0:BTY02h^;P0c<c<0L71`059BDP18
B4P0Cdm?03<c<`1`L700?Shn04U9B@1EEED0A4A407]kN`1YJFT0EEEE06m_K`18B4P0J6QX09>CT`1[
Jf/0Rh^;06][J`1dM7@0Fe]K04Y:BP1mOGd0FUYJ07UiN@1lO7`0Kfm_0451@@1_Kfl0EeMG08F5Q@1G
EeL0KVi^05YJFP1PH600MgMg06MWI`2QXJ40I6AT06EUI@26QXH0>CTi07QhN02BTY80FEUI0:n_[`2<
S8`0?3`l05UIF@27QhL0<c<c04i>CP2IVIT0K6a/04I6AP1fMWH0RXZ:04M7A`1nOWh0JVYZ075aL@1j
NWX0D51@07IfMP2<S8`0KVi^096AT@2IVIT0SHf=07emO@2^[Zh0Jf][07]kN`2IVIT0_kno07QhN01K
Fe/0R8R806UYJ@1[Jf/0alO708B4Q01DE5@0U9BD09fMW@17AdL0QHF505MGE`1JFUX0Fe]K0::RXP2H
V9P0AdM708>3P`1dM7@0<c<c0:2PX021PH40NGUi0;6a/@1@D500:BTY06m_K`19BDT0E5AD05YJFP1?
Cdl0BTY:0;Jf]P1hN7P0J6QX0:FUY@1eMGD0BDU90451@@3@d=00bLW907]kN`14A4@0Ng]k08^;R`1/
K6`0Jf][05ADE014A4@0LG5a09VIV@1PH600YJFU0:BTY01[Jf/07QhN06QXJ01bLW80;Rh^02DU9@2>
SXh0K6a/03`l?01cLg<0RXZ:05IFEP1eMGD0UYJF06i^KP1>CTh0KVi^08Z:RP3De=@0WYjN05]KF`1n
OWh0I6AT06m_K`0U9BD002<0L71`08>3P`0V9RH0RXZ:08B4Q00f=SH0=3@d07alO02IVIT0E5AD0492
@P1/K6`0PH6103De=@2NWYh0P820030`<01=CDd0MgMg03Ti>@1bLW80<30`08R8R01iNGT0EEEE07Qh
N023Ph<0ATI602HV9P1ZJVX0S8b<03@d=00V9RH0R8R809JFUP0Looooo`0V07AdM01BDU80IVIV0;^k
^`2SXj<0PX:2092@T02GUiL0ZJVY09JFUP2CTi<0EeMG03<c<`0U9BD071`L014A4@0>3Ph0M7Ad0:JV
YP27QhL0O7al014A4@0@41003`l?00h>3P0=3@d030`<00l?3`0C4a<0IFEU05=CD`15ADD09bLW04Y:
BP19BDT0YjNW03Lg=`0F5QH201@D50804a<C02<07QhN00l?3`0@4100410@01<C4`0D51@06a/K04];
B`1mOGd0IVIV08V9R@2WYjL0?Cdm01/K6`0a<C40>c/k04Q8B02SXj<0];Bd0<;2`P1`L700W9bL0:FU
Y@1gMgL0E5AD04e=C@1<C4`0D51@05YJFP2i^KT0SXj>05YJFP1@D5009bLW01<C4`0201DE5@0l01TI
6@0S8b<092@T02@T900g=cL0FEUI04a<C012@T80S8b<07alO02@T900Bd];065QH@0Q8B406a/K02h^
;P1BDU80NGUi08b<S02;Rh/0/[:b05MGE`0S8b<0@d=307AdM02ZZZX0^k^k06QXJ024Q8@0I6AT02`/
;00K6a/0FUYJ03hn?P19BDT0TY:B0;Jf]P3:b/X0UIFE05=CD`1=CDd0RXZ:0:BTY022PX80EUIF06e]
K@2j^[X0b/[:09NGU`2OWil0/;2`08J6QP1KFe/0Rh^;0:j^[P2ZZZX0WYjN03`l?00G5aL04a<C0P0E
5AD0U@0];Bd0De=C04e=C@12@T80OWin0<S8b02@T900XZ:R0:JVYP0M7Ad05ADE01<C4`0D51@05ADE
01HF5P0I6AT07QhN03De=@1VIVH0BDU9069RHP2YZJT0O7al03Xj>P17AdL0Hf=S09:BTP1iNGT0De=C
06IVIP39bLT0VIVI08^;R`3IfMT0i^KV0>7Qh@30`<00=cLg038b<P13@d<0BDU903`l?01:BTX0EUIF
059BDP1FEUH0OGem0;^k^`1LG5`0XJ6Q0>WYj@3Shn<0f][J0<K6aP2i^KT0ZZZZ09:BTP1cLg<0HV9R
06ATI01RHV80IFEU061PH01kNg/0[Zj^08j>SP2CTi<0IVIV020P800N7Qh092@T06IVIP0k>c/0=cLg
02`/;01<C4`0G5aL09ZJVP2_[jl0L71`06QXJ024Q8@0Z:RX0=?Cd`1lO7`0PH6105mOG`0V9RH08b<S
03<c<`1kNg/09BDU01DE5@0J6QX071`L07UiN@1CDe<0LW9b07UiN@3IfMT0f=SH0::RXP17AdL0GUiN
059BDP0j>SX0A4A409bLW02XZ:P0G5aL08:2PP0P8200:BTY028R8P0I6AT071`L02@T900Y:BT0FUYJ
08f=S@3?cll0alO709>CT`2YZJT0d];B09BDU01XJ6P0Shn?0;>c/`20P800>c/k02HV9P0^;Rh0Kfm_
0::RXP2PX:00WIfM02d];@0S8b<0;2`/02DU9@0];Bd092@T03/k>`2?Shl0dm?C0;:b/P1cLg<0G5aL
017ooooo000?ooooo`0/06IVIP2KVi/0CDe=04E5A@1VIVH0@T9204U9B@20P800BTY:02d];@1XJ6P0
M7Ad04I6AP0m?Cd0A4A403Ti>@0d=3@0AdM707]kN`12@T80EEEE0492@P0[:b/0L71`03/k>`1`L700
K6a/055AD@1;Bd/0G5aL03Xj>P0k>c/0Lg=c04U9B@1?Cdl0:RXZ04I6AP26QXH0L71`02l_;`28R8P0
IVIV03`l?00k>c/202XZ:P3d07EeM@1/K6`0@D51055AD@1KFe/0<c<c03dm?@1JFUX0NWYj05iNGP1L
G5`0=3@d04];B`2HV9P0F5QH03/k>`1;Bd/0>3Ph07IfMP1jNWX0ADE507IfMP2YZJT0GemO04a<C01f
MWH0Hf=S096AT@27QhL0B4Q8065QH@20P800=3@d08F5Q@15ADD0Bd];09>CT`1QHF40:2PX0;no_`1D
E5@0;Rh^09jNWP2CTi<0GEeM07=cL`0f=SH07AdM06i^KP1VIVH0?Cdm02d];@0`<300IfMW0451@@1I
FET0EEEE03De=@1iNGT0>3Ph04M7A`1VIVH0Bd];08f=S@1RHV80I6AT06UYJ@17AdL0IFEU08Z:RP1J
FUX0OGem06=SH`1XJ6P0HF5Q07=cL`1eMGD0D51@079bLP1^KVh0J6QX05QHF01aLG40Cdm?07IfMP1R
HV80PH6105=CD`26QXH0NGUi065QH@24Q8@0EUIF051@D028R8P0>SXj08B4Q028R8P0EUIF0:FUY@2;
Rh/0>c/k07MgM`2CTi<0<C4a04M7A`2DU9@0AdM705EEE@2BTY80UYJF04E5A@1gMgL0GEeM07emO@29
RHT0G5aL08B4Q027QhL0MgMg0:^[Z`2a/K40Vi^K07IfMP2f][H0Jf][06m_K`27QhL0/K6a06IVIP1N
GUh0UYJF08B4Q02=SHd0e=CD06IVIP13@d<0Vi^K0:^[Z`15ADD0KFe]05MGE`1CDe<0CDe=071`L02;
Rh/0CTi>07alO01LG5`0CDe=0:FUY@1/K6`0F5QH09BDU01NGUh0=CDe08N7Q`1FEUH0ADE507]kN`1d
M7@0Hf=S0<k>cP1mOGd0HF5Q0:j^[P1oOgl0EEEE03Ph>02GUiL0WIfM08Z:RP12@T80M7Ad05IFEP1H
F5P0M7Ad05=CD`0o?cl0Hf=S09:BTP16ATH0JFUY0861P@1;Bd/09BDU08B4Q01ADE40Jf][04e=C@1/
K6`0F5QH03Xj>P1RHV80KVi^03Hf=P1VIVH0Ph>304];B`17AdL0H61P08>3P`30`<00JVYZ04Y:BP27
QhL0SXj>08:2PP0`<300CTi>05iNGP0W9bL0S8b<06=SH`0T92@0<c<c065QH@1dM7@09RHV0410@01f
MWH0FEUI04e=C@2VYZH0JVYZ02<S8`1=CDd0HV9R03@d=01hN7P0=SHf092@T023Ph<0EUIF0<W9b@1n
OWh0@d=3038b<P1@D500L71`03`l?00g=cL0U9BD09:BTQcooooo0280LG5a08:2PP2;Rh/0Rh^;06QX
J012@T80D51@07YjNP25QHD0LG5a07QhN01`L700HF5Q05MGE`1?Cdl0D51@079bLP2h^;P0/;2`0<k>
cP2e]KD0J6QX059BDP1:BTX0@T9204I6AP1:BTX0EeMG06UYJ@2c/k<0]kNg0:^[Z`2=SHd0U9BD0P39
bLT0500a<C404a<C01@D500A4A40410@01DE5@0i>CT04Q8B014A4@0?3`l04A4A01HF5P0C4a<04A4A
01/K6`16ATH0WIfM0;Rh^037alL0VYZJ0P28R8P0H@2^[Zh0d];B0=?Cd`3?cll0P82005aLG01RHV80
LW9b07moO`1aLG40L71`07EeM@2[Zj/0^k^k06][J`1<C4`07alO01HF5P0A4A406ATI01`L700Z:RX0
8B4Q01hN7P0F5QH051@D01/K6`1:BTX0J6QX08j>SP2ZZZX0aLG50;jn_P1cLg<0EeMG05=CD`19BDT0
=3@d02/[:`0X:2P08B4Q02LW9`19BDT0<c<c01/K6`0U9BD0?Shn06=SH`1[Jf/0WYjN05iNGP1FEUH0
HF5Q07=cL`1<C4`0DE5A06UYJ@2KVi/0`/;20;Rh^02KVi/0M7Ad0820P024Q8@0PX:206e]K@1VIVH0
U9BD0:VYZ@2ZZZX0c/k>092@T014A4@0D51@04i>CP0e=CD0FUYJ079bLP1dM7@0D51@01/K6`0C4a<0
51@D01HF5P1WIfL0WYjN06MWI`1CDe<0QXJ60;Bd]03:b/X0d];B03@d=00X:2P0:RXZ02LW9`0Z:RX0
0P0Y:BT0:`0V9RH08R8R05MGE`1IFET0UYJF0;Rh^02;Rh/0UIFE08R8R026QXH0T92@08B4Q01gMgL0
NGUi0;Bd]02_[jl0fm_K0<?3``1XJ6P09RHV02l_;`1^KVh0JVYZ065QH@2NWYh0X:2P08^;R`1fMWH0
Kfm_06ATI01PH600Shn?08N7Q`31`L40g]kN0<k>cP2NWYh0X:2P0:FUY@1oOgl0EUIF02d];@0Y:BT0
0P0W9bL0>P0Y:BT0;bl_03De=@0h>3P0HV9R09^KV`1HF5P0@T9202<S8`0O7al0>c/k04U9B@13@d<0
Ng]k08>3P`2=SHd0Zj^[0;Jf]P1eMGD0Lg=c0820P02^[Zh0MGEe07IfMP1kNg/0Cdm?02`/;00[:b/0
<S8b059BDP20P800@T9202/[:`17AdL0_kno0:b/[032`/80gmoO0>;RhP2ATI40D51@05YJFP18B4P0
?3`l05EEE@26QXH0`<300<;2`P2TY:@0:BTY01DE5@0F5QH05ADE01HF5P0G5aL07AdM028R8P0a<C42
09^KV`0L07EeM@1LG5`0T92@03Ph>019BDT0G5aL06=SH`25QHD0ZJVY0<71`@2d];@0[:b/0<;2`P2l
_;`0QHF505iNGP2CTi<0KVi^059BDP1LG5`0JVYZ07]kN`2?Shl0UIFE079bLP2DU9@0L71`06][Ja7o
oooo000?ooooo`2O05iNGP2GUiL0CDe=05]KF`1RHV80?Cdm05MGE`2KVi/0KFe]02l_;`1fMWH0T92@
04I6AP0m?Cd092@T03Ti>@0f=SH0G5aL06=SH`0^;Rh0RXZ:05UIF@0n?Sh0P82003Ti>@2BTY80NWYj
061PH01SHf<0KVi^04m?C`11@D40L71`04M7A`1TI6@0?Cdm03<c<`1`L700KFe]030`<02@T900820P
03Xj>P0g=cL06ATI04];B`2CTi<0GemO03Ti>@1>CTh0@D51018B4P0h>3P0EUIF07emO@28R8P0QHF5
04A4A015ADD0Vi^K059BDP0k>c/0BDU902@T900o?cl0Fe]K02PX:01_Kfl0];Bd051@D01GEeL0RXZ:
05eMG@27QhL0P82005iNGP0i>CT0O7al02`/;01]KFd0CTi>04E5A@2UYJD0D51@02PX:02^[Zh0?Shn
03lo?`2EUID0V9RH061PH02<S8`0E5AD030`<01lO7`0DU9B02d];@0l?3`0EEEE07MgM`1/K6`0Fe]K
06IVIP0h>3P0Ph>302`/;01<C4`0EEEE0451@@2PX:00K6a/061PH01XJ6P0?Cdm05UIF@25QHD0FEUI
07inOP1LG5`0CTi>05aLG01PH600MgMg0410@01HF5P0OWin06i^KP1EEED0HF5Q04M7A`1_Kfl0QHF5
07MgM`1:BTX0Rh^;06i^KP1NGUh0RXZ:03`l?017AdL0LW9b05UIF@2SXj<0OGem051@D02DU9@0VIVI
02l_;`1ZJVX0T92@03Ph>01JFUX0YZJV06YZJP19BDT0NWYj092@T014A4@0Ogmo0080IFEU0840NWYj
05IFEP1lO7`0LG5a05EEE@1jNWX0QXJ608Z:RP1aLG40[Jf]07UiN@21PH40S8b<096AT@0`<300Bd];
07moO`1XJ6P0Rh^;0;:b/P1bLW80F5QH09RHV02GUiL0HF5Q08b<S00g=cL0I6AT04i>CP1UIFD0I6AT
03@d=01/K6`0MWIf05mOG`2@T900W9bL06YZJP2e]KD0De=C03Ph>02EUID0Fe]K03dm?@18B4P0EeMG
06e]K@3@d=00TI6A05MGE`2RXZ80][Jf08B4Q01LG5`0_kno0:RXZ02NWYh0ATI608Z:RP1VIVH0KVi^
08^;R`0O7al0:2PX04e=C@2DU9@0DE5A0820P02;Rh/0<C4a020P801`L700DU9B02PX:00d=3@0SHf=
03Ph>00d=3@0HV9R07]kN`0o?cl0NWYj07moO`0G5aL0>SXj06][J`1oOgl0dm?C071`L00j>SX0H61P
05YJFP1>CTh09BDU04Q8B01ZJVX0;Bd]08j>SP1MGEd07alO03Lg=`1DE5@0O7al03Ti>@12@T80HV9R
05eMG@0g=cL0J6QX061PH00Q8B40BDU906MWI`0a<C40MgMg0451@@2YZJT0JFUY06ATI03@d=00TI6A
034a<@0n?Sh0JVYZ08>3P`0X:2P0:b/[08j>SP2KVi/07?ooool0600m?Cd0TI6A09JFUP1[Jf/0JVYZ
0:VYZ@2k^k/0KVi^02d];@0U9BD0@d=307=cL`2MWId0P82005YJFP1^KVh0PX:20;Bd]023Ph<0UIFE
0<c<c02TY:@0?3`l034a<@80;bl_0P0a<C405@18B4P0W9bL0:^[Z`1nOWh0Kfm_07AdM01UIFD0Shn?
06a/K00I6AT05ADE01<C4`0>3Ph07QhN09NGU`0L71`03`l?00h>3P0C4a<05QHF00h>3P02014A4@0?
020P801[Jf/0IVIV0:VYZ@0b<S80;Bd]03Xj>P2h^;P0/;2`0<_;b`2_[jl0J6QX05YJFP1UIFD0J6QX
0080JFUY01/0Rh^;0:BTY03GemL0SXj>02TY:@0k>c/09bLW04e=C@14A4@071`L01@D500E5AD04A4A
01<C4`0B4Q804a<C01DE5@0D51@0Bd];0=GEe@2b/[80a/K60;Vi^@1VIVH0=3@d01TI6@0E5AD00P0C
4a<0<P0B4Q8061PH01HF5P0G5aL0CDe=02/[:`0K6a/0=SHf069RHP2DU9@0HV9R02d];@1DE5@0FUYJ
05EEE@1dM7@0F5QH04Q8B01?Cdl0QXJ609:BTP2FUYH0GEeM02<S8`0o?cl0Shn?0;no_`35aLD0Ph>3
03hn?P0i>CT0Lg=c08F5Q@0f=SH06QXJ03/k>`0O7al09RHV04m?C`15ADD0HV9R07]kN`0U9BD05QHF
02l_;`12@T80Y:BT0=7Ad@27QhL0M7Ad0P2d];@0<`2c/k<0NWYj02LW9`0E5AD051@D01DE5@0F5QH0
5aLG01DE5@0`<300CTi>06QXJ02_[jl0G5aL02PX:01ZJVX0Q8B404U9B@10@4006a/K038b<P1cLg<0
`L710>7Qh@3Zj^X0RHV90492@P17AdL0?Shn04Y:BP1oOgl0];Bd05]KF`1NGUh0JVYZ03dm?@0h>3P0
>c/k04Y:BP1HF5P0bl_;0=?Cd`3EeMD0_;bl07EeM@1gMgL0F5QH06=SH`1@D500<C4a030`<00202TY
:@0602/[:`0a<C40>CTi04];B`1DE5@0QHF50P1OGel0:P1@D5007alO03Ph>01WIfL0Jf][08>3P`28
R8P0XZ:R0;Rh^02j^[X0Xj>S065QH@1aLG40PX:20451@@1BDU80G5aL06EUI@0b<S80=CDe0410@01E
EED0WIfM0<W9b@2JVYX0Fe]K07=cL`1XJ6P0EUIF0:VYZ@3Ng]h0c<c<0:b/[02OWil0X:2P0;Vi^@28
R8P0NWYj0<S8b03Jf]X0QhN701LG5`805ADE0P0F5QH02P0I6AT06a/K01lO7`1eMGD0OWin06=SH`1H
F5P0TI6A02PX:00F5QH201LG5`0F01DE5@0G5aL06ATI02h^;P1EEED0][Jf0=KFeP2UYJD0T92@0:n_
[`30`<00aLG50:2PX01`L700BDU905IFEP2QXJ40PX:209:BTP1lO7`0QHF5069RHQ7ooooo000?oooo
o`1^06YZJP1XJ6P0Cdm?05=CD`1KFe/0<S8b0451@@1hN7P0F5QH02TY:@1VIVH0>3Ph03lo?`1ZJVX0
Fe]K03Ti>@11@D40H61P05aLG00T92@0HV9R06EUI@1=CDd0NGUi02@T901WIfL0K6a/059BDP20P800
Shn?05QHF01<C4`0KFe]04E5A@1lO7`0@D5104=3@`2KVi/0Bd];024Q8@1gMgL0=cLg03<c<`0j>SX0
6ATI024Q8@1XJ6P0?3`l03Lg=`1WIfL0HF5Q03De=@0l?3`0BDU908N7Q`2TY:@0Q8B404I6AP19BDT0
SXj>03Xj>P1HF5P0L71`04i>CP1EEED0HV9R02TY:@1CDe<0ZJVY06][J`1RHV80Ogmo05eMG@2f][H0
WIfM06a/K00b<S80?Cdm02<S8`1_Kfl0NWYj061PH02f][H04Q8B02PX:02FUYH0HV9R02XZ:P2BTY80
WYjN01hN7P1FEUH0Fe]K02d];@23Ph<0Z:RX06=SH`0T92@09bLW065QH@1SHf<0Ogmo06MWI`0b<S80
MGEe061PH01XJ6P0LW9b02TY:@28R8P206e]K@2Z03<c<`0a<C40JVYZ08V9R@1OGel0KVi^04A4A01M
GEd0KFe]071`L01^KVh0A4A406m_K`2SXj<0LW9b05mOG`1@D500<S8b07alO024Q8@0DE5A02HV9P1/
K6`0Ti>C05mOG`2f][H0<S8b02HV9P2>SXh0?clo08^;R`1TI6@0;Bd]096AT@2JVYX0ATI607emO@26
QXH09BDU03Hf=P1`L700A4A405]KF`2MWId0P82002l_;`1cLg<0GemO07=cL`1UIFD0DE5A08n?S`2=
SHd0LG5a08b<S01lO7`0IFEU071`L032`/80TI6A09BDU02b/[80/;2`06ATI01:BTX0PH6106i^KP2D
U9@0`l?306QXJ01ZJVX0SHf=09:BTP0m?Cd0Hf=S059BDP0m?Cd0ADE506UYJ@1eMGD0@D5104a<C01L
G5`0ATI608>3P`1/K6`0P8200;Jf]P1dM7@0?3`l08V9R@1?Cdl0@T9205UIF@1>CTh0De=C0:RXZ023
Ph<0CTi>0820P01oOgl0N7Qh05eMG@3<c<`0c/k>09RHV00b<S80MgMg07QhN01UIFD0R8R805YJFP0m
?Cd0H61P0:2PX01KFe/0NWYj07QhN011@D40;bl_07]kN`17AdL0GEeM04e=C@1`L700JFUY03Lg=`1@
D500IVIV02h^;P1XJ6P0MWIf04M7A`1?Cdl0HF5Q051@D037alL0H61P04];B`20P800JVYZ06a/K00^
;Rh0BDU906IVIP0h>3P0SHf=06IVIP0d=3@0>SXj04m?C`27QhL0@d=304M7A`1XJ6P0LW9b0410@01e
MGD0G5aL02h^;P23Ph<0QXJ602h^;P1GEeL09BDU079bLP1cLg<0IFEU0<k>cP1[Jf/201LG5`0602d]
;@1LG5`0;Bd]02LW9`28R8P0O7al7?ooool05P15ADD0JVYZ0451@@1ADE40TY:B0<;2`P2n_[h0Y:BT
07MgM`1NGUh0D51@05eMG@2CTi<0/;2`0:JVYP2?Shl0GemO0;>c/`1DE5@0;Rh^09:BTP1IFET2018B
4P0O00l?3`0@41004A4A00h>3P0F5QH0AdM70:>SX`1CDe<0ADE503@d=00E5AD0?3`l0;:b/P0j>SX0
5aLG014A4@0=3@d0=3@d09ZJVP1:BTX0ADE5030`<00X:2P0410@00h>3P0S8b<05QHF055AD@2JVYX0
Q8B408N7Q`0203@d=00K06IVIP2CTi<0@T920;Bd]032`/80S8b<03De=@0Z:RX0=SHf0492@P17AdL0
@D5104Q8B02l_;`0[Jf]02l_;`0j>SX05aLG02h^;P0h>3P03Ph>00l?3`0C4a<04A4A010@400C4a<0
5ADE00804a<C00P0820P0<_;b`2`/;00/;2`0:n_[`1NGUh0820P01@D50804A4A03X03`l?010@400F
5QH06ATI01PH600_;bl0GemO02TY:@0o?cl0HV9R07UiN@1eMGD0IfMW0492@P0^;Rh07alO02PX:00`
<300=cLg02XZ:P1WIfL0T92@03hn?P1WIfL0>3Ph01dM7@0Y:BT0Lg=c09NGU`0m?Cd0;Rh^030`<01F
EUH0Q8B40492@P0L71`0?Shn02DU9@0M7Ad0<30`05YJFP0l?3`0GemO07MgM`0k>c/0@d=308R8R02K
Vi/0C4a<02HV9P0Y:BT0Rh^;0<g=c@2HV9P0P82007EeM@0Y:BT04a<C0`0E5AD0:`0O7al0GEeM04I6
AP2MWId0EeMG02HV9P0X:2P0A4A405ADE00`<300@d=301/K6`0V9RH0?Cdm06IVIP2RXZ80g=cL08B4
Q00n?Sh0ATI603Xj>P0f=SH0@T92096AT@0X:2P0FEUI0:j^[P2?Shl0I6AT0492@P0Y:BT06ATI09RH
V03De=@0bl_;0=OGe`2JVYX0ZJVY07AdM012@T80@d=301dM7@0[:b/00P0Q8B40<`0S8b<08R8R01LG
5`0G5aL07QhN06ATI02NWYh0CTi>08j>SP1nOWh0Zj^[09BDU02NWYh0Shn?0::RXP1iNGT0Fe]K07=c
L`33`l<0DE5A034a<@11@D40EeMG05EEE@1OGel0?clo02@T900a<C40N7Qh0<;2`P2f][H0^KVi0492
@P0K6a/09BDU08b<S01dM7@0Ti>C0<K6aP3Cdm<0alO70;Jf]P20P800DU9B07]kN`32`/80Rh^;06m_
K`2VYZH0<S8b01@D500201DE5@0S01TI6@0O7al0<S8b06EUI@2`/;00Jf][06QXJ02LW9`0@D5101DE
5@0F5QH05aLG01TI6@0G5aL05QHF01DE5@0G5aL08B4Q0:2PX02a/K40_[jn092@T02h^;P0_;bl0<C4
a02:RXX0BTY:04Q8B02/[:`0Zj^[08J6QP1JFUX0I6AT06][J`1>CTh04Oooool000oooooo0<d0Kfm_
07AdM01;Bd/0DU9B061PH010@400@d=306m_K`10@400;bl_06UYJ@1`L700<C4a02HV9P0l?3`0;2`/
01/K6`17AdL0Fe]K0492@P1LG5`0:2PX04I6AP1WIfL0<S8b08N7Q`0i>CT0<S8b04M7A`1SHf<0GUiN
05mOG`1gMgL0>SXj051@D00W9bL0CTi>09FEU@1MGEd09RHV0861P@1CDe<0?clo03Hf=P0e=CD0:BTY
07moO`1FEUH0;bl_04A4A01FEUH0>c/k03@d=00g=cL0BDU9061PH01WIfL0?Cdm05EEE@2LW9`0;2`/
030`<016ATH0GUiN08J6QP1PH6008B4Q055AD@2DU9@0JFUY07alO02>SXh0?clo06e]K@22PX80C4a<
0492@P1]KFd08R8R069RHP1BDU80LG5a0;bl_01=CDd071`L09RHV01@D500:2PX09:BTP2=SHd0?Shn
06e]K@1KFe/0=SHf08R8R01cLg<0E5AD02h^;P0e=CD0KVi^07QhN01HF5P0MgMg03/k>`1aLG40De=C
03lo?`20P800HV9R08Z:RP1TI6@0PH6106ATI00d=3@0F5QH07YjNP1JFUX0Lg=c02PX:00h>3P0EUIF
07alO01]KFd08b<S0492@P1/K6`0EUIF06EUI@1hN7P0<c<c06=SH`1UIFD0MgMg04i>CP18B4P0OWin
05mOG`24Q8@0E5AD03hn?P1XJ6P0@D5109BDU01cLg<0@d=307IfMP2@T900BDU909:BTP2GUiL0=cLg
03Ph>022PX80EUIF04A4A01[Jf/0Ogmo03dm?@1NGUh0IVIV08f=S@13@d<0A4A409nOW`2LW9`0MGEe
08J6QP35aLD0IVIV05UIF@2a/K40D51@06YZJP2BTY80XJ6Q05]KF`1XJ6P0YjNW06QXJ02IVIT0^k^k
05QHF01nOWh0Zj^[0:JVYP13@d<0KFe]04a<C00f=SH0E5AD08N7Q`1aLG40?3`l04M7A`1NGUh0De=C
06i^KP1FEUH0HF5Q0:^[Z`1_Kfl0>CTi08Z:RP1NGUh0@T920080Kfm_05<0Lg=c0;^k^`1ZJVX0D51@
0:>SX`1nOWh0EEEE03@d=02DU9@0Shn?09>CT`0l?3`0Hf=S07UiN@1XJ6P0Ogmo05ADE00l?3`0E5AD
08N7Q`1@D500I6AT09>CT`1aLG40?Shn09BDU01LG5`0Kfm_04M7A`1ZJVX0MGEe04];B`1XJ6P0Q8B4
04U9B@1[Jf/0IVIV07=cL`1TI6@0T92@08J6QP37alL0UIFE05=CD`28R8P0^;Rh09>CT`0e=CD0C4a<
04M7A`0f=SH0OGem06MWI`12@T80<C4a04I6AP20P800:RXZ06][J`2EUID0Hf=S03hn?P1/K6`0CTi>
01dM7@1GEeL0K6a/03@d=01gMgL0<C4a09^KV`1dM7@0N7Qh0=?Cd`1PH600@d=3034a<@1FEUH0LW9b
03Lg=`0Z:RX0MGEe07alO00Looooo`0J05aLG01JFUX0<S8b02`/;01CDe<0cLg=0=?Cd`2g]kL0MGEe
04a<C010@400>c/k059BDP2>SXh0UiNG08F5Q@2;Rh/0Vi^K05YJFP0d=3@0LG5a05YJFP0G5aL05ADE
01hN7P0F5QH200h>3P0b01<C4`0M7Ad0UIFE065QH@1UIFD08b<S014A4@0K6a/0Vi^K08f=S@0O7al0
51@D01lO7`1VIVH09RHV01DE5@0X:2P0MgMg06m_K`0K6a/04Q8B01lO7`15ADD0Y:BT0=7Ad@3@d=00
c<c<08b<S025QHD0`l?305QHF01OGel0IVIV01lO7`0j>SX0Jf][05YJFP0c<c<071`L02XZ:P0U9BD0
:2PX06YZJP2a/K40Hf=S03lo?`0C4a<05ADE04E5A@0F5QH200h>3P0401@D500I6AT05QHF01@D5080
5ADE00L07QhN09:BTP2WYjL0QHF507=cL`0g=cL05aLG00@03Ph>0P0A4A40E`0D51@071`L01/K6`1?
Cdl0M7Ad0820P02f][H0G5aL05iNGP0l?3`09RHV01TI6@0F5QH071`L020P800S8b<0<C4a08F5Q@1P
H600FEUI04];B`1>CTh07QhN01`L701YJFT0T92@03dm?@0Z:RX0:2PX04=3@`2EUID0Q8B40451@@15
ADD0>3Ph01dM7@0V9RH0KVi^02PX:00[:b/0@D5108V9R@1RHV80MWIf07emO@0R8R80<C4a04];B`1V
IVH0b/[:09>CT`1XJ6P0KVi^09>CT`1VIVH071`L01HF5P0I6AT0K6a/04a<C01WIfL0Rh^;01hN7P0M
7Ad0D51@05QHF01GEeL0=cLg071`L015ADD0A4A403Ph>01HF5P0/;2`0;Rh^02HV9P0=cLg03<c<`0a
<C40<30`02`/;02MWId0;Bd]03Ph>01ADE40LW9b06MWI`0201DE5@0=01`L702i^KT0bl_;0=CDe03J
f]X0BTY:038b<P0m?Cd08R8R02XZ:P0^;Rh06ATI01@D500501DE5@0j02l_;`1[Jf/0c<c<08>3P`2C
Ti<0_Kfm08f=S@1QHF40YjNW06m_K`0h>3P08R8R02DU9@0_;bl0JFUY092@T00f=SH0;2`/05]KF`1H
F5P0I6AT04E5A@25QHD0WYjN071`L01OGel0Z:RX07YjNP0];Bd0;Rh^02HV9P1ADE40]KFe09:BTP2k
^k/0/[:b09:BTP1EEED0CTi>08n?S`2LW9`0<30`01TI6@0U9BD0Hf=S08R8R00[:b/09bLW03/k>`1K
Fe/0QHF509fMW@3>c/h0]kNg09jNWP26QXH0_kno01dM7@805ADE0P0G5aL05P0E5AD05aLG01HF5P0I
6AT0HF5Q08b<S011@D40];Bd0::RXP2SXj<0_;bl0:NWY`2YZJT0/k>c0:^[Z`37alL0Lg=c05ADE01a
LG40Kfm_06IVIP1GEeLAooooo`003oooool05@1ZJVX0VYZJ055AD@14A4@0IVIV04I6AP15ADD0WYjN
07alO00U9BD0I6AT06a/K00e=CD0;2`/04e=C@18B4P0ATI605UIF@1iNGT0@d=306UYJ@0204Y:BP1T
07QhN00c<c<0S8b<06i^KP1JFUX0EUIF065QH@0e=CD0ATI606a/K01<C4`0EeMG038b<P0/;2`0GemO
04Y:BP0];Bd0V9RH04Q8B01;Bd/0A4A4038b<P0a<C40NWYj059BDP0e=CD0Cdm?051@D00k>c/0B4Q8
04=3@`1TI6@0JVYZ05mOG`0c<c<0ATI608Z:RP1ADE40>3Ph05MGE`0d=3@0BTY:05iNGP0_;bl08B4Q
07inOP1FEUH0K6a/09BDU01QHF40VYZJ07IfMP1GEeL0>SXj06m_K`0Y:BT0GemO05ADE01<C4`0Y:BT
06e]K@0S8b<0`L7105aLG01XJ6P0^[Zj0:6QX@1NGUh0LW9b06IVIP0Y:BT0OWin07=cL`0b<S80C4a<
06MWI`2:RXX0QhN705aLG01HF5P0A4A408^;R`1NGUh0>SXj06a/K01;Bd/0XJ6Q079bLP1TI6@0IFEU
04=3@`22PX80MgMg059BDP1bLW80Fe]K04e=C@1FEUH0EeMG07inOP80?clo04D0IVIV06e]K@1QHF40
MGEe04Y:BP1XJ6P0M7Ad0861P@1GEeL0D51@06IVIP1SHf<0T92@04m?C`1<C4`0Cdm?05YJFP2i^KT0
[jn_08F5Q@1bLW80ZJVY0410@01hN7P0VIVI03hn?P1GEeL0WinO05eMG@18B4P0MGEe09>CT`15ADD0
OGem05QHF01UIFD0Lg=c055AD@21PH40L71`05UIF@22PX80UIFE075aL@20P800/k>c07IfMP21PH40
VIVI08^;R`0Z:RX0?clo07alO01KFe/0TY:B0:^[Z`15ADD0EEEE05aLG029RHT0CTi>07moO`10@400
GemO03lo?`1HF5P0Fe]K03Xj>P1`L7000P1=CDd0GP1YJFT0MgMg0492@P2KVi/0LG5a03Hf=P27QhL0
?Shn04a<C026QXH0OGem06e]K@2h^;P0LW9b06QXJ03=cLd0`<3006YZJP1<C4`0[:b/0:BTY02JVYX0
>SXj06m_K`1fMWH0L71`08>3P`1WIfL0<S8b05QHF02@T900GEeM065QH@25QHD09bLW02h^;P2FUYH0
PX:206m_K`14A4@0L71`02PX:00j>SX0LW9b07IfMP14A4@0KFe]05aLG00W9bL0GemO09:BTP1nOWh0
a<C40:RXZ01BDU80RXZ:09RHV02FUYH0;bl_04Q8B01cLg<0De=C0;Bd]01bLW80AdM702d];@0h>3P0
UiNG0451@@10@400P82006IVIP1BDU80KFe]05iNGP0W9bL0HF5Q04m?C`0O7al0JFUY03De=@2UYJD0
Kfm_04U9B@2f][H0P820061PH00i>CT0JVYZ07emO@0b<S80;2`/0820P02FUYHLooooo`0H08R8R01Z
JVX0=SHf02h^;P13@d<0WYjN0<g=c@1mOGd07AdM01DE5@0D51@04A4A00l?3`0@4100R8R809^KV`1G
EeL0GEeM07YjNP0n?Sh0HV9R06=SH`0G5aL05ADE0P0G5aL0:P0@4100<C4a02<S8`0K6a/0JFUY06m_
K`2?Shl08B4Q00h>3P0C4a<0DU9B0;>c/`14A4@092@T07]kN`0`<300410@018B4P0G5aL07AdM03hn
?P1OGel0M7Ad09FEU@28R8P0^k^k0=SHf036a/H0alO70<K6aP3>c/h0Vi^K04Y:BP1YJFT04Q8B00X:
2P0=3@d0410@02PX:01?Cdl0GemO03hn?P808b<S00P0=cLg0:NWY`28R8P0EEEE01<C4`0D51@0:BTY
03De=@<03Ph>0100410@018B4P0G5aL04Q8B01<C4`0Z:RX0OGem0::RXP27QhL0Jf][02h^;P0@4100
3Ph>01@D500A4A404a<C0P0E5AD03@0C4a<06a/K01XJ6P0];Bd0QXJ60<c<c03Rh^80g]kN0=3@d02;
Rh/092@T01`L700R8R800P0J6QX0600N7Qh0De=C02d];@0F5QH0BDU906YZJP1HF5P08R8R01dM7@0m
?Cd0KFe]02`/;00T92@08B4Q04i>CP3:b/X0SXj>03hn?P1LG5`0?Shn03Ti>@1SHf<0]KFe06QXJ080
;bl_00d0K6a/09JFUP26QXH0>CTi03`l?01ADE40LG5a06a/K01bLW80QHF5055AD@1MGEd0H61P0080
UIFE01l0K6a/08f=S@1KFe/0G5aL07AdM00X:2P06a/K01hN7P15ADD0ZJVY069RHP0h>3P0L71`02d]
;@0h>3P0@41003Ph>02ATI40XZ:R0<[:bP17AdL0:2PX02TY:@0e=CD0=cLg08F5Q@1PH600Lg=c05=C
D`17AdL0BTY:00805ADE04h0GUiN0<K6aP3IfMT0Z:RX09RHV02][Jd0IfMW02/[:`0N7Qh06ATI04m?
C`0];Bd0:b/[028R8P0L71`07AdM01`L700T92@0EeMG08B4Q02?Shl0YJFU0=WIf@3EeMD0]kNg0<c<
c01iNGT0:b/[02HV9P0S8b<09BDU02h^;P0o?cl0GemO06i^KP0d=3@0D51@07=cL`25QHD0[jn_08F5
Q@1KFe/0BTY:06QXJ03@d=00?Cdm01LG5`0O7al0KFe]05QHF01gMgL0c/k>0;Bd]02XZ:P0QHF5075a
L@39bLT0WYjN02HV9P0G5aL06a/K01hN7P0X:2P0TI6A0<g=c@2n_[h0[jn_09bLW028R8P0T92@0=CD
e037alL0W9bL07]kN`2?Shl0EEEE02TY:@0S8b<401DE5@0D01XJ6P1>CTh0OWin02XZ:P1bLW80[jn_
09NGU`2d];@0/[:b0:BTY02a/K40];Bd0=OGe`2NWYh0>SXj04M7A`1LG5`0WinO0:6QX@2VYZHAoooo
o`003oooool06P1PH600TI6A051@D01KFe/0FEUI04Y:BP1YJFT0/K6a08B4Q00^;Rh0M7Ad08R8R01:
BTX0CDe=0451@@10@400>c/k05aLG01MGEd0?Shn079bLP15ADD0EUIF071`L00d=3@0IVIV0P1?Cdl0
1`1]KFd0JFUY03dm?@1SHf<0P82005=CD`1`L7000P0j>SX04P1OGel0CTi>038b<P2LW9`0?clo03Xj
>P0k>c/07QhN03hn?P1mOGd0C4a<03Ti>@1FEUH0>3Ph02XZ:P16ATH0?3`l071`L080Jf][0:/0?clo
04e=C@21PH40?Cdm03Ph>01MGEd0EUIF04a<C01WIfL0?Cdm02@T901WIfL0Kfm_079bLP26QXH0G5aL
09nOW`1kNg/0HF5Q04Q8B013@d<0>3Ph07AdM01JFUX0CTi>0:^[Z`0X:2P0>c/k0<O7a`1bLW80?Shn
0:2PX02>SXh0<C4a06m_K`1ZJVX0=CDe07moO`27QhL0<c<c02DU9@0_;bl0HF5Q05mOG`19BDT0?clo
020P801GEeL0CTi>03/k>`1OGel08b<S07MgM`1WIfL0JVYZ03Lg=`0f=SH0JVYZ07inOP1HF5P0J6QX
034a<@1QHF40JFUY06IVIP1WIfL0?Shn06YZJP2<S8`0J6QX06IVIP1TI6@0B4Q807emO@1lO7`0Fe]K
03Ph>01eMGD0LG5a059BDP2FUYH0;Bd]05EEE@1VIVH0=cLg09:BTP2:RXX0GemO06QXJ025QHD0BTY:
08B4Q022PX80>CTi05IFEP1iNGT0FUYJ04A4A01YJFT0I6AT04I6AP2=SHd0Hf=S06][J`1JFUX0IVIV
0;Rh^02EUID0GEeM09^KV`2MWId0>3Ph05YJFP2JVYX0F5QH07inOP2RXZ80TY:B05IFEP18B4P0T92@
05QHF02PX:00/k>c05aLG02>SXh0H61P06QXJ01TI6@0P82005ADE00k>c/0?clo061PH01ADE40;Bd]
05=CD`1XJ6P0Jf][05=CD`1<C4`0FEUI0::RXP1>CTh0D51@0::RXP19BDT0B4Q805UIF@11@D40KFe]
0:f][@1DE5@0ATI606EUI@29RHT0P820069RHP3GemL0fm_K0:2PX013@d<0T92@08J6QP1`L700U9BD
03<c<`0W9bL0EUIF08^;R`1NGUh00P2>SXh0?01LG5`0:2PX08F5Q@1OGel0=3@d04A4A022PX80N7Qh
0451@@1TI6@0O7al04Q8B01TI6@0LG5a05UIF@1]KFd0LW9b07EeM@2e]KD0X:2P03`l?01jNWX0Rh^;
06i^KP0_;bl0LW9b09^KV`19BDT0XJ6Q08R8R00W9bL0?clo08>3P`2VYZH0EUIF04E5A@1jNWX0>c/k
06MWI`2YZJT0MgMg02l_;`1OGel0FEUI02HV9P1RHV80D51@0<;2`P21PH40GUiN0=7Ad@2EUID0EeMG
04I6AP1oOgl0Lg=c034a<@19BDT0Zj^[0:2PX1cooooo00`0_kno08Z:RP18B4P0=cLg05]KF`1nOWh0
/k>c03dm?@0E5AD04A4A018B4P0>3Ph200d=3@0:05IFEP24Q8@0MgMg05ADE02ATI40MgMg05UIF@1^
KVh061PH01TI6@<05ADE01H0;2`/06MWI`0R8R80?Cdm09BDU035aLD0?Cdm010@400>3Ph0;bl_09^K
V`2n_[h0UIFE08:2PP1:BTX0GUiN06][J`1iNGT0QXJ607inOP1TI6@0B4Q80P0l?3`02@31`L40f][J
06ATI02;Rh/0_kno0=?Cd`2EUID0L71`03De=@0300d=3@0A00h>3P0=3@d03@d=01HF5P0n?Sh0HF5Q
05QHF014A4@0QHF508^;R`2=SHd0Fe]K02@T900G5aL0=cLg01HF5P0=3@d00`0>3Ph02P0C4a<05ADE
01DE5@0j>SX0Hf=S0:f][@31`L40YZJV038b<P0G5aL201TI6@0e01LG5`0C4a<04Q8B00h>3P0@4100
4a<C01TI6@1BDU80bLW90=cLg03:b/X0X:2P0:VYZ@1^KVh0AdM704m?C`1>CTh0Cdm?051@D01_Kfl0
FUYJ01`L700G5aL07alO04e=C@1QHF40ADE501dM7@0g=cL0FEUI02TY:@0T92@0820P05MGE`1TI6@0
[Zj^04Q8B01NGUh0Ogmo09fMW@2_[jl0VIVI08Z:RP1dM7@0DE5A08N7Q`21PH40];Bd05EEE@1SHf<0
N7Qh04I6AP10@4000P11@D40K`1XJ6P0FUYJ059BDP1FEUH0Ph>30=kNgP3=cLd0BTY:061PH01bLW80
6QXJ01PH600L71`0?clo0<O7a`2n_[h0Y:BT0:JVYP0S8b<08B4Q03hn?P0];Bd0F5QH0:FUY@3De=@0
K6a/02l_;`0e=CD0EeMG07alO02OWil0N7Qh06m_K`1YJFT0?clo061PH00N7Qh0ADE506UYJ@1KFe/0
`L7108Z:RP15ADD0H61P09jNWP1[Jf/092@T01/K6`1ADE40=CDe02LW9`0Z:RX09bLW02d];@0g=cL0
BDU908>3P`2FUYH0d=3@0;bl_031`L40fm_K0<O7a`3De=@0N7Qh038b<P0M7Ad09RHV02/[:`0S8b<0
:b/[0492@P1eMGD0OGem061PH039bLT0_[jn08N7Q`1:BTX0CDe=07=cL`3GemL0hN7Q092@T00f=SH0
GEeM09ZJVP2HV9P0@d=30=CDe034a<@0c/k>0;Jf]P38b<P0GEeM02HV9P0G5aL05ADE01LG5`0J6QX0
8b<S06ATI02i^KT0EeMG034a<@0V9RH0820P02h^;P2j^[X0Kfm_05eMG@0206IVIP0K09>CT`1RHV80
=CDe02LW9`0T92@06ATI02XZ:P1RHV80OGem04a<C01BDU80WIfM0:>SX`1eMGD0bLW908:2PP1`L700
ZJVY07alO02f][H0[jn_04i>CP2:RXX0WinO09bLW024Q8@0KFe]017ooooo000?ooooo`0;06=SH`1_
Kfl0DE5A05IFEP1NGUh0>SXj03Ti>@1hN7P0H61P02`/;01VIVH00P0_;bl0o`17AdL0@D51038b<P0/
;2`0H61P05aLG00c<c<0EEEE02h^;P1UIFD0L71`03Ti>@20P800<c<c03Hf=P1/K6`0L71`0451@@1T
I6@0Fe]K04M7A`1/K6`0=3@d03Hf=P1SHf<06a/K02@T901mOGd0A4A403De=@14A4@0<c<c02`/;01l
O7`0;2`/03dm?@1kNg/0EUIF03De=@19BDT0;Rh^06m_K`23Ph<0K6a/04A4A01;Bd/0Ng]k02TY:@1G
EeL0M7Ad065QH@11@D40Cdm?038b<P1JFUX0X:2P07YjNP1aLG40KFe]04Q8B029RHT0NWYj04e=C@1;
Bd/0:2PX01DE5@1<C4`0FUYJ04Y:BP2PX:009bLW01LG5`1fMWH0DE5A03@d=02MWId0WYjN01XJ6P1A
DE40IVIV03Hf=P1jNWX0QhN703Ph>00k>c/0@41007YjNP1TI6@0ATI604E5A@0Y:BT0KVi^03hn?P0l
?3`0KFe]04Q8B024Q8@0GUiN05]KF`1_Kfl0ADE507IfMP2=SHd0HV9R075aL@1BDU80ATI606EUI@1Q
HF40QHF503`l?011@D40Jf][06EUI@1RHV80GUiN04M7A`1UIFD0OGem07inOP1DE5@0TY:B08:2PP1H
F5P0SHf=04Y:BP13@d<0Fe]K03dm?@2;Rh/0MWIf02/[:`1DE5@0SXj>0492@P2<S8`0Shn?04Q8B01O
Gel0SHf=05eMG@0k>c/0HV9R08F5Q@0o?cl0G5aL04Y:BP1XJ6P0C4a<04E5A@1gMgL0R8R805eMG@2R
XZ80UYJF071`L028R8P0W9bL05]KF`2<S8`0`L710:ZZZP1SHf<0Cdm?0:6QX@0m?Cd0NGUi0:JVYP1K
Fe/0UIFE06UYJ@2FUYH0?clo069RHP1?Cdl0C4a<04U9B@2JVYX0O7al03hn?P1KFe/0Bd];02PX:01?
Cdl0QXJ607alO02ZZZX0D51@02/[:`1^KVh0FEUI04];B`1LG5`0>CTi04i>CP2TY:@0GEeM05mOG`2Y
ZJT0PX:204a<C00Q8B40Jf][0861P@1cLg<0:RXZ06IVIP18B4P0KVi^0;Bd]01[Jf/0;Bd]05eMG@23
Ph<0;bl_04M7A`1KFe/0?3`l02/[:`1TI6@0>3Ph04a<C00`<300ATI605=CD`0n?Sh0LG5a05ADE00m
?Cd0UiNG09^KV`1^KVh0QHF506m_K`1eMGD0e=CD0;Rh^01[Jf/0S8b<09FEU@1UIFD07alO0410@024
Q8@0DU9B065QH@1YJFT0;Bd]028R8P0_;bl0LG5a05IFEP13@d<0QXJ603lo?`005P0n?Sh0EUIF04Q8
B00[:b/0S8b<07EeM@0a<C40HV9R03Hf=P2FUYH0GemO07QhN03Fe]H0P82002LW9`10@400WYjN09JF
UP0X:2P07QhN05=CD`23Ph<Looooo`090;Zj^P1>CTh0ATI6079bLP2EUID0Lg=c09VIV@0W9bL05ADE
00804a<C0300410@00l?3`0=3@d0A4A403Ph>00P8200@d=307AdM03<c<`0QXJ607MgM`0d=3@071`L
01@D500@410051@D01DE5@1CDe<0VYZJ09FEU@2KVi/0UIFE07AdM01aLG40KFe]07emO@2LW9`0g=cL
0=GEe@3=cLd0^[Zj0:RXZ025QHD0K6a/06IVIP19BDT0=SHf03dm?@1KFe/0Y:BT0=3@d031`L40CDe=
0820P01hN7P0a/K60<30`01oOgl2010@400300l?3`0>3Ph0410@00@03Ph>02/04A4A03dm?@2GUiL0
Z:RX09bLW01BDU80Hf=S07IfMP17AdL0?clo04A4A00I6AT03Ph>00d=3@0?3`l03Ph>010@401KFe/0
SXj>096AT@3EeMD0fMWI0:FUY@1VIVH0<S8b04=3@`0n?Sh0>c/k034a<@0S8b<061PH01@D500>3Ph0
8R8R0:FUY@2f][H0aLG507AdM034a<@0[Jf]08^;R`29RHT0PH610080K6a/0;40>c/k02l_;`1=CDd0
9RHV01DE5@0I6AT0:RXZ06IVIP1IFET09RHV03hn?P1;Bd/0<30`034a<@0j>SX0J6QX0492@P2IVIT0
g=cL0<C4a02TY:@0RXZ:05mOG`1=CDd0Bd];05mOG`2>SXh0YJFU08F5Q@28R8P0PX:204i>CP0_;bl0
?Cdm03Ti>@0X:2P05aLG03Lg=`1FEUH0GemO04E5A@0o?cl0XZ:R0;no_`24Q8@0NWYj04=3@`0L71`0
61PH020P801PH600De=C04Y:BP1^KVh0`/;205ADE00W9bL0=3@d02LW9`0k>c/0OGem0<C4a02g]kL0
EeMG05ADE00i>CT0<S8b04E5A@1mOGd092@T055AD@13@d<0HF5Q075aL@26QXH0ATI601hN7P1aLG40
RXZ:03`l?00n?Sh0DU9B09^KV`1bLW807alO03Lg=`1^KVh0;Bd]028R8P0[:b/0=3@d030`<00Y:BT0
ADE508j>SP2HV9P0RHV90<71`@2d];@0Shn?06YZJP2][Jd0J6QX02TY:@0Q8B407AdM024Q8@0[:b/0
=3@d061PH02TY:@0bl_;09VIV@1dM7@0W9bL08R8R02DU9@0YZJV0=?Cd`1YJFT0EeMG08:2PP3<c<`0
YZJV0:b/[00d=3@0/k>c0<O7a`3GemL0^k^k06=SH`0G5aL05QHF01PH600I6AT05aLG01dM7@0X:2P0
SXj>06UYJ@0G5aL05ADE01PH600L71`0=cLg09FEU@1CDe<0E5AD04a<C024Q8@0GUiN06i^KP1CDe<0
Ng]k08V9R@1aLG40G5aL04a<C01NGUh0BDU905MGE`1@D500IFEU05aLG030`<00KVi^04U9B@1mOGd0
X:2P0:BTY02a/K40YZJV04I6AP0c<c<0>c/k0:JVYP1HF5P04Oooool000oooooo0600HV9R06YZJP19
BDT0Cdm?06a/K01<C4`0@d=30:NWY`2:RXX0:BTY07MgM`2?Shl0?Shn02l_;`16ATH0<c<c03@d=00h
>3P0GEeM05IFEP1CDe<08b<S04M7A`1QHF40=CDe079bLP1TI6@0@d=304m?C`1LG5`0;bl_05mOG`1]
KFd0?clo05EEE@0e=CD0>SXj051@D015ADD0<C4a07]kN`0];Bd0A4A403hn?P0];Bd0:b/[07]kN`13
@d<0?3`l04Y:BP0d=3@0;Rh^0451@@0_;bl0GemO05=CD`1UIFD0@D5104i>CP2<S8`0>c/k02d];@1N
GUh0Lg=c04A4A01<C4`09RHV02DU9@1PH600DE5A05eMG@1SHf<0Cdm?08Z:RP2@T900Fe]K05MGE`12
@T80820P06=SH`15ADD0?3`l08N7Q`13@d<092@T0;6a/@1:BTX0AdM70:NWY`2ATI40;2`/06EUI@1M
GEd0;bl_079bLP2;Rh/204=3@`0M04A4A025QHD0LG5a051@D01OGel0=CDe06i^KP16ATH0@T9206YZ
JP1ADE40Ti>C05]KF`1JFUX0PX:204i>CP28R8P0Ti>C06][J`1cLg<0J6QX059BDP1WIfL0De=C08J6
QP1:BTX0CTi>06m_K`1ZJVX00P1LG5`0X@1?Cdl0KVi^07MgM`1oOgl0Cdm?06=SH`1QHF40H61P08n?
S`1?Cdl0GEeM05=CD`0d=3@0RXZ:07EeM@0i>CT0=CDe07moO`19BDT0WIfM08b<S01<C4`0K6a/09bL
W01ADE40?Cdm07YjNP2@T900ATI6061PH01?Cdl0IfMW07YjNP1VIVH0PH6108>3P`1XJ6P0/[:b09nO
W`28R8P0X:2P0:FUY@0m?Cd0De=C08B4Q02:RXX0EUIF075aL@2f][H0E5AD0:NWY`2LW9`0@41007in
OP2?Shl0SXj>04U9B@1UIFD0I6AT04Q8B00W9bL0DU9B07]kN`0l?3`0IFEU05iNGP1;Bd/0>CTi05mO
G`1aLG40UIFE06e]K@0i>CT0TY:B05YJFP1<C4`0J6QX06ATI01KFe/0RHV905mOG`1EEED0/k>c07Ee
M@12@T80=SHf0:2PX02RXZ80GEeM02`/;01[Jf/0?Shn04A4A01NGUh0EUIF03hn?P1YJFT0RXZ:0410
@01CDe<0DU9B02HV9P19BDT0Ti>C04e=C@1]KFd0=cLg055AD@1JFUX0EeMG08b<S01KFe/09bLW04E5
A@1BDU80ATI607MgM`1@D500@D5107UiN@27QhL0Fe]K09JFUP2/[:`0OGem02l_;`1:BTX0O7al04i>
CP1LG5`0KFe]03dm?@0Y:BT0?Cdm08V9R@1<C4`0EEEE0:2PX01OGel0AdM705mOG`11@D408R8R07in
OP1<C4`0;Rh^07]kN`11@D40ZZZZ0492@P0c<c<0Vi^K09:BTP1FEUH0=cLg05iNGP1SHf<0>c/k02LW
9`1ZJVX0TY:B01cooooo00`0XZ:R09JFUP2JVYX0XJ6Q09VIV@2VYZH0Ti>C01lO7`0F5QH05ADE01@D
500>3Ph2010@400_03/k>`0b<S805aLG01PH600o?cl0dM7A0;jn_P24Q8@0Lg=c06=SH`0M7Ad0<C4a
03/k>`1]KFd0P82008V9R@21PH40Ogmo06QXJ01?Cdl0BDU90451@@2GUiL0clo?0=SHf02m_Kd0RHV9
04a<C013@d<0;bl_024Q8@0n?Sh0Hf=S06][J`2<S8`0Jf][02`/;01CDe<0_kno08>3P`2GUiL0FUYJ
0:b/[02k^k/0?Shn00d=3@0A4A400P0?3`l200h>3P0]00l?3`0>3Ph03Ph>00h>3P0@41005aLG05MG
E`2<S8`0G5aL08F5Q@1^KVh0O7al09BDU02:RXX0A4A401hN7P0J6QX05QHF01LG5`0E5AD0BDU90:j^
[P3?cll0`<300>WYj@3Cdm<0a/K60:RXZ01iNGT0GEeM05MGE`1EEED0D51@055AD@1@D500=3@d05AD
E01IFET0<C4a07IfMP2_[jl0YJFU07inOP12@T80?clo0080?3`l0500?clo05mOG`1BDU80;Bd]04U9
B@0O7al05aLG01XJ6P1?Cdl0E5AD05QHF01SHf<0MGEe06MWI`1@D500UYJF09jNWP0n?Sh0WYjN07em
O@1EEED0MgMg0410@00l?3`0?Shn04m?C`1JFUX0OWin0<_;b`2TY:@0YJFU0:^[Z`0n?Sh0ADE503<c
<`0U9BD06a/K01LG5`0K6a/09RHV04I6AP1LG5`0KFe]07AdM032`/80Shn?08B4Q00R8R806QXJ02d]
;@1;Bd/0EeMG06IVIP1>CTh0>CTi04];B`16ATH0@41003Hf=P0l?3`0De=C08J6QP2ATI40c/k>02/[
:`0L71`06QXJ01lO7`0U9BD0GemO02h^;P0m?Cd0EEEE07emO@2IVIT0B4Q8020P800G5aL0?Cdm0;>c
/`80CDe=02h0GemO09NGU`22PX80U9BD03Lg=`18B4P071`L01LG5`0E5AD05QHF01XJ6P0I6AT0:BTY
096AT@1]KFd0MgMg0;^k^`1JFUX0Ng]k079bLP28R8P0^;Rh06QXJ00V9RH07alO01dM7@0P8200<30`
05YJFP2d];@0IVIV061PH037alL0Zj^[06UYJ@1nOWh0d=3@059BDP0Q8B409bLW02h^;P14A4@0[Zj^
0:NWY`1VIVH0eMGE0P3MgMd01@32`/80De=C01DE5@0F5QH05aLG00806ATI02T071`L030`<02CTi<0
?clo01LG5`0K6a/06ATI024Q8@1LG5`0OGem05EEE@1;Bd/0DE5A07=cL`1PH600@410059BDP2f][H0
NGUi06][J`0U9BD0H61P0492@P0`<300<C4a030`<016ATH0Fe]K07emO@1`L700@T9206UYJ@0l?3`0
?Cdm08:2PP1jNWX0820P02TY:@0^;Rh0Lg=c02h^;P0Aooooo`003oooool0F`1YJFT0VYZJ055AD@1G
EeL0L71`04e=C@19BDT0YJFU08^;R`0^;Rh0NGUi092@T010@400<30`04Q8B00i>CT0A4A405YJFP1e
MGD0CDe=06ATI016ATH0L71`07MgM`0n?Sh0NGUi07MgM`1CDe<0IfMW06ATI00k>c/0GemO07moO`1C
De<0Fe]K03De=@1;Bd/0GUiN051@D00k>c/0Shn?03dm?@11@D40AdM702l_;`0];Bd0MGEe04m?C`0n
?Sh0Fe]K03Ph>00^;Rh0<c<c02l_;`1aLG40DU9B06MWI`0h>3P0DU9B09JFUP1>CTh0@D5106YZJP1j
NWX0A4A405eMG@1>CTh0<C4a07emO@1EEED0CTi>06UYJ@1PH600WinO08J6QP1IFET0OGem06MWI`0c
<c<0K6a/0451@@0n?Sh0TY:B059BDP0Q8B40YZJV03dm?@1=CDd0W9bL08B4Q01;Bd/00P1aLG40:@0o
?cl0P8200:^[Z`0l?3`0BDU904m?C`1oOgl0BDU905iNGP1eMGD0?3`l079bLP19BDT0I6AT08n?S`1D
E5@0S8b<06=SH`1/K6`0QhN7055AD@1kNg/0T92@06i^KP20P800Hf=S06QXJ01SHf<0MWIf09jNWP1?
Cdl0D51@07MgM`1ADE40Lg=c075aL@1FEUH0Jf][09BDU02?Shl0D51@0080IFEU09X0AdM707emO@1@
D500M7Ad04a<C01:BTX0W9bL06i^KP0o?cl0=3@d07]kN`0_;bl0EEEE07emO@12@T80I6AT08n?S`0b
<S80FUYJ09bLW02IVIT0A4A407QhN00d=3@0G5aL06YZJP1TI6@0Shn?07UiN@1=CDd0UiNG0:2PX01i
NGT0WIfM0;:b/P1dM7@0JFUY0:6QX@27QhL0>c/k05MGE`2GUiL0H61P0;Vi^@2;Rh/0<C4a05mOG`1E
EED0MGEe0492@P1bLW80Cdm?06IVIP0k>c/0KVi^075aL@0h>3P0Q8B405mOG`1>CTh0?clo06UYJ@19
BDT0TI6A05YJFP0c<c<0RXZ:04Q8B01OGel0TI6A061PH01HF5P0XZ:R071`L01LG5`0e=CD0<k>cP1T
I6@0ATI60:n_[`2h^;P0Ogmo04E5A@2DU9@0JVYZ065QH@1bLW80@41003Xj>P1oOgl0T92@04i>CP1A
DE40IfMW02LW9`0V9RH0GEeM05EEE@1TI6@0?Shn05IFEP0[:b/0ATI608^;R`1[Jf/0>CTi05UIF@1G
EeL0=cLg08Z:RP1YJFT0J6QX08V9R@2ATI40EUIF0;:b/P3Cdm<0UIFE030`<01<C4`0HF5Q03@d=017
AdL0BDU902d];@0W9bL0>CTi07MgM`0[:b/0?Cdm07]kN`17AdL0EEEE0:^[Z`2<S8`0;Bd]07emO@17
AdL05aLG05UIF@10@400WinO04E5A@0o?cl0/[:b06QXJ01>CTh0?Shn08N7Q`1fMWH09BDU04i>CP2H
V9P0X:2P7?ooool02`2;Rh/0F5QH05UIF@1IFET0T92@0=3@d02JVYX0>CTi05IFEP0`<300;Bd]0080
<S8b02L08b<S04I6AP12@T80EEEE07EeM@2EUID0VIVI0;fm_@39bLT0=SHf030`<02k^k/0]kNg08j>
SP1DE5@0@d=30861P@2_[jl0Kfm_0820P00^;Rh0<C4a05]KF`1LG5`0TI6A0;Rh^02JVYX0SHf=0410
@00X:2P071`L030`<028R8P0Shn?069RHP0X:2P06ATI02`/;01HF5P00P2YZJT01P2PX:00R8R80:2P
X02_[jl0FEUI00h>3P803@d=00<03Ph>00d=3@0=3@d00`0>3Ph06@0B4Q804A4A01DE5@0X:2P0E5AD
0410@02RXZ80]KFe0:NWY`2JVYX0W9bL09FEU@1/K6`0EEEE02HV9P0Y:BT0AdM707alO02/[:`0ZJVY
0<71`@3>c/h0PH6109^KV`19BDT00P0E5AD09@0G5aL04Q8B00h>3P0@41005QHF034a<@1jNWX08B4Q
01HF5P1QHF40TI6A0;Bd]02DU9@0Cdm?03Xj>P0^;Rh0:b/[03`l?01KFe/0O7al05=CD`0X:2P0?Shn
024Q8@0J6QX0;bl_09jNWP31`L40V9RH0:NWY`2YZJT0QhN70;no_`2OWil0F5QH09fMW@0L71`00P0P
82003P0H61P05QHF01dM7@0N7Qh0820P02<S8`2UYJD0ZZZZ059BDP31`L40Rh^;034a<@0P82006QXJ
0P0K6a/03`0M7Ad071`L01`L700];Bd0CDe=07YjNP3GemL0^k^k09jNWP0g=cL0>3Ph05aLG023Ph<0
BDU901XJ6P0201DE5@0H01LG5`14A4@0?clo05YJFP1]KFd0EUIF03`l?02VYZH0_[jn069RHP0N7Qh0
6a/K01hN7P0M7Ad0=CDe05YJFP0g=cL0QHF509bLW01ZJVX09bLW01DE5@0V9RH0T92@0P3Fe]H09P2K
Vi/0KFe]05YJFP1dM7@0WinO07IfMP0n?Sh07QhN01LG5`0F5QH05aLG01TI6@0Q8B40LG5a0:6QX@1M
GEd0OWin08Z:RP1=CDd0HF5Q0;>c/`1eMGD0ZJVY07alO016ATH07QhN01lO7`0S8b<0<S8b06QXJ02Q
XJ40GEeM06a/K02EUID0V9RH0:6QX@31`L40MGEe0P0N7Qh0700U9BD0:RXZ02h^;P1RHV80^k^k0=KF
eP2YZJT0h>3P0=[JfP2g]kL0QHF502@T900E5AD06a/K01DE5@0L71`06a/K03/k>`2:RXX0<30`01`L
700K6a/07AdM03`l?02?Shl0NGUi05iNGP1ADE4206EUI@0K06ATI01NGUh0FEUI04U9B@0d=3@0:BTY
03lo?`1mOGd0=CDe03`l?00b<S809BDU05YJFP1eMGD0Fe]K06UYJ@1HF5P0LG5a03Ph>00Z:RX0CDe=
08F5Q@0[:b/0;Bd]05ADE02ZZZX0>SXj017ooooo000?ooooo`3X06QXJ02LW9`0CTi>04m?C`1YJFT0
B4Q804M7A`1dM7@092@T02l_;`1fMWH0OWin03Ph>00/;2`0BDU903Xj>P1;Bd/0J6QX06i^KP0k>c/0
KFe]04=3@`1gMgL0Lg=c04E5A@1oOgl0Kfm_05EEE@1dM7@0HV9R03De=@1UIFD0Lg=c05ADE015ADD0
8R8R04I6AP1LG5`0E5AD03hn?P2[Zj/08R8R04a<C012@T808b<S0410@01fMWH0CDe=0451@@18B4P0
;bl_02DU9@1BDU80?3`l06MWI`1@D500A4A403<c<`1ZJVX0[jn_04I6AP15ADD0DU9B06EUI@22PX80
N7Qh04i>CP0^;Rh0OGem04U9B@12@T80K6a/05aLG02e]KD0J6QX02/[:`1=CDd0Cdm?02<S8`1dM7@0
OGem059BDP2JVYX0CTi>02@T902e]KD0Fe]K03Lg=`23Ph<0MWIf03Lg=`26QXH0L71`01dM7@1HF5P0
K6a/04e=C@1@D500PH6109:BTP1NGUh0C4a<04Y:BP0h>3P0P82003Xj>P0i>CT0Hf=S04e=C@2[Zj/0
ATI605QHF01FEUH0HF5Q0;Bd]01lO7`0?clo06EUI@1>CTh0Ti>C069RHP15ADD0GemO0410@01kNg/0
WYjN04M7A`18B4P0D51@04e=C@1eMGD0HV9R055AD@0W9bL0RHV907alO01=CDd0MgMg02l_;`1OGel0
LW9b030`<01bLW80H61P03`l?01IFET0OGem03hn?P1ZJVX0Ng]k04M7A`1oOgl0YZJV05aLG00c<c<0
J6QX06m_K`1;Bd/0Q8B405QHF01MGEd0Kfm_05iNGP2`/;00Lg=c05iNGP2b/[80QhN7034a<@1cLg<0
^KVi07MgM`1SHf<0Y:BT0:FUY@1XJ6P0IVIV09FEU@1CDe<0`<3008Z:RP0o?cl0PH6106UYJ@27QhL0
A4A4071`L01PH600G5aL04Q8B01/K6`0G5aL02h^;P28R8P0M7Ad05EEE@11@D40EUIF05ADE01nOWh0
EEEE02DU9@1`L700?clo04M7A`1EEED0>3Ph04m?C`2SXj<0IFEU03hn?P2KVi/0TI6A08V9R@1IFET0
_kno0:RXZ02FUYH09RHV05iNGP1VIVH0Hf=S0861P@1JFUX0=CDe06UYJ@2GUiL0EEEE04a<C01NGUh0
BDU902TY:@80Lg=c03P0KFe]03<c<`1MGEd0GUiN04A4A025QHD0JVYZ03lo?`1PH600Cdm?02DU9@1N
GUh0MGEe065QH@2UYJD0WYjN03@d=02<S8`0OGem0820P00^;Rh0B4Q807alO01DE5@0Jf][03dm?@0W
9bL0?Cdm07EeM@2UYJD0L71`03hn?P1YJFT04A4A03Xj>P1GEeL0E5AD02HV9P1eMGD0CDe=02DU9@1X
J6P0@T920:VYZ@1PH600@D510;Zj^P1PH600>c/k03`l?01jNWX0Jf][01XJ6P0S8b<0@T9207alO1co
oooo03h0TY:B04];B`1IFET0L71`09RHV02f][H0]KFe0:JVYP1@D50092@T01dM7@0_;bl0>CTi04m?
C`1_Kfl0Rh^;06YZJP19BDT0?Cdm0492@P1mOGd0MgMg08f=S@25QHD0SXj>05=CD`1HF5P0ATI602`/
;00Q8B40=CDe02XZ:P2MWId0MGEe05iNGP1BDU80FEUI06m_K`2PX:00b/[:0:JVYP2IVIT0R8R804I6
AP18B4P0PH6106MWI`1:BTX0Cdm?05aLG01HF5P0ATI608F5Q@2<S8`0ZZZZ09FEU@0l?3`0OGem07Ad
M00C4a<03@d=00h>3P803@d=0P0>3Ph0;@0C4a<03Ph>014A4@0C4a<0410@01dM7@19BDT05ADE020P
801DE5@0VIVI0<[:bP2d];@0Vi^K0:b/[02m_Kd0Kfm_0410@013@d<0DE5A0<;2`P3Cdm<0U9BD08^;
R`2SXj<0QhN708>3P`1EEED09bLW01DE5@0B4Q804A4A010@400>3Ph0410@04m?C`0J6QX06ATI05YJ
FP1fMWH0Shn?05YJFP1`L700JFUY05EEE@0202h^;P0904m?C`1SHf<0GEeM05eMG@0];Bd0@d=302LW
9`0T92@0RXZ:0080Xj>S00/0R8R806i^KP0b<S80M7Ad0861P@2k^k/0Lg=c01TI6@0G5aL05ADE01HF
5P0201DE5@0K01XJ6P0L71`09BDU0861P@1PH600Bd];09^KV`1?Cdl07QhN01`L700J6QX071`L01/K
6`0L71`06a/K01XJ6P0G5aL08b<S04m?C`2PX:00Ti>C08f=S@1nOWh0N7Qh07EeM@0e=CD071`L00@0
5ADE00`08B4Q0451@@1nOWh0DU9B02<S8`0i>CT0][Jf0=WIf@3>c/h0QHF505MGE`0o?cl203De=@12
0;bl_02DU9@0]KFe07=cL`1jNWX06ATI02<S8`2?Shl0N7Qh04e=C@22PX80X:2P07MgM`19BDT0ADE5
05iNGP2RXZ80H61P02PX:00G5aL061PH01XJ6P0W9bL0RXZ:07emO@2FUYH0A4A402/[:`1;Bd/0K6a/
08B4Q02m_Kd0];Bd09fMW@2][Jd0KFe]04];B`1OGel0AdM704e=C@21PH40S8b<05mOG`2XZ:P0NWYj
069RHP2BTY80/;2`04A4A00Y:BT0820P02<S8`0/;2`0B4Q807=cL`2RXZ80bLW907YjNP1oOgl0dm?C
0;bl_02JVYX0Shn?04];B`0J6QX06ATI0P0M7Ad0:019BDT0S8b<020P800M7Ad0:2PX0410@01OGel0
Z:RX0:JVYP27QhL0L71`04Q8B00J6QX06ATI04e=C@1?Cdl0HF5Q03/k>`0`<300QHF503Ti>@0a<C40
92@T02<S8`0[:b/0Fe]K04Y:BP1KFe/0NWYj079bLP1fMWH0>3Ph02l_;`0k>c/0Lg=c04m?C`19BDT0
@D51055AD@1[Jf/Aooooo`003oooool0;01RHV80N7Qh055AD@1EEED0FEUI04M7A`1EEED0VIVI06AT
I00S8b<0HF5Q04];B`0c<c<0B4Q803dm?@14A4@0?3`l05iNGP11@D4092@T061PH00e=CD0R8R804m?
C`0`<300G5aL05]KF`1:BTX0OGem069RHP0a<C40E5AD04a<C01=CDd0BDU902TY:@19BDT0GemO03dm
?@0a<C40S8b<03Xj>P0h>3P0B4Q80P0/;2`0L`1QHF40>SXj0492@P1RHV80@d=302`/;00a<C40;Rh^
06m_K`1XJ6P0DE5A02TY:@14A4@0OGem03Ph>01FEUH0IVIV0410@01oOgl0F5QH03De=@0g=cL0PX:2
05IFEP18B4P0DU9B0492@P2GUiL0Hf=S03@d=01KFe/0@d=302HV9P1mOGd0IVIV03Ti>@1nOWh0<C4a
03<c<`2KVi/0A4A403<c<`2HV9P0Ti>C02PX:01IFET0Hf=S02l_;`1RHV80S8b<02h^;P16ATH0IFEU
07alO01]KFd0EEEE04Y:BP0Z:RX0I6AT030`<00g=cL0DE5A0451@@29RHT0FEUI05IFEP1TI6@0@T92
075aL@1mOGd0EUIF05YJFP1<C4`0IVIV061PH01@D500NGUi04E5A@1>CTh0IfMW05UIF@1PH600DU9B
04Q8B01NGUh0LG5a0861P@1<C4`0Q8B406IVIP1MGEd0N7Qh04e=C@1_Kfl0G5aL03Ti>@1kNg/0JVYZ
03@d=00o?cl0Ng]k03lo?`2;Rh/0QhN703`l?01=CDd0PH6104Y:BP13@d<0VYZJ07QhN00h>3P0I6AT
05EEE@1`L7000P1PH600O`2`/;00Shn?06m_K`30`<00UIFE07emO@27QhL0ZZZZ07MgM`1oOgl0_;bl
0;>c/`1]KFd0Jf][09JFUP1MGEd0a<C408j>SP18B4P0TY:B08f=S@1gMgL0E5AD071`L01KFe/0ATI6
04Q8B01fMWH0PX:204=3@`20P800LG5a04];B`1BDU80J6QX075aL@2GUiL0GUiN04];B`2[Zj/0F5QH
05IFEP1NGUh0@D5105mOG`2VYZH0I6AT04m?C`2m_Kd0Ph>306QXJ012@T80a/K60:j^[P1WIfL0=3@d
06=SH`14A4@0HV9R08b<S01SHf<0@T9207EeM@1oOgl0?Shn05mOG`1MGEd0Bd];03hn?P2DU9@0Shn?
05MGE`16ATH0J6QX05UIF@11@D40Shn?05EEE@0j>SX0LG5a079bLP0l?3`0HF5Q04I6AP1ZJVX0[Jf]
09^KV`1TI6@0Ti>C06EUI@1IFET06QXJ06EUI@2:RXX0FUYJ07MgM`1;Bd/07QhN030`<013@d<0MgMg
059BDP0j>SX0F5QH05EEE@16ATH0EUIF05EEE@0[:b/0PH6105eMG@0Z:RX0GUiN03Lg=`2;Rh/0K6a/
03hn?P2`/;00JVYZ03<c<`0j>SX0PH6107]kN`0c<c<0>3Ph055AD@24Q8@07?ooool02`26QXH0C4a<
04Y:BP1CDe<0IFEU05mOG`2;Rh/0KVi^04m?C`0U9BD06ATI00805ADE03004a<C03De=@1ADE40@410
03`l?00[:b/0<S8b03hn?P0K6a/0Kfm_09:BTP2PX:00Hf=S030`<00W9bL09BDU024Q8@0Y:BT0@D51
08b<S01=CDd0:BTY02@T900V9RH0<30`06=SH`37alL0_;bl0;>c/`36a/H0TI6A08R8R02][Jd0QhN7
06ATI01LG5`0FEUI059BDP1IFET0Fe]K08Z:RP1hN7P0Cdm?01dM7@1:BTX0NWYj0451@@0@410500d=
3@1300l?3`0>3Ph03`l?014A4@0P8200@41004U9B@0c<c<051@D01<C4`0K6a/0=cLg079bLP2MWId0
]KFe0:VYZ@2b/[80Q8B406e]K@1aLG40O7al06a/K01bLW80NWYj09FEU@2>SXh0TY:B04U9B@1CDe<0
A4A404=3@`0k>c/0?Shn0451@@0n?Sh0LG5a06a/K021PH40PX:20820P01bLW80<C4a020P800I6AT0
8R8R03Ti>@11@D40A4A404a<C01@D500ATI604m?C`1<C4`0D51@08^;R`27QhL0/k>c06=SH`1/K6`0
GemO04U9B@0U9BD0KFe]07alO01FEUH0=CDe01dM7@0301DE5@0<01HF5P0G5aL061PH01hN7P1bLW80
NWYj04=3@`1=CDd0J6QX01dM7@0H61P06QXJ0P0I6AT03`0J6QX06ATI01PH600H61P071`L02@T901O
Gel0Zj^[0;Fe]@2[Zj/0D51@02`/;00M7Ad05ADE01@D500201DE5@0a01HF5P0E5AD0>CTi04Q8B00o
?cl0;Rh^05YJFP2/[:`0Xj>S0820P00];Bd0=3@d04A4A01EEED0NWYj0=OGe`3Lg=`0];Bd092@T02:
RXX0H61P065QH@0g=cL0<S8b03Lg=`0^;Rh0:2PX03Ti>@17AdL0ATI604Q8B01MGEd0QhN708n?S`1V
IVH0J6QX07moO`1hN7P0DU9B05eMG@2<S8`0K6a/05mOG`1_Kfl0OGem0861P@27QhL0PX:208V9R@02
09nOW`0=0:2PX02`/;00^;Rh0;Bd]02l_;`0`/;20:NWY`2DU9@0LW9b08B4Q02JVYX0=SHf02`/;002
03Lg=`0i03`l?01XJ6P0YjNW05YJFP1kNg/0U9BD02PX:00j>SX0GEeM0;Fe]@31`L40QhN708b<S01P
H600AdM705UIF@1LG5`0Ph>309RHV01EEED0IVIV07moO`2<S8`0Q8B40;^k^`1jNWX0CDe=01lO7`0F
5QH05ADE01HF5P0K6a/0E5AD04U9B@1TI6@0U9BD07MgM`10@400:b/[01dM7@0W9bL0<C4a02XZ:P0[
:b/0=SHf05aLG01`L700OWin061PH01LG5`0FEUI071`L02VYZH0NWYj03@d=00Z:RX0;2`/017ooooo
000?ooooo`3o06MWI`2[Zj/0CDe=06=SH`1^KVh0EEEE05UIF@2JVYX0KFe]02@T901gMgL0Ph>302`/
;00U9BD0?3`l02XZ:P0Q8B40Cdm?05QHF00n?Sh0Hf=S01lO7`1]KFd0GemO03Xj>P1ZJVX0@41003Ti
>@1jNWX0IFEU03De=@1DE5@0Hf=S04a<C01BDU80=CDe05EEE@1TI6@0<S8b03lo?`2EUID0AdM70492
@P1?Cdl0;bl_03Lg=`1LG5`08b<S03/k>`11@D40BDU902l_;`0^;Rh0@D5105iNGP18B4P0C4a<02l_
;`1<C4`0QHF502d];@0e=CD0HV9R034a<@2RXZ80EeMG02XZ:P0X:2P0MWIf04M7A`0h>3P0GUiN05IF
EP2PX:00HV9R02`/;01dM7@0JFUY02XZ:P1eMGD0CDe=02TY:@1^KVh0@d=302`/;02WYjL0ATI6069R
HP2h^;P0VIVI05]KF`1`L700K6a/02d];@1UIFD0Shn?04E5A@0n?Sh0Hf=S08f=S@17AdL0GEeM071`
L00l?3`0MgMg02l_;`19BDT0HV9R03hn?P29RHT0ADE507AdM01cLg<0FEUI06e]K@1cLg<0Cdm?08^;
R`1RHV80KVi^05mOG`1fMWH0SHf=04];B`1@D500KFe]05ADE01dM7@0OWin05EEE@1VIVH0Fe]K075a
L@1=CDd0?Cdm04E5A@0k>c/0L71`05iNGP1iNGT0HF5Q04U9B@2VYZH0Ng]k04=3@`1PH600LG5a03Ph
>01LG5`0Q8B403/k>`1@D500Shn?055AD@0a<C40GUiN07AdM010@400M7Ad05=CD`22PX80MGEe06YZ
JP2f][H0L71`06EUI@2k^k/0YZJV08F5Q@2?Shl0T92@051@D01FEUH0]KFe0:j^[P1WIfL0QhN70:>S
X`1YJFT0clo?08>3P`0e=CD0Jf][0:2PX022PX80@d=3075aL@1FEUH0FEUI04A4A023Ph<0TI6A04Y:
BP20P800LG5a03/k>`1eMGD0LW9b06=SH`2WYjL0Fe]K04Y:BP2VYZH0DE5A069RHP2UYJD0@T9204=3
@`2MWId0R8R8055AD@2o_kl0MWIf07moO`0^;Rh0U9BD0;no_`2IVIT0>c/k06MWI`0Y:BT0>3Ph07Yj
NP1oOgl0AdM70:>SX`2LW9`0DU9B05MGE`1OGel09RHV02<S8`1nOWh0O7al06EUI@0_;bl0FUYJ04E5
A@1>CTh0UiNG06QXJ014A4@0HV9R06i^KP1?Cdl0JVYZ059BDP1]KFd0UYJF08>3P`1KFe/0Q8B407Ui
N@23Ph<0=SHf000S059BDP1>CTh0=SHf07]kN`1hN7P0E5AD03lo?`16ATH0L71`03Hf=P1RHV80V9RH
05QHF01JFUX0DU9B04M7A`0O7al0Jf][04i>CP0[:b/0Kfm_034a<@21PH40BDU902h^;P2d];@0YZJV
07AdM00n?Sh0Lg=c06=SH`0h>3P0Kfm_07alO028R8P07?ooool00`2n_[h0CTi>04I6AP0206QXJ00i
07inOP18B4P0A4A404A4A01UIFD0>CTi01TI6@0F5QH05ADE03@d=016ATH09RHV03De=@0o?cl0Cdm?
01dM7@15ADD0ATI6030`<017AdL0]kNg0<S8b02WYjL0Vi^K09ZJVP3IfMT0d];B07alO00L71`06ATI
01DE5@0Q8B40820P07]kN`29RHT08b<S051@D02[Zj/0g=cL0=_Kf`2l_;`0UYJF07MgM`1SHf<0ATI6
03Xj>P0/;2`09RHV05YJFP0[:b/0<30`03Xj>P0g=cL0KFe]07EeM@0D51@03Ph>00H03@d=04<03Ph>
024Q8@1ZJVX0:b/[018B4P24Q8@0H61P04U9B@0l?3`0De=C0:>SX`29RHT0Z:RX07=cL`2<S8`0dM7A
08:2PP0[:b/0:BTY01TI6@0i>CT0M7Ad08R8R01QHF40MGEe06a/K01KFe/0BDU903`l?00`<300:BTY
02LW9`0Y:BT0H61P0;2`/02OWil0YZJV0=?Cd`0i>CT07QhN030`<012@T80=CDe01/K6`0H61P08B4Q
051@D01IFET0AdM7061PH01UIFD0_kno0;Zj^P3>c/h0gMgM08^;R`1>CTh0Ogmo09:BTP1/K6`0T92@
0;Ng]`1SHf<0?Cdm02l_;`0Z:RX05aLG00805ADE01/05aLG01DE5@0E5AD0=cLg05eMG@1DE5@0KFe]
0;Bd]01SHf<0Fe]K03Ti>@0c<c<07QhN01XJ6P0G5aL05ADE01HF5P0I6AT09RHV06EUI@3Ng]h0f][J
0=OGe`2RXZ80F5QH02<S8`0H61P0100E5AD0G`0G5aL07alO06QXJ01>CTh0GemO0;6a/@1OGel0YjNW
02LW9`0J6QX06a/K020P801?Cdl0SHf=03Xj>P1lO7`0Rh^;09RHV033`l<0]KFe02HV9P11@D407AdM
01TI6@0K6a/07alO024Q8@0S8b<0820P034a<@1HF5P0Bd];06i^KP33`l<0/K6a09^KV`20P800RXZ:
0<30`01lO7`0Bd];055AD@1[Jf/0EUIF0492@P1PH600SHf=059BDP18B4P0YjNW0;^k^`2=SHd0[Zj^
0:BTY02j^[X0_Kfm0<;2`P2d];@0/;2`0=KFeP0e=CD08b<S028R8P0Q8B407AdM01hN7P0h>3P0MgMg
04a<C02c/k<0?clo02<S8`16ATH0De=C09:BTP1EEED0A4A406m_K`2WYjL0emOG08n?S`1@D500bl_;
09VIV@1DE5@0=CDe02<S8`0X:2P0=cLg06a/K00e=CD09RHV01LG5`0E5AD05aLG00805ADE01@0?Cdm
05UIF@13@d<0Xj>S07UiN@0b<S806a/K02/[:`0X:2P09BDU01PH600I6AT0:2PX05mOG`21PH40MGEe
05aLG02][Jd0^k^k092@T080^KVi00<0XJ6Q09ZJVP29RHT04Oooool000oooooo0600KFe]0:^[Z`1=
CDd0AdM705aLG01=CDd0BDU907=cL`0l?3`0?Shn08f=S@22PX80;Rh^02`/;01<C4`0@d=303Xj>P1G
EeL0=3@d03<c<`1cLg<0;bl_096AT@0j>SX0BDU906i^KP1VIVH0DU9B09^KV`1SHf<0>3Ph07EeM@22
PX80FEUI04Q8B00W9bL0HF5Q0820P01LG5`0ADE50:FUY@0H61P0ATI604U9B@0N7Qh0DE5A08V9R@0j
>SX0@D510410@00j>SX0<30`05ADE01CDe<0JVYZ055AD@1:BTX0?3`l06m_K`2WYjL0BDU905ADE01E
EED0<C4a08R8R01`L700<c<c02`/;024Q8@0ADE50451@@1_Kfl0G5aL08j>SP1EEED0820P04U9B@1W
IfL0<C4a07moO`1IFET0>c/k05EEE@1BDU80<C4a0:VYZ@0e=CD0:b/[06YZJP1cLg<0EeMG06MWI`1_
Kfl0@410055AD@27QhL20451@@1/07alO02:RXX0NGUi05QHF01NGUh0<S8b08^;R`0o?cl0=CDe06UY
J@18B4P0SHf=04i>CP1<C4`0IFEU04a<C01iNGT0DE5A03dm?@1/K6`0EeMG08V9R@1GEeL0D51@07em
O@12@T80CTi>06i^KP1ADE40DU9B05YJFP1FEUH0Kfm_07AdM01hN7P0D51@06m_K`1DE5@0DU9B07If
MP1<C4`0QXJ607IfMP0_;bl0OGem08B4Q017AdL0Hf=S08f=S@14A4@0LG5a0:2PX011@D40CTi>09>C
T`1MGEd0?clo07QhN029RHT0@D5107UiN@1DE5@0IVIV06=SH`1YJFT0_[jn07QhN01VIVH0aLG509nO
W`2>SXh0WYjN07]kN`1WIfL0KFe]0<k>cP2=SHd0Cdm?08^;R`2XZ:P0NWYj0=WIf@1iNGT0@D5106AT
I02=SHd0EUIF04a<C02EUID0H61P04e=C@0k>c/0NGUi05mOG`15ADD0`L7109:BTP1@D500RHV907If
MP0n?Sh0WinO05YJFP1XJ6P0UiNG0492@P16ATH0JVYZ0P1HF5P04@2h^;P0PX:205]KF`3;bl/0/k>c
06m_K`0h>3P0QhN707EeM@1jNWX0?Cdm07alO01GEeL0J6QX0861P@11@D40>CTi0080TY:B03l0CDe=
069RHP0m?Cd0@D5102l_;`23Ph<0MWIf05=CD`0`<300H61P02d];@0_;bl0PH61071`L01<C4`0Jf][
07EeM@19BDT0VYZJ07emO@1dM7@0Y:BT09NGU`1lO7`0XZ:R09RHV01iNGT0<C4a07MgM`1bLW80CDe=
05]KF`1EEED0Bd];059BDP1EEED0QXJ603Ti>@0e=CD0EeMG05ADE01XJ6P0W9bL06i^KP0a<C40LW9b
0451@@0V9RH0H61P02TY:@1^KVh0D51@024Q8@27QhL0Shn?065QH@0d=3@0L71`05]KF`0J6QX0>SXj
05UIF@1iNGT07?ooool0<@3IfMT0R8R806QXJ01`L700Ogmo03lo?`0n?Sh0:2PX03`l?00m?Cd0J6QX
03lo?`0J6QX05ADE03@d=01<C4`0;Bd]02PX:014A4@0;2`/03lo?`1<C4`0;bl_01lO7`0N7Qh0=SHf
0;>c/`37alL0a<C40=3@d03Cdm<0_kno051@D00J6QX08B4Q01HF5P0K6a/05aLG07EeM@0/;2`04A4A
010@400P8200Zj^[03`l?00P82005ADE018B4P0>3Ph00P0<30`01@0=3@d020P803dm?@2FUYH0<30`
0080?Shn00P0Hf=S06YZJP0e=CD03`l?00/;2`0=3@d02PX:00d=3@8030`<04@0410@07EeM@2>SXh0
<30`03dm?@0a<C4071`L038b<P18B4P0OWin0<O7a`15ADD0Cdm?01/K6`0n?Sh0X:2P034a<@0`<300
ATI605MGE`17AdL07QhN02TY:@1HF5P0DU9B08N7Q`0n?Sh0Cdm?04i>CP17AdL0>CTi02l_;`0Y:BT0
KFe]0;Jf]P2:RXX0S8b<0;Zj^P0j>SX04a<C01DE5@0I6AT09BDU03`l?00Y:BT05aLG01DE5@0f=SH0
QhN70:VYZ@32`/80^k^k0=cLg03:b/X0WIfM09JFUP22PX80R8R806=SH`1QHF40Vi^K0;Zj^P1BDU80
:BTY03@d=00_;bl0>CTi02@T90806ATI01`061PH01DE5@0Z:RX0H61P06IVIP1SHf<0>SXj020P800Q
8B409RHV03@d=00o?cl0?Shn03@d=00O7al05aLG01XJ6P0b<S80UYJF0<C4a033`l<0/[:b0:j^[P2o
_kl0^k^k07IfMP0`<3005aLG0`0E5AD01`0F5QH0L71`08V9R@2n_[h0clo?05iNGP2RXZ800P0L71`0
DP0T92@0BTY:08B4Q00];Bd08b<S06i^KP2XZ:P0[:b/0<C4a039bLT0KFe]01hN7P0I6AT08R8R02TY
:@0X:2P0;Bd]03Ph>012@T80A4A403/k>`0m?Cd0GemO0<71`@35aLD0U9BD09bLW035aLD0Zj^[0:6Q
X@2DU9@0YjNW05ADE00c<c<0C4a<05=CD`1BDU80G5aL04];B`1aLG40UIFE0;6a/@2SXj<0WIfM0;Vi
^@2WYjL0R8R805]KF`17AdL0Ti>C03De=@0R8R807AdM01`L700M7Ad0820P03De=@1ZJVX0K6a/09bL
W00V9RH0;Rh^05mOG`2>SXh0`l?308b<S00l?3`0;Rh^03De=@2VYZH0CDe=034a<@2TY:@0=cLg01HF
5P0I6AT0;2`/03lo?`0i>CT0E5AD03`l?00X:2P501DE5@0I02d];@1;Bd/0EUIF08V9R@2BTY80=cLg
02h^;P0W9bL0:RXZ01dM7@0H61P0;2`/05YJFP2FUYH0alO709ZJVP1lO7`0bl_;0;Rh^02_[jl0X:2P
05eMG@1WIfL0T92@096AT@0Aooooo`003oooool0:@1RHV80Ng]k051@D01SHf<0FEUI04I6AP1RHV80
XZ:R05IFEP0V9RH0IVIV06YZJP0U9BD0:2PX03Hf=P1DE5@0<c<c04e=C@0b<S80;Bd]05QHF00P8200
UiNG065QH@0e=CD0E5AD04];B`1FEUH0Z:RX07IfMP0T92@0FUYJ071`L01LG5`0ATI602`/;01<C4`0
LG5a03lo?`0j>SX0X:2P0080B4Q808d0D51@02DU9@0Z:RX0EUIF04A4A017AdL0EUIF05aLG00f=SH0
>3Ph04Q8B01gMgL0HV9R034a<@0R8R80ATI608J6QP10@400CTi>07UiN@18B4P0P82005EEE@12@T80
@41008j>SP1MGEd0Bd];05iNGP1;Bd/0UIFE07AdM00i>CT0EEEE055AD@0h>3P0OGem06e]K@1RHV80
MWIf0410@00Z:RX0[Jf]06QXJ00Y:BT0T92@07]kN`0g=cL0KFe]07inOP16ATH0Hf=S092@T00L71`0
BDU906a/K01oOgl0O7al06QXJ011@D409bLW08f=S@1TI6@0?3`l05]KF`0b<S80WinO06=SH`1=CDd0
92@T0410@026QXH0S8b<04a<C01JFUX0>3Ph07emO@1_Kfl0IfMW04U9B@0`<300Hf=S08b<S01SHf<0
KFe]05YJFP1TI6@0PX:207=cL`1`L700?Shn09:BTP1UIFD0F5QH07moO`11@D40De=C07MgM`11@D40
T92@08^;R`1@D500QhN709ZJVP16ATH0Q8B409bLW01;Bd/0Fe]K09^KV`1FEUH0J6QX0:b/[01aLG40
@T920820P01]KFd0MWIf038b<P1BDU80/;2`09bLW01jNWX0bl_;09ZJVP0j>SX0[:b/0;2`/01YJFT0
SHf=0=SHf021PH40@D5107emO@24Q8@0E5AD0<G5a@1/K6`0Bd];07IfMP2MWId00P1?Cdl0J023Ph<0
LG5a03Lg=`0f=SH0Shn?07]kN`0m?Cd0MGEe06IVIP0h>3P0WYjN08:2PP1/K6`0[:b/03De=@1ADE40
XJ6Q061PH01BDU80IFEU01dM7@15ADD0^KVi06][J`15ADD0WinO0861P@1bLW80BDU90;bl_039bLT0
SHf=03Hf=P1ZJVX0JFUY07QhN02QXJ40IfMW03dm?@2;Rh/0PH6103hn?P1oOgl0KVi^05UIF@0g=cL0
MgMg07IfMP0f=SH0De=C08V9R@0c<c<0;bl_06UYJ@1[Jf/0CDe=06i^KP1bLW80>3Ph071`L01BDU80
FUYJ0;Zj^P2i^KT0/;2`07emO@1SHf<0<C4a01TI6@1HF5P0NWYj05mOG`1NGUh0Cdm?020P801ADE40
RHV90:BTY01^KVh0=cLg055AD@0G5aL0Bd];06QXJ01YJFT0;bl_06MWI`1RHV80:2PX06i^KP0^;Rh0
RHV906ATI00Y:BT0U9BD09>CT`0l?3`0:2PX06YZJP1RHV80;bl_04a<C01:BTX0LG5a7?ooool05`3=
cLd0e=CD0<g=c@2TY:@0ATI602/[:`0m?Cd09BDU020P800e=CD0@41006EUI@1FEUH08b<S03De=@0m
?Cd07AdM04E5A@10@400?clo04Q8B00_;bl071`L00807QhN00l0ATI609NGU`19BDT0<C4a03<c<`2/
[:`0`/;208R8R00O7al06a/K01DE5@0A4A40;Rh^055AD@0B4Q800`0@4100301aLG407AdM01@D500E
5AD04a<C00d=3@061PH03@d=00`<300:2PX07AdM05]KF`80OWin00L0_kno0;Jf]P1UIFD0LW9b01dM
7@0?3`l03Ph>00<03@d=00L03`l?05MGE`1aLG40>3Ph02l_;`0R8R806a/K00805aLG02005ADE03De
=@2;Rh/0MgMg07moO`0K6a/0>3Ph09nOW`1ADE40FEUI04Y:BP0O7al04a<C01TI6@0G5aL092@T055A
D@1VIVH0DE5A01lO7`0o?cl0Cdm?06QXJ02MWId0QXJ6075aL@2a/K40[jn_04A4A00l?3`0NGUi01dM
7@<05ADE02@07AdM02LW9`0g=cL0;Bd]02<S8`0[:b/0b<S80<c<c03GemL0fm_K0<30`02LW9`0SXj>
09RHV02OWil0RXZ:07moO`37alL0^KVi03`l?00Y:BT0=CDe02d];@0d=3@0?3`l03<c<`0P820061PH
01LG5`0[:b/0J6QX08B4Q021PH40820P01/K6`0M7Ad201XJ6P1C01/K6`0U9BD0<S8b04e=C@18B4P0
<c<c06i^KP1nOWh0LG5a08^;R`2k^k/0[:b/055AD@15ADD0NGUi0;6a/@2LW9`0Cdm?01lO7`0E5AD0
5QHF05EEE@2d];@0aLG50<71`@2`/;00]kNg05YJFP0l?3`0D51@08^;R`0Y:BT0:RXZ0492@P1MGEd0
WIfM08j>SP2n_[h0_;bl08F5Q@0Y:BT0:2PX04A4A01OGel0G5aL05iNGP13@d<0:b/[02DU9@0c<c<0
?clo05UIF@2@T900NGUi059BDP1FEUH0PX:20:NWY`1mOGd0B4Q805aLG00[:b/06ATI034a<@0g=cL0
71`L02/[:`1;Bd/0De=C07=cL`2@T900b<S80:j^[P30`<00RHV908f=S@12@T809bLW07QhN01LG5`0
7QhN02DU9@0R8R800P0Q8B406P0o?cl0O7al09BDU01eMGD0<c<c03Ti>@1=CDd0K6a/09fMW@0g=cL0
AdM706i^KP1HF5P0GUiN07EeM@1PH600Ng]k03<c<`0E5AD07alO03Xj>P1HF5P06a/K038b<P1RHV80
9BDU1@0E5AD06@0/;2`0C4a<0451@@2CTi<0YZJV08N7Q`1<C4`0DU9B03hn?P12@T80LW9b08N7Q`25
QHD0[Jf]08n?S`34a<@0dm?C09:BTP2SXj<0W9bL07MgM`0^;Rh0<30`03dm?@1?Cdl04Oooool000oo
oooo0?l0JVYZ07alO01;Bd/0HF5Q05ADE00g=cL0CTi>08f=S@1NGUh09bLW07MgM`1QHF40<c<c04U9
B@1=CDd0ATI603De=@1QHF40H61P03Ti>@12@T803Ph>08Z:RP1OGel0?clo05aLG00J6QX0;bl_06=S
H`2?Shl0>CTi05IFEP0i>CT0CDe=05UIF@0`<300FUYJ07inOP0F5QH0<30`0861P@15ADD0>3Ph03/k
>`0V9RH0;Rh^05aLG00E5AD0>CTi06QXJ01/K6`0D51@03Ti>@0^;Rh0HV9R07QhN01WIfL0>SXj04M7
A`25QHD0;2`/061PH024Q8@0AdM707inOP12@T809RHV04=3@`2LW9`0F5QH04e=C@1MGEd0>SXj07Qh
N01nOWh0?3`l04m?C`1WIfL0:b/[04M7A`1;Bd/0JFUY06a/K019BDT0;Bd]0:j^[P1TI6@0:b/[096A
T@2HV9P0=cLg07moO`21PH40@41007emO@2[Zj/0CTi>03@d=01?Cdl0Kfm_05]KF`1]KFd0MgMg03Xj
>P1dM7@0DE5A05EEE@1gMgL0ADE5096AT@1IFET0Fe]K06UYJ@12@T80I6AT08>3P`1PH600O7al05eM
G@1_Kfl0FEUI08^;R`2=SHd0@d=304Q8B01VIVH0CTi>08f=S@1PH600De=C06IVIP24Q8@0TI6A0451
@@2BTY80EUIF03Ph>01nOWh0I6AT07YjNP1bLW80Bd];0:VYZ@1lO7`0<30`079bLP1lO7`0DE5A09ZJ
VP2MWId0<c<c04M7A`1kNg/0=3@d03lo?`1WIfL0MWIf03Ph>01UIFD0BDU907QhN01<C4`0AdM709nO
W`1TI6@0NWYj0=7Ad@2][Jd0FEUI09NGU`1/K6`0@41008F5Q@34a<@0VIVI05IFEP2:RXX0X:2P07Ee
M@3?cll0DU9B04Y:BP26QXH0YZJV08F5Q@0o?cl0Hf=S06][J`0m?Cd0=3@d08N7Q`1lO7`0?Cdm071`
L01VIVH0?Cdm08F5Q@1oOgl0H61P0;Bd]01/K6`0Cdm?061PH00n?Sh0DU9B05eMG@0e=CD0>c/k08V9
R@1ZJVX0B4Q80:f][@1bLW80HF5Q02LW9`2?Shl0Z:RX08b<S00k>c/0HF5Q03Hf=P12@T80Rh^;079b
LP0e=CD0Ng]k07QhN00V9RH0CTi>06MWI`1HF5P0=cLg06e]K@1nOWh0@d=302d];@1KFe/0ATI602TY
:@1dM7@0<30`02d];@1TI6@0P82004U9B@2CTi<0BTY:03/k>`1fMWH0VIVI08n?S`2`/;00b<S808Z:
RP0];Bd002<0Cdm?06=SH`1CDe<0H61P065QH@0l?3`0?Cdm04E5A@1`L700GUiN02h^;P1CDe<0DE5A
04e=C@1QHF40GUiN038b<P20P800F5QH02<S8`1IFET0:RXZ06UYJ@1BDU80820P07inOP2OWil09BDU
03/k>`2YZJT0TI6A03De=@1@D500Bd];079bLP0Looooo`050=GEe@3Jf]X0dM7A071`L00n?Sh00P0e
=CD09P0T92@0820P01hN7P0l?3`0?Shn05mOG`1lO7`0Lg=c065QH@14A4@0C4a<05=CD`11@D407QhN
01/K6`0U9BD08R8R0410@02@T900C4a<02DU9@0K6a/05QHF0492@P2k^k/0TY:B0451@@0B4Q804a<C
01PH6018B4P08B4Q014A4@0?3`l0410@018B4P1VIVH06QXJ0P0E5AD0400>3Ph02PX:00`<300=3@d0
1PH600`<300C4a<0GEeM07YjNP2][Jd0PX:207AdM02IVIT0W9bL05iNGP0K6a/200`<30803`l?00H0
@d=305ADE00R8R806ATI01DE5@0F5QH201DE5@0H01lO7`1=CDd0R8R809VIV@29RHT0NGUi05iNGP2@
T900/k>c092@T00W9bL06QXJ01<C4`0B4Q806a/K01LG5`0F5QH07AdM04Y:BP1oOgl08B4Q01LG5`0S
8b<0=cLg0P1YJFT02`1PH600c/k>09VIV@0Z:RX09bLW08F5Q@1=CDd0820P01DE5@0G5aL05ADE0080
6ATI01407alO03Ph>01/K6`0]KFe0=kNgP2^[Zh0cLg=0:ZZZP20P800Shn?08j>SP2HV9P0UIFE0;fm
_@3;bl/0R8R806=SH`0202/[:`1A034a<@0h>3P0>SXj04=3@`1=CDd0:b/[028R8P1CDe<0TI6A08:2
PP2CTi<09RHV01/K6`0L71`06QXJ01`L700J6QX05aLG01`L700M7Ad0?3`l0;Vi^@1fMWH0IFEU06m_
K`2f][H0`l?30:f][@2@T900P82005]KF`17AdL0Jf][0:2PX02_[jl0IFEU02XZ:P1?Cdl0RXZ:0=;B
dP2n_[h0ZZZZ0861P@1=CDd0>c/k061PH017AdL0Cdm?059BDP1>CTh0>c/k03dm?@2?Shl0clo?09fM
W@2d];@0K6a/06QXJ01ADE40<S8b01`L700S8b<0=SHf04E5A@1BDU80A4A405iNGP2CTi<0VYZJ06EU
I@1hN7P0SHf=0:>SX`2[Zj/0XJ6Q03lo?`0k>c/08b<S02DU9@16ATH0:BTY00805ADE02d05aLG06EU
I@2OWil0NWYj09^KV`2JVYX0T92@07EeM@0i>CT0E5AD034a<@1QHF40SXj>01lO7`0J6QX0:RXZ055A
D@1>CTh0AdM705EEE@2VYZH0LW9b04A4A01DE5@0@T9209FEU@1TI6@0820P01`L700S8b<0D51@06QX
J02QXJ40_[jn09:BTP20P800Bd];04a<C021PH40:RXZ01PH600N7Qh0PH6103`l?00G5aL0100E5AD0
6@10@400Cdm?03Xj>P2RXZ80`<300<[:bP32`/80VYZJ0:^[Z`2YZJT0_kno0<c<c03=cLd0Xj>S04=3
@`2HV9P0_;bl07]kN`2;Rh/0Vi^K05aLG00W9bL09RHV04E5A@1WIfL04Oooool000oooooo00D0LG5a
0:RXZ01@D500Hf=S05mOG`0204m?C`1A096AT@1TI6@0:RXZ06MWI`0d=3@09bLW04Q8B012@T809RHV
01DE5@1:BTX0G5aL03Lg=`1ZJVX0<30`09:BTP1PH600Bd];07YjNP1dM7@0FUYJ07IfMP1PH600=cLg
05EEE@1/K6`0G5aL038b<P0[:b/0Fe]K06YZJP0a<C40@D5108f=S@0j>SX0?clo04A4A00R8R80=SHf
05]KF`0S8b<0=cLg0410@01GEeL0AdM704A4A00Y:BT0Hf=S06e]K@1GEeL0>SXj05ADE02=SHd08B4Q
05eMG@1nOWh0ATI607moO`1<C4`09BDU02TY:@2=SHd0BTY:04e=C@1OGel0F5QH07MgM`1_Kfl0@D51
06][J`1cLg<0=CDe08R8R01YJFT0J6QX07MgM`1MGEd0;bl_0:ZZZP0b<S80?Shn0080NWYj02/0C4a<
07QhN01OGel0=SHf05EEE@25QHD0Cdm?03De=@1BDU80Jf][06UYJ@1NGUh0MWIf03Xj>P1aLG40>CTi
03De=@1^KVh0Bd];08R8R00];Bd0De=C05]KF`11@D40GEeM04m?C`0k>c/0N7Qh05aLG01kNg/0AdM7
05UIF@22PX80C4a<04A4A01PH600ADE505ADE01UIFD0J6QX07QhN01WIfL0RHV90080CTi>04<0Cdm?
03lo?`1]KFd0Bd];08N7Q`1[Jf/0<c<c07emO@1]KFd0>SXj08:2PP1gMgL0=cLg06ATI02ATI40>3Ph
05IFEP2:RXX0BDU904a<C01lO7`0Rh^;03De=@1@D500DE5A069RHP0m?Cd0C4a<09>CT`1`L700GemO
0:BTY02HV9P0JFUY0;Bd]02OWil0HF5Q08J6QP3EeMD0UYJF05iNGP2YZJT0][Jf0820P03@d=00K6a/
069RHP32`/80b<S80820P01:BTX0IFEU0820P00n?Sh0>CTi08^;R`1lO7`0Bd];0:VYZ@1gMgL0ADE5
0:NWY`2?Shl0L71`0;2`/021PH40B4Q80080EEEE05H0NGUi09BDU016ATH0ADE50:BTY01dM7@0C4a<
0:BTY01PH600GEeM03<c<`28R8P0NGUi0861P@0e=CD0IVIV04e=C@1ZJVX0MgMg05iNGP0j>SX0Ph>3
09>CT`15ADD0CDe=05]KF`1DE5@0JFUY0:BTY024Q8@0AdM703hn?P1QHF40=CDe02<S8`1cLg<0EeMG
04M7A`1DE5@0J6QX04M7A`2n_[h0QHF505eMG@2ATI40UYJF03dm?@1aLG40TY:B07UiN@0X:2P0C4a<
05EEE@1WIfL0Vi^K09:BTP1DE5@0EEEE04E5A@1PH600=SHf02l_;`1dM7@0B4Q804I6AP1OGel0?clo
04];B`2FUYH0N7Qh02HV9P1ZJVX08B4Q05aLG019BDT09bLW06IVIP2=SHd0De=C020P800o?cl0KFe]
03/k>`1MGEd0Cdm?05mOGacooooo02P0/;2`0;jn_P37alL0KVi^038b<P0Y:BT09RHV01dM7@0Q8B40
7alO02@T901CDe<0BDU90451@@2b/[80c<c<079bLP1aLG40?3`l02HV9P0K6a/07alO04Q8B01JFUX0
E5AD08F5Q@0[:b/07AdM01LG5`0F5QH0@D510<G5a@2BTY80IfMW03Lg=`0E5AD0:BTY03dm?@0I6AT0
4a<C0P0>3Ph01P0C4a<0GUiN01LG5`0D51@03Ph>00l?3`8030`<0`0=3@d04`0>3Ph0FEUI0=SHf02o
_kl0YZJV0::RXP1gMgL0R8R808:2PP18B4P04A4A00`<300F5QH0Lg=c06IVIP0M7Ad05aLG01DE5@0A
4A400P0C4a<03@0E5AD0;Bd]051@D01aLG40T92@07moO`1UIFD0V9RH0:NWY`2<S8`07AdM01@D500B
4Q800P0C4a<0;`0E5AD05aLG01HF5P0G5aL08B4Q09nOW`2QXJ40MGEe05eMG@1NGUh0Jf][092@T02n
_[h0gmoO0;>c/`0c<c<09BDU05ADE01^KVh0=3@d030`<00Q8B405ADE01HF5P0H61P071`L05eMG@2G
UiL0YJFU0:ZZZP2DU9@0TI6A08F5Q@24Q8@0L71`07alO01fMWH0GemO08Z:RP2TY:@0H61P07emO@18
B4P0BTY:03Xj>P0c<c<0<S8b0080>c/k05H0EUIF04A4A01LG5`0`<300:RXZ02TY:@0BDU901`L700H
61P06ATI01LG5`0I6AT071`L01TI6@0K6a/0Bd];08j>SP2@T900[Jf]07IfMP1hN7P0_Kfm075aL@0k
>c/0<c<c05MGE`1lO7`0Lg=c04I6AP1=CDd0TI6A0;Vi^@2:RXX0bl_;0;Vi^@2RXZ80`<300:f][@15
ADD0CDe=06a/K00f=SH0:b/[01dM7@0G5aL05QHF01dM7@1PH600dm?C09fMW@2c/k<0Shn?02PX:00Q
8B40=3@d038b<P0e=CD0;bl_01dM7@0I6AT07AdM020P801lO7`0/k>c079bLP1>CTh0IFEU09fMW@1F
EUH0QHF503/k>`0d=3@0=CDe03@d=00H61P05aLG01HF5P0H61P05aLG05QHF01WIfL0<30`04I6AP1M
GEd0Bd];069RHP80=CDe0400De=C055AD@2=SHd0KFe]02l_;`0b<S80ADE504M7A`1EEED0ATI609>C
T`2l_;`0QHF504I6AP1GEeL0TY:B05aLG00V9RH07QhN01`L700N7Qh0<C4a09FEU@3Lg=`0_;bl0=WI
f@2h^;P0eMGE09VIV@0J6QX05QHF01TI6@1iNGT0AdM702DU9@0E5AD05QHF01DE5@0S8b<0LW9b08j>
SP2ZZZX0];Bd0=CDe036a/H0^[Zj09jNWP1aLG40I6AT06YZJP1CDe<0Ogmo08N7Q`2@T900_;bl09FE
U@2^[Zh0][Jf0<W9b@18B4P0:2PX03hn?P1QHF40I6AT4Oooool000oooooo01L0LW9b0:NWY`1ADE40
IfMW06UYJ@1>CTh0DU9B08N7Q`1CDe<0?3`l0820P01UIFD07alO02`/;017AdL0?Shn02`/;01QHF40
Fe]K030`<01hN7P0>3Ph0:>SX`0206EUI@1Y08b<S01aLG40FUYJ08R8R01GEeL0@D5108N7Q`25QHD0
GemO034a<@0b<S80RHV908:2PP14A4@0@d=309>CT`0b<S80BDU903Ti>@0R8R80De=C07YjNP0i>CT0
@D5104I6AP10@400?Shn069RHP1?Cdl0GemO04a<C00_;bl0>CTi071`L02IVIT0>c/k04Y:BP1XJ6P0
?Shn0::RXP1cLg<0=CDe02d];@25QHD0;Bd]04];B`1nOWh0DE5A06e]K@14A4@09BDU04A4A01_Kfl0
>3Ph08F5Q@0a<C40;bl_06a/K01JFUX0=3@d0:f][@1UIFD08b<S08b<S02ATI40>CTi07moO`28R8P0
BDU906YZJP2HV9P0I6AT03dm?@1BDU80Hf=S07UiN@1YJFT0Kfm_03dm?@21PH40HF5Q04e=C@1cLg<0
AdM708f=S@1KFe/0EeMG05mOG`0m?Cd0G5aL07moO`12@T80O7al05]KF`1hN7P0EeMG07MgM`2?Shl0
BDU904=3@`1VIVH0GEeM06UYJ@1FEUH0Hf=S0080N7Qh09h0Rh^;04I6AP1ADE40A4A404I6AP1NGUh0
ATI6092@T01/K6`0@d=309VIV@1^KVh0>3Ph08B4Q029RHT0DE5A06MWI`2EUID0=cLg06IVIP2IVIT0
AdM705ADE01/K6`0OWin05UIF@1gMgL0JVYZ075aL@1OGel0Jf][0:n_[`2>SXh0UYJF0<W9b@2KVi/0
MGEe0;fm_@2_[jl0IFEU08Z:RP3>c/h0DU9B06IVIP2XZ:P0YZJV06MWI`30`<00DU9B03`l?01^KVh0
T92@06UYJ@1<C4`0LG5a06YZJP1_Kfl0BDU908J6QP1FEUH0<c<c05mOG`1VIVH0AdM70:BTY01PH600
JVYZ0:>SX`1bLW80<S8b05eMG@0i>CT0@T9206ATI01GEeL0ADE509nOW`1_Kfl0FEUI0;fm_@37alL0
SXj>051@D02h^;P0/K6a09NGU`1;Bd/0^;Rh07inOP1mOGd0Lg=c051@D011@D40V9RH09NGU`19BDT0
A4A404];B`0U9BD0:b/[06][J`1iNGT0CTi>04=3@`1HF5P09BDU01lO7`1gMgL0Fe]K05ADE01EEED0
BTY:02<S8`1[Jf/0E5AD05UIF@2>SXh0QHF505aLG022PX80Ph>307QhN00W9bL0BTY:04E5A@0[:b/0
EEEE08R8R01FEUH0DU9B04I6AP1=CDd0<C4a03lo?`29RHT0AdM703lo?`1MGEd0<c<c034a<@1cLg<0
G5aL02PX:01XJ6P0:2PX06a/K01aLG40<C4a06UYJ@2GUiL0?Cdm02<S8`1?Cdl0I6AT03Ph>01OGel0
Cdm?06][Jacooooo02P0@D510:ZZZP33`l<0UIFE03dm?@0X:2P07alO01`L700M7Ad071`L01dM7@0V
9RH0BTY:03dm?@2RXZ80a<C407YjNP2ATI40AdM7055AD@1@D500BDU903Lg=`18B4P0IFEU08R8R00b
<S80=cLg055AD@1SHf<0QHF50:BTY03<c<`0E5AD06QXJ021PH40Rh^;020P800O7al06a/K0P0?3`l0
;@0I6AT0FUYJ01LG5`0@41004a<C00l?3`0C4a<03Ph>00X:2P092@T03@d=01DE5@2PX:00VYZJ08V9
R@1]KFd0T92@0;Vi^@26QXH0XZ:R03Xj>P0m?Cd0Cdm?07IfMP2o_kl0=3@d018B4P0A4A403Ph>014A
4@0B4Q807QhN034a<@17AdL0D51@03@d=00K6a/0D51@04E5A@25QHD0Q8B406e]K@0_;bl04A4A00d=
3@0200h>3P1j01DE5@0H61P05QHF01PH601CDe<0[Zj^07MgM`1JFUX0J6QX08b<S029RHT0UIFE0;6a
/@3Cdm<0/K6a03De=@0T92@0>c/k03Hf=P0D51@05aLG02XZ:P0^;Rh07QhN01LG5`0L71`0JFUY09BD
U02TY:@0^[Zj09>CT`1oOgl0DE5A04A4A01TI6@0G5aL03dm?@0g=cL0>CTi08J6QP1KFe/0F5QH02DU
9@0^;Rh0BDU90492@P0m?Cd0>CTi03Ph>00l?3`0MWIf0:6QX@3AdM40`<300:BTY02d];@0ATI601TI
6@0L71`05aLG01PH600I6AT06QXJ02DU9@1aLG40JFUY05mOG`1nOWh0GemO04m?C`2k^k/0TY:B04I6
AP0i>CT0;bl_03Lg=`1>CTh0Hf=S06MWI`1HF5P0[Jf]0>3Ph03WinL0PX:20:j^[P2][Jd0DE5A04m?
C`24Q8@092@T01PH600I6AT06QXJ01HF5P0G5aL0:b/[0451@@2PX:00Ti>C08^;R`2>SXh0AdM704=3
@`0f=SH08b<S01dM7@0I6AT06QXJ01LG5`0J6QX0;2`/04a<C02a/K40NGUi07YjNP12@T80K6a/04e=
C@0n?Sh0@D5103Xj>P0/;2`201HF5P<05ADE04X0820P04I6AP1@D500>CTi03Lg=`1BDU80?Shn08>3
P`1YJFT0GEeM04];B`1gMgL0^k^k0<o?c`2EUID0QhN709BDU02HV9P0YjNW0;bl_02NWYh0Ogmo09ZJ
VP1BDU80U9BD07emO@1;Bd/08R8R01hN7P0L71`08R8R06=SH`2a/K40V9RH0:f][@36a/H0UiNG0<W9
b@2EUID0PX:202XZ:P0I6AT0Cdm?08N7Q`1NGUh0=cLg03dm?@1RHV80RXZ:0:6QX@2RXZ80SXj>09ZJ
VP39bLT0c/k>0:^[Z`2/[:`0Cdm?02h^;P16ATH0KVi^08V9R@2;Rh/0WinO0;Rh^03>c/h0d=3@0=[J
fP39bLT0J6QX0451@@1ZJVX0MGEe05MGEa7ooooo000?ooooo`1U06ATI029RHT0CTi>04I6AP1KFe/0
BDU9059BDP1kNg/0@D5102DU9@1RHV80EUIF01lO7`0/;2`0?Cdm05aLG00d=3@0H61P03Xj>P0e=CD0
Kfm_030`<02IVIT0=cLg0410@01OGel0FUYJ04i>CP2:RXX0Cdm?02PX:01PH600JVYZ06MWI`0Q8B40
8R8R051@D01_Kfl0A4A404I6AP2NWYh0<30`04=3@`0k>c/07QhN03@d=01JFUX0=cLg04E5A@1<C4`0
GUiN04U9B@12@T80BTY:05mOG`1:BTX0=cLg02PX:01<C4`0J6QX03<c<`1?Cdl0E5AD030`<01dM7@0
EUIF03@d=00];Bd0TY:B03dm?@16ATH0FUYJ04Q8B01gMgL0Ng]k03hn?P1;Bd/0GEeM03Hf=P1nOWh0
Cdm?05EEE@20P800Bd];03<c<`2i^KT0N7Qh02DU9@27QhL0Ogmo01/K6`27QhL0P82003lo?`1[Jf/0
UiNG051@D01[Jf/0X:2P09RHV01gMgL00P1LG5`04`1=CDd0SXj>05mOG`1BDU80Kfm_05=CD`2[Zj/0
Jf][05IFEP1BDU80L71`0:>SX`23Ph<0ADE506][J`19BDT0TY:B06EUI@23Ph<00P1IFET0R@2=SHd0
T92@06=SH`1VIVH0FEUI08>3P`2;Rh/0OGem07=cL`1<C4`0WIfM06][J`1=CDd0HV9R03@d=01jNWX0
Q8B404Q8B02KVi/0MGEe04=3@`2:RXX0OWin05UIF@1LG5`0UIFE05aLG02LW9`0WinO04];B`1LG5`0
IfMW05]KF`0d=3@0LW9b06YZJP1QHF40AdM707inOP2j^[X0Shn?0:2PX030`<00Rh^;03hn?P2IVIT0
S8b<04I6AP2GUiL0b<S807AdM01ADE40_[jn0:b/[01^KVh0a/K605MGE`1EEED0O7al0;Jf]P21PH40
C4a<06YZJP1VIVH0EEEE03`l?020P800Q8B40451@@1jNWX0SXj>055AD@2YZJT0MWIf05mOG`2OWil0
K6a/01`L700];Bd0?3`l04m?C`1RHV80@d=304M7A`26QXH0HV9R0451@@23Ph<0H61P0861P@1<C4`0
bLW90:f][@2DU9@0:b/[06ATI01fMWH0LW9b06YZJP1HF5P0:2PX06e]K@2IVIT0E5AD04A4A01SHf<0
E5AD0410@01ZJVX0OWin04U9B@15ADD0EUIF01lO7`15ADD0WinO07EeM@1CDe<0FEUI05]KF`12@T80
OWin04U9B@1SHf<0O7al07UiN@1OGel0XZ:R0:6QX@1mOGd0:b/[05eMG@1RHV80GUiN05IFEP1hN7P0
I6AT0080C4a<01/0GemO04m?C`0d=3@0KFe]05UIF@0m?Cd0M7Ad04m?C`0n?Sh0MWIf03<c<`0Q8B40
Fe]K02LW9`1TI6@0Jf][02/[:`1<C4`0SHf=04U9B@0b<S80EeMG06m_K`0c<c<0NWYj06QXJ01mOGd0
7?ooool01`0e=CD0R8R80=?Cd`36a/H0RXZ:03Ph>00R8R800P0K6a/2020P800M01dM7@0[:b/0JFUY
0:NWY`2KVi/0aLG50:6QX@1MGEd0B4Q804I6AP12@T80:2PX02/[:`2KVi/0TI6A07MgM`1UIFD0@d=3
02h^;P0V9RH0;2`/06][J`25QHD0?Cdm04a<C02GUiL07QhN010@400C4a<00P0=3@d01P0M7Ad0BDU9
010@400?3`l03@d=00l?3`<03@d=01L020P800d=3@1@D500IfMW01lO7`0];Bd0GUiN06EUI@29RHT0
/[:b0;Vi^@1/K6`0UIFE0;Fe]@2j^[X0ZZZZ09FEU@16ATH0:RXZ02TY:@0f=SH0@D5103lo?`0202l_
;`0;01DE5@0C4a<04A4A024Q8@1YJFT0FUYJ08F5Q@1SHf<0DU9B01lO7`0@41000P0>3Ph04`0A4A40
5aLG01`L701aLG40W9bL06i^KP0e=CD0<30`02h^;P0f=SH0EEEE06ATI01RHV80_kno08j>SP1^KVh0
7QhN03@d=00b<S800P0@4100;P0A4A4092@T069RHP1?Cdl0MWIf07YjNP14A4@0N7Qh08J6QP1hN7P0
Ogmo01lO7`0H61P09BDU03/k>`1NGUh0@4100451@@1/K6`0G5aL06=SH`1BDU80>c/k02l_;`0n?Sh0
BTY:03lo?`18B4P0BDU909JFUP2c/k<0IfMW09BDU02HV9P0XZ:R06a/K01IFET09bLW01XJ6P0K6a/0
61PH01dM7@1PH600MgMg08b<S01CDe<205QHF00F08n?S`0f=SH0IfMW04m?C`0Q8B4071`L03<c<`1L
G5`0Cdm?06m_K`34a<@0`l?30>3Ph03QhN40Ti>C0=KFeP2/[:`0<S8b03Ph>01QHF40<30`01TI6@80
5aLG01h05QHF01`L700j>SX09bLW07alO01fMWH0SHf=09:BTP0c<c<09RHV01TI6@0J6QX071`L01XJ
6P0K6a/06ATI02DU9@1@D500IFEU03@d=01]KFd0Ng]k06QXJ01IFET0GEeM03Hf=P0d=3@0?Cdm024Q
8@0L71`401DE5@0L028R8P1>CTh0A4A404=3@`1=CDd0N7Qh06QXJ01KFe/0:2PX03`l?01eMGD0^KVi
0;jn_P3<c<`0GEeM07EeM@2@T900LG5a07]kN`1`L700/K6a0:>SX`2_[jl0_;bl0<W9b@1nOWh0=CDe
028R8P808b<S01T0De=C0:VYZ@1WIfL0@d=308J6QP2][Jd0K6a/06ATI01BDU80C4a<06IVIP1CDe<0
EEEE0<k>cP31`L40WIfM07inOP1RHV80L71`08>3P`1WIfL0JVYZ05IFEP35aLD0][Jf0080WYjN0140
MWIf06e]K@1bLW80?clo03Hf=P0d=3@0;2`/05YJFP2EUID0ZJVY0<S8b033`l<0][Jf09ZJVP2NWYh0
B4Q801lO7`0Aooooo`003oooool0B@1jNWX0W9bL04Y:BP1^KVh0Fe]K04a<C01ADE40Xj>S07UiN@0l
?3`0P82007EeM@0Q8B40=3@d03lo?`1:BTX0;2`/069RHP0n?Sh0:BTY06i^KP0g=cL0P82006IVIP1@
D500MGEe06m_K`18B4P0XJ6Q06ATI00d=3@0Ogmo08F5Q@1^KVh0?3`l030`<01FEUH0KFe]02@T900o
?cl0UIFE05EEE@1UIFD0B4Q802XZ:P0o?cl0IVIV03`l?01FEUH0QHF506i^KP1=CDd0@T9204a<C02Q
XJ40MWIf03dm?@0Z:RX0I6AT06MWI`0^;Rh0CTi>079bLP10@400QhN704];B`0^;Rh0<c<c0:FUY@1D
E5@0Hf=S05=CD`0n?Sh00P1fMWH07P0o?cl0ADE505UIF@1lO7`0S8b<03Xj>P1ADE40RHV904A4A010
@400_Kfm08:2PP0W9bL0R8R807alO00Q8B40MWIf07moO`0l?3`0Lg=c08R8R017AdL0;Rh^04I6AP1U
IFD0LW9b05=CD`1NGUh0=SHf07AdM080B4Q80;L0E5AD03hn?P1iNGT0DE5A04a<C00_;bl0=cLg069R
HP1]KFd0@D5106a/K019BDT0Ng]k05QHF01^KVh0OGem0410@01:BTX0L71`051@D01NGUh0ATI605iN
GP1nOWh0JFUY075aL@1;Bd/0SHf=06m_K`1<C4`0IfMW05mOG`21PH40MGEe04];B`2EUID0IfMW05UI
F@2RXZ80UiNG04i>CP1JFUX0Ph>303/k>`1LG5`0XZ:R04a<C01MGEd0J6QX07emO@0i>CT0J6QX05mO
G`1QHF40C4a<05YJFP28R8P0SHf=0:RXZ034a<@0M7Ad06UYJ@31`L40UIFE06MWI`2OWil0alO708>3
P`1MGEd0^;Rh0:^[Z`1dM7@0dm?C08Z:RP1aLG40WIfM0;no_`1dM7@0C4a<06QXJ01[Jf/0@41003<c
<`1oOgl0P82004A4A01eMGD0L71`04E5A@2ZZZX0NWYj07moO`2MWId0K6a/01hN7P0T92@0=cLg05MG
E`1UIFD0C4a<04M7A`2:RXX0LG5a05ADE02MWId0N7Qh06QXJ00i>CT0][Jf092@T02?Shl0>CTi06m_
K`24Q8@0MWIf07moO`1VIVH0:BTY06][J`2XZ:P0E5AD05eMG@28R8P0EeMG04=3@`1YJFT0OGem04];
B`1FEUH0MWIf04A4A00Q8B40QHF505eMG@1?Cdl0EEEE079bLP1<C4`0OGem05]KF`1QHF40ZZZZ08R8
R01cLg<0a/K60<S8b01VIVH07AdM055AD@1[Jf/0IfMW075aL@1jNWX0A4A4051@D01MGEd0MWIf07Ui
N@0n?Sh0Kfm_03hn?P10@400Rh^;065QH@14A4@0Ti>C06YZJP0];Bd0I6AT01dM7@1<C4`0HV9R03De
=@0l?3`0VYZJ03dm?@0b<S80NWYj08j>SP0Q8B40D51@05MGE`1fMWH07?ooool0<@0g=cL0R8R80=SH
f03De=@0][Jf0::RXP2:RXX0KFe]055AD@0h>3P0;Rh^038b<P1GEeL0/K6a0:b/[02l_;`0a<C409nO
W`1lO7`0Ng]k08V9R@1aLG40@D5105QHF01RHV80<c<c03hn?P0k>c/0;bl_02TY:@0];Bd08R8R01XJ
6P1^KVh0?Shn01LG5`1HF5P0HF5Q01DE5@0B4Q804A4A00d=3@0G5aL0?clo00d=3@0:2PX020P800l?
3`0410@00P0<30`05P0@4100820P05eMG@0K6a/0820P02HV9P0G5aL0ADE505UIF@2c/k<0alO70<S8
b02m_Kd0T92@05ADE00V9RH0C4a<09RHV01mOGd0>3Ph02DU9@0H61P201DE5@1k01dM7@0E5AD051@D
018B4P0H61P0?Cdm08R8R02RXZ80GEeM03Ph>014A4@061PH00h>3P0@41003`l?01dM7@1[Jf/0KVi^
05]KF`0W9bL06QXJ01/K6`0G5aL06ATI01lO7`1HF5P0:RXZ09fMW@2d];@0Lg=c04Q8B00_;bl0=cLg
00h>3P0G5aL07QhN02DU9@1/K6`0b<S80=7Ad@24Q8@0Y:BT09>CT`26QXH0EeMG05IFEP0F5QH05ADE
03hn?P0T92@0A4A405EEE@14A4@0IVIV07AdM01XJ6P0GemO02XZ:P0];Bd0=cLg04Y:BP1CDe<0<C4a
07inOP2e]KD0MgMg02LW9`2ATI40_;bl09>CT`0e=CD0D51@075aL@18B4P07QhN01TI6@0j>SX0VIVI
07alO01kNg/0D51@06QXJ02<S8`0>3Ph01HF5P0I6AT0IfMW05UIF@0Y:BT0<S8b030`<014A4@0X:2P
0=;BdP2l_;`0b<S80=kNgP2i^KT0fMWI0<K6aP0n?Sh0@D5101hN7P0W9bL0DE5A034a<@0];Bd0>3Ph
05iNGP1MGEd06QXJ04a<C01RHV80WinO092@T00j>SX061PH01TI6@0L71`07AdM01`L700O7al0<C4a
0080CDe=00/09BDU02PX:00m?Cd0Rh^;096AT@1gMgL0[Jf]03dm?@0a<C40?Cdm02d];@0202`/;010
01TI6@0V9RH0<c<c04A4A02:RXX0BDU904Q8B01kNg/0Ph>307inOP1UIFD0=SHf034a<@0g=cL0X:2P
0<o?c`3=cLd0_kno09BDU01nOWh0F5QH05EEE@1[Jf/0`L710:ZZZP2i^KT0S8b<0;6a/@2UYJD0G5aL
02`/;010@400DU9B061PH01SHf<08b<S04a<C01kNg/0Hf=S09fMW@1kNg/0EeMG04Y:BP12@T80@410
07YjNP3Hf=P0]KFe0410@00f=SH0BTY:06UYJ@32`/80YjNW06][J`1YJFT0^KVi04Y:BP0h>3P0Bd];
05IFEP21PH407alO01TI6@808B4Q00T09bLW03Xj>P1oOgl0R8R80;2`/02o_kl0UYJF0;Fe]@17AdL0
0P0O7alAooooo`003oooool03P1lO7`0PH61051@D01`L700E5AD04i>CP1dM7@0[:b/071`L00l?3`0
OWin05MGE`0_;bl0EeMG0P19BDT04@12@T80LG5a05UIF@0f=SH0HF5Q03<c<`1fMWH0IVIV05IFEP1_
Kfl0>3Ph05MGE`2GUiL0Ogmo03@d=01bLW80B4Q80080E5AD08T0<c<c05UIF@1lO7`071`L03Hf=P1n
OWh0DE5A05=CD`0n?Sh08R8R03Hf=P1MGEd06QXJ03@d=01IFET0D51@0410@015ADD0<c<c05EEE@1@
D500@d=302LW9`1PH600IfMW02XZ:P1oOgl0QXJ603lo?`21PH40@T9202h^;P1GEeL0S8b<055AD@1J
FUX0Bd];04Y:BP1RHV80OWin03dm?@15ADD0AdM702l_;`1[Jf/0AdM7051@D02;Rh/09bLW03<c<`2Q
XJ40LG5a02DU9@24Q8@0P820034a<@23Ph<0OGem03Ph>01oOgl0YZJV06IVIP1>CTh0HF5Q07alO027
QhL0F5QH06IVIP15ADD0Ti>C05QHF016ATH0M7Ad05aLG02FUYH0GemO04i>CP1CDe<0A4A407inOP1f
MWH0>c/k06m_K`1GEeL0SHf=05IFEP1/K6`0RXZ:04i>CP1FEUH0QhN705EEE@1FEUH0N7Qh06i^KP20
P800HV9R0861P@1CDe<0MWIf04i>CP17AdL0J6QX06EUI@2SXj<0L71`0492@P2MWId0P82004A4A020
P800QhN703lo?`1ADE40T92@04U9B@1dM7@0Xj>S04=3@`1FEUH0MGEe07emO@0o?cl0GemO05YJFP1L
G5`0@D5106=SH`22PX80TI6A0:JVYP2d];@0R8R807inOP35aLD0WinO06m_K`020<K6aP1d08:2PP1Y
JFT0_;bl096AT@1MGEd0aLG505eMG@1[Jf/0VIVI0:>SX`1<C4`0CDe=06i^KP1GEeL0@D5103@d=02;
Rh/0NGUi04Y:BP1`L700DE5A030`<02DU9@0GUiN08V9R@2][Jd0AdM702/[:`0m?Cd0>c/k06MWI`1[
Jf/0:BTY0492@P2EUID0QXJ6055AD@2OWil0Jf][07UiN@0k>c/0[Jf]0;Vi^@2OWil0>3Ph06e]K@1g
MgL0JVYZ09nOW`1jNWX0AdM708V9R@2UYJD0?3`l05QHF01XJ6P0?clo05MGE`2?Shl0O7al04m?C`0j
>SX0GemO0451@@0_;bl0Vi^K0492@P0m?Cd0FEUI061PH015ADD0TI6A06a/K00h>3P0J6QX07QhN01?
Cdl0^;Rh0:6QX@1hN7P0:BTY04M7A`1FEUH0P8200:n_[`2JVYX0>SXj03/k>`1SHf<0R8R806ATI01D
E5@0QXJ604M7A`0d=3@0NWYj03lo?`0g=cL0OWin08R8R00f=SH0Jf][01`L701:BTX0Kfm_051@D00g
=cL0VYZJ04m?C`0X:2P0DE5A07MgM`0j>SX0H61P04M7A`1VIVHLooooo`0L04e=C@2XZ:P0e]KF0:FU
Y@18B4P0Fe]K08N7Q`2h^;P0c<c<0<_;b`2o_kl0[jn_0<;2`P3Cdm<0emOG0=SHf02d];@0EEEE04A4
A00i>CT0<c<c02/[:`0c<c<0EUIF03hn?P0G5aL04a<C014A4@<03Ph>02@03@d=00h>3P0^;Rh0KVi^
04=3@`0];Bd0GemO04=3@`0B4Q805aLG00d=3@0D51@0A4A400`<300;2`/02@T900`<300C4a<03Ph>
00d=3@0E5AD0G5aL034a<@0H61P09BDU01LG5`0D51@05ADE01TI6@2VYZH0cLg=0<O7a`2e]KD0SXj>
069RHP17AdL202/[:`04075aL@2ATI40@d=301HF5P@05ADE05405aLG01XJ6P0I6AT0DE5A09ZJVP1o
Ogl0KFe]03/k>`0h>3P0?clo00l?3`0=3@d04a<C08J6QP1cLg<0FUYJ01`L700J6QX06ATI01XJ6P0F
5QH06ATI01/K6`16ATH09bLW06MWI`3<c<`0KFe]08Z:RP1SHf<0IfMW0410@00e=CD0<30`03De=@1U
IFD0IVIV09fMW@2WYjL0_kno08J6QP2;Rh/0Q8B405ADE00I6AT05aLG04E5A@0];Bd08B4Q04i>CP1=
CDd0Cdm?08b<S01NGUh0EUIF02h^;P0F5QH05aLG01TI6@0g=cL0Ng]k05ADE024Q8@0R8R807YjNP2B
TY80cLg=09JFUP1JFUX08b<S03Lg=`1VIVH0LG5a02XZ:P26QXH0Q8B409JFUP1UIFD0QXJ60:2PX00d
=3@00`0E5AD08`0X:2P0BDU905EEE@0d=3@0;Bd]02<S8`1/K6`0KFe]08f=S@3De=@0jNWY0=GEe@1Y
JFT0IfMW030`<00g=cL06a/K02LW9`1hN7P0De=C03Hf=P0d=3@0=CDe05ADE00O7al0<C4a07IfMP2;
Rh/0Ph>303Hf=P0H61P071`L01lO7`0X:2P0=3@d0080?Shn01P0ATI603Lg=`0c<c<09BDU02d];@1T
I6@0T92@09jNWP2ZZZX0NGUi07inOP2VYZH0]kNg0:BTY01XJ6P0DE5A05ADE01EEED0OWin0;Jf]P1l
O7`0IFEU04=3@`1/K6`2079bLP0c04a<C00e=CD0CDe=09fMW@2ZZZX0GUiN0;Bd]02f][H0a<C40;Zj
^P2QXJ40/K6a0<G5a@2c/k<0_[jn0;no_`2RXZ80QXJ60::RXP2;Rh/0NWYj05aLG01fMWH09RHV0410
@01IFET0<c<c04=3@`1DE5@0NWYj09^KV`1RHV80G5aL06EUI@2c/k<0_kno06YZJP1HF5P0JFUY08^;
R`29RHT0SHf=0;jn_P26QXH0^KVi0:>SX`0`<300;bl_04m?C`0m?Cd0;Bd]008061PH00d05ADE01TI
6@0P8200;bl_06EUI@2<S8`0Lg=c0;2`/02PX:00TY:B028R8P0L71`07alO017ooooo000?ooooo`17
07emO@1IFET0B4Q805eMG@1ADE40<S8b04I6AP1cLg<0AdM703De=@1WIfL0<S8b01PH600/;2`0?3`l
03Hf=P0R8R80D51@04i>CP0U9BD0F5QH034a<@1_Kfl0HV9R04e=C@1>CTh0DU9B04a<C02GUiL0LW9b
02l_;`1^KVh0NGUi05UIF@0h>3P0;Rh^06EUI@1jNWX0ADE505mOG`1lO7`0A4A404Y:BP18B4P06a/K
038b<P1GEeL0=3@d05ADE01YJFT0H61P03/k>`18B4P0De=C09:BTP1eMGD0@T9202LW9`1YJFT0IVIV
02d];@14A4@0Jf][0492@P2;Rh/0C4a<02TY:@0j>SX0S8b<03dm?@1ADE400P1FEUH07022PX80KVi^
03De=@1GEeL0GEeM06ATI01lO7`0;Bd]04U9B@2CTi<0@41003Ph>02PX:00EEEE02DU9@24Q8@0Rh^;
03Ti>@23Ph<0OWin03`l?01nOWh0U9BD055AD@1?Cdl0FUYJ07UiN@1bLW8205mOG`2k04];B`2@T900
De=C04a<C01[Jf/0IfMW09fMW@1IFET0D51@04A4A01>CTh0S8b<05]KF`14A4@0M7Ad05EEE@2EUID0
DE5A07AdM01^KVh0Cdm?06=SH`1bLW80BTY:05QHF01LG5`0Jf][07AdM01hN7P0NWYj04a<C026QXH0
DU9B04E5A@1QHF40Cdm?08R8R01gMgL0A4A40:BTY01iNGT0DE5A09JFUP1oOgl0@T9205iNGP2ATI40
EEEE08f=S@2ATI40?clo061PH01lO7`0Hf=S05=CD`2:RXX0GUiN06=SH`19BDT0Ng]k09fMW@1iNGT0
T92@0:j^[P1SHf<0HF5Q0<71`@1hN7P0CDe=0;fm_@2LW9`0FEUI06=SH`2TY:@0MWIf06ATI03=cLd0
GEeM08n?S`2PX:00ZZZZ069RHP1ADE40Hf=S05iNGP1@D500@T9208j>SP1SHf<0BDU907alO01OGel0
@d=309NGU`17AdL0MgMg08f=S@17AdL0?clo02h^;P0Q8B40IFEU06UYJ@0k>c/0<c<c079bLP1YJFT0
ADE509jNWP20P800Jf][04A4A02_[jl0SXj>08N7Q`0g=cL0O7al05eMG@1OGel0RHV906MWI`0h>3P0
NGUi09BDU011@D40Cdm?05QHF010@400?clo05iNGP1bLW80GUiN04U9B@1PH600;Rh^05=CD`2PX:00
JFUY04M7A`1GEeL0JVYZ04Y:BP1XJ6P0IfMW05IFEP2<S8`0RHV906YZJP2o_kl0Vi^K07UiN@0Z:RX0
DU9B07]kN`1IFET0De=C07]kN`13@d<0BDU907QhN02>SXh0CDe=03`l?01IFET0DU9B03@d=02?Shl0
B4Q803Ti>@1aLG40L71`03@d=01iNGT08R8R055AD@1_Kfl0ATI603Lg=`2CTi<0DU9B038b<P1QHF40
J6QX03Hf=P1nOWh0De=C08J6QP0Looooo`0I07IfMP1=CDd0D51@0;Bd]01JFUX0:b/[02DU9@0X:2P0
>3Ph05MGE`1_Kfl0PH610;Fe]@3Hf=P0eMGE0;no_`1HF5P092@T02`/;00i>CT0CDe=05ADE01CDe<0
>CTi00l?3`0200h>3P803@d=0`0>3Ph09@0=3@d03Ph>03Hf=P1RHV80E5AD03De=@1?Cdl0EEEE01lO
7`0=3@d05aLG04m?C`0>3Ph02`/;00`<300>3Ph03`l?014A4@0j>SX0Cdm?02h^;P0F5QH08R8R01TI
6@0D51@05QHF02XZ:P1YJFT0^;Rh06][J`1SHf<0OWin065QH@28R8P0KVi^06MWI`1NGUh00P0f=SH0
6P1JFUX0KVi^04A4A00[:b/09bLW03@d=00f=SH0>CTi03@d=016ATH0[:b/08N7Q`1<C4`0JFUY04i>
CP14A4@0<S8b020P800d=3@0BTY:03Lg=`0N7Qh06a/K01`L700I6AT05aLG0P0I6AT0?P0L71`0;Rh^
03Xj>P1[Jf/0^[Zj0:VYZ@38b<P0fm_K09FEU@1RHV80CTi>04M7A`1DE5@0GemO06YZJP2=SHd0^;Rh
0<g=c@31`L40Zj^[0861P@1JFUX0?Cdm0410@027QhL0?clo01hN7P0U9BD0C4a<04i>CP1]KFd0IVIV
03Lg=`14A4@09bLW01DE5@0F5QH05aLG03@d=02NWYh0QXJ607inOP0V9RH061PH03hn?P2HV9P0Xj>S
03<c<`0P82008B4Q051@D02n_[h0^[Zj0;>c/`2][Jd0V9RH05UIF@0Z:RX09RHV01DE5@0F5QH05ADE
0P0F5QH04`0b<S80E5AD05mOG`1<C4`0[:b/069RHP16ATH0[jn_0>KViP3:b/X0PX:206m_K`1oOgl0
BTY:03hn?P10@4009BDU01dM7@0K6a/00P0J6QX01`0S8b<0<c<c01hN7P2EUID0SXj>09JFUP1]KFd0
0P0_;bl03`0i>CT0B4Q804M7A`14A4@0>SXj028R8P0e=CD092@T024Q8@0f=SH0HF5Q0<;2`P2l_;`0
]KFe08b<S00209BDU01@0861P@2DU9@0YjNW0;>c/`2KVi/0SHf=08:2PP2VYZH0][Jf09FEU@23Ph<0
IVIV04e=C@0g=cL0>c/k08N7Q`2b/[80WinO03Hf=P0o?cl0CTi>03<c<`17AdL0NWYj09bLW02VYZH0
/k>c07EeM@2LW9`0Rh^;09bLW027QhL0WIfM0<C4a036a/H0`<3005iNGP1^KVh0F5QH02PX:00N7Qh0
9bLW05EEE@1oOgl0e=CD0=SHf02^[Zh0^;Rh0<O7a`2XZ:P0EeMG06][J`1fMWH0Fe]K05YJFP1_Kfl0
VIVI0;Ng]`2h^;P0ZJVY05]KF`1QHF40DU9B04e=C@0d=3@07QhN01/K6`0N7Qh092@T034a<@1WIfL0
QHF509jNWP2?Shl0Q8B40;Vi^@2g]kL0@T9203Ti>@1;Bd/Aooooo`003oooool0F`25QHD0QXJ604U9
B@1EEED0E5AD04I6AP1SHf<0V9RH05iNGP0f=SH0NWYj05ADE00i>CT0EUIF03@d=01KFe/0:BTY05aL
G00a<C408R8R06ATI00c<c<0Ng]k03De=@15ADD0Fe]K04i>CP1[Jf/0WinO06ATI00V9RH0GEeM04E5
A@1RHV809RHV02DU9@1FEUH0HV9R02/[:`1RHV80KVi^03Ti>@16ATH0C4a<01LG5`0X:2P0FUYJ02HV
9P0f=SH0D51@04m?C`0c<c<0?Shn03Hf=P1nOWh0HV9R03<c<`0O7al0Fe]K04A4A00/;2`0L71`06IV
IP10@400NWYj05MGE`0];Bd0Cdm?08^;R`0e=CD0@d=304U9B@1<C4`0N7Qh07alO00j>SX0CDe=04E5
A@1QHF40Hf=S0451@@1MGEd0OWin03Xj>P10@400Z:RX06][J`0Q8B40R8R809fMW@1BDU800P25QHD0
1012@T80RXZ:0:JVYP1FEUH2051@D01F06UYJ@1oOgl0Hf=S06MWI`15ADD0OWin04m?C`1:BTX0JVYZ
06e]K@2FUYH0Hf=S04Y:BP13@d<0=cLg08F5Q@1ZJVX0Bd];0861P@1OGel0VIVI059BDP1PH600P820
05EEE@1FEUH0M7Ad05ADE01=CDd0>3Ph055AD@1`L700NWYj07emO@1FEUH0UiNG05EEE@1ADE40J6QX
06EUI@2OWil0Ng]k03lo?`2TY:@0LW9b04Q8B02;Rh/0QHF503dm?@1JFUX0Ph>306ATI01mOGd0SHf=
04A4A01KFe/0Kfm_06IVIP1QHF40Rh^;05YJFP1EEED0=cLg07IfMP2;Rh/0TI6A0;:b/P2ZZZX0EEEE
061PH033`l<0Shn?04i>CP36a/H0WinO08>3P`1KFe/0VIVI06][J`1YJFT0_[jn07AdM02?Shl0ZZZZ
0;:b/P1IFET2061PH01W05aLG010@400@D5108R8R01TI6@0C4a<06EUI@1FEUH0@d=309bLW01ADE40
T92@08n?S`1ADE40P820065QH@0_;bl0HF5Q06YZJP0n?Sh0C4a<07IfMP1IFET0B4Q807emO@1MGEd0
DU9B04=3@`35aLD0Y:BT07inOP0f=SH0JFUY05IFEP1eMGD0UIFE065QH@0k>c/0TY:B096AT@15ADD0
TI6A07YjNP17AdL0?Shn06ATI01fMWH0CTi>06IVIP1nOWh0B4Q807YjNP2^[Zh0GemO04e=C@1DE5@0
MgMg059BDP1ZJVX0FUYJ0820P02l_;`0SHf=06m_K`2XZ:P0[:b/05iNGP16ATH0SXj>07inOP1ADE40
BTY:07EeM@0h>3P0<c<c04a<C01WIfL0G5aL03dm?@1TI6@0<30`04i>CP2QXJ40KVi^03Ph>01hN7P0
A4A402@T901YJFT05aLG0492@P1QHF40DE5A01TI6@29RHT0;Rh^034a<@1hN7P0HV9R01dM7@1EEED0
JVYZ08F5Q@0Looooo`0J04=3@`0n?Sh0=SHf05aLG020P800<30`01dM7@0O7al07AdM02`/;01CDe<0
GUiN05IFEP2NWYh0d];B08j>SP0f=SH08R8R03dm?@0j>SX0GUiN03/k>`0G5aL05ADE010@400>3Ph9
00d=3@1E014A4@1nOWh0HF5Q07=cL`1=CDd0WYjN02HV9P0M7Ad0QXJ6010@400:2PX03Ph>00d=3@0G
5aL0J6QX03Lg=`0J6QX06ATI01PH600J6QX05aLG02DU9@1>CTh0BDU9069RHP0d=3@02@T901lO7`23
Ph<0Jf][04a<C00[:b/07alO04Q8B01JFUX0;Rh^01`L700d=3@0C4a<03De=@13@d<0BDU90410@00N
7Qh04a<C03Lg=`1HF5P0Ogmo05UIF@0h>3P0OGem096AT@2JVYX0Jf][038b<P0G5aL051@D01DE5@0G
5aL08B4Q02LW9`0N7Qh06QXJ01/K6`0J6QX0?3`l069RHP20P800J6QX0<71`@2@T900d];B05ADE01E
EED0?Cdm04a<C00_;bl06a/K01`L700M7Ad0LW9b08n?S`36a/H0SXj>05MGE`0202PX:00T02HV9P0U
9BD0?Cdm03dm?@0N7Qh06a/K059BDP1?Cdl0KVi^03Ph>00f=SH0FUYJ02DU9@0E5AD05aLG05UIF@0h
>3P0ADE503hn?P0];Bd05QHF01TI6@2c/k<0f][J09JFUP0/;2`0:RXZ06YZJP2m_Kd0`l?30=;BdP2k
^k/0<c<c02<S8`0b<S807alO1@0E5AD0O`0F5QH061PH04U9B@2n_[h0emOG06m_K`2TY:@0ZZZZ0=KF
eP2j^[X0aLG50=[JfP2_[jl0:b/[02PX:00V9RH07AdM01XJ6P0I6AT05aLG01TI6@0L71`0<30`03De
=@2`/;00W9bL0;fm_@1/K6`0@41005]KF`1FEUH0@T9201lO7`0H61P06ATI02XZ:P0V9RH0820P03hn
?P1IFET0^;Rh09bLW032`/80i>CT0=_Kf`38b<P0`l?309VIV@1ADE40;bl_02<S8`0P820092@T03<c
<`20P800Y:BT0;Vi^@35aLD0UIFE02/[:`0M7Ad09BDU07MgM`2c/k<0TI6A04a<C01cLg<0M7Ad03/k
>`1MGEd0NGUi07emO@20P800Shn?06UYJ@1:BTX0@41003Xj>P1_Kfl0XZ:R0<C4a02e]KD0XZ:R04Q8
B01LG5`092@T02LW9`0[:b/0=SHf09NGU`3AdM40_Kfm0<O7a`2VYZH0XJ6Q09:BTP2a/K40Lg=c05IF
EP0];Bd06ATI01DE5@0J6QX0CDe=069RHP1aLG40Y:BT08B4Q01XJ6P0Kfm_04i>CP1:BTX08R8R02@T
901;Bd/0GemO07MgM`2QXJ40]KFe0;:b/P2n_[h0`/;20<K6aP37alL0`L7106][J`0[:b/04Oooool0
00oooooo0;D0U9BD09FEU@1<C4`0MWIf059BDP0f=SH0D51@08j>SP1HF5P0?Cdm07moO`1=CDd0:b/[
0451@@0d=3@0Cdm?03`l?024Q8@0EeMG02HV9P19BDT0:BTY075aL@1DE5@0@D5105IFEP0j>SX0DE5A
08j>SP1^KVh0;Bd]055AD@1OGel0Cdm?0410@00`<300FUYJ06YZJP0M7Ad0@T9205ADE00n?Sh0DE5A
04m?C`0L71`0:2PX05UIF@0n?Sh0AdM704E5A@1CDe<0?clo04Q8B01=CDd0U9BD04Y:BP0^;Rh0820P
065QH@0o?cl09RHV04M7A`1dM7@0@d=308B4Q01<C4`09bLW03/k>`1]KFd0>SXj059BDP0i>CT0D51@
08Z:RP1`L700>CTi03lo?`1DE5@0WIfM06ATI00c<c<0IVIV08R8R00g=cL0Bd];08J6QP1KFe/07QhN
08R8R02e]KD0CTi>08Z:RP28R8P0A4A408N7Q`2YZJT0Fe]K04m?C`1@D500OGem06QXJ01dM7@0IFEU
0492@P1cLg<0ADE505MGE`1MGEd0IfMW08j>SP1NGUh0CTi>04E5A@0g=cL0U9BD06YZJP1CDe<0OWin
06YZJP2FUYH0HF5Q06ATI025QHD0FEUI055AD@1hN7P0EEEE04m?C`1DE5@0Hf=S07MgM`22PX80Q8B4
055AD@1kNg/0?clo05ADE01dM7@0Hf=S0:f][@1MGEd0?clo0:VYZ@1gMgL0Cdm?09>CT`24Q8@0=CDe
07UiN@1lO7`0LG5a07alO02<S8`0AdM706YZJP2BTY80J6QX06UYJ@22PX80Hf=S06ATI01;Bd/0Ng]k
08n?S`2ATI40Z:RX0:b/[01SHf<0LW9b0;bl_029RHT0D51@07]kN`2ZZZX0LW9b055AD@2RXZ80JFUY
05iNGP2g]kL0EUIF0080WinO00D0Y:BT0451@@25QHD0V9RH05ADE0020410@01T08:2PP1TI6@0BDU9
05iNGP10@400A4A40:>SX`1^KVh0OGem08n?S`0`<300RHV906YZJP0^;Rh0FEUI069RHP0O7al0E5AD
0:JVYP1VIVH0BTY:09RHV01lO7`0IFEU04i>CP35aLD0YjNW08V9R@0e=CD0IVIV05UIF@1gMgL0][Jf
06a/K011@D40YZJV0::RXP0W9bL0DU9B05iNGP0a<C40DE5A07IfMP20P8008b<S04M7A`1lO7`0?Shn
08F5Q@2h^;P0>3Ph05UIF@26QXH0K6a/04A4A01KFe/0>c/k059BDP24Q8@0Jf][06IVIP2h^;P0]KFe
05aLG00X:2P0Fe]K079bLP1>CTh0Cdm?08J6QP12@T80>c/k07=cL`1fMWH0FEUI04=3@`1^KVh0DE5A
02`/;02BTY80B4Q803De=@1fMWH0DE5A02h^;P1iNGT07QhN04U9B@1MGEd0<C4a01dM7@2:RXX07alO
028R8P1MGEd0KFe]03/k>`1PH600=CDe07]kNacooooo01H0GEeM03lo?`0b<S80;Rh^0820P012@T80
8B4Q01`L700M7Ad07alO03Xj>P0n?Sh0B4Q807YjNP3;bl/0H61P03<c<`0m?Cd0@d=306i^KP0n?Sh0
5ADE0P0A4A40100C4a<04Q8B01DE5@0>3Ph200d=3@0o00L71`092@T03@d=00T92@0=3@d030`<024Q
8@27QhL0M7Ad07EeM@1iNGT0YJFU09RHV038b<P0>3Ph01@D500E5AD0<c<c07MgM`0/;2`06ATI01/K
6`0G5aL06a/K01@D500`<300F5QH02TY:@0E5AD0Lg=c01<C4`0=3@d06QXJ02/[:`1hN7P0CDe=02<S
8`0J6QX06a/K02h^;P1MGEd0A4A402PX:01:BTX0AdM702h^;P0D51@0410@00h>3P0E5AD05aLG01/K
6`0e=CD0Rh^;06QXJ02KVi/0dm?C0=KFeP20P8005ADE014A4@0C4a<0410@00<05ADE01X05QHF01LG
5`0K6a/0820P051@D02=SHd0H61P03Lg=`1kNg/0YZJV0;Zj^P1EEED0:RXZ07emO@1HF5P07AdM01/K
6`0M7Ad07QhN06m_K`2MWId0_kno08b<S01HF5P09bLW01`L70809BDU02@0:BTY03lo?`0i>CT06a/K
04i>CP1KFe/0LW9b04i>CP0c<c<0=cLg061PH00M7Ad0>c/k05IFEP16ATH0<S8b03De=@0^;Rh06a/K
02h^;P1QHF40b/[:0=?Cd`2m_Kd0alO70=GEe@3?cll0d];B0<o?c`2BTY80?3`l03hn?P1LG5`0@D51
01lO7`0G5aL301DE5@0501HF5P0I6AT06a/K07]kN`2;Rh/00P2ZZZX02`2JVYX0Ogmo04e=C@1QHF40
QHF50;Jf]P0l?3`0:RXZ01lO7`0H61P071`L00<06a/K02D06ATI01dM7@0j>SX0WIfM0:n_[`2PX:00
_Kfm069RHP0[:b/0<c<c055AD@0Z:RX05aLG01PH600i>CT0;Bd]04e=C@0e=CD0>SXj08^;R`0g=cL0
FEUI0=SHf02RXZ80GEeM04I6AP1?Cdl08B4Q01`L700M7Ad07alO01`L700M7Ad0HF5Q06MWI`2?Shl0
^[Zj0080O7al0100IfMW06IVIP2FUYH0OGem05iNGP2XZ:P0_kno0;fm_@2?Shl0TY:B07EeM@24Q8@0
KFe]06=SH`1bLW80Lg=c0P1:BTX05P1IFET0SXj>06=SH`1GEeL0FEUI07EeM@1FEUH07alO02<S8`1R
HV80[jn_0;Fe]@2CTi<0KFe]0861P@16ATH0?Shn06a/K024Q8@0=3@d01XJ6P0F5QH201DE5@0I01TI
6@0g=cL0F5QH04];B`1oOgl0SHf=07=cL`1lO7`0QhN7079bLP0m?Cd0Bd];07]kN`2ATI40MGEe05aL
G01SHf<0[Jf]0:FUY@35aLD0`L710:NWY`2<S8`0GEeM024Q8@0Aooooo`003oooool0d@20P800JFUY
051@D01fMWH0GEeM055AD@1OGel0Shn?05IFEP17AdL0Vi^K06][J`0S8b<0?clo04I6AP0o?cl09RHV
061PH01=CDd0:2PX061PH00b<S80W9bL05UIF@0j>SX0GemO04i>CP1QHF40TY:B07=cL`0[:b/0FUYJ
06QXJ01/K6`0Cdm?03Hf=P1[Jf/0NGUi03Lg=`1IFET0GEeM03lo?`1ADE40CDe=02<S8`1@D500N7Qh
03Lg=`1:BTX0@410055AD@19BDT0JFUY04];B`2<S8`0D51@03hn?P0];Bd0Q8B406QXJ00d=3@0FUYJ
07QhN012@T80WYjN05QHF00^;Rh0>c/k06EUI@0W9bL0DU9B04=3@`1EEED0Q8B4061PH00j>SX0ADE5
05iNGP34a<@0GEeM02PX:01HF5P0YJFU0410@013@d<0Lg=c04];B`0M7Ad0RHV90::RXP1=CDd0OWin
059BDP0U9BD0OGem0:JVYP1QHF40IVIV06QXJ021PH40@D5104a<C01SHf<0?3`l0861P@0e=CD0LG5a
06EUI@1SHf<0TY:B055AD@1jNWX0FEUI03Lg=`2[Zj/0=cLg06m_K`1nOWh0Jf][08^;R`1SHf<0VYZJ
08^;R`1PH600E5AD06EUI@1<C4`0Ng]k05iNGP1MGEd0H61P0:>SX`2CTi<0BTY:06i^KP0o?cl0EEEE
08R8R01FEUH0W9bL061PH01RHV80`<3008V9R@1<C4`0RXZ:05UIF@1BDU80/;2`08>3P`1[Jf/0OGem
05IFEP0f=SH0KVi^07QhN01LG5`0Cdm?08B4Q011@D40LG5a06IVIP1cLg<0P82003`l?02IVIT0/k>c
08b<S023Ph<0/;2`03Ph>00m?Cd0GEeM09^KV`1HF5P0DE5A09jNWP23Ph<0I6AT0;:b/P1_Kfl0Vi^K
0:BTY02`/;00E5AD05EEE@1HF5P0=SHf03/k>`0n?Sh0T92@08:2PP1FEUH0G5aL05EEE@18B4P0X:2P
06IVIP1iNGT0WYjN04m?C`2EUID0GEeM02TY:@1bLW80N7Qh02d];@14A4@0JFUY0080B4Q804l0KVi^
05ADE01[Jf/0?Cdm0:n_[`3Fe]H0VIVI02PX:01^KVh0BTY:05IFEP2;Rh/0B4Q8038b<P2m_Kd0XZ:R
0410@01JFUX0Lg=c038b<P0l?3`0IFEU08B4Q012@T80BDU906EUI@0R8R80RXZ:0;^k^`0k>c/0?Cdm
05=CD`18B4P0>SXj05eMG@14A4@0FEUI09JFUP1NGUh0@d=308:2PP28R8P0HF5Q05ADE02<S8`0KFe]
06IVIP1]KFd0Ng]k03`l?01=CDd0X:2P09FEU@1UIFD0DU9B06IVIP10@400>SXj0:^[Z`1SHf<0;Rh^
06IVIP1?Cdl07AdM06UYJ@0U9BD0B4Q8061PH01MGEd06ATI071`L016ATH0820P04];B`1CDe<0>3Ph
079bLP0m?Cd0NWYj01cooooo01X0Lg=c05MGE`0m?Cd0<S8b07alO01;Bd/09BDU028R8P1NGUh0;Bd]
02XZ:P0a<C40?Shn09jNWP31`L40Ogmo04U9B@1;Bd/0IVIV03Hf=P0E5AD0410@01<C4`0A4A404Q8B
014A4@803`l?00L05ADE01dM7@0@410030`<00d=3@0;2`/0410@00804a<C02L0@D5109VIV@2XZ:P0
]KFe0<W9b@3GemL0a/K60:FUY@2SXj<0VIVI0:VYZ@0_;bl08B4Q020P800G5aL04a<C01XJ6P0d=3@0
DE5A01`L700=3@d0;Bd]06MWI`0P82009RHV051@D00e=CD0J6QX05UIF@0X:2P05aLG01DE5@0G5aL0
8B4Q06a/K026QXH0De=C01TI6@0A4A400P0>3Ph0300@41005aLG01DE5@0E5AD0<C4a02h^;P2j^[X0
c/k>0:f][@36a/H0K6a/01XJ6P804Q8B01X051@D01DE5@0E5AD051@D01DE5@0G5aL09BDU05EEE@1g
MgL0Lg=c04i>CP0L71`09BDU06YZJP2k^k/0S8b<02DU9@1:BTX0F5QH02<S8`0K6a/071`L02TY:@23
Ph<0c/k>09fMW@80<C4a03X0D51@02HV9P0L71`0820P02PX:00W9bL0B4Q802HV9P0h>3P0MGEe0:ZZ
ZP2g]kL0De=C03Hf=P1VIVH0TI6A07alO00e=CD0DE5A01dM7@0_;bl0LW9b05MGE`1;Bd/0TY:B0=OG
e`3De=@0gMgM0861P@2ATI40^;Rh0:ZZZP30`<00X:2P06i^KP0^;Rh07alO01dM7@0f=SH0=cLg01dM
7@0P82007alO024Q8@0J6QX071`L08F5Q@2YZJT0a/K60<30`02e]KD0@41001lO7`0L71`0BDU905UI
F@2KVi/0>CTi0`0K6a/08P0M7Ad071`L024Q8@0_;bl0D51@079bLP2c/k<0dM7A0:b/[01HF5P05ADE
01@D500E5AD06QXJ07]kN`1LG5`0F5QH0;2`/020P800<c<c01HF5P1<C4`0ADE5024Q8@1>CTh0VIVI
01lO7`18B4P0MWIf06UYJ@1[Jf/0?clo02/[:`0R8R8201lO7`0^06IVIP2OWil0IVIV07inOP1[Jf/0
IVIV092@T03Bd]80WIfM02`/;00k>c/0Vi^K0>3Ph03Rh^80bl_;07YjNP27QhL0HV9R051@D01=CDd0
M7Ad03lo?`0V9RH0>c/k0410@011@D40DU9B04];B`1HF5P0U9BD04m?C`0o?cl0Rh^;0:RXZ023Ph<0
Ng]k061PH01^KVh0QHF502HV9P0E5AD05aLG03hn?P12@T80;2`/01LG5`805ADE01T05aLG024Q8@15
ADD0>3Ph05UIF@2CTi<0QHF509NGU`2e]KD0bLW909jNWP1lO7`0H61P04U9B@0l?3`0>CTi04E5A@2:
RXX0Vi^K0;Rh^02IVIT0WYjN08R8R01bLW80CTi>017ooooo000?ooooo`2U07alO02EUID0BTY:075a
L@1TI6@0DU9B069RHP1TI6@09BDU04U9B@1fMWH0EUIF02HV9P11@D40CDe=07=cL`0e=CD0MGEe04];
B`0e=CD0Ng]k03Ph>02KVi/0>CTi06ATI027QhL0BDU904i>CP2BTY80G5aL03lo?`2VYZH0PX:206UY
J@0R8R80:2PX096AT@2JVYX0F5QH065QH@24Q8@09BDU05eMG@17AdL02`/;03Xj>P1PH600=3@d04I6
AP0l?3`09bLW01/K6`1?Cdl0CTi>08j>SP14A4@03`l?01hN7P28R8P0TI6A03Ti>@1SHf<0@T92034a
<@2_[jl0O7al02h^;P0j>SX0LW9b01/K6`1KFe/0MGEe04Y:BP1iNGT0DE5A03<c<`1NGUh0CTi>0:VY
Z@1FEUH09bLW04E5A@1mOGd0>SXj04U9B@1VIVH0=SHf0451@@2?Shl0UIFE04];B`2:RXX0G5aL03@d
=01iNGT0Ti>C03Ph>01=CDd0CTi>07EeM@1`L700Hf=S05=CD`12@T80RXZ:06EUI@1SHf<0GEeM069R
HP24Q8@0=SHf0492@P0m?Cd0=3@d0:NWY`1?Cdl0E5AD071`L01TI6@0KVi^04E5A@1RHV80KVi^05AD
E01GEeL0HV9R03Xj>P19BDT0A4A404Q8B01ZJVX0GUiN07inOP11@D40GemO04];B`19BDT0J6QX05EE
E@2OWil0MWIf03@d=02EUID0KFe]04m?C`2GUiL0KFe]034a<@2MWId0Lg=c07EeM@1`L700QhN704Q8
B01HF5P0LG5a06MWI`0l?3`0Ti>C05mOG`1_Kfl0J6QX07=cL`27QhL0KFe]0080NGUi05X0EeMG07Ee
M@2a/K40Lg=c03dm?@2UYJD0TY:B04i>CP1HF5P0ZJVY07UiN@1PH600]kNg05eMG@1oOgl0WIfM08^;
R`17AdL0Ng]k07alO011@D40@d=303Lg=`20P800Fe]K05IFEP24Q8@0G5aL055AD@2][Jd0?Shn06YZ
JP2FUYH0CDe=0;:b/P1jNWX09BDU05YJFP1UIFD0?clo051@D02VYZH0EEEE03@d=028R8P0DU9B061P
H00Z:RX0Ogmo08N7Q`1]KFd0=SHf07]kN`1aLG40OGem092@T01OGel0@4100;Zj^P2QXJ40DE5A09>C
T`29RHT0?clo04i>CP1VIVH0OGem03/k>`1YJFT0QhN7030`<01RHV80Rh^;04Q8B01ADE40J6QX0410
@00g=cL0EeMG05EEE@28R8P0/k>c08F5Q@1CDe<0T92@08^;R`17AdL0:2PX05QHF01DE5@204];B`0O
07EeM@0U9BD0;2`/07alO02HV9P0Ng]k04=3@`1LG5`0=3@d02DU9@21PH40CDe=02l_;`1LG5`0GemO
02LW9`1_Kfl092@T04I6AP1/K6`0Ogmo02XZ:P2BTY80?Shn020P8014A4@0CTi>02<S8`1bLW80OWin
09RHV00Looooo`0>096AT@2IVIT0MWIf05QHF022PX80Xj>S09bLW021PH40VYZJ07emO@1aLG40O7al
0;6a/@2ZZZX20;no_`0908j>SP1`L700?clo01DE5@0D51@04A4A01hN7P0G5aL06ATI00804A4A02h0
4a<C05eMG@1RHV8071`L014A4@0E5AD04a<C01LG5`0K6a/0;2`/03Ph>01nOWh0/K6a0;Vi^@37alL0
W9bL0820P01IFET0YJFU0<o?c`2SXj<0<c<c028R8P0E5AD06a/K020P800l?3`0C4a<01hN7P0a<C40
<S8b04I6AP0c<c<0>c/k02h^;P0H61P0>c/k02h^;P2?Shl0:BTY01`L700E5AD06ATI01XJ6P0k>c/0
E5AD0P0K6a/01@0A4A403Ph>00h>3P0E5AD06ATI00805ADE00X0<S8b01XJ6P2IVIT0F5QH04I6AP2I
VIT0QXJ603`l?00G5aL051@D0P0C4a<01`0N7Qh071`L03@d=01HF5P0L71`05ADE00];Bd00P0j>SX0
F00K6a/06QXJ03Ti>@27QhL0aLG506i^KP1FEUH0G5aL04I6AP0J6QX07AdM02`/;02YZJT0i>CT0:>S
X`0m?Cd071`L03Ph>014A4@0BDU903Xj>P0`<3009bLW030`<01;Bd/0<S8b09nOW`2TY:@0]KFe08^;
R`1JFUX0BTY:0<g=c@1kNg/0FEUI04=3@`0Y:BT0A4A406YZJP2EUID0PH6105IFEP26QXH0bl_;0:RX
Z02^[Zh0MGEe07UiN@1:BTX0MWIf092@T022PX80L71`02DU9@0M7Ad07QhN02@T900X:2P06ATI01PH
600L71`09BDU079bLP2[Zj/0^;Rh0:FUY@2a/K40<c<c024Q8@0M7Ad071`L02TY:@1PH600^;Rh065Q
H@0Z:RX0=SHf03hn?P1DE5@0CTi>05MGE`1MGEd0FEUI061PH03Lg=`0`<300;fm_@1BDU8401DE5@14
075aL@2^[Zh0UYJF0;Zj^P1[Jf/06ATI02PX:01IFET092@T01dM7@1CDe<0EeMG01DE5@0G5aL0;2`/
0;Rh^02_[jl0SHf=07alO01iNGT0QHF508B4Q028R8P0>SXj09JFUP2i^KT0/;2`0<O7a`3=cLd0gMgM
03Xj>P0M7Ad0<c<c0:n_[`3>c/h0fm_K0<71`@3Bd]80^KVi08j>SP1iNGT0J6QX06YZJP0X:2P0A4A4
02`/;00C4a<05aLG03<c<`1>CTh0G5aL09BDU03EeMD0/K6a06m_K`1UIFD0BDU905aLG011@D40>c/k
06EUI@0I6AT05ADE01<C4`0V9RH0Cdm?03De=@0G5aL201DE5@0<01LG5`0L71`0>c/k034a<@0d=3@0
GemO0<30`02f][H0[Jf]09RHV01OGel0=cLg0P0f=SH02`0d=3@0>3Ph0451@@2:RXX0W9bL06UYJ@22
PX80Bd];07UiN@25QHD0Ogmo017ooooo000?ooooo`1608R8R02DU9@0BTY:06EUI@1_Kfl0Bd];069R
HP1PH600;Rh^04Q8B01lO7`0CDe=02DU9@11@D40820P055AD@0W9bL0CDe=010@400];Bd0F5QH02/[
:`1dM7@071`L03/k>`1gMgL0@41004=3@`22PX80De=C01lO7`1LG5`0K6a/05YJFP0S8b<06a/K05YJ
FP1YJFT0@41005]KF`1LG5`0<c<c04i>CP0n?Sh071`L03Ti>@1XJ6P0;bl_04e=C@0n?Sh0GUiN0492
@P1<C4`0ADE50:ZZZP1_Kfl0?Cdm01dM7@1ZJVX0HV9R038b<P1XJ6P0AdM702/[:`1lO7`0I6AT02LW
9`0j>SX0Ogmo02XZ:P80?3`l02L0@41009FEU@1`L700;bl_03hn?P0m?Cd0Shn?071`L01DE5@0HV9R
08V9R@0k>c/0CTi>06QXJ01KFe/06a/K06EUI@1dM7@0>3Ph07inOP1hN7P0BTY:07MgM`2DU9@0BDU9
04m?C`14A4@0LW9b08:2PP1YJFT0B4Q803Ti>@1mOGd0EeMG06][J`1ADE40PX:209VIV@1IFET00P1@
D5003`0m?Cd0XJ6Q05MGE`1HF5P0JVYZ06i^KP2PX:00H61P075aL@1dM7@0De=C05mOG`2=SHd0GemO
05aLG00205UIF@2507moO`1eMGD0HV9R03Lg=`22PX80De=C055AD@1LG5`0@T9208>3P`21PH40ADE5
0;2`/01ADE40@T9208:2PP1fMWH0?Cdm0:6QX@1eMGD0CTi>06EUI@1oOgl0@T9205YJFP1_Kfl0I6AT
0492@P2MWId0KFe]08:2PP1LG5`0OGem08>3P`21PH40Z:RX08j>SP18B4P0QXJ60;Jf]P1hN7P0F5QH
0<;2`P1jNWX0@T9206MWI`2XZ:P0L71`07emO@2o_kl0L71`0:2PX02TY:@0MGEe03<c<`2ATI40QHF5
03dm?@1<C4`0@T92079bLP0f=SH0C4a<07IfMP0o?cl0AdM709NGU`1eMGD0NGUi08^;R`0d=3@0T92@
07EeM@0a<C40FUYJ061PH01;Bd/0Cdm?0:VYZ@1[Jf/0?Shn07emO@1QHF40LG5a04];B`36a/H0/[:b
08Z:RP0Q8B40HF5Q08Z:RP28R8P0/k>c07inOP17AdL0a/K609VIV@0k>c/0Fe]K07emO@0n?Sh0E5AD
06i^KP1cLg<0<30`03dm?@1aLG40;bl_04U9B@1oOgl0@D5104M7A`1[Jf/0GUiN04Q8B01TI6@0?3`l
05YJFP25QHD0Kfm_0451@@2<S8`0WYjN07UiN@0b<S80KFe]06i^KP1?Cdl0EEEE09ZJVP1XJ6P0De=C
0:j^[P0207IfMP0I03dm?@1VIVH0Kfm_02h^;P2;Rh/0FEUI02/[:`1VIVH0QhN703Hf=P1ZJVX0:RXZ
05UIF@1jNWX0Lg=c03/k>`2j^[X0>SXj01hN7P0l?3`0EUIF03lo?`1PH600>3Ph07]kN`0Looooo`1<
05QHF01RHV80OWin07UiN@2SXj<0WinO07QhN01EEED0I6AT06MWI`1IFET0@D5103dm?@2:RXX0/k>c
0;jn_P2PX:00G5aL01TI6@0E5AD04a<C010@400C4a<05ADE018B4P0A4A404a<C01`L701hN7P0@410
02/[:`0d=3@0A4A405=CD`1FEUH0IfMW06YZJP1WIfL0EUIF08n?S`2=SHd0^KVi096AT@1MGEd0<S8b
0:b/[02HV9P0/[:b09bLW01MGEd0IFEU05MGE`1HF5P0HF5Q03lo?`12@T80;2`/02TY:@1;Bd/04Q8B
00l?3`0A4A403`l?01HF5P0N7Qh0M7Ad04M7A`0R8R805QHF01DE5@0G5aL0?Cdm0410@00G5aL07QhN
01TI6@803Ph>01406QXJ01DE5@0E5AD05QHF02d];@0a<C40WYjN0451@@18B4P0[:b/0=7Ad@29RHT0
Kfm_04I6AP0h>3P0=SHf04E5A@0206ATI00R0451@@0X:2P05QHF01/K6`0c<c<0?clo01TI6@0G5aL0
;bl_04i>CP3?cll0UiNG0:f][@2ATI40Fe]K02l_;`0[:b/0Q8B40<G5a@3Hf=P0c<c<09jNWP0k>c/0
:b/[01DE5@0Q8B40C4a<05MGE`0g=cL0=3@d04a<C00i>CT0;Bd]07moO`80GEeM01X0S8b<0:f][@3B
d]80`<3009fMW@1HF5P0EUIF07emO@2CTi<0OGem04E5A@0N7Qh0@d=309NGU`0e=CD0Kfm_0=;BdP2@
T900EeMG096AT@26QXH0BTY:09NGU`2CTi<0:BTY01/K6`8071`L00X07AdM01TI6@0S8b<0L71`06QX
J01LG5`0aLG5096AT@2<S8`07AdM0P0L71`01`0M7Ad0;bl_03<c<`2LW9`0`/;208>3P`1KFe/00P1<
C4`03P17AdL0@41003De=@0h>3P0UIFE0=?Cd`33`l<0f=SH0;Zj^P1SHf<07alO024Q8@1ADE40G5aL
0P0];Bd0:P15ADD0GemO01lO7`1YJFT0?clo024Q8@0g=cL0DU9B03De=@0E5AD06ATI03De=@19BDT0
6ATI01dM7@0Q8B409bLW03Xj>P2=SHd0CDe=01`L701_Kfl0f][J0<_;b`2OWil0`L710:f][@18B4P0
7AdM05ADE02YZJT0JFUY0<30`02DU9@0bl_;0;fm_@2a/K40YJFU0<?3``2GUiL0@d=302l_;`805ADE
00h04a<C01DE5@0_;bl0E5AD08f=S@3?cll0WinO04i>CP0b<S80=3@d05ADE00_;bl0=3@d059BDP<0
5ADE00@071`L04];B`1;Bd/06ATI0P0E5AD06@0G5aL08B4Q04U9B@0/;2`0<c<c04M7A`3@d=00/[:b
0:b/[01]KFd0I6AT030`<00b<S80<c<c030`<00e=CD0?Shn0:6QX@2SXj<0IFEU09FEU@0b<S80EUIF
09NGU`2LW9`04Oooool000oooooo0540Jf][07YjNP1=CDd0=SHf05QHF00o?cl0HV9R08n?S`1:BTX0
HF5Q08J6QP11@D40<S8b05ADE00h>3P0E5AD02PX:01PH600<C4a028R8P1MGEd0<S8b06i^KP1<C4`0
?Cdm07UiN@1=CDd0BDU909fMW@1]KFd0;bl_06][J`1IFET0IFEU04m?C`0e=CD0MgMg065QH@0];Bd0
I6AT06m_K`15ADD0BDU904A4A00R8R80@410079bLP0Q8B40=cLg03lo?`1CDe<0?3`l04Y:BP0h>3P0
Ng]k06e]K@1;Bd/0;2`/08B4Q01DE5@0?3`l0820P01`L700@D5109bLW01OGel0;Rh^055AD@28R8P0
?3`l04Y:BP10@400<c<c08>3P`1TI6@0=cLg03/k>`1ADE40MWIf079bLP1:BTX00P28R8P03@0m?Cd0
HF5Q08b<S01SHf<0<30`08n?S`22PX80BDU908N7Q`1kNg/0E5AD07AdM02;Rh/00P1:BTX0`019BDT0
IfMW06m_K`1kNg/0HF5Q03/k>`1aLG40@d=3079bLP1GEeL0HF5Q08:2PP16ATH0D51@03De=@0m?Cd0
XZ:R04m?C`1DE5@0F5QH05]KF`28R8P0H61P06i^KP1JFUX0B4Q806ATI01lO7`0FUYJ06ATI011@D40
CDe=07=cL`2IVIT0QXJ604e=C@2ATI40Cdm?07=cL`29RHT0H61P092@T01lO7`0ADE50;Rh^029RHT0
BDU908Z:RP1hN7P0Bd];092@T01kNg/0EUIF065QH@1aLG40DE5A07QhN024Q8@0@d=303Ti>@1fMWH0
KFe]07YjNP16ATH0R8R808j>SP23Ph<0]KFe08^;R`0n?Sh0Ogmo0:b/[01SHf<0Rh^;0<?3``2ATI40
?Cdm059BDP2CTi<0=CDe05ADE02k^k/0LG5a0;6a/@31`L40Vi^K04e=C@1NGUh0MgMg03dm?@0e=CD0
=3@d092@T01MGEd0Bd];07moO`1FEUH0?Cdm096AT@1WIfL0Ph>308^;R`1<C4`0Vi^K06][J`0a<C40
EUIF05=CD`0[:b/0IFEU0:n_[`1VIVH0>CTi06m_K`1MGEd0Jf][04M7A`3De=@0aLG50:2PX00T92@0
I6AT04a<C01FEUH0Ph>308N7Q`1:BTX0b/[:0:VYZ@1JFUX0L71`08Z:RP12@T80FUYJ06=SH`26QXH0
GUiN04e=C@1nOWh0@T9203/k>`1QHF40B4Q804m?C`1MGEd0Jf][04U9B@1QHF40DE5A07IfMP2RXZ80
TI6A03lo?`2:RXX0[Jf]07UiN@0j>SX0Lg=c06a/K01<C4`0De=C07inOP1OGel0DE5A0::RXP2NWYh0
Fe]K03@d=01[Jf/0MgMg030`<025QHD0FEUI034a<@2HV9P0QhN702l_;`1bLW80:RXZ04=3@`1nOWh0
TY:B055AD@28R8P0BDU902@T901IFET0PH6105YJFP20P800@T9207]kNacooooo01T0QHF509nOW`1d
M7@0CTi>07UiN@32`/80H61P03@d=00U9BD0@41002d];@0W9bL071`L06a/K02MWId0^[Zj0<_;b`2H
V9P0B4Q801hN7P0G5aL06ATI024Q8@0b<S80CDe=0080IFEU0200MgMg08^;R`27QhL0JFUY05=CD`13
@d<0?3`l0451@@13@d<0B4Q803lo?`0/;2`0;Rh^09VIV@1oOgl0c/k>07MgM`2WYjL0^;Rh05aLG02I
VIT0d];B09JFUP27QhL0NGUi0:>SX`11@D406ATI01LG5`0@4100>SXj03/k>`80410@0P0>3Ph0400D
51@05aLG03<c<`1oOgl09BDU01LG5`0E5AD05aLG04e=C@0V9RH05ADE01TI6@0Q8B404a<C018B4P0D
51@301DE5@0]020P8016ATH0YJFU0451@@14A4@0N7Qh09bLW01cLg<0GUiN03Lg=`11@D40EeMG0820
P02`/;00;Bd]01/K6`0F5QH05aLG024Q8@0b<S80FUYJ03De=@18B4P0JFUY07emO@27QhL0AdM706=S
H`1PH600YZJV09FEU@2c/k<0e=CD09fMW@1NGUh0JFUY0:BTY02VYZH0TI6A02TY:@0M7Ad05aLG01lO
7`1DE5@0EEEE0080Bd];0200?Shn0;6a/@1OGel0EUIF04Q8B02XZ:P0hN7Q0=KFeP2d];@0[:b/0:VY
Z@1^KVh0Fe]K0:JVYP22PX80Cdm?04e=C@2@T900=CDe02d];@2TY:@0WinO0;2`/02EUID0MGEe038b
<P10@400IVIV09^KV`0i>CT06QXJ01LG5`8071`L03407AdM02HV9P15ADD0WIfM0<k>cP39bLT0ZZZZ
02DU9@0H61P071`L01lO7`0X:2P0:RXZ0=;BdP3Lg=`0N7Qh03Ph>00U9BD0820P024Q8@0P82008b<S
05]KF`1nOWh0V9RH0>3Ph037alL0dm?C0<[:bP2ZZZX0XJ6Q05iNGP16ATH0=3@d03dm?@0S8b<0NGUi
07moO`2BTY80?Shn07]kN`2c/k<0WinO0451@@0G5aL0<30`04Q8B00F5QH04a<C00804A4A0P0E5AD0
5`0];Bd0<30`020P801dM7@0R8R808:2PP1PH600EEEE0;Rh^02UYJD0Vi^K08F5Q@17AdL0D51@09RH
V02WYjL0TY:B0861P@2GUiL0ZJVY0:JVYP2FUYH0MGEe00805ADE00l051@D01<C4`0E5AD05aLG02HV
9P1OGel0Xj>S06m_K`0M7Ad092@T034a<@0o?cl0:2PX03/k>`1HF5P00`0E5AD07`0H61P0?Cdm07Yj
NP1<C4`07QhN01LG5`0H61P0=CDe09^KV`1CDe<0?3`l06i^KP2h^;P0NWYj04U9B@1hN7P0J6QX04=3
@`0];Bd0;Rh^02l_;`0e=CD0HF5Q0:NWY`2;Rh/0SXj>0;no_`27QhL0S8b<0;Vi^@3@d=004Oooool0
00oooooo02X0JFUY08R8R01@D500De=C05MGE`0h>3P0De=C08J6QP18B4P0H61P08n?S`1HF5P09BDU
03dm?@0h>3P0=CDe034a<@1fMWH0De=C03@d=01WIfL0>c/k07IfMP1FEUH0=CDe05QHF00_;bl0>CTi
07=cL`1YJFT0:BTY069RHP19BDT0@D5105QHF00d=3@0QHF506IVIP0Y:BT0ATI607EeM@10@40204m?
C`0801hN7P11@D40HV9R03Lg=`10@400=CDe05IFEP0g=cL204I6AP3/09^KV`21PH40C4a<02XZ:P25
QHD0HV9R02XZ:P1QHF40H61P03hn?P2QXJ40@D5102/[:`17AdL0MgMg038b<P12@T80>c/k04A4A027
QhL0Fe]K03@d=014A4@0O7al06EUI@1eMGD0DE5A08V9R@26QXH0=CDe059BDP1TI6@0FUYJ03Lg=`2M
WId0UiNG04A4A02?Shl0MGEe04Q8B02=SHd0UYJF04m?C`1QHF40MWIf07MgM`1DE5@0G5aL05IFEP0j
>SX0NGUi03lo?`1bLW80GEeM05aLG01JFUX0>SXj06][J`1CDe<0=3@d08n?S`0f=SH0LW9b06m_K`1[
Jf/0Ogmo04i>CP20P800Kfm_0410@018B4P0E5AD04E5A@1QHF40EUIF04m?C`1LG5`0J6QX0820P01:
BTX0M7Ad034a<@19BDT0KVi^055AD@2OWil0K6a/05ADE02d];@0N7Qh04E5A@2<S8`0E5AD05eMG@2K
Vi/0Kfm_05EEE@1IFET0E5AD03Xj>P1CDe<0Ph>305YJFP0f=SH0Kfm_04=3@`1/K6`0@410079bLP1f
MWH0J6QX0;Rh^02TY:@0Hf=S08b<S02FUYH0?3`l05IFEP2c/k<0S8b<04Y:BP1fMWH0]kNg06e]K@1H
F5P0Xj>S05]KF`2RXZ80]KFe08f=S@11@D40MGEe07IfMP0n?Sh0>3Ph02HV9P1lO7`0@d=3055AD@2:
RXX0CTi>0492@P1kNg/0;Rh^07MgM`1mOGd0Cdm?0;Bd]01KFe/0=CDe07alO01XJ6P0?Shn05ADE02H
V9P0De=C051@D02SXj<0VIVI07EeM@0];Bd0Y:BT08n?S`1eMGD08R8R065QH@26QXH0LG5a09>CT`1U
IFD0Bd];0=3@d02RXZ80D51@07AdM02=SHd0@T920820P02ATI40UIFE06i^KP1@D500OGem03dm?@1D
E5@0P82006IVIP1GEeL0IVIV075aL@1CDe<0Ng]k0492@P1iNGT0UIFE08Z:RP0j>SX0OWin0;Bd]01c
Lg<0=SHf06m_K`1WIfL0?Shn04A4A01lO7`0=cLg055AD@2h^;P0IfMW04A4A019BDT0Z:RX07IfMP0d
=3@0OGem03Ph>00];Bd0L71`07moO`0c<c<0OGem03Ti>@13@d<0Q8B408n?S`1:BTX0XZ:R04A4A00V
9RH0:BTY05]KF`1FEUH0RXZ:0410@01hN7PLooooo`0V06i^KP1lO7`0JVYZ04a<C01>CTh0_;bl0=3@
d02?Shl0EEEE05IFEP18B4P0A4A403Ti>@2PX:00U9BD0<O7a`2`/;00UYJF0:FUY@2GUiL0WYjN0:6Q
X@2JVYX0R8R806a/K01<C4`0ADE506MWI`2HV9P0Kfm_04U9B@1?Cdl0BTY:03dm?@0X:2P06a/K01DE
5@0F5QH201LG5`0D02`/;02j^[X0f][J0=SHf03Ng]h0f=SH0<S8b035aLD0eMGE0=WIf@3GemL0g=cL
0=WIf@0T92@0410@00h>3P0I6AT0Fe]K028R8P0A4A4300h>3P0@018B4P0?3`l07AdM0;2`/00f=SH0
8R8R01LG5`0H61P0D51@020P800E5AD071`L02DU9@0_;bl09RHV01LG5`805ADE08D05QHF01PH601G
EeL0SHf=055AD@1JFUX0ZJVY03dm?@10@400DE5A01PH600S8b<0AdM703@d=00a<C40Fe]K02DU9@0I
6AT06a/K05YJFP1fMWH0OWin03Xj>P1EEED0De=C06QXJ01cLg<0ATI607YjNP1GEeL0GemO0=3@d03N
g]h0`L710492@P0O7al09BDU03Hf=P19BDT0GUiN038b<P0^;Rh0:2PX034a<@0M7Ad0=3@d07UiN@20
P800clo?0<;2`P0o?cl0=cLg04];B`2:RXX0fMWI0>OWi`3YjNT0g]kN05mOG`1NGUh0=CDe05mOG`0o
?cl0D51@07=cL`2PX:00J6QX04Y:BP1fMWH0HV9R09ZJVP3<c<`0ZZZZ05QHF00n?Sh0=3@d05QHF026
QXH0>3Ph01`L700E5AD061PH02h^;P1HF5P0QXJ60<O7a`3IfMT0e]KF0;Vi^@1:BTX0=3@d01lO7`0V
9RH0:BTY08R8R02JVYX0a<C409jNWP0U9BD07alO02@T900S8b<0:2PX069RHP1iNGT0>SXj0:FUY@3M
gMd0^;Rh08n?S`2ATI40VIVI0;:b/P2i^KT0RHV904M7A`0P82008b<S07QhN031`L40PH610:>SX`2G
UiL0Z:RX0<S8b01PH600>3Ph05iNGP0E5AD0410@01DE5@0C4a<051@D00805ADE01P071`L02<S8`1:
BTX0I6AT024Q8@0^;Rh0a<C407]kN`1eMGD0aLG506e]K@2i^KT0U9BD06MWI`2VYZH0SHf=0:>SX`21
PH40QHF50::RXP1TI6@0K6a/059BDP0I6AT401DE5@0<01LG5`0O7al0FUYJ05ADE01GEeL0:BTY02<S
8`0l?3`0?clo02PX:019BDT0A4A40`0E5AD04P0F5QH09bLW06IVIP1bLW80:BTY02`/;01HF5P0M7Ad
07inOP24Q8@0XJ6Q0:JVYP1^KVh0?Shn034a<@1?Cdl0M7Ad06a/K080;bl_00/0A4A406e]K@1UIFD0
GUiN065QH@2GUiL0IfMW06UYJ@2QXJ40^KVi0<c<c00Aooooo`003oooool03@1VIVH0IFEU055AD@1^
KVh0IFEU04M7A`1?Cdl0Q8B40492@P1]KFd0TY:B06UYJ@0W9bL00P19BDT0=`1FEUH0:BTY06ATI01<
C4`0@T92051@D00P8200JVYZ05ADE00_;bl0De=C04=3@`0^;Rh0NWYj06ATI00U9BD0Fe]K061PH01>
CTh0Cdm?03Ph>02FUYH0IVIV038b<P1<C4`0Lg=c0492@P1?Cdl0E5AD020P801GEeL0Hf=S03De=@1;
Bd/0A4A404m?C`0j>SX0GEeM04U9B@1oOgl0Jf][04=3@`0i>CT0Z:RX07QhN00^;Rh0Jf][06IVIP10
@400Z:RX06IVIP0`<300Bd];06m_K`0];Bd00P1@D5006`13@d<0TY:B03hn?P0e=CD0IfMW071`L014
A4@0MgMg03/k>`1aLG40Q8B403Lg=`1OGel0KVi^04m?C`1<C4`0VIVI08B4Q012@T80Y:BT061PH00a
<C40IVIV08V9R@0j>SX0A4A4055AD@0206][J`0?061PH010@400D51@08B4Q01PH600R8R805IFEP21
PH40Ogmo04Y:BP1FEUH0EEEE04=3@`2?Shl0@D510080HV9R05h0P82009VIV@1GEeL0L71`05mOG`1F
EUH0JFUY08B4Q01MGEd0FUYJ03Xj>P1VIVH0N7Qh07AdM01[Jf/0@D51071`L01ADE40K6a/05mOG`13
@d<0XZ:R08:2PP12@T80/k>c04];B`19BDT0W9bL061PH018B4P0][Jf05UIF@1LG5`0IFEU079bLP15
ADD0HV9R0820P01NGUh0EUIF07inOP1JFUX0MGEe04A4A01]KFd0Hf=S05iNGP2QXJ40HV9R0492@P2?
Shl0Z:RX05IFEP2>SXh0^k^k0410@00g=cL0N7Qh09nOW`1MGEd0IfMW07=cL`1>CTh0Q8B40;bl_01g
MgL0>CTi07emO@1hN7P0@D5106YZJP0o?cl0S8b<03Lg=`1QHF40UiNG05QHF014A4@0MgMg03Ph>01S
Hf<0GemO04M7A`21PH40=cLg02TY:@1FEUH0@D5102h^;P1LG5`0Xj>S03Lg=`0/;2`0De=C0P1QHF40
C019BDT0_;bl09FEU@1mOGd092@T06a/K01iNGT0L71`075aL@1KFe/0@d=30=?Cd`2HV9P0C4a<07Ui
N@1MGEd0;bl_055AD@1>CTh0MWIf059BDP1@D500JVYZ02PX:00n?Sh0Ng]k05QHF01GEeL0HF5Q0451
@@0i>CT0A4A404a<C01]KFd0UiNG08N7Q`14A4@0JVYZ09:BTP1_Kfl0:BTY06UYJ@1RHV80<C4a06EU
I@2=SHd0@41004Y:BP25QHD0M7Ad0410@00e=CD0K6a/06m_K`0g=cL0N7Qh04Q8B00^;Rh0MGEe08F5
Q@0f=SH0N7Qh03`l?013@d<0QHF507IfMP1DE5@0]kNg05=CD`0_;bl0<C4a05YJFP1MGEd0OGem03lo
?`24Q8@Looooo`0I05iNGP1:BTX0?clo03<c<`0m?Cd0Rh^;0=GEe@3De=@0];Bd0;Jf]P2/[:`0Xj>S
0;Rh^039bLT0bl_;0;no_`1=CDd07alO096AT@32`/80LG5a03Xj>P0b<S80:b/[034a<@02038b<P07
07EeM@2PX:00KVi^03`l?00Z:RX06ATI01<C4`0301@D500901DE5@0C4a<04A4A01<C4`2IVIT0fMWI
0=KFeP31`L40];Bd0080/k>c00`0/K6a09ZJVP25QHD0TI6A0;bl_01`L7005ADE010@400e=CD0D51@
01LG5`0E5AD200h>3P803`l?00l0410@01dM7@3=cLd0ZZZZ051@D01:BTX0=cLg07AdM00H61P05ADE
01/K6`0N7Qh0:b/[04=3@`0m?Cd00P0G5aL0Q@0E5AD05QHF08F5Q@1eMGD0LW9b08n?S`1[Jf/0@T92
04A4A00n?Sh05ADE02DU9@0O7al09bLW01/K6`0N7Qh0>SXj03Hf=P0a<C40A4A40:>SX`0_;bl07AdM
03Lg=`0h>3P0BDU9071`L00F5QH0;Rh^03Ti>@1^KVh0d=3@0=WIf@1BDU80820P024Q8@0U9BD07AdM
01`L700T92@0=CDe02XZ:P0Y:BT0<30`03Hf=P0e=CD0B4Q80=SHf03Ph>00c<c<0:NWY`1eMGD0M7Ad
0<S8b030`<00a/K608Z:RP2PX:00TI6A03Xj>P1ADE407alO01TI6@0O7al0FEUI08R8R01mOGd0QXJ6
07=cL`0g=cL0?clo0:j^[P22PX80TI6A075aL@11@D40Cdm?04e=C@1oOgl0=3@d03/k>`1@D500JFUY
096AT@2TY:@0]kNg0=cLg03:b/X0CDe=06][J`1=CDd0Cdm?04e=C@2CTi<0Shn?03<c<`1VIVH0gMgM
09jNWP21PH40I6AT059BDP26QXH0Z:RX03lo?`1bLW80`/;209bLW02n_[h0U9BD0:^[Z`2k^k/0`L71
0;Bd]02GUiL0X:2P08N7Q`17AdL0`<300:6QX@2;Rh/0V9RH092@T03AdM40e]KF04i>CP29RHT0JFUY
01<C4`0D51@05ADE01<C4`0A4A400P0E5AD06`0I6AT0:2PX06m_K`0[:b/06a/K06MWI`2CTi<0RXZ:
0:RXZ03:b/X0aLG506QXJ02QXJ40e=CD0<?3``30`<00UIFE09nOW`1eMGD0?3`l02d];@10@400H61P
03De=@0C4a<05ADE018B4P0201DE5@0<01dM7@1JFUX0A4A4065QH@1ADE40:RXZ05YJFP0h>3P0:2PX
06e]K@0b<S805QHF0`0E5AD07P0N7Qh0G5aL09bLW026QXH0T92@07=cL`1DE5@0Hf=S06UYJ@33`l<0
aLG509NGU`0a<C4092@T02PX:021PH40UiNG08B4Q01ZJVX0IVIV04A4A00c<c<0A4A408^;R`2>SXh0
CDe=06ATI02?Shl0^[Zj08N7Qa7ooooo000?ooooo`0h069RHP1XJ6P0EUIF05UIF@1CDe<0?Shn05EE
E@1hN7P0A4A4059BDP1[Jf/0?clo038b<P1CDe<0=cLg04i>CP0b<S80G5aL03<c<`0d=3@0G5aL02l_
;`1ZJVX0>c/k038b<P1PH600>c/k0492@P2:RXX0F5QH02`/;01TI6@0B4Q804E5A@0W9bL0:2PX06i^
KP19BDT0820P06ATI01dM7@0<S8b04E5A@16ATH06a/K03lo?`1MGEd0:RXZ04a<C01ADE40?Shn02/[
:`14A4@0<C4a07alO01ZJVX203@d=00<07inOP11@D40=cLg06][J`18B4P0>3Ph08j>SP1;Bd/0>SXj
06MWI`1fMWH0>CTi0P17AdL0fP11@D40UYJF06UYJ@0g=cL0F5QH04a<C00U9BD0GemO059BDP2ZZZX0
KFe]03dm?@1ZJVX0NGUi04I6AP0g=cL0QXJ604U9B@0d=3@0P82007MgM`16ATH0L71`08V9R@1QHF40
E5AD04Y:BP1TI6@0LW9b05UIF@1EEED0@d=307AdM01:BTX0QXJ605EEE@1aLG40MGEe0410@01MGEd0
EEEE05MGE`23Ph<0=SHf04m?C`1KFe/0QHF508B4Q01FEUH0KVi^06MWI`15ADD0De=C075aL@1PH600
EeMG04=3@`1LG5`0KVi^071`L01fMWH0A4A406IVIP12@T80JFUY07=cL`1@D500QXJ607IfMP1;Bd/0
ZJVY06UYJ@0o?cl0Ti>C06EUI@1<C4`0a<C406ATI01<C4`0Cdm?06UYJ@13@d<0HF5Q07AdM017AdL0
GUiN05eMG@1CDe<0HF5Q03De=@1cLg<0O7al07=cL`2o_kl0HF5Q03dm?@28R8P0UYJF059BDP2l_;`0
a<C4096AT@14A4@0V9RH08^;R`0f=SH0UYJF09NGU`1>CTh0Rh^;0<;2`P1ZJVX0>c/k09nOW`29RHT0
=SHf04E5A@0e=CD0Y:BT04Q8B01BDU80TI6A05ADE015ADD0QHF505MGE`1eMGD0LW9b04a<C02;Rh/0
@d=303Xj>P1eMGD0DE5A03De=@1?Cdl0Ph>304M7A`0a<C40HV9R05IFEP11@D40=cLg0;Ng]`2NWYh0
H61P02HV9P1hN7P0Jf][05EEE@1TI6@0BTY:03Hf=P3:b/X0IfMW04e=C@21PH40Ogmo04U9B@1IFET0
D51@07alO01BDU80BTY:07moO`0g=cL0ATI608R8R01[Jf/0EUIF06m_K`1^KVh0FEUI05=CD`17AdL0
Ogmo09JFUP27QhL0=CDe05mOG`2;Rh/0GUiN03Hf=P2<S8`0IfMW06ATI01nOWh0XJ6Q0861P@0];Bd0
YjNW08F5Q@1ZJVX0?3`l07MgM`1@D500AdM709FEU@1LG5`0?3`l07YjNP1@D5009bLW07AdM00c<c<0
CTi>08j>SP1GEeL0Fe]K0;fm_@1ADE40;bl_03De=@1QHF40>c/k06UYJ@20P800UYJF7?ooool0>P1M
GEd0A4A404Y:BP17AdL0@D5103De=@1QHF40OWin03Xj>P0Y:BT0<30`04e=C@1lO7`0bl_;0;>c/`2g
]kL0>c/k020P8020P800Shn?03hn?P0L71`061PH01HF5P0G5aL05QHF01PH600_;bl0?Shn024Q8@0E
5AD04a<C018B4P0D51@04A4A01<C4`0B4Q8051@D01DE5@0C4a<09BDU0;Zj^P2SXj<0]kNg0=[JfP3;
bl/0MGEe06EUI@2KVi/0V9RH05UIF@11@D40@d=308R8R02?Shl0S8b<09fMW@0Z:RX201DE5@0E014A
4@0B4Q8092@T04U9B@1RHV80R8R8092@T02DU9@0Xj>S0:NWY`2j^[X0UIFE051@D00b<S807alO01LG
5`0I6AT08b<S05ADE01WIfL0>3Ph00806a/K01T0S8b<04m?C`26QXH0WYjN07alO01EEED0HV9R02l_
;`0F5QH0820P04M7A`16ATH0=CDe0451@@0g=cL0B4Q804E5A@1>CTh0FEUI01XJ6P0E5AD092@T02/[
:`11@D40MGEe008061PH02@09RHV051@D03GemL0^[Zj071`L00i>CT0CTi>02DU9@0J6QX05aLG01HF
5P0E5AD07alO038b<P18B4P0GEeM06=SH`2?Shl0RHV90:FUY@28R8P0DU9B06IVIP39bLT0`l?30:NW
Y`1mOGd0NGUi08:2PP1cLg<0Ph>305aLG00i>CT0:BTY01lO7`1ZJVX2055AD@0o07AdM01OGel0=SHf
05EEE@2FUYH0S8b<04];B`18B4P0HV9R08N7Q`2>SXh0VIVI0<?3``30`<00Xj>S0;6a/@2/[:`0Ti>C
08:2PP24Q8@0TY:B06ATI00W9bL0?clo08Z:RP2`/;00I6AT02HV9P0U9BD0;2`/09jNWP2;Rh/0VYZJ
0:VYZ@3Hf=P0g=cL0;Zj^P2VYZH0Ng]k03Ti>@0g=cL0Kfm_0:RXZ02[Zj/0S8b<08V9R@2=SHd0Vi^K
0::RXP2d];@0_kno0=cLg02e]KD0TI6A0;Ng]`3:b/X0TY:B0820P02?Shl0Fe]K03Hf=P0J6QX05aLG
00<05QHF01@051@D01HF5P0J6QX0FEUI03Xj>P0g=cL0GEeM04I6AP0U9BD0820P02`/;02CTi<0d=3@
0:BTY02GUiL0c<c<0<S8b02LW9`0Fe]K02@T90807QhN03H08R8R02TY:@0j>SX0EUIF03De=@0E5AD0
4a<C01DE5@0I6AT0<S8b07QhN01DE5@0Lg=c0<_;b`2TY:@0[Jf]069RHP1WIfL0ZJVY02DU9@0C4a<0
51@D02@T901<C4`0J6QX08B4Q02h^;P0Ph>306IVIP10@400:BTY03/k>`2ATI40[Zj^09VIV@1UIFD0
K6a/06i^KP1MGEd0V9RH0<G5a@31`L40TY:B06IVIP1/K6`0E5AD04];B`0^;Rh09RHV05iNGP20P800
W9bL0:ZZZP2_[jlAooooo`003oooool0<01OGel0TI6A05=CD`1iNGT0EUIF04M7A`1CDe<0SHf=059B
DP1PH600VYZJ069RHP0d=3@0CTi>04Y:BP1<C4`0;bl_06m_K`1@D500ATI606=SH`0/;2`0N7Qh05IF
EP0N7Qh0K6a/04M7A`18B4P0IfMW069RHP0O7al0C4a<05QHF01=CDd0DU9B034a<@1OGel0?Cdm01/K
6`14A4@0Jf][02l_;`0m?Cd0DE5A01/K6`0e=CD0Cdm?02`/;080CDe=05H0C4a<02h^;P1<C4`0=cLg
075aL@1nOWh0AdM70410@02?Shl0E5AD03<c<`1IFET0E5AD03<c<`2?Shl0D51@02h^;P1PH600NGUi
03Xj>P1<C4`0>c/k05UIF@2QXJ40F5QH03De=@1GEeL0FUYJ028R8P1=CDd0Bd];0:FUY@29RHT0>c/k
07UiN@1KFe/0=SHf03Lg=`24Q8@0F5QH03`l?022PX80D51@03lo?`1iNGT0K6a/04i>CP1NGUh0ATI6
04=3@`1HF5P0K6a/03Ti>@16ATH0LW9b051@D01gMgL0I6AT096AT@1dM7@0@T9207MgM`1XJ6P0EUIF
08:2PP0e=CD0O7al06EUI@2ATI40KVi^06=SH`2=SHd0Jf][04m?C`1HF5P0GemO06MWI`1mOGd0F5QH
07UiN@1ZJVX0YJFU07MgM`11@D40U9BD028R8P80Ogmo0540F5QH09jNWP1JFUX0LG5a0:ZZZP1cLg<0
B4Q8092@T00Q8B40>3Ph09>CT`26QXH0EEEE069RHP0n?Sh0JFUY0:2PX02VYZH0FUYJ07=cL`1RHV80
IfMW07=cL`0n?Sh0MGEe06EUI@1mOGd0bl_;08B4Q01XJ6P0WYjN07]kN`0i>CT0`L710:JVYP21PH40
HV9R0<G5a@2DU9@0?Shn09BDU01fMWH0IVIV0:RXZ033`l<0H61P02DU9@1IFET0Jf][02HV9P1;Bd/0
A4A40:j^[P1OGel0GUiN08n?S`0];Bd0=CDe09BDU02BTY80LG5a061PH00e=CD0QHF504a<C00h>3P0
JVYZ04=3@`0a<C40Lg=c09:BTP1DE5@0@T9206UYJ@1@D500J6QX04a<C02k^k/0P82007emO@0Y:BT0
0P1SHf<0:@1KFe/0W9bL06][J`13@d<0`<3008Z:RP1LG5`0YjNW09:BTP15ADD0Ph>307=cL`29RHT0
9bLW061PH02JVYX0EEEE075aL@2WYjL0=SHf06YZJP27QhL0LG5a06][J`1OGel0=cLg055AD@22PX80
EEEE04=3@`1cLg<0Shn?0451@@0E5AD0HV9R05mOG`1nOWh0UiNG092@T014A4@0:BTY0080TI6A01X0
Jf][04e=C@2?Shl0?Shn02DU9@1[Jf/0=SHf02d];@1YJFT0MgMg02`/;01lO7`0?Shn03`l?022PX80
IFEU09BDU03Fe]H0MgMg03Ti>@0M7Ad0F5QH04=3@`0S8b<0?Shn06YZJQcooooo07L0C4a<0410@014
A4@0>CTi02h^;P0V9RH08R8R04];B`0K6a/05QHF01@D500E5AD0:BTY092@T02HV9P0bl_;06YZJP1U
IFD0PX:205QHF01_Kfl06a/K01@D500A4A405ADE01@D500W9bL0GEeM06QXJ00J6QX04a<C014A4@0>
3Ph04Q8B01DE5@0H61P08b<S02/[:`0a<C40BTY:0:n_[`3:b/X0c/k>0>7Qh@2o_kl0Shn?07IfMP0^
;Rh0:2PX07]kN`1hN7P0<30`03<c<`1ADE40XZ:R0=3@d03<c<`0X:2P02l_;`0R8R80@41006QXJ01c
Lg<0@D5102TY:@0P82007alO03Lg=`0i>CT0Kfm_0<;2`P2j^[X0JFUY05ADE01XJ6P0CTi>03Hf=P0_
;bl0820P04=3@`26QXH0N7Qh05QHF02HV9P0TY:B05IFEP13@d<0CTi>04A4A02KVi/0FEUI03Lg=`11
@D40]KFe07]kN`0n?Sh0;Rh^02`/;00d=3@0<c<c03Lg=`0e=CD05aLG01HF5P0g=cL0?Shn05MGE`2b
/[809RHV01HF5P0H61P0GUiN0<W9b@2c/k<0Q8B4059BDP1EEED09BDU01LG5`0201DE5@0j01<C4`0E
5AD05ADE05aLG03>c/h0YZJV09:BTP26QXH0Lg=c08R8R035aLD0/k>c0;:b/P2f][H0YJFU04U9B@1?
Cdl0Zj^[051@D01[Jf/0=SHf0410@01GEeL0L71`0;Rh^011@D40CDe=06ATI01oOgl0QhN704Y:BP0Y
:BT08R8R03<c<`1NGUh0DU9B07EeM@2OWil0NGUi0<G5a@34a<@0g=cL07inOP2?Shl0S8b<05ADE00^
;Rh07AdM06ATI02PX:00UIFE09>CT`2@T900@D5103Lg=`0Y:BT0De=C02@T90805QHF03@06QXJ02TY
:@2h^;P0f=SH04=3@`0[:b/0;Bd]01TI6@0Q8B40D51@09^KV`2OWil0I6AT03dm?@0_;bl0=CDe05MG
E`3GemL0T92@06=SH`2_[jl0clo?0:n_[`1/K6`0;Bd]0<W9b@35aLD0]kNg0:NWY`2EUID0QhN707Ui
N@1cLg<0MGEe08F5Q@2GUiL0S8b<08f=S@1/K6`0>c/k02PX:00R8R808B4Q03@d=02JVYX0EUIF05]K
F`0O7al0BDU90;2`/02<S8`0>SXj0`0L71`04@0O7al08B4Q02l_;`0i>CT0K6a/05=CD`1=CDd0IfMW
0820P02DU9@0aLG50<30`02o_kl0V9RH0<;2`P2l_;`0b<S80080f][J00@0Fe]K02<S8`1/K6`0MgMg
0P1?Cdl04`1MGEd0VIVI0:6QX@1EEED0?Shn02l_;`1MGEd0RXZ:08B4Q00l?3`0:BTY03Lg=`0h>3P0
BDU909FEU@1>CTh0PH6109bLW00N7Qh00P0I6AT0200N7Qh08B4Q02<S8`1DE5@0MWIf09bLW02IVIT0
SHf=4Oooool000oooooo00d0IVIV096AT@1FEUH0NWYj05=CD`15ADD0Bd];08Z:RP1>CTh0HF5Q09^K
V`1PH600=3@d0080D51@0140F5QH03dm?@23Ph<0GemO03dm?@1cLg<0;bl_07moO`1>CTh061PH061P
H015ADD0FEUI06i^KP1NGUh071`L055AD@0205]KF`1K04=3@`0/;2`0IVIV03Xj>P0Q8B40E5AD05iN
GP0];Bd0B4Q805UIF@0J6QX0AdM705IFEP0`<300Cdm?0451@@0i>CT0=CDe04Y:BP0V9RH0J6QX07Yj
NP19BDT0B4Q809BDU01:BTX0=SHf061PH01IFET0>c/k092@T01HF5P0=3@d059BDP20P800>CTi04Y:
BP10@400GEeM08^;R`1DE5@0@T9206a/K01FEUH0:2PX05YJFP0F5QH0=cLg07moO`0h>3P0PH6105=C
D`0b<S80D51@09jNWP1:BTX0<c<c07EeM@0e=CD0@T920;6a/@2<S8`0E5AD05iNGP1;Bd/0IfMW01PH
601YJFT0HF5Q0492@P1DE5@0:2PX08R8R01OGel0T92@03lo?`0V9RH0JFUY04m?C`1ADE40KVi^01HF
5P1QHF40E5AD08^;R`1XJ6P0?Cdm06UYJ@17AdL0B4Q805YJFP0202DU9@2S051@D01:BTX0MgMg03`l
?01EEED0HF5Q03dm?@1oOgl09BDU04Y:BP1TI6@0IFEU0;no_`1PH600EEEE09^KV`1SHf<0GemO09RH
V01ADE408R8R05UIF@1NGUh0J6QX07emO@0_;bl0<C4a04U9B@1dM7@0EeMG08B4Q016ATH0?Cdm08n?
S`16ATH0Ogmo02TY:@0];Bd0R8R806m_K`1NGUh0W9bL07UiN@1[Jf/0Y:BT0:JVYP1:BTX0G5aL0:n_
[`2EUID0B4Q809fMW@1UIFD0D51@07alO02YZJT0OWin04a<C01RHV80Shn?03Ph>01:BTX0<c<c08Z:
RP1CDe<0Lg=c0;6a/@1<C4`0;2`/061PH00b<S80KFe]06m_K`0n?Sh0KFe]02LW9`0g=cL0WIfM04U9
B@0J6QX0@41007EeM@1LG5`0=CDe07QhN01<C4`0DU9B0451@@36a/H0`L7109NGU`0W9bL0GemO03dm
?@19BDT0SXj>06UYJ@15ADD0Vi^K0:b/[01:BTX0KFe]04=3@`0b<S80GemO06MWI`1jNWX0@d=303/k
>`1QHF40Fe]K07IfMP2:RXX0@d=303/k>`1IFET09bLW06YZJP1fMWH0De=C07inOP1kNg/0CTi>02/[
:`19BDT0M7Ad05IFEP0J6QX0J6QX0451@@1?Cdl0GEeM06m_K`1FEUH09bLW0:n_[`29RHT0CDe=02l_
;`1]KFd0MGEe03<c<`1bLW80AdM703@d=01[Jf/0IfMW034a<@1hN7P0>CTi03`l?02:RXX0DU9B07Ee
M@2UYJD0M7Ad03De=@0Q8B40BTY:05MGE`0Y:BT0CDe=09BDU00Looooo`11051@D00l?3`0>CTi030`
<00Y:BT07QhN01/K6`1;Bd/0;Rh^01DE5@0C4a<04Q8B01PH601oOgl0bl_;0=WIf@2d];@0_;bl0:ZZ
ZP2>SXh0/[:b08J6QP1;Bd/0ATI60451@@0h>3P0;bl_01dM7@0d=3@0B4Q803@d=00l?3`0AdM7065Q
H@1[Jf/0GUiN06UYJ@1SHf<0HV9R09NGU`3=cLd0][Jf08B4Q01fMWH0Z:RX08Z:RP1jNWX0FUYJ02@T
900o?cl0PX:2055AD@0Z:RX08b<S03Ph>01UIFD0Y:BT0<[:bP2d];@0WYjN06EUI@0m?Cd08R8R01hN
7P0P82000P0Y:BT0=00k>c/0S8b<0;Ng]`2^[Zh0D51@08f=S@27QhL0C4a<05UIF@1VIVH0CDe=03dm
?@13@d<0FEUI08V9R@37alL0bLW90:6QX@13@d<0AdM703<c<`0o?cl0?Shn01DE5@0D51@05ADE05AD
E01fMWH0H61P04A4A00b<S80;2`/02d];@0o?cl0>c/k01lO7`0F5QH0>SXj08f=S@3@d=00dM7A0:f]
[@1kNg/0C4a<08b<S02e]KD0dm?C08^;R`1DE5@09bLW01hN7P0J6QX301DE5@1`01<C4`0F5QH0J6QX
0410@00d=3@0EeMG08n?S`2;Rh/0Ogmo0=cLg03?cll0Jf][06i^KP2o_kl0DE5A05EEE@2h^;P0[Jf]
06a/K00Z:RX09BDU030`<00c<c<0PX:207inOP18B4P0HV9R08B4Q01?Cdl08B4Q01/K6`0N7Qh08B4Q
02@T901@D500`L710:ZZZP3Cdm<0]kNg0<30`035aLD0TI6A05UIF@0c<c<08B4Q01LG5`0E5AD08b<S
07=cL`3AdM40JFUY02/[:`1CDe<0QHF508^;R`1lO7`06QXJ01DE5@0G5aL05QHF024Q8@2PX:00cLg=
04I6AP0i>CT07AdM02l_;`0[:b/0@d=307alO02JVYX0Fe]K02PX:016ATH0O7al09NGU`3;bl/0YJFU
09jNWP2:RXX0GEeM07MgM`2MWId0Ng]k0<K6aP2e]KD0UYJF06EUI@0j>SX0;Rh^02/[:`0b<S80<c<c
04Y:BP2?Shl0a/K6075aL@12@T80=3@d02LW9`0S8b<08B4Q04i>CP1cLg<0<30`05UIF@0L71`0<c<c
06][J`2l_;`0JVYZ01hN7P8071`L02`0820P02@T900Y:BT0=SHf08V9R@3AdM40S8b<075aL@1_Kfl0
YJFU07emO@24Q8@0XZ:R0:b/[038b<P0clo?0=OGe`2MWId0VYZJ0<k>cP2][Jd0IVIV04E5A@1@D500
EeMG05aLG01dM7@0TY:B09NGU`1jNWX0EUIF09BDU033`l<0V9RH02XZ:P0/;2`0<S8b04M7A`0/;2`0
PX:208n?S`34a<@0UiNG01/K6`806ATI00P07AdM01hN7P0`<300GUiN09JFUP2EUID0CTi>08Z:RQ7o
oooo000?ooooo`0g08R8R02?Shl0F5QH07IfMP1TI6@0A4A404Y:BP1jNWX0CDe=07YjNP2HV9P0De=C
03De=@1CDe<0FUYJ075aL@0k>c/0NGUi05YJFP1@D500RXZ:03dm?@2=SHd0DU9B065QH@1iNGT0@D51
04i>CP1XJ6P0C4a<03<c<`1dM7@0E5AD05aLG00X:2P0G5aL0:>SX`1;Bd/0;Bd]05IFEP1ZJVX0<c<c
03hn?P18B4P092@T079bLP1OGel0<30`051@D01>CTh07AdM04=3@`1RHV80=SHf06ATI00203hn?P2^
08F5Q@2ATI40BTY:03Hf=P1PH600;bl_04e=C@2:RXX0H61P03dm?@1MGEd0IFEU0410@01VIVH0IfMW
06i^KP2=SHd0;bl_024Q8@1CDe<0E5AD03<c<`1=CDd0DE5A09RHV01`L700>3Ph08F5Q@1GEeL04a<C
02PX:01IFET0KVi^038b<P1jNWX0<30`02TY:@1WIfL0L71`04E5A@1gMgL0IfMW07IfMP14A4@0DU9B
02h^;P1GEeL0Fe]K02l_;`1`L700ADE509BDU01GEeL09BDU04U9B@0a<C40G5aL06i^KP0Z:RX0BTY:
03/k>`2BTY80JVYZ04A4A01ADE40@T92055AD@1VIVH0GemO04U9B@17AdL0=3@d06m_K`1UIFD0MWIf
05ADE00b<S80K6a/0492@P1SHf<0JFUY05MGE`2:RXX0GemO05EEE@2EUID0De=C0492@P1kNg/0Hf=S
024Q8@1ZJVX0FUYJ04];B`1EEED0FEUI03dm?@1GEeL0ADE50451@@2<S8`0@41003`l?01HF5P0=SHf
06IVIP1=CDd0GEeM09>CT`0o?cl0;Bd]092@T02<S8`0UIFE09JFUP2XZ:P0MGEe07=cL`2o_kl0XZ:R
051@D02[Zj/0TY:B06][J`1_Kfl0Z:RX09:BTP1LG5`0Lg=c06a/K00o?cl0Hf=S04E5A@2?Shl0<C4a
04U9B@2=SHd0LW9b04Y:BP2;Rh/0Jf][075aL@1hN7P0A4A408f=S@0g=cL0A4A405eMG@19BDT0;2`/
04a<C020P800?Cdm034a<@2IVIT0NGUi065QH@0Q8B40FEUI06IVIP1aLG40;Bd]05eMG@19BDT0CDe=
06UYJ@0e=CD07alO06ATI01`L700De=C08n?S`1QHF40A4A40P1XJ6P0>@1cLg<0DU9B059BDP1gMgL0
G5aL05EEE@2>SXh0Jf][04Q8B024Q8@0FUYJ075aL@1HF5P0?Shn09NGU`1mOGd0Fe]K03<c<`1DE5@0
NWYj059BDP0S8b<0SXj>05EEE@1OGel0NWYj07MgM`0m?Cd0=CDe0:>SX`22PX80HV9R02h^;P1NGUh0
EEEE055AD@2:RXX0Fe]K038b<P1WIfL0IVIV03<c<`1`L700?clo0451@@2[Zj/0JVYZ07EeM@2n_[h0
DU9B02/[:`0R8R80AdM704E5A@0Y:BT0RXZ:0:6QX@0Looooo`1P04U9B@0g=cL0=CDe02TY:@0Z:RX0
8R8R01dM7@0d=3@0F5QH01LG5`0C4a<05ADE02d];@2RXZ80fMWI0<S8b02e]KD0clo?06EUI@1fMWH0
R8R808>3P`0g=cL07AdM01lO7`0Q8B40>CTi06ATI01fMWH0RHV908>3P`1aLG40GEeM04i>CP0i>CT0
:RXZ02TY:@0U9BD06a/K04];B`2VYZH0<S8b024Q8@0N7Qh0;Bd]08V9R@2CTi<0RHV906EUI@11@D40
UIFE0<K6aP2=SHd0CTi>03/k>`0[:b/0NWYj0<30`02UYJD0@D5103Lg=`0i>CT0ATI605YJFP1SHf<0
IFEU05mOG`1[Jf/0JVYZ08B4Q02SXj<0K6a/03De=@1UIFD0WinO09BDU01VIVH0GemO079bLP1JFUX0
?Shn05aLG02QXJ40f][J06a/K00f=SH0>SXj034a<@19BDT06QXJ018B4P0E5AD06ATI028R8P1ADE40
Bd];0P0M7Ad201`L700E01lO7`0[:b/0<S8b01lO7`20P800cLg=0:RXZ01kNg/0DE5A07IfMP2][Jd0
f][J0=gMg@2h^;P0UYJF08Z:RP0[:b/06ATI01`L700J6QX061PH00805aLG03P0:BTY075aL@0R8R80
7alO04];B`14A4@0AdM705UIF@30`<00d=3@065QH@14A4@0SHf=08:2PP1HF5P0X:2P05eMG@1IFET0
:BTY02DU9@0T92@0:RXZ05eMG@2[Zj/0MgMg08R8R01RHV80GemO02TY:@0H61P06ATI028R8P0W9bL0
9RHV08V9R@35aLD0^[Zj07YjNP2LW9`0PH6102/[:`0W9bL0:BTY02<S8`0G5aL06ATI01XJ6P1TI6@0
dM7A0:VYZ@1oOgl0@41008Z:RP34a<@0NGUi02<S8`805QHF04`071`L0451@@1_Kfl0c<c<04e=C@0R
8R80820P02<S8`0G5aL0?Shn04A4A02b/[80`<300;^k^`1]KFd0TY:B0;Rh^02k^k/0_kno04i>CP0M
7Ad0820P04M7A`1mOGd0/;2`0=OGe`1bLW80Ng]k09JFUP1SHf<0>3Ph03Xj>P0i>CT0@T9205aLG02h
^;P0P8200<30`038b<P0U9BD06m_K`15ADD0>c/k08^;R`0i>CT0;2`/05eMG@0b<S80ATI6055AD@3B
d]80EEEE02h^;P0O7al06a/K02@T900W9bL0<30`06a/K02IVIT0[jn_07alO01oOgl0SHf=069RHP1_
Kfl0Vi^K09bLW02o_kl0WYjN0<?3``24Q8@0T92@09VIV@2c/k<0_;bl0P2SXj<03P2QXJ40JVYZ055A
D@0W9bL0<30`02DU9@1LG5`0Ti>C07EeM@1VIVH0MGEe05=CD`0m?Cd0>3Ph0P0e=CD03`2ATI40e=CD
0=kNgP3De=@0GEeM01XJ6P0M7Ad06QXJ01lO7`1;Bd/0NGUi075aL@1?Cdl0Lg=c079bLP0Aooooo`00
3oooool0EP1JFUX0EUIF065QH@16ATH0CDe=03hn?P1UIFD0Cdm?02DU9@19BDT0GUiN03Lg=`16ATH0
AdM702d];@13@d<09RHV04i>CP0K6a/0<S8b05MGE`0_;bl0OGem02<S8`0a<C40EEEE03Ph>01FEUH0
R8R805ADE00K6a/0AdM703/k>`1NGUh09BDU024Q8@1KFe/0;bl_02LW9`1/K6`0CDe=03De=@0L71`0
>c/k01LG5`0l?3`0@D5101dM7@13@d<0@T9202`/;00d=3@0>3Ph01dM7@1hN7P0E5AD02l_;`0o?cl0
I6AT03Ti>@0g=cL0EEEE02/[:`0a<C40Fe]K04a<C00i>CT0Fe]K06a/K00[:b/08R8R03Ti>@1<C4`0
Shn?04Y:BP0];Bd0ADE502/[:`0e=CD0F5QH04m?C`2FUYH0GUiN04M7A`1lO7`0Jf][0P0^;Rh0?`1O
Gel0ATI603`l?02;Rh/0FEUI03@d=024Q8@0NWYj03<c<`1LG5`0AdM706EUI@1JFUX0HV9R03dm?@16
ATH0H61P04E5A@1]KFd0@41007AdM01NGUh0:BTY05UIF@1?Cdl0DE5A07moO`0f=SH0DU9B06ATI02:
RXX0MGEe055AD@27QhL0EeMG0410@01QHF40LW9b065QH@1DE5@0Cdm?07UiN@1SHf<0L71`07UiN@0h
>3P0@d=302/[:`1YJFT0NGUi08J6QP2`/;00Fe]K05aLG02JVYX0GEeM04i>CP2?Shl0IfMW02l_;`1?
Cdl0Bd];059BDP02061PH02903lo?`1EEED0MgMg04a<C02=SHd0<C4a05=CD`1IFET0=3@d05eMG@1a
LG40MWIf0:FUY@1EEED0DU9B08V9R@2@T900U9BD08>3P`2LW9`0LG5a08^;R`2n_[h0Q8B4059BDP2`
/;00NGUi06MWI`1`L700YjNW065QH@23Ph<0VYZJ07QhN00j>SX0DE5A03<c<`21PH40ADE505=CD`2>
SXh0Fe]K05QHF02][Jd0SHf=07EeM@1SHf<0@d=308Z:RP1?Cdl0ATI606i^KP1IFET0ATI605eMG@2@
T900DU9B02@T901ADE40F5QH05IFEP1>CTh0_Kfm096AT@22PX807QhN04I6AP17AdL0GEeM079bLP1E
EED0:b/[04e=C@1YJFT0De=C09RHV01[Jf/0?Cdm06ATI01VIVH0IfMW03Ti>@1YJFT0T92@0451@@1@
D500Shn?06ATI01?Cdl0WIfM06i^KP1cLg<0G5aL03<c<`2PX:00Xj>S069RHP0^;Rh0E5AD06m_K`0m
?Cd0@d=309BDU01RHV80FUYJ06MWI`2;Rh/0Ogmo02/[:`2i^KT0PX:204M7A`0a<C40H61P05ADE00^
;Rh0F5QH04e=C@0a<C40Q8B4079bLP0e=CD0HF5Q02<S8`0n?Sh0UiNG05EEE@1bLW80YjNW05EEE@0Z
:RX0D51@06IVIP0c<c<05ADE05MGE`26QXH07?ooool03`1MGEd0BTY:030`<00X:2P09RHV024Q8@0M
7Ad08R8R08N7Q`0O7al08B4Q05eMG@2UYJD0ZZZZ0<[:bP020<g=c@0C0<W9b@2][Jd0UYJF07EeM@14
A4@0QhN707alO023Ph<0T92@07alO01FEUH0G5aL06i^KP1IFET0BTY:038b<P0O7al06ATI01HF5P02
01PH600G01DE5@1GEeL0AdM701dM7@0K6a/06ATI01XJ6P0_;bl0OGem0:^[Z`30`<00`l?30<K6aP3?
cll0b<S80:JVYP22PX80FUYJ07MgM`3@d=00Ti>C03lo?`19BDT00P1HF5P0aP1QHF40B4Q803@d=00W
9bL0EeMG0410@018B4P0>SXj06e]K@0j>SX09bLW03De=@1GEeL0RHV90::RXP2EUID0QhN709RHV02C
Ti<0f][J0=7Ad@1XJ6P0M7Ad096AT@2?Shl0P82001TI6@0K6a/05QHF01DE5@0M7Ad0:BTY04M7A`0R
8R806a/K01`L700K6a/071`L03Hf=P1WIfL0Ph>30:FUY@20P800Jf][04A4A010@400>3Ph0410@038
b<P0g]kN0;Fe]@1gMgL0C4a<06QXJ01DE5@0;Bd]01TI6@0L71`07AdM02DU9@1WIfL0@41003Hf=P19
BDT0GemO04Y:BP0U9BD0:BTY05IFEP2DU9@0?Shn02/[:`1aLG40^;Rh065QH@1KFe/0D51@03hn?P17
AdL0;Bd]02<S8`0Y:BT0@T920:RXZ02NWYh0IVIV02DU9@1QHF40BDU901lO7`0J6QX06a/K02PX:00O
7al0>SXj07moO`2;Rh/0IVIV04m?C`1FEUH07alO02HV9P0/;2`08B4Q01HF5P0G5aL06QXJ08B4Q01Q
HF40<c<c069RHP36a/H0eMGE0:f][@1_Kfl0@d=301dM7@0Q8B40DE5A02DU9@0o?cl0bl_;03De=@0L
71`061PH01DE5@0G5aL0A4A40451@@1LG5`0f=SH0>7Qh@3;bl/0Vi^K07MgM`2<S8`0EUIF01dM7@0L
71`07QhN05ADE01QHF40Ng]k0820P02GUiL0UYJF09bLW033`l<0NWYj05UIF@1?Cdl0GEeM09nOW`2M
WId0Ph>308N7Q`2;Rh/0T92@0::RXP2c/k<0bl_;0<?3``0T92@0;2`/05=CD`2NWYh0TY:B06m_K`2j
^[X0_Kfm07alO01RHV80;bl_028R8P0a<C40PX:20=7Ad@2i^KT0[jn_09:BTP1DE5@0:RXZ038b<P1^
KVh0e]KF09fMW@1]KFd0Zj^[05mOG`1]KFd0GemO05YJFP2WYjL0^;Rh08f=S@2DU9@0Vi^K0;Vi^@80
ATI601/0D51@05QHF01KFe/0Ng]k0:>SX`2FUYH0Shn?0:b/[01ZJVX0BDU9059BDP1]KFd0VYZJ0;Fe
]@2:RXX0S8b<0;Bd]01hN7P0:BTY01hN7P0j>SX0HF5Q07UiN@0n?Sh0Bd];06i^KP0`<3004Oooool0
00oooooo0:<0Hf=S05mOG`1DE5@0JVYZ04a<C00d=3@0B4Q806YZJP0f=SH0LW9b06ATI00S8b<0:RXZ
04I6AP12@T808B4Q02DU9@1]KFd0@410038b<P0l?3`09BDU07YjNP19BDT0A4A403<c<`0R8R80>c/k
06YZJP1EEED07AdM04m?C`0n?Sh0ATI604=3@`0V9RH0IFEU02h^;P0W9bL0FEUI05YJFP0Y:BT0;2`/
03@d=00J6QX0?3`l04e=C@0d=3@0AdM703lo?`16ATH0@T9205IFEP0i>CT0JVYZ06e]K@0n?Sh0FUYJ
07EeM@0^;Rh0>SXj06EUI@19BDT0=cLg06ATI00[:b/0=cLg06QXJ01iNGT0?clo03Lg=`1<C4`0Fe]K
08:2PP1NGUh0E5AD06ATI01<C4`0DE5A04Y:BP16ATH0Y:BT05YJFP0f=SH0MWIf05QHF00h>3P0@d=3
08Z:RP13@d<0;Rh^06e]K@12@T80>3Ph0:NWY`2CTi<0DU9B06UYJ@1<C4`0JVYZ05UIF@1hN7P0ATI6
04a<C01lO7`0DE5A075aL@1DE5@0N7Qh075aL@0b<S80Hf=S05UIF@1OGel0QXJ603hn?P1DE5@0H61P
08B4Q01EEED0F5QH0820P01CDe<0@d=305MGE`1TI6@0J6QX05IFEP16ATH0SHf=05aLG01aLG40NGUi
03hn?P1>CTh0:BTY06EUI@1aLG40Shn?0:ZZZP1PH600JVYZ0:VYZ@1LG5`0F5QH09bLW01]KFd0>3Ph
05EEE@1FEUH0CDe=05aLG01TI6@0@d=305]KF`25QHD0?Shn08V9R@1<C4`0EeMG0820P01>CTh0H61P
0080Lg=c04h0UiNG04i>CP17AdL0TY:B079bLP2?Shl0YJFU0:b/[01/K6`0WinO0<71`@1]KFd0@d=3
0:JVYP1YJFT0RHV909:BTP2WYjL0RHV907IfMP1>CTh0DE5A03<c<`1JFUX0?Cdm07inOP1MGEd0Kfm_
0;2`/01<C4`0BDU908j>SP1VIVH0P82005aLG01=CDd0N7Qh02h^;P10@400SHf=04i>CP0S8b<0JFUY
0:FUY@1TI6@0<30`05UIF@1?Cdl0IFEU06][J`3@d=00`l?309fMW@0Y:BT0HV9R04I6AP1OGel0S8b<
07MgM`0j>SX0@d=308F5Q@19BDT0R8R807UiN@0i>CT0Kfm_07AdM02>SXh0GemO05MGE`26QXH0@410
05]KF`2JVYX0>CTi04M7A`2WYjL207=cL`0]05]KF`0b<S80OGem07UiN@1RHV80<30`051@D01_Kfl0
ATI6020P801lO7`0G5aL07emO@2RXZ80Ti>C07EeM@0];Bd0`L7107AdM00U9BD0;bl_05]KF`1EEED0
<C4a04Y:BP0l?3`0:RXZ069RHP1`L700:b/[06][J`10@400<c<c08^;R`1;Bd/0J6QX08j>SP1^KVh0
=3@d01PH600n?Sh0CDe=01LG5`0n?Sh0MWIf01cooooo00D0I6AT04];B`0n?Sh0;Rh^02HV9P0201dM
7@0I024Q8@2CTi<0[Jf]0:NWY`22PX80HF5Q07MgM`1aLG40b<S80=cLg032`/80UiNG0820P01iNGT0
>CTi02XZ:P2f][H0];Bd06][J`1iNGT0HV9R04M7A`1FEUH0CDe=02TY:@0201XJ6P0701PH600J6QX0
6a/K01LG5`0a<C40IFEU02PX:00201`L700:01PH600F5QH061PH02l_;`1NGUh0^k^k0>7Qh@36a/H0
cLg=092@T080DU9B00P0K6a/0:JVYP37alL0WYjN04Y:BP0h>3P0:2PX02<S8`8071`L07X07AdM03lo
?`0`<3009bLW01lO7`0I6AT09RHV05iNGP0I6AT08R8R02LW9`0c<c<0B4Q8075aL@2PX:00alO70<g=
c@3IfMT0inOW0<O7a`2i^KT0UIFE09NGU`1JFUX0<c<c01hN7P0E5AD05QHF01dM7@0R8R808b<S02l_
;`0K6a/06ATI01/K6`0Q8B40<c<c08V9R@2IVIT0WIfM04U9B@0I6AT0<C4a03lo?`14A4@0MWIf0:ZZ
ZP3?cll0b<S806YZJP0c<c<0;bl_03`l?01JFUX0Hf=S038b<P0O7al0=SHf079bLP12@T80FUYJ0820
P01=CDd0<C4a02DU9@0^;Rh0>CTi07emO@0k>c/0;2`/04I6AP2TY:@0_kno09jNWP2IVIT0>SXj03lo
?`14A4@0?clo0410@01IFET0Z:RX09jNWP0l?3`07QhN03De=@1CDe<0=CDe01HF5P0H61P05aLG01/K
6`0i>CT0?Shn06ATI01KFe/0BTY:05MGE`0Q8B40:BTY034a<@0M7Ad05ADE01LG5`0K6a/0L71`02l_
;`0M7Ad092@T0;Vi^@3Bd]80L71`03lo?`1bLW80QHF506=SH`0`<3006a/K03De=@2CTi<0:BTY01LG
5`805ADE04/08B4Q04Q8B00n?Sh0DU9B0<k>cP1bLW80;Bd]01hN7P0O7al0BTY:02@T900J6QX071`L
02HV9P0e=CD05QHF05eMG@1ADE40@41007AdM01fMWH0IFEU075aL@1_Kfl0IFEU07moO`2c/k<0R8R8
0:n_[`32`/80T92@06MWI`0m?Cd0<c<c0492@P2QXJ408b<S02TY:@1RHV80bl_;05ADE00c<c<0Xj>S
04e=C@0];Bd0@d=308>3P`1^KVh0ZJVY0=?Cd`3Kfm/0clo?09nOW`13@d<05QHF01TI6@0X:2P0De=C
08J6QP1?Cdl0VYZJ0<;2`P24Q8@0CDe=051@D01DE5@0OGem08V9R@1kNg/0NWYj06i^KP2l_;`0T92@
03Lg=`0N7Qh00P0I6AT06013@d<0Lg=c0451@@1lO7`0^k^k0:b/[02;Rh/0];Bd0<g=c@2f][H0GEeM
01dM7@0X:2P0G5aL0:JVYP2UYJD0EUIF06][J`2ZZZX0?clo0410@01=CDd0SHf=061PH17ooooo000?
ooooo`0Z06YZJP2;Rh/0GUiN07QhN01MGEd0@T9204M7A`1UIFD0:b/[05QHF01iNGT0?3`l03dm?@18
B4P0CTi>05mOG`0[:b/0Ng]k06IVIP15ADD0J6QX02TY:@1nOWh0GemO04=3@`1;Bd/0?Cdm04Q8B01^
KVh0C4a<02@T901OGel0JFUY05MGE`11@D40;Bd]08>3P`17AdL0>CTi07QhN01/K6`0;bl_0P19BDT0
DP0X:2P0EeMG06m_K`0j>SX0DE5A0410@00^;Rh0EUIF06UYJ@0f=SH0GUiN04Y:BP0l?3`0NWYj08F5
Q@1=CDd0;Bd]06MWI`1UIFD0>SXj07alO01QHF40<C4a06YZJP1]KFd0@T9204a<C01OGel0JVYZ08:2
PP11@D40?Cdm059BDP17AdL0DU9B05QHF01BDU80NGUi05YJFP0k>c/0PH6105YJFP0m?Cd0AdM7096A
T@1DE5@0>SXj07AdM00i>CT0<S8b07MgM`1hN7P0@41007UiN@25QHD0MGEe04U9B@1ZJVX0ADE505iN
GP1bLW80BTY:07IfMP1=CDd0NWYj06UYJ@13@d<0J6QX04U9B@1/K6`0LG5a0492@P1YJFT0F5QH08F5
Q@1BDU80BTY:07MgM`1:BTX0DE5A06IVIP1=CDd206MWI`2R04E5A@2GUiL0JFUY08:2PP1/K6`0Cdm?
07QhN00Y:BT0LW9b06EUI@2:RXX0^[Zj05YJFP1nOWh0V9RH065QH@1/K6`0TY:B03@d=011@D40NWYj
06=SH`1CDe<0Lg=c0410@01FEUH0OGem06EUI@0n?Sh0TI6A0410@01lO7`0Hf=S04Y:BP1WIfL0F5QH
071`L02XZ:P0EeMG05=CD`2a/K40Lg=c06MWI`1hN7P0R8R803lo?`1oOgl0Y:BT07emO@1DE5@0[jn_
05UIF@1SHf<0GEeM08f=S@1jNWX0PX:205mOG`1HF5P0<30`065QH@0`<300Kfm_02l_;`1JFUX0UiNG
06UYJ@1EEED0RHV903hn?P1ZJVX0F5QH04];B`1[Jf/06QXJ03dm?@2_[jl0EeMG030`<01=CDd0Ti>C
05ADE00[:b/0GUiN04i>CP1TI6@0A4A409>CT`25QHD0V9RH02HV9P1`L700Jf][06=SH`28R8P0J6QX
04Q8B01:BTX0Ti>C04m?C`2>SXh0<30`02`/;01^KVh0NGUi07moO`1NGUh0Hf=S05aLG00_;bl0K6a/
09BDU01KFe/0?clo0:6QX@0l?3`0MWIf07QhN01KFe/0W9bL06UYJ@0f=SH0ADE506i^KP1hN7P0CDe=
01hN7P1kNg/0;bl_04=3@`1TI6@0QXJ607QhN00];Bd0c<c<08f=S@1bLW80=3@d05YJFP1QHF40=cLg
0410@01<C4`0=cLg069RHP1_Kfl0>c/k07emO@10@400<C4a07QhN019BDT0MWIf09BDU01WIfL0<c<c
01LG5`0g=cL0D51@01/K6`13@d<0RXZ:7?ooool0:`2XZ:P0Shn?07AdM015ADD0>c/k02HV9P0P8200
@D510;>c/`1ZJVX0@T92065QH@1?Cdl071`L04I6AP2MWId0a<C40<G5a@33`l<0_;bl08Z:RP1^KVh0
YJFU0=?Cd`3<c<`0QhN703hn?P0Y:BT07QhN01dM7@0R8R80De=C05iNGP1=CDd0=3@d038b<P0`<300
=SHf08j>SP0d=3@07alO020P800O7al00P0P820201`L700F069RHP2BTY80d];B05ADE02FUYH0K6a/
0492@P1=CDd0@d=3092@T01mOGd0[:b/069RHP0b<S80<C4a02d];@0Q8B40<C4a04M7A`0i>CT0;2`/
01dM7@<05ADE00/0C4a<06ATI00O7al06ATI01`L700N7Qh09BDU03Lg=`1TI6@0][Jf0<k>cP020>OW
i`060<[:bP1_Kfl0EeMG08:2PP18B4P0@D510P0g=cL0;@0W9bL07alO01`L700O7al0CDe=05UIF@0[
:b/0:BTY02l_;`2JVYX0emOG05mOG`0b<S806ATI01DE5@0G5aL0=3@d08J6QP1TI6@0SHf=0<O7a`1K
Fe/0@D51030`<00j>SX0<C4a0451@@1IFET0Lg=c0;Ng]`1:BTX0ATI608J6QP1]KFd0:BTY02<S8`0X
:2P0;bl_04I6AP20P800ATI6034a<@0n?Sh0KVi^0;Zj^P0209jNWP0O06m_K`1CDe<0DE5A06MWI`23
Ph<0AdM708>3P`2JVYX0DE5A02DU9@0Y:BT0>c/k04m?C`0U9BD05aLG01XJ6P0L71`0ATI603Ph>01h
N7P0PH6105=CD`1IFET08R8R02/[:`0O7al06ATI01PH600I6AT07alO06][J`0202/[:`0=07emO@1f
MWH0@T9205QHF01ZJVX0GemO0:j^[P16ATH092@T01`L700j>SX0BDU901XJ6P0301DE5@1<03<c<`1J
FUX0U9BD0=OGe`3Jf]X0DU9B01dM7@0L71`06ATI03dm?@0H61P06ATI01/K6`0a<C405aLG01DE5@1Y
JFT0@D5104A4A00m?Cd0VYZJ0:j^[P1nOWh0MGEe071`L029RHT0^k^k09fMW@38b<P0Shn?0410@00R
8R807AdM01`L700U9BD0Q8B403De=@1?Cdl0Vi^K09ZJVP1>CTh0BDU909jNWP0U9BD0>c/k03Xj>P0N
7Qh0^;Rh0<C4a02UYJD0_;bl069RHP14A4@06ATI01DE5@0O7al09bLW06QXJ00g=cL08B4Q03Hf=P2>
SXh0>SXj024Q8@0k>c/0CTi>04];B`2DU9@0Cdm?04M7A`16ATH0EUIF04E5A@0E5AD04a<C01DE5@80
51@D01L0:RXZ05MGE`0i>CT0EeMG0<W9b@3Kfm/0d];B0:JVYP2`/;00KVi^05EEE@1DE5@0CTi>04];
B`1UIFD0a<C40;fm_@1CDe<0>3Ph04e=C@26QXH0EeMG03dm?@0Aooooo`003oooool20820P01_06MW
I`1HF5P0E5AD03hn?P15ADD0T92@0492@P1dM7@0VYZJ04E5A@13@d<0DE5A03hn?P1PH600<30`06a/
K01;Bd/0CDe=07MgM`0Z:RX0SHf=03/k>`1HF5P0Cdm?03Xj>P19BDT0IFEU03dm?@0[:b/0H61P05YJ
FP1DE5@071`L03`l?02FUYH0?3`l03<c<`1cLg<0E5AD03`l?018B4P0A4A401XJ6P0o?cl0CDe=02/[
:`1IFET0>3Ph024Q8@0n?Sh0Cdm?02/[:`1JFUX09bLW02/[:`24Q8@0HF5Q03<c<`0e=CD0J6QX0410
@01SHf<0M7Ad055AD@0`<300JVYZ05YJFP0X:2P0;bl_04i>CP1DE5@0Q8B405MGE`14A4@0BTY:02`/
;01?Cdl0K6a/05eMG@2@T900FUYJ04Q8B02@T900Ng]k03Hf=P1KFe/0SXj>04Q8B00o?cl0OGem05IF
EP0^;Rh0O7al065QH@0`<300FUYJ04e=C@1IFET0BTY:07AdM00^;Rh0EUIF075aL@19BDT0IVIV03Ti
>@23Ph<0K6a/038b<P1:BTX0>3Ph0080OGem0900>c/k04i>CP0g=cL0L71`07IfMP1CDe<0H61P04A4
A015ADD0GUiN061PH01DE5@0Fe]K03dm?@1^KVh0GUiN05aLG01EEED0MgMg05aLG00k>c/0JVYZ04U9
B@1]KFd0W9bL05=CD`1WIfL0MWIf04Q8B01QHF40Rh^;05]KF`16ATH0H61P04Y:BP0b<S80IFEU059B
DP0o?cl0BTY:0451@@0n?Sh0U9BD03Ti>@1EEED0@d=304Y:BP1dM7@0Cdm?05QHF01nOWh0?3`l03dm
?@2HV9P0LW9b07QhN01/K6`0U9BD05YJFP2HV9P0/[:b08V9R@1NGUh0][Jf079bLP1lO7`0K6a/08N7
Q`1[Jf/0YJFU09VIV@25QHD09bLW05YJFP0X:2P0JFUY0451@@1ADE40Lg=c04e=C@1IFET0PH6105QH
F02GUiL0HV9R04];B`1nOWh09bLW03Ph>02g]kL0@d=303Ph>01?Cdl0Ti>C02TY:@0W9bL0LW9b08N7
Q`1iNGT0EUIF0;jn_P2QXJ40MWIf03<c<`1oOgl0Fe]K05mOG`1bLW80=SHf02@T901CDe<0RXZ:051@
D02;Rh/0Fe]K04A4A01UIFD0Kfm_07moO`1PH600MGEe08R8R00g=cL0CDe=07=cL`1UIFD0AdM70:JV
YP1eMGD0N7Qh06i^KP1]KFd0W9bL07moO`1VIVH0AdM705EEE@1`L700BDU9024Q8@2>SXh0KVi^04e=
C@1^KVh2096AT@0M03Hf=P2c/k<0UiNG08B4Q00j>SX0C4a<075aL@0j>SX0GemO05iNGP11@D40EEEE
02l_;`0M7Ad0KVi^03Hf=P0a<C40PX:205QHF02XZ:P0YjNW05eMG@0f=SH04a<C03Hf=P1HF5P06a/K
04a<C027QhL07?ooool06P1/K6`0GemO06YZJP2@T900K6a/0451@@1DE5@0YJFU071`L01OGel0NWYj
02h^;P0J6QX07AdM05mOG`2GUiL0?clo06IVIP2_[jl0VYZJ08n?S`2k^k/0f][J0=7Ad@2EUID0Jf][
0P0K6a/06P0M7Ad05aLG01DE5@0j>SX0LG5a03Hf=P0W9bL0:BTY02d];@1]KFd0CDe=0410@01ADE40
EeMG05IFEP16ATH0ADE503lo?`1?Cdl0Kfm_065QH@34a<@0MWIf04U9B@0K6a/05ADE0P0F5QH0<P0g
=cL0KFe]06ATI01;Bd/0H61P03`l?00[:b/0:2PX03`l?013@d<0CTi>02h^;P0L71`06ATI01XJ6P0E
5AD07AdM09RHV01LG5`0BDU902XZ:P0K6a/07AdM01lO7`0];Bd0RHV90<?3``38b<P0VYZJ0<_;b`2m
_Kd0^k^k0<;2`P1cLg<0DU9B06a/K02EUID0Rh^;07alO01gMgL0NGUi08^;R`2BTY80MGEe05aLG01/
K6`0_kno0=?Cd`1=CDd0>c/k0P0F5QH0:@0Q8B40GUiN03@d=01^KVh0NWYj08F5Q@12@T80CDe=05IF
EP1=CDd0@d=303Ti>@0h>3P0EeMG0<S8b02@T900QHF508j>SP0c<c<08R8R020P800c<c<07alO06=S
H`2=SHd0?Shn034a<@0Y:BT0Ng]k06YZJP1@D500I6AT03Xj>P1=CDd0IfMW0;2`/01CDe<0LG5a07al
O02PX:00Hf=S0080820P00<08B4Q03/k>`0g=cL00`0L71`02@18B4P0?3`l075aL@2;Rh/0LG5a079b
LP0[:b/0A4A401hN7P0201XJ6P0K01/K6`0/;2`0PX:204I6AP26QXH0GemO03De=@0L71`0820P030`
<01QHF40JVYZ03Lg=`0i>CT07AdM03/k>`0c<c<06QXJ01DE5@0H61P0AdM70:^[Z`2RXZ80Y:BT0:6Q
X@2/[:`0ZZZZ00806ATI01/061PH03/k>`0H61P06a/K01lO7`0X:2P05ADE01TI6@1IFET0<30`0451
@@10@400RXZ:0;bl_02?Shl0OGem075aL@28R8P0U9BD05IFEP2EUID0]kNg08B4Q01WIfL0MGEe04Q8
B01UIFD00P2/[:`01P2@T900B4Q805UIF@1XJ6P0Fe]K08N7Q`806ATI01T0>SXj05YJFP2YZJT0D51@
03hn?P1JFUX0D51@03`l?00H61P09BDU03De=@1dM7@0WIfM01hN7P0O7al09RHV04];B`0X:2P061PH
01`L700Y:BT0DE5A08n?S`0M7Ad09BDU00809bLW01d0B4Q801dM7@0C4a<051@D01<C4`0B4Q805QHF
06UYJ@1oOgl0Fe]K0;Vi^@3AdM40U9BD06MWI`2GUiL0@D5104E5A@19BDT0EEEE06QXJ01/K6`0TY:B
0;bl_01PH600MgMg08V9R@1DE5@08B4Q01hN7P0Aooooo`003oooool0d`1QHF40De=C05YJFP1KFe/0
Cdm?03<c<`1=CDd0Q8B40410@01lO7`0OGem03`l?01FEUH0NGUi04Q8B01RHV80:2PX06][J`0a<C40
=CDe05IFEP0O7al0QhN703@d=00m?Cd0CDe=0492@P1LG5`0Jf][051@D00S8b<0Cdm?02DU9@1CDe<0
:2PX02h^;P2EUID0:b/[03@d=01/K6`0ATI603Hf=P0R8R80@41001dM7@0n?Sh0?Cdm01hN7P16ATH0
?3`l03De=@1@D500CDe=02@T901VIVH0BDU902l_;`2>SXh0@d=301hN7P0j>SX0LW9b03Xj>P1:BTX0
AdM702TY:@0^;Rh0DE5A065QH@0l?3`0;bl_03hn?P1YJFT0OWin05EEE@1RHV80F5QH03Hf=P1CDe<0
FEUI05MGE`2KVi/0B4Q803hn?P1`L700I6AT03De=@1<C4`0Ogmo02XZ:P0b<S80IfMW03hn?P0c<c<0
LG5a06a/K013@d<0MGEe04a<C018B4P0>SXj075aL@0o?cl0HV9R05eMG@1ADE40JFUY05QHF01bLW80
M7Ad03Ti>@1[Jf/0Fe]K08>3P`22PX80?Shn06=SH`1TI6@0M7Ad05=CD`1JFUX0QHF504M7A`1;Bd/0
DU9B05]KF`1ADE40GUiN04i>CP1bLW80GEeM07MgM`1aLG40WIfM051@D00h>3P0OWin06EUI@2=SHd0
Xj>S04Y:BP1dM7@0Ng]k05aLG01lO7`0QXJ604Q8B01MGEd0QXJ605YJFP0_;bl0J6QX05EEE@14A4@0
CDe=06MWI`0o?cl0RXZ:03Xj>P1ZJVX0IVIV04E5A@1jNWX0I6AT06YZJP1iNGT0ATI604i>CP2UYJD0
QHF507MgM`1/K6`0QhN7059BDP2?Shl0/[:b0861P@1fMWH0_Kfm06m_K`21PH40IVIV06m_K`1DE5@0
[Jf]0<c<c01GEeL09RHV06MWI`0W9bL0KVi^0451@@1HF5P0Jf][04A4A01LG5`0PH61059BDP2<S8`0
A4A405eMG@2NWYh0Bd];03/k>`2i^KT0BTY:04U9B@1UIFD0QHF503`l?00W9bL00P1?Cdl0C@1JFUX0
CTi>0<[:bP2WYjL0T92@034a<@1WIfL0Bd];06][J`20P800EeMG03hn?P1ZJVX0Lg=c06IVIP2c/k<0
GemO03Xj>P1^KVh0Lg=c03Hf=P0m?Cd0TY:B0:JVYP0o?cl0EEEE06e]K@1XJ6P0@D5108B4Q01aLG40
QHF506a/K01WIfL0d];B0;jn_P1_Kfl0C4a<05ADE01nOWh0?clo0451@@3?cll0Kfm_05EEE@1VIVH0
RHV907emO@0_;bl0QhN708V9R@1ADE40=cLg051@D015ADD0GemO09jNWP1ZJVX0B4Q805mOG`1eMGD0
9bLW05iNGP0l?3`0=cLg07inOP0i>CT0J6QX0:b/[01LG5`09RHV018B4P0f=SH0KFe]024Q8@1PH600
VIVI01cooooo01X0De=C04i>CP16ATH0@D5106YZJP2b/[80alO70:FUY@22PX80J6QX03Lg=`0G5aL0
6a/K03@d=01XJ6P0D51@024Q8@0h>3P0_[jn0;Bd]01?Cdl0>c/k0;Fe]@2TY:@0G5aL020P80804a<C
0P0A4A40100C4a<0=SHf02PX:00G5aL301DE5@0O038b<P1;Bd/0>c/k03Hf=P0i>CT0?Cdm03Ph>00b
<S80?Cdm04Y:BP1jNWX0OGem0<k>cP2b/[80;bl_01DE5@0D51@05ADE01<C4`0a<C40Bd];05=CD`0L
71`0?Cdm02<S8`0U9BD07AdM01lO7`0Y:BT0:b/[02d];@0201dM7@1Q01`L700G5aL05aLG04Y:BP0E
5AD071`L04I6AP19BDT08b<S03<c<`1IFET0Ph>30>;RhP3AdM40M7Ad03lo?`13@d<0MWIf0<c<c03D
e=@0]KFe07inOP2;Rh/0LG5a06QXJ01hN7P0NWYj08Z:RP22PX80ZZZZ0:n_[`30`<00e=CD0;bl_021
PH40A4A402d];@0U9BD0PH6103De=@0f=SH0KFe]038b<P1GEeL0HV9R024Q8@0L71`0:BTY02h^;P0d
=3@0?Cdm04a<C029RHT0WYjN0=OGe`10@4009bLW02<S8`0O7al0:BTY01lO7`1oOgl0S8b<04Q8B00`
<300820P07IfMP1<C4`0FEUI06QXJ00X:2P0>3Ph03lo?`21PH40EEEE06QXJ02c/k<0VIVI04m?C`0N
7Qh06a/K01XJ6P0M7Ad0>c/k03Hf=P0L71`0:BTY038b<P0f=SH0M7Ad0<71`@2IVIT0RXZ:04m?C`17
AdL0820P01XJ6P0201/K6`0503Ti>@2n_[h0VYZJ05iNGP0g=cL00`0L71`0F00M7Ad0?clo08V9R@1V
IVH0>CTi01dM7@0m?Cd0<30`02@T9016ATH0OWin071`L019BDT0J6QX07alO01gMgL0IfMW0:f][@15
ADD07AdM01hN7P1GEeL05aLG01TI6@0V9RH08R8R01DE5@0S8b<0AdM7028R8P0h>3P0MGEe0:ZZZP1D
E5@0@41003Lg=`0^;Rh0;2`/04M7A`1KFe/0HF5Q0;Bd]00];Bd08R8R03@d=02o_kl0ZZZZ08F5Q@1i
NGT0<30`038b<P1CDe<0G5aL03lo?`2;Rh/06ATI01LG5`0N7Qh0<C4a08j>SP0`<300A4A403hn?P1D
E5@0=cLg038b<P1TI6@0G5aL03<c<`1EEED07AdM02<S8`0P8200=cLg03<c<`0F5QH06ATI01dM7@0_
;bl0K6a/034a<@0M7Ad08b<S01lO7`0_;bl0ADE501DE5@0B4Q8201<C4`0G028R8P1VIVH0G5aL04Q8
B02OWil0Zj^[05eMG@0_;bl0M7Ad01lO7`0Q8B40:BTY038b<P0e=CD0?3`l05eMG@2IVIT0>3Ph08F5
Q@23Ph<0@d=303De=@0O7al04Oooool000oooooo0?l0LG5a08F5Q@1XJ6P0L71`06ATI00n?Sh0ADE5
08R8R00n?Sh0OGem06EUI@0[:b/0<c<c04];B`0l?3`08B4Q02HV9P1^KVh0C4a<038b<P0f=SH06ATI
07UiN@13@d<0@D5105eMG@0d=3@0BDU906YZJP1:BTX092@T05aLG01CDe<0DE5A034a<@0X:2P0PX:2
02/[:`12@T80C4a<03`l?00/;2`0?clo03dm?@0J6QX0>c/k03Xj>P0f=SH0BTY:034a<@0];Bd0?clo
05aLG00h>3P0KVi^069RHP0^;Rh0UiNG07MgM`12@T80;Bd]06UYJ@15ADD0EeMG05ADE01>CTh0;Rh^
030`<01MGEd0>3Ph034a<@19BDT0JVYZ07EeM@0/;2`0A4A405iNGP0n?Sh0DU9B02l_;`1@D500Z:RX
05EEE@1<C4`0S8b<05QHF00_;bl0Cdm?071`L00^;Rh0=CDe06QXJ00e=CD0=SHf0820P02;Rh/0>c/k
07QhN01;Bd/0Cdm?0492@P25QHD0@41006][J`1EEED0LG5a08N7Q`1CDe<0SXj>06EUI@12@T80Jf][
03Xj>P1oOgl0M7Ad07IfMP2FUYH0Ogmo08:2PP0b<S80QXJ60820P015ADD0CTi>055AD@1JFUX0HV9R
06][J`1BDU80Kfm_05eMG@1jNWX0JVYZ09fMW@0m?Cd0>3Ph08^;R`1OGel0UIFE0;2`/01JFUX0/;2`
08b<S01MGEd0R8R80820P00a<C40MWIf0:>SX`1UIFD09BDU079bLP1DE5@0NWYj08:2PP1FEUH0>SXj
08^;R`10@400LW9b071`L01:BTX0U9BD07AdM01`L700LW9b04];B`1=CDd0VYZJ07]kN`1_Kfl0MgMg
09>CT`1CDe<0RHV908f=S@0a<C40A4A40;2`/01^KVh0RXZ:06YZJP1^KVh0Bd];08V9R@2?Shl0CTi>
02LW9`1EEED09RHV07EeM@0o?cl0C4a<0820P01DE5@0Jf][07moO`1TI6@0RHV904E5A@0Y:BT0HF5Q
04I6AP0[:b/0`/;203dm?@0Y:BT0Rh^;08j>SP0a<C40<S8b05YJFP1;Bd/0ADE503`l?03>c/h0ZJVY
08R8R00e=CD0PH61051@D02:RXX0^[Zj06EUI@10@400NWYj06i^KP1LG5`0[:b/065QH@0j>SX0MgMg
06i^KP1[Jf/0CTi>05ADE01]KFd0>SXj059BDP2FUYH0;Bd]03De=@2KVi/0J6QX07UiN@1]KFd0;Bd]
08>3P`2;Rh/0GemO04U9B@1CDe<0MgMg02DU9@0C4a<002<0VIVI06YZJP1FEUH0Jf][07emO@0/;2`0
7alO07]kN`2:RXX0FEUI03Ti>@1NGUh092@T03@d=013@d<0?Shn05EEE@22PX80NGUi02`/;01ADE40
<30`06EUI@2WYjL0GEeM06][J`1ZJVX0D51@02/[:`0A4A40<S8b02LW9`0O7al0PX:20:6QX@0Loooo
o`0:05eMG@1BDU80C4a<03lo?`1SHf<0alO70=;BdP3Cdm<0`l?302/[:`806ATI02X0;Bd]03@d=01b
LW80CDe=06IVIP1/K6`0J6QX0:2PX029RHT0?3`l0861P@2<S8`0MWIf05UIF@0N7Qh06a/K02<S8`0M
7Ad07QhN04e=C@0e=CD071`L01DE5@0C4a<05ADE01XJ6P0k>c/0<c<c02XZ:P0X:2P08b<S028R8P0_
;bl0=3@d02h^;P1mOGd0`<300=kNgP2d];@0O7al04Q8B00J6QX201DE5@0=03lo?`17AdL0Cdm?01/K
6`0I6AT05ADE01`L700M7Ad06ATI02<S8`0/;2`0;Rh^01XJ6P0201`L700_01HF5P0H61P0?3`l01LG
5`0C4a<05ADE03/k>`2?Shl0UIFE09fMW@2e]KD0e=CD0:b/[022PX80>SXj03<c<`0];Bd0=SHf06MW
I`1@D500AdM703De=@0L71`07AdM01`L700V9RH0QXJ607emO@1EEED0IFEU0<O7a`3Ti>@0d=3@0<O7
a`2FUYH0MgMg09nOW`1lO7`0?clo03Xj>P1RHV806a/K01`L701eMGD0BDU901lO7`0K6a/00P0J6QX0
;@0U9BD0;Bd]05IFEP0l?3`0S8b<03`l?00S8b<09BDU028R8P0S8b<0>3Ph0861P@1^KVh0ADE502DU
9@0];Bd0OWin03lo?`18B4P0HF5Q02PX:00e=CD0;bl_04a<C02EUID0O7al0820P034a<@0Jf][02XZ
:P0L71`07QhN01`L700O7al0@d=3038b<P15ADD0>SXj03/k>`24Q8@0_Kfm0=?Cd`36a/H0RHV903Hf
=P0201hN7P807alO0240Jf][0:BTY01ADE40>CTi01/K6`0J6QX07AdM01`L700M7Ad0<30`03dm?@1`
L700Kfm_03lo?`1ZJVX0T92@07moO`1]KFd0@D51051@D02TY:@0^k^k06ATI00O7al0GemO05QHF02T
Y:@092@T028R8P1BDU805QHF01TI6@0m?Cd00P0E5AD0EP0g=cL0=CDe01dM7@0Z:RX0S8b<07]kN`0a
<C40:b/[01lO7`0K6a/05QHF02HV9P1GEeL0=CDe0;6a/@1EEED07AdM05=CD`2CTi<0>3Ph05eMG@1a
LG409BDU02h^;P13@d<0FEUI03Hf=P2?Shl06ATI01DE5@0H61P08R8R08N7Q`1mOGd0O7al07MgM`2N
WYh0/;2`07alO00^;Rh05ADE01LG5`0k>c/07QhN02DU9@0S8b<0:2PX0492@P0L71`05aLG01/K6`0V
9RH0GEeM02XZ:P0W9bL07alO028R8P0N7Qh0=CDe030`<00E5AD04a<C01DE5@10@400Bd];08f=S@25
QHD0VIVI092@T015ADD0@41006][J`0M7Ad07alO01hN7P0W9bL0<30`03hn?P0o?cl0M7Ad03De=@1P
H600K6a/02l_;`1@D500FUYJ4Oooool000oooooo07L0OWin07UiN@1XJ6P0F5QH079bLP14A4@0EeMG
08Z:RP0n?Sh0R8R80:FUY@12@T80BTY:055AD@1>CTh0Fe]K03<c<`1dM7@0ADE504Q8B01WIfL0;bl_
09:BTP1<C4`0H61P075aL@14A4@0Cdm?06MWI`1JFUX09RHV06m_K`1SHf<0CTi>02`/;011@D40TI6A
03/k>`1ADE40DU9B04M7A`0i>CT0BDU904=3@`0/;2`0GEeM03Lg=`0f=SH0E5AD03`l?00c<c<0F5QH
06e]K@0m?Cd0Jf][03dm?@0g=cL0Z:RX07]kN`0l?3`0=cLg07=cL`0n?Sh0M7Ad061PH01KFe/0>SXj
04a<C01RHV80>3Ph04e=C@1PH600GUiN06ATI010@400C4a<04m?C`0c<c<0De=C04a<C01ADE40OWin
04I6AP1BDU80PX:204U9B@0j>SX0N7Qh08F5Q@0g=cL0=SHf05eMG@0`<300EEEE06IVIP1^KVh0=CDe
08Z:RP1CDe<0DE5A02h^;P1_Kfl0>3Ph06e]K@1GEeL0GemO06m_K`1;Bd/0O7al04i>CP0];Bd0FUYJ
03/k>`1jNWX0Hf=S04U9B@1jNWX0LG5a06IVIP02051@D02Y079bLP0l?3`0Bd];05]KF`1CDe<0FUYJ
075aL@18B4P0HF5Q05aLG01kNg/0IFEU08^;R`1:BTX0=SHf07alO01OGel0YZJV0:>SX`19BDT0M7Ad
075aL@1VIVH0YJFU05EEE@0`<300F5QH09JFUP17AdL0:2PX05iNGP0i>CT0EUIF07EeM@1DE5@0>SXj
08Z:RP0k>c/0S8b<07MgM`0i>CT0Ogmo06UYJ@2ATI40WIfM06EUI@1>CTh0Xj>S05eMG@1aLG40UIFE
06e]K@15ADD0T92@0:^[Z`1aLG40Jf][0;6a/@1JFUX0WIfM09FEU@2GUiL0P82007UiN@1eMGD0@T92
03hn?P1TI6@0:BTY08B4Q00g=cL0DE5A08:2PP1aLG40SHf=09NGU`1BDU80TI6A05IFEP1<C4`0LG5a
03hn?P0X:2P0SXj>055AD@16ATH0@41005iNGP1;Bd/0=3@d069RHP1KFe/0=3@d04M7A`3?cll0b/[:
08B4Q00d=3@0Ph>302TY:@1[Jf/0P820051@D01:BTX0XZ:R07=cL`19BDT0O7al03Ph>00_;bl0T92@
07alO021PH40EeMG05UIF@1hN7P0?clo069RHP1bLW80BTY:03De=@1NGUh0CTi>06m_K`19BDT0CTi>
09NGU`1DE5@0CDe=04];B`1eMGD0O7al04M7A`0W9bL0YjNW05mOG`1aLG40UIFE08F5Q@1<C4`0;Rh^
04=3@`1/K6`0<S8b03dm?@1eMGD0DE5A03Xj>P15ADD0?clo0410@01NGUh0I6AT03Lg=`1iNGT0=3@d
04];B`2<S8`0CDe=0861P@2>SXh0ATI602XZ:P0];Bd0A4A405QHF00M7Ad0Bd];07QhN00Looooo`0B
06UYJ@1cLg<0MGEe06YZJP2/[:`0`l?30:j^[P2XZ:P0HV9R06a/K01`L700OWin07QhN022PX80KVi^
05IFEP0b<S8071`L0P0H61P02@0i>CT0KVi^09bLW02d];@0_kno0=GEe@2SXj<0Ogmo05eMG@0205IF
EP0V07MgM`1`L700BTY:03@d=00c<c<09bLW01/K6`0[:b/0>CTi03Hf=P0_;bl0:b/[03Hf=P0m?Cd0
LW9b09^KV`2ATI40UYJF07IfMP1<C4`0EEEE06IVIP1LG5`0AdM703dm?@1eMGD0Fe]K06MWI`0Y:BT0
5aLG01DE5@0G5aL071`L01hN7P0_;bl09bLW03<c<`0O7al201/K6`0C01dM7@0F5QH08R8R01lO7`0D
51@04a<C02@T901hN7P0E5AD04I6AP2h^;P0alO70;Ng]`1RHV80De=C03`l?00_;bl0;Rh^02l_;`02
02h^;P0O04E5A@1:BTX0Bd];03hn?P11@D40DE5A05MGE`1CDe<0EUIF0;2`/032`/80ADE504i>CP1P
H600EEEE08b<S022PX80RHV90;Rh^01YJFT06ATI01HF5P0Q8B40MGEe069RHP0Y:BT071`L01LG5`0M
7Ad08b<S04i>CP0204=3@`0c075aL@0^;Rh07alO020P800Q8B40@410069RHP1YJFT0@T92034a<@1E
EED0P82004e=C@0[:b/0820P024Q8@0[:b/09BDU030`<02;Rh/0GEeM04a<C02][Jd0e=CD06QXJ019
BDT0@41003Ph>00`<300<C4a05]KF`1`L700K6a/07=cL`2JVYX0YjNW07UiN@2ATI40QhN706EUI@1I
FET0E5AD05mOG`1HF5P0OWin09FEU@17AdL0<c<c02HV9P0T92@08B4Q00807AdM0200?Cdm03Lg=`0/
;2`0GUiN0<O7a`2^[Zh0QXJ605]KF`1FEUH0EeMG061PH01`L700UYJF06IVIP1KFe/0IFEU04i>CP1J
FUX0O7al03<c<`1ADE40820P03Ph>01FEUH05ADE01HF5P12@T80;Bd]01dM7@0k>c/0F5QH028R8P@0
5ADE01h05QHF01XJ6P1CDe<08R8R06ATI02[Zj/0R8R806QXJ00k>c/0ATI608N7Q`2f][H0M7Ad0410
@00j>SX0H61P05eMG@2d];@0D51@01hN7P0P8200Kfm_0:6QX@2PX:00VYZJ0:BTY027QhL0NGUi05YJ
FP0];Bd201HF5P0/03<c<`0M7Ad07QhN01hN7P0O7al0>c/k03Hf=P0M7Ad071`L02/[:`1/K6`0ATI6
03lo?`0^;Rh08R8R02DU9@0R8R80;Bd]03Ti>@0X:2P0ADE504e=C@1CDe<0OGem079bLP2JVYX0OGem
06YZJP2<S8`0Ogmo051@D00o?cl0:2PX02@T900[:b/0;Bd]03Ph>020P800Ph>306e]K@1bLW80;2`/
02XZ:P0_;blAooooo`003oooool0f01hN7P0Ng]k07YjNP1]KFd0Jf][03dm?@1<C4`0Cdm?02@T901W
IfL0Q8B403Ti>@19BDT0E5AD03dm?@1GEeL0:RXZ075aL@14A4@0:2PX04e=C@0U9BD0Kfm_02/[:`18
B4P0Fe]K03Hf=P12@T80KVi^03De=@0_;bl0G5aL04M7A`1?Cdl092@T02HV9P1UIFD0<c<c04M7A`1O
Gel0@41003@d=00g=cL0>3Ph01hN7P19BDT0>c/k038b<P1BDU80;Bd]01PH6014A4@0CTi>02@T901c
Lg<0=cLg02@T902LW9`0G5aL038b<P0d=3@0I6AT02DU9@21PH40HV9R04I6AP0[:b/0KVi^05aLG00X
:2P0EUIF04=3@`1KFe/0Lg=c04a<C017AdL0?clo03@d=01`L700Fe]K06QXJ02LW9`0?clo07emO@2_
[jl0CDe=02XZ:P1CDe<0JFUY03dm?@1BDU80PX:204a<C01OGel0D51@05]KF`0X:2P0Ng]k065QH@1B
DU80;Bd]05aLG00a<C40R8R805YJFP1SHf<0C4a<04U9B@2GUiL0IVIV03De=@1FEUH0>SXj08V9R@25
QHD0F5QH051@D01bLW80P82004a<C01LG5`0?3`l04];B`22PX80L71`05IFEP1QHF40H61P04I6AP1N
GUh0HV9R06a/K01PH600Kfm_04U9B@1<C4`0LG5a0492@P2;Rh/0W9bL05mOG`2<S8`0EeMG04I6AP2K
Vi/0I6AT0410@024Q8@0]KFe04A4A01;Bd/0R8R803`l?01@D500EeMG03Hf=P1DE5@0QhN702`/;01I
FET0HF5Q02/[:`1IFET0@T9206IVIP1FEUH0?Shn05iNGP2h^;P0IfMW09:BTP2YZJT0Hf=S03lo?`1j
NWX0ZZZZ071`L01bLW80]KFe06YZJP2HV9P0QHF508:2PP2<S8`0MWIf08N7Q`0`<300A4A407alO00]
;Bd0Ogmo03Ti>@1GEeL0LW9b04a<C029RHT0OGem04a<C01lO7`0ATI604U9B@1YJFT08R8R01/K6`1d
M7@0C4a<05eMG@1@D500Fe]K03Hf=P1>CTh0RHV907]kN`18B4P0@T920;>c/`80RXZ:04P0=CDe09VI
V@1WIfL0I6AT05IFEP16ATH0Kfm_0;jn_P1oOgl0HV9R0:FUY@0b<S80=3@d06IVIP1[Jf/0GemO04a<
C029RHT0Ng]k02DU9@0k>c/0QXJ605=CD`14A4@0EeMG02TY:@1]KFd0Hf=S065QH@30`<00JVYZ024Q
8@0n?Sh0FUYJ06YZJP10@400@d=30;fm_@1@D500A4A406IVIP1HF5P0:b/[03Ph>01/K6`0G5aL02/[
:`0b<S80Kfm_03Lg=`1FEUH0Bd];04I6AP1:BTX0Cdm?06EUI@0S8b<0JVYZ03Hf=P1NGUh0V9RH03lo
?`29RHT0_[jn03/k>`0Q8B404Q8B03Lg=`1VIVH0:2PX06YZJP2@T90Looooo`0Z034a<@1IFET0M7Ad
05ADE02YZJT0];Bd0:JVYP2?Shl0>c/k05aLG02MWId0SXj>08B4Q01DE5@0:b/[01dM7@0T92@06a/K
01hN7P0L71`09BDU06YZJP2n_[h0e]KF0<C4a037alL0CDe=02XZ:P0T92@09bLW02h^;P1PH600DU9B
038b<P0h>3P0>c/k06ATI01fMWH0K6a/06YZJP0i>CT061PH0`0E5AD01`0f=SH0A4A407emO@0Z:RX0
B4Q805UIF@0f=SH00P0S8b<0;00g=cL0DU9B07alO02DU9@0TI6A03dm?@0E5AD051@D01DE5@0D51@0
5QHF030`<01;Bd/0Cdm?03Ti>@0e=CD0>c/k02DU9@0I6AT05aLG034a<@0E5AD05aLG0451@@0f=SH0
B4Q808B4Q034a<@0UiNG06QXJ00a<C40ATI6069RHP1[Jf/0HF5Q03dm?@0n?Sh0:RXZ0410@02FUYH0
/k>c08b<S01<C4`0;Rh^0P0H61P04`0E5AD0<C4a06][J`1RHV807QhN05UIF@30`<00V9RH0:6QX@1l
O7`0SXj>0492@P17AdL07alO01LG5`0o?cl0WIfM059BDP0b<S800P0Q8B40;00U9BD0M7Ad065QH@12
@T80@d=305MGE`0];Bd0;2`/038b<P2:RXX0U9BD05=CD`16ATH0QHF508R8R020P800LG5a01dM7@0L
71`06QXJ01hN7P0d=3@0IFEU0=3@d02?Shl0_kno0;jn_P1lO7`0@41003Hf=P16ATH0AdM706MWI`1e
MGD0/;2`0;Rh^032`/80bl_;0;Jf]P3GemL0Z:RX07]kN`1FEUH0FUYJ0P1@D500501JFUX0Ogmo08f=
S@2HV9P0G5aL06EUI@1FEUH0I6AT05eMG@1[Jf/0MWIf0:NWY`0X:2P0HF5Q08V9R@2^[Zh0MgMg069R
HP0[:b/08B4Q0P0N7Qh0500`<300>CTi04A4A01gMgL0]KFe06IVIP0i>CT0FEUI0:JVYP23Ph<0PH61
07]kN`2;Rh/0;Rh^03dm?@26QXH0<C4a03/k>`1EEED0<c<c0P0E5AD05P0C4a<05ADE01DE5@0G5aL0
71`L06MWI`0P8200A4A408f=S@24Q8@0ADE505eMG@2WYjL0]kNg04];B`1_Kfl0/K6a06QXJ02@T900
a<C40:RXZ02YZJT20<S8b0050=oOg`2LW9`0R8R80;Bd]01fMWH00P0];Bd01@0k>c/0DE5A069RHP18
B4P09RHV008071`L00d07AdM01hN7P0R8R80B4Q802XZ:P0O7al0>CTi03/k>`0C4a<09bLW04];B`0h
>3P092@T0080:RXZ01X0;Bd]07=cL`0c<c<0HF5Q07alO00g=cL0CTi>07MgM`17AdL0RXZ:07moO`0o
?cl06QXJ03Xj>P1_Kfl0@D5103<c<`16ATH0JVYZ069RHP2b/[80Kfm_09^KV`29RHT0Ng]k06UYJA7o
oooo000?ooooo`2K06][J`1<C4`0JFUY05eMG@1CDe<0=cLg069RHP28R8P0<c<c07QhN02OWil0@T92
055AD@1gMgL0DU9B05YJFP0l?3`0T92@04m?C`0f=SH0?clo030`<027QhL0A4A404Y:BP11@D40?3`l
05ADE02:RXX0EeMG02HV9P17AdL08R8R05iNGP0h>3P0=SHf07emO@0Q8B40@d=307YjNP1KFe/0?Cdm
02XZ:P12@T80:2PX04i>CP0T92@0=3@d06=SH`0[:b/08R8R05EEE@1JFUX0;2`/08F5Q@1IFET09BDU
0:RXZ01XJ6P0<C4a02d];@1^KVh0@41007=cL`0W9bL08R8R02l_;`1YJFT0BTY:03<c<`1NGUh08B4Q
04=3@`1PH600@41003hn?P0j>SX07alO04];B`1FEUH0J6QX0;2`/01=CDd0Bd];06QXJ01QHF40;bl_
069RHP1fMWH08R8R03Ti>@1UIFD0ADE505ADE01ADE40KVi^03@d=021PH40ADE504A4A00];Bd0Kfm_
03De=@1dM7@0EeMG06MWI`1^KVh0De=C07MgM`1UIFD0>3Ph05=CD`0W9bL0J6QX06MWI`1BDU80IVIV
069RHP1EEED0AdM706ATI00m?Cd0;2`/04M7A`1IFET0EUIF06YZJP1]KFd0?Shn07alO01iNGT0LG5a
03Ti>@1RHV80Jf][05=CD`1oOgl0C4a<08V9R@2LW9`0EEEE0:NWY`1mOGd0EEEE0:NWY`15ADD0;Bd]
07inOP2WYjL0Cdm?02XZ:P1WIfL0<C4a07inOP1cLg<00P0m?Cd0Q@1jNWX0<S8b06a/K00j>SX0HV9R
08J6QP1DE5@0U9BD096AT@0f=SH0@D5109^KV`1CDe<0DU9B07AdM01XJ6P0@41007inOP2BTY80>CTi
07=cL`2j^[X0NWYj0<W9b@2^[Zh0QXJ606EUI@1gMgL0F5QH02PX:00h>3P0Jf][0492@P2=SHd0>3Ph
04U9B@1FEUH0<S8b08Z:RP2ATI40EEEE09jNWP1;Bd/0C4a<06MWI`0^;Rh06ATI051@D00T92@0LW9b
069RHP1@D50071`L03De=@1FEUH0RHV9065QH@1BDU80c/k>09nOW`21PH40ATI60:2PX01NGUh0J6QX
06][J`0[:b/0C4a<0:ZZZP1DE5@0GemO0:RXZ01[Jf/0<S8b07moO`1TI6@0H61P03Ti>@19BDT0Jf][
02d];@1CDe<0Vi^K05ADE01GEeL0FUYJ04Y:BP1TI6@0FEUI05QHF03<c<`0MWIf04];B`12@T80GEeM
06a/K00a<C407AdM08>3P`1PH600D51@06a/K01OGel0@41002`/;01>CTh0I6AT04i>CP1?Cdl0R8R8
04U9B@0l?3`0ATI603lo?`1XJ6P0P82006i^KP0U9BD0F5QH03dm?@2ATI40XZ:R05=CD`1_Kfl0UYJF
04m?C`0d=3@06QXJ03`l?00`<3006QXJ04I6AP1jNWX07?ooool0900k>c/0M7Ad07IfMP1BDU80UiNG
0;bl_02][Jd0b/[:0<c<c01jNWX0IVIV07UiN@1HF5P0;2`/01DE5@0A4A403Ph>014A4@0L71`0?3`l
04Y:BP1OGel0Ti>C0861P@2HV9P0]kNg09VIV@1TI6@0@T9202`/;013@d<0@D5103/k>`10@4009BDU
01hN7P807AdM00h0;2`/03lo?`0];Bd05ADE01HF5P0E5AD05QHF04Q8B015ADD0=SHf01PH600Z:RX0
KFe]04e=C@809BDU00P08R8R02LW9`0k>c/0O7al07MgM`2IVIT0<C4a01dM7@<05ADE02009BDU08B4
Q02RXZ80CTi>02PX:00_;bl092@T01TI6@0G5aL0@D5101LG5`1MGEd0@T9204e=C@2>SXh0e=CD0;Zj
^P1_Kfl06ATI01<C4`0E5AD06QXJ02PX:00n?Sh0IVIV06UYJ@20P800WinO08j>SP1ZJVX0HV9R01/K
6`805ADE07805QHF01DE5@0I6AT0=SHf08R8R00U9BD0IFEU04m?C`1>CTh0Ogmo04M7A`0i>CT071`L
03De=@14A4@0;bl_01hN7P1fMWH0VYZJ0451@@1<C4`0H61P06][J`2TY:@0]kNg09:BTP1mOGd0QHF5
0861P@1IFET0DU9B08B4Q032`/80N7Qh06e]K@2RXZ80YjNW0;Bd]02XZ:P0K6a/05IFEP1BDU80Cdm?
05aLG02_[jl0T92@0<o?c`3GemL0]kNg03Ti>@0Q8B409bLW02/[:`0e=CD0ADE506QXJ02`/;00a/K6
0<o?c`2c/k<0d=3@0<[:bP10@4008b<S02@T900];Bd0<c<c03/k>`0o?cl0EUIF06i^KP2NWYh0:2PX
0451@@0_;bl0;Bd]02@T900X:2P0=CDe06EUI@2IVIT0Ph>30;2`/02;Rh/0GUiN051@D00V9RH07QhN
020P800M7Ad0<C4a02LW9`1ADE40QXJ6092@T02[Zj/0EeMG04Y:BP1_Kfl0b/[:0<;2`P35aLD0`L71
0;Zj^P3<c<`0d];B0:>SX`2m_Kd0VIVI034a<@0E5AD04a<C01@D500E5AD201PH600Z02XZ:P2>SXh0
?clo02TY:@1dM7@0S8b<09FEU@2DU9@0^KVi05QHF00c<c<0<S8b08R8R03?cll0dM7A08B4Q01ADE40
=cLg06YZJP34a<@0h>3P08^;R`2j^[X0[Zj^06a/K00j>SX0;Bd]038b<P0h>3P0ADE507EeM@0X:2P0
7AdM01`L700P82009RHV02l_;`0l?3`0@D5102PX:01aLG40EeMG0P0E5AD07`0M7Ad0BTY:03Lg=`0O
7al0;Bd]03Ti>@1IFET0<c<c05ADE027QhL0A4A406YZJP1FEUH0NWYj06ATI00I6AT0BTY:03Ti>@0F
5QH0:BTY08^;R`2>SXh0S8b<05iNGP1GEeL0TI6A08:2PP2BTY80Fe]K06YZJP1fMWH04Oooool000oo
oooo0:D0M7Ad07alO01eMGD0I6AT06QXJ00c<c<0ADE506i^KP0i>CT0OGem04U9B@0];Bd0F5QH065Q
H@1:BTX0;Rh^02/[:`1iNGT0Bd];04A4A015ADD06ATI07moO`13@d<0B4Q803De=@0O7al09RHV071`
L01JFUX0<C4a06QXJ01;Bd/0DE5A038b<P0g=cL0KVi^03<c<`10@400Hf=S069RHP0n?Sh0<c<c03lo
?`0];Bd0F5QH02TY:@0[:b/0GemO05EEE@0h>3P0DE5A05=CD`0/;2`0Rh^;04m?C`0X:2P0YZJV04e=
C@0_;bl0CTi>07inOP1>CTh0WYjN02h^;P0I6AT092@T09FEU@13@d<0>CTi08B4Q010@400DE5A04i>
CP0e=CD0?clo04Y:BP0c<c<0F5QH03Hf=P18B4P0PX:204e=C@1NGUh0S8b<05ADE00k>c/0SHf=07in
OP0a<C40?3`l065QH@0h>3P0Fe]K06a/K01mOGd0>c/k08Z:RP19BDT0I6AT02XZ:P1WIfL0;Bd]07Ad
M00o?cl0GUiN07=cL`1NGUh0PH6105QHF01>CTh0IfMW03De=@1jNWX0IVIV06=SH`1[Jf/0PX:206YZ
JP14A4@0B4Q804i>CP0i>CT0DE5A04i>CP0g=cL0Bd];05UIF@17AdL0H61P04=3@`1`L700AdM705EE
E@17AdL0@T9207YjNP1NGUh0^k^k09^KV`12@T80R8R80861P@1FEUH0YjNW04M7A`0k>c/0JVYZ0861
P@1DE5@0:2PX059BDP0N7Qh0?3`l04i>CP1CDe<0DE5A08^;R`0f=SH0S8b<06][J`0h>3P0EEEE02`/
;01SHf<00P1<C4`0501@D500YZJV061PH01mOGd0WYjN04Q8B00o?cl0S8b<09fMW@1BDU80I6AT09jN
WP1TI6@0c<c<0=[JfP2?Shl0J6QX061PH01TI6@08b<S0P1XJ6P0I@1:BTX0TY:B04=3@`1RHV80A4A4
02`/;01nOWh0MgMg04E5A@2:RXX0=CDe04e=C@1aLG40ATI601`L701HF5P07QhN055AD@1TI6@0JFUY
03Hf=P13@d<0J6QX06a/K010@400AdM70=3@d02EUID0GEeM03@d=01UIFD0@d=3075aL@1mOGd0D51@
075aL@2WYjL0IVIV05IFEP2FUYH0Hf=S03dm?@2TY:@0SXj>08N7Q`1IFET0EUIF075aL@0Y:BT0PX:2
09>CT`13@d<0@D5105ADE018B4P0WinO07MgM`1VIVH0fm_K061PH011@D40Q8B40:j^[P1^KVh0?3`l
02HV9P2=SHd0J6QX08n?S`2h^;P0Rh^;079bLP16ATH0Cdm?05]KF`0W9bL0FUYJ08V9R@1BDU80DE5A
04a<C00k>c/0B4Q805iNGP1RHV809bLW06IVIP0^;Rh0HV9R07YjNP1?Cdl0XZ:R08f=S@15ADD0=SHf
04a<C01/K6`0FUYJ01lO7`1:BTX0Ogmo01cooooo00l0G5aL04I6AP0c<c<0:2PX06MWI`1TI6@0IFEU
0:FUY@2XZ:P0][Jf08j>SP2][Jd0Ng]k04M7A`0M7Ad00P0C4a<06@0H61P06a/K01lO7`0K6a/07QhN
07EeM@1EEED0Jf][09:BTP2c/k<0TY:B05]KF`17AdL08B4Q010@400>3Ph06QXJ04A4A00f=SH09BDU
02@T900b<S80KVi^059BDP0b<S800P0G5aL09`0Z:RX0@d=306ATI00I6AT07alO02d];@1LG5`0JFUY
05EEE@17AdL0<C4a02DU9@0L71`0<C4a07AdM02/[:`0MgMg071`L00Y:BT05aLG01lO7`1@D500ZZZZ
08R8R01VIVH0CDe=03/k>`0g=cL0<30`0410@01gMgL0PH610:j^[P2`/;00/k>c0=OGe`3Ph>00^[Zj
071`L00301<C4`0;010@400E5AD092@T0451@@0k>c/0Rh^;03hn?P0d=3@0@D5105YJFP0/;2`00`0E
5AD07@0G5aL06ATI02XZ:P1PH600EUIF05eMG@0Q8B4071`L05IFEP0k>c/0;Bd]01LG5`0I6AT07QhN
03Hf=P0n?Sh0@T920=CDe02f][H0[Zj^0<30`02i^KT0_kno0;fm_@34a<@0a/K60<[:bP2@T900E5AD
0080Q8B40200KVi^09BDU01oOgl0ZZZZ0;fm_@2OWil0Cdm?03<c<`0Z:RX09RHV02TY:@0f=SH0Lg=c
0;Ng]`3De=@0cLg=09NGU`1JFUX092@T024Q8@0P8200@41007QhN01UIFD0QhN70<g=c@3IfMT0c/k>
07IfMP2:RXX0<30`01XJ6P8071`L02d08B4Q01`L700O7al0:BTY07moO`2k^k/0S8b<038b<P0k>c/0
9bLW02HV9P0S8b<071`L051@D034a<@0^;Rh0<c<c02KVi/0KVi^05mOG`0k>c/0:BTY02LW9`0X:2P0
8b<S01lO7`15ADD0@T9205YJFP2FUYH0Fe]K06QXJ02DU9@0]KFe06][J`2DU9@0SXj>09nOW`39bLT0
hN7Q0=;BdP31`L40T92@02TY:@0B4Q800P0C4a<0;@0E5AD05QHF01lO7`1`L700KVi^08B4Q00[:b/0
MGEe0:NWY`24Q8@0W9bL0:BTY018B4P0@T9203lo?`1TI6@0f][J0:JVYP1nOWh0:BTY02XZ:P0o?cl0
HF5Q0=3@d02h^;P0J6QX059BDP1fMWH0;bl_02DU9@0`<300;bl_034a<@18B4P0@41001dM7@0N7Qh0
7alO01dM7@0[:b/0?3`l07alO02GUiL0aLG507emO@0301DE5@0L01PH601:BTX0<C4a024Q8@0U9BD0
G5aL02XZ:P1HF5P0W9bL06][J`1mOGd0Lg=c06i^KP0F5QH04a<C01XJ6P1[Jf/0?clo03<c<`1ADE40
VYZJ06e]K@19BDT0EEEE0:>SX`1_Kfl0F5QH0<71`@80SHf=4Oooool000oooooo07h0OWin071`L01b
LW80BDU906e]K@0m?Cd0DE5A08j>SP0h>3P0Ph>309FEU@0m?Cd0Cdm?07IfMP1KFe/0KVi^03dm?@2A
TI40D51@03`l?01IFET0<S8b09FEU@1<C4`0FUYJ06EUI@0Y:BT0=3@d06a/K00j>SX0=cLg06a/K017
AdL0B4Q801LG5`1@D500N7Qh02d];@1HF5P0I6AT04];B`14A4@0DU9B04U9B@0k>c/0JVYZ0451@@0h
>3P0BDU902`/;00T92@0GUiN04];B`0O7al0Hf=S03@d=00V9RH0XZ:R038b<P0J6QX08b<S04e=C@10
@400MgMg0410@00e=CD0?clo09RHV00_;bl0;Bd]07]kN`0k>c/0L71`05ADE00^;Rh0Bd];04a<C018
B4P0Hf=S05=CD`1FEUH0W9bL03lo?`1_Kfl0WIfM055AD@0Z:RX0FEUI06YZJP0e=CD0ADE506EUI@0U
9BD0>3Ph055AD@22PX80>3Ph09^KV`1iNGT0Jf][03Lg=`1XJ6P0?clo09RHV01QHF40LW9b05MGE`1C
De<0WinO059BDP0g=cL0GEeM03lo?`2?Shl0JFUY04];B`0i>CT0NWYj07moO`1@D500EUIF02/[:`17
AdL0HV9R061PH01ADE4205iNGP1703/k>`1`L700G5aL05UIF@14A4@0NWYj05mOG`17AdL0KFe]04i>
CP2DU9@0V9RH05IFEP2BTY80EEEE06UYJ@2^[Zh0@T9205mOG`27QhL0Ogmo05IFEP0Y:BT0F5QH02`/
;01;Bd/0DU9B05EEE@1RHV80Rh^;02TY:@1bLW80IVIV04E5A@1RHV80Cdm?08n?S`1@D500@41005UI
F@2b/[80FEUI08N7Q`2IVIT0;2`/030`<01]KFd0Shn?05UIF@1aLG40W9bL0410@02?Shl0ZZZZ0::R
XP1YJFT0IfMW05iNGP0W9bL0?clo07UiN@0];Bd0LG5a03`l?01aLG40F5QH03Ti>@1eMGD0KVi^01dM
7@2a/K400P1=CDd0?P1QHF40820P02<S8`1MGEd09BDU06QXJ01>CTh0@D5101hN7P1QHF40Ti>C08F5
Q@0m?Cd0GUiN0=3@d031`L40KFe]03hn?P1UIFD0:2PX059BDP1VIVH0@41008:2PP2i^KT0MGEe065Q
H@2FUYH09BDU03`l?01fMWH0Lg=c07emO@1GEeL0GEeM069RHP0Q8B40K6a/08R8R01CDe<0Cdm?03dm
?@0Z:RX0EeMG05mOG`1VIVH0fMWI05IFEP15ADD0@d=305ADE01ZJVX0<30`02LW9`23Ph<0>SXj04a<
C01OGel0MgMg05=CD`0n?Sh0DU9B0P1mOGd06@1EEED0SHf=06a/K01IFET0Cdm?055AD@1JFUX0IfMW
07]kN`0W9bL0KFe]02`/;01gMgL0PX:204E5A@2DU9@0NWYj04E5A@0U9BD06ATI03dm?@10@400@D51
092@T02PX:007?ooool04@17AdL0?Cdm02l_;`0/;2`0JFUY05QHF01BDU80KVi^07moO`2JVYX0Z:RX
0;>c/`1^KVh0@41003Lg=`0@41004a<C00805ADE00`04a<C00h>3P0>3Ph0GEeM0451@@1KFe/0XJ6Q
0:n_[`2=SHd0K6a/0451@@0K6a/200h>3P0f00l?3`0@4100:BTY055AD@10@400>c/k03hn?P1^KVh0
PX:204U9B@0P8200FUYJ065QH@1<C4`061PH03<c<`11@D40IFEU0451@@0o?cl0C4a<059BDP12@T80
<C4a02<S8`1SHf<0WinO04i>CP1aLG40RHV907]kN`1HF5P0E5AD05aLG01QHF40MWIf065QH@1lO7`0
VIVI09fMW@2HV9P0WIfM07YjNP1TI6@0IVIV07moO`3Cdm<0emOG0=3@d02TY:@06ATI01DE5@0C4a<0
410@0P0C4a<04@0G5aL0?clo05EEE@16ATH0:2PX03<c<`19BDT0DU9B01lO7`0M7Ad07QhN01XJ6P0K
6a/08b<S06m_K`1mOGd0C4a<00806ATI0100>CTi0451@@0_;bl05QHF01DE5@0F5QH05aLG028R8P0k
>c/0_[jn06ATI015ADD0>c/k03@d=01:BTX0S8b<0P2UYJD09@2m_Kd0fm_K0<W9b@25QHD0OWin06YZ
JP2LW9`0b<S80<c<c026QXH0LW9b05YJFP12@T80;Bd]02LW9`0X:2P0AdM709BDU03>c/h0Vi^K05UI
F@2@T900R8R808N7Q`1VIVH0QhN707EeM@1ZJVX0Lg=c04M7A`26QXH0_Kfm09FEU@0T92@0@41006i^
KP0`<3000P0H61P0;@0J6QX06a/K020P800d=3@0UiNG06EUI@1XJ6P0OWin05=CD`0b<S80;Bd]02LW
9`0Q8B40EUIF0:JVYP2b/[80ZJVY09VIV@1`L700Kfm_04e=C@13@d<0A4A4038b<P0I6AT0;2`/04E5
A@0];Bd0;2`/07MgM`29RHT0MGEe0;Rh^02IVIT0BTY:06e]K@25QHD0T92@0:ZZZP2f][H0fMWI0=OG
e`1mOGd08B4Q01dM7@0301DE5@0]01`L701dM7@0H61P01LG5`1RHV80JFUY05=CD`1iNGT0Hf=S0<S8
b01aLG407alO01PH600N7Qh0Ogmo09NGU`32`/80TY:B06UYJ@15ADD0BTY:061PH02l_;`0[Zj^02`/
;01CDe<0?3`l04i>CP0W9bL0:RXZ03Ti>@0O7al0<30`05UIF@0M7Ad071`L01dM7@0c<c<0F5QH08J6
QP2SXj<0TY:B08^;R`1gMgL061PH00<05ADE00d07AdM05EEE@0`<300;Rh^059BDP0/;2`0O7al0;Bd
]02NWYh0PX:209^KV`0Q8B40410@008051@D00h06ATI0:f][@2i^KT0Jf][06i^KP2SXj<0FUYJ07=c
L`2ATI40UIFE06EUI@1JFUX0EUIF06ATI17ooooo000?ooooo`1e06m_K`1/K6`0QXJ6061PH01QHF40
?Shn05EEE@1WIfL0@T9209:BTP2RXZ80@D51055AD@1oOgl0IfMW06][J`0k>c/0SHf=04m?C`0n?Sh0
FUYJ02LW9`1cLg<0;bl_04=3@`1aLG40=3@d059BDP1YJFT0B4Q802HV9P1TI6@0BDU9059BDP0K6a/0
=CDe06QXJ00O7al0I6AT07UiN@0[:b/0>3Ph03Xj>P0o?cl092@T04a<C00a<C40@d=306i^KP0d=3@0
6QXJ05aLG01HF5P0>3Ph0861P@0O7al0?3`l0:2PX01IFET0:BTY03dm?@1/K6`0De=C07IfMP0R8R80
5QHF05eMG@1lO7`0>c/k03Ti>@2ATI405ADE04E5A@16ATH0;Rh^04=3@`0_;bl0=3@d05ADE01=CDd0
IfMW0:2PX00i>CT0SXj>092@T01DE5@0=cLg06m_K`1gMgL09BDU05ADE01oOgl0<30`04=3@`1JFUX0
HF5Q02@T901/K6`0CTi>05QHF00f=SH0Ph>3034a<@1oOgl0H61P06][J`1]KFd0FEUI09FEU@1QHF40
>c/k05eMG@0[:b/0L71`06MWI`1BDU80DE5A0080MGEe0280FUYJ059BDP1BDU80;Bd]03hn?P1QHF40
F5QH06MWI`1dM7@0@D5106QXJ01LG5`0F5QH02d];@20P800I6AT04=3@`1>CTh0>c/k05eMG@1NGUh0
Fe]K0:FUY@1CDe<0ADE508n?S`0j>SX0I6AT0;^k^`2BTY80BDU906=SH`1^KVh0;Bd]0P1<C4`0FP0b
<S80Kfm_08:2PP17AdL0P8200492@P1OGel0Jf][04Q8B025QHD0Bd];01DE5@0g=cL0V9RH04e=C@2X
Z:P0W9bL05]KF`0h>3P0FEUI09JFUP1<C4`0MgMg092@T01VIVH0]KFe0;>c/`2GUiL0Jf][06MWI`1H
F5P0<30`03/k>`1dM7@0=cLg079bLP0/;2`0@d=305eMG@0o?cl0MgMg079bLP1:BTX0^KVi04m?C`1W
IfL0Kfm_01dM7@0I6AT0G5aL030`<01SHf<0E5AD04m?C`0@4100Bd];071`L02<S8`0CDe=04Y:BP2g
]kL0NGUi04i>CP1@D500M7Ad04E5A@1JFUX0Fe]K02TY:@1@D500YJFU06a/K01LG5`0UIFE05aLG00f
=SH0PH61071`L026QXH0FUYJ05=CD`1kNg/0ATI6079bLP2=SHd0DE5A05EEE@16ATH0A4A406][J`80
De=C02/0dM7A05=CD`1PH600EEEE05QHF01iNGT0<C4a02/[:`1lO7`0AdM7065QH@1NGUh0LW9b03Ti
>@12@T80K6a/09RHV025QHD0HF5Q07EeM@11@D40RHV90:RXZ01IFET0G5aL05eMG@1/K6`0?3`l0861
P@0b<S80Ph>307emO@17AdL0Zj^[0:JVYP1EEED0>3Ph01dM7@0o?cl08B4Q020P801YJFT0VYZJ01co
oooo0200QXJ606=SH`15ADD0=CDe06i^KP17AdL0IVIV0410@01eMGD0HF5Q05mOG`2DU9@0QHF502LW
9`0N7Qh03Ph>00d=3@0A4A404Q8B010@400=3@d03Ph>05eMG@0f=SH0ADE506][J`2NWYh0FEUI04a<
C010@40071`L01LG5`803`l?01H03Ph>010@400I6AT0BDU905UIF@0m?Cd0BDU9069RHP2JVYX0MgMg
07]kN`2LW9`09BDU024Q8@0o?cl0Jf][04Q8B00K6a/05aLG01DE5@0G5aL0:RXZ0P1@D5006`1IFET0
/;2`0492@P17AdL0R8R807YjNP17AdL0:b/[01lO7`0N7Qh0;2`/05MGE`1IFET0A4A403Hf=P0^;Rh0
NWYj06][J`2TY:@0IVIV06QXJ01ZJVX0SHf=0<O7a`2OWil09BDU01HF5P0501DE5@0601lO7`1FEUH0
ZJVY09>CT`1`L700I6AT0P2:RXX03@1<C4`0B4Q804U9B@1GEeL0Kfm_07moO`1GEeL0CTi>01dM7@0J
6QX08b<S04Q8B00j>SX00P0G5aL0=00E5AD05aLG01TI6@1>CTh0EUIF04U9B@1IFET0<C4a01/K6`0L
71`0:RXZ05IFEP2d];@0ZJVY0=cLg02IVIT0@T92055AD@0U9BD0FUYJ0<?3``36a/H0YjNW04I6AP0i
>CT0ADE505EEE@18B4P0@41006EUI@2n_[h0GUiN03@d=00n?Sh0G5aL09fMW@3:b/X0W9bL065QH@1B
DU80G5aL075aL@0_;bl0NGUi0:n_[`2<S8`0=CDe02DU9@1FEUH0LW9b02<S8`0J6QX201`L701=038b
<P1kNg/0EUIF059BDP11@D40Bd];069RHP23Ph<0Kfm_03lo?`0f=SH0K6a/09FEU@2QXJ40W9bL061P
H016ATH0FEUI03Hf=P0^;Rh0=cLg03`l?01<C4`0K6a/03hn?P0[:b/0>CTi06UYJ@0`<300HV9R0;Bd
]011@D406ATI02d];@1EEED0GUiN07QhN02KVi/0Xj>S09fMW@2OWil0?clo01/K6`0I6AT05ADE01TI
6@1IFET0IfMW01PH600E5AD09RHV0<G5a@2JVYX0Rh^;0:>SX`2o_kl0;Bd]01LG5`0^;Rh0JFUY061P
H00K6a/0BDU909jNWP30`<00YZJV07moO`2^[Zh0f][J0:f][@0l?3`0IFEU01LG5`0j>SX0Fe]K030`
<012@T800P0[:b/0301eMGD0?clo065QH@1XJ6P0M7Ad06e]K@2:RXX0VYZJ075aL@1HF5P0Lg=c03@d
=0@05ADE01X06a/K071`L01<C4`0FUYJ04=3@`2SXj<0aLG50:FUY@2][Jd09RHV014A4@0D51@0410@
01<C4`0I6AT0OGem071`L01RHV80>3Ph04I6AP3>c/h0^[Zj0;>c/`35aLD0R8R809JFUP80Ti>C4Ooo
ool000oooooo0480IVIV04e=C@1YJFT0BTY:05]KF`10@400JFUY07=cL`0b<S80J6QX05eMG@0m?Cd0
Ph>308R8R01dM7@0EeMG05=CD`25QHD0?3`l04A4A013@d<0?3`l09fMW@17AdL0?3`l03lo?`14A4@0
Hf=S07emO@11@D40:2PX0451@@0W9bL0J6QX02d];@0j>SX0NWYj01`L7010@400C4a<02l_;`0T92@0
7alO03Hf=P0T92@0F5QH01lO7`0a<C40?3`l030`<00[:b/0EeMG04E5A@0Y:BT0NGUi04];B`0Q8B40
TY:B038b<P0_;bl0FUYJ06i^KP1?Cdl0LW9b01/K6`0F5QH203lo?`2i01dM7@0h>3P0Q8B401TI6@1>
CTh0;Bd]03`l?01fMWH0@T920451@@1TI6@0Bd];06UYJ@2LW9`0=CDe07emO@22PX80>c/k03<c<`1o
Ogl0MgMg01hN7P0d=3@0Fe]K02h^;P16ATH0PH6107alO00f=SH0Ti>C04m?C`0f=SH0?Shn09VIV@0g
=cL0OGem04Y:BP1ZJVX0Ng]k06e]K@2PX:00H61P03hn?P1ZJVX0B4Q809FEU@1^KVh0GEeM06][J`2F
UYH0NGUi04a<C01gMgL0HF5Q03De=@0o?cl0G5aL02XZ:P1kNg/0YZJV055AD@2EUID0Jf][06i^KP11
@D40PH6105ADE01@D500DU9B06=SH`2UYJD0PH6104A4A02c/k<0M7Ad059BDP2_[jl0=SHf07IfMP3E
eMD0Fe]K0492@P0l?3`0BDU902<S8`1<C4`0ATI602DU9@1WIfL0Fe]K030`<01gMgL0@D5104I6AP1O
Gel0@4100:6QX@1UIFD0ADE505YJFP2k^k/0AdM709fMW@2i^KT0HV9R03De=@0k>c/0Lg=c04];B`1I
FET0RXZ:05YJFP2e]KD0[:b/08j>SP1/K6`0Jf][06IVIP0_;bl0A4A407alO00d=3@0PX:203/k>`18
B4P0P82005IFEP1nOWh0N7Qh05=CD`2j^[X0?3`l07UiN@25QHD0EeMG02<S8`1IFET0:RXZ09JFUP2D
U9@0LG5a02TY:@1RHV80K6a/07AdM012@T80F5QH0=3@d02BTY80@D5103`l?01BDU80A4A405=CD`11
@D40@41006EUI@2n_[h0De=C05EEE@2>SXh0Fe]K03lo?`29RHT0KVi^08J6QP1HF5P0FUYJ07EeM@0l
?3`0M7Ad08V9R@1ADE40EeMG051@D017AdL0IfMW069RHP1?Cdl0bl_;06][J`1VIVH0F5QH06=SH`21
PH400P0h>3P08`2JVYX0DE5A06ATI01kNg/0JFUY04];B`1oOgl0_;bl0::RXP1hN7P0MWIf03lo?`0E
5AD0G5aL06IVIP1?Cdl0H61P04m?C`0I6AT0AdM709BDU00c<c<0N7Qh061PH00W9bL0a<C40;:b/P1[
Jf/0>3Ph024Q8@0o?cl0G5aL02HV9P16ATH0RHV901cooooo03<0Y:BT0<K6aP2n_[h0Z:RX0:f][@1=
CDd0EUIF02/[:`1`L700Ogmo05EEE@1fMWH0C4a<05eMG@0A4A403@d=00`<300A4A40410@00h>3P0=
3@d03Ph>065QH@0a<C408B4Q034a<@1DE5@0U9BD06ATI01@D500>c/k01TI6@0C4a<03`l?00d=3@0>
3Ph05QHF02h^;P1LG5`0D51@05eMG@1YJFT0Lg=c0<O7a`3Bd]80_kno034a<@12@T80GemO07=cL`0]
;Bd00P0U9BD0800M7Ad08b<S01/K6`0I6AT0CDe=07EeM@33`l<0E5AD06i^KP2BTY80Ph>307UiN@19
BDT06QXJ01TI6@0N7Qh08B4Q04e=C@1bLW80Rh^;08f=S@1jNWX0KVi^096AT@2XZ:P0QhN707alO01D
E5@0GEeM08B4Q01<C4`06ATI0P0E5AD201@D500g01<C4`0U9BD0CTi>06YZJP0o?cl0=CDe03dm?@1R
HV80KVi^020P800M7Ad06a/K02PX:010@400Lg=c05QHF014A4@0=3@d02h^;P14A4@0B4Q803Xj>P0I
6AT05QHF01TI6@0K6a/0ATI605IFEP0Z:RX0:BTY030`<01<C4`0>SXj02XZ:P0M7Ad0=CDe0<?3``3>
c/h0_;bl0;Rh^01[Jf/0A4A40492@P29RHT0ZJVY07moO`1SHf<0VIVI06=SH`0X:2P0?3`l06ATI02I
VIT0/;2`04i>CP0202DU9@1402<S8`1`L700clo?0=;BdP1GEeL0?3`l03<c<`0l?3`0BDU908N7Q`1o
Ogl0ZJVY09:BTP1NGUh092@T02l_;`1CDe<0I6AT02@T900K6a/0?Shn07IfMP15ADD08B4Q03<c<`1H
F5P0;Rh^02d];@0g=cL0DU9B08^;R`2SXj<0aLG50=CDe02@T900DU9B03Hf=P1@D500G5aL03Xj>P0L
71`08R8R020P800Q8B40AdM704E5A@0`<300@T9204Y:BP0f=SH0OGem09JFUP0M7Ad0820P01dM7@0L
71`0=CDe03`l?01ADE40@T9209bLW02ATI40U9BD02d];@0M7Ad09RHV05IFEP2<S8`201LG5`1:03lo
?`1jNWX0RXZ:0>3Ph03Fe]H0hN7Q0;fm_@0^;Rh0<C4a09nOW`1hN7P071`L01DE5@0I6AT0@T9209NG
U`3Kfm/0bLW909nOW`1mOGd0YjNW09JFUP2KVi/0:BTY01`L701FEUH0PH6105YJFP1dM7@0QhN70;Jf
]P1mOGd0HV9R04e=C@1hN7P0Ph>30:>SX`1GEeL0A4A404i>CP0Y:BT0>c/k03Ti>@0G5aL05ADE01dM
7@0G5aL09RHV09BDU02=SHd0Ph>30:^[Z`2m_Kd0_[jn07moO`1?Cdl0BDU904A4A00o?cl0@D5106QX
J02ZZZX0Fe]K024Q8@0K6a/09BDU0=7Ad@3:b/X0XJ6Q0<;2`P1BDU80>CTi02`/;00f=SHAooooo`00
3oooool0UP1eMGD0KFe]07alO019BDT0IVIV03Ti>@1;Bd/0KFe]03Ph>02DU9@0CDe=02DU9@0o?cl0
I6AT071`L00e=CD0>CTi06i^KP1;Bd/0A4A402LW9`0Z:RX0NWYj04E5A@0i>CT0=CDe02h^;P1?Cdl0
J6QX04A4A00V9RH0GemO05UIF@1GEeL0;2`/03hn?P29RHT0?Shn05MGE`1<C4`0B4Q802d];@0k>c/0
>CTi02HV9P1HF5P0=cLg06ATI017AdL0;Bd]02`/;01HF5P0I6AT03Hf=P29RHT0FEUI028R8P1SHf<0
H61P01lO7`0d=3@0MGEe05=CD`1fMWH0=3@d02PX:014A4@0AdM7024Q8@14A4@0QHF503Lg=`1DE5@0
;bl_01`L701@D500C4a<04I6AP1OGel08b<S05IFEP2GUiL0@D5108Z:RP22PX80@T92034a<@2<S8`0
R8R802LW9`0j>SX0DE5A02XZ:P1ADE40LG5a07UiN@0^;Rh0WYjN04U9B@0c<c<0=SHf07YjNP0d=3@0
MgMg01/K6`1dM7@0N7Qh06m_K`2HV9P0;Bd]05UIF@23Ph<0CDe=0:FUY@1?Cdl0S8b<07UiN@2;Rh/0
KFe]02TY:@1IFET0CTi>03Hf=P13@d<0Bd];02DU9@1FEUH0IFEU04M7A`24Q8@0@41006UYJ@12@T80
SXj>02DU9@1OGel0OWin07]kN`2MWId0UYJF03@d=02BTY80IVIV05=CD`2ZZZX092@T04E5A@3AdM40
DE5A05EEE@80Bd];01P0:b/[05IFEP1@D500=cLg07emO@1EEED0<S8b08J6QP1UIFD0GemO05aLG00b
<S80QXJ60820P01QHF40LW9b0;Fe]@1BDU80Kfm_07alO01DE5@0<S8b0492@P1_Kfl203lo?`1`07em
O@1QHF40UiNG0:VYZ@2CTi<0RHV90;2`/02DU9@0?3`l04E5A@1mOGd0<c<c08B4Q00m?Cd0DU9B08N7
Q`1@D500Ogmo09>CT`1^KVh0];Bd03<c<`2GUiL0WinO05eMG@0V9RH0?Cdm01TI6@1CDe<0GemO07mo
O`16ATH0H61P069RHP1/K6`0D51@05IFEP3;bl/0Vi^K05]KF`0h>3P0J6QX04I6AP1BDU80BTY:0410
@01ZJVX0`l?304i>CP1HF5P0SHf=05UIF@0m?Cd0S8b<06YZJP1bLW80EEEE0:>SX`2=SHd0=cLg08N7
Q`22PX80ADE508Z:RP1/K6`0@T9206MWI`1IFET0?3`l08n?S`1FEUH0MgMg065QH@1FEUH0ADE503`l
?01_Kfl0^[Zj079bLP1QHF40KVi^03@d=00V9RH0@d=3071`L02IVIT0HF5Q08:2PP1SHf<0=SHf05eM
G@1?Cdl0BTY:06EUI@1KFe/0H61P03Hf=P1nOWh0=3@d06EUI@1gMgL0:BTY07alO02;Rh/0BTY:03Ti
>@0X:2P0>SXj04m?C`0Y:BT0CDe=09BDU1cooooo0100Bd];059BDP1[Jf/0UIFE0<;2`P1?Cdl0A4A4
03`l?00Y:BT0=3@d04a<C01BDU80>SXj05ADE00b<S803Ph>0P0=3@d0400>3Ph03@d=010@400P8200
X:2P04=3@`0J6QX0820P02@T9015ADD0K6a/07MgM`1aLG40=SHf02XZ:P0U9BD202XZ:P0n03`l?01K
Fe/0Hf=S06IVIP1cLg<0YZJV0<71`@30`<00WIfM0;Fe]@2LW9`0HF5Q096AT@2;Rh/0;2`/02<S8`0Q
8B408R8R024Q8@0X:2P0@D5107YjNP2RXZ80];Bd09>CT`1mOGd0Cdm?03@d=019BDT0OGem06QXJ012
@T80Cdm?03Xj>P0d=3@0NGUi0;Ng]`1YJFT0DU9B06i^KP2/[:`0c<c<0<[:bP1UIFD05aLG01TI6@1V
IVH0HV9R02HV9P0F5QH051@D01<C4`0B4Q805ADE03`l?00o?cl0A4A402XZ:P0R8R80:BTY02l_;`0g
=cL201DE5@0>01LG5`0J6QX0:2PX04=3@`1IFET0@d=3055AD@0R8R80;bl_07emO@1cLg<0=CDe028R
8P0Y:BT205UIF@0K03dm?@0X:2P08R8R01`L700O7al0Bd];06m_K`1iNGT0MGEe08b<S02OWil0^KVi
0:j^[P2OWil0DE5A09VIV@1HF5P0>3Ph02/[:`0d=3@0ADE5079bLP2MWId0SXj>08:2PP2j^[X0YjNW
00<0:2PX01L0<c<c061PH02j^[X0eMGE0;bl_02^[Zh0];Bd0:ZZZP32`/80>c/k01`L7020P800aLG5
0;2`/01FEUH0A4A403hn?P1RHV80GemO04Q8B01WIfL0=cLg01/K6`0201TI6@0@0410@013@d<0;2`/
02DU9@0Z:RX0BTY:09NGU`2k^k/0_;bl08F5Q@1^KVh0GUiN04];B`0Q8B40=SHf03hn?P<071`L02D0
;2`/0492@P0b<S80EEEE02d];@1QHF40Shn?04A4A00F5QH06QXJ02DU9@0_;bl08R8R02HV9P0f=SH0
5aLG05=CD`20P800TY:B0:j^[P1hN7P0Shn?0=GEe@1gMgL0C4a<05UIF@22PX80^[Zj0=3@d03EeMD0
fm_K0=;BdP2i^KT0UiNG0<C4a01HF5P06QXJ00805ADE01<0;2`/05IFEP1CDe<0VYZJ04U9B@0R8R80
9bLW06IVIP23Ph<0@41007AdM00b<S80=SHf0<c<c034a<@0Vi^K07YjNP2LW9`0WYjN0080VIVI02@0
YjNW0;jn_P1>CTh05aLG01dM7@0U9BD08B4Q01TI6@1IFET0AdM702l_;`0K6a/05ADE01XJ6P0l?3`0
cLg=09FEU@1jNWX0^k^k09^KV`0g=cL0<S8b03/k>`11@D40?3`l03Ph>01OGel0/[:b06ATI00M7Ad0
7QhN03lo?`2g]kL0I6AT02h^;P21PH42028R8P0302HV9P0[:b_ooooo013ooooo000?ooooo`0X07Mg
M`1iNGT0P82004U9B@1jNWX0@41005eMG@10@4009BDU08V9R@1bLW80<S8b04=3@`1DE5@0Hf=S07Qh
N01PH600UIFE06EUI@1CDe<0B4Q804M7A`2BTY80De=C03Xj>P1EEED0?Shn05EEE@1[Jf/0ATI602LW
9`1LG5`0E5AD05QHF00S8b<0F5QH0:FUY@1@D500HV9R04m?C`80CTi>0?P0?clo04A4A01SHf<0RXZ:
0492@P1KFe/0BDU9038b<P0Y:BT0RXZ:05eMG@0d=3@0SHf=0410@00[:b/0JFUY04e=C@0O7al0>c/k
06e]K@1CDe<0QhN703`l?00`<300@T92075aL@0_;bl0<c<c06QXJ00Z:RX0Cdm?02l_;`0^;Rh0H61P
04=3@`14A4@0De=C03/k>`1eMGD0VYZJ04=3@`2=SHd0QXJ60410@01>CTh0_;bl0:>SX`0j>SX0?clo
051@D00[:b/0A4A405mOG`1WIfL0:b/[09VIV@16ATH0ADE504=3@`1hN7P0=3@d05mOG`0W9bL0I6AT
05YJFP1bLW80PX:201/K6`1CDe<0LG5a04=3@`2EUID0@T9206YZJP1FEUH0Ph>306EUI@0m?Cd0D51@
05MGE`0g=cL0@d=303Ti>@0b<S80KFe]04a<C011@D40Lg=c05ADE01<C4`0>SXj08F5Q@0];Bd0>SXj
07=cL`1[Jf/0YZJV08R8R01=CDd0UIFE06YZJP1CDe<0TI6A02h^;P14A4@0QHF507YjNP1YJFT0FEUI
05IFEP0e=CD0N7Qh07MgM`16ATH0PH6107YjNP1:BTX0VIVI069RHP1/K6`0FEUI01/K6`1bLW80Fe]K
055AD@1hN7P0_Kfm06ATI028R8P0XJ6Q06IVIP0g=cL0?Shn055AD@0H61P0De=C0:n_[`1>CTh0Ogmo
0:j^[P2>SXh0E5AD08f=S@1kNg/0;Bd]04];B`1gMgL0@T9207IfMP0h>3P0BDU908N7Q`1JFUX0Xj>S
09RHV01ZJVX0[jn_01TI6@1fMWH0SHf=04m?C`0/;2`0Fe]K03De=@1QHF40AdM705aLG00l?3`0J6QX
055AD@1LG5`06a/K05UIF@35aLD0clo?06e]K@0_;bl0K6a/04m?C`1]KFd0Hf=S04M7A`1/K6`0a/K6
04m?C`1kNg/0[:b/069RHP0o?cl0S8b<06YZJP0M7Ad0<30`07UiN@2ATI40>3Ph08^;R`1hN7P0:b/[
05EEE@1PH600?Shn06=SH`1LG5`0<C4a07alO01`L700Kfm_05aLG01MGEd0;Bd]01TI6@0h>3P0NGUi
05iNGP1[Jf/0GUiN06=SH`0^;Rh0BDU907emO@1_Kfl0B4Q809jNWP1YJFT0>CTi069RHP1EEED0ADE5
09>CT`2:RXX0MGEe03`l?02;Rh/0?Cdm08:2PP2OWil0A4A409RHV02=SHd0EUIF03Ti>@0U9BD0@D51
05EEE@0[:b/0F5QH08Z:RQcooooo00T0DE5A04U9B@0m?Cd0?clo09>CT`21PH40?Shn02@T900K6a/0
0P0E5AD08`0J6QX0:2PX04E5A@1;Bd/0:2PX01DE5@0A4A4061PH034a<@1OGel0R8R80:VYZ@2_[jl0
ATI602TY:@0Q8B409bLW061PH02JVYX0Z:RX08^;R`1IFET0JVYZ04Y:BP1@D500EEEE05MGE`1oOgl0
RHV908Z:RP22PX80RXZ:07]kN`2XZ:P0QHF50080Zj^[01D0[Zj^08V9R@1RHV80=SHf02DU9@0N7Qh0
9bLW06IVIP1oOgl0E5AD0410@01oOgl0@T9207AdM01RHV80HF5Q096AT@2c/k<0JVYZ07EeM@1lO7`0
0P1^KVh06`24Q8@0F5QH05eMG@1`L700R8R80;6a/@39bLT0/;2`04U9B@0U9BD05ADE05EEE@1BDU80
Hf=S01PH600C4a<05ADE01LG5`0[:b/0@D5104=3@`0e=CD0820P02<S8`0R8R80<C4a03Hf=P0401DE
5@0?01`L700j>SX0Bd];04i>CP1WIfL0ADE505QHF02PX:00NGUi03Xj>P1PH600MWIf05]KF`0i>CT0
6QXJ00806ATI00h05QHF01TI6@0R8R80Cdm?0:FUY@1aLG40Kfm_05EEE@1cLg<0XJ6Q0:ZZZP2l_;`0
JFUY02d];@8071`L02407AdM01lO7`0Y:BT0_;bl06MWI`1NGUh0Q8B409NGU`1?Cdl0CTi>05aLG01H
F5P0WIfM0=3@d02`/;00MGEe04m?C`1JFUX0Q8B40:2PX01?Cdl08R8R0:n_[`2`/;00ZJVY08J6QP2:
RXX0T92@08n?S`2a/K40a<C40492@P0I6AT00P0G5aL04P0J6QX0820P04E5A@1BDU80@4100451@@1H
F5P0Shn?0;:b/P3IfMT0`/;204a<C00Z:RX0820P01`L700N7Qh0>c/k04A4A0807AdM02<08b<S0492
@P0m?Cd0UiNG08:2PP2ZZZX0LG5a01dM7@0C4a<05ADE01/K6`0T92@071`L028R8P0];Bd04a<C01LG
5`1NGUh0QHF50<O7a`3?cll0UYJF061PH01_Kfl0QXJ607EeM@1SHf<0QHF508>3P`2_[jl0[Jf]0:2P
X02i^KT0bLW904U9B@0201DE5@0o01HF5P0R8R80>c/k06=SH`1YJFT0Ti>C02l_;`0h>3P0IFEU071`
L02k^k/0JVYZ04A4A02ATI40ZJVY0:^[Z`2?Shl0[Zj^0:BTY02?Shl0XJ6Q0;no_`39bLT0aLG50<O7
a`0m?Cd05ADE01/K6`0P8200E5AD04=3@`1VIVH0NGUi04a<C01OGel0>SXj02<S8`0_;bl0f=SH0=CD
e02h^;P0[jn_069RHP0[:b/0;bl_02/[:`0/;2`0:2PX034a<@1DE5@0UiNG05MGE`0M7Ad0820P06AT
I02>SXh0ADE501lO7`1eMGD0CDe=034a<@0g=cL0@410017ooooo000?ooooo`2>0:6QX@1bLW80NGUi
03/k>`1`L700@T92069RHP0e=CD09bLW071`L01cLg<0<S8b03`l?01:BTX0AdM7061PH01DE5@0MGEe
055AD@1dM7@0DE5A05EEE@2DU9@0FUYJ05EEE@1[Jf/0=cLg059BDP1XJ6P0>CTi03Ph>01[Jf/0E5AD
059BDP0@4100Fe]K096AT@17AdL0De=C04U9B@0/;2`0@41003De=@0^;Rh09bLW05MGE`10@400H61P
03dm?@0V9RH05aLG05QHF01@D500=SHf08:2PP0E5AD0J6QX09ZJVP1BDU808R8R0410@012@T80DU9B
09RHV01XJ6P0=cLg0410@023Ph<0;2`/03Hf=P1IFET06a/K05=CD`0T92@0<C4a05eMG@0m?Cd0CDe=
04i>CP12@T80KVi^07EeM@0l?3`0T92@07emO@0R8R8092@T069RHP1cLg<0;Bd]03hn?P1XJ6P0>CTi
05]KF`1^KVh0JFUY02XZ:P2OWil0EeMG0451@@12@T80Ng]k03Xj>P1SHf<0B4Q805YJFP19BDT0Lg=c
05YJFP0h>3P0ATI606QXJ00m?Cd0RHV906][J`1aLG40DU9B07]kN`1GEeL0?Cdm05iNGP1LG5`0@T92
055AD@0j>SX0A4A408f=S@1@D500CDe=092@T01UIFD0H61P03/k>`1cLg<0Kfm_055AD@1fMWH0MgMg
09jNWP2ATI40EEEE0:FUY@80HV9R0980TY:B04=3@`1jNWX0XJ6Q05]KF`1MGEd0LW9b04E5A@0`<300
Vi^K09VIV@0o?cl0OWin05]KF`0];Bd0X:2P05MGE`1gMgL0E5AD04Y:BP2JVYX0Fe]K04i>CP27QhL0
_[jn069RHP1mOGd0R8R805QHF00g=cL0FUYJ06a/K00Y:BT0=cLg07=cL`12@T80OWin0;fm_@2EUID0
PX:207YjNP1KFe/07alO04=3@`1IFET0TY:B05YJFP0f=SH0BDU9071`L00^;Rh0J6QX09:BTP1>CTh0
Zj^[028R8P1OGel0JVYZ03/k>`0d=3@0HF5Q03@d=027QhL0D51@04m?C`0S8b<0JVYZ04e=C@1DE5@0
9BDU04Q8B01bLW80Shn?07UiN@0V9RH0BDU903Xj>P2j^[X0WinO04E5A@1^KVh0_[jn02h^;P1OGel0
XJ6Q06IVIP0l?3`0XJ6Q07inOP1LG5`0C4a<06ATI022PX80=SHf09ZJVP2=SHd0CTi>059BDP1ADE40
>3Ph05]KF`1RHV809bLW08^;R`2ATI40IVIV06QXJ01SHf<0KVi^02LW9`0^;Rh0MWIf05iNGP27QhL0
XZ:R06a/K00n?Sh0EEEE0;2`/011@D40>c/k09^KV`1kNg/0=3@d05EEE@1>CTh0;Bd]069RHP1^KVh0
H61P03`l?01/K6`0>CTi08b<S02MWId0ATI609fMW@2:RXX0<C4a04I6AP1KFe/0PX:203dm?@0`<300
GemO07MgMacooooo03<0Cdm?04Q8B01=CDd0GEeM09FEU@39bLT0I6AT01/K6`0I6AT05ADE01<C4`0D
51@04a<C01XJ6P1TI6@0L71`07UiN@1eMGD0Kfm_069RHP0l?3`0:BTY02HV9P0k>c/0QhN705IFEP0m
?Cd0<C4a0410@02<S8`0^KVi0=[JfP3>c/h0ZZZZ07EeM@1UIFD0Jf][05=CD`0h>3P0EEEE03/k>`1J
FUX0R8R807=cL`1VIVH0[Zj^08Z:RP1lO7`0T92@03lo?`0];Bd00P17AdL00`1JFUX0PH6103Ph>002
01DE5@0Y04I6AP0_;bl0820P01`L702][Jd0alO7096AT@1WIfL0=SHf03dm?@2b/[80PH6106m_K`1n
OWh0Shn?07]kN`1WIfL0F5QH051@D02QXJ40MGEe08V9R@1=CDd06a/K02l_;`1[Jf/0KVi^02PX:00E
5AD04A4A02`/;01>CTh0<C4a075aL@0d=3@07QhN01`L700M7Ad092@T03Lg=`0F5QH00`0E5AD07P0F
5QH08R8R0:>SX`32`/80_Kfm0;^k^`39bLT0emOG0;fm_@1oOgl0TI6A06m_K`1YJFT0ADE503Hf=P0T
92@06ATI01PH600F5QH071`L03dm?@1YJFT0WinO09VIV@1BDU80@d=304Y:BP2;Rh/0^KVi0410@080
6a/K040071`L01dM7@0L71`08B4Q08R8R00a<C40GemO0820P023Ph<0LG5a0451@@1HF5P0QHF50:^[
Z`2WYjL0`<3004=3@`0];Bd09bLW03Ph>00b<S80KVi^0:NWY`1iNGT0AdM7065QH@0];Bd092@T034a
<@19BDT0NGUi0:NWY`0l?3`05ADE01TI6@0G5aL06QXJ01`L700^;Rh0Cdm?05IFEP1KFe/0ZZZZ0<S8
b031`L40W9bL09nOW`0d=3@09RHV024Q8@0L71`07AdM02@T900k>c/0=cLg03<c<`1BDU80R8R80;Fe
]@3Hf=P0hN7Q0<K6aP2<S8`06a/K0P0E5AD0AP0K6a/0<c<c01hN7P0a<C40;Rh^014A4@0E5AD0EeMG
09NGU`2b/[80S8b<04=3@`1RHV80H61P06YZJP1hN7P0Xj>S0<o?c`2TY:@0PH610:RXZ01<C4`0MWIf
09RHV00G5aL05ADE01<C4`0G5aL09RHV04i>CP1jNWX0PX:209bLW01?Cdl0G5aL03hn?P0U9BD0B4Q8
0<W9b@2>SXh0]KFe0<C4a02>SXh0:RXZ0:RXZ039bLT0]KFe09nOW`1aLG40@4100451@@13@d<0QhN7
03<c<`0S8b<0B4Q802`/;00V9RH0?3`l07MgM`1NGUh0>c/k08B4Q01gMgL0W9bL0<K6aP3Ng]h0d];B
0:BTY013@d<201XJ6P0B01lO7`0R8R806QXJ01hN7P0];Bd0I6AT05eMG@0];Bd0:b/[09jNWP1]KFd0
<C4a02XZ:P1iNGT0Bd];04E5A@1CDe<0IVIV4Oooool000oooooo0=80N7Qh06YZJP20P800@T9206a/
K00o?cl0IFEU07emO@17AdL0T92@08Z:RP0d=3@0?clo07alO01WIfL0GEeM04Q8B01KFe/0<C4a069R
HP17AdL0?3`l07YjNP0c<c<0IFEU06=SH`0d=3@0Bd];05YJFP0Z:RX0<30`069RHP1DE5@0FEUI01XJ
6P1;Bd/0TY:B03De=@1@D500EEEE03hn?P18B4P0;Bd]03<c<`14A4@0LG5a03<c<`1;Bd/0=SHf01TI
6@0W9bL0Hf=S04Q8B00_;bl0QhN703Ti>@0a<C40JFUY04a<C00S8b<0E5AD05IFEP0g=cL0L71`0451
@@0Z:RX0D51@08V9R@0U9BD0>SXj05=CD`0K6a/0IfMW02h^;P0f=SH0GEeM03<c<`1MGEd0GUiN04Q8
B02HV9P0Ng]k03`l?029RHT0KFe]04U9B@0i>CT0V9RH07moO`0T92@0CDe=06m_K`0n?Sh0GUiN079b
LP1NGUh0<C4a09BDU01/K6`0E5AD03/k>`1lO7`0BTY:08Z:RP14A4@0GemO04Y:BP1kNg/0Hf=S03Xj
>P1ADE40LG5a04A4A02FUYH0MGEe0820P01ADE40U9BD07moO`1=CDd0I6AT051@D00o?cl0G5aL065Q
H@19BDT0Lg=c05iNGP1BDU80S8b<05mOG`11@D40BDU908^;R`1aLG40I6AT051@D01DE5@0UYJF08Z:
RP1@D500XZ:R03lo?`1fMWH0R8R804A4A02LW9`0XJ6Q0492@P1OGel0Ng]k04I6AP0[:b/0GemO04U9
B@0W9bL0MWIf05EEE@14A4@0PX:205IFEP2@T900Fe]K04Y:BP29RHT0DU9B04=3@`2SXj<0`l?306m_
K`2:RXX0QXJ604A4A00f=SH0JFUY08^;R`0l?3`0IFEU07EeM@0[:b/0Ogmo0;Zj^P2@T900UYJF09jN
WP1TI6@0;2`/06=SH`1kNg/0?3`l05=CD`0b<S80JVYZ06QXJ012@T80TY:B06e]K@0l?3`0Y:BT02PX
:01UIFD0DE5A03hn?P1QHF40NGUi03hn?P1fMWH0D51@05IFEP0Y:BT207AdM00M06m_K`1EEED0T92@
09>CT`2?Shl0Cdm?04Y:BP1BDU80?clo0:>SX`1KFe/0<30`07MgM`2i^KT0ADE505mOG`1kNg/0@d=3
0492@P1dM7@0Kfm_07MgM`1/K6`0EeMG06m_K`0R8R80V9RH08b<S01:BTX00P1=CDd0;`0o?cl0KVi^
06m_K`12@T80TI6A071`L01bLW80Ti>C08b<S01hN7P0;Bd]03@d=01fMWH0CTi>059BDP1^KVh0RXZ:
055AD@1oOgl0_[jn08R8R01YJFT0Rh^;07=cL`11@D40OGem07EeM@0n?Sh0HF5Q06IVIP1QHF40BDU9
08V9R@0d=3@0R8R808F5Q@1;Bd/0_Kfm09BDU016ATH0>3Ph02`/;01@D500CTi>03De=@1]KFd0W9bL
01cooooo00P0Q8B406][J`20P800NWYj07]kN`2RXZ80/;2`04Q8B0807alO07@05QHF01DE5@0C4a<0
51@D05IFEP1_Kfl0B4Q803`l?015ADD0A4A403Hf=P0];Bd08B4Q01`L700X:2P0DE5A06a/K02:RXX0
W9bL09ZJVP39bLT0aLG50<O7a`1HF5P0;Bd]02PX:00U9BD0:BTY04Q8B01<C4`0>CTi01dM7@0I6AT0
O7al08F5Q@1`L700PH6107QhN01gMgL0VIVI08F5Q@2=SHd0R8R8055AD@0[:b/09bLW03/k>`1HF5P0
@d=302/[:`0Q8B40<C4a06UYJ@1VIVH0I6AT02l_;`0g=cL0CTi>0:n_[`28R8P0EUIF03lo?`0R8R80
6a/K01XJ6P0K6a/071`L06UYJ@2NWYh0Ti>C06EUI@1FEUH0=cLg05]KF`25QHD0XZ:R07QhN01MGEd0
IVIV07EeM@1kNg/0UiNG0:f][@1gMgL0H61P04e=C@1:BTX0FEUI01hN7P0F5QH05ADE01HF5P0K6a/0
;Rh^05YJFP1YJFT0W9bL08B4Q01iNGT0KFe]06YZJP2][Jd0NWYj061PH01>CTh0ATI6055AD@1BDU80
FUYJ04Q8B01;Bd/0I6AT07]kN`1VIVH0E5AD03<c<`808B4Q01D08b<S04=3@`2DU9@09BDU038b<P0S
8b<07AdM01`L700M7Ad07QhN04A4A01EEED0@41003De=@1[Jf/0H61P07QhN01ZJVX0JFUY05aLG024
Q8@00P1]KFd0?@1/K6`0IfMW02TY:@0N7Qh0;bl_06YZJP1@D500:2PX05MGE`0c<c<092@T02HV9P0_
;bl0DU9B05ADE01OGel0A4A402<S8`0Q8B409BDU02XZ:P1DE5@0@T9203hn?P1VIVH0IFEU0:b/[02?
Shl0DE5A09^KV`1MGEd0;Bd]028R8P0Q8B407alO020P800W9bL0OGem0:6QX@22PX80YZJV0<71`@3=
cLd0YJFU0:RXZ01jNWX0HF5Q028R8P0E5AD07AdM01`L700N7Qh0:BTY02HV9P0A4A4051@D04=3@`1P
H600/k>c0:>SX`1mOGd00P1`L7009@1aLG40Ogmo06][J`2UYJD0Ti>C05IFEP0S8b<0=cLg096AT@2J
VYX0:2PX02TY:@0i>CT0:BTY03Lg=`1NGUh0P82008R8R035aLD0@T9202HV9P0R8R808b<S02TY:@1U
IFD0e]KF09bLW02UYJD0T92@08j>SP2?Shl0K6a/024Q8@0V9RH0>3Ph03lo?`18B4P00P0h>3P09@1f
MWH0M7Ad06i^KP0T92@0<30`034a<@1iNGT0`l?30;bl_02][Jd0Ti>C0:BTY031`L40dm?C0=KFeP3E
eMD0Lg=c02DU9@0L71`06QXJ02<S8`0^;Rh0@d=305YJFP2CTi<0XZ:R09fMW@31`L40e=CD07inOP1?
Cdl0HV9R0820P00I6AT05QHF01DE5@0J6QX04Oooool000oooooo0340LW9b06=SH`2e]KD0A4A406e]
K@18B4P0QXJ607QhN015ADD0RHV908B4Q00g=cL0E5AD09FEU@1SHf<0GEeM05YJFP2:RXX0DE5A05AD
E01=CDd0;bl_09VIV@1?Cdl0F5QH05UIF@15ADD0KFe]07QhN010@400<C4a04=3@`0V9RH0JVYZ01hN
7P1LG5`0UYJF02<S8`18B4P0HF5Q02l_;`0d=3@0:RXZ04=3@`14A4@0K6a/02DU9@1<C4`0EUIF0080
>c/k01/0GemO038b<P0^;Rh0OWin02/[:`0g=cL0LW9b02DU9@0k>c/0MGEe05iNGP0c<c<0HF5Q04Q8
B00U9BD0MGEe08J6QP0n?Sh0<S8b05=CD`0H61P0J6QX02XZ:P0`<300F5QH03<c<`0n?Sh00P19BDT0
;02ATI40Ogmo04A4A02KVi/0Shn?05ADE00k>c/0Vi^K05aLG00L71`0@D51075aL@0k>c/0K6a/07]k
N`1mOGd0=3@d0:ZZZP1SHf<0=CDe03Ti>@28R8P0BDU907EeM@0l?3`0Q8B406MWI`2=SHd0MgMg0451
@@1bLW80KFe]03Ti>@1lO7`0H61P09fMW@1HF5P0TY:B07=cL`13@d<0NGUi05QHF016ATH0I6AT0P0j
>SX0Y01/K6`0EeMG05]KF`1_Kfl0H61P03dm?@1BDU80KVi^04E5A@1cLg<0Ng]k06i^KP2=SHd0QXJ6
04e=C@2d];@0FUYJ07emO@1YJFT0ADE508n?S`2>SXh0DU9B05eMG@1]KFd0C4a<0451@@1oOgl0LW9b
03Lg=`1aLG40Fe]K04];B`2?Shl0CDe=08V9R@1VIVH0DU9B0:f][@1XJ6P0BTY:0:JVYP2][Jd0IFEU
0;>c/`2DU9@0DU9B03<c<`1XJ6P0EEEE03De=@1YJFT0QXJ603De=@26QXH0b/[:065QH@1/K6`0S8b<
059BDP0N7Qh0A4A404i>CP1SHf<0F5QH03<c<`1cLg<0@41004E5A@2JVYX0I6AT03`l?02<S8`0;2`/
07UiN@1FEUH0:BTY04M7A`16ATH0<c<c08n?S`1nOWh0G5aL01XJ6P1JFUX0De=C04e=C@1BDU80VIVI
0<;2`P2][Jd0De=C04I6AP1PH600DU9B0<C4a01/K6`0?3`l06e]K@2WYjL0@41008R8R02MWId0EeMG
04A4A02DU9@0OWin05ADE01TI6@0WinO08:2PP0T92@0U9BD08R8R01=CDd0O7al06m_K`16ATH0Fe]K
05QHF014A4@0Rh^;06ATI01iNGT0[Jf]09^KV`1?Cdl0@T9206a/K01mOGd0GUiN07=cL`2;Rh/0LG5a
04U9B@2b/[80`l?307QhN01FEUH0X:2P04a<C00T92@0FUYJ05aLG014A4@0TY:B08B4Q01MGEd0>3Ph
07QhN01@D500[jn_07=cL`0h>3P0Shn?09^KV`1]KFd0AdM705EEE@2[Zj/0?Cdm02TY:@1[Jf/0MgMg
7?ooool08`2_[jl0_;bl07EeM@0n?Sh0;2`/028R8P1YJFT0X:2P04I6AP0N7Qh06ATI01LG5`0D51@0
61PH04i>CP0E5AD06ATI01/K6`0M7Ad06ATI01lO7`0b<S80IVIV06=SH`1QHF40RXZ:0:NWY`33`l<0
b<S80=WIf@3GemL0b/[:06e]K@0N7Qh06QXJ00<05ADE0P0G5aL01@0^;Rh0I6AT06IVIP1kNg/09BDU
00806a/K01h07AdM04];B`3@d=00`<300<o?c`0a<C405ADE01PH600R8R80QhN706][J`1HF5P0EEEE
075aL@0l?3`0JFUY05eMG@13@d<06ATI01DE5@0J6QX0Kfm_028R8P0G5aL061PH01HF5P0L71`07alO
02TY:@0b<S8209bLW00_09VIV@1CDe<0:BTY061PH01ZJVX0^KVi0:JVYP29RHT0[Zj^09JFUP1eMGD0
Fe]K07=cL`2RXZ80Y:BT08V9R@24Q8@0KFe]04U9B@1CDe<0KVi^03Hf=P0/;2`0ADE503Ti>@1NGUh0
LW9b05iNGP0b<S8071`L01/K6`0N7Qh0JFUY03Lg=`0Q8B407alO01dM7@0L71`07alO02h^;P1LG5`0
/[:b0=KFeP1aLG40F5QH051@D00N7Qh00P0L71`01`0M7Ad0L71`08N7Q`0L71`07AdM03@d=00];Bd0
0P0L71`03P0M7Ad0?3`l079bLP0e=CD09BDU069RHP1>CTh0EeMG03Lg=`0`<300G5aL03De=@0O7al0
@D510P0k>c/0?P0O7al07AdM02d];@0l?3`0GUiN03@d=00m?Cd0<C4a02/[:`0j>SX0EUIF08Z:RP21
PH40@d=308N7Q`23Ph<0EEEE04A4A00e=CD0;bl_0451@@0h>3P0@T9204A4A02IVIT0UIFE055AD@1g
MgL0<S8b08J6QP1ADE40=3@d03/k>`1IFET0MgMg0:>SX`1iNGT0Vi^K0<30`03?cll0[jn_06EUI@0l
?3`0L71`04E5A@1CDe<07QhN02/[:`0R8R807QhN02h^;P0];Bd03Ph>01XJ6P1PH600I6AT06][J`0o
?cl0=cLg034a<@0c<c<0=CDe0P0_;bl0;00d=3@0PX:2030`<00N7Qh0:BTY0;jn_P3Ng]h0b<S80;Vi
^@37alL0^KVi0;Bd]036a/H0clo?0=GEe@3Hf=P0QXJ602d];@0U9BD08R8R01lO7`14A4@0d];B06EU
I@1fMWH0Zj^[0;jn_P2LW9`0H61P01DE5@0I6AT05ADE01HF5P0`<300RHV907=cL`2NWYh0K6a/08V9
R@1:BTX0:2PX055AD@2RXZ80c/k>0P3IfMT00`2XZ:P0/;2`0<c<c0020=?Cd`0F0<k>cP2ATI40Bd];
08n?S`2NWYh0/k>c0;Ng]`2UYJD0[Jf]0;6a/@2^[Zh0TI6A06][J`2BTY80`<3008j>SP0j>SX0P820
03`l?00S8b<05ADE01HF5Q7ooooo000?ooooo`3o08:2PP1DE5@0OGem04Q8B01SHf<0@T9207]kN`1Q
HF40?clo08:2PP1:BTX0>c/k06QXJ023Ph<0BTY:02LW9`1>CTh0MGEe04U9B@1BDU808R8R03Hf=P25
QHD0BTY:06e]K@10@4009bLW04A4A01JFUX092@T03Ph>01MGEd0@d=304U9B@0E5AD0NWYj09NGU`15
ADD0A4A403De=@0I6AT0Bd];02DU9@0^;Rh0CDe=07EeM@16ATH0?Cdm03<c<`0J6QX0<30`07YjNP15
ADD0=3@d06][J`0X:2P0G5aL08V9R@0N7Qh09BDU05YJFP1CDe<0ADE507UiN@0V9RH08R8R05MGE`1A
DE406ATI03@d=01<C4`07alO07UiN@0L71`0?Cdm06IVIP16ATH0G5aL03dm?@0d=3@0MWIf06i^KP0b
<S80MGEe05UIF@0T92@0EUIF0:b/[01XJ6P0:RXZ04Y:BP1QHF40?clo059BDP1WIfL0JFUY05=CD`32
`/80VYZJ0410@00];Bd0HV9R06YZJP2=SHd0<30`06ATI01:BTX0W9bL07AdM00Q8B40>3Ph05QHF019
BDT0QXJ602`/;01cLg<0CTi>09NGU`1OGel0:BTY04m?C`19BDT0L71`09fMW@1WIfL0=SHf051@D014
A4@0Ogmo08j>SP16ATH0?Shn07]kN`2:RXX0ATI604i>CP1NGUh0JFUY0<G5a@2NWYh0BDU90:6QX@0j
>SX0Rh^;07EeM@18B4P0Jf][06e]K@12@T80NWYj08^;R`13@d<0Cdm?08V9R@1aLG40=CDe07EeM@13
@d<0DU9B09BDU01DE5@0V9RH04Q8B01FEUH0OGem065QH@15ADD0ZZZZ0:2PX01VIVH0[Jf]07alO01C
De<0I6AT09jNWP27QhL0>CTi05EEE@1IFET06ATI0:ZZZP3=cLd0ZJVY08f=S@2HV9P0@T9204=3@`26
QXH0NGUi03@d=01BDU80D51@0:JVYP1FEUH0BTY:08>3P`1HF5P0ADE50:JVYP0Y:BT0F5QH05ADE00h
>3P0LG5a05IFEP0Z:RX0CDe=03/k>`16ATH08B4Q06m_K`1OGel0ADE502TY:@1^KVh0K6a/08B4Q019
BDT0B4Q80492@P0W9bL0Vi^K05eMG@0k>c/0RHV90;6a/@0f=SH0De=C06a/K00U9BD0Cdm?08Z:RP2L
W9`0H61P05UIF@1HF5P0@T9204I6AP2NWYh0PX:203Lg=`10@400;Bd]04m?C`2YZJT0RHV903@d=01m
OGd0FUYJ065QH@2m_Kd0`<3006e]K@0P8200=CDe000M06QXJ01DE5@0TI6A09:BTP1/K6`0<c<c08f=
S@2SXj<0=cLg05IFEP28R8P0MWIf02LW9`1OGel0CDe=02DU9@1IFET0Lg=c06MWI`0m?Cd0H61P04m?
C`2MWId0VIVI0492@P2d];@0]KFe06MWI`1=CDd00P2RXZ80101?Cdl0;Bd]06][J`1JFUXLooooo`0T
0<_;b`1^KVh0>c/k038b<P0Y:BT07QhN028R8P27QhL0PX:203<c<`0I6AT06a/K01XJ6P0_;bl0@T92
01DE5@0I6AT05ADE02<S8`0Q8B40:RXZ04i>CP22PX80SHf=0:>SX`29RHT0PX:209VIV@2RXZ80]kNg
0=KFeP3?cll0YjNW03Xj>P0J6QX04Q8B100E5AD03@0G5aL0;Rh^09:BTP2`/;007alO018B4P0A4A40
4Q8B01PH6026QXH0B4Q809BDU018B4P00P0E5AD05@0I6AT0IVIV03De=@0`<300<c<c038b<P0h>3P0
MGEe06][J`0h>3P06ATI01PH600O7al0L71`01`L700J6QX06ATI02LW9`0`<300D51@06QXJ00207If
MP0O01TI6@0H61P0:RXZ04=3@`15ADD0^KVi0;Fe]@13@d<0>c/k04m?C`1CDe<0L71`06e]K@1`L700
DE5A04A4A01BDU80IVIV07IfMP1ZJVX0[:b/075aL@1`L700MGEe0410@01HF5P0DE5A02h^;P0Z:RX0
@410028R8P0201lO7`0>05iNGP1VIVH0@D5103Hf=P0Y:BT09BDU02<S8`0P82007AdM04a<C02RXZ80
JVYZ07=cL`0Y:BT201dM7@0E01lO7`1:BTX0aLG50:VYZ@0V9RH071`L01dM7@0`<300:b/[01lO7`10
@400ATI607UiN@0g=cL0:BTY07QhN01BDU80CTi>0492@P0o?cl0G5aL00805aLG00@0:RXZ03Ti>@0`
<300;Bd]0P0O7al0<`0f=SH0KFe]05ADE01<C4`0AdM701hN7P0V9RH0>3Ph05ADE01VIVH0GEeM06UY
J@1hN7P0CDe=03Lg=`0f=SH0@41004=3@`1ZJVX0D51@07YjNP2c/k<0b<S80;Fe]@1_Kfl0>c/k09bL
W031`L40[jn_09VIV@1VIVH0GEeM08n?S`2<S8`0KFe]03`l?00e=CD0GEeM06=SH`1>CTh0<30`05EE
E@1KFe/0FUYJ034a<@1CDe<0Bd];04U9B@0f=SH05aLG04a<C00206QXJ00c02<S8`0C4a<05ADE01<C
4`0E5AD04a<C010@400C4a<061PH07UiN@1:BTX0<S8b07QhN03IfMT0[:b/04a<C01DE5@0I6AT069R
HP1dM7@0LW9b08f=S@2h^;P0WinO0;2`/01_Kfl0?Shn028R8P0P8200Bd];0<k>cP2:RXX0OGem0:BT
Y01kNg/0GemO07moO`0X:2P0;bl_028R8P0O7al08B4Q05eMG@3<c<`0TI6A06YZJP1UIFD0YjNW0820
P01eMGD0UiNG0080`l?301`0^;Rh07AdM02XZ:P0LW9b03Hf=P1LG5`0YZJV0:f][@1kNg/0LW9b09fM
W@26QXH0PH6106QXJ00o?cl0D51@07QhN02<S8`0Ng]k075aL@1cLg<0P82005YJFP23Ph<0AdM706MW
I`1/K6`0MGEe4Oooool000oooooo01/0Ogmo05eMG@2HV9P0@D51065QH@0o?cl0MWIf06UYJ@1<C4`0
Shn?07QhN00a<C40ADE508V9R@1DE5@0BTY:04=3@`1SHf<0ADE5079bLP19BDT0:b/[06ATI00V9RH0
BTY:06MWI`0k>c/00P1CDe<0_P0Q8B40;2`/05MGE`1?Cdl0BTY:01DE5@1>CTh0OWin03`l?019BDT0
?3`l01TI6@13@d<0<C4a024Q8@0c<c<0HF5Q04I6AP1=CDd0ADE5020P800S8b<0IFEU05=CD`1:BTX0
J6QX01<C4`1:BTX0IfMW03Xj>P0O7al0IVIV02@T9012@T80JFUY04i>CP1:BTX0UiNG07inOP0M7Ad0
:b/[05aLG00X:2P0R8R803lo?`0[:b/0CDe=034a<@1cLg<0IfMW05QHF024Q8@0Rh^;04Q8B030`<00
TY:B03De=@0k>c/0U9BD04=3@`0f=SH0Ogmo08B4Q00e=CD0GUiN06UYJ@0g=cL0;2`/05mOG`1/K6`0
F5QH03dm?@1;Bd/0B4Q807IfMP15ADD0KVi^03lo?`1dM7@0Jf][034a<@1ADE40BTY:05MGE`1mOGd0
Hf=S08b<S00d=3@0R8R807]kN`0m?Cd0EeMG02`/;00b<S80EUIF061PH017AdL0HV9R04E5A@19BDT0
Kfm_04m?C`0M7Ad0B4Q808R8R01PH600K6a/03Ti>@0^;Rh0Cdm?05mOG`1=CDd0Zj^[01`L701EEED0
IVIV04E5A@29RHT0Lg=c02LW9`1HF5P0JVYZ04];B`10@400FEUI04Y:BP0a<C40NGUi05YJFP1?Cdl0
R8R805aLG02OWil0EeMG04a<C01KFe/0Bd];06=SH`3:b/X0_;bl08R8R02n_[h0MgMg030`<014A4@0
IFEU07=cL`0g=cL0De=C06EUI@0f=SH0RXZ:09bLW01kNg/0R8R807emO@0i>CT06ATI05IFEP1OGel0
Bd];04=3@`17AdL0Q8B407AdM01kNg/0Ti>C04Y:BP0/;2`0KFe]03@d=01_Kfl0;bl_02`/;020P800
Kfm_03De=@1LG5`0Cdm?04Q8B00Q8B40QhN709FEU@1ZJVX0EUIF096AT@2KVi/0SXj>02TY:@15ADD2
03/k>`0K08b<S00b<S806ATI06EUI@2LW9`0AdM706=SH`1TI6@0;2`/03lo?`1XJ6P0IFEU071`L01k
Ng/0JFUY071`L00T92@0NWYj07QhN011@D40CTi>04E5A@0];Bd0Bd];07=cL`0m?Cd0UIFE0080FUYJ
02P0P82007YjNP1[Jf/08b<S03hn?P1bLW80De=C04M7A`1LG5`0Lg=c04A4A02/[:`0UIFE04U9B@0l
?3`0G5aL07inOP0l?3`0P820065QH@0i>CT0EUIF06UYJ@1SHf<0CTi>08>3P`0k>c/0MgMg06e]K@0n
?Sh0c/k>0<;2`P10@4009BDU03dm?@18B4P0CTi>02LW9`1hN7P0TI6A7?ooool01@2PX:00@D5103De
=@0^;Rh09RHV00806QXJ03@0=SHf0;6a/@1DE5@0:BTY01@D500I6AT0G5aL02d];@0E5AD071`L01dM
7@1]KFd0VYZJ0::RXP2;Rh/0L71`06IVIP14A4@09BDU02TY:@11@D40W9bL04E5A@29RHT0`L71075a
L@1nOWh07QhN01DE5@0D51@05ADE01LG5`0/;2`0?clo079bLP2BTY80Zj^[05eMG@0F5QH051@D01<C
4`0E5AD0JVYZ028R8P1OGel0RXZ:02/[:`0g=cL0@D51096AT@1ZJVX0?Shn0P0U9BD04P0X:2P0O7al
05YJFP0U9BD06QXJ01/K6`0o?cl0GEeM01`L700W9bL0>CTi04i>CP1<C4`0>c/k02h^;P1MGEd07alO
00h>3P805ADE02@08B4Q04M7A`2d];@0Zj^[075aL@2CTi<0OWin03Ti>@1<C4`0DU9B04a<C01?Cdl0
Hf=S06ATI01RHV80F5QH07QhN02@T900TY:B0<G5a@2:RXX0P82004a<C00S8b<06QXJ01`L700l?3`0
<c<c02l_;`15ADD0CDe=079bLP1;Bd/0ADE505aLG00k>c/203<c<`0>030`<01@D500W9bL0;Fe]@1f
MWH06ATI02HV9P13@d<0JVYZ09jNWP3Ph>00YJFU05UIF@0e=CD201`L701;03De=@29RHT0CTi>03Hf
=P1MGEd0JVYZ07IfMP3>c/h0][Jf09FEU@1CDe<0S8b<04a<C00F5QH05aLG01TI6@0];Bd0;2`/03/k
>`0j>SX06a/K02/[:`1XJ6P0HV9R07IfMP2g]kL0M7Ad059BDP19BDT0?3`l03Hf=P17AdL0CDe=08>3
P`2HV9P0IfMW05eMG@1NGUh0J6QX075aL@2:RXX0OGem09BDU02m_Kd0a/K60<C4a02OWil0X:2P0:n_
[`2/[:`0_kno0;Vi^@2d];@0MgMg01hN7P0G5aL061PH02@T901EEED0JFUY08:2PP1nOWh0a/K60820
P02?Shl0OGem08F5Q@1fMWH0OWin04M7A`10@400DE5A061PH013@d<05ADE00804a<C00<051@D01DE
5@0E5AD00P0E5AD07P0I6AT0FUYJ0820P021PH40Ti>C0<c<c01[Jf/0;bl_03Xj>P29RHT0Xj>S04U9
B@1=CDd0K6a/0;>c/`2DU9@0IfMW09BDU01<C4`071`L028R8P1KFe/0[Zj^07AdM021PH40Bd];02d]
;@0i>CT0JFUY05mOG`80>CTi02T0>SXj04=3@`2GUiL0_;bl0:2PX02CTi<0RHV90:NWY`0_;bl08b<S
08Z:RP2LW9`0U9BD034a<@0G5aL0>c/k03Xj>P0M7Ad08B4Q06a/K03AdM40_kno0:RXZ01TI6@0@T92
02l_;`0/;2`0BDU905]KF`1_Kfl0M7Ad05IFEP0c<c<0IfMW06i^KP1gMgL0Hf=S04];B`0S8b<0:b/[
03Ph>00Aooooo`003oooool0A01mOGd0D51@08R8R011@D40H61P05IFEP2UYJD0?Cdm02d];@1^KVh0
Hf=S03@d=01DE5@0CTi>05=CD`0l?3`0C4a<03<c<`0V9RH0@T9204Y:BP0`<300SHf=04a<C01:BTX0
M7Ad03Xj>P1;Bd/0K6a/0451@@0d=3@0EEEE04m?C`1iNGT06a/K04a<C020P800=SHf079bLP1XJ6P0
=SHf02DU9@1>CTh0?3`l03Ph>01eMGD0?Cdm06MWI`1`L700=cLg03Xj>P1ADE40<C4a04e=C@1WIfL0
9RHV059BDP1?Cdl092@T04U9B@2@T900C4a<03dm?@1eMGD05ADE01XJ6P10@400B4Q80P0a<C40>@1C
De<08b<S06i^KP12@T80;2`/059BDP0Y:BT0CDe=04i>CP1XJ6P0SHf=04=3@`0Z:RX0IfMW051@D00h
>3P0@T920;Bd]01<C4`05aLG0451@@1TI6@0<c<c061PH01?Cdl0Lg=c038b<P2EUID0Jf][04Q8B00n
?Sh0G5aL05IFEP1UIFD0?Shn08B4Q01DE5@0QXJ606][J`0k>c/0BTY:06=SH`1FEUH0G5aL06EUI@2D
U9@0BTY:096AT@1iNGT0?clo065QH@16ATH0@d=3065QH@1=CDd0ATI606=SH`0206EUI@2Q055AD@1;
Bd/0<S8b04];B`2>SXh0GemO07moO`0l?3`0MGEe09:BTP1oOgl0@410092@T015ADD0O7al06i^KP0c
<c<0QhN705eMG@0j>SX0FUYJ04I6AP0i>CT0@D5105ADE00i>CT071`L069RHP1BDU80ATI609:BTP0d
=3@0JFUY05QHF00k>c/0@d=303hn?P0e=CD0SXj>09BDU01[Jf/0[Zj^06IVIP19BDT0B4Q80820P02A
TI40=cLg05UIF@1_Kfl0?3`l09BDU02UYJD0MWIf08J6QP2?Shl0D51@02HV9P1FEUH0LW9b051@D01c
Lg<0>3Ph07moO`1cLg<0NWYj09bLW01TI6@0L71`08j>SP0Y:BT0J6QX05ADE00/;2`0KFe]06=SH`0_
;bl0E5AD05=CD`1;Bd/07alO05iNGP1@D500CTi>05UIF@2NWYh0UYJF0861P@0l?3`0<c<c03lo?`0m
?Cd0KVi^04Q8B00d=3@0IVIV09BDU00_;bl0H61P05YJFP0f=SH0ATI60861P@1XJ6P0IVIV08R8R02X
Z:P0P82002@T901[Jf/0MGEe05]KF`2>SXh0GUiN04m?C`1HF5P0C4a<03Hf=P2HV9P0H61P08>3P`2I
VIT0Lg=c05mOG`0M7Ad0@D5106ATI01XJ6P0FUYJ06ATI01dM7@0@d=30<c<c02XZ:P0C4a<04I6AP1i
NGT0@d=303Ti>@28R8P0Ogmo04I6AP2?Shl0LW9b03Lg=`1OGel0Ogmo04E5A@2TY:@0HF5Q02<S8`2>
SXh0]KFe08f=S@1;Bd/0UIFE05iNGP1FEUH0>CTi08b<S02OWil07?ooool0C@2d];@0@T9203Ph>00b
<S808b<S01`L700K6a/05ADE05iNGP2QXJ40C4a<01PH600[:b/0J6QX02@T900e=CD0BTY:07inOP2N
WYh0];Bd07moO`0e=CD08B4Q07AdM02CTi<0Bd];03lo?`1KFe/0RXZ:01TI6@0Q8B40RHV909^KV`1D
E5@0Ph>303De=@0T92@0;bl_04m?C`1UIFD0M7Ad04a<C00i>CT0L71`079bLP1HF5P06ATI01<C4`0B
4Q80IfMW02TY:@18B4P0a<C409FEU@1GEeL0=cLg03`l?01PH600Jf][06EUI@0b<S808B4Q08^;R`1T
I6@08R8R01XJ6P0I6AT0ADE504A4A00W9bL0>SXj02h^;P0/;2`0:BTY02`/;011@D40:2PX00@05ADE
00/05QHF03Ph>02QXJ40LG5a09RHV02IVIT0^k^k0820P012@T809BDU01dM7@0201XJ6P0;01`L700U
9BD0>SXj08b<S01fMWH0MGEe07IfMP2j^[X0KFe]01hN7P0L71`00P0H61P0DP0/;2`0M7Ad051@D017
AdL0BTY:09>CT`1>CTh0@D5104M7A`0_;bl0<S8b03/k>`11@D40Jf][0:j^[P2_[jl0U9BD08b<S023
Ph<0M7Ad09ZJVP2ZZZX0IFEU06UYJ@1ZJVX0Cdm?04];B`0Q8B407AdM08J6QP0m?Cd09BDU04I6AP2e
]KD0YZJV0:f][@3?cll0b/[:0<30`03@d=00<C4a01DE5@0F5QH05ADE01hN7P0l?3`0<S8b069RHP0O
7al0:RXZ06i^KP1?Cdl0^;Rh0:NWY`33`l<0GEeM01/K6`0J6QX0820P01lO7`0m?Cd0O7al09fMW@1b
LW80NWYj07AdM01UIFD0J6QX08V9R@2NWYh0QhN70;bl_02GUiL0eMGE0;Rh^01cLg<0AdM703De=@0i
>CT0Cdm?0:^[Z`0f=SH201DE5@0B01LG5`0P8200GemO06YZJP2UYJD0/[:b0<[:bP2UYJD0UiNG09RH
V02DU9@0IfMW05ADE01dM7@0O7al04M7A`1[Jf/07AdM100C4a<0@`0E5AD05aLG01LG5`0E5AD05QHF
03hn?P2NWYh0Jf][05ADE02KVi/0B4Q802/[:`0^;Rh0ATI608f=S@1JFUX0BDU905=CD`2WYjL0T92@
04i>CP1CDe<0WYjN02XZ:P0L71`0LG5a0:^[Z`25QHD0=3@d02h^;P0W9bL08R8R04A4A02f][H0O7al
0820P02>SXh0b<S80=KFeP2i^KT0GEeM024Q8@0U9BD0EEEE04A4A01]KFd0TY:B075aL@1[Jf/06ATI
01LG5`0U9BD0?Shn01hN7P0Q8B40>CTi0:b/[02c/k<0`/;209RHV01HF5P0Cdm?05UIF@0_;bl08R8R
05ADE01WIfL00P1QHF40201GEeL0OGem08b<S01LG5`0Lg=c024Q8@0W9bL09RHV4Oooool000oooooo
0840YJFU065QH@2NWYh0@d=3075aL@0o?cl0EEEE05MGE`0o?cl0QXJ604I6AP1=CDd0[Jf]09^KV`1B
DU80ADE505YJFP2;Rh/0@T9204a<C00a<C40@D5108J6QP17AdL0BDU904m?C`0m?Cd0L71`07emO@0l
?3`0;bl_03@d=00Z:RX0DE5A01XJ6P16ATH0M7Ad03hn?P11@D40?Shn02DU9@11@D40ATI603Hf=P0o
?cl0NGUi03De=@0d=3@0?Shn04I6AP17AdL0DE5A02`/;00g=cL0G5aL02LW9`1JFUX0GemO02/[:`0V
9RH0I6AT04=3@`15ADD0I6AT034a<@0_;bl0FEUI03lo?`0S8b<0CTi>05EEE@0R8R80Lg=c02XZ:P0i
>CT0HV9R03`l?01WIfL0E5AD07MgM`2DU9@0?3`l02l_;`1nOWh0DU9B03@d=010@400^k^k059BDP0a
<C40Cdm?07EeM@0a<C40JFUY05IFEP1[Jf/0=3@d09FEU@1SHf<0@41004Q8B01MGEd0IVIV06][J`14
A4@0QhN704a<C027QhL0F5QH03Xj>P1;Bd/0IfMW075aL@1CDe<0GemO09>CT`1HF5P0MWIf06EUI@0n
?Sh0E5AD0492@P17AdL0H61P0410@013@d<0I6AT065QH@1]KFd00P1:BTX0:`0i>CT0De=C09jNWP1O
Gel0LW9b055AD@27QhL0Ph>308F5Q@14A4@0X:2P04U9B@1fMWH0IFEU02TY:@1^KVh0KFe]04I6AP1N
GUh0CDe=0410@01?Cdl0FEUI04i>CP0V9RH0MWIf06EUI@1CDe<0Z:RX04];B`28R8P0F5QH0451@@14
A4@0?Shn03lo?`2PX:00T92@04m?C`21PH40PX:205ADE01=CDd00P2IVIT0@@11@D40IVIV09JFUP0e
=CD0VIVI09BDU01QHF40XZ:R0<o?c`1/K6`0<S8b05UIF@1^KVh0DU9B05eMG@0k>c/0QHF506MWI`1e
MGD0[Zj^079bLP1OGel0SHf=03<c<`1mOGd0I6AT03Ph>01cLg<0FEUI03Xj>P1SHf<0M7Ad06ATI00/
;2`0EUIF04A4A01EEED0D51@0:ZZZP2SXj<0SHf=0492@P17AdL0?Shn03De=@1XJ6P0Fe]K03/k>`1_
Kfl0Ti>C02XZ:P21PH40O7al03lo?`16ATH0UIFE06YZJP0m?Cd0Hf=S05iNGP1>CTh0GEeM09jNWP1>
CTh0<c<c0080GemO02l0G5aL08^;R`1_Kfl0?clo0:n_[`1^KVh0OGem0;6a/@25QHD0EeMG03Xj>P20
P800LG5a06MWI`1LG5`0MGEe061PH00];Bd0[Zj^08f=S@15ADD0Fe]K09:BTP1fMWH0;bl_05ADE01>
CTh0:BTY06IVIP1jNWX0BDU905=CD`1EEED0De=C0;>c/`1aLG40@4100;>c/`35aLD0GemO059BDP3>
c/h0[:b/01lO7`0P8200Jf][07IfMP0Looooo`050=KFeP1YJFT0?3`l038b<P0W9bL00P0L71`03P0F
5QH08b<S0:j^[P26QXH092@T075aL@1TI6@0KVi^0:NWY`2MWId0Ph>305mOG`1IFET08B4Q0P0E5AD0
6`0j>SX09bLW00l?3`0>3Ph0410@059BDP0/;2`05ADE03Xj>P2<S8`0C4a<0:ZZZP30`<00RHV908b<
S01OGel0=cLg02DU9@0G5aL061PH0410@00d=3@0E5AD069RHP0M7Ad051@D07=cL`0205aLG00A08n?
S`0`<300@T9206][J`1bLW80Kfm_05YJFP1?Cdl0De=C05eMG@2?Shl0DU9B01dM7@0G5aL071`L07=c
L`0^;Rh00P0M7Ad01@0S8b<08R8R02DU9@0a<C40>CTi00805ADE00`05aLG01DE5@0E5AD05ADE01/K
6`1PH600CTi>0:6QX@2FUYH0E5AD04Q8B00O7al201`L700<01/K6`0L71`06a/K01TI6@0N7Qh0ADE5
030`<00Y:BT0EEEE08J6QP15ADD0;Rh^0P0G5aL0>P0I6AT0<S8b038b<P0M7Ad07alO02DU9@21PH40
KVi^03<c<`0Q8B409bLW02PX:00b<S80@d=3038b<P2[Zj/0f][J0<30`02@T900GUiN0:JVYP1kNg/0
;Bd]01hN7P0[:b/0TY:B07=cL`17AdL0EEEE02@T9015ADD0=SHf04a<C01SHf<0@T9207QhN02c/k<0
Ng]k0:JVYP3:b/X0_;bl065QH@0J6QX05QHF01DE5@0G5aL0De=C05QHF01NGUh0>CTi03dm?@2PX:00
WYjN07]kN`1]KFd0[jn_07QhN00L71`201TI6@0/01lO7`0[:b/0P82006m_K`0h>3P0HF5Q07inOP13
@d<0=CDe03/k>`2?Shl0NWYj0:BTY02j^[X0/[:b09RHV019BDT0AdM703De=@0];Bd0<c<c07IfMP18
B4P06ATI01DE5@0G5aL0:2PX03<c<`0S8b<0RXZ:0=OGe`2m_Kd0RHV908f=S@27QhL0S8b<09nOW`2a
/K40]kNg05iNGP1EEED0OGem01TI6@0D51@2010@400301<C4`0E5AD05ADE00805ADE00L05aLG03hn
?P1BDU80GEeM05MGE`2FUYH0>CTi0080:BTY02P0ADE506IVIP0l?3`0@41007AdM00l?3`08b<S065Q
H@11@D40CTi>05MGE`0L71`0SHf=0:NWY`1>CTh07alO02@T900M7Ad08B4Q05EEE@1NGUh07alO024Q
8@0[:b/0Fe]K0<S8b033`l<0D51@028R8P0N7Qh0?Cdm0<?3``2UYJD0JFUY08f=S@0W9bL05QHF01PH
600N7Qh0>SXj0P0R8R805P0g=cL0OGem05ADE01oOgl0=3@d08^;R`1YJFT06a/K01XJ6P0R8R80<C4a
03hn?P1@D500KVi^06ATI01SHf<0NGUi0820P01eMGD0ADE5038b<P0j>SXAooooo`003oooool01`1k
Ng/0EEEE07QhN00j>SX0IfMW04U9B@1XJ6P00P0f=SH0V@2@T900ATI602LW9`1=CDd0MWIf04M7A`0R
8R80E5AD06UYJ@0f=SH0C4a<02<S8`0d=3@0R8R804E5A@1<C4`0A4A4034a<@1KFe/0I6AT03Ph>00k
>c/0KVi^04a<C01SHf<0820P06YZJP1oOgl0DE5A05=CD`17AdL0=3@d04a<C019BDT0=CDe059BDP2@
T900Cdm?051@D019BDT0<C4a04U9B@1/K6`0I6AT061PH01IFET0;bl_08F5Q@1oOgl0>3Ph030`<01S
Hf<0?Shn08B4Q01oOgl0G5aL03Ph>01LG5`0@D5101<C4`1NGUh0Hf=S02PX:01bLW807alO05ADE02?
Shl0A4A4075aL@0i>CT0@d=308^;R`1_Kfl0?3`l07alO01>CTh0<30`06m_K`2`/;00D51@03@d=01C
De<0JFUY038b<P1^KVh0Ph>307]kN`0e=CD0TI6A075aL@0a<C40Bd];07EeM@1RHV80Lg=c05mOG`1o
Ogl0Bd];09>CT`1@D500F5QH07inOP1[Jf/0M7Ad05mOG`1DE5@0XJ6Q065QH@1iNGT0HV9R04];B`1e
MGD0?Shn04Q8B01[Jf/0>CTi04m?C`1lO7`0M7Ad06MWI`1MGEd0KFe]0410@01ADE40Ng]k03dm?@2?
Shl0Fe]K08:2PP2CTi<0PX:204e=C@2CTi<0?Cdm05mOG`1;Bd/0:b/[08B4Q02KVi/0@41005aLG00j
>SX0=SHf05ADE01WIfL0ADE5020P801`L700EUIF0451@@2HV9P0C4a<06UYJ@0204Y:BP1d0451@@1?
Cdl0@T920:NWY`28R8P0DE5A07EeM@2;Rh/0Cdm?04i>CP2TY:@0CDe=02`/;017AdL0P82003Ti>@2>
SXh0V9RH05UIF@27QhL0VIVI05ADE00d=3@0GemO05]KF`1RHV80ATI603dm?@1dM7@0?Cdm06UYJ@2Z
ZZX0KFe]04E5A@2:RXX0=CDe08f=S@1`L700?3`l07MgM`0g=cL0:2PX04A4A01OGel0KVi^030`<011
@D40=cLg03dm?@0c<c<0UIFE09bLW02QXJ40EUIF04m?C`0g=cL06ATI06ATI01cLg<0?Cdm071`L02J
VYX0:2PX051@D01HF5P07alO04];B`1eMGD0OWin07=cL`1WIfL0N7Qh03hn?P0^;Rh0JVYZ06UYJ@0k
>c/0EUIF01hN7P0W9bL0G5aL07inOP15ADD0Vi^K030`<017AdL0YZJV0:b/[011@D407QhN051@D01]
KFd0ATI608>3P`2WYjL0Ph>304=3@`2c/k<0Kfm_02d];@0c<c<0HV9R08Z:RP0l?3`0HV9R06UYJ@0m
?Cd0G5aL06e]K@0k>c/0Fe]K05IFEP0f=SH0L71`065QH@0[:b/20<K6aP0803Ti>@0Y:BT0CTi>06e]
K@0n?Sh09BDU06UYJ@1cLg<Looooo`070:FUY@2d];@0GUiN03@d=00Y:BT07AdM01/K6`0201PH600;
071`L02`/;00WinO0<K6aP30`<00WIfM059BDP0j>SX0:BTY01lO7`0I6AT00`0E5AD00`13@d<04Q8B
00h>3P0200h>3P0[02TY:@18B4P04a<C010@400^;Rh0HF5Q07AdM03;bl/0[jn_03@d=00G5aL05ADE
01PH600L71`05ADE02DU9@17AdL0;2`/0451@@1/K6`0ATI60;:b/P2h^;P0[Zj^096AT@0G5aL051@D
01DE5@0S8b<0BDU907QhN021PH40Hf=S0:^[Z`2OWil0Kfm_03<c<`0W9bL0EEEE0<S8b01VIVH0=3@d
020P800201lO7`0302HV9P14A4@071`L00H05ADE00P06QXJ03Hf=P0O7al0Ti>C07inOP18B4P0=SHf
01PH60807alO01405aLG01DE5@0E5AD05ADE01HF5P0G5aL06QXJ01lO7`0Y:BT0F5QH03Ph>01?Cdl0
7AdM01TI6@0L71`0@41001`L700201dM7@0o020P800a<C40Shn?05eMG@0/;2`09RHV02/[:`0X:2P0
<S8b06MWI`2m_Kd0^KVi09nOW`28R8P0a/K605QHF00U9BD07AdM01hN7P0O7al0=cLg07moO`27QhL0
Bd];06][J`1DE5@0IVIV09VIV@1OGel0JVYZ0<O7a`3Cdm<0/[:b09NGU`2m_Kd0W9bL06i^KP1?Cdl0
71`L01DE5@0X:2P0ADE505ADE02WYjL0W9bL0:RXZ03Hf=P0MgMg05QHF01=CDd0:2PX06a/K01<C4`0
6a/K01TI6@0N7Qh0=SHf07MgM`2BTY80IFEU092@T02b/[80TI6A0080Q8B40280SXj>0:n_[`2m_Kd0
];Bd09RHV02@T900@41004Y:BP1;Bd/0@d=303De=@1IFET0UYJF03/k>`0J6QX092@T03Lg=`0N7Qh0
7AdM04=3@`1]KFd0:BTY02HV9P0g=cL0ADE507QhN02b/[80fm_K0;2`/01jNWX0Rh^;07emO@0K6a/0
51@D0`0A4A40C@0@41005ADE014A4@0C4a<05ADE04Q8B00g=cL0LG5a07IfMP2TY:@0;Bd]02@T900i
>CT0RXZ:06ATI00b<S80EUIF05aLG00E5AD05aLG024Q8@1ADE40C4a<0861P@1/K6`0e=CD0<30`011
@D4071`L02<S8`0N7Qh0AdM704U9B@0V9RH07AdM01`L700N7Qh09RHV0820P01nOWh0IFEU02<S8`0R
8R80D51@07inOP1^KVh0Ph>303lo?`0E5AD06ATI01HF5P0L71`0=CDe028R8P0U9BD0=CDe06a/K017
AdL0L71`02HV9P1EEED09BDU01HF5P0G5aL06a/K02@T900_;bl0?Shn05QHF02NWYh0K6a/06ATI02D
U9@0W9bL09jNWP1aLG40MWIf017ooooo000?ooooo`0=08J6QP1RHV80[Jf]03`l?01^KVh0CDe=07If
MP12@T809RHV06m_K`1ADE40?3`l07=cL`0203lo?`3o03@d=01?Cdl0:BTY02<S8`12@T80@d=304A4
A01nOWh08R8R05]KF`1^KVh0@410079bLP1]KFd05aLG03<c<`1FEUH0JVYZ06m_K`0A4A40De=C08b<
S01ADE40IfMW0410@00Q8B40?3`l04i>CP0F5QH0<S8b071`L00e=CD0F5QH04m?C`0@410092@T04Q8
B012@T80EeMG03lo?`0F5QH0EEEE06QXJ00c<c<0<S8b05eMG@0L71`0B4Q806ATI01=CDd0CTi>09FE
U@1OGel0<S8b04e=C@1SHf<09RHV07alO00n?Sh09bLW05mOG`11@D40IFEU04a<C01KFe/0Ng]k04];
B`0i>CT0UIFE05YJFP0V9RH0?3`l06YZJP10@400<C4a05IFEP1WIfL0820P03Ph>01OGel0IVIV03lo
?`2/[:`0RXZ:03/k>`0n?Sh0FUYJ06IVIP1IFET0>3Ph07EeM@19BDT0W9bL05iNGP0a<C40ATI605YJ
FP29RHT0FEUI03lo?`2@T900Fe]K08b<S01TI6@0;Bd]05ADE018B4P0HV9R08R8R01QHF40BDU9065Q
H@1=CDd0NWYj059BDP1=CDd0;Bd]061PH02ATI40Cdm?06YZJP0j>SX0HV9R0:JVYP26QXH0?Shn08J6
QP0o?cl0DU9B04i>CP0V9RH0?Shn092@T01EEED0GUiN06m_K`14A4@0QXJ60;Ng]`1NGUh0820P06e]
K@1FEUH0Bd];096AT@1?Cdl0K6a/04m?C`1BDU80Bd];05=CD`1=CDd0];Bd08R8R01PH600UiNG0;Bd
]01<C4`0DU9B0:>SX`28R8P0?clo055AD@1LG5`0ATI60;Bd]02QXJ40NWYj08Z:RP2/[:`0?Cdm059B
DP2OWil0Hf=S03<c<`0];Bd0BDU907UiN@1IFET0IFEU09FEU@0j>SX0C4a<08f=S@0e=CD0KVi^04U9
B@0k>c/0U9BD06ATI00`<300ADE5059BDP1?Cdl09BDU0451@@0m?Cd0GUiN04Y:BP2BTY80JVYZ08^;
R`1>CTh0G5aL04=3@`0g=cL0E5AD04];B`10@400WIfM0:6QX@1>CTh0IFEU05=CD`0Y:BT0BTY:07If
MP1MGEd0LW9b06m_K`1dM7@0D51@03<c<`1/K6`0GUiN03Xj>P1HF5P0@D5103Xj>P18B4P0Lg=c055A
D@2WYjL0FUYJ04M7A`20P800SXj>061PH00Q8B40De=C04a<C00k>c/0=3@d06e]K@1/K6`0@d=30<W9
b@2KVi/0@d=303Xj>P1OGel0GUiN05QHF02NWYh0Ph>3000D03hn?P1OGel0IVIV030`<01oOgl0MGEe
03/k>`28R8P0?clo01lO7`2EUID0^;Rh07MgM`11@D40T92@051@D00Q8B40:b/[071`L029RHTLoooo
o`0J05EEE@22PX80W9bL051@D00Y:BT071`L01XJ6P0G5aL05ADE061PH01[Jf/0/[:b0<;2`P1mOGd0
:BTY01HF5P0G5aL06a/K01dM7@0H61P07QhN01PH600F5QH0EEEE00l?3`0=3@d200h>3P0;01@D501D
E5@05ADE00h>3P0C4a<0Ph>303Xj>P2OWil0HF5Q01LG5`0E5AD00P0H61P0500T92@09bLW02<S8`18
B4P0GUiN04Y:BP11@D40UiNG06m_K`1DE5@0[Jf]07emO@1FEUH0>CTi02h^;P0Q8B407AdM02h^;P1L
G5`0clo?0P3Bd]803038b<P0`/;209jNWP2][Jd0W9bL09>CT`1GEeL0CDe=03Xj>P0R8R80;bl_03Hf
=P805QHF100E5AD03@0G5aL0:RXZ03De=@0K6a/0R8R807=cL`18B4P0;2`/01HF5P0G5aL05QHF01DE
5@0F5QH00P0H61P0@@0E5AD05aLG01LG5`0T92@0;bl_05IFEP0k>c/0?clo04Q8B00M7Ad09RHV03lo
?`0E5AD06QXJ01TI6@0S8b<09BDU07MgM`29RHT0CDe=04Q8B013@d<0=cLg02l_;`21PH40];Bd0<;2
`P3<c<`0[jn_0:6QX@0[:b/071`L01XJ6P0L71`07AdM01hN7P0b<S80SXj>0:RXZ01/K6`0c<c<09VI
V@2OWil0YJFU06YZJP0n?Sh0IfMW0=7Ad@3Bd]80<c<c02DU9@1>CTh0H61P03`l?00[:b/0B4Q804E5
A@25QHD0][Jf0<K6aP3Hf=P0emOG08f=S@1ZJVX0L71`0080:BTY01h0Ph>303hn?P0J6QX08b<S06MW
I`1mOGd0MWIf06e]K@2EUID0YjNW06ATI014A4@0AdM70:^[Z`31`L40/K6a0;Fe]@1OGel0I6AT04];
B`1<C4`0ATI6030`<00P82006QXJ05YJFP0V9RH0:2PX04E5A@0m?Cd201`L700>069RHP0m?Cd05ADE
01@D500C4a<05QHF01`L7011@D40SHf=09JFUP1/K6`0VYZJ07moO`0/;2`201<C4`0400h>3P0@4100
4a<C01@D50805ADE01@05QHF04e=C@0/;2`0PX:20:j^[P37alL0Ogmo09:BTP2/[:`0aLG50;6a/@1V
IVH0PH61028R8P0E5AD05aLG01/K6`0M7Ad0EeMG0:6QX@80inOW03<0c/k>069RHP0V9RH0>CTi03Xj
>P0i>CT0De=C01XJ6P0G5aL06QXJ01dM7@0O7al0G5aL04e=C@1VIVH0<S8b02XZ:P1VIVH0?3`l07Yj
NP1NGUh05aLG01HF5P0I6AT07AdM01lO7`0c<c<092@T02<S8`0c<c<0GemO02h^;P1`L70092@T04E5
A@0N7Qh05ADE01TI6@0L71`09RHV02/[:`0f=SH0B4Q804M7A`0a<C40D51@08n?S`2][Jd0^k^k0:VY
Z@2_[jl04Oooool000oooooo06<0QHF5051@D024Q8@0@d=306ATI01]KFd0ZZZZ061PH00h>3P0UIFE
02/[:`0g=cL0GemO0861P@0j>SX0:b/[06][J`1QHF409BDU03De=@0Z:RX0@D5107UiN@0d=3@0ATI6
04m?C`0g=cL0P82009VIV@0e=CD0<S8b02l_;`0[:b/0IfMW01lO7`1WIfL0EEEE02@T901HF5P0H61P
02h^;P0Y:BT0F5QH038b<P0l?3`0G5aL01`L701LG5`0EUIF04E5A@17AdL0FEUI04i>CP1NGUh0HF5Q
02@T901hN7P0EEEE02h^;P16ATH0NWYj04e=C@1PH600D51@01`L700W9bL0CTi>04m?C`0a<C40Hf=S
05MGE`0M7Ad0IfMW04];B`0d=3@0Fe]K02HV9P1gMgL0FUYJ07EeM@27QhL0C4a<02d];@1`L700HF5Q
02XZ:P1DE5@0YjNW04I6AP0g=cL0F5QH079bLP0a<C40EeMG05YJFP0d=3@0>SXj05eMG@26QXH00P1K
Fe/0XP11@D40MgMg08B4Q018B4P0JFUY0451@@2TY:@0MgMg0410@01?Cdl09bLW06a/K01ZJVX0De=C
07EeM@0a<C40WinO07moO`0n?Sh0GUiN030`<01<C4`0Jf][06EUI@1ADE40F5QH01TI6@1_Kfl0MGEe
055AD@0D51@0Fe]K08j>SP1@D500QHF50492@P0o?cl0EEEE0820P017AdL0Ph>302l_;`1lO7`0RHV9
03Lg=`11@D40Xj>S03Ph>01XJ6P0IfMW03Ph>017AdL0De=C0492@P0X:2P0IFEU03Xj>P0h>3P0S8b<
061PH021PH40@41006a/K026QXH0MGEe05ADE02o_kl0Shn?03lo?`1[Jf/0Rh^;04Y:BP1KFe/0Shn?
07AdM011@D40IFEU06UYJ@0O7al0QhN708:2PP1PH600U9BD0:b/[00_;bl08b<S06][J`1OGel0FEUI
02h^;P0k>c/0KVi^04];B`1/K6`0WIfM05YJFP1IFET0OWin03Lg=`23Ph<09RHV03Ph>02OWil0K6a/
038b<P17AdL0F5QH03hn?P0Y:BT0LW9b08B4Q01`L700FUYJ0:BTY023Ph<0]KFe02l_;`1EEED0EUIF
03hn?P1IFET0;2`/02h^;P1SHf<0PX:20492@P2;Rh/0LG5a03De=@17AdL0KFe]05YJFP1<C4`0R8R8
0<71`@1IFET0=CDe07=cL`1YJFT0D51@07UiN@1;Bd/0>3Ph04U9B@1dM7@0G5aL0;no_`1^KVh0EEEE
0:6QX@26QXH0H61P02XZ:P1dM7@0DU9B05YJFP10@400LW9b04m?C`0c<c<0[jn_09jNWP80DE5A01T0
K6a/05EEE@0o?cl0BTY:06IVIP16ATH0KFe]05UIF@15ADD0Hf=S065QH@0i>CT0Ogmo07=cL`0j>SX0
Ti>C0<S8b01dM7@0?3`l08>3P`1HF5P0<30`020P8010@400P82001cooooo01T0ATI608N7Q`1RHV80
^;Rh05QHF00M7Ad061PH01LG5`0F5QH0Ng]k05]KF`1WIfL0R8R804M7A`0L71`07AdM01`L700H61P0
5QHF020P801GEeL0:2PX02@T901HF5P0410@00<03Ph>03@0410@04U9B@0O7al04Q8B010@401bLW80
Fe]K07alO00j>SX06ATI01`L700K6a/05ADE01@D500E5AD05QHF01DE5@0Z:RX0EEEE07=cL`2OWil0
Q8B407IfMP18B4P06QXJ03Lg=`1UIFD0NWYj07inOP2<S8`0[:b/0;Zj^P2VYZH0ZZZZ0<C4a02/[:`0
]kNg0=WIf@2g]kL0:b/[03Ti>@1cLg<0EEEE05iNGP1IFET0IFEU01`L700F5QH05ADE01LG5`0E5AD0
61PH0P0E5AD01`0l?3`092@T01PH6020P800Shn?04Q8B00X:2P00P0G5aL00`0F5QH05ADE01LG5`02
01/K6`1W01XJ6P0G5aL05ADE02DU9@0b<S80CTi>04A4A00/;2`0CDe=0410@00a<C40@d=301DE5@0F
5QH06ATI02PX:00P8200BDU902<S8`0I6AT08B4Q04=3@`1^KVh0];Bd0<;2`P2o_kl0b/[:07EeM@1]
KFd0Q8B404i>CP0M7Ad071`L01LG5`0K6a/07AdM020P8010@400X:2P0=SHf02c/k<0bl_;0<;2`P22
PX80>CTi05MGE`2OWil0g]kN09^KV`0n?Sh06a/K01HF5P0J6QX0=SHf09ZJVP27QhL0^[Zj0<K6aP2m
_Kd0`l?309fMW@22PX80WinO08n?S`2][Jd0RHV903Xj>P0l?3`0JFUY05EEE@1DE5@0RXZ:079bLP14
A4@0;Rh^04i>CP1TI6@0;Bd]01dM7@0R8R80FUYJ06a/K01MGEd0Xj>S09BDU01dM7@0JFUY02DU9@0R
8R807AdM028R8P0J6QX0CDe=04m?C`16ATH0E5AD02/[:`0O7al08b<S079bLP0c<c<05ADE01HF5P03
01DE5@0801TI6@1=CDd0Lg=c03dm?@1RHV80TY:B06ATI00F5QH301<C4`0Q014A4@0E5AD04Q8B01@D
500O7al0@T92038b<P2FUYH0c/k>0>;RhP3WinL0fm_K09jNWP2PX:00/k>c0;Ng]`24Q8@05aLG01DE
5@0G5aL06a/K01TI6@0F5QH0S8b<0>CTi03IfMT0dM7A08R8R011@D40?3`l04I6AP13@d<0?clo00@0
5ADE02P061PH04I6AP0`<300F5QH05YJFP0c<c<0H61P03dm?@1[Jf/07alO01DE5@0K6a/071`L01LG
5`0L71`0<30`024Q8@0V9RH0=SHf05UIF@0Y:BT0Hf=S02HV9P10@400:2PX01LG5`0L71`07QhN02PX
:00^;Rh0>SXj04=3@`0M7Ad05aLG024Q8@1`L700YJFU0;fm_@2UYJD0_Kfm4Oooool000oooooo0?l0
YZJV05YJFP2YZJT0AdM707AdM019BDT0Ph>305ADE010@400/;2`06e]K@0e=CD0DE5A08n?S`17AdL0
;Bd]05YJFP1kNg/0>SXj055AD@0a<C40<30`08N7Q`1FEUH0ADE5059BDP0/;2`0DU9B06i^KP0c<c<0
BTY:06MWI`17AdL0EUIF02XZ:P1]KFd0Jf][03`l?01?Cdl0?Cdm02l_;`0b<S80EEEE02l_;`1IFET0
KFe]038b<P14A4@0>3Ph020P8013@d<0H61P03<c<`1>CTh0BDU902@T902?Shl0@D51028R8P0n?Sh0
IfMW03dm?@1dM7@0GEeM03hn?P0l?3`0I6AT03Hf=P0I6AT0J6QX06MWI`0Z:RX0LW9b02LW9`14A4@0
LW9b03<c<`1RHV80?3`l07UiN@1bLW80@T92034a<@1CDe<0AdM702h^;P1lO7`0YZJV03De=@0g=cL0
H61P06EUI@0f=SH0HV9R06EUI@1OGel0@d=308>3P`28R8P0C4a<05eMG@1LG5`0I6AT06=SH`1@D500
JFUY03/k>`2;Rh/0IVIV04m?C`1NGUh0Hf=S08:2PP1OGel0B4Q808n?S`1UIFD0R8R8069RHP13@d<0
OGem055AD@1FEUH0K6a/05eMG@1HF5P0O7al06ATI01cLg<0GUiN06m_K`0e=CD0CDe=07IfMP1ADE40
PX:205ADE01]KFd0QhN7075aL@18B4P0TI6A03@d=01/K6`0CDe=02LW9`1@D500UIFE04a<C01/K6`0
F5QH03Hf=P1cLg<0Ti>C05UIF@0O7al0I6AT059BDP11@D40K6a/05ADE01aLG40Bd];07EeM@1ZJVX0
F5QH05IFEP3:b/X0RXZ:04U9B@1aLG40IfMW038b<P1EEED0YJFU06a/K00g=cL0K6a/08>3P`0h>3P0
RXZ:08J6QP1QHF40Fe]K07emO@1<C4`09RHV06UYJ@1EEED0K6a/04m?C`0h>3P0O7al06=SH`1DE5@0
RHV905UIF@1GEeL0H61P0410@022PX80DE5A03Lg=`1mOGd0?Cdm03Hf=P1UIFD0K6a/04A4A00U9BD0
FUYJ05=CD`1EEED0CTi>0:n_[`2CTi<0X:2P04Y:BP1JFUX0E5AD03Hf=P1cLg<0MGEe04Q8B01^KVh0
TI6A03Ti>@1JFUX0QHF503hn?P1<C4`0K6a/071`L01QHF40M7Ad0:BTY01=CDd0<30`07QhN01NGUh0
CTi>079bLP1IFET09BDU04Y:BP1QHF40IVIV0<K6aP1cLg<0H61P0:>SX`26QXH0AdM7030`<01fMWH0
02<0GEeM04Q8B017AdL0W9bL06i^KP11@D40/;2`0:f][@10@400B4Q808N7Q`1TI6@0H61P055AD@1:
BTX0?Cdm08Z:RP1lO7`0A4A4071`L01CDe<0EEEE0:NWY`1TI6@0?Cdm09RHV035aLD0G5aL0492@P1j
NWX0N7Qh0451@@0V9RH0=cLg07AdM00Looooo`0H0:BTY039bLT0fMWI0=[JfP2ZZZX0BDU902LW9`0U
9BD0JVYZ0;fm_@2OWil0W9bL0;Bd]01QHF40=SHf03@d=00`<3007alO01PH600S8b<0A4A4020P801H
F5P0DU9B0`0?3`l2014A4@0:04E5A@1KFe/06ATI014A4@14A4@0][Jf08N7Q`0/;2`05aLG01HF5P80
5ADE02<051@D01HF5P0E5AD03Ph>014A4@0B4Q8071`L04i>CP22PX80LW9b04e=C@0S8b<04Q8B01HF
5P0M7Ad07alO02DU9@0W9bL0?clo08N7Q`2?Shl0WYjN0<30`02RXZ80J6QX08b<S01jNWX0=3@d034a
<@1;Bd/0E5AD04M7A`16ATH09RHV01HF5P0201DE5@0@01HF5P0H61P0820P03Lg=`1[Jf/0AdM704U9
B@2DU9@0bLW908f=S@1gMgL0C4a<04E5A@0Q8B406QXJ01LG5`806ATI0P0L71`04P0M7Ad0<S8b04i>
CP1;Bd/0K6a/03dm?@0n?Sh0EeMG09RHV01CDe<05QHF01LG5`0R8R807alO02DU9@1>CTh05QHF01DE
5@805QHF00d09bLW0;6a/@1_Kfl0WinO06MWI`1kNg/0a<C4075aL@1bLW80Kfm_04U9B@0n?Sh0;2`/
00809bLW01l0@D5108J6QP2@T900c/k>0=?Cd`3EeMD0YZJV07inOP1IFET0@D51038b<P1CDe<0GemO
05MGE`0o?cl0C4a<07=cL`2[Zj/0fm_K0:RXZ02GUiL0TI6A07moO`1QHF40IfMW06IVIP1lO7`0P820
08:2PP1oOgl0IfMW0080S8b<00h0];Bd0;6a/@25QHD07alO020P800`<300ADE502<S8`0M7Ad08b<S
08n?S`0i>CT0>3Ph06MWI`80KFe]00l0IfMW02d];@0];Bd0>CTi059BDP15ADD0HV9R0:VYZ@2>SXh0
L71`05EEE@16ATH0D51@08V9R@0O7al0100E5AD01P0I6AT06a/K01TI6@11@D40;2`/06QXJ080PH61
00D0Fe]K05IFEP0h>3P09RHV01DE5@0201<C4`0Q01@D500`<300<c<c04i>CP23Ph<0OWin05ADE01G
EeL0EUIF05iNGP1oOgl0Ph>3034a<@12@T80EEEE03dm?@0T92@06a/K01XJ6P0L71`0RHV90<G5a@1]
KFd0?3`l030`<01>CTh0JVYZ06i^KP26QXH0:b/[01HF5P0C4a<051@D00805ADE00/0?Cdm02/[:`15
ADD0Hf=S04];B`1WIfL0B4Q801/K6`0E5AD06ATI01XJ6P0201LG5`0J01/K6`0m?Cd08R8R02HV9P0k
>c/0EEEE02LW9`1LG5`0;Rh^03Xj>P0a<C4061PH01`L700S8b<0;Rh^03Ti>@0k>c/09BDU01`L700J
6QX071`L02LW9`1PH600UiNG0;:b/P33`l<Aooooo`003oooool0H`1jNWX0HF5Q08J6QP13@d<0I6AT
05EEE@23Ph<0<C4a03Lg=`27QhL0GUiN03@d=01<C4`0>SXj06QXJ00c<c<0GEeM05]KF`0n?Sh0JVYZ
065QH@0[:b/0NWYj04E5A@1UIFD0L71`02l_;`1ADE40IfMW020P8011@D40EeMG04=3@`1SHf<07QhN
05aLG01MGEd0>CTi079bLP0m?Cd0A4A4034a<@1?Cdl09RHV04Q8B01QHF40:b/[05=CD`10@4006ATI
03Ph>01VIVH0HF5Q05MGE`0`<3007alO0820P01IFET0;bl_04m?C`1bLW80AdM7059BDP1JFUX0<c<c
05iNGP1iNGT0@41002PX:01WIfL0A4A4020P801iNGT0>SXj03@d=01GEeL0;2`/06i^KP16ATH0Lg=c
06i^KP0b<S80ADE508f=S@1>CTh0:BTY06a/K02DU9@0=3@d05=CD`1cLg<0LG5a02XZ:P1@D500@410
04M7A`1JFUX0TY:B092@T00205YJFP1_04M7A`23Ph<0Ng]k065QH@1<C4`0=3@d08F5Q@1^KVh0Cdm?
05]KF`0i>CT0P82006][J`1=CDd0IVIV03lo?`1hN7P0I6AT04M7A`1YJFT0>c/k059BDP1bLW80HF5Q
05EEE@1IFET0:b/[075aL@1QHF40FEUI01dM7@1KFe/0O7al04A4A01QHF40=3@d04M7A`1dM7@0N7Qh
03lo?`1_Kfl0<30`06m_K`1CDe<0;2`/04i>CP1gMgL0:RXZ05IFEP1>CTh0=CDe06=SH`1BDU80=3@d
02d];@1hN7P0De=C03`l?01VIVH0Kfm_07UiN@0e=CD0EeMG04=3@`0n?Sh0IfMW0=3@d01bLW80>c/k
06e]K@1HF5P0<S8b07=cL`2TY:@0Ph>303Ti>@1^KVh0R8R802d];@2IVIT0MWIf04a<C01UIFD0Ti>C
03hn?P0j>SX0Q8B405MGE`1EEED092@T06UYJ@1lO7`0KVi^069RHP2EUID0?clo04M7A`1eMGD0D51@
08V9R@1GEeL0G5aL0:n_[`1UIFD0?Shn05IFEP1ADE40<S8b03/k>`2DU9@0MWIf0080De=C00`0^;Rh
07alO01eMGD0De=C07moO`0g=cL0;Bd]08N7Q`1VIVH0BTY:08F5Q@28R8P205EEE@0n071`L00c<c<0
IVIV0:6QX@1[Jf/0H61P08R8R02`/;00?Cdm05MGE`2^[Zh0PX:2051@D01WIfL0=CDe02<S8`1LG5`0
H61P06QXJ039bLT0ATI606e]K@2_[jl0V9RH04];B`0U9BD0I6AT03`l?01=CDd0>c/k08F5Q@0n?Sh0
>CTi0<W9b@36a/H0NGUi04e=C@1kNg/0I6AT08N7Q`1KFe/0K6a/04I6AP1VIVH0L71`04M7A`1^KVh0
DE5A03De=@1bLW80Jf][04M7A`1eMGD0`<3002LW9`0T92@0@D5107=cL`1:BTX0:RXZ03De=@1WIfLL
ooooo`0H0:BTY03De=@0i^KV0>[ZjP3YjNT0g=cL0<S8b033`l<0h^;R0=SHf03<c<`0a<C40:j^[P16
ATH0J6QX071`L01]KFd0Fe]K051@D00l?3`071`L01DE5@2BTY80KFe]0P0F5QH0300P8200=CDe06MW
I`2>SXh0];Bd08b<S01LG5`0I6AT0;Bd]03:b/X07QhN01@D50D05ADE00h051@D00h>3P0A4A404Q8B
04=3@`1>CTh0Fe]K02PX:00o?cl0GemO02@T900E5AD04A4A01<C4`805ADE0580;bl_01hN7P18B4P0
`/;209jNWP2EUID0IFEU05MGE`1JFUX0M7Ad01lO7`0E5AD05aLG03hn?P1>CTh09bLW02`/;00V9RH0
=SHf04E5A@1>CTh0>SXj01hN7P1CDe<0dM7A0;2`/02l_;`0];Bd0:>SX`29RHT0GUiN06ATI01_Kfl0
?clo0451@@1:BTX0B4Q804i>CP1?Cdl0>SXj02PX:01IFET0Lg=c0<C4a02c/k<0TI6A09RHV02MWId0
WYjN04Y:BP0P8200:b/[0492@P2MWId0SHf=03Ti>@10@400ATI604m?C`2<S8`0[Jf]0<_;b`3Cdm<0
`<300<o?c`3EeMD0`/;20;jn_P30`<00P82006EUI@2:RXX0FUYJ07=cL`2IVIT0MGEe0;no_`2>SXh0
MgMg0=_Kf`19BDT05aLG100E5AD0=00O7al0FUYJ08n?S`3AdM40b<S80<G5a@3AdM40Fe]K065QH@1E
EED0A4A404I6AP0f=SH08B4Q01`L700O7al0;bl_05eMG@2ZZZX0^KVi0=7Ad@3<c<`0clo?0;Jf]P1N
GUh0F5QH06EUI@1SHf<0J6QX04];B`15ADD0]KFe06e]K@0];Bd0;2`/04m?C`0k>c/0JVYZ04e=C@0c
<c<0RXZ:05QHF00e=CD0JVYZ09BDU03?cll0/k>c0:ZZZP2[Zj/0];Bd0:BTY00];Bd301DE5@0?01TI
6@0L71`0820P01lO7`1QHF40AdM7065QH@1RHV80B4Q802PX:00Y:BT0;2`/03lo?`1BDU80@4100080
5ADE00D0>c/k096AT@2^[Zh0L71`03De=@0301<C4`0Q02PX:02JVYX0V9RH03@d=00f=SH0>3Ph0410
@01kNg/0H61P02TY:@0W9bL0YJFU09RHV01ADE40;bl_03Ph>01LG5`0=cLg07AdM00g=cL0EEEE04Q8
B00U9BD05ADE01PH600E5AD0>CTi02DU9@0X:2P0D51@07=cL`1mOGd061PH00805ADE01h05QHF01TI
6@0K6a/061PH01`L701FEUH0<C4a02@T9010@400MGEe03Ti>@1MGEd0>SXj03Ph>00];Bd061PH02<S
8`0d=3@0>SXj0492@P0U9BD071`L01TI6@0L71`06a/K01lO7`0i>CT0KFe]0:2PX03AdM4Aooooo`00
3oooool0302LW9`0F5QH09BDU013@d<0GemO04a<C01lO7`0BDU90451@@2:RXX0ATI604];B`80Ogmo
00X0B4Q803<c<`1MGEd0@T9201`L700m?Cd0;bl_0410@01PH600;2`/0P0e=CD0]00h>3P0HV9R07Yj
NP0h>3P0EEEE03hn?P0b<S80KFe]02`/;01fMWH0AdM7028R8P17AdL0C4a<04=3@`0T92@0EeMG02h^
;P14A4@0C4a<01dM7@1@D500EEEE03Ti>@0m?Cd0EUIF03`l?01XJ6P0CDe=024Q8@2FUYH0?Shn02@T
901<C4`0Jf][04m?C`1:BTX0C4a<01dM7@0Z:RX0EeMG04Q8B00Z:RX0GUiN059BDP0f=SH0QXJ604Q8
B00g=cL0IfMW02TY:@1YJFT0F5QH0:BTY01_Kfl0AdM703Xj>P1BDU80GemO02DU9@1bLW80S8b<02HV
9P0n?Sh0Hf=S065QH@0/;2`0E5AD04I6AP0o?cl0B4Q8071`L02DU9@0H61P05QHF01EEED0MWIf06UY
J@1DE5@0NGUi05IFEP26QXH0KFe]04m?C`1ADE40IVIV07]kN`1MGEd0DE5A09JFUP1eMGD0UiNG06AT
I012@T80NGUi055AD@18B4P0M7Ad06ATI01@D500JVYZ05iNGP21PH40Fe]K06ATI00m?Cd0KVi^08j>
SP1CDe<0LG5a03Ph>01VIVH0Rh^;06UYJ@0m?Cd0Jf][03Hf=P24Q8@0?clo02LW9`1CDe<0NGUi02h^
;P1GEeL0?3`l03De=@1VIVH0D51@02XZ:P0M7Ad0J6QX051@D00d=3@0BTY:05EEE@1OGel0?3`l075a
L@1QHF40GEeM06UYJ@3Cdm<0G5aL03hn?P1kNg/0HF5Q03dm?@1QHF40XZ:R08n?S`11@D40LG5a0:2P
X00e=CD0]kNg07moO`1@D500O7al08b<S00e=CD092@T08n?S`1QHF40DE5A02XZ:P0e=CD0EUIF05YJ
FP22PX80OWin04e=C@1<C4`0EeMG05=CD`1nOWh0ATI603hn?P25QHD0GEeM0451@@80EEEE01L0CTi>
02`/;01@D500J6QX06MWI`1KFe/0aLG508^;R`1fMWH0?clo05QHF00Z:RX09BDU07]kN`0];Bd0?clo
07=cL`28R8P0CTi>055AD@1RHV80:BTY04i>CP0206UYJ@0i05YJFP2UYJD0c<c<04A4A00h>3P0UYJF
07YjNP1;Bd/0HF5Q04m?C`0Z:RX0?3`l04];B`1TI6@0bLW906MWI`1TI6@0XJ6Q09>CT`1EEED08R8R
061PH01ADE40EeMG04i>CP2GUiL0ATI603Ph>02<S8`0Z:RX075aL@1HF5P0RHV902PX:01iNGT0IfMW
06UYJ@1>CTh0Ogmo05]KF`0a<C40OGem06EUI@0l?3`0QXJ60861P@1GEeL0PH610:RXZ016ATH0<30`
05ADE01dM7@0?Shn02h^;P11@D40OGem01cooooo0380`<300;Rh^038b<P0h^;R0>SXj03;bl/0Shn?
0:RXZ03Kfm/0emOG05eMG@2QXJ40][Jf0:ZZZP1<C4`0ADE505=CD`1[Jf/0T92@08j>SP20P800O7al
0<S8b02k^k/0Ng]k06a/K01WIfL0DU9B030`<00P8200>SXj05iNGP1KFe/0QXJ60;Vi^@3?cll0EeMG
05eMG@1:BTX0=3@d02d];@0Q8B4071`L01LG5`0C4a<05aLG03Hf=P1;Bd/0@T9202TY:@806ATI0400
=CDe04U9B@0E5AD051@D01<C4`0E5AD08b<S02PX:00J6QX0:2PX09bLW01aLG40Fe]K08J6QP15ADD0
;2`/04e=C@1ADE405aLG01DE5@0G5aL0>3Ph08N7Q`1lO7`0Ogmo06EUI@0`<3006a/K01HF5P0E5AD0
GemO061PH02XZ:P0/K6a0;bl_02YZJT0XZ:R09>CT`1kNg/0DU9B04Y:BP0l?3`0;Rh^01TI6@0M7Ad0
:BTY03lo?`17AdL0B4Q807QhN02UYJD0Ph>307inOP2IVIT0YJFU0<71`@3AdM40QHF507emO@29RHT0
c/k>0<;2`P27QhL0MWIf0P1cLg<03P2VYZH0_kno0=KFeP2VYZH0Lg=c0820P02e]KD0ZJVY04U9B@0S
8b<06ATI028R8P1@D500HF5Q0P21PH401`32`/80a/K608F5Q@1<C4`0a/K602LW9`0F5QH0100E5AD0
C00J6QX07AdM07MgM`3QhN40hn?S0;Ng]`37alL0N7Qh04U9B@0Z:RX07QhN01`L700S8b<0=CDe01hN
7P0K6a/06ATI01hN7P1BDU80W9bL0<O7a`2ATI40M7Ad05ADE013@d<0>CTi03@d=013@d<0=SHf020P
800O7al0F5QH0;fm_@0h>3P09BDU03dm?@1EEED0T92@0:BTY02][Jd0DE5A04M7A`1=CDd0J6QX08V9
R@2b/[80G5aL05IFEP12@T80<c<c07alO01VIVH06ATI01DE5@0W9bL07alO01XJ6P0M7Ad0@d=307Ui
N@2:RXX0H61P05EEE@1oOgl0=cLg024Q8@0Z:RX0;Rh^030`<017AdL0IfMW03Ph>01/K6`0b<S80861
P@1EEED201dM7@0;01DE5@0D51@0;bl_09JFUP3IfMT0a<C40;>c/`21PH40@D5103dm?@1[Jf/00P2J
VYX0202g]kL0aLG50;2`/02k^k/0clo?0=?Cd`2YZJT0WYjN0P0E5AD0300Z:RX0GUiN05iNGP1NGUh0
?Cdm03Xj>P1XJ6P0?Shn08V9R@2_[jl0FEUI03Lg=`805QHF01D05ADE01LG5`0J6QX07alO02PX:02E
UID0KVi^04A4A01JFUX0Ti>C03Ph>01^KVh0ATI603/k>`0n?Sh08R8R03<c<`10@400@T9202XZ:P0K
6a/00`0L71`01P0J6QX0=3@d07IfMP2OWil0[jn_0=7AdA7ooooo000?ooooo`3o0:ZZZP1PH600Vi^K
04=3@`1lO7`0EeMG08f=S@1:BTX0@D510:2PX01HF5P0<C4a04i>CP1mOGd0DU9B02LW9`1QHF40LW9b
02TY:@0k>c/0>CTi030`<01nOWh0EUIF0492@P1ADE40:2PX04I6AP1EEED09RHV055AD@1HF5P0>3Ph
05iNGP0c<c<0I6AT071`L00e=CD0De=C04I6AP0k>c/0BTY:08^;R`0^;Rh0@D5106][J`0i>CT0A4A4
03Xj>P0T92@0>3Ph061PH01KFe/0IVIV03Lg=`0U9BD0Rh^;069RHP0_;bl0B4Q807MgM`1;Bd/0Cdm?
05iNGP0b<S80ATI606MWI`16ATH07alO06YZJP1SHf<0<c<c08F5Q@1:BTX0>CTi07=cL`0i>CT0K6a/
04A4A027QhL0Lg=c0410@00l?3`0EeMG069RHP0[:b/0RXZ:09BDU00m?Cd0BTY:055AD@1mOGd0:2PX
05MGE`1?Cdl0EEEE05ADE01lO7`0VIVI05aLG01eMGD0H61P07QhN01NGUh0GEeM08:2PP1QHF40MWIf
05QHF01DE5@0EeMG05]KF`1oOgl0ATI6055AD@2BTY80O7al09jNWP1FEUH0Cdm?06a/K01?Cdl0CDe=
07EeM@1UIFD0EeMG07AdM01IFET0P82004e=C@1TI6@0=SHf07EeM@2<S8`0J6QX06i^KP13@d<0MWIf
08R8R01UIFD0ATI607QhN00h>3P0Ph>303hn?P0i>CT0MgMg09JFUP17AdL0DE5A05eMG@19BDT0J6QX
05iNGP0m?Cd0820P071`L01?Cdl0>CTi05IFEP1ZJVX0LG5a04U9B@21PH40HV9R06e]K@21PH40fMWI
05MGE`17AdL0VYZJ08j>SP0j>SX0C4a<0:ZZZP1gMgL0B4Q808B4Q02BTY80=SHf0;no_`1ADE40<S8b
07MgM`23Ph<0>3Ph02/[:`2d];@0JVYZ07alO00i>CT0?Cdm05YJFP17AdL0GEeM07YjNP1>CTh0H61P
04U9B@1IFET0NWYj04Y:BP11@D40OGem051@D00l?3`0DU9B05iNGP1LG5`0?3`l05YJFP1LG5`0F5QH
071`L034a<@0]KFe096AT@1`L700PX:204M7A`0[:b/0V9RH06a/K015ADD0Rh^;0:ZZZP1GEeL0FUYJ
08B4Q00f=SH0GUiN07moO`1CDe<0ADE507]kN`2XZ:P0>CTi04E5A@2CTi<0BDU9051@D021PH40ATI6
02<S8`19BDT0?clo04];B`35aLD0D51@06a/K02a/K40LG5a04A4A00d=3@0QhN7000S05UIF@1GEeL0
H61P08>3P`1=CDd0=cLg08Z:RP2b/[80E5AD065QH@2DU9@0>3Ph06a/K011@D409BDU04e=C@1oOgl0
L71`03Ti>@1aLG40D51@05mOG`2UYJD0Fe]K02l_;`24Q8@0QHF503<c<`0e=CD0J6QX06a/K00/;2`0
=CDe04a<C01TI6@07?ooool0501cLg<0e=CD0=;BdP3YjNT0cLg=0:b/[01QHF40RXZ:0=7Ad@3EeMD0
];Bd0410@01lO7`0_[jn07=cL`12@T80>c/k04E5A@1?Cdl0Kfm_0P3;bl/0102=SHd08b<S01LG5`0E
5AD201LG5`0;01lO7`0Q8B408b<S034a<@0^;Rh0LG5a0=GEe@3Jf]X0T92@08j>SP29RHT00P2:RXX0
2@1`L700IfMW05eMG@1UIFD0S8b<08N7Q`1IFET0G5aL01XJ6P0201LG5`0J01TI6@16ATH0:BTY01DE
5@0C4a<06a/K02XZ:P0I6AT07AdM03<c<`26QXH0@D51024Q8@0/;2`0ADE505QHF00c<c<0BTY:04];
B`0K6a/0:2PX04I6AP1fMWH0J6QX03Ph>00U9BD301DE5@0_02DU9@1TI6@0<30`075aL@2i^KT0`<30
0;Jf]P26QXH0MGEe07YjNP1TI6@0?3`l03Xj>P17AdL0DU9B04Y:BP0g=cL092@T01lO7`0M7Ad0VYZJ
09BDU01OGel0WinO09RHV02FUYH0N7Qh09JFUP2?Shl0Z:RX0;Jf]P3:b/X0G5aL05EEE@1BDU80EEEE
05eMG@1fMWH0`/;20;:b/P2TY:@0B4Q8061PH030`<00d];B03Xj>P0F5QH00P0E5AD07`0I6AT08b<S
05]KF`1KFe/0XJ6Q0;no_`2@T900FEUI0:BTY00W9bL061PH01LG5`0H61P05QHF01TI6@0K6a/071`L
055AD@36a/H0dm?C09NGU`2NWYh0>SXj028R8P0U9BD07AdM01HF5P0J6QX07AdM02@T900M7Ad00P0L
71`0B`0^;Rh0C4a<09:BTP2j^[X0ZZZZ08f=S@0S8b<09bLW02`/;00l?3`06a/K01HF5P0I6AT0820P
07moO`1kNg/0;2`/02/[:`1WIfL0RXZ:09jNWP24Q8@0GUiN04E5A@0b<S808R8R02d];@1JFUX0E5AD
0451@@14A4@0@D5103<c<`2@T900BDU901TI6@0Q8B407AdM01`L700a<C40FUYJ04=3@`18B4P0=SHf
07emO@2b/[80MWIf03Lg=`0Y:BT09RHV03Xj>P1@D500ADE508n?S`2n_[h0Xj>S05eMG@0Z:RX071`L
01lO7`0E5AD092@T06e]K@34a<@0gMgM0>[ZjP3WinL0iNGU09^KV`20P800GemO09>CT`3Jf]X0c/k>
06i^KP0207=cL`0B0:^[Z`3:b/X0aLG50;Ng]`0M7Ad051@D01DE5@0D51@06a/K038b<P1DE5@0NGUi
0:JVYP2a/K40]KFe079bLP0j>SX0C4a<0`0G5aL01@0K6a/06QXJ03Hf=P1MGEd0SHf=0080X:2P00/0
]kNg0;jn_P1SHf<0P820079bLP1BDU80HV9R04I6AP1?Cdl0Fe]K030`<00201dM7@0901`L700l?3`0
<30`04Q8B01`L700E5AD061PH01oOgl0V9RH017ooooo000?ooooo`1:0;Rh^01UIFD0VIVI0492@P1k
Ng/0GUiN08:2PP19BDT0BTY:0:^[Z`1WIfL0@D5106e]K@2;Rh/0GUiN03@d=01oOgl0OGem02TY:@17
AdL0GUiN03Ti>@2ATI40Fe]K0492@P1aLG40BDU9065QH@1LG5`09BDU05=CD`1TI6@0ADE505IFEP0a
<C40Hf=S06IVIP0f=SH0D51@03lo?`0k>c/0C4a<09ZJVP0[:b/0>SXj06][J`0c<c<0C4a<03De=@0M
7Ad0=3@d06EUI@1mOGd0JFUY03Hf=P0U9BD0OWin05EEE@0_;bl0BTY:075aL@12@T80Cdm?05]KF`0b
<S80CTi>065QH@0W9bL05aLG06QXJ01YJFT0=3@d07MgM`0m?Cd206a/K03F0451@@1YJFT0<c<c09RH
V01jNWX0>c/k03Ti>@1DE5@0B4Q802DU9@2:RXX0TI6A03`l?01EEED0G5aL07UiN@0c<c<0Hf=S06][
J`1MGEd0Fe]K08N7Q`2@T900De=C06][J`1NGUh0QhN705IFEP1cLg<0KFe]05ADE01dM7@0ATI606AT
I01MGEd0BDU907MgM`0k>c/0?clo06m_K`23Ph<0WinO04e=C@0o?cl0MWIf04Y:BP1ADE40KFe]04I6
AP1TI6@0N7Qh05QHF02;Rh/0B4Q807EeM@0e=CD0OWin07=cL`1XJ6P0SXj>05QHF01^KVh0R8R806YZ
JP1KFe/0OWin03Lg=`28R8P0DE5A03Ph>01NGUh0HV9R04I6AP1DE5@0GemO03lo?`29RHT0TI6A05UI
F@0M7Ad0NGUi06m_K`1@D500G5aL07MgM`1aLG40B4Q80820P01dM7@0QHF508V9R@3De=@0FUYJ05IF
EP2XZ:P0SHf=04A4A01HF5P0Ti>C06YZJP0d=3@0JVYZ08^;R`0m?Cd0`/;205IFEP16ATH0Ph>308n?
S`19BDT0=3@d0;Zj^P1CDe<0KFe]02XZ:P19BDT0L71`065QH@1/K6`0UiNG051@D021PH40EUIF07Yj
NP2>SXh0D51@04Q8B026QXH0>SXj0451@@1]KFd0OWin0492@P1DE5@0R8R807AdM00l?3`0BDU908^;
R`1SHf<0LG5a06IVIP2[Zj/0ADE504];B`2/[:`0MGEe05QHF02NWYh0VYZJ03Ph>01^KVh0F5QH02LW
9`1QHF40K6a/0861P@1IFET0L71`0:2PX00T92@0JVYZ0::RXP1PH600=3@d069RHP0l?3`09bLW06QX
J011@D40@4100;6a/@0i>CT0Jf][0<;2`P1oOgl0=SHf01lO7`1MGEd0@d=305MGE`1nOWh0Shn?04m?
C`0j>SX0P8200:^[Z`0n?Sh0E5AD07]kN`0f=SH0Q8B404Q8B01>CTh0@d=3055AD@1dM7@0>c/k08:2
PP18B4P0EEEE0:JVYP2ATI40EEEE08V9R@2HV9P0?3`l03Hf=P26QXH0RHV903Hf=P0`<300:BTY05IF
EQcooooo0900A4A40;Rh^03GemL0i>CT09bLW01TI6@0O7al0<G5a@3?cll0d=3@0<S8b02FUYH0GUiN
09FEU@2IVIT0>c/k04e=C@1KFe/0FEUI05mOG`25QHD0`/;20:VYZ@0l?3`05QHF01LG5`0K6a/06QXJ
01HF5P0J6QX07alO03De=@11@D40P8200=3@d02ATI40ZJVY09bLW01eMGD0S8b<0:j^[P1dM7@0P820
06YZJP1VIVH0KFe]07]kN`38b<P0DE5A01PH600F5QH05aLG01DE5@0W9bL0JVYZ034a<@0S8b<0?Cdm
020P800O7al0>3Ph05EEE@2:RXX0>c/k02<S8`0G5aL05ADE02`/;01[Jf/0GEeM07moO`1`L700<c<c
01LG5`0E5AD0?Cdm04e=C@0l?3`0JFUY05IFEP1EEED0C4a<05QHF02:RXX0[Jf]09bLW02SXj<0X:2P
07emO@1MGEd0BTY:05QHF018B4P0?clo034a<@0Z:RX0;Rh^03Lg=`19BDT0DE5A07=cL`2JVYX0N7Qh
04E5A@1XJ6P0[Jf]0;^k^`2o_kl0NGUi09jNWP3?cll0[jn_0;Vi^@1CDe<0BTY:03`l?00h>3P0<C4a
02d];@2_[jl0MGEe0;2`/01aLG40V9RH0;Bd]02_[jl0Kfm_01HF5P0E5AD06ATI01XJ6P0M7Ad0<S8b
07]kN`1nOWh0Zj^[0:FUY@25QHD0WinO04A4A00R8R807AdM01TI6@0L71`201hN7P1:05ADE027QhL0
Z:RX0;Rh^01iNGT0PX:2020P800N7Qh08R8R01hN7P0H61P06a/K01XJ6P0R8R8092@T01XJ6P0L71`0
9bLW0451@@2IVIT0XJ6Q065QH@2m_Kd0>3Ph01dM7@0Y:BT0?3`l01/K6`0J6QX06a/K01dM7@0d=3@0
PX:2059BDP0g=cL0C4a<079bLP1_Kfl0UiNG03Lg=`0F5QH04a<C01HF5P0L71`09bLW05QHF00S8b<0
@d=304];B`10@400O7al0:VYZ@1?Cdl0:2PX01TI6@0S8b<0HV9R07alO010@400;Rh^01hN7P1:BTX0
b/[:0861P@1UIFD0M7Ad07QhN01bLW80QXJ609ZJVP3=cLd0e=CD0:j^[P1SHf<201/K6`0702DU9@13
@d<0N7Qh06QXJ019BDT0PH610=_Kf`020>[ZjP0A0>CTi03>c/h0a<C40=3@d033`l<0_[jn0;Zj^P1P
H600@d=308n?S`32`/80GemO07AdM01BDU805QHF01DE5@0D51@00P0E5AD0:00J6QX0IVIV04A4A01k
Ng/0XZ:R07AdM00/;2`0DE5A030`<00K6a/07alO02l_;`1=CDd0EUIF04Q8B01JFUX0_Kfm09:BTP2G
UiL0a/K60:>SX`2UYJD0ZZZZ08R8R02YZJT0TY:B08^;R`1=CDd0:2PX02<S8`0Z:RX0:2PX065QH@1e
MGD0HV9R02/[:`1<C4`0LG5a09RHV01kNg/Aooooo`003oooool0dP30`<00JFUY08N7Q`15ADD0LW9b
061PH01dM7@0<S8b04E5A@2ATI40EEEE03hn?P1hN7P0Ogmo05mOG`0_;bl0Ogmo07MgM`0R8R80De=C
04];B`0k>c/0T92@051@D011@D40Fe]K04E5A@1[Jf/0E5AD02TY:@1eMGD0GemO0451@@1:BTX0AdM7
08V9R@1ZJVX0=SHf059BDP0h>3P0=CDe04E5A@22PX809bLW04Q8B01PH600=CDe05UIF@0_;bl05ADE
03De=@1^KVh0MGEe061PH00U9BD0>SXj08f=S@1FEUH0;Rh^04i>CP1QHF40@T9206e]K@1JFUX0;bl_
05UIF@1bLW80>3Ph02DU9@1MGEd0Fe]K03Ti>@25QHD0?Shn05MGE`1QHF40ATI60861P@0d=3@0R8R8
071`L00b<S80?clo05QHF01MGEd07alO08^;R`26QXH0<C4a06YZJP2DU9@0LW9b02<S8`1?Cdl0EeMG
03/k>`1aLG40Y:BT09bLW01kNg/0I6AT05aLG02RXZ80MGEe071`L01@D500EeMG0::RXP1TI6@0CTi>
05aLG00a<C40MGEe059BDP18B4P0@d=304A4A02ATI40KVi^03De=@1GEeL0ADE506UYJ@2EUID0HV9R
04m?C`1ADE409RHV09JFUP1UIFD0EEEE03Hf=P2HV9P0Ng]k051@D01]KFd09RHV06YZJP2ZZZX0OWin
04Q8B01BDU80>SXj09ZJVP1XJ6P0>c/k08>3P`1NGUh0:b/[05aLG01PH600?Cdm05MGE`1=CDd0A4A4
01dM7@1dM7@0=cLg05=CD`1JFUX0Ng]k05iNGP0Y:BT0Jf][06MWI`1[Jf/0I6AT0<o?c`1<C4`0EUIF
09nOW`26QXH0?3`l04Y:BP2@T900SXj>0410@01]KFd0O7al03@d=039bLT0Ogmo04E5A@2<S8`0Shn?
01dM7@0e=CD0ZJVY05aLG01fMWH0;Rh^071`L02FUYH0IFEU07moO`2PX:00?clo06a/K01`L700GemO
06EUI@0X:2P0K6a/0:VYZ@1EEED0>CTi04U9B@1KFe/0;Bd]059BDP80PH6103<0G5aL06QXJ02VYZH0
PH6106i^KP1;Bd/0MWIf02l_;`0a<C40NWYj02h^;P1WIfL0/K6a0:6QX@1?Cdl0Fe]K05mOG`0X:2P0
CTi>04];B`27QhL0Hf=S07AdM02VYZH0EeMG04i>CP2ATI40HV9R038b<P1^KVh0<S8b01dM7@1EEED0
EeMG0410@02^[Zh07QhN03hn?P21PH40QXJ604M7A`0M7Ad0G5aL05ADE00j>SX0RHV90::RXP1hN7P0
ATI609:BTP2b/[800P1cLg<06@2EUID0BDU90:f][@2<S8`0CTi>04=3@`1FEUH0MWIf0492@P1lO7`0
Fe]K03hn?P1jNWX0RXZ:05ADE023Ph<0];Bd024Q8@0];Bd0DE5A07AdM00k>c/0=cLg034a<@1XJ6P0
7?ooool0;013@d<0SXj>07YjNP2b/[80]kNg0;^k^`3=cLd0];Bd07=cL`2g]kL0`l?30;Ng]`1gMgL0
GUiN0:2PX01@D5006ATI01@D500C4a<05ADE02DU9@1oOgl0QhN703`l?00m?Cd092@T01XJ6P0G5aL0
5QHF01DE5@0[:b/0<c<c01PH602EUID0[Jf]0861P@1gMgL0:2PX01PH600Q8B40;bl_03<c<`0i>CT0
=CDe0P0`<300500^;Rh0MgMg08N7Q`1>CTh0820P01LG5`0F5QH05aLG03hn?P2JVYX0G5aL034a<@0X
:2P0>SXj05QHF025QHD0NWYj03lo?`0k>c/08b<S0P0E5AD0100U9BD0MgMg04m?C`1KFe/201<C4`0f
014A4@0E5AD0>SXj06QXJ01]KFd0:b/[02`/;016ATH0K6a/07AdM01jNWX0WYjN0::RXP1iNGT0LW9b
04Q8B019BDT0GUiN06EUI@1RHV80DE5A03Xj>P0_;bl0:BTY02PX:00`<300N7Qh0:JVYP22PX80;bl_
03Ti>@1RHV80bl_;0=CDe02VYZH0Ti>C09jNWP2PX:00MgMg08F5Q@1_Kfl0@41002l_;`0Q8B40;Rh^
0:RXZ01PH600Hf=S0<G5a@2=SHd0MGEe08f=S@2EUID0=SHf0P0K6a/05P0T92@0@41005ADE02MWId0
QhN708:2PP15ADD0GUiN08b<S014A4@0G5aL03Xj>P0k>c/0=cLg020P800Q8B40G5aL0:2PX02][Jd0
Vi^K07EeM@1gMgL201dM7@2801/K6`0H61P05aLG01TI6@0E5AD06a/K030`<00P820071`L02PX:01>
CTh0Y:BT06QXJ00e=CD0Z:RX065QH@0M7Ad0;2`/038b<P0S8b<07AdM01/K6`0F5QH06ATI051@D02R
XZ80TY:B0:j^[P2n_[h0CTi>05]KF`0Q8B404Q8B014A4@0E5AD06ATI02PX:02PX:00IVIV04a<C01I
FET0IVIV07emO@2c/k<0OGem07inOP1eMGD0QXJ609bLW00j>SX0;bl_034a<@0n?Sh0?3`l08^;R`1V
IVH0De=C0492@P16ATH0B4Q805eMG@2/[:`0bLW90>3Ph038b<P0I6AT01dM7@0c<c<0LW9b05eMG@0T
92@04Q8B01PH600`<300Zj^[0=oOg`3Rh^80b<S808Z:RP1LG5`0Z:RX0<;2`P1[Jf/0=cLg09FEU@1`
L700FUYJ09RHV018B4P0AdM707]kN`0o?cl061PH01lO7`0f=SH0CDe=05IFEP1cLg<0WinO09FEU@2M
WId0MgMg02l_;`1GEeL0SHf=05UIF@1UIFD0Fe]K03lo?`0l?3`0<C4a03Hf=P1FEUH0HF5Q0:^[Z`2j
^[X0QhN70:JVYP2HV9P0ZJVY0;Rh^036a/H0[:b/03@d=00h>3P0Bd];05mOG`1IFET0ATI602LW9`0Q
8B40>CTi06MWI`29RHT0KVi^08R8R17ooooo000?ooooo`0D0:b/[01hN7P0QXJ60451@@1=CDd0Fe]K
08B4Q00o?cl0Bd];07UiN@0c<c<0Cdm?09>CT`1FEUH0MgMg02h^;P1cLg<0LG5a024Q8@1XJ6P204U9
B@1708^;R`1:BTX0@D5105EEE@12@T80Jf][03/k>`0W9bL0GEeM03Lg=`1>CTh0EUIF034a<@1eMGD0
>c/k03Lg=`1^KVh0;bl_04E5A@0_;bl0P82002LW9`1XJ6P0Bd];038b<P1dM7@0BDU901TI6@1=CDd0
JFUY065QH@1JFUX0>CTi03De=@29RHT0=cLg03De=@1dM7@0IVIV03@d=012@T80BTY:01hN7P1BDU80
Hf=S04Q8B00f=SH0LG5a04Y:BP0c<c<0KFe]03Hf=P1XJ6P0A4A404Q8B01UIFD0Bd];09>CT`28R8P0
?Cdm04i>CP1SHf<0GemO01lO7`2?Shl0EUIF01`L701FEUH0K6a/06UYJ@0T92@00P1DE5@0Q`16ATH0
MWIf07emO@24Q8@0QhN706m_K`1>CTh0MWIf05MGE`1UIFD0FUYJ05QHF02JVYX0EEEE04e=C@1WIfL0
GUiN07AdM01:BTX0CDe=09BDU01eMGD0U9BD079bLP0k>c/0EUIF03lo?`1HF5P0MWIf06ATI01HF5P0
JFUY05=CD`2=SHd0FEUI05mOG`0d=3@0MgMg08b<S01MGEd0J6QX03<c<`1eMGD0Shn?06MWI`1?Cdl0
CTi>034a<@1lO7`0DU9B05IFEP2ZZZX0G5aL01/K6`1XJ6P0CTi>03Xj>P1YJFT0DU9B02@T900M7Ad0
TY:B04];B`1CDe<0Cdm?07]kN`1=CDd0:RXZ06a/K01CDe<0G5aL05IFEP2a/K40ATI607AdM02OWil0
QXJ60451@@1dM7@0]KFe08B4Q00g=cL0H61P07YjNP0`<300YjNW051@D012@T80W9bL08R8R01:BTX0
>c/k0:j^[P20P800Rh^;02`/;00f=SH0FEUI04Q8B02][Jd0MgMg06=SH`1nOWh0FUYJ07MgM`27QhL0
>c/k059BDP25QHD0EUIF03Hf=P19BDT0GEeM04E5A@2@T900`<3008^;R`1NGUh0WIfM0;no_`2a/K40
IFEU05=CD`1dM7@0;Rh^03hn?P20P800<C4a03hn?P1HF5P0NWYj04e=C@1[Jf/0Cdm?02HV9P02051@
D00j055AD@0g=cL0VYZJ0<k>cP1?Cdl0Hf=S09ZJVP1]KFd0@d=3075aL@27QhL0ADE5065QH@1IFET0
ATI60;6a/@1VIVH0IFEU07MgM`1LG5`0>c/k01dM7@1PH600CDe=03Ph>01fMWH0Ng]k079bLP13@d<0
aLG50=7Ad@1RHV80MWIf08f=S@0R8R80QHF50861P@1?Cdl0AdM704i>CP14A4@0>CTi09NGU`1^KVh0
BDU907MgM`1hN7P0E5AD09bLW02FUYH0AdM702/[:`1>CTh0J6QX03De=@1<C4`0IfMW06a/K1cooooo
01T0GemO07YjNP1iNGT0_;bl0=;BdP2LW9`0P8200:BTY015ADD0GEeM0;^k^`2XZ:P0BTY:051@D01g
MgL0YjNW03hn?P0B4Q803Ph>010@400C4a<0BDU906i^KP15ADD08B4Q0080<c<c00`0<S8b03Xj>P0c
<c<0:RXZ02l_;`19BDT0`l?30;Vi^@2QXJ40=CDe03Xj>P0H61P201HF5P805aLG05004A4A00h>3P0A
4A404a<C02<S8`1SHf<0MgMg05QHF00P82006a/K01TI6@1ADE40MGEe09FEU@1YJFT0I6AT075aL@2g
]kL0][Jf04e=C@0I6AT09bLW03Ti>@0P82005aLG01@D500g=cL09BDU03@d=00D51@04a<C01LG5`0k
>c/0MGEe07moO`1WIfL0>c/k04=3@`2`/;00XJ6Q09FEU@2XZ:P0BDU9030`<00g=cL0Bd];08j>SP2`
/;00TY:B07=cL`1HF5P0D51@05MGE`1<C4`0?Shn034a<@0f=SH0`l?30<c<c02[Zj/0?3`l04Q8B02M
WId0[Jf]0<?3``2NWYh0aLG50=WIf@1UIFD0I6AT05=CD`1<C4`0FUYJ06UYJ@1[Jf/0MgMg0=3@d01L
G5`0?3`l096AT@80KVi^03<0MgMg08J6QP2>SXh0CDe=03De=@1NGUh0ADE5024Q8@1KFe/0MWIf07Yj
NP0m?Cd0?3`l0861P@0E5AD08B4Q05iNGP1PH600F5QH09JFUP28R8P0T92@04a<C02i^KT0O7al051@
D01fMWH06ATI01XJ6P0F5QH05aLG01HF5P0E5AD05QHF01LG5`0U9BD0<c<c01dM7@0k>c/0M7Ad0:VY
Z@1NGUh0;Rh^07YjNP2<S8`0ADE505IFEP0N7Qh05ADE01LG5`0M7Ad00P0O7al02@0_;bl0]kNg09^K
V`2JVYX0`<3008N7Q`1;Bd/05ADE01<C4`0201DE5@0:01TI6@0d=3@0De=C03@d=01SHf<0K6a/08F5
Q@2WYjL0[Jf]09NGU`80TI6A0140d=3@07alO00U9BD0B4Q802h^;P14A4@0FUYJ0451@@0Y:BT06ATI
020P800/;2`0?Shn05aLG02ATI40^k^k0<W9b@020:ZZZP0J06MWI`1dM7@0@41002PX:00I6AT051@D
01DE5@0Q8B40@D510;bl_02XZ:P0B4Q804E5A@1ADE40WYjN09VIV@1iNGT0HV9R05]KF`2;Rh/0N7Qh
03`l?01FEUH0@41004m?C`2UYJD2079bLP0S05MGE`0k>c/0;Rh^03Ph>01kNg/0^[Zj0=KFeP2TY:@0
?Shn0:^[Z`2e]KD0QHF504e=C@0b<S808R8R01`L700O7al09RHV06IVIP1`L700>CTi05iNGP37alL0
^k^k0:j^[P33`l<0GemO0861P@2RXZ80MWIf06m_K`1JFUX0@41002PX:00U9BD00P0T92@01@1DE5@0
Lg=c061PH01cLg<0CDe=017ooooo000?ooooo`0<08R8R01bLW80QHF504A4A01QHF40H61P07emO@0j
>SX0E5AD0::RXP1HF5P0;bl_0P1MGEd0IP18B4P0<C4a06ATI00l?3`0>CTi07IfMP0l?3`0Bd];05iN
GP15ADD0DU9B04Q8B014A4@0OGem06EUI@0Q8B40De=C030`<010@400DU9B02h^;P1jNWX0@d=3030`
<017AdL0:RXZ02`/;00];Bd0Hf=S02HV9P1?Cdl0D51@028R8P0l?3`0?Cdm02`/;00o?cl0@410034a
<@1OGel0=SHf03Ph>01aLG407alO02TY:@1@D500GemO02l_;`12@T80G5aL03Hf=P1cLg<0K6a/0410
@00S8b<0Lg=c061PH01>CTh0O7al02l_;`1^KVh0D51@06EUI@1SHf<0C4a<09BDU02ATI40<C4a04];
B`1EEED0Cdm?02TY:@2>SXh0Hf=S03<c<`1fMWH0I6AT05YJFP0Z:RX0EeMG055AD@0n?Sh0I6AT06MW
I`1oOgl0QXJ608>3P`1FEUH0MWIf04M7A`1NGUh0HF5Q06YZJP27QhL0?clo04Q8B01XJ6P0E5AD06=S
H`0Z:RX0EUIF08F5Q@80PX:209H0EUIF03Ti>@1=CDd0Bd];06IVIP1mOGd0Fe]K05MGE`1`L700EeMG
07=cL`1>CTh0Hf=S03lo?`22PX80QhN7065QH@1XJ6P0?3`l0:ZZZP2GUiL0B4Q807QhN01iNGT0;Rh^
06IVIP0Y:BT0D51@09>CT`1SHf<0=cLg059BDP1[Jf/0@d=306UYJ@1SHf<07QhN02LW9`2CTi<0BTY:
06IVIP1RHV80TI6A065QH@0h>3P0MWIf06=SH`1XJ6P0?Cdm08^;R`1;Bd/0LW9b08b<S01`L700@410
08>3P`2d];@0P82003`l?01aLG40WIfM03Ti>@2n_[h0DU9B04M7A`2f][H0U9BD04m?C`12@T80^[Zj
05IFEP1bLW809bLW030`<01/K6`0@D5105UIF@1`L700H61P09FEU@1ADE40L71`07IfMP1@D500FUYJ
0861P@1MGEd0Hf=S09>CT`2KVi/0CDe=07IfMP1OGel0H61P06i^KP2JVYX0eMGE0:j^[P1FEUH0FUYJ
06ATI00[:b/0LW9b08R8R016ATH0B4Q805iNGP29RHT0<c<c0861P@1RHV80=3@d055AD@1=CDd0FEUI
055AD@1[Jf/0SHf=0492@P1ADE40P82002/[:`1QHF40TY:B071`L012@T80C4a<03Ti>@1LG5`0TY:B
04Y:BP1PH600QHF506=SH`0f=SH0820P07EeM@1MGEd0Jf][0820P01NGUh0>3Ph02XZ:P2VYZH0/K6a
03Lg=`1`L700/K6a03Xj>P2>SXh205ADE00D06EUI@1`L700H61P02`/;01kNg/0FEUI05EEE@22PX80
>SXj01lO7`2:RXX0Shn?05=CD`0];Bd0E5AD05QHF00O7al0HV9R06MWI`1DE5@Looooo`0^04Q8B01h
N7P0C4a<08^;R`2RXZ80JFUY06ATI00_;bl06a/K020P802j^[X0emOG08J6QP14A4@0>c/k09ZJVP2a
/K40?clo024Q8@0L71`08b<S03lo?`1eMGD0VIVI0820P01hN7P0M7Ad079bLP1hN7P0QXJ607moO`2<
S8`0`l?30<K6aP2g]kL0IVIV02h^;P0_;bl0A4A4020P800X:2P0=cLg02HV9P0E5AD05aLG01<C4`80
5ADE00T0@d=303`l?01[Jf/0IVIV038b<P1=CDd0E5AD061PH02ZZZX00P2WYjL0D02e]KD0`l?30<C4
a00n?Sh05ADE01LG5`0Q8B40>3Ph02PX:00J6QX0<S8b024Q8@0a<C405ADE03Ph>01BDU80?Shn02d]
;@0S8b<0X:2P08N7Q`1PH600NWYj09bLW02k^k/0/[:b028R8P0L71`0<c<c024Q8@12@T80RXZ:03Xj
>P1ADE40HF5Q07alO01hN7P0OWin0;Ng]`2l_;`0`<300<[:bP29RHT0Ti>C0;bl_02YZJT0dm?C0:FU
Y@32`/80aLG50;Ng]`2MWId092@T03@d=01;Bd/0CDe=04I6AP10@400=CDe04M7A`25QHD0^;Rh055A
D@1KFe/0Q8B404e=C@1ADE40IfMW07inOP2c/k<0UIFE02`/;00I6AT05QHF03De=@1_Kfl0JVYZ03hn
?P10@400MGEe0P0E5AD04@0F5QH09RHV05]KF`3Fe]H0[jn_02d];@0_;bl0NGUi069RHP1LG5`0Z:RX
02d];@0J6QX071`L01HF5P0E5AD05QHF00805aLG044071`L05mOG`1GEeL0Q8B40;Zj^P2MWId0S8b<
06YZJP21PH40bLW90::RXP2OWil0M7Ad01dM7@0E5AD05aLG03Ti>@0m?Cd0Lg=c0;6a/@1EEED0>CTi
06][J`28R8P0MWIf01TI6@0A4A405ADE01LG5`0M7Ad0BTY:01`L700E5AD05aLG07]kN`2LW9`0Zj^[
0;Ng]`3?cll0`l?30=GEe@3MgMd0Rh^;08J6QP1kNg/0;Rh^04A4A01FEUH09bLW01LG5`0@41005ADE
01PH600O7al0:BTY03Ti>@1UIFD0X:2P09fMW@2VYZH0NWYj02PX:00M7Ad07QhN020P800201DE5@0F
01HF5P0[:b/0NWYj06QXJ01EEED0C4a<05EEE@2CTi<0PX:204A4A00D51@05ADE01TI6@1eMGD0UIFE
08f=S@2ATI40_kno0<g=c@2<S8`0SXj>06MWI`80OGem02L0/K6a0861P@1WIfL0Ti>C0<k>cP2BTY80
Q8B40861P@1MGEd0;2`/028R8P0L71`07AdM01lO7`1@D500>3Ph02PX:00/;2`0Jf][07moO`2j^[X0
_kno0;Vi^@1VIVH0DE5A06e]K@2<S8`0B4Q803hn?P0l?3`0=cLg03dm?@1<C4`0>CTi07]kN`1NGUh0
LG5a04i>CP1=CDd04Oooool000oooooo03@0]KFe07AdM02=SHd0CDe=07inOP1XJ6P0O7al04A4A01^
KVh0]KFe06EUI@0g=cL0Jf][06UYJ@1EEED0:RXZ06e]K@1KFe/08B4Q059BDP0m?Cd0K6a/07QhN00o
?cl0>3Ph02d];@0g=cL0FEUI061PH00X:2P0J6QX05EEE@14A4@0BDU905iNGP2UYJD0HV9R03<c<`1=
CDd0<S8b030`<011@D40Hf=S02d];@1IFET0E5AD03hn?P15ADD0;bl_01/K6`1;Bd/0JFUY0P1CDe<0
E@0Y:BT0@41007=cL`0c<c<0;Bd]05]KF`1ADE40;Bd]04a<C016ATH0=3@d06IVIP1RHV80;Bd]01XJ
6P1PH600G5aL03`l?01cLg<0:2PX08>3P`1@D500I6AT05EEE@19BDT0[Zj^08F5Q@0m?Cd0?Shn04i>
CP1EEED0>3Ph0:b/[01lO7`0=cLg079bLP1RHV80EUIF04m?C`1mOGd0Ng]k051@D01<C4`0F5QH07Mg
M`1GEeL0bl_;061PH01gMgL0BDU908F5Q@1^KVh0Hf=S06YZJP0e=CD0LG5a07UiN@1ADE40Jf][020P
801]KFd0Ogmo079bLP2:RXX0E5AD061PH01YJFT0C4a<06UYJ@1lO7`0GUiN09:BTP2?Shl0Cdm?06UY
J@1@D500Shn?03Lg=`1nOWh0GEeM0861P@2@T900GemO0:RXZ02FUYH00P1?Cdl0@01cLg<0<C4a06e]
K@1CDe<0>c/k07alO01VIVH0BTY:05EEE@1>CTh0@d=309JFUP2VYZH0>c/k01/K6`26QXH0Fe]K06UY
J@1KFe/0Z:RX06UYJ@0n?Sh0NWYj06IVIP1?Cdl0GEeM0:BTY01HF5P0NGUi0:f][@1?Cdl0=CDe05QH
F02MWId0FUYJ05UIF@2ATI40Q8B403Lg=`33`l<0NWYj04];B`2JVYX0Shn?038b<P1GEeL0/K6a06QX
J01[Jf/092@T02LW9`1PH600?Shn06a/K01cLg<0ADE507]kN`1CDe<0KVi^05mOG`0o?cl0GEeM07Mg
M`1;Bd/204E5A@10051@D011@D40HF5Q05eMG@1BDU80Hf=S07UiN@2SXj<0T92@05MGE`1PH600GEeM
02@T901nOWh0NGUi04i>CP1:BTX0Fe]K09bLW00i>CT0KVi^05QHF00a<C40I6AT07YjNP22PX80De=C
08B4Q02a/K40;Rh^07MgM`2JVYX0G5aL03/k>`1YJFT0AdM70492@P1/K6`0=3@d05mOG`21PH40ADE5
06a/K02YZJT0Kfm_020P800c<c<0R8R805UIF@1EEED0SXj>07alO019BDT0;Rh^08B4Q02XZ:P0<C4a
07QhN02/[:`0=cLg09^KV`1GEeL0<30`05EEE@80MWIf0140=cLg07YjNP18B4P0EEEE08:2PP27QhL0
ADE507AdM02UYJD0=SHf03Ph>01dM7@0PX:202`/;00k>c/0ATI605aLG00Looooo`0N05]KF`1HF5P0
@D5104Q8B02;Rh/0I6AT0410@00g=cL0CTi>08b<S02o_kl0gMgM0=7Ad@2][Jd0BTY:04e=C@2VYZH0
_[jn0<S8b02i^KT0ZJVY09^KV`2VYZH0[jn_05EEE@13@d<0@41003Ti>@0e=CD0;Rh^0P0a<C402@1W
IfL0/K6a04M7A`14A4@0EEEE030`<012@T80NGUi02l_;`0201XJ6P0`028R8P0d=3@0<S8b02HV9P0G
5aL07AdM051@D00j>SX0K6a/096AT@2?Shl0M7Ad09fMW@2HV9P0K6a/05EEE@1;Bd/0VYZJ0;Zj^P0i
>CT05QHF01PH600J6QX092@T03Ph>00T92@0?3`l0451@@12@T80AdM703/k>`0P82005aLG01HF5P10
@400FUYJ09^KV`1PH600CDe=08^;R`1eMGD0Ogmo03<c<`0J6QX0<c<c02DU9@0V9RH0EUIF0P0M7Ad0
5`0_;bl0BTY:0=7Ad@2`/;00Shn?07=cL`1oOgl0]KFe05=CD`0e=CD0NGUi0=gMg@25QHD0DE5A0<G5
a@39bLT0GemO092@T00I6AT05aLG01TI6@0K6a/0=CDe00809BDU00`0<c<c03hn?P1hN7P0^k^k0;no
_`1jNWX0@d=302LW9`0i>CT0GUiN09^KV`0S8b<201TI6@0701XJ6P0T92@0GUiN05QHF01OGel0?clo
065QH@0201DE5@0A01HF5P0E5AD05ADE08>3P`1VIVH07AdM01lO7`1YJFT0Jf][0;Bd]02UYJD0/k>c
09JFUP1`L700?3`l02/[:`0L71`00P0I6AT09@0T92@0?Shn02DU9@19BDT0VYZJ08>3P`1CDe<0E5AD
0;Bd]01SHf<0MWIf08j>SP2VYZH0RXZ:06YZJP0S8b<07QhN051@D02<S8`0?clo08:2PP13@d<0QHF5
071`L01/K6`0H61P01XJ6P0A4A405aLG03/k>`0[:b/05ADE01@D500E5AD0BDU9051@D01^KVh00P3<
c<`02P2TY:@0clo?0=3@d02e]KD0L71`07YjNP1;Bd/0De=C05EEE@0M7Ad201DE5@0J01HF5P0H61P0
61PH01LG5`0J6QX08b<S08b<S03Bd]80Q8B404];B`0J6QX06a/K01hN7P0Q8B406ATI01@D500F5QH0
7AdM079bLP2TY:@0ADE503dm?@29RHT0K6a/06IVIP0d=3@301<C4`0E03De=@3Bd]80aLG50;Fe]@2h
^;P0][Jf07EeM@1KFe/0@T92030`<00O7al0;bl_02LW9`1SHf<0/K6a092@T02^[Zh0YJFU0;>c/`1E
EED0:BTY00808R8R0140>3Ph05ADE014A4@0?3`l05QHF02:RXX0UiNG0:FUY@3Kfm/0[:b/07alO02N
WYh0[jn_0<;2`P30`<00XJ6Q06e]K@0206ATI00807MgM`2OWil0[jn_07AdM01kNg/0DU9B05=CD`0L
71`Aooooo`003oooool0m@2a/K40NWYj05EEE@1@D500Hf=S06e]K@1PH600;Bd]05QHF020P800C4a<
03/k>`1HF5P0?Cdm08>3P`0i>CT0Ng]k05UIF@0k>c/0LW9b03Hf=P1[Jf/0LG5a04e=C@1`L700HF5Q
03Xj>P18B4P0;Rh^03Ph>01kNg/0De=C04=3@`0d=3@09bLW06IVIP17AdL0;Bd]05ADE00O7al0@T92
03hn?P1FEUH09RHV06ATI01FEUH0<c<c03dm?@0_;bl04Q8B06UYJ@1XJ6P0@d=304I6AP0F5QH0J6QX
07EeM@0l?3`0:2PX069RHP0h>3P0=3@d06m_K`1DE5@0>CTi07MgM`1XJ6P04a<C01hN7P1QHF40EeMG
03lo?`1dM7@06a/K06IVIP15ADD0GEeM05aLG00^;Rh0H61P08R8R01BDU80@T9204Q8B00R8R80?3`l
09VIV@1/K6`0<c<c05aLG01WIfL0GemO024Q8@10@400De=C04Q8B01OGel0L71`06m_K`1LG5`0_;bl
04];B`2:RXX0CTi>069RHP1QHF40GemO08F5Q@0h>3P0@41006][J`1HF5P0HV9R0410@01MGEd0OGem
06m_K`24Q8@0@T9202PX:01DE5@0A4A405]KF`1bLW80ADE505IFEP1^KVh0BDU907MgM`1DE5@0GUiN
02d];@1cLg<0LW9b06i^KP1mOGd0D51@0:FUY@2_[jl0LW9b065QH@1YJFT0ATI60:6QX@1SHf<0?3`l
09RHV01ZJVX0ADE505iNGP2DU9@0E5AD05EEE@1BDU80C4a<02@T901`L700;Bd]07YjNP1ZJVX0KFe]
05]KF`1?Cdl0Y:BT08N7Q`0o?cl0@4100;Rh^01aLG40Vi^K09jNWP2<S8`0AdM708F5Q@2UYJD0JFUY
03Lg=`1LG5`0LG5a034a<@2JVYX0F5QH05ADE02h^;P0PX:204M7A`0k>c/0Q8B405iNGP1TI6@0=CDe
07UiN@1kNg/0AdM707inOP1]KFd0Cdm?08V9R@1DE5@0MgMg071`L00m?Cd0OGem08f=S@0m?Cd0:b/[
03Ti>@19BDT09BDU06MWI`1_Kfl0LW9b06e]K@24Q8@0UiNG0:>SX`1=CDd0EUIF07inOP0k>c/0O7al
08:2PP0_;bl0HF5Q09RHV02KVi/0DU9B06IVIP1SHf<0:2PX04A4A012@T80M7Ad055AD@2IVIT0^k^k
04];B`1IFET0SXj>061PH00n?Sh0MgMg05MGE`0c<c<0@4100080D51@02/0SHf=02TY:@1CDe<0M7Ad
06MWI`0e=CD06a/K05=CD`1FEUH0;bl_08f=S@2@T900KFe]04];B`2o_kl0][Jf04M7A`1jNWX0YjNW
03Ti>@2XZ:P0DU9B05]KF`1<C4`0DU9B07EeM@0a<C40KFe]04e=C@1>CTh0L71`08:2PP1BDU80N7Qh
09RHV00m?Cd08R8R03hn?P1]KFd0<c<c04A4A01>CTh0Jf][01cooooo05/0N7Qh04E5A@0m?Cd0ADE5
09RHV02a/K40ZZZZ0<?3``24Q8@0ADE503Xj>P1GEeL0ZZZZ0;Rh^02JVYX0=cLg07=cL`2b/[80OWin
04Y:BP13@d<0IfMW08Z:RP2d];@0>c/k030`<00[:b/09bLW02/[:`0O7al05ADE01lO7`1OGel0RHV9
01/K6`0G5aL0=cLg05EEE@1HF5P0Hf=S01hN7P0L71`0>SXj04E5A@0X:2P09BDU03@d=019BDT0>SXj
05mOG`18B4P0OGem0;2`/02o_kl0Y:BT09VIV@25QHD0MWIf06a/K01ZJVX0L71`08B4Q00o?cl061PH
01TI6@0F5QH05aLG01hN7P1=CDd0HF5Q05QHF01KFe/0<S8b01PH600G5aL05ADE03/k>`1@D500=cLg
08B4Q01ZJVX0F5QH07QhN01@D500@D51065QH@0P8200;Bd]030`<00Q8B40De=C008071`L0180=CDe
09bLW02:RXX0FUYJ051@D00n?Sh0;Bd]09JFUP17AdL0=CDe05QHF03@d=00BDU90;Fe]@3Lg=`0^[Zj
05QHF01gMgL301LG5`0A01PH600I6AT05aLG01LG5`0H61P06ATI03Hf=P1>CTh0Ph>306e]K@0];Bd0
:b/[0451@@1fMWH0JVYZ01/K6`0I6AT00P0G5aL01P0K6a/0D51@03dm?@1EEED0?Shn069RHPD05ADE
00h0I6AT03De=@0I6AT07AdM06m_K`2HV9P0NWYj05eMG@0_;bl0?3`l05IFEP1]KFd0NWYj07EeM@80
N7Qh02D0IfMW04];B`1?Cdl0OWin0:j^[P2HV9P0F5QH08R8R02WYjL0Bd];04E5A@0N7Qh0:BTY05UI
F@2UYJD0V9RH07inOP2OWil0EEEE06EUI@27QhL0N7Qh08n?S`2PX:00XZ:R09BDU02LW9`0@410030`
<00o?cl04Q8B01<C4`0?3`l05ADE038b<P0Z:RX0<S8b0080^KVi00h0SXj>0;Rh^02n_[h0YZJV0<?3
``2c/k<0YJFU09RHV00l?3`07AdM010@400C4a<05ADE01HF5P805ADE02805aLG024Q8@1WIfL0]KFe
0;bl_01YJFT071`L01hN7P0T92@0;2`/034a<@0M7Ad06QXJ02PX:01PH600OWin03hn?P1OGel0H61P
04E5A@1WIfL0:b/[018B4P0E5AD05aLG06YZJP2>SXh0MGEe05UIF@1HF5P0NGUi01lO7`0D51@04a<C
0P0E5AD09@0f=SH0Cdm?07emO@0o?cl0CTi>075aL@1ZJVX0P82007MgM`28R8P0Ng]k04E5A@1WIfL0
RXZ:08N7Q`25QHD0PX:207alO028R8P0Y:BT0=OGe`2a/K40@410059BDP2?Shl0Xj>S0:ZZZP2SXj<0
RHV90820P02<S8`0WIfM0<[:bP2VYZH0VIVI07]kN`13@d<00P0I6ATAooooo`003oooool0@@2:RXX0
TY:B07EeM@1?Cdl0IfMW06QXJ028R8P0B4Q807MgM`22PX80?clo04Q8B01eMGD0BDU904i>CP10@400
Lg=c03Ti>@0g=cL0M7Ad03De=@1mOGd0@D5102d];@15ADD0>CTi04I6AP1QHF40@d=3034a<@1=CDd0
<C4a04e=C@1EEED0=SHf08>3P`0a<C40>SXj069RHP18B4P0BTY:02TY:@1?Cdl0;bl_04e=C@10@400
;2`/04];B`13@d<0;Rh^06m_K`17AdL09bLW05=CD`0R8R80I6AT06MWI`0H61P0=3@d06a/K01LG5`0
;2`/03`l?00f=SH0<S8b0080IFEU02l0>CTi01dM7@1ZJVX0?3`l0492@P1/K6`0<S8b0861P@12@T80
CTi>05=CD`1LG5`0VIVI07alO00S8b<0CDe=05mOG`11@D40<C4a09ZJVP15ADD0;Rh^06MWI`2=SHd0
BTY:030`<019BDT0EUIF03Xj>P1eMGD0E5AD05mOG`1IFET0`L710410@029RHT0CTi>06e]K@1;Bd/0
HV9R08b<S01:BTX0A4A407IfMP1IFET0EUIF03Ph>00206EUI@0Q06=SH`1mOGd0Fe]K03Lg=`17AdL0
Fe]K08f=S@2ATI40Hf=S06EUI@1IFET0@d=308V9R@1UIFD0E5AD03/k>`1mOGd0MgMg06m_K`1GEeL0
:RXZ08>3P`2DU9@0CDe=06e]K@1CDe<0=cLg07YjNP1@D500>c/k08^;R`1CDe<0:b/[0080K6a/08/0
@d=305IFEP1EEED0>3Ph03Lg=`2CTi<0BTY:06e]K@1LG5`0TI6A05aLG00o?cl0NWYj051@D017AdL0
H61P0:b/[01ADE40Jf][07QhN01SHf<0AdM707inOP2XZ:P0JVYZ04=3@`1mOGd0TI6A03`l?02LW9`0
HV9R059BDP2g]kL0IVIV03`l?01FEUH0[Jf]06YZJP1]KFd09RHV0492@P1ADE40@d=30:f][@1aLG40
@d=308f=S@1ADE40Ogmo07AdM00d=3@0HF5Q07QhN00h>3P0ATI605YJFP1YJFT0=3@d05eMG@1DE5@0
Cdm?05ADE01hN7P0SHf=09NGU`17AdL0C4a<07UiN@0g=cL0R8R8079bLP1;Bd/0DE5A05aLG029RHT0
@T9206e]K@18B4P09RHV059BDP13@d<0LG5a055AD@22PX80R8R804M7A`1LG5`0P82004a<C01=CDd0
PX:206ATI01BDU80@T92051@D01LG5`0TI6A05IFEP1SHf<0PX:205MGE`0^;Rh09bLW079bLP25QHD0
Fe]K096AT@1^KVh0E5AD0492@P2HV9P0QhN703Ph>02:RXX0TI6A03Hf=P2g]kL0T92@04a<C01RHV80
Cdm?051@D00T92@0Ogmo051@D01EEED0I6AT04A4A01BDU80UIFE06QXJ00k>c/0;2`/04A4A01JFUX0
820P05IFEP1@D500CTi>01cooooo03/0K6a/03lo?`0n?Sh0JFUY07QhN01WIfL0Lg=c04U9B@0Z:RX0
7alO01`L700K6a/07alO0410@01lO7`0WYjN0;Jf]P22PX80@T9203Lg=`0o?cl0ATI606][J`1aLG40
;2`/02LW9`0S8b<09BDU02XZ:P0W9bL07QhN04];B`2LW9`0>SXj024Q8@0D51@0<C4a03@d=014A4@0
G5aL07alO01oOgl0DE5A02/[:`0S8b<09BDU02/[:`0_;bl0Bd];0::RXP1nOWh0WIfM09^KV`2_[jl0
/;2`069RHP1:BTX0ADE501hN7P0201LG5`0g02LW9`1PH600<c<c01dM7@0G5aL07alO02/[:`1BDU80
Hf=S06EUI@1QHF40CTi>04E5A@1ADE40FUYJ04Q8B00d=3@0A4A405iNGP0S8b<08R8R04e=C@1GEeL0
C4a<04E5A@1ADE4092@T034a<@0Q8B40M7Ad07MgM`1aLG40KVi^04=3@`0_;bl0;2`/03`l?01VIVH0
O7al09bLW02>SXh0GemO07emO@2QXJ40O7al07MgM`2HV9P0_kno06QXJ01/K6`06ATI01HF5P0G5aL0
6ATI01XJ6P0201TI6@0]01HF5P0G5aL07QhN04A4A013@d<0UYJF02h^;P0k>c/0CDe=09RHV00`<300
6QXJ01`L700`<300ADE505YJFP26QXH0SXj>08n?S`2@T900P82001LG5`0E5AD05aLG01DE5@0F5QH0
IFEU02<S8`0R8R80@4100:f][@1bLW80HV9R08b<S01/K6`0;Rh^02XZ:P0W9bL0>CTi05UIF@1YJFT0
OGem08j>SP2RXZ80Vi^K0080ZZZZ02d0J6QX0:b/[02YZJT0<C4a02LW9`1CDe<0>3Ph01TI6@0J6QX0
:RXZ055AD@32`/80A4A402/[:`1FEUH0Z:RX0<C4a02@T900Xj>S0:b/[02KVi/0[Zj^0;fm_@2UYJD0
<C4a02@T900S8b<08R8R03De=@0l?3`09bLW04m?C`1^KVh0CTi>06][J`1FEUH0W9bL07emO@1bLW80
X:2P0;Ng]`2m_Kd0?3`l01`L700K6a/00P0G5aL301HF5P1;01PH600O7al0BTY:09RHV03@d=00e=CD
09NGU`27QhL0T92@09RHV02j^[X0Z:RX08f=S@1hN7P0]KFe0=3@d038b<P0[Zj^06i^KP11@D40MgMg
02HV9P0E5AD0820P04m?C`17AdL08B4Q05=CD`29RHT0C4a<07MgM`0D51@05ADE01@D500F5QH0<30`
07AdM01NGUh0;Bd]01PH600j>SX0KFe]09fMW@1XJ6P0<30`04i>CP1_Kfl0RHV905YJFP0P82005aLG
01DE5@0L71`0E5AD061PH021PH40fMWI0=cLg02l_;`0X:2P08>3P`0o?cl0IFEU09VIV@1NGUh0MGEe
08b<S02MWId0a<C40;Fe]@39bLT0N7Qh01hN7P0K6a/06QXJ017ooooo000?ooooo`2Z0:j^[P2=SHd0
K6a/05IFEP1nOWh0JVYZ06UYJ@1?Cdl0P8200:b/[01HF5P0@41006m_K`1;Bd/0J6QX038b<P1lO7`0
C4a<04A4A01?Cdl0;2`/07alO01QHF40<C4a0492@P0W9bL0=cLg05]KF`0m?Cd0=SHf06YZJP1UIFD0
EeMG04=3@`16ATH0TY:B03dm?@0i>CT0BTY:03De=@0i>CT0=SHf069RHP0_;bl0@T9205QHF00d=3@0
Bd];059BDP0o?cl0H61P06m_K`14A4@0EEEE020P801jNWX0L71`02h^;P0Z:RX0G5aL051@D00^;Rh0
AdM7051@D01<C4`0GemO05IFEP0R8R8071`L06IVIP1?Cdl0C4a<065QH@0X:2P0NGUi04E5A@1?Cdl0
@d=304M7A`2DU9@0L71`03Lg=`0n?Sh0DE5A03<c<`0i>CT0UiNG04a<C00Y:BT0=SHf08B4Q00g=cL0
9RHV03/k>`1TI6@0BTY:0820P018B4P0Fe]K04E5A@2HV9P0>c/k071`L00j>SX0O7al06IVIP1RHV80
O7al04E5A@1KFe/0NWYj06QXJ01DE5@09BDU06ATI01^KVh0N7Qh07inOP1HF5P0AdM7059BDP1LG5`0
YjNW09ZJVP1[Jf/0MGEe07YjNP1;Bd/0Ogmo05iNGP1VIVH0CDe=07inOP1VIVH0Q8B406e]K@1CDe<0
WinO09FEU@12@T80Jf][05iNGP13@d<0Q8B403@d=013@d<0WYjN05=CD`0_;bl0BTY:05IFEP10@400
GemO069RHP0U9BD0<S8b09>CT`0`<300Ng]k06=SH`1kNg/0?clo04Y:BP2n_[h0G5aL05YJFP1fMWH0
YjNW0410@01`L70208B4Q01f04Q8B02ATI40[jn_07YjNP13@d<0T92@07=cL`11@D40][Jf08^;R`1X
J6P0bl_;08f=S@0F5QH0KVi^0:BTY01cLg<0IfMW034a<@1PH600AdM703Ti>@2KVi/0MWIf05UIF@2K
Vi/0BTY:0:>SX`22PX80@41007QhN01iNGT0:RXZ04Q8B01EEED0Lg=c04a<C01WIfL0FEUI06=SH`1X
J6P0Ph>307EeM@1dM7@0B4Q8059BDP1YJFT092@T06][J`1HF5P0@T9208:2PP23Ph<0T92@04U9B@1T
I6@0>CTi03<c<`1SHf<0EeMG06m_K`1<C4`0OGem07alO00];Bd0N7Qh09JFUP1EEED0B4Q8075aL@10
@400GUiN055AD@0m?Cd0H61P06e]K@0l?3`0KFe]0;Ng]`1/K6`09BDU02TY:@1EEED0>CTi03Ph>02j
^[X0WYjN08F5Q@1IFET0`<3009bLW00G5aL0O7al09JFUP0e=CD0VIVI065QH@0A4A40JVYZ09FEU@1d
M7@0:2PX07emO@0_;bl0Kfm_0:FUY@1OGel0Hf=S07EeM@18B4P0820P0451@@1VIVH0QHF501dM7@1Q
HF40@d=302/[:acooooo01D0AdM704E5A@1BDU80ZJVY069RHP2_[jl0VIVI03`l?00W9bL07QhN01`L
700G5aL06QXJ01LG5`0K6a/0E5AD09ZJVP2i^KT0^[Zj09RHV02GUiL00P2YZJT0102f][H0U9BD04e=
C@0/;2`2024Q8@0o02h^;P1mOGd0_;bl05mOG`0J6QX09BDU01dM7@0E5AD05QHF01dM7@1MGEd0RXZ:
079bLP1OGel0Hf=S04Q8B00m?Cd0<c<c02l_;`1=CDd0U9BD092@T01fMWH0Ti>C0;:b/P2BTY80?3`l
03De=@0Q8B405aLG01DE5@0F5QH05aLG05eMG@1GEeL0MWIf05MGE`1ZJVX0IFEU071`L02FUYH0De=C
03/k>`0L71`0A4A404Y:BP16ATH0B4Q805EEE@1PH600<c<c034a<@0_;bl0FUYJ03<c<`1<C4`0BDU9
04I6AP1:BTX09BDU038b<P1?Cdl08b<S00808B4Q00<06a/K01`L700H61P00P0J6QX03@0i>CT0OWin
08R8R00Y:BT09RHV03lo?`1SHf<0?clo05QHF02[Zj/0Ph>306m_K`0F5QH00P0E5AD00`0I6AT05QHF
01LG5`0201DE5@1701LG5`0F5QH0=3@d04];B`28R8P0T92@07]kN`21PH40TI6A04A4A00g=cL0Jf][
0492@P0b<S80;bl_02h^;P1cLg<0Ti>C0<_;b`29RHT0DE5A01hN7P0E5AD05aLG03Hf=P1[Jf/0>SXj
08>3P`36a/H0]KFe07UiN@14A4@0T92@0=gMg@3AdM40`L7109fMW@2<S8`0Jf][07IfMP2CTi<0CDe=
03@d=00S8b<07alO06ATI02o_kl0a<C40;>c/`0/;2`06ATI02@T901=CDd0<30`01LG5`0L71`0820P
08Z:RP1HF5P0D51@07inOP2h^;P0Hf=S09NGU`2BTY80R8R807]kN`1KFe/0LW9b0;2`/00e=CD00P0a
<C40=P0e=CD0GemO071`L00_;bl0JFUY05QHF00K6a/09bLW04A4A01YJFT0VYZJ04I6AP1:BTX0LW9b
08j>SP1QHF40:b/[01dM7@0L71`06QXJ01HF5P0E5AD05QHF01DE5@0[:b/0FUYJ05MGE`25QHD0eMGE
07emO@1KFe/0SXj>0=;BdP2i^KT0ATI603De=@0g=cL0MgMg08B4Q01`L700TY:B0:FUY@2TY:@0Xj>S
02<S8`0m?Cd0EeMG01dM7@0J6QX071`L038b<P2KVi/0Kfm_07UiN@<05ADE02T07QhN06QXJ022PX80
7alO01DE5@0K6a/0?3`l0451@@2JVYX0`l?309bLW01/K6`07QhN01dM7@1YJFT06ATI01HF5P0H61P0
ATI60861P@2b/[80YJFU06m_K`3GemL0a/K607inOP1/K6`0_;bl07QhN01PH600820P02PX:00g=cL0
F5QH0:BTY03Fe]H0TI6A05mOG`0Q8B406ATI01XJ6P0Aooooo`003oooool0S@2a/K40U9BD06QXJ01K
Fe/0Ogmo06YZJP1YJFT0EUIF08>3P`2f][H0F5QH04Y:BP1_Kfl0BDU905UIF@14A4@0Vi^K05ADE013
@d<0MWIf03Lg=`1dM7@0IVIV03Hf=P1ADE40?clo03Xj>P1LG5`0=CDe03Xj>P1eMGD0L71`05ADE01G
EeL0<30`07IfMP10@400?Shn05=CD`0e=CD0ATI603<c<`1OGel0;bl_04E5A@1MGEd0ADE504M7A`1F
EUH0?Cdm05iNGP1kNg/0Bd];06][J`0X:2P0Rh^;075aL@0d=3@0:RXZ06ATI01>CTh0<C4a05UIF@1D
E5@0C4a<05MGE`1SHf<0?3`l02HV9P1lO7`0FEUI03hn?P1QHF40:b/[071`L01:BTX0E5AD04A4A01K
Fe/0Ogmo06m_K`0o?cl0@T9205mOG`0^;Rh0DU9B0:6QX@1OGel0;Bd]03<c<`25QHD0ATI603<c<`0o
?cl0LW9b04=3@`2:RXX0IVIV079bLP1EEED0Ng]k04a<C01aLG40=SHf05]KF`1ZJVX0IVIV08b<S017
AdL0D51@07UiN@1WIfL0CTi>034a<@1QHF40OWin07emO@1nOWh0BDU903hn?P1FEUH0H61P09JFUP1l
O7`0Hf=S08J6QP1QHF40@d=307alO01@D500GemO05YJFP21PH40GUiN071`L01?Cdl0@T920;6a/@2N
WYh0ATI607EeM@0205EEE@060:NWY`1>CTh0>SXj0:6QX@1PH600B4Q80P1IFET0B@0m?Cd0GEeM05YJ
FP0_;bl0=3@d09:BTP0j>SX0MGEe06m_K`1kNg/0Cdm?04U9B@1hN7P0GemO079bLP1mOGd0]kNg05YJ
FP1UIFD0SHf=03lo?`0f=SH0QhN70;Jf]P1iNGT0BDU90:ZZZP25QHD0>SXj0:^[Z`0`<300F5QH0:BT
Y02?Shl0?clo03dm?@22PX80MGEe07UiN@11@D40YJFU08F5Q@1@D500]kNg07AdM015ADD0OGem051@
D02FUYH0I6AT02/[:`26QXH0Ph>303lo?`1BDU80GUiN06e]K@0_;bl0Kfm_08Z:RP1dM7@0Kfm_08j>
SP1`L700S8b<04E5A@1MGEd0PX:203Ph>01/K6`0EUIF01<C4`1YJFT00P2?Shl0@00n?Sh0KVi^02HV
9P0Z:RX0HV9R06][J`1FEUH0Bd];09fMW@2GUiL08b<S07MgM`25QHD0BDU904M7A`1SHf<06ATI05QH
F01UIFD0GUiN05mOG`1KFe/04a<C04I6AP1nOWh0J6QX030`<00Z:RX0Hf=S04I6AP0W9bL0OWin07mo
O`0b<S80I6AT0=[JfP2o_kl0=SHf09:BTP2OWil0<C4a09^KV`1RHV80?3`l04m?C`1HF5P0JVYZ02HV
9P1cLg<0?clo04m?C`2:RXX0Hf=S06a/K01IFET0G5aL02HV9P0L71`09bLW06=SH`0R8R80GemO04E5
A@1PH60Looooo`0_04U9B@1PH600UYJF0:JVYP2ATI40[Jf]0;2`/02ATI40Fe]K02XZ:P0Q8B4071`L
01XJ6P0G5aL05QHF01hN7P1<C4`0@T920:RXZ01OGel08R8R01/K6`0j>SX0BTY:04U9B@1/K6`0L71`
07AdM01iNGT0/[:b0;Vi^@2d];@0DE5A01`L700S8b<0?Shn01LG5`0I6AT07alO04e=C@1?Cdl0D51@
06YZJP0/;2`07AdM01`L700O7al00P1BDU80:P1/K6`0O7al08N7Q`1SHf<0JVYZ079bLP0m?Cd0=cLg
03hn?P16ATH0?clo01hN7P0F5QH0Hf=S09jNWP29RHT0J6QX09:BTP1MGEd0Q8B407UiN@23Ph<0LG5a
065QH@1IFET0?Shn03Xj>P0l?3`0DE5A05aLG00m?Cd09RHV01LG5`0Q8B40C4a<02d];@1^KVh0G5aL
059BDP1GEeL0Hf=S03dm?@@071`L00L05QHF01TI6@0H61P071`L03Hf=P1gMgL0FEUI008071`L00l0
:RXZ05]KF`0d=3@0E5AD08^;R`2?Shl0Lg=c024Q8@0E5AD061PH01TI6@0G5aL06ATI01HF5P0E5AD0
0P0F5QH0Z@0];Bd0IFEU06IVIP3=cLd0VIVI06QXJ01^KVh0Zj^[08j>SP0d=3@0;2`/02PX:00];Bd0
>CTi0820P03Fe]H0SXj>01/K6`0V9RH0FEUI0492@P1JFUX0TY:B08f=S@2?Shl0`<300;^k^`1LG5`0
KFe]03dm?@2SXj<0`l?308F5Q@1UIFD0>SXj02h^;P0[:b/0Bd];03`l?00N7Qh071`L01dM7@0N7Qh0
Jf][0<K6aP1IFET0C4a<09RHV00c<c<0820P02d];@1;Bd/092@T03Ph>011@D40MgMg09NGU`1JFUX0
Ph>30:ZZZP1GEeL0YjNW0:VYZ@0];Bd0<S8b04Q8B01>CTh0Rh^;07AdM00^;Rh09BDU02l_;`13@d<0
QhN70861P@2=SHd0@41001PH600Y:BT0<c<c02HV9P1jNWX0MgMg03hn?P14A4@0LW9b07EeM@0n?Sh0
;bl_020P800T92@08R8R02`/;00J6QX06ATI03@d=01]KFd0AdM705eMG@35aLD0V9RH03lo?`0c<c<0
=CDe02l_;`0L71`05QHF024Q8@1NGUh0NGUi04i>CP2CTi<0TI6A0<k>cP37alL0ADE504i>CP0N7Qh0
5QHF01/K6`0M7Ad0;2`/0:6QX@2HV9P0YJFU01/K6`0L71`08B4Q04E5A@2NWYh0De=C01<C4`0G5aL0
7QhN04E5A@1:BTX0K6a/0;Vi^@2TY:@09BDU01PH600J6QX0CDe=03lo?`0E5AD05aLG05YJFP2PX:00
TY:B05]KF`2FUYH0SHf=03Xj>P1[Jf/0Xj>S0:2PX038b<P0[Jf]0410@01MGEd0Vi^K0;Zj^P2HV9P0
_[jn075aL@1/K6`0>CTi01dM7@0O7al04Oooool000oooooo0?l0YZJV09RHV01SHf<0NGUi07IfMP1d
M7@0SHf=061PH02<S8`0^k^k05=CD`1<C4`0L71`04Y:BP1SHf<0?clo07MgM`0d=3@0GEeM0861P@0k
>c/0O7al06IVIP1BDU80JFUY04M7A`18B4P0FUYJ03dm?@0^;Rh0Fe]K05ADE01fMWH0GemO03Xj>P21
PH40:2PX05MGE`1XJ6P0<30`03De=@0U9BD0IFEU030`<01ZJVX0CTi>0451@@18B4P0Cdm?030`<01T
I6@0MWIf03/k>`1TI6@07AdM07IfMP1ZJVX0;Bd]02`/;01ZJVX0Jf][02<S8`16ATH0BDU904e=C@1]
KFd0M7Ad03hn?P0V9RH0MWIf03/k>`1NGUh0LG5a034a<@1JFUX0>SXj05MGE`1NGUh0PX:20:2PX01`
L700?clo05IFEP1SHf<0?Cdm03Lg=`2HV9P0AdM702d];@1FEUH0TY:B0451@@0e=CD0?Cdm059BDP0R
8R80PX:20820P01bLW80?Shn08Z:RP12@T80TI6A04];B`1fMWH0CTi>071`L02KVi/0Cdm?05aLG01J
FUX0De=C06e]K@1<C4`0JVYZ028R8P0o?cl0Rh^;06EUI@0i>CT0=SHf06=SH`2?Shl0PH6106m_K`1`
L700>3Ph02LW9`2DU9@0GUiN03Ti>@1MGEd0WYjN06QXJ02JVYX0HF5Q034a<@1eMGD0Shn?06=SH`20
P800>3Ph04i>CP2SXj<0De=C04=3@`2ZZZX0ATI602h^;P24Q8@0K6a/03Xj>P1CDe<0C4a<020P800i
>CT0T92@03`l?01gMgL0I6AT0;Vi^@1WIfL0E5AD09bLW01CDe<0AdM707EeM@2g]kL0MgMg06i^KP2O
Wil0?Cdm034a<@26QXH0ZZZZ06a/K01[Jf/0_Kfm09^KV`17AdL0Z:RX06m_K`1HF5P0/;2`07YjNP13
@d<0BDU909RHV01RHV80U9BD02LW9`0k>c/0Bd];04=3@`2f][H0Cdm?028R8P1<C4`0D51@0<C4a01l
O7`08R8R06IVIP1_Kfl0BTY:09^KV`2OWil0UIFE024Q8@1<C4`0JFUY07AdM01OGel0Ti>C08n?S`2<
S8`0@41003Ph>01bLW80>SXj06YZJP1[Jf/0ADE505MGE`1FEUH0J6QX03De=@2SXj<0QhN702d];@13
@d<0Fe]K02PX:00C4a<0Vi^K0<G5a@16ATH0IFEU07YjNP15ADD0ATI606IVIP19BDT0D51@0451@@1=
CDd0IFEU04E5A@0/;2`0Fe]K07QhN01ADE40<30`06QXJ02e]KD002<0WIfM04i>CP29RHT0OGem065Q
H@1>CTh0VYZJ09BDU012@T80Xj>S0;2`/00c<c<0/k>c06e]K@18B4P0K6a/05]KF`1PH6007alO08b<
S01@D500EEEE08B4Q01JFUX0PX:205iNGP1GEeL0<S8b02<S8`0c<c<0IVIV028R8P1MGEd0@T9207=c
L`0Looooo`0D09:BTP2c/k<0]kNg09bLW01dM7@0Shn?04m?C`28R8P0S8b<06][J`0j>SX07QhN01/K
6`0F5QH05ADE01HF5P1?Cdl07AdM05aLG00h>3P2010@400F02HV9P0[:b/051@D014A4@0I6AT0=SHf
0:RXZ01hN7P0:RXZ03Xj>P1iNGT0:2PX02DU9@0a<C40:RXZ01TI6@0K6a/0>CTi04=3@`0`<3008R8R
01@D50805ADE01l05aLG0492@P1aLG40Jf][05MGE`0b<S807QhN055AD@1BDU8092@T02HV9P0E5AD0
61PH02`/;01JFUX0K6a/05mOG`1gMgL0OWin09^KV`1SHf<0EeMG03Ph>01DE5@0GemO055AD@1`L700
QhN707AdM01jNWX0HF5Q00809BDU00l0=cLg05=CD`14A4@07QhN02LW9`12@T80@d=308n?S`2;Rh/0
YZJV05IFEP12@T80820P01`L700M7Ad00P0K6a/301`L700>04M7A`1oOgl0A4A401`L700M7Ad09bLW
05eMG@1KFe/0=SHf04];B`2KVi/0KVi^04I6AP0F5QH401DE5@1/01HF5P0D51@061PH01HF5P0_;bl0
IVIV06m_K`2CTi<0fm_K0;Vi^@2IVIT0Ph>305YJFP11@D40@41006i^KP2SXj<0][Jf0;Bd]03@d=00
CTi>03Lg=`0d=3@0DU9B09>CT`20P800Fe]K051@D019BDT0GUiN09nOW`0m?Cd0?Shn09RHV02ZZZX0
>c/k02@T900V9RH09BDU038b<P1:BTX0A4A401`L700J6QX07AdM024Q8@0a<C40ZZZZ0:^[Z`1RHV80
6a/K04M7A`1eMGD08R8R02TY:@1?Cdl0OWin03Ph>015ADD0E5AD0<71`@1kNg/0LW9b0820P01QHF40
Shn?09NGU`1BDU806ATI01PH600g=cL0Q8B409VIV@1[Jf/0Bd];03`l?014A4@0S8b<0;bl_02MWId0
=CDe01/K6`0g=cL07AdM01/K6`13@d<0WinO06ATI01ADE40EUIF08n?S`1HF5P0BTY:04M7A`0a<C40
;bl_05ADE00`<300@D5108>3P`24Q8@0>3Ph07inOP2KVi/0DE5A01PH600E5AD061PH0`0G5aL05@0Q
8B40FEUI07alO01LG5`0WinO0:VYZ@1aLG40V9RH0:FUY@0I6AT06a/K01TI6@0M7Ad07QhN05eMG@2i
^KT0YZJV0;Rh^00Y:BT09RHV05QHF002092@T00W020P800G5aL071`L02DU9@18B4P0ATI6038b<P21
PH40MGEe02l_;`0G5aL06QXJ02<S8`2=SHd06ATI03<c<`2UYJD0QHF504M7A`1PH600Xj>S02DU9@0G
5aL06a/K03Hf=P2KVi/0^KVi0<?3``3Fe]H0_Kfm05iNGP0X:2P08B4Q08>3P`2[Zj/0^k^k0;Jf]P2;
Rh/0TY:B017ooooo000?ooooo`3o08J6QP2[Zj/0I6AT08B4Q018B4P0M7Ad08>3P`1]KFd0UYJF04e=
C@0e=CD0IfMW08^;R`0n?Sh0CDe=04U9B@29RHT0@D51055AD@1?Cdl0;Rh^096AT@12@T80@D5103`l
?00R8R80@410069RHP0l?3`0<c<c03hn?P0U9BD0ATI604i>CP1cLg<0VYZJ02<S8`0b<S80ATI6030`
<00b<S804Q8B05QHF00Y:BT0IFEU01HF5P0W9bL0Bd];05MGE`0X:2P0@T9202d];@0O7al0MWIf02@T
901nOWh0A4A4010@401EEED0Q8B405mOG`0M7Ad0ATI601@D500W9bL0AdM705ADE00e=CD0AdM708Z:
RP0R8R80>SXj05IFEP0U9BD0FEUI02`/;01^KVh0Fe]K08b<S02HV9P0QhN701DE5@1:BTX0NWYj04U9
B@1;Bd/0V9RH034a<@0J6QX0820P05eMG@0b<S80>CTi04=3@`1RHV80;Bd]06QXJ013@d<0GemO03dm
?@1iNGT0>3Ph07]kN`15ADD0GEeM03/k>`1DE5@0PX:204Y:BP1/K6`0D51@0451@@1XJ6P0BTY:06m_
K`0m?Cd0=SHf05mOG`1BDU80@T9204a<C011@D40G5aL06m_K`1fMWH0MgMg05iNGP0j>SX0Jf][05UI
F@1DE5@0D51@07UiN@1OGel0TY:B07IfMP18B4P0Ogmo09BDU00j>SX0YZJV07MgM`18B4P0PH61038b
<P1UIFD0`l?304a<C00V9RH0C4a<04Q8B00f=SH0GEeM05IFEP0I6AT0>3Ph08Z:RP0i>CT0MWIf03lo
?`1nOWh0Ng]k05aLG02MWId0AdM701/K6`0l?3`0OGem05eMG@1SHf<0S8b<07moO`0k>c/0UYJF08B4
Q00P8200ATI60:VYZ@2?Shl0BDU909BDU01bLW80Fe]K0;2`/01OGel0>SXj05]KF`2][Jd0MgMg07Ee
M@0Z:RX0Hf=S0410@01gMgL0c/k>069RHP26QXH0X:2P03dm?@1iNGT0Ogmo03Ti>@1fMWH0DE5A02l_
;`0m?Cd0DE5A0;Fe]@1<C4`0I6AT05EEE@1oOgl0?Shn09bLW03Hf=P0_[jn05]KF`1LG5`0F5QH03De
=@2=SHd0EEEE04I6AP1RHV80Rh^;0410@00D51@0MgMg065QH@0[:b/0ADE504U9B@1NGUh0?Cdm07Ee
M@2<S8`0BDU907=cL`1TI6@0;Rh^08Z:RP2g]kL0KFe]06YZJP16ATH0De=C07IfMP1ADE40@T9206QX
J01_Kfl0BDU901LG5`12@T80Hf=S000S08n?S`1<C4`0R8R809:BTP25QHD0JVYZ0=?Cd`2`/;00?clo
0:^[Z`2/[:`0C4a<0=[JfP2f][H0ATI606IVIP1IFET0HF5Q02LW9`2WYjL0D51@05ADE023Ph<0HV9R
09ZJVP1XJ6P0C4a<034a<@0X:2P0:RXZ05=CD`0H61P0NWYj06i^KP1kNg/07?ooool0:`3MgMd0eMGE
0;Fe]@20P800K6a/05iNGP1^KVh0CTi>065QH@23Ph<0GEeM04e=C@0b<S807AdM01XJ6P0G5aL0@d=3
02TY:@0c<c<0EeMG014A4@0>3Ph0;bl_04M7A`0J6QX04Q8B01@D500G5aL0QhN703`l?00T92@09bLW
09FEU@1NGUh0?3`l03<c<`1:BTX09bLW02XZ:P0o?cl0CTi>030`<00P82000P0D51@01P0G5aL0<C4a
05]KF`0o?cl0FUYJ02/[:`806ATI01T0?3`l08J6QP0X:2P0:2PX01/K6`0L71`0:BTY03lo?`2ATI40
WYjN06][J`1WIfL0/k>c04i>CP0e=CD07QhN03Ph>017AdL0=3@d03Hf=P19BDT0C4a<065QH@1DE5@0
61PH00805ADE02<07alO03Xj>P19BDT0<c<c030`<015ADD0OWin0<K6aP2EUID0Q8B404a<C00R8R80
820P02@T900U9BD0820P01`L700M7Ad07QhN065QH@22PX80Bd];020P800R8R809BDU03Ph>01`L700
@D5105IFEP2h^;P0OGem059BDP0h>3P07AdM01LG5`0501DE5@0T01LG5`0l?3`0X:2P07]kN`2[Zj/0
f=SH08J6QP1ADE40E5AD04m?C`2KVi/0V9RH061PH00c<c<07alO02LW9`2PX:00/K6a07QhN01VIVH0
GEeM0<k>cP1IFET0=cLg04E5A@0g=cL0NGUi0<71`@1^KVh0HV9R0<_;b`2PX:00GUiN075aL@1kNg/0
I6AT0P1]KFd06`1RHV80H61P05iNGP1HF5P0AdM709RHV02:RXX0ZZZZ08n?S`0U9BD07alO07YjNP0i
>CT0@41006=SH`1:BTX0DE5A075aL@22PX80_Kfm05iNGP1]KFd0;Bd]01TI6@0d=3@0FUYJ05MGE`02
03De=@0S03Ph>01mOGd0VYZJ08N7Q`0l?3`0@41005iNGP2RXZ80a/K60:NWY`1GEeL09bLW02HV9P0H
61P07QhN03@d=01GEeL0ATI606IVIP1DE5@0OWin07]kN`0h>3P0ATI6059BDP11@D40=SHf06IVIP26
QXH0RHV906=SH`0m?Cd0WIfM06][J`1GEeL00P0E5AD0<@0G5aL05ADE01DE5@0G5aL07AdM0410@02A
TI40RHV907]kN`1jNWX0D51@04i>CP2<S8`061PH01/K6`0I6AT07AdM03Ti>@1WIfL0HF5Q0;^k^`33
`l<0?clo03Lg=`1?Cdl0WinO05]KF`0/;2`0;Rh^05mOG`27QhL0EUIF04A4A00O7al0@d=309^KV`1R
HV806a/K01XJ6P0N7Qh0Lg=c04A4A02VYZH0T92@04M7A`1OGel0]kNg04I6AP0G5aL00P0K6a/03`0U
9BD0ATI603Ti>@0];Bd0JFUY07moO`0H61P05aLG028R8P2k^k/0`l?30<K6aP2LW9`0NWYj06e]K@0A
ooooo`003oooool0QP1fMWH0S8b<05QHF02<S8`0GemO06ATI01iNGT0L71`08N7Q`1hN7P0?3`l04=3
@`1[Jf/0?Shn05iNGP0l?3`0MWIf03Xj>P1FEUH0D51@02@T901/K6`0F5QH03`l?01KFe/0<c<c03Xj
>P1>CTh0:RXZ05EEE@28R8P0DU9B051@D00e=CD0A4A407moO`10@400ADE504m?C`0P8200BTY:02/[
:`1KFe/0ATI607inOP0f=SH0ADE50451@@17AdL09BDU05=CD`0o?cl08R8R05eMG@0O7al0Ph>304Q8
B00>3Ph09bLW05]KF`17AdL0?Shn0861P@16ATH0Cdm?06=SH`0f=SH05QHF02LW9`1jNWX0ADE506AT
I01GEeL06a/K04A4A00b<S80@T9202l_;`2>SXh0VIVI05IFEP0Q8B40=3@d06MWI`16ATH0B4Q808b<
S01NGUh0;bl_02PX:027QhL0=cLg05aLG01NGUh0IfMW03/k>`1fMWH0ATI604e=C@15ADD0M7Ad04Q8
B01hN7P0AdM708V9R@1[Jf/0JFUY075aL@1^KVh0[:b/08R8R01bLW80OGem04Y:BP2<S8`0N7Qh05eM
G@1VIVH0@d=306m_K`1SHf<0De=C07emO@1ZJVX0Ng]k0:BTY01cLg<0BDU906m_K`1XJ6P0JFUY06QX
J01PH600?Cdm0P2k^k/0R01OGel0S8b<08b<S00X:2P0OWin06IVIP1CDe<0Q8B4024Q8@1<C4`0^KVi
09RHV01BDU80E5AD03Ti>@1JFUX0/;2`09NGU`10@400@T9208^;R`0m?Cd0TY:B079bLP2BTY80Hf=S
05]KF`2MWId0F5QH0451@@2:RXX0Shn?03/k>`1mOGd0Ti>C08V9R@0k>c/0XZ:R08b<S01BDU80EeMG
0<;2`P2=SHd0@D5107QhN01dM7@0HF5Q0;6a/@17AdL0=cLg05UIF@2_[jl0S8b<07=cL`0W9bL0GUiN
04a<C00o?cl0QHF509BDU02?Shl0UiNG0451@@2;Rh/0H61P03@d=01iNGT0IFEU03Ph>00Y:BT05QHF
0820P00i>CT0QhN705IFEP1PH600=SHf07moO`27QhL0SXj>071`L01;Bd/0ADE501XJ6P20P800QHF5
05ADE01QHF40YJFU07EeM@0g=cL0Ng]k0492@P0b<S80DE5A04m?C`1QHF40C4a<0;:b/P2EUID0B4Q8
09FEU@1cLg<09bLW03De=@1NGUh0?clo061PH014A4@0?clo09NGU`25QHD0Bd];065QH@1_Kfl0JFUY
024Q8@0b<S80J6QX08F5Q@1>CTh0Ti>C09BDU01dM7@0EEEE0=OGe`2ZZZX0>3Ph0<W9b@2VYZH08R8R
09jNWP2/[:`0Bd];06YZJP1HF5P203dm?@0@0<C4a01OGel0DE5A09RHV01PH600^KVi0<;2`P1YJFT0
=3@d02<S8`0V9RH0@41002HV9P2CTi<0UIFE08:2PQcooooo00/0^[Zj0;bl_01TI6@0Cdm?03dm?@0Z
:RX0?Cdm07moO`1HF5P0GemO06m_K`02055AD@1103hn?P0];Bd0<c<c07YjNP1BDU80:2PX061PH00W
9bL07QhN04Q8B01oOgl0H61P03`l?00^;Rh0>3Ph0::RXP1GEeL0=CDe06ATI02f][H0^k^k0:NWY`2M
WId0Ng]k059BDP1>CTh0FEUI07QhN01dM7@0De=C02@T900H61P0>c/k05]KF`0a<C40D51@02h^;P0I
6AT05aLG01XJ6P0Z:RX0clo?069RHP13@d<0Bd];06=SH`1jNWX0Ogmo05ADE01>CTh0VYZJ07inOP1`
L700:BTY01HF5P0E5AD08R8R04m?C`0_;bl071`L04];B`0d=3@0?clo04Q8B00T92@00`0E5AD00`0I
6AT07QhN04];B`0206=SH`0N0;:b/P1TI6@0TY:B08B4Q02?Shl0>CTi01XJ6P0M7Ad0820P024Q8@0M
7Ad071`L030`<01ZJVX0Ph>305]KF`0U9BD0;2`/02PX:00V9RH0Kfm_08j>SP2_[jl0b/[:0:JVYP0b
<S80C4a<0492@P0P82004a<C0`0E5AD0?@0G5aL07AdM06QXJ02?Shl0Ng]k0:NWY`3Rh^80_[jn0;6a
/@2g]kL0e=CD0:n_[`0Y:BT05aLG01DE5@0W9bL0ATI608^;R`0Z:RX09RHV03dm?@1hN7P0`/;20;:b
/P1fMWH0KFe]06i^KP38b<P0d=3@09nOW`2UYJD0dM7A09BDU01gMgL0EEEE03Xj>P0_;bl09BDU03hn
?P0Y:BT06ATI01LG5`0S8b<0@4100;Zj^P12@T80IVIV0=SHf02:RXX0:RXZ03Lg=`2VYZH0P82008Z:
RP1YJFT0=cLg02XZ:P0W9bL0OWin04i>CP1ZJVX00P0I6AT0:`0Q8B40=CDe03<c<`1ADE40H61P03dm
?@1PH600RXZ:0<71`@21PH40C4a<065QH@2h^;P0b/[:0;Vi^@1mOGd0CTi>01/K6`0L71`07AdM02l_
;`1SHf<06QXJ01dM7@1IFET0JVYZ09nOW`1`L700>CTi04];B`1YJFT0[Jf]0;Ng]`2OWil0JVYZ06i^
KP1YJFT0^;Rh05MGE`1[Jf/05aLG01DE5@0G5aL00P0E5AD00`0F5QH08b<S05QHF002092@T00j03Ph
>00m?Cd0K6a/04];B`2>SXh06a/K01`L700O7al0>CTi03dm?@1BDU80LW9b0<30`02/[:`0GemO061P
H02[Zj/0clo?055AD@0U9BD0;Bd]04=3@`2>SXh0JFUY0410@00J6QX08b<S07moO`2JVYX0NWYj05aL
G01CDe<0Xj>S0;no_`21PH40GemO075aL@38b<P0dM7A024Q8@0H61P071`L01dM7@0P8200IVIV028R
8P0E5AD05aLG059BDP12@T808B4Q07moO`2EUID0SXj>0;Vi^@30`<00MWIf07AdM17ooooo000?oooo
o`0:0:FUY@2b/[80Fe]K0;bl_01eMGD0L71`06ATI01jNWX0XJ6Q0;Bd]080C4a<00d0B4Q802d];@23
Ph<0D51@06e]K@0/;2`0RXZ:09>CT`0m?Cd0U9BD05]KF`1=CDd0OGem0080>CTi00T0E5AD01DE5@0k
>c/0HV9R05ADE01=CDd0GemO04=3@`2PX:000P0o?cl0@`17AdL0=SHf04M7A`0Y:BT0AdM702TY:@1l
O7`0?3`l059BDP14A4@0>SXj02l_;`1YJFT0IfMW03Ti>@1NGUh07alO096AT@1bLW809bLW03Ti>@1a
LG409bLW038b<P1=CDd0;bl_061PH01nOWh0Bd];02TY:@0d=3@0MGEe03Hf=P1NGUh0Cdm?02DU9@1Z
JVX0?3`l05IFEP0d=3@0OWin09RHV010@40092@T03Ph>01>CTh0<c<c04U9B@2KVi/0I6AT038b<P0Y
:BT0Shn?02XZ:P0o?cl0GEeM08F5Q@0m?Cd0IFEU04Q8B00e=CD0<S8b09JFUP1=CDd0H61P02XZ:P2I
VIT00P1QHF40601NGUh0=CDe05mOG`1aLG40IfMW06a/K00[:b/0OWin06MWI`17AdL0NGUi034a<@14
A4@0J6QX059BDP1bLW80>SXj0451@@2[Zj/0Shn?04A4A01QHF40EeMG06QXJ080IfMW09d0:BTY0820
P02<S8`0GemO09JFUP2MWId0CDe=08^;R`1WIfL0JFUY0:FUY@1=CDd0?Cdm0;6a/@1eMGD0ATI6069R
HP18B4P0=cLg05EEE@1`L700DE5A04a<C01/K6`0:2PX069RHP1hN7P0Shn?03/k>`0c<c<0U9BD07em
O@1JFUX0SHf=0:6QX@0Q8B40H61P08B4Q01`L700>SXj09fMW@2LW9`0M7Ad06UYJ@37alL0V9RH05aL
G02BTY80SHf=06=SH`2`/;00Hf=S04e=C@1[Jf/0[:b/08J6QP1IFET0:BTY05]KF`1EEED0ADE50:6Q
X@1LG5`0Ogmo09FEU@1ADE40^k^k0861P@0l?3`0O7al071`L00b<S80:RXZ01LG5`1OGel0<30`09fM
W@1TI6@0GemO06MWI`2IVIT0Shn?06a/K018B4P0JFUY06MWI`0g=cL0OWin05eMG@19BDT0V9RH0<;2
`P1nOWh0?clo06i^KP0_;bl0?3`l06MWI`1[Jf/0L71`059BDP2j^[X0TY:B024Q8@2DU9@0PH6103Ti
>@0m?Cd0GemO030`<01iNGT0GUiN03dm?@1SHf<0B4Q8030`<029RHT0`<3008^;R`0a<C40<30`06IV
IP0c<c<07AdM061PH01bLW80AdM703De=@3Cdm<0XJ6Q03Hf=P2?Shl0TI6A02@T9025QHD0GUiN03Hf
=P2TY:@0QHF503Hf=P0G5aL0PH6104];B`1CDe<0Y:BT04I6AP1oOgl0Rh^;059BDP0a<C408b<S02h^
;P1KFe/05aLG05MGE`1QHF40<30`01cooooo06H0QhN70:FUY@1JFUX0=CDe02HV9P0W9bL0;2`/0492
@P0l?3`0>c/k07]kN`21PH40K6a/06][J`1/K6`0CTi>03Hf=P1ZJVX0IVIV05mOG`1gMgL0CTi>03hn
?P1@D500A4A403Lg=`0d=3@0F5QH071`L02LW9`0XZ:R0<[:bP22PX80CDe=05mOG`1lO7`0WYjN08^;
R`2=SHd0QHF507MgM`29RHT0RXZ:05EEE@1gMgL0KVi^03<c<`1;Bd/0<30`01TI6@0G5aL09BDU01TI
6@1DE5@0XJ6Q0;Jf]P3Bd]80][Jf08>3P`0l?3`06a/K01dM7@0X:2P0?3`l05ADE00b<S80;Bd]01@D
500C4a<05aLG05ADE00b<S806a/K024Q8@11@D40B4Q804i>CP0i>CT06QXJ01DE5@0H61P06QXJ01/K
6`0O7al0BTY:0<C4a026QXH0IfMW06QXJ02BTY80VIVI04];B`0d=3@0<S8b02LW9`0O7al07AdM01lO
7`1WIfL0FUYJ07QhN01TI6@203<c<`0R030`<010@400PH6109JFUP2KVi/0`l?308b<S01[Jf/08B4Q
030`<013@d<0>SXj02h^;P0O7al08b<S038b<P1KFe/0LG5a07alO01OGel0UIFE0<c<c02EUID0V9RH
0861P@27QhL0SHf=03hn?P18B4P0?Cdm04Y:BP1JFUX0=3@d01HF5P805ADE00h071`L06ATI01VIVH0
<c<c08f=S@0h>3P0I6AT0:VYZ@15ADD0@41009jNWP0f=SH07QhN01HF5P805ADE00D0:2PX038b<P0A
4A404Q8B014A4@0201<C4`0A06i^KP10@400CDe=0;:b/P2<S8`0UYJF04E5A@1lO7`0UIFE05IFEP0Y
:BT06a/K01dM7@0G5aL0GUiN08^;R`1LG5`00`0E5AD0:00O7al0<C4a02h^;P0Q8B405ADE02HV9P27
QhL0^KVi0<W9b@1nOWh0JFUY09ZJVP1]KFd0SXj>0;Vi^@2PX:009BDU01TI6@0L71`08B4Q04M7A`0F
5QH061PH01dM7@1YJFT0Rh^;0;Rh^02EUID0MgMg08:2PP2NWYh0_Kfm0;Ng]`2=SHd0TY:B0<71`@2Y
ZJT0E5AD09>CT`0S8b<201LG5`0/01TI6@0L71`0820P04];B`2QXJ40_kno05]KF`1gMgL07alO06IV
IP1=CDd0YZJV061PH01CDe<0EeMG079bLP1nOWh0UIFE0;2`/036a/H0bLW9075aL@0g=cL0>CTi05=C
D`2<S8`0@41002LW9`0`<300FUYJ05mOG`1>CTh07AdM02<S8`1lO7`0e=CD0<30`02][Jd0/[:b08Z:
RP2XZ:P0QXJ60;no_`3<c<`20:6QX@0705EEE@0K6a/05aLG01/K6`0];Bd0QXJ601/K6`0201DE5@0:
01hN7P1VIVH0TY:B08^;R`0j>SX0UiNG0<o?c`3;bl/0fm_K0<g=cA7ooooo000?ooooo`1309VIV@2g
]kL0E5AD08:2PP1XJ6P0LW9b04U9B@13@d<0MgMg09bLW019BDT0BTY:06a/K00h>3P0MgMg05]KF`1j
NWX0:RXZ051@D01`L700ATI60:NWY`0j>SX0Shn?08Z:RP0_;bl0;Rh^069RHP0f=SH0<C4a06UYJ@1]
KFd0CTi>05UIF@1:BTX0X:2P0410@00i>CT0B4Q803hn?P1CDe<09bLW06IVIP0d=3@0Ng]k0410@01>
CTh0De=C02PX:018B4P0PH6107]kN`0k>c/0HF5Q034a<@2FUYH0Ng]k02PX:015ADD0MGEe05=CD`0a
<C40EEEE03hn?P1WIfL0U9BD05iNGP0203<c<`1O07IfMP11@D40Kfm_079bLP0S8b<0D51@0410@01>
CTh0?3`l08Z:RP3=cLd0Bd];034a<@0l?3`0AdM702DU9@24Q8@0/;2`06=SH`10@400F5QH08B4Q00b
<S80>3Ph04I6AP1IFET0C4a<09>CT`1hN7P0E5AD0492@P1QHF40AdM7061PH011@D40Lg=c04e=C@29
RHT0MgMg04i>CP1_Kfl0HF5Q07YjNP27QhL0C4a<07inOP1MGEd0@d=306][J`18B4P0G5aL04];B`1^
KVh0U9BD06a/K01]KFd0WIfM034a<@18B4P0JFUY05=CD`15ADD0R8R806m_K`1NGUh0NWYj05UIF@13
@d<0W9bL09^KV`15ADD0OGem03Hf=P2@T900UYJF0451@@0o?cl0a<C403lo?`0/;2`0OWin05EEE@0d
=3@0CTi>05UIF@0];Bd0Kfm_08n?S`0n?Sh0G5aL065QH@2VYZH0>CTi03`l?01WIfL00P1=CDd0:`2I
VIT0YJFU03Lg=`1RHV80PX:2079bLP15ADD0^;Rh0:n_[`1bLW80IVIV0;fm_@1bLW80Hf=S0:>SX`2<
S8`0FEUI0;:b/P0l?3`061PH071`L02NWYh0LG5a055AD@1?Cdl0X:2P059BDP1=CDd0/K6a04Q8B01Q
HF40Rh^;03lo?`2i^KT0NGUi03dm?@1oOgl0O7al03hn?P0d=3@0:2PX05YJFP0_;bl00P2/[:`0C`2<
S8`0JFUY09RHV02:RXX0T92@05YJFP10@400H61P03/k>`1jNWX0>c/k01lO7`19BDT0HF5Q06e]K@10
@400JVYZ05=CD`0V9RH0>SXj06EUI@1fMWH0D51@0;^k^`2=SHd0?clo06EUI@21PH40ADE50492@P1K
Fe/071`L0451@@1CDe<0HV9R07AdM01MGEd0820P059BDP1ZJVX0OWin02`/;00e=CD0IfMW07QhN00e
=CD0M7Ad07MgM`19BDT0@4100:NWY`3Hf=P0I6AT0<71`@2SXj<0:b/[0;2`/01iNGT0;2`/07AdM01m
OGd0GemO02<S8`2OWil09BDU075aL@2c/k<0Hf=S08J6QP2VYZH0@41001<C4`0/;2`0C4a<06QXJ00J
6QX0IFEU07moO`1XJ6P07?ooool02@2ATI40^;Rh07emO@0a<C409BDU02<S8`0V9RH09BDU0451@@02
051@D00404a<C01?Cdl0EEEE04M7A`80?Cdm03<0AdM707alO01nOWh0T92@05MGE`1SHf<0GUiN038b
<P19BDT0IfMW03Xj>P0Z:RX0?3`l0:n_[`3AdM40NWYj07AdM01UIFD0GEeM02HV9P0Q8B40:BTY05AD
E02?Shl0SHf=07emO@25QHD0]KFe08Z:RP1gMgL0CDe=04I6AP0l?3`0=SHf028R8P0^;Rh0Jf][01DE
5@17AdL0Ph>30492@P0Z:RX06a/K01`L700M7Ad09BDU02d];@1MGEd0=CDe03lo?`0M7Ad00P0E5AD0
4@1=CDd0=cLg01hN7P0E5AD0Cdm?05=CD`1MGEd0B4Q802PX:00H61P06QXJ01PH600M7Ad09RHV03<c
<`1nOWh0UYJF0080EUIF0180A4A40:6QX@2SXj<0Lg=c075aL@1/K6`0HV9R07YjNP1bLW80/k>c05MG
E`2/[:`0PX:204E5A@1:BTX0EeMG05YJFP1[Jf/2096AT@0b0<G5a@1^KVh0Jf][06a/K00e=CD09RHV
05iNGP2HV9P0MgMg05QHF01`L700QXJ605=CD`1cLg<0YjNW0:^[Z`2DU9@0>3Ph034a<@0o?cl0BDU9
05IFEP1fMWH0Bd];07UiN@2>SXh0RHV901XJ6P0E5AD051@D01DE5@0F5QH0=cLg04E5A@22PX80b/[:
05ADE00S8b<0XZ:R05MGE`0i>CT0LG5a03Lg=`0O7al05aLG01XJ6P0Q8B40B4Q801DE5@0C4a<2018B
4P0=01<C4`0D51@0Bd];04];B`1JFUX0LW9b01`L700/;2`0JFUY04];B`1HF5P0BTY:024Q8@0201TI
6@0@02/[:`1mOGd0Ti>C07QhN00D51@0410@01DE5@0I6AT0>SXj020P800U9BD05ADE02DU9@2>SXh0
X:2P08B4Q0806ATI0180;bl_07UiN@1@D500Vi^K07MgM`1HF5P0>c/k01dM7@0U9BD0ADE501LG5`0K
6a/071`L05IFEP32`/80_Kfm0;:b/P22PX8207UiN@1<0:j^[P38b<P0];Bd0<;2`P3MgMd0[Jf]07em
O@2n_[h0De=C02/[:`0c<c<0@d=3051@D01XJ6P0SHf=0;Rh^02[Zj/0LG5a07alO01:BTX0C4a<04I6
AP2MWId0S8b<06i^KP1LG5`0CTi>055AD@1cLg<0UiNG0<[:bP3@d=00FUYJ065QH@1YJFT0Kfm_06e]
K@2RXZ80S8b<08N7Q`1aLG40^[Zj05EEE@0K6a/0EEEE0;6a/@3Ng]h0e=CD09FEU@1KFe/0Ng]k0<O7
a`3:b/X0`<3005UIF@0R8R80>SXj07EeM@1JFUX06ATI01`L700/;2`0UIFE01PH600C4a<05aLG01XJ
6P10@400Zj^[03<c<`19BDT0WYjN0:6QX@2n_[h0^[Zj0<;2`Q7ooooo000?ooooo`1^08R8R037alL0
GemO08N7Q`1HF5P0SHf=06MWI`1`L700U9BD07UiN@1KFe/0Rh^;09BDU011@D40MgMg061PH02OWil0
A4A406i^KP29RHT0A4A40::RXP12@T80@D5106=SH`14A4@0HV9R07inOP0g=cL0=CDe03/k>`14A4@0
K6a/04];B`15ADD0Kfm_02DU9@1;Bd/0De=C03Hf=P0l?3`0820P079bLP0Y:BT0IfMW01dM7@1FEUH0
OGem03lo?`0a<C40<c<c01PH600m?Cd0GUiN01dM7@27QhL0@41002XZ:P1lO7`0KFe]03`l?00d=3@0
Cdm?02TY:@2DU9@0YjNW05QHF00`<300=cLg06][J`0[:b/0IfMW06QXJ00W9bL0HV9R03Hf=P1^KVh0
>CTi04=3@`2@T900PX:204=3@`21PH40Jf][02PX:01=CDd0R8R804=3@`0U9BD092@T07=cL`0/;2`0
?clo04E5A@1IFET0<C4a05iNGP0m?Cd0HF5Q03/k>`1LG5`0B4Q8059BDP0m?Cd0EEEE04Q8B01_Kfl0
AdM704Q8B01^KVh205aLG02907=cL`0l?3`0IVIV065QH@1?Cdl0CDe=03dm?@1KFe/0@D5105IFEP1T
I6@0IfMW06a/K02?Shl0ADE506i^KP1=CDd0DU9B04E5A@1QHF40ATI604i>CP1hN7P0D51@05YJFP2C
Ti<0RXZ:038b<P1gMgL0AdM707]kN`2MWId0>SXj04=3@`2HV9P0CDe=03@d=01WIfL0ADE503Ti>@1A
DE40ATI601lO7`1UIFD0RHV903Ph>01/K6`0DU9B09BDU01LG5`0DE5A08:2PP1CDe<0<c<c08b<S02S
Xj<0ADE50492@P1jNWX0@41003Lg=`2WYjL0WinO06e]K@1/K6`0bl_;09JFUP1BDU80W9bL08N7Q`1@
D500UIFE03Lg=`0T92@0Kfm_09fMW@1YJFT0FUYJ024Q8@1NGUh0DU9B04m?C`2e]KD0DU9B08B4Q02k
^k/0?3`l0;Bd]00o?cl0;bl_08f=S@1RHV80@d=304M7A`1BDU80MWIf02<S8`1WIfL0EEEE05=CD`1V
IVH0U9BD07]kN`1YJFT0A4A405YJFP1TI6@0?clo06QXJ01:BTX0?Shn04M7A`1aLG40K6a/03Xj>P1I
FET0D51@02l_;`10@400JVYZ06IVIP1HF5P0/k>c08B4Q00i>CT0HV9R07UiN@15ADD0?Shn069RHP15
ADD0IfMW03De=@13@d<0KVi^03lo?`0n?Sh00P1_Kfl09`26QXH0:b/[03`l?01gMgL0OWin03<c<`1e
MGD0QHF506IVIP1WIfL0Vi^K0=GEe@1TI6@0`L7109FEU@0Z:RX0TY:B08B4Q00c<c<0NWYj07MgM`16
ATH0:RXZ09JFUP0a<C40A4A407moO`1@D500MWIf0<C4a010@4006ATI020P800Y:BT0@T9202DU9@20
P800Ph>307AdM00Looooo`0<09ZJVP2g]kL0QHF503De=@0X:2P0:BTY030`<012@T80?clo05=CD`16
ATH0=cLg0P0];Bd06@0[:b/0;Bd]05EEE@19BDT0Bd];07emO@1oOgl0UiNG04m?C`1PH600E5AD04e=
C@0k>c/0>CTi03Xj>P0g=cL0Ti>C0:NWY`2c/k<0S8b<09jNWP15ADD061PH018B4P0F5QH00P0N7Qh0
401BDU80QhN708f=S@31`L40Xj>S09^KV`2FUYH0V9RH09BDU02MWId0WYjN0;no_`16ATH03Ph>04U9
B@1;Bd/202d];@1=01XJ6P0O7al07QhN02HV9P1>CTh0PH6106QXJ01nOWh0RHV902`/;00T92@0IFEU
07MgM`0^;Rh05ADE0492@P2GUiL0TY:B06UYJ@1OGel0:b/[02<S8`0Q8B4092@T02/[:`0k>c/0Fe]K
0;^k^`1=CDd0FUYJ06e]K@2k^k/0WIfM08B4Q027QhL0UIFE09nOW`2e]KD0b<S80=cLg03?cll0G5aL
0<S8b02XZ:P0LW9b04i>CP1BDU80JVYZ0:NWY`2YZJT0VIVI09FEU@24Q8@0FUYJ07alO027QhL0NWYj
09BDU02BTY80Bd];09BDU01SHf<0PH6106IVIP0h>3P0B4Q8071`L00i>CT0C4a<03`l?00g=cL0BDU9
059BDP2i^KT0a/K60<O7a`1LG5`00`0E5AD05@0G5aL0?Cdm06MWI`1PH600?3`l04Y:BP1kNg/0>CTi
07MgM`1TI6@0@d=306i^KP0f=SH06a/K01TI6@0J6QX0Cdm?02l_;`0C4a<04A4A018B4P0201<C4`0:
01DE5@0e=CD0E5AD0820P013@d<05QHF01LG5`12@T80H61P03dm?@80;2`/06P0?Shn055AD@1]KFd0
BTY:06QXJ00n?Sh0@D5101DE5@0A4A405aLG03Hf=P0X:2P0;Rh^01DE5@0Y:BT0PH610:ZZZP2][Jd0
BDU903Xj>P1>CTh0bl_;08f=S@1^KVh0R8R805ADE01IFET0@41002/[:`1PH6009BDU01dM7@0G5aL0
@D510;Rh^03EeMD0e=CD0<S8b032`/80dM7A0=oOg`3Hf=P0cLg=0=[JfP3WinL0^[Zj0;^k^`3Kfm/0
e=CD0<G5a@2c/k<0UIFE07alO01YJFT0C4a<04A4A01MGEd0Ti>C059BDP1fMWH0<30`04I6AP2/[:`0
O7al08j>SP1YJFT0EEEE06IVIP1hN7P0];Bd0=gMg@2k^k/05aLG01DE5@0W9bL0EUIF09>CT`1WIfL0
[Jf]0<71`@2d];@0_kno07emO@0_;bl0][Jf0;>c/`3>c/h0e]KF0:NWY`2PX:00_kno0<_;b`1`L700
NGUi05UIF@0T92@0:BTY03`l?01JFUX0JVYZ038b<P0W9bL0Lg=c01LG5`805ADE00X08B4Q05ADE01X
J6P0GemO09RHV02BTY80GemO09ZJVP2YZJT0EEEE4Oooool000oooooo01`0PH610;no_`1FEUH0R8R8
06UYJ@2:RXX0K6a/07=cL`26QXH0JVYZ03dm?@1DE5@0L71`03Ti>@1@D500K6a/092@T014A4@0HV9R
03/k>`1EEED0YjNW06ATI01>CTh0MWIf028R8P0X:2P0K6a/0P0a<C401P1PH600?Cdm04Y:BP19BDT0
C4a<07IfMP80;2`/03H0?Cdm024Q8@0g=cL07alO05QHF00T92@0DE5A02TY:@15ADD0Cdm?03/k>`0o
?cl0FEUI05mOG`1?Cdl0G5aL01hN7P2ATI40EeMG01XJ6P16ATH0DE5A02<S8`0d=3@0AdM702<S8`1U
IFD0QhN704E5A@0U9BD0=SHf06QXJ00g=cL0K6a/05mOG`0V9RH0GemO03@d=01QHF40=3@d08B4Q02N
WYh0CDe=01dM7@1:BTX0@d=303Ph>01:BTX0U9BD05YJFP0/;2`0820P096AT@0g=cL203lo?`1A04=3
@`0d=3@0MgMg03`l?01NGUh0<C4a069RHP17AdL0JVYZ04Q8B01_Kfl0EEEE08b<S01=CDd0?clo079b
LP1]KFd0JVYZ079bLP0m?Cd0Fe]K07=cL`1GEeL0KFe]04=3@`1]KFd0HV9R06YZJP1XJ6P0NWYj069R
HP2DU9@0GUiN07alO01IFET0GUiN055AD@1bLW80FEUI05YJFP1`L700IFEU08^;R`2RXZ80TY:B03Xj
>P25QHD0D51@08N7Q`2RXZ80B4Q804I6AP31`L40HV9R04a<C01RHV80EeMG03Xj>P1BDU80FUYJ03@d
=01_Kfl0TY:B03Hf=P1eMGD0Kfm_09:BTP18B4P0F5QH08N7Q`1aLG40Fe]K08R8R02<S8`08R8R04Y:
BP1UIFD0HV9R03Ti>@30`<00WYjN0080LG5a0740bl_;09FEU@1<C4`0RXZ:07YjNP1EEED0Ti>C04=3
@`0e=CD0Ogmo09nOW`1LG5`0C4a<02`/;01OGel0DU9B05MGE`2`/;00I6AT06EUI@1/K6`0ADE509:B
TP0m?Cd0:b/[06IVIP11@D40@41005IFEP1kNg/0MgMg034a<@1fMWH0<c<c03Ti>@1JFUX0UYJF05aL
G01EEED09bLW05ADE01LG5`0<S8b06ATI01iNGT0AdM704];B`2<S8`0Ng]k0451@@1ZJVX0GEeM030`
<016ATH0LG5a04i>CP1oOgl0alO7092@T00l?3`0EeMG06EUI@11@D40OGem08J6QP1;Bd/0MWIf03@d
=019BDT0LW9b03hn?P13@d<0NGUi05mOG`23Ph<0:RXZ04A4A02KVi/0NWYj03<c<`1[Jf/0@410030`
<00/;2`0Jf][0<;2`P1NGUh0YjNW09JFUP0];Bd0MGEe05]KF`10@400PX:206=SH`0[:b/0:BTY09VI
V@12@T80BTY:08:2PP0o?cl0MWIf0;Rh^01BDU808b<S02DU9@0[:b/0EUIF01dM7@1@D500K6a/061P
H00Looooo`0<0;Bd]03EeMD0ZZZZ04U9B@10@400Cdm?05MGE`1BDU80GEeM03/k>`0K6a/06QXJ0P0E
5AD03@0J6QX0Cdm?04m?C`1<C4`0=SHf05QHF01bLW80YJFU0:b/[02LW9`0DU9B02HV9P0K6a/00P0F
5QH0200e=CD0LW9b07EeM@22PX80/;2`07=cL`1OGel0;Rh^0P0W9bL07P0O7al0=SHf07MgM`1lO7`0
OGem0;2`/01ZJVX0ADE5034a<@0`<300=cLg04E5A@1YJFT0Z:RX038b<P0A4A40K6a/03@d=00X:2P0
FEUI03<c<`0V9RH0;2`/02l_;`11@D4092@T03dm?@0O7al0@T9204U9B@80>c/k0280FEUI065QH@17
AdL0Ng]k0:n_[`2d];@0Zj^[08^;R`1OGel0FUYJ04A4A010@400CTi>03De=@0/;2`0Y:BT061PH020
P800c<c<0:RXZ01VIVH0CDe=04A4A00o?cl0=cLg04I6AP24Q8@0d=3@0=OGe`1RHV80UiNG055AD@1I
FET0SXj>0P2<S8`0S019BDT0<30`0492@P1?Cdl0Kfm_08V9R@2EUID0YJFU0;>c/`2o_kl0/k>c0;Jf
]P1bLW80MGEe024Q8@0E5AD04a<C01DE5@0b<S80=SHf01hN7P0o?cl0E5AD05EEE@1IFET0OWin09^K
V`2[Zj/0LG5a01PH600M7Ad0?Cdm06a/K01TI6@0820P05MGE`0H61P051@D02HV9P1jNWX0P820092@
T01[Jf/0QhN704=3@`0L71`06a/K02d];@0o?cl05aLG014A4@0E5AD04A4A01<C4`0B4Q804a<C03@d
=01NGUh0V9RH02`/;00L71`061PH02/[:`1fMWH0XJ6Q06i^KP1fMWH0=CDe02`/;00L71`05ADE05IF
EP0U9BD0KVi^059BDP0A4A405ADE02TY:@0h>3P09RHV01LG5`0c<c<0N7Qh09BDU01/K6`0De=C05mO
G`1aLG40Rh^;0;fm_@2JVYX0Fe]K07moO`18B4P0EEEE07MgM`25QHD0IVIV05iNGP0a<C40GemO09jN
WP3Cdm<0fMWI0<_;b`2[Zj/0/K6a0:>SX`2KVi/0Ti>C0:j^[P33`l<0a<C40<_;b`2k^k/0^;Rh05eM
G@0^;Rh09bLW024Q8@0O7al0;Bd]02@T900l?3`0GEeM0:b/[02QXJ40Jf][07emO@34a<@0YjNW0:2P
X01WIfL0GUiN06i^KP2][Jd0cLg=0=gMg@34a<@06ATI0P0E5AD0:@0G5aL0FUYJ0=;BdP3Jf]X0b/[:
0<_;b`33`l<0`L710;Jf]P26QXH0W9bL0;fm_@1TI6@08R8R01lO7`0X:2P0Hf=S03@d=00R8R80CDe=
05YJFP0l?3`0:BTY03Lg=`13@d<0M7Ad055AD@1ZJVX06ATI01DE5@0I6AT0;Rh^0861P@16ATH0TI6A
0;2`/01GEeL0:2PX05QHF02f][H0EeMG017ooooo000?ooooo`3o0:VYZ@2f][H0DU9B0::RXP1^KVh0
S8b<05IFEP28R8P0SHf=08^;R`13@d<0EUIF06QXJ00j>SX0S8b<07YjNP1ZJVX0=CDe07IfMP1VIVH0
@41009NGU`16ATH0Rh^;0::RXP0g=cL0<C4a071`L00T92@0FEUI08f=S@1DE5@0B4Q80451@@1kNg/0
W9bL04];B`11@D40@d=302HV9P1DE5@0;Bd]04];B`0o?cl0Lg=c03Xj>P1HF5P0E5AD03<c<`1WIfL0
PX:206YZJP29RHT0BDU903Ti>@2j^[X0Lg=c02@T901ADE40F5QH03`l?01>CTh0PH6104Q8B02<S8`0
OWin059BDP0];Bd0DU9B06i^KP0e=CD0IFEU05aLG00g=cL0JFUY0492@P27QhL0@T9208n?S`2[Zj/0
CDe=038b<P1XJ6P0?Shn02h^;P1iNGT0XJ6Q05YJFP0W9bL071`L092@T00e=CD0DU9B06YZJP1CDe<0
?Cdm0820P019BDT0Bd];04Q8B01lO7`0?Shn06=SH`18B4P0LG5a04A4A02DU9@0@41004Y:BP1oOgl0
OGem06IVIP1/K6`0Bd];05YJFP1IFET0D51@092@T015ADD0QhN705iNGP1QHF40I6AT05=CD`1;Bd/0
O7al04I6AP1cLg<0EeMG071`L01@D500MWIf051@D01=CDd0Ti>C05QHF021PH40/K6a08Z:RP0];Bd0
Q8B403`l?02:RXX0SHf=0451@@1WIfL0`L71061PH00o?cl0Kfm_05EEE@1IFET0QHF5079bLP0h>3P0
O7al079bLP0k>c/0NGUi06EUI@2>SXh09RHV05iNGP2[Zj/0Kfm_061PH02CTi<0S8b<03<c<`1WIfL0
Lg=c075aL@0k>c/0a<C407UiN@1EEED0NWYj0<_;b`26QXH0EUIF0;bl_022PX80L71`0:f][@1QHF40
?Cdm09BDU029RHT0CDe=04a<C00a<C40JVYZ0451@@1lO7`0X:2P06ATI01oOgl0R8R8051@D02KVi/0
D51@038b<P1WIfL0>c/k04A4A01gMgL0Vi^K096AT@0j>SX0EeMG03/k>`19BDT0?Shn08j>SP24Q8@0
K6a/03Ti>@1>CTh0?Cdm02DU9@25QHD0HV9R03dm?@1HF5P0V9RH04U9B@0];Bd0M7Ad03hn?P0d=3@0
@410059BDP0o?cl0IVIV06YZJP1@D500?Shn04a<C01MGEd0;2`/0492@P1YJFT0CTi>06QXJ00n?Sh0
=SHf08j>SP1dM7@0@D5107=cL`1WIfL0JFUY02TY:@1HF5P0WinO000S06EUI@0X:2P0HF5Q06MWI`0]
;Bd0<30`0:6QX@3Lg=`0N7Qh09^KV`2ZZZX0<c<c075aL@14A4@0<S8b096AT@2?Shl0L71`02/[:`2B
TY80:BTY06QXJ024Q8@0EUIF06MWI`2FUYH0KFe]028R8P0g=cL0@D5105IFEP0M7Ad0CDe=06YZJP16
ATH07?ooool0N@3MgMd0hN7Q0;no_`27QhL0OWin08b<S01^KVh0MgMg04Q8B00`<30092@T01PH600D
51@05aLG01TI6@0d=3@0;Bd]0451@@0[:b/0=CDe071`L02OWil0];Bd06YZJP0l?3`05aLG01TI6@0E
5AD0;Bd]069RHP0i>CT0@D5107emO@1lO7`0IFEU09NGU`2m_Kd0S8b<075aL@1nOWh0SXj>02l_;`0M
7Ad05aLG03Hf=P1UIFD0LW9b055AD@0a<C409RHV02TY:@0X:2P0<C4a05aLG00c<c<0OWin03Hf=P0]
;Bd06a/K024Q8@0i>CT0BTY:05UIF@0U9BD0;bl_08^;R`1SHf<0>CTi03@d=015ADD0?3`l030`<00c
<c<0MGEe08>3P`2OWil0YJFU07YjNP0j>SX0820P02@T900a<C40C4a<04i>CP19BDT0E5AD0:6QX@33
`l<0O7al06MWI`1;Bd/0A4A404i>CP1ADE40FUYJ08>3P`2UYJD0ZJVY08V9R@2;Rh/0b/[:092@T01?
Cdl0@d=305QHF01@D5009bLW01/K6`0G5aL06a/K02HV9P0W9bL0=3@d06IVIP2_[jl0aLG50=?Cd`3N
g]h0^k^k08B4Q00R8R801@0E5AD07`0f=SH09BDU01TI6@0I6AT0:RXZ06UYJ@1lO7`0SXj>08F5Q@2U
YJD0I6AT0492@P0^;Rh08B4Q01PH600F5QH0@d=302TY:@0C4a<051@D01lO7`17AdL0ZZZZ06=SH`2a
/K40XJ6Q06YZJP1eMGD0K6a/01HF5P0D51@00P0B4Q803`0C4a<05ADE01XJ6P0U9BD0CDe=0:NWY`2`
/;00;2`/01HF5P0I6AT0:2PX06MWI`1BDU80>3Ph02PX:00301DE5@1601@D500b<S80AdM701hN7P1J
FUX0K6a/03Ph>00G5aL0ATI605EEE@1?Cdl0FUYJ08F5Q@1hN7P0EUIF061PH01IFET0E5AD04U9B@15
ADD0EEEE07IfMP1eMGD0TI6A09JFUP2YZJT0H61P04e=C@1XJ6P0OWin0;Ng]`28R8P0TY:B08b<S01X
J6P0D51@04M7A`18B4P0MgMg06m_K`1IFET0K6a/07YjNP2ATI40VYZJ0:n_[`1kNg/0G5aL04A4A00c
<c<0:RXZ03hn?P0X:2P092@T04I6AP1lO7`0bl_;0<K6aP3>c/h0_[jn09FEU@2MWId0XZ:R0:NWY`30
`<00PH61065QH@1GEeL0NGUi05YJFP805ADE02T08b<S07EeM@36a/H0bLW90:>SX`2c/k<0]kNg0;jn
_P38b<P0d];B0;no_`1SHf<0820P01lO7`0S8b<0:2PX0492@P1<C4`09BDU02LW9`0o?cl0FUYJ06MW
I`1NGUh0CTi>04m?C`1YJFT0NGUi065QH@1BDU80D51@07moO`2KVi/0LG5a0861P@1>CTh0<C4a02XZ
:P0m?Cd0ZJVY0:BTY00Aooooo`003oooool0f@2TY:@0_Kfm05]KF`1oOgl0IfMW08Z:RP0e=CD0<S8b
04];B`1gMgL0@410055AD@1NGUh08b<S06a/K01_Kfl0EEEE028R8P1JFUX0Hf=S04=3@`20P800;2`/
04Q8B01jNWX0<c<c03lo?`1kNg/061PH034a<@1QHF40ADE505ADE00a<C40Cdm?07EeM@0i>CT0?clo
04=3@`0S8b<0@D51030`<01BDU80:RXZ04E5A@0W9bL0FEUI04i>CP0W9bL0J6QX06a/K01WIfL0[:b/
04E5A@0U9BD0PX:2051@D00V9RH0GUiN03dm?@0I6AT09bLW0451@@0`<300SXj>08:2PP0Y:BT06a/K
04Y:BP1UIFD0<S8b05mOG`1KFe/0;bl_05eMG@16ATH0Jf][02`/;01aLG40WYjN05QHF00];Bd0NWYj
05QHF00i>CT0F5QH09JFUP1GEeL0:2PX028R8P2CTi<0=3@d03Xj>P1>CTh0<S8b06ATI030`<00Ph>3
07=cL`0n?Sh0Kfm_04A4A01RHV80CTi>055AD@10@400XJ6Q03<c<`14A4@0M7Ad06m_K`1SHf<0L71`
059BDP0g=cL0?clo05MGE`1nOWh0GUiN09nOW`15ADD0HF5Q07IfMP1UIFD0AdM705IFEP11@D40TI6A
05iNGP1mOGd0>SXj08B4Q019BDT0De=C07QhN00m?Cd0M7Ad0<[:bP2GUiL0ATI607UiN@0i>CT0/[:b
0:>SX`11@D40KFe]0;Fe]@17AdL0@41007inOP1MGEd0AdM706a/K01JFUX0<c<c08Z:RP1jNWX0<S8b
05QHF01OGel0ZZZZ04M7A`1EEED0Hf=S05mOG`1]KFd0WinO0:BTY00j>SX0EeMG08Z:RP1CDe<0Bd];
0;Rh^02a/K40EUIF06=SH`2l_;`0GEeM03@d=02DU9@0IVIV05YJFP2_[jl0:RXZ01/K6`22PX80UiNG
05EEE@12@T80EEEE0:6QX@1EEED0Jf][07EeM@14A4@0J6QX08Z:RP0i>CT0E5AD055AD@0^;Rh0Lg=c
0410@00m?Cd0LG5a08^;R`25QHD0?Shn07]kN`21PH40KFe]061PH01jNWX0JVYZ096AT@0d=3@00P1`
L700A`0j>SX0QhN7055AD@0I6AT0O7al0:^[Z`1iNGT0=SHf05aLG00A4A40<c<c051@D01QHF40Cdm?
06EUI@1]KFd0?Shn03lo?`2NWYh0MWIf03<c<`0k>c/0A4A402l_;`1oOgl0J6QX03`l?01iNGT0@410
03`l?02QXJ40/;2`09FEU@0X:2P0=SHf06QXJ00d=3@0FEUI0820P01YJFT06ATI01lO7`2FUYH0/[:b
02TY:@1nOWh0P82002/[:`1aLG40@T9202DU9@1UIFD0M7Ad05IFEP0_;bl0SHf=02/[:`1ADE40HV9R
051@D01MGEd0OGem06ATI00U9BD0:2PX02`/;00n?Sh0820P04E5A@1HF5P0EEEE01cooooo06d0XZ:R
0:^[Z`2ZZZX0Bd];034a<@1?Cdl0FEUI034a<@0[:b/0>c/k03Ti>@17AdL0D51@04Y:BP0i>CT092@T
01dM7@0/;2`08B4Q0410@00];Bd0AdM70:JVYP2@T900?clo01DE5@0C4a<051@D06IVIP0l?3`0?clo
06=SH`1`L7009bLW04m?C`1@D500Z:RX0:6QX@1WIfL08b<S01HF5P0L71`0:RXZ034a<@0i>CT0=cLg
03lo?`1UIFD0HF5Q0492@P1;Bd/0B4Q804m?C`1^KVh0Shn?08j>SP1EEED06ATI01LG5`0L71`0820P
05=CD`17AdL0RHV906a/K020P8006a/K01@D500>3Ph051@D01<C4`0S8b<0NWYj04];B`0_;bl0EUIF
071`L01LG5`0MWIf06IVIP0n?Sh0;Rh^03Ti>@0_;bl0?clo0:RXZ02GUiL0[Zj^0:>SX`2=SHd0AdM7
01TI6@0L71`0;Bd]04A4A02?Shl0[Zj^0820P01EEED0BTY:09RHV02d];@0H61P03<c<`0_;bl092@T
01`L700I6AT06QXJ00805aLG00X06ATI04E5A@16ATH0JFUY06MWI`1lO7`0_;bl04m?C`1<C4`05QHF
1@0E5AD02`0K6a/0@D5102DU9@0P82005QHF01`L7010@400VYZJ09^KV`1dM7@0<c<c00<05ADE00@0
5QHF01LG5`0_;bl0>3Ph100E5AD0201WIfL0De=C07UiN@2JVYX0]kNg0=KFeP0g=cL04a<C0P0@4100
=P0E5AD051@D01LG5`13@d<0;bl_05aLG032`/80a/K6065QH@0K6a/06ATI030`<01KFe/0DU9B030`
<00F5QH05ADE01<C4`0D51@04a<C01`L701MGEd07AdM01LG5`0a<C40QHF508N7Q`1^KVh0U9BD06IV
IP2BTY80CDe=01LG5`0R8R80;Bd]03`l?01WIfL0GEeM05IFEP0i>CT0=3@d08n?S`2MWId0[:b/0;>c
/`0i>CT08R8R03Ph>02:RXX0f=SH08b<S01KFe/07QhN01DE5@805QHF00<0ADE502XZ:P0d=3@00P0G
5aL0<`0V9RH0UiNG0:FUY@2^[Zh0_Kfm0:VYZ@2PX:00T92@06IVIP1^KVh0FEUI03Lg=`1=CDd0^k^k
0<o?c`3Fe]H0aLG509BDU02XZ:P0[Jf]0;Ng]`2ZZZX0MgMg05YJFP0h>3P07alO02/[:`1hN7P0Ph>3
06][J`2CTi<0GUiN03dm?@0a<C40:RXZ06=SH`2e]KD0e=CD0<o?c`3Jf]X0Zj^[02DU9@0S8b<09BDU
02PX:00R8R80=3@d04e=C@0V9RH09BDU034a<@0202h^;P0B05UIF@2CTi<0WYjN0:NWY`23Ph<0B4Q8
04e=C@21PH40d=3@0;Fe]@2f][H0G5aL0451@@10@400>3Ph06a/K02WYjL07AdM4Oooool000oooooo
0?l0[:b/0<[:bP1TI6@0T92@07=cL`2n_[h0GemO08>3P`1oOgl0I6AT07MgM`2i^KT0Z:RX03`l?01n
OWh0Xj>S09ZJVP12@T80EUIF04Y:BP21PH40_;bl05QHF028R8P0JVYZ08F5Q@2MWId0/K6a02l_;`0h
>3P0=SHf0410@02UYJD0De=C07EeM@1RHV80=3@d06e]K@1cLg<0=cLg02XZ:P1>CTh0M7Ad03De=@1E
EED08b<S0861P@2:RXX0DE5A07AdM01KFe/0>3Ph0<c<c01dM7@0<S8b0:>SX`0l?3`0GUiN09bLW01I
FET0=CDe051@D01EEED09BDU09nOW`2KVi/0IfMW01lO7`1TI6@0B4Q800l?3`1GEeL0OGem03`l?01N
GUh09RHV07MgM`1?Cdl0QhN709ZJVP1DE5@0@D510;fm_@1HF5P0?clo06MWI`25QHD0=cLg04];B`1H
F5P0WYjN04U9B@0k>c/0D51@034a<@0l?3`0HV9R06m_K`1WIfL0=cLg06QXJ019BDT0Ph>305IFEP16
ATH0=3@d0;Fe]@1MGEd0Bd];05eMG@0g=cL0TI6A08n?S`1CDe<0@d=303De=@1_Kfl0Zj^[05aLG02E
UID0<C4a07emO@2CTi<0UIFE04I6AP1PH60071`L092@T01XJ6P0RXZ:02d];@2HV9P0TI6A04m?C`1e
MGD05ADE02`/;01VIVH0VYZJ04U9B@1oOgl05aLG08J6QP2KVi/0@d=307emO@32`/80410@02DU9@1f
MWH0JFUY04m?C`1oOgl0>SXj00`<3020P800NWYj03/k>`1@D500820P0:^[Z`1nOWh0KFe]07emO@1;
Bd/06QXJ06QXJ02LW9`0DU9B05]KF`1_Kfl0DE5A02@T902`/;00OGem05iNGP1[Jf/0_Kfm08>3P`16
ATH0L71`05eMG@1gMgL0Ti>C03Hf=P0h>3P0Xj>S092@T017AdL0<c<c01XJ6P1OGel0GUiN07emO@2P
X:00<S8b059BDP23Ph<0B4Q805QHF00];Bd0>3Ph0:6QX@14A4@0B4Q809bLW02^[Zh0P820024Q8@1N
GUh0IVIV07inOP1MGEd0BTY:01lO7`1eMGD0>CTi03lo?`1NGUh0?clo07MgM`1RHV80>SXj05aLG02C
Ti<0KVi^03Ph>01UIFD0<S8b03<c<`0h>3P0DU9B05=CD`1JFUX0GUiN0492@P0Y:BT0DU9B05aLG00X
:2P0>c/k04];B`0Y:BT0>SXj03Hf=P0a<C40M7Ad04E5A@0/;2`0IfMW05YJFP1aLG4092@T03hn?P1T
I6@002<0;Rh^02@T901[Jf/0Hf=S028R8P0g=cL0/[:b09:BTP1DE5@0W9bL08R8R00_;bl0WinO07Ui
N@0i>CT0GUiN05eMG@1CDe<0?Cdm09ZJVP0n?Sh0EEEE05MGE`1?Cdl0MGEe07]kN`1UIFD0<30`02l_
;`0`<300BTY:02PX:01aLG40TY:B05mOG`0Looooo`0<05]KF`17AdL0ZZZZ075aL@0l?3`0:RXZ04];
B`1:BTX0@d=304U9B@1IFET0DU9B0P13@d<06P1RHV80HF5Q05YJFP1FEUH0?clo03/k>`0[:b/0ATI6
0<c<c02PX:00CDe=02TY:@0L71`0:b/[0:^[Z`2?Shl0Xj>S0<G5a@28R8P0>3Ph034a<@0O7al0MgMg
06EUI@0Q8B403Ph>0`0=3@d06@0>3Ph06a/K01/K6`0I6AT07QhN038b<P1IFET0@d=302`/;00o?cl0
ADE50=3@d01FEUH0=SHf02XZ:P0G5aL07AdM04i>CP0_;bl09RHV06QXJ01dM7@0?clo014A4@0@4100
0P0A4A409@0E5AD05aLG07moO`0j>SX0820P03<c<`1gMgL0;bl_02TY:@1MGEd0UYJF06QXJ00H61P0
5ADE03Lg=`2CTi<0/[:b02h^;P0O7al0=cLg08>3P`1eMGD0CTi>05QHF01eMGD0WIfM0;fm_@2OWil0
SHf=06YZJP2h^;P0[Jf]03Hf=P0U9BD092@T01PH600E5AD00`0F5QH02`0I6AT08B4Q06EUI@0n?Sh0
@d=306][J`1:BTX0[:b/059BDP1:BTX06a/K00H05ADE00<0BDU902PX:00L71`00P0L71`01@0m?Cd0
`l?307YjNP12@T80@d=300<05ADE00@05QHF01`L700M7Ad0BDU90P0E5AD0A`0A4A404a<C03Lg=`1/
K6`0D51@07UiN@1OGel0`L71034a<@0C4a<04A4A01<C4`0A4A404Q8B030`<00X:2P07alO0;Bd]03G
emL0gMgM0;>c/`0e=CD09BDU06EUI@1OGel0QHF502<S8`0C4a<0410@01@D500@41004A4A01DE5@1G
EeL0?3`l01dM7@0E5AD09RHV09RHV03=cLd0WinO0;Jf]P2?Shl07QhN01XJ6P0T92@0?3`l04A4A00d
=3@08R8R034a<@1>CTh0G5aL03lo?`1nOWh0LG5a09BDU02j^[X0Hf=S04a<C01SHf<0c/k>0820P016
ATH05ADE01PH600G5aL07AdM04A4A00H61P06QXJ00805ADE00D05QHF051@D01>CTh0JFUY07IfMP02
0;Ng]`0J07EeM@1?Cdl0ADE504];B`1dM7@0VIVI08j>SP38b<P0^k^k0<?3``1mOGd0SXj>065QH@0g
=cL0=CDe04I6AP1YJFT0JVYZ04=3@`0];Bd0CTi>0<o?c`2n_[h0GUiN02LW9`0^;Rh203hn?P0T069R
HP36a/H0e]KF0=KFeP31`L40UYJF03<c<`0d=3@0:b/[02DU9@0P8200:BTY04i>CP0b<S80=SHf05AD
E00l?3`0=cLg0410@01LG5`0[Jf]0;no_`39bLT0Rh^;0:f][@3QhN40c<c<0;2`/01oOgl0Bd];04m?
C`1]KFd0Zj^[0<K6aP2n_[h0FUYJ4Oooool000oooooo0?l0H61P0<S8b01QHF40ZZZZ04i>CP2CTi<0
EUIF0:^[Z`24Q8@0DE5A03`l?01FEUH0N7Qh03lo?`1ADE40MGEe07alO01:BTX0CTi>03/k>`1?Cdl0
R8R804a<C025QHD0C4a<02PX:00o?cl0PX:202DU9@0h>3P0=SHf02LW9`1MGEd0B4Q807emO@1[Jf/0
:2PX034a<@17AdL0:2PX03`l?00_;bl0FUYJ02l_;`14A4@08B4Q03lo?`18B4P0<c<c055AD@17AdL0
92@T08f=S@1DE5@0>3Ph0:FUY@0Z:RX09BDU05]KF`1TI6@0@D5105IFEP1LG5`061PH04E5A@1CDe<0
AdM701/K6`1UIFD0CDe=01DE5@0l?3`0E5AD03Xj>P1NGUh05aLG03lo?`1;Bd/0TY:B0:NWY`1WIfL0
71`L06YZJP1mOGd0=3@d06YZJP1jNWX0820P01DE5@0G5aL0MWIf03dm?@0k>c/0D51@0492@P15ADD0
MWIf05EEE@1SHf<0?Cdm06a/K010@400I6AT05IFEP1BDU80=CDe0861P@1>CTh0FEUI06UYJ@12@T80
F5QH06i^KP1DE5@0>CTi02d];@1OGel0PH6104i>CP2QXJ40@D51059BDP1DE5@0ATI605MGE`1eMGD0
?3`l06e]K@16ATH0UYJF04Y:BP1gMgL0?Cdm06ATI02LW9`0KVi^08Z:RP2WYjL0HF5Q03Xj>P2ATI40
?Cdm08J6QP1HF5P0>SXj09JFUP2^[Zh0Hf=S03Hf=P1]KFd0FEUI07moO`2XZ:P0Jf][02LW9`1VIVH0
J6QX03`l?01QHF40Bd];0;2`/019BDT0NGUi0:j^[P1^KVh0DE5A09JFUP1fMWH0?clo079bLP1RHV80
JFUY03<c<`2n_[h0N7Qh06EUI@2;Rh/0c/k>08R8R01JFUX0YJFU038b<P1>CTh0NWYj04m?C`10@400
Shn?06IVIP16ATH0A4A402l_;`1iNGT0AdM70:NWY`2m_Kd0IVIV055AD@23Ph<0=3@d07alO011@D40
9BDU05eMG@0k>c/0?Cdm08>3P`32`/80UYJF034a<@1FEUH0C4a<04m?C`0o?cl0OGem0820P026QXH0
C4a<055AD@1SHf<0BTY:0:j^[P2MWId0De=C06YZJP2UYJD0=SHf01hN7P1gMgL0Cdm?038b<P0k>c/0
MgMg0410@01lO7`0WIfM071`L014A4@0F5QH06=SH`0g=cL0GemO08>3P`1@D500EeMG02l_;`0^;Rh0
R8R8069RHP16ATH0OWin06e]K@1hN7P07AdM0451@@29RHT002<0H61P02/[:`1VIVH0=CDe03/k>`1c
Lg<0^k^k09BDU01=CDd0[Jf]08:2PP0L71`0Cdm?061PH00g=cL0HF5Q04];B`0K6a/08B4Q08B4Q00j
>SX0E5AD05eMG@0P8200FUYJ09FEU@2:RXX0<c<c0410@00m?Cd0?Shn01`L7019BDT0HV9R061PH00L
ooooo`0X08f=S@19BDT0DU9B09fMW@1_Kfl0DU9B071`L01bLW80MWIf08F5Q@21PH40QXJ608n?S`1f
MWH0KFe]05mOG`1NGUh0NGUi08:2PP2:RXX0UYJF0<K6aP3IfMT0_kno0820P02;Rh/0EeMG06MWI`3>
c/h0Y:BT04Q8B00f=SH0EEEE07IfMP22PX80OWin0:NWY`1FEUH05QHF00h>3P<03@d=01P03Ph>01<C
4`0E5AD05ADE01@D500E5AD06ATI0451@@1NGUh0BTY:04E5A@3;bl/0D51@03`l?00n?Sh06QXJ04E5
A@0e=CD06ATI04i>CP1DE5@0Hf=S01XJ6P0@410200h>3P0C010@400C4a<0A4A405UIF@1LG5`061PH
05EEE@2RXZ80<c<c01dM7@0N7Qh0CTi>05eMG@0E5AD06ATI05iNGP2j^[X0D51@03Hf=P0201DE5@0?
02/[:`1HF5P061PH01TI6@0Q8B40Jf][07UiN@24Q8@0QhN709RHV038b<P0NGUi02PX:00M7Ad06a/K
00<05ADE00d05aLG01TI6@0J6QX08R8R069RHP0`<300:b/[069RHP1CDe<0ZZZZ05iNGP1?Cdl0:RXZ
00805ADE00l04a<C01@D500E5AD05ADE03`l?017AdL07AdM024Q8@0/;2`0Lg=c09ZJVP1^KVh0>3Ph
07IfMP0G5aL00P0E5AD0100F5QH05aLG01LG5`1EEED201DE5@0:018B4P0E5AD09bLW07moO`16ATH0
LW9b03`l?02XZ:P0EUIF014A4@804a<C01404A4A01@D501PH600<C4a04M7A`0j>SX0EEEE0::RXP38
b<P0/;2`06e]K@2>SXh0TI6A0;>c/`1:BTX04a<C010@400201<C4`0W014A4@0C4a<0I6AT079bLP1@
D500BTY:06UYJ@30`<00c<c<0=SHf037alL0Jf][05MGE`1TI6@0HV9R05iNGP0d=3@09BDU01/K6`0L
71`06QXJ02h^;P0J6QX0>c/k0:VYZ@2ATI40W9bL0<c<c02ZZZX0a<C40=[JfP2g]kL0>3Ph01LG5`0E
5AD07AdM0410@00M7Ad04a<C00805ADE04P04Q8B01DE5@0L71`05aLG051@D01<C4`0Vi^K0:RXZ024
Q8@0HV9R06QXJ01dM7@0UiNG0<k>cP3@d=00a<C40;Ng]`2][Jd0:RXZ03<c<`0N7Qh06a/K01XJ6P0L
71`0:b/[0492@P1bLW80MWIf04E5A@2[Zj/0TY:B03hn?P1kNg/0W9bL0;6a/@2@T900RHV90:JVYP3A
dM40f=SH0;^k^`2i^KT0IfMW055AD@0k>c/09RHV024Q8@0U9BD0GemO05MGE`1BDU80UYJF0:>SX`2:
RXX0OGem08Z:RP2e]KD0^;Rh0:ZZZP1GEeL0Bd];0;6a/@2g]kL0`<3006UYJ@28R8P0[Zj^09^KV`1Q
HF40=CDe03Ph>02@T90Aooooo`003oooool0o`2RXZ80UYJF04m?C`2?Shl0JFUY08f=S@1VIVH0VYZJ
0;Bd]025QHD0ATI605eMG@1YJFT0EeMG0861P@2GUiL0QHF505EEE@1`L700JFUY05eMG@2OWil0HF5Q
08n?S`2:RXX0?Cdm04Y:BP1WIfL09BDU05QHF01MGEd0@T9205IFEP0Y:BT0Q8B406i^KP0l?3`0Bd];
03Xj>P0Z:RX0Bd];03<c<`0e=CD0ADE505YJFP0k>c/0FUYJ05EEE@12@T80GUiN07emO@1LG5`0YJFU
05aLG01EEED0ZZZZ05ADE00d=3@0Jf][05=CD`1:BTX0Ogmo08R8R010@400M7Ad061PH017AdL0<C4a
06EUI@1SHf<092@T05iNGP1KFe/0@d=307EeM@0h>3P0EUIF04];B`27QhL0R8R805QHF00_;bl0O7al
06IVIP0j>SX0[jn_09fMW@1HF5P0820P01XJ6P25QHD0=3@d05QHF01cLg<0B4Q805EEE@2RXZ80Fe]K
02l_;`1XJ6P0Lg=c05IFEP0`<300HF5Q06e]K@1:BTX0LG5a02d];@1IFET0Lg=c05iNGP27QhL0>CTi
05UIF@1@D500BDU907YjNP1HF5P0;2`/08N7Q`1=CDd0MGEe08:2PP0l?3`0CDe=06MWI`0j>SX0PH61
05ADE01UIFD0@41007inOP16ATH0@T9206i^KP1eMGD0UIFE0<?3``27QhL0@T9207UiN@0m?Cd0WIfM
07MgM`13@d<0P82009bLW01LG5`0>3Ph06][J`0K6a/0DE5A08B4Q01/K6`0;Bd]069RHP10@400De=C
07IfMP1?Cdl0[:b/028R8P0j>SX0G5aL065QH@1YJFT0Zj^[07QhN00];Bd0J6QX07QhN01WIfL0<c<c
0;Ng]`0o?cl0<30`065QH@2QXJ40Lg=c05aLG01hN7P0Hf=S06EUI@2[Zj/0LG5a0451@@1]KFd0R8R8
04A4A010@400=3@d07YjNP10@400N7Qh092@T01NGUh0JFUY0:BTY00l?3`0@d=304U9B@0`<300PH61
02DU9@0V9RH0GemO075aL@23Ph<0?3`l05UIF@1>CTh0Jf][03@d=01]KFd0E5AD07EeM@1JFUX0EeMG
04=3@`0R8R80JVYZ08B4Q00l?3`0G5aL0:>SX`1UIFD0>CTi061PH01=CDd0=3@d04A4A01cLg<0;Bd]
03Lg=`1DE5@0I6AT03`l?01FEUH0@T9201XJ6P0j>SX0I6AT04a<C01gMgL0?clo02LW9`2IVIT0S8b<
04=3@`1hN7P0Jf][05QHF00S8b<0EUIF0:JVYP005@1TI6@0;2`/06ATI00];Bd0820P03Xj>P2i^KT0
C4a<08J6QP32`/80TI6A02XZ:P1EEED0Bd];02h^;P1fMWH0HF5Q02@T900U9BD0X:2P038b<P0205=C
D`0<051@D01KFe/0QhN705iNGP0h>3P0Ti>C0:j^[P1NGUh09BDU04E5A@1dM7@0:b/[7?ooool0:P36
a/H0Y:BT08N7Q`3:b/X0G5aL03De=@0];Bd0@D5103<c<`0Y:BT0<30`03Xj>P10@400FUYJ08F5Q@2G
UiL0RXZ:0:j^[P2YZJT0UYJF0;Fe]@2_[jl0W9bL0;^k^`3?cll0]KFe06UYJ@0l?3`0@T9209BDU01F
EUH0;Bd]02@T901@D500ZZZZ0;Zj^P3AdM40RHV901TI6@0?3`l04A4A00h>3P<03@d=02l04A4A01DE
5@0E5AD05ADE01<C4`0D51@06ATI04Y:BP2BTY80d];B0;Rh^01XJ6P0DE5A061PH01?Cdl0<c<c03lo
?`2HV9P0MWIf03hn?P0I6AT05ADE010@400A4A405aLG03<c<`1aLG40:RXZ04A4A01:BTX0@410034a
<@15ADD0@D5101lO7`0Q8B40D51@01hN7P0U9BD0/k>c07YjNP17AdL0A4A401/K6`0R8R805ADE01LG
5`0201DE5@0/01LG5`12@T80VIVI02l_;`14A4@08b<S07AdM02;Rh/0Bd];0410@00l?3`0;bl_034a
<@0d=3@0?clo04Y:BP19BDT0G5aL07emO@19BDT0@T9207inOP1FEUH0_;bl07]kN`1EEED0?Cdm01hN
7P0K6a/061PH01DE5@0I6AT05ADE02DU9@1YJFT0>c/k02DU9@0d=3@0PX:203<c<`1CDe<0>c/k07mo
O`0Y:BT301DE5@0@01HF5P0E5AD0GEeM028R8P0C4a<05ADE01HF5P0h>3P0YjNW03Lg=`21PH40?Shn
08Z:RP2FUYH05ADE010@40804A4A01L09RHV0<71`@1TI6@08b<S02LW9`0a<C40Vi^K0<S8b02MWId0
]KFe0:FUY@1fMWH0Hf=S06m_K`1=CDd0410@01<C4`0B4Q804A4A02@T901aLG40O7al07QhN00205=C
D`0<09bLW033`l<0dm?C0<G5a@2_[jl0LG5a09bLW02VYZH0CTi>03De=@0U9BD06ATI0P0G5aL05P0Q
8B406a/K02h^;P2FUYH0c<c<0;Rh^02VYZH0^;Rh0>KViP3Bd]80g]kN07alO01FEUH0?Shn03Ph>01V
IVH06ATI01DE5@0G5aL05ADE01<C4`0A4A4201LG5`0@04Q8B01;Bd/0PX:2051@D01WIfL0Lg=c03hn
?P1CDe<0U9BD09:BTP2IVIT0Vi^K051@D018B4P0Cdm?03Lg=`807AdM02h071`L01/K6`0J6QX07AdM
03<c<`1OGel0XZ:R09BDU02][Jd0^KVi08R8R019BDT08R8R024Q8@0l?3`0Ph>30<;2`P34a<@0Vi^K
0;Bd]02n_[h0[:b/09NGU`2<S8`0ATI605]KF`2HV9P0YZJV09nOW`2DU9@0X:2P0<K6aP3Hf=P0`l?3
0:f][@1eMGD0UiNG07moO`1ZJVX0^k^k0:6QX@3Hf=P0a<C40;Fe]@2IVIT0C4a<0P0L71`00`0V9RH0
OWinooooo`0@ooooo`003oooool01`2b/[80`/;205eMG@2MWId0OWin0:NWY`1<C4`00P1YJFT0O01@
D500LW9b0:^[Z`1HF5P0<c<c06IVIP2HV9P0=cLg03Ph>01eMGD0FEUI06e]K@26QXH07AdM08Z:RP1n
OWh0FUYJ08N7Q`1^KVh06QXJ03Hf=P1UIFD0?Shn05aLG014A4@0QhN707MgM`0h>3P0C4a<05=CD`0e
=CD0GUiN0410@018B4P09BDU04];B`0[:b/0GEeM04I6AP0Q8B40Hf=S06MWI`1<C4`0WIfM03Ti>@1:
BTX0RXZ:0492@P0i>CT0LG5a02h^;P0X:2P0ATI605eMG@1:BTX0PX:2075aL@0Q8B406ATI04e=C@1N
GUh08b<S06YZJP10@400>3Ph06MWI`0g=cL0IFEU02XZ:P1_Kfl0Y:BT069RHP0a<C40SXj>03Ph>00V
9RH0WinO09VIV@1GEeL0AdM706IVIP2TY:@0<C4a02d];@1CDe<0:2PX06IVIP2NWYh0P82004i>CP0l
?3`0BDU905mOG`1SHf<0FUYJ04U9B@17AdL0XJ6Q03dm?@13@d<0K6a/04e=C@2ATI40JVYZ05aLG00a
<C40:b/[08^;R`1jNWX0BTY:09>CT`0j>SX0Lg=c0861P@1/K6`0Lg=c0492@P0`<300WinO05QHF01T
I6@0?Shn09BDU01DE5@206][J`0K034a<@1gMgL0[jn_09bLW017AdL0KVi^04E5A@2OWil0Ng]k04];
B`2GUiL0Y:BT04A4A01QHF40WinO04M7A`1VIVH0KVi^05EEE@0l?3`0VIVI04a<C00l?3`0HF5Q06AT
I02a/K40G5aL0080Kfm_04/0OGem05YJFP2j^[X0QhN704A4A01/K6`0KFe]05YJFP0m?Cd0`/;208n?
S`1FEUH0LW9b0;Vi^@1WIfL0Shn?0;2`/01dM7@0Lg=c0:BTY01FEUH0=3@d08V9R@2FUYH0GUiN03Ph
>01KFe/0];Bd06m_K`20P800Vi^K03Ph>024Q8@0`/;204Y:BP1>CTh0?Shn03@d=02DU9@0Bd];04A4
A01VIVH0QHF5079bLP0d=3@0H61P05EEE@1gMgL0J6QX09^KV`1dM7@0NGUi0492@P1IFET0B4Q803Hf
=P21PH40JVYZ0492@P1aLG40ZJVY06=SH`0j>SX0JVYZ034a<@0h>3P0E5AD05]KF`1;Bd/0DU9B04m?
C`0l?3`0>SXj05iNGP1_Kfl00P0f=SH0<@1VIVH0JFUY08j>SP1XJ6P0A4A407emO@1nOWh0@D5109>C
T`2HV9P0Lg=c024Q8@0n?Sh0Ng]k05IFEP1<C4`0Vi^K07moO`0b<S80C4a<0;^k^`1WIfL0@D5109NG
U`1XJ6P0=CDe08Z:RP1ADE40=SHf0;>c/`2FUYH0ADE502d];@2NWYh0>SXj08Z:RP2DU9@0H61P08:2
PP2:RXX0GUiN024Q8@0];Bd0?Cdm04A4A00b<S80F5QH07UiN@14A4@07?ooool02P25QHD0Rh^;0:j^
[P2l_;`0EUIF03<c<`0X:2P08B4Q03Lg=`0n?Sh202@T900D02LW9`0g=cL0=SHf03@d=01FEUH0UIFE
0<W9b@2>SXh0ATI602`/;00Z:RX0Ng]k0<;2`P0o?cl05ADE014A4@0>3Ph07alO08f=S@1TI6@202h^
;P090820P01JFUX0Zj^[0:FUY@1NGUh05ADE00h>3P0=3@d03Ph>00803@d=00<03Ph>01@D500G5aL0
0P0G5aL0:00L71`0:b/[05EEE@31`L40eMGE0=WIf@2e]KD0`l?30;2`/020P800NWYj06][J`2@T900
Ng]k061PH01LG5`0GEeM065QH@1LG5`0IFEU08J6QP2c/k<0De=C05IFEP1XJ6P0Jf][07=cL`1HF5P0
KFe]07IfMP1=CDd0?3`l03Ti>@1RHV80fMWI096AT@1RHV80EEEE01PH600D51@201<C4`1001dM7@0G
5aL06ATI06i^KP3>c/h0CTi>0:n_[`28R8P0X:2P0<[:bP2IVIT0RHV907emO@1ZJVX0GUiN05]KF`1G
EeL0BDU903`l?00g=cL0I6AT09VIV@2a/K40Zj^[06YZJP2c/k<0UIFE07AdM01XJ6P0:RXZ01hN7P0S
8b<092@T028R8P0Q8B40ADE5096AT@19BDT0B4Q806QXJ01OGel07AdM02XZ:P1DE5@0I6AT065QH@0E
5AD051@D01<C4`0E5AD05QHF059BDP1iNGT0?clo04e=C@1fMWH0];Bd0>;RhP2VYZH0_[jn03Lg=`1j
NWX0clo?020P8080410@00d05QHF05MGE`17AdL0F5QH04e=C@1MGEd0WIfM0<K6aP3>c/h0K6a/05YJ
FP2IVIT0BTY:0080IVIV02/0HF5Q02@T900?3`l03Ph>01DE5@0o?cl0@D5101<C4`0O7al0De=C09RH
V02/[:`0b<S80=?Cd`2l_;`0MGEe06EUI@2<S8`0R8R805iNGP0[:b/07QhN01`L700K6a/06ATI02LW
9`0_;bl0ADE506EUI@1VIVH0VIVI0;fm_@2d];@0g=cL0=7Ad@2OWil0YJFU02d];@1@D500^;Rh06=S
H`0I6AT05aLG00805ADE04P051@D01dM7@0R8R806ATI04E5A@10@400Ng]k04a<C00j>SX0W9bL0=[J
fP3Kfm/0bLW909fMW@1eMGD0UIFE05UIF@1EEED0B4Q804E5A@0X:2P0820P02@T900P82006QXJ01dM
7@0O7al092@T092@T039bLT0X:2P034a<@0E5AD06QXJ02l_;`1PH600LW9b04e=C@1ZJVX0VYZJ08R8
R026QXH0L71`05]KF`34a<@0`L710;Rh^02TY:@0O7al09NGU`2KVi/0UIFE0;:b/P3AdM40emOG0;^k
^`19BDT09BDU05mOG`38b<P0`l?30<30`02_[jl0_[jn09RHV01MGEd0@d=302h^;P0O7al08B4Q02DU
9@1[Jf/Aooooo`003oooool0o`2HV9P0`L7105UIF@2;Rh/0FUYJ0:^[Z`1NGUh0SHf=06][J`0e=CD0
A4A406UYJ@1UIFD0?clo04E5A@2EUID0L71`0410@01ADE40820P06e]K@27QhL0@T9209BDU00f=SH0
B4Q808R8R02@T90092@T03/k>`0[:b/0De=C09>CT`10@400RHV903hn?P0h>3P0M7Ad06UYJ@13@d<0
A4A406YZJP1FEUH0<C4a03lo?`0[:b/0PH6107moO`13@d<0HV9R04Q8B01OGel0bLW906UYJ@1KFe/0
UYJF03dm?@1TI6@0XZ:R06QXJ010@400D51@04e=C@19BDT0/;2`079bLP1@D5007alO06UYJ@17AdL0
<C4a0:JVYP1aLG40?Shn051@D00l?3`0OGem03`l?01mOGd0ZZZZ03/k>`16ATH0^KVi06QXJ00d=3@0
XJ6Q07]kN`0K6a/08R8R03De=@1oOgl0?clo02d];@1ADE40@D5105UIF@1jNWX0HF5Q055AD@10@400
?clo04E5A@1DE5@0EUIF04Y:BP0j>SX0Lg=c0492@P17AdL0Kfm_04M7A`1QHF40GemO05UIF@0c<c<0
9BDU06e]K@1`L700Bd];08b<S01FEUH0F5QH07AdM01YJFT0O7al07inOP1EEED0N7Qh05MGE`1JFUX0
FEUI08Z:RP1BDU80EeMG06UYJ@1UIFD0U9BD0;Vi^@2ATI40@d=307emO@0k>c/0Vi^K07=cL`1?Cdl0
U9BD08B4Q010@400=SHf06UYJ@19BDT0J6QX06YZJP0];Bd09RHV09VIV@1ADE40AdM704i>CP0i>CT0
Zj^[06ATI01eMGD0IfMW04E5A@1:BTX0YJFU0:>SX`0m?Cd0KVi^05EEE@11@D40:b/[0:^[Z`2CTi<0
I6AT07=cL`2_[jl0IVIV06YZJP28R8P0GUiN07]kN`2OWil06a/K02d];@2h^;P0UIFE061PH00Y:BT0
;bl_09>CT`1ZJVX0PX:208Z:RP0k>c/0C4a<07MgM`0i>CT0IVIV02TY:@1MGEd0ZJVY05YJFP0m?Cd0
AdM706QXJ01/K6`0:BTY08R8R02YZJT0Z:RX06YZJP2QXJ40Fe]K08n?S`0a<C40TY:B07UiN@17AdL0
R8R806YZJP16ATH0_[jn0<S8b027QhL0?3`l06QXJ00G5aL0@41008b<S01XJ6P0GEeM05=CD`1YJFT0
B4Q803Ti>@2NWYh0LG5a034a<@0f=SH0DU9B02/[:`27QhL0PX:203hn?P2@T900>CTi04I6AP2HV9P0
VYZJ07UiN@0_;bl0F5QH09>CT`008`0N7Qh0ATI605aLG00X:2P0;Bd]06e]K@2`/;00Lg=c051@D034
a<@0HF5Q020P801]KFd0HF5Q02LW9`1NGUh0DE5A02LW9`0];Bd0WinO03<c<`1DE5@0CDe=034a<@1n
OWh0XZ:R05QHF00^;Rh0=cLg04M7A`0d=3@0=cLg0820P021PH40F5QH01cooooo02`0KFe]06ATI01U
IFD0I6AT05YJFP0^;Rh0:RXZ02HV9P0O7al0?clo05mOG`1>CTh0LW9b07emO@0m?Cd08R8R034a<@0k
>c/0UIFE04A4A00[:b/0:2PX028R8P1nOWh0YZJV01TI6@0E5AD04a<C00l?3`0@41006ATI06MWI`1a
LG40=cLg06UYJ@1EEED0Z:RX07=cL`1KFe/0Bd];01TI6@0=3@d030`<00h>3P<03@d=02T0GemO08:2
PP28R8P0WinO0;bl_02g]kL0_[jn0<_;b`31`L40a<C40=cLg036a/H0R8R808n?S`2NWYh0YJFU09RH
V02FUYH0N7Qh05YJFP0o?cl0:RXZ02l_;`1bLW80NGUi05]KF`1@D500>SXj038b<P0h>3P0EEEE0492
@P1BDU80M7Ad0820P026QXH0]kNg07]kN`1OGel0ADE5069RHP0201<C4`0a01DE5@0C4a<05ADE02l_
;`1LG5`0^k^k0<k>cP3;bl/0inOW0>3Ph02o_kl0d];B09BDU012@T80?clo0451@@12@T80CDe=05IF
EP18B4P0@41004U9B@1PH600B4Q804e=C@1YJFT0ZJVY0;bl_01ZJVX0VYZJ0;Zj^P1fMWH0IFEU0451
@@0d=3@0:RXZ02TY:@0X:2P0Q8B405ADE01NGUh0YjNW03Hf=P0L71`05QHF03Xj>P1?Cdl0TI6A01TI
6@0301DE5@0U01/K6`2?Shl0QXJ606IVIP1@D500MGEe07IfMP2^[Zh0clo?0=[JfP1cLg<0JVYZ0=kN
gP2VYZH0I6AT05YJFP1kNg/0>3Ph01<C4`0E5AD0=cLg09:BTP1VIVH0Cdm?09ZJVP2^[Zh0De=C06YZ
JP1TI6@0Lg=c06EUI@0n?Sh0GemO02d];@0E5AD09bLW04];B`02010@401]01<C4`0G5aL0@d=305]K
F`35aLD0WIfM0:>SX`0N7Qh08b<S03Ph>01<C4`0?clo02LW9`0L71`05QHF01LG5`0M7Ad0=SHf04m?
C`1>CTh0;Bd]02LW9`0f=SH0NWYj09fMW@37alL0G5aL06i^KP2DU9@0LG5a02TY:@1BDU80GemO01XJ
6P0F5QH06a/K01LG5`0E5AD061PH02@T900J6QX0@d=304I6AP1aLG40Bd];02HV9P1hN7P0dm?C0<g=
c@1`L700?Shn05]KF`23Ph<0EeMG03lo?`1^KVh0DE5A05MGE`0j>SX0=cLg034a<@0S8b<0820P02DU
9@0R8R80BDU90;>c/`1TI6@09BDU02LW9`12@T80I6AT04Y:BP0g=cL0;Rh^04I6AP24Q8@0WYjN05aL
G01IFET0E5AD06][J`0o?cl0<C4a02PX:00_;bl0Bd];020P800I6AT092@T038b<P1FEUH0GEeM01`L
700P8200;Bd]0<G5a@2o_kl0/k>c08R8R02ATI40QHF503Hf=P0c<c<0=3@d024Q8@0T92@0=CDe06QX
J00Aooooo`003oooool0o`1nOWh0[jn_05=CD`2RXZ80Kfm_0:f][@1NGUh0VIVI08>3P`1nOWh0Bd];
08b<S01mOGd0ADE506m_K`2IVIT0Ng]k0492@P1RHV80CDe=075aL@2GUiL0HF5Q092@T01dM7@0:RXZ
06ATI02:RXX0:RXZ03Xj>P15ADD0>CTi06e]K@0j>SX0PH61061PH00b<S80@d=304Q8B00d=3@0>3Ph
04E5A@0f=SH0=3@d04A4A00`<300BDU904];B`0k>c/0FUYJ03Ti>@1MGEd0Cdm?03hn?P1aLG40QhN7
02@T900^;Rh0K6a/05EEE@0l?3`0AdM704U9B@13@d<0QHF50492@P0h>3P08B4Q06UYJ@0m?Cd07QhN
06=SH`1BDU80BTY:04m?C`0f=SH0GemO03Lg=`22PX80[jn_02XZ:P0Q8B40GEeM05IFEP0`<300/k>c
06a/K00j>SX0<c<c02TY:@2;Rh/0>3Ph02d];@1CDe<0<S8b06][J`2BTY80Jf][05=CD`0n?Sh0E5AD
05UIF@1PH600EEEE05iNGP1BDU80OGem04I6AP19BDT0P820071`L021PH40Lg=c05eMG@0l?3`0<S8b
07YjNP1iNGT0DU9B09BDU01LG5`0IVIV06QXJ01RHV80Jf][07alO01IFET0PH6105QHF01>CTh0Fe]K
08n?S`1BDU80De=C07IfMP21PH40ZZZZ0;2`/01iNGT0@d=307UiN@13@d<0Z:RX05QHF01?Cdl0QhN7
079bLP1NGUh0Bd];08b<S01=CDd0MWIf07EeM@1XJ6P0:b/[07UiN@0l?3`0AdM704=3@`1BDU80YZJV
04a<C025QHD0GemO06m_K`1>CTh0VYZJ06QXJ00W9bL0LG5a06i^KP1fMWH0>3Ph0;fm_@20P800IfMW
07inOP2WYjL0LW9b08F5Q@1bLW80DE5A09nOW`2ATI40=CDe01lO7`2HV9P0Lg=c05QHF00U9BD0AdM7
07MgM`1BDU80RHV908B4Q01HF5P0Q8B40861P@0n?Sh0CDe=028R8P0U9BD0M7Ad03Ti>@0k>c/0?Cdm
030`<01=CDd06ATI04A4A01=CDd0OGem05ADE02TY:@0JVYZ08n?S`0V9RH0@d=306=SH`14A4@0WinO
06i^KP0/;2`0Fe]K0;2`/01HF5P0<c<c07UiN@0i>CT09RHV04];B`1RHV80;Bd]05]KF`1lO7`0IFEU
02`/;01DE5@0ADE502<S8`1>CTh0GemO02l_;`1UIFD0EEEE02XZ:P25QHD0HF5Q03Ti>@2=SHd0N7Qh
03`l?00K6a/0ADE508B4Q0008`1BDU80>3Ph07EeM@1;Bd/06QXJ0492@P2/[:`0DE5A05IFEP31`L40
RXZ:02@T901>CTh0FUYJ04E5A@27QhL0E5AD01hN7P0V9RH0WIfM03Ph>020P800BDU903Ph>01?Cdl0
QhN705QHF00[:b/0ATI606ATI013@d<0:RXZ04m?C`1@D500<S8b01cooooo02X0Vi^K06=SH`1?Cdl0
C4a<05eMG@0c<c<092@T01lO7`0N7Qh08R8R05EEE@1RHV80BDU907emO@0a<C40;bl_0492@P13@d<0
O7al06EUI@0U9BD0<30`06IVIP2c/k<0XJ6Q01dM7@0I6AT04A4A00h>3P0A4A404a<C01@D501KFe/0
LW9b06a/K01aLG40WinO09:BTP0T92@0<c<c059BDP0K6a/200h>3P803@d=04804a<C04Q8B014A4@0
FUYJ059BDP14A4@0D51@07QhN014A4@0]KFe0<g=c@3Kfm/0clo?0:b/[01IFET0C4a<07emO@2KVi/0
OWin08>3P`1nOWh0K6a/05eMG@18B4P0D51@07emO@1`L700:b/[01LG5`0C4a<03Ph>02DU9@1RHV80
9bLW02d];@1DE5@0^KVi09fMW@1>CTh0IFEU075aL@2ZZZX0?clo02h^;P0_;bl0>3Ph051@D02CTi<0
bLW90=CDe01]KFd0d];B0=kNgP3De=@0cLg=0;Zj^P2NWYh0J6QX06][J`1HF5P0E5AD05MGE`1ADE40
?3`l03De=@0Z:RX201dM7@0O01lO7`16ATH0`L710<o?c`12@T80XZ:R075aL@1;Bd/0DU9B07emO@2P
X:00/;2`08R8R01?Cdl0T92@06][J`2^[Zh0Jf][03Ti>@0G5aL05QHF01LG5`18B4P0Rh^;02TY:@0B
4Q804a<C01DE5@1RHV80TI6A01TI6@0401DE5@1403<c<`3;bl/0c<c<08Z:RP1HF5P0_;bl02l_;`1<
C4`0UIFE04U9B@0C4a<092@T04=3@`1WIfL0CTi>04=3@`0c<c<06a/K03`l?024Q8@0SHf=09JFUP2D
U9@0KFe]059BDP0k>c/0GEeM06IVIP1KFe/0>SXj010@400B4Q804a<C02<S8`0h>3P0NWYj0<S8b01M
GEd0[:b/03Xj>P0I6AT08B4Q04M7A`0n?Sh0?clo020P800G5aL071`L024Q8@1>CTh0BTY:03De=@0^
;Rh0:2PX03<c<`1<C4`0Fe]K079bLP0W9bL0>3Ph05ADE02?Shl0ADE503<c<`1XJ6P08R8R01TI6@0J
6QX201PH600]01TI6@11@D40>SXj06QXJ01KFe/0GUiN03dm?@0V9RH0E5AD05]KF`2OWil0G5aL07Qh
N02LW9`0/K6a05MGE`0`<300EeMG03Xj>P0i>CT0?3`l04i>CP1BDU80D51@0410@00e=CD0?Cdm04];
B`2BTY80QXJ608F5Q@1QHF40ATI602l_;`0[:b/0<C4a02`/;00f=SH0Rh^;09RHV014A4@0KVi^06][
J`18B4P061PH00806ATI00<07AdM03Hf=P0M7Ad00P0J6QX04`0L71`08R8R04];B`0O7al07QhN03/k
>`27QhL0ZJVY07UiN@26QXH0RHV90:RXZ01;Bd/0@41002PX:00T92@09BDU05UIF@18B4P04Oooool0
00oooooo0?l0^[Zj0;Rh^01ADE40ZJVY07]kN`2][Jd0F5QH09VIV@26QXH0Q8B4055AD@25QHD0Ng]k
03Xj>P1bLW80YJFU07=cL`10@400JFUY05=CD`1`L700VYZJ061PH027QhL0P82004M7A`1WIfL0Ph>3
028R8P10@400EUIF05EEE@1TI6@0>3Ph08b<S01YJFT0<30`051@D01=CDd0;bl_0410@01HF5P0>CTi
03@d=015ADD0>c/k05IFEP0j>SX09RHV04i>CP16ATH0RHV904i>CP11@D40O7al08^;R`14A4@0ATI6
07inOP1EEED0?clo05]KF`1TI6@0HV9R0:^[Z`17AdL0?Shn03@d=01SHf<0FUYJ03Lg=`29RHT0GemO
05=CD`1SHf<0ADE507inOP0o?cl0WinO0;bl_010@400<C4a0861P@1ADE40?Cdm0<G5a@1jNWX0?3`l
0410@00d=3@0NWYj03@d=01>CTh0H61P03@d=01;Bd/0Y:BT07=cL`0j>SX0L71`05aLG01NGUh0?Cdm
06a/K01KFe/0G5aL07YjNP14A4@0G5aL08B4Q01_Kfl0R8R804Y:BP1[Jf/0EeMG03/k>`23Ph<0CTi>
05QHF029RHT0GUiN07UiN@1YJFT09bLW061PH01fMWH0EUIF09RHV017AdL0KVi^04m?C`20P8009bLW
05IFEP1mOGd0IVIV0<S8b02f][H0?Shn04Q8B01jNWX0A4A409NGU`0];Bd0CDe=08B4Q020P800FUYJ
05iNGP29RHT0=cLg09:BTP2a/K40JFUY02`/;01`L700:RXZ06EUI@1=CDd0HV9R08B4Q00T92@0QHF5
08f=S@1^KVh0IfMW0:FUY@1BDU80BTY:08j>SP1QHF40HV9R02l_;`2m_Kd0De=C03Hf=P1GEeL0LG5a
06ATI026QXH0RXZ:03/k>`1cLg<0R8R804M7A`0e=CD0]kNg0451@@0l?3`0<c<c04U9B@1ZJVX0C4a<
0:FUY@2b/[80IfMW08B4Q02HV9P0>c/k06UYJ@16ATH0:RXZ08:2PP0U9BD0?Shn06=SH`1TI6@0NGUi
03@d=01NGUh0AdM706EUI@0W9bL0LW9b08F5Q@1bLW80@41005EEE@11@D409bLW06a/K01aLG40?clo
09RHV02f][H0DU9B034a<@1QHF40:RXZ03Hf=P1YJFT0J6QX04A4A016ATH0FEUI04U9B@15ADD0P820
05aLG00Y:BT0:RXZ04m?C`1;Bd/0MgMg06a/K00_;bl0OGem05YJFP15ADD0[Jf]0;6a/@1]KFd07QhN
04=3@`27QhL002<0=3@d051@D01]KFd0>SXj01dM7@1ADE40ZJVY07alO01aLG40b<S808j>SP0^;Rh0
DE5A05aLG00f=SH0FUYJ05QHF00^;Rh0:2PX096AT@12@T80IFEU059BDP0i>CT0CTi>08f=S@1DE5@0
9BDU04M7A`1ZJVX0HV9R03De=@1OGel0IVIV04A4A00Looooo`0404M7A`1WIfL0LG5a05IFEP80DU9B
06<0:BTY024Q8@0O7al071`L03<c<`2n_[h0UIFE0:b/[02:RXX0Rh^;04Y:BP0I6AT0JFUY09ZJVP1a
LG40S8b<0;:b/P39bLT0/[:b08b<S01PH600=3@d020P800H61P05aLG01<C4`0E5AD0O7al09NGU`2b
/[80dm?C0<C4a01WIfL09RHV02LW9`1MGEd0;bl_010@400>3Ph04a<C00l?3`0G5aL05ADE01HF5P0K
6a/0;Bd]07QhN00V9RH0410@03Ti>@38b<P0^KVi08n?S`1MGEd0IFEU092@T02KVi/05aLG018B4P0H
61P0:b/[034a<@1TI6@0Jf][07UiN@2[Zj/0?3`l01/K6`0I6AT06a/K01LG5`0C4a<0Kfm_08f=S@1X
J6P0Hf=S08>3P`2n_[h0ZZZZ0;>c/`2j^[X0]kNg07inOP23Ph<0S8b<09>CT`1BDU80Xj>S065QH@1f
MWH0d];B0<C4a018B4P0=SHf05UIF@2`/;00`/;203Lg=`0S8b<01@0E5AD201@D500F01dM7@0e=CD0
B4Q806UYJ@32`/80alO706ATI01kNg/0KFe]05IFEP0l?3`0=cLg03Ti>@1>CTh0MGEe0<K6aP3AdM40
P82008J6QP0m?Cd0=SHf01`L70805ADE01h0;Rh^05aLG01SHf<05QHF01DE5@0_;bl0[Zj^02PX:00D
51@04a<C01DE5@0D51@04A4A020P801^KVh0g]kN0:VYZ@2UYJD0[Zj^08F5Q@2`/;00NWYj07MgM`1`
L700M7Ad07EeM@1QHF40<S8b01DE5@0C4a<2014A4@1I01`L701`L700Xj>S0;^k^`2`/;00Ng]k04M7
A`1>CTh0[jn_07UiN@0D51@03Ph>01DE5@0G5aL0<30`04I6AP1aLG40SXj>0:BTY018B4P0EEEE01DE
5@0J6QX0?3`l04E5A@1;Bd/0?Cdm020P800T92@0?clo04];B`12@T80C4a<034a<@0k>c/0>SXj02d]
;@0M7Ad0[:b/02DU9@0T92@0>CTi05aLG02LW9`0EeMG09VIV@1OGel0ADE50410@01ADE40J6QX05mO
G`2m_Kd0QhN70;>c/`2TY:@0Q8B405YJFP1HF5P0KFe]06i^KP2NWYh0Y:BT08F5Q@1oOgl0[Zj^0:RX
Z02<S8`0?Cdm01hN7P0`<300;bl_01hN7P0L71`0;Rh^0492@P1YJFT0VIVI0;:b/P2OWil0TY:B05]K
F`0e=CD07QhN01TI6@0T92@08B4Q02DU9@16ATH00P2i^KT0100b<S80LG5a061PH00o?cl201TI6@0I
01/K6`0M7Ad0=cLg01hN7P0I6AT06QXJ01hN7P0h>3P0WinO07QhN01KFe/0PH6109fMW@1dM7@0@410
07AdM02FUYH0fm_K09bLW01NGUh0<c<c02TY:@0e=CD0EEEE04U9B@0Aooooo`003oooool01`2i^KT0
TI6A05=CD`2XZ:P0Ng]k08>3P`1BDU800P2CTi<05@1]KFd0D51@07UiN@1<C4`0Bd];06m_K`2:RXX0
C4a<04A4A01aLG40A4A407inOP1hN7P0?Shn08:2PP1WIfL0BDU907=cL`15ADD09RHV04a<C00204I6
AP0Y07AdM00Z:RX0Ogmo04I6AP0`<300DE5A03Ph>00d=3@0<C4a05IFEP0S8b<0=cLg03Ph>00c<c<0
G5aL04a<C00Q8B40E5AD0410@01_Kfl0IFEU034a<@1dM7@0HV9R02l_;`1>CTh0IfMW03Lg=`0];Bd0
Cdm?04a<C01PH600Q8B403/k>`0W9bL0;Bd]05eMG@13@d<0<S8b08F5Q@1:BTX00P1<C4`0MP0o?cl0
K6a/034a<@24Q8@0WYjN03Ti>@0j>SX0Rh^;04U9B@0c<c<0^;Rh06QXJ00b<S80CTi>04a<C01ZJVX0
:RXZ02<S8`1;Bd/0@T9202d];@1aLG40IVIV03Lg=`1<C4`0@41005iNGP1>CTh0FUYJ04e=C@1LG5`0
PH610451@@0i>CT0KVi^05]KF`1oOgl0FUYJ05QHF00f=SH0>CTi08f=S@1LG5`0GEeM07alO01FEUH0
LG5a05mOG`16ATH0D51@06][J`1EEED0Ti>C059BDP12@T80DE5A07EeM@0k>c/0EeMG06e]K@1BDU80
];Bd0;Ng]`1aLG40ADE506UYJ@1=CDd0TY:B0492@P1FEUH0IfMW07emO@1BDU80IfMW08N7Q`17AdL0
J6QX07=cL`16ATH0@41008:2PP0m?Cd0DU9B0410@01fMWH0N7Qh03lo?`23Ph<0EeMG06EUI@1XJ6P0
ZJVY06MWI`0];Bd0MWIf05EEE@1KFe/0=SHf0;:b/P28R8P0G5aL05mOG`1UIFD0DE5A096AT@2BTY80
IfMW092@T02;Rh/0=CDe02h^;P2YZJT0Ng]k04=3@`0a<C40D51@08B4Q01EEED208:2PP0805=CD`2;
Rh/0UiNG03`l?01ADE408b<S02`/;01oOgl203Lg=`0405IFEP1GEeL0FEUI02TY:@80Hf=S04l0MGEe
05]KF`2EUID0CTi>07]kN`0l?3`0I6AT05UIF@0o?cl0N7Qh04e=C@0n?Sh0RHV90:ZZZP1`L700=SHf
06UYJ@0`<300:b/[04a<C00i>CT0ATI604];B`1PH600Kfm_0492@P1RHV80JFUY03@d=00`<300DE5A
03Ph>01FEUH0MWIf03Hf=P26QXH0Ogmo04Q8B02ATI40VIVI075aL@0P8200DU9B08b<S01DE5@0CDe=
07UiN@1HF5P0=3@d07MgM`2/[:`0O7al06i^KP2l_;`0OGem03Ph>02CTi<0R8R80451@@1HF5P0ATI6
028R8P0e=CD0Rh^;0492@P1jNWX0KFe]04U9B@1WIfL0Ph>306ATI00X:2P0@41006m_K`1LG5`0>3Ph
079bLP2=SHd0H61P01cooooo02d0>c/k03Lg=`0i>CT0?clo05QHF01hN7P0FUYJ07=cL`1mOGd0PX:2
08j>SP2LW9`0_[jn0;fm_@2VYZH0Zj^[0861P@1iNGT0X:2P0;no_`2WYjL0FEUI03Hf=P1KFe/0Lg=c
02l_;`0`<300>CTi0410@011@D40ADE50451@@1<C4`0Lg=c0;6a/@2g]kL0/;2`09JFUP2PX:00W9bL
05aLG019BDT0@D5103Xj>P0P82000P0V9RH04@0U9BD0:BTY030`<01YJFT0GemO020P800:2PX030`<
03dm?@2HV9P0D51@06i^KP1IFET0EUIF08:2PP1kNg/06ATI00805QHF00D04A4A018B4P0@41005QHF
01/K6`0204U9B@0A01DE5@0G5aL05ADE02@T900o?cl0Hf=S0451@@0o?cl0Bd];07alO02TY:@0RHV9
06EUI@1jNWX0EeMG03`l?00i>CT00P0l?3`07@1DE5@0MWIf08>3P`2YZJT0QXJ609BDU013@d<0B4Q8
08j>SP39bLT0^KVi07EeM@1SHf<0FEUI03lo?`10@400@T9204U9B@13@d<0?3`l04=3@`1cLg<0Shn?
0:NWY`3:b/X0a/K60=7Ad@2^[Zh0=3@d00<071`L04H07AdM02<S8`0i>CT0J6QX0<;2`P3:b/X0Shn?
07]kN`1PH6009RHV01TI6@0E5AD05aLG03Hf=P39bLT0RXZ:06YZJP2i^KT0=cLg018B4P0A4A403`l?
01<C4`0J6QX0;2`/05iNGP22PX80Vi^K030`<01NGUh0UIFE09BDU00Z:RX092@T07QhN031`L40W9bL
07AdM00j>SX092@T01HF5P0D51@04a<C014A4@0C4a<0LG5a07QhN02BTY80J6QX05]KF`1mOGd0XZ:R
09JFUP1:BTX051@D01LG5`0U9BD0A4A403Ph>00T92@0C4a<02@T900e=CD0DU9B05MGE`0f=SH05aLG
02LW9`1LG5`0E5AD0P1ZJVX01@1KFe/0>c/k030`<00h>3P0<C4a0080=3@d02D092@T02TY:@1DE5@0
dM7A07=cL`0Y:BT08R8R06][J`1iNGT0bLW909>CT`1cLg<0L71`07=cL`1nOWh0Ogmo07IfMP2>SXh0
emOG0<K6aP2j^[X0c/k>0<30`02=SHd0MWIf06=SH`1_Kfl0PX:207MgM`1`L700V9RH0:FUY@2DU9@0
D51@01lO7`0R8R809bLW0080<S8b0300;2`/02XZ:P0m?Cd0FUYJ09ZJVP35aLD0UIFE0410@00T92@0
820P02LW9`0N7Qh07alO02XZ:P1eMGD0AdM704I6AP1[Jf/0EUIF07UiN@0m?Cd0>SXj01TI6@0M7Ad0
:2PX04E5A@1KFe/0>CTi04=3@`1HF5P0P8200:RXZ01dM7@0QhN70;Vi^@2ZZZX0PX:205MGE`2XZ:P0
clo?0;:b/P2YZJT0UiNG07MgM`1[Jf/0NGUi05YJFP1;Bd/Aooooo`003oooool0T02e]KD0XZ:R055A
D@2DU9@0LW9b08f=S@1ADE40UiNG0820P019BDT0KFe]09^KV`1VIVH0D51@04m?C`2RXZ80HV9R04M7
A`1KFe/0:b/[08B4Q02ATI40KFe]07alO01`L700@T9207IfMP1aLG408R8R059BDP1WIfL0EEEE06e]
K@0o?cl0WYjN05QHF00e=CD0C4a<04=3@`0];Bd0<S8b04I6AP0S8b<0=cLg05MGE`11@D40De=C04a<
C00^;Rh0GUiN059BDP1KFe/0EEEE04E5A@20P800Fe]K03Hf=P1;Bd/0JVYZ04e=C@0Y:BT0D51@04Y:
BP1[Jf/0IfMW03dm?@0i>CT0<30`06][J`1HF5P0>c/k06QXJ01ADE40BTY:055AD@18B4P0Lg=c04Q8
B02^[Zh0PX:202TY:@0d=3@0IVIV05QHF00d=3@0a<C404a<C00_;bl0CTi>05UIF@1UIFD0?Shn04M7
A`1MGEd0FUYJ02XZ:P1/K6`0D51@03Ph>01?Cdl0:b/[05iNGP1:BTX0G5aL04i>CP1SHf<0Ogmo04M7
A`10@400QXJ606e]K@28R8P0IVIV05EEE@0b<S80?Shn08j>SP1fMWH0NWYj06][J`1WIfL0Jf][061P
H019BDT0GemO07emO@1OGel0N7Qh05QHF015ADD0FUYJ07IfMP0o?cl0FUYJ07emO@1eMGD0`l?30:NW
Y`1OGel0@41006YZJP1:BTX0Q8B403Lg=`80IVIV0900IFEU05eMG@1TI6@0QHF505IFEP2=SHd0Z:RX
05iNGP18B4P0Lg=c04A4A01LG5`0=cLg06ATI01`L700@T920:JVYP1_Kfl0?clo06IVIP2MWId0LW9b
02DU9@1jNWX0DE5A06=SH`0i>CT0YJFU09FEU@1TI6@0Ng]k09>CT`1>CTh0SHf=0:2PX01aLG40^k^k
09FEU@1:BTX0HF5Q09:BTP1iNGT0CDe=03Ph>010@400QXJ606][J`2<S8`0Ti>C09JFUP2][Jd0PX:2
05iNGP1QHF40;Bd]02HV9P1_Kfl0B4Q804U9B@1aLG40IfMW05mOG`0T92@0EEEE04a<C01EEED0EUIF
08f=S@1NGUh0HV9R02XZ:P1bLW80EEEE03dm?@1hN7P0K6a/03/k>`1jNWX0_[jn08J6QP1>CTh0LW9b
04A4A00l?3`0AdM70451@@1EEED0Ti>C09:BTP1nOWh0?Cdm05=CD`1GEeL0>3Ph04=3@`1CDe<0CTi>
04A4A01QHF40<c<c08F5Q@1dM7@0CTi>09RHV02=SHd0EEEE03`l?02BTY80`l?3075aL@1HF5P0E5AD
00@4100/;2`0R8R80;^k^`1kNg/0D51@08Z:RP1/K6`08R8R06MWI`1fMWH0>CTi05EEE@18B4P09BDU
02d];@2IVIT0C4a<07inOP1IFET0:BTY05aLG02][Jd0Ph>302l_;`16ATH0Ng]k0410@015ADD0UYJF
07emO@1CDe<Looooo`090861P@0n?Sh0<c<c02`/;019BDT0d];B0=CDe033`l<0VIVI0080K6a/00h0
QXJ60:j^[P2h^;P0SXj>02@T900P8200>CTi09FEU@1gMgL0LW9b038b<P0N7Qh0DU9B03`l?0804a<C
044051@D01HF5P0D51@051@D00h>3P0E5AD0OGem08B4Q01hN7P0SHf=07IfMP1?Cdl0EEEE075aL@1X
J6P0F5QH08J6QP1oOgl0KFe]071`L02@T900YJFU0=CDe02WYjL04a<C00d=3@0;2`/02@T905eMG@1l
O7`0HF5Q08n?S`2:RXX0HV9R09FEU@2OWil0@d=3024Q8@0<30`03@d=00h>3P0=3@d0410@01<C4`0N
7Qh0Kfm_020P800D51@0?Shn04e=C@0[:b/07alO024Q8@0T92@0;bl_06ATI029RHT0UYJF07inOP1a
LG408B4Q01`L700J6QX071`L01XJ6P0201`L700;02<S8`1oOgl0PX:207EeM@2;Rh/0IfMW03Xj>P3=
cLd0dM7A08>3P`0`<3000P0E5AD00`0D51@05ADE01DE5@0201DE5@1901<C4`0E5AD05ADE034a<@1G
EeL0b<S80>3Ph02ZZZX0NWYj02XZ:P0[:b/0@d=307]kN`2QXJ40/k>c0:f][@2ATI40`l?30<71`@2`
/;00bLW90;:b/P1UIFD0820P01lO7`29RHT0gMgM0<S8b035aLD0gMgM06QXJ00];Bd0;bl_03dm?@1A
DE40E5AD03Ti>@0_;bl0UiNG09fMW@1?Cdl0Lg=c08V9R@2IVIT08b<S05MGE`1nOWh0KFe]04I6AP1n
OWh0SHf=09NGU`1MGEd0;Bd]01hN7P0K6a/0Cdm?0<W9b@2e]KD0ATI608J6QP1FEUH0F5QH09bLW02@
T900EUIF01HF5P0U9BD0GUiN04U9B@0I6AT0?Shn02@T900201DE5@0U02d];@0n?Sh0PH6104=3@`0L
71`0<30`0:j^[P2c/k<0RXZ:04];B`0`<300>c/k04U9B@17AdL0=CDe02@T9011@D40PH610;Ng]`2H
V9P0ZZZZ09NGU`1IFET0GEeM08J6QP3>c/h0emOG0:BTY01jNWX0G5aL061PH028R8P0OGem04a<C012
@T80ZZZZ0<K6aP020<?3``0[0:b/[025QHD0:b/[01hN7P0S8b<0Hf=S08R8R02ATI40^;Rh09:BTP1k
Ng/0;Rh^01lO7`0M7Ad09BDU02@T900c<c<0H61P02l_;`0W9bL0CDe=07IfMP3>c/h0Xj>S04e=C@10
@400Fe]K03Ph>00[:b/0NWYj059BDP0M7Ad0=CDe059BDP1_Kfl0KVi^08n?S`1mOGd0KFe]04i>CP1;
Bd/0ADE507EeM@0202l_;`0C03Lg=`1XJ6P0]kNg09JFUP2ZZZX0GUiN06a/K02^[Zh0clo?0:6QX@1F
EUH0PX:203hn?P0a<C40@d=309BDU03;bl/0/;2`08V9R@0Aooooo`003oooool0]P2e]KD0Vi^K065Q
H@2k^k/0PX:208F5Q@1YJFT0a<C40<30`01KFe/0CDe=06MWI`1RHV80TI6A071`L02QXJ40KFe]05mO
G`21PH40?3`l08n?S`2CTi<0KFe]07inOP1oOgl0BDU90861P@1<C4`0CDe=08b<S01]KFd0JVYZ05iN
GP0T92@0Shn?06=SH`0l?3`0C4a<02DU9@1FEUH0?clo05mOG`0S8b<0GemO05eMG@1=CDd0DU9B03/k
>`0b<S80MgMg04I6AP1SHf<0GemO03/k>`20P800DU9B038b<P1<C4`0IVIV05EEE@0h>3P0O7al05iN
GP1gMgL0MGEe05aLG00j>SX0=SHf08Z:RP1OGel0>CTi069RHP1CDe<0Cdm?05aLG01ADE40Lg=c05=C
D`2e]KD0Rh^;0410@00k>c/0Lg=c05aLG00e=CD0bl_;05]KF`0k>c/0EUIF06=SH`1BDU80@T9206IV
IP26QXH0Hf=S02PX:01oOgl0LG5a059BDP2HV9P0=3@d065QH@13@d<0NWYj0410@01KFe/0GemO04A4
A01KFe/0Jf][065QH@1nOWh0FEUI055AD@0V9RH0?clo08j>SP1IFET0Ph>305QHF01OGel0J6QX05eM
G@0k>c/0K6a/07inOP1TI6@0SHf=07alO02>SXh0Bd];05iNGP0c<c<0WYjN09ZJVP1`L700^k^k09^K
V`18B4P0Ng]k07YjNP1<C4`0KVi^03Ph>02=SHd0TY:B08>3P`1EEED0HF5Q07AdM01VIVH0c<c<0=7A
d@1GEeL0BDU905mOG`1NGUh0UYJF03dm?@1fMWH0K6a/04a<C039bLT0[Jf]06][J`1ZJVX0Vi^K05iN
GP1IFET0Zj^[06EUI@1_Kfl0@D510<;2`P1EEED0F5QH08^;R`2MWId0A4A408j>SP2PX:00?clo0P2d
];@0JP1jNWX0QHF50820P01BDU80Ogmo03/k>`19BDT0Rh^;04a<C033`l<0_;bl07emO@2QXJ40Rh^;
07QhN01jNWX0C4a<02PX:01cLg<0HF5Q05aLG02LW9`0UYJF07QhN00`<300GUiN04E5A@1BDU80GEeM
08V9R@1jNWX0N7Qh03Lg=`1aLG40AdM704Y:BP2a/K40H61P03Lg=`1mOGd0ZJVY04Y:BP0Z:RX0WIfM
06m_K`0h>3P0>CTi04Y:BP0Q8B40L71`08B4Q025QHD0?clo05iNGP0e=CD07alO06a/K02OWil0H61P
03Ti>@1iNGT0:RXZ0:^[Z`2DU9@0D51@092@T02;Rh/0=CDe01/K6`17AdL0R8R8055AD@1GEeL0I6AT
02@T900Q8B40DE5A09bLW01UIFD0=SHf05iNGP1RHV80<c<c075aL@1mOGd0<S8b04i>CP1DE5@0@T92
03@d=027QhL0B4Q806UYJ@1<C4`0B4Q8061PH02KVi/0J6QX028R8P13@d<0NGUi05eMG@0^;Rh0Q8B4
07EeM@1HF5PLooooo`0L0:JVYP1^KVh0=cLg0410@02DU9@0ZJVY07MgM`1NGUh0TY:B05eMG@0X:2P0
820P02XZ:P17AdL0UIFE08B4Q01dM7@0HF5Q09VIV@24Q8@0UIFE08J6QP1[Jf/0W9bL03Xj>P0H61P0
:BTY01LG5`805ADE01h051@D01<C4`0C4a<0EUIF07=cL`1VIVH0`/;207MgM`0[:b/08R8R02PX:01F
EUH0L71`0;Zj^P20P800Shn?09ZJVP2=SHd0I6AT034a<@1_Kfl0J6QX01lO7`0>3Ph04A4A08J6QP1g
MgL0KVi^075aL@2GUiL20:>SX`0]0;>c/`1CDe<0;Rh^00l?3`0=3@d030`<00d=3@0>3Ph04Q8B01TI
6@1/K6`0GUiN05aLG00o?cl09RHV02h^;P0`<300=cLg02`/;00o?cl0DU9B08f=S@2ZZZX0YZJV05YJ
FP1TI6@0?Cdm02PX:00U9BD07AdM01`L700I6AT07AdM03/k>`24Q8@0<c<c08J6QP0h>3P0@T9209FE
U@2GUiL07AdM01DE5@0>3Ph04a<C00L05ADE04L06ATI04E5A@1TI6@0[Jf]0;Vi^@2PX:00RXZ:0;>c
/`3:b/X0`l?30:>SX`1aLG40Jf][05IFEP0k>c/0IfMW0:^[Z`2=SHd0JVYZ0:6QX@39bLT0];Bd0;>c
/`3Ogml0[Jf]0:b/[02XZ:P0QhN70;Vi^@2n_[h0SHf=05QHF00m?Cd0:2PX01lO7`0Z:RX0clo?0<O7
a`2:RXX0Z:RX0<o?c`3:b/X0Q8B409>CT`1:BTX07QhN01<C4`0G5aL092@T04e=C@1nOWh0`l?30<[:
bP2_[jl0QXJ608N7Q`3MgMd0R8R806m_K`2][Jd0ZZZZ0;Vi^@2:RXX0GUiN02h^;P1DE5@0B4Q801LG
5`0E5AD0?3`l01HF5P0201<C4`1C01DE5@0h>3P0=CDe09:BTP0a<C40;bl_0;Rh^02<S8`0IFEU05mO
G`13@d<0D51@061PH01<C4`0<C4a055AD@1jNWX0Vi^K061PH00I6AT0<30`0:VYZ@2ZZZX0WIfM0<S8
b03Hf=P0/k>c04M7A`0_;bl0?clo0861P@1<C4`0BDU904a<C01;Bd/0VIVI07emO@2ATI40`L710<?3
``2OWil06QXJ01DE5@0I6AT0Bd];0:JVYP2=SHd0V9RH08b<S02XZ:P0CTi>04Q8B00m?Cd0<30`02PX
:00V9RH0CTi>024Q8@0T92@0DE5A07]kN`1iNGT0?clo06MWI`1aLG40LW9b0;Vi^@2c/k<0c<c<02l_
;`0I6AT092@T03Lg=`1mOGd0T92@09:BTP2JVYX0[jn_04m?C`0o?cl0?Shn07AdM016ATH00P0a<C40
4P1@D500IFEU07inOP2`/;00WIfM0;Ng]`3Bd]80aLG509bLW02QXJ40`L7109ZJVP1fMWH0H61P07Ad
M01YJFT0S8b<09nOWa7ooooo000?ooooo`0V0;Jf]P1YJFT0GUiN09ZJVP1mOGd0FUYJ03Hf=P1GEeL0
R8R804i>CP1BDU80EUIF020P801FEUH0HF5Q06EUI@0`<300LW9b08Z:RP10@400U9BD05=CD`0_;bl0
QXJ607EeM@0n?Sh0QHF502d];@0H61P0CTi>05MGE`1QHF40G5aL02HV9P1oOgl0C4a<03hn?P15ADD2
02LW9`3j02DU9@1XJ6P07AdM02h^;P13@d<0@D51051@D00c<c<0:RXZ06i^KP11@D40E5AD05iNGP0b
<S80TI6A06UYJ@0c<c<0CDe=03`l?00];Bd0EeMG08Z:RP1JFUX0JVYZ0861P@0a<C40;Bd]05aLG023
Ph<0IFEU034a<@1OGel0DE5A07AdM01WIfL0DE5A08j>SP0Q8B40S8b<0;Rh^01RHV80?Shn07=cL`0f
=SH0B4Q80<C4a02OWil0>CTi04];B`1VIVH0D51@020P800Y:BT0GemO05]KF`0[:b/0Q8B405UIF@0R
8R80EEEE04E5A@1OGel0?clo08V9R@17AdL0C4a<04i>CP0h>3P0D51@06IVIP1DE5@0K6a/02TY:@1E
EED0GEeM03Lg=`22PX807AdM06=SH`1UIFD0Fe]K06i^KP1KFe/09bLW07=cL`21PH40GUiN07emO@0h
>3P0De=C04U9B@1VIVH05ADE04U9B@1/K6`0EEEE0:j^[P2DU9@0:BTY02`/;01HF5P0DE5A06UYJ@0d
=3@0Bd];05mOG`1hN7P0De=C05eMG@1^KVh0:RXZ05ADE01aLG40?Shn05EEE@13@d<0DU9B08V9R@1I
FET0MWIf04I6AP0I6AT0IVIV079bLP1RHV80LG5a0;>c/`0i>CT0:2PX05aLG01VIVH0EUIF059BDP34
a<@0J6QX02h^;P1@D500N7Qh030`<02FUYH0Vi^K04A4A02:RXX0MWIf034a<@23Ph<0W9bL05EEE@0m
?Cd0>SXj03Ti>@1VIVH092@T06YZJP1nOWh0C4a<0820P02>SXh0@41007YjNP1;Bd/08R8R075aL@0W
9bL0B4Q808>3P`28R8P0SHf=04U9B@1VIVH0ADE505iNGP0/;2`0MGEe0:RXZ02FUYH0GUiN07MgM`0/
;2`0<c<c08:2PP1VIVH0A4A407EeM@2EUID0@T9201LG5`1/K6`0=cLg02XZ:P0g=cL0;2`/0492@P1H
F5P0De=C06=SH`0g=cL0EUIF02h^;P092@T0;bl_061PH015ADD0;Rh^06IVIP0F5QH0M7Ad07IfMP1@
D500QhN708f=S@1WIfL06QXJ04I6AP1lO7`0;Rh^04i>CP2:RXX0IVIV03De=@1bLW80U9BD030`<01<
C4`0QhN706MWI`0l?3`0NGUi069RHP0b<S80LW9b03`l?00R8R80<c<c06e]K@0d=3@0MGEe06IVIP1:
BTX0Fe]K075aL@1MGEd08b<S04E5A@1lO7`0C4a<03@d=02@T900P82005IFEQcooooo00`0[Jf]09nO
W`2^[Zh0`l?308j>SP1ADE40CDe=04M7A`19BDT0Kfm_05=CD`0K6a/201TI6@0409ZJVP2b/[80R8R8
065QH@80RXZ:02h0GUiN09:BTP1YJFT0_kno07inOP1=CDd0C4a<04E5A@0n?Sh0<c<c02TY:@0W9bL0
7alO06e]K@26QXH0D51@0;Jf]P35aLD0QXJ607IfMP2CTi<0a<C40:FUY@2h^;P0UIFE05IFEP0/;2`0
4Q8B00h>3P0A4A4051@D04Q8B01mOGd0BDU906a/K02j^[X0PH6108J6QP1^KVh0IFEU069RHP1cLg<0
a/K6034a<@0F5QH02@T90P0<30`200d=3@803Ph>00L0ADE50<?3``1GEeL0A4A403Xj>P10@400?Cdm
0080A4A401X0Hf=S04m?C`22PX80clo?034a<@0K6a/071`L02d];@0o?cl0CDe=04Q8B00a<C40=SHf
02DU9@0o?cl0WinO08:2PP1LG5`0XZ:R0:BTY01_Kfl0WIfM01dM7@0D51@04A4A01<C4`803Ph>03D0
4a<C01DE5@0G5aL09RHV04M7A`1ADE40@d=307emO@2GUiL0Lg=c0<O7a`2GUiL0e=CD0:f][@1nOWh0
LW9b04a<C00_;bl0>CTi03dm?@0c<c<0YjNW06e]K@0k>c/0CTi>05eMG@2[Zj/0hN7Q0>WYj@2XZ:P0
_[jn09nOW`1ADE40FUYJ05mOG`2DU9@0aLG50=CDe02[Zj/0UIFE0:6QX@3Lg=`0fm_K0>3Ph03Ogml0
hn?S0>KViP3Cdm<0Fe]K02l_;`0@41003Ph>01DE5@0200h>3P1E01TI6@2>SXh0bLW907emO@0J6QX0
61PH07alO037alL0RXZ:08b<S03<c<`0d=3@0=SHf02_[jl0PH6105UIF@0F5QH05ADE01TI6@11@D40
5ADE010@400A4A404Q8B038b<P0V9RH0GemO09jNWP2CTi<0Xj>S0:6QX@2=SHd0WYjN0::RXP2PX:00
JVYZ07EeM@1YJFT0TI6A08n?S`15ADD061PH01LG5`0L71`0?Cdm08j>SP1CDe<0Fe]K0=cLg03Ti>@0
e]KF0;fm_@2n_[h0>SXj03Lg=`1ADE40L71`09:BTP37alL0N7Qh0:>SX`3Cdm<0clo?0:JVYP0I6AT0
5ADE02l_;`1?Cdl0@d=308:2PP1BDU80CDe=0:BTY01UIFD0EUIF04M7A`15ADD0A4A404e=C@1ZJVX0
BDU904a<C01mOGd0UYJF04e=C@0201LG5`0W02`/;02KVi/0Xj>S04=3@`0e=CD0AdM701`L700Q8B40
<C4a07=cL`2i^KT0XZ:R0;Bd]02ZZZX0Jf][05IFEP1QHF40WinO0:f][@26QXH0P82007EeM@1BDU80
W9bL0:2PX02n_[h0emOG0:FUY@2:RXX0bl_;06QXJ00S8b<0;Rh^04=3@`2@T900[Zj^06i^KP11@D40
>3Ph017ooooo000?ooooo`0M0<;2`P2KVi/0D51@09nOW`21PH40WYjN05UIF@28R8P0[:b/05EEE@1A
DE40M7Ad05QHF01TI6@0F5QH08f=S@1BDU80>c/k069RHP0^;Rh0WYjN06][J`0_;bl0HF5Q07YjNP1=
CDd0WYjN079bLP0a<C400P1GEeL0IP1VIVH0MWIf030`<02GUiL0>CTi0492@P1LG5`0?3`l02`/;00F
5QH0EEEE02TY:@0h>3P09BDU03lo?`1UIFD0Bd];02d];@1ZJVX0@T92061PH01kNg/0;bl_061PH01>
CTh0:2PX05IFEP1>CTh0@41002/[:`1cLg<0@T9207IfMP1LG5`09BDU01dM7@0O7al0DE5A04Y:BP0Z
:RX0FEUI030`<00g=cL0D51@03Hf=P1IFET0;Bd]06YZJP20P800=3@d03`l?01ZJVX08R8R03De=@2d
];@0FEUI02l_;`1GEeL0PH6106ATI00d=3@0?clo06=SH`0g=cL0;bl_09:BTP1SHf<0<c<c05=CD`1<
C4`0L71`03lo?`1SHf<0D51@061PH01^KVh0<C4a03/k>`1RHV80DU9B08N7Q`1=CDd0CTi>02h^;P10
@400Ti>C06EUI@1gMgL0FUYJ05QHF02CTi<0Kfm_03/k>`1QHF40ADE505eMG@2EUID0EeMG05QHF019
BDT0OGem04M7A`80D51@09/0=SHf08N7Q`2EUID0DE5A0492@P1MGEd0EUIF079bLP10@400FUYJ06e]
K@18B4P0>c/k05eMG@22PX80Kfm_07QhN01bLW80<S8b07AdM01TI6@0A4A407YjNP1BDU80Q8B407in
OP0b<S80V9RH06IVIP10@400NWYj0::RXP1VIVH0<C4a06a/K00b<S80:b/[04m?C`39bLT0Ti>C04a<
C01]KFd0Q8B404A4A02TY:@0UIFE06e]K@2n_[h0TI6A03Ti>@1NGUh0D51@05aLG01DE5@0:BTY02h^
;P19BDT0=SHf08J6QP1cLg<0AdM706e]K@2KVi/0ATI607YjNP0O7al071`L06UYJ@0U9BD0>SXj05eM
G@1?Cdl0I6AT03Ti>@1NGUh0AdM7059BDP12@T80AdM7079bLP1dM7@0Bd];065QH@1=CDd0>CTi07Ee
M@1BDU80>SXj07IfMP2LW9`0Kfm_03Lg=`1nOWh0:2PX038b<P1FEUH0Bd];055AD@1^KVh0JVYZ05iN
GP0n?Sh0De=C04=3@`0T92@0>c/k03dm?@0/;2`0:b/[04Q8B00a<C40VIVI07AdM01:BTX0S8b<08n?
S`1SHf<08B4Q04Y:BP1hN7P0;2`/04i>CP2>SXh0IVIV03Xj>P20P800^KVi05YJFP0L71`0:b/[06=S
H`0n?Sh0VYZJ04Q8B00/;2`0Kfm_05QHF00j>SX0>CTi07EeM@16ATH0Y:BT07MgM`16ATH0FEUI09BD
U013@d<0A4A408f=S@2WYjL0?Shn03Xj>P2DU9@0JFUY02@T900Looooo`0b08B4Q03@d=00gmoO0<o?
c`2ZZZX0Q8B407AdM01LG5`0GemO05]KF`1LG5`0@T92020P800Q8B40IVIV03lo?`0Z:RX0=CDe05EE
E@2IVIT0J6QX09NGU`35aLD0]kNg04m?C`0j>SX0=SHf03Ph>00m?Cd0BDU904m?C`1MGEd0L71`0;Bd
]01NGUh0Jf][05UIF@0Z:RX05ADE01HF5P17AdL0Kfm_075aL@1WIfL0KFe]03Lg=`0`<300<C4a02<S
8`0C4a<2010@400A02LW9`2OWil0TY:B0=GEe@2:RXX0AdM704E5A@13@d<0>c/k06UYJ@32`/80RXZ:
02LW9`0<30`02@T900L71`0<30`00`0=3@d03P18B4P0YJFU0:n_[`2IVIT0Ph>307=cL`1YJFT0IfMW
069RHP1hN7P0T92@0<g=c@2f][H0;Rh^0P0J6QX0500F5QH05aLG01LG5`0N7Qh0<c<c04Q8B01KFe/0
TI6A0:FUY@2[Zj/0>CTi0:ZZZP2<S8`0C4a<09RHV00O7al04Q8B010@400C4a<03Ph>0P0A4A403P0J
6QX0BTY:04A4A00Y:BT07alO03Lg=`2XZ:P0LG5a08:2PP2d];@0_;bl05UIF@1FEUH0MWIf0P2=SHd0
901HF5P0BDU903Ti>@0f=SH0S8b<09:BTP0];Bd0:2PX03hn?P1UIFD0gmoO0>KViP3Hf=P0dm?C0;Bd
]02HV9P0UIFE09:BTP20P800M7Ad092@T03@d=00i^KV0<k>cP3Ogml0g]kN0=cLg02VYZH0]KFe0=gM
g@3:b/X0;Rh^014A4@0?3`l0410@00h>3P804A4A010061PH09:BTP1bLW807AdM01<C4`0D51@05aLG
07=cL`2h^;P0H61P0<W9b@3Bd]80hN7Q0=OGe`2/[:`05aLG0P0E5AD03P1OGel0G5aL01DE5@0B4Q80
4A4A01@D500L71`0@41002PX:02HV9P0[jn_04E5A@2HV9P0a/K60P39bLT01`2n_[h0Zj^[0<71`@2^
[Zh0N7Qh034a<@0I6AT00P0G5aL0BP0J6QX0:RXZ03Lg=`0];Bd0?clo09nOW`1IFET0TI6A0;^k^`2R
XZ8061PH01DE5@0K6a/0@d=30820P02;Rh/0UIFE0<_;b`3UiND0inOW0<71`@1CDe<0>SXj04];B`0n
?Sh0@41001XJ6P1:BTX0E5AD06e]K@2ZZZX0JVYZ06MWI`1[Jf/0I6AT075aL@2BTY80Ph>308b<S02k
^k/0XJ6Q05mOG`0O7al07AdM03De=@29RHT0JFUY014A4@0D51@0=3@d04i>CP0X:2P0=cLg05eMG@2T
Y:@0eMGE0<S8b02YZJT0UYJF0:6QX@2g]kL0e=CD0=_Kf`38b<P0`L710<G5a@3:b/X0`l?309JFUP3C
dm<0/;2`07IfMP2VYZH0Ti>C0P0R8R801`0/;2`0<c<c06ATI02BTY80Vi^K05EEE@0k>c/04Oooool0
00oooooo0140[jn_08^;R`1BDU80Ogmo08B4Q02CTi<0GUiN092@T02NWYh0J6QX079bLP2/[:`0JFUY
07emO@1@D500X:2P05QHF002051@D01L03<c<`2PX:00S8b<03Lg=`1_Kfl0A4A4059BDP2>SXh0GemO
03Hf=P1:BTX0<S8b05EEE@1fMWH0<c<c09^KV`17AdL0>SXj04a<C00e=CD0<C4a02HV9P1JFUX0:RXZ
0492@P11@D40>SXj04A4A00o?cl08R8R05YJFP0a<C40BTY:05=CD`0j>SX0KVi^02h^;P0V9RH0GEeM
055AD@0l?3`0=cLg08Z:RP0d=3@0OWin06QXJ014A4@0;Rh^03Xj>P1bLW80ATI603<c<`2;Rh/0EUIF
04e=C@1HF5P0ATI606IVIP1@D500W9bL07=cL`0U9BD0@T9207inOP1GEeL0=CDe0<G5a@0d=3@0:RXZ
03lo?`1jNWX0EUIF02`/;019BDT0K6a/05eMG@0R8R80Vi^K059BDP0[:b/0HF5Q03Hf=P1VIVH0Bd];
06UYJ@0U9BD0F5QH061PH00m?Cd0@D5104M7A`0m?Cd2069RHP2a05=CD`0j>SX0<C4a07alO01WIfL0
MWIf05aLG01OGel0GEeM06EUI@19BDT0N7Qh07alO01ADE40Hf=S065QH@1RHV80EeMG075aL@16ATH0
FEUI07inOP1cLg<0WYjN092@T00h>3P0FEUI06QXJ01>CTh0C4a<04A4A02OWil0TI6A06=SH`19BDT0
A4A406][J`1oOgl0YZJV09BDU00i>CT0F5QH04I6AP1?Cdl0PX:202d];@1OGel0Fe]K0492@P37alL0
UiNG05QHF01gMgL0W9bL06=SH`15ADD0Rh^;04E5A@1=CDd0L71`0=CDe026QXH0IFEU0:JVYP2d];@0
A4A40:>SX`1oOgl0FUYJ0<c<c02YZJT0J6QX079bLP1DE5@0C4a<05UIF@0M7Ad0>SXj065QH@0o?cl0
RHV907UiN@0S8b<0FUYJ08F5Q@1CDe<0V9RH01`L700S8b<0MWIf04E5A@10@400MgMg055AD@1NGUh0
92@T06QXJ01UIFD0HF5Q059BDP1ADE40TI6A08f=S@0/;2`0KFe]05MGE`0m?Cd0Lg=c0410@00Q8B40
AdM708^;R`1dM7@0ADE507alO010@4009BDU04i>CP1HF5P0E5AD0:j^[P2=SHd0DE5A03Ph>01iNGT0
DU9B034a<@12@T80=cLg02d];@0d=3@0DE5A03`l?029RHT0De=C07YjNP3<c<`0];Bd06YZJP0Q8B40
Bd];07EeM@0A4A40BDU9096AT@1`L700DU9B0:VYZ@2m_Kd0K6a/028R8P12@T80@410051@D038b<P0
Q8B402/[:`17AdL0@T9203Ti>@1UIFD0Y:BT0451@@1kNg/0B4Q807AdM02RXZ80SXj>05UIF@0O7al0
>3Ph069RHP18B4P0@D5109fMW@1^KVh0=3@d01cooooo01`0B4Q80<S8b02l_;`0CDe=02h^;P0[:b/0
<S8b04Y:BP1bLW80YJFU08j>SP2QXJ40>SXj038b<P1XJ6P0:RXZ02LW9`0/;2`0=3@d04e=C@2@T900
c<c<0=[JfP3?cll0ATI602h^;P0W9bL08B4Q0P0I6AT0900J6QX0:2PX02d];@1^KVh0N7Qh0820P00Q
8B404A4A010@400A4A40410@01`L700X:2P0ADE506QXJ01=CDd09bLW02TY:@0g=cL0A4A402`/;00E
5AD09bLW06a/K02XZ:P0e]KF08j>SP0d=3@0>c/k02<S8`0Z:RX0PX:205IFEP14A4@0Lg=c02TY:@80
30`<00P00`<300d=3@0=3@d03`l?03dm?@0Y:BT07QhN020P80807AdM00h08B4Q02PX:017AdL0YJFU
0:RXZ02[Zj/0/K6a09jNWP1EEED0;Bd]01dM7@0J6QX06a/K01HF5P805ADE03<05aLG038b<P2>SXh0
S8b<06=SH`1=CDd0JVYZ04e=C@2ATI408b<S014A4@0>3Ph05ADE01@D500S8b<0ATI6051@D00];Bd0
8b<S02@T900Q8B40PH6108>3P`0d=3@0EUIF0<71`@2g]kL0>3Ph01LG5`0E5AD07QhN04I6AP1mOGd0
P820065QH@1GEeL0S8b<0=3@d01MGEd08B4Q01hN7P0Y:BT0dM7A0=_Kf`3Ph>00bl_;05QHF017AdL0
CDe=04Q8B01?Cdl00P1=CDd03P1_Kfl0SHf=0<;2`P3;bl/0JFUY04m?C`30`<00f=SH0<_;b`2/[:`0
KVi^010@400?3`l03Ph>0P0@41002P0C4a<0ATI609NGU`0d=3@05ADE010@400D51@04Q8B01dM7@2m
_Kd20;jn_P0L0<_;b`3GemL0eMGE07IfMP0D51@05ADE02h^;P3>c/h0Lg=c01HF5P0E5AD051@D01<C
4`0A4A40ADE502PX:01lO7`0F5QH04U9B@1JFUX0`L7108J6QP1MGEd0Ph>30=_Kf`38b<P0BDU902HV
9P805QHF0`0J6QX202d];@0803Hf=P1;Bd/0NWYj0451@@0U9BD0Bd];0;^k^`0R8R8201DE5@0<01dM
7@1SHf<0@41006YZJP1aLG40/k>c0>CTi03@d=00/[:b07IfMP15ADD0:BTY0P0E5AD0400J6QX0ATI6
06a/K02<S8`0<30`02h^;P0V9RH092@T02`/;01LG5`0=SHf04I6AP2NWYh0^[Zj05mOG`1JFUX204e=
C@0R08B4Q01SHf<05ADE01<C4`0O7al0Bd];06m_K`1JFUX0MgMg0:JVYP2ATI40UIFE0:6QX@1VIVH0
HV9R04M7A`19BDT0FEUI05mOG`2EUID0bLW90=3@d03Cdm<0`/;20;^k^`30`<00`L710<o?c`2HV9P0
;Bd]02/[:`0f=SH0>SXj06UYJ@80?Cdm00<0Lg=c08B4Q?ooool04?ooool000oooooo0?l0aLG509:B
TP1BDU80U9BD07IfMP1lO7`0IFEU07YjNP1OGel0?clo05QHF028R8P0LW9b08N7Q`1>CTh0UiNG05YJ
FP1CDe<0L71`02`/;02DU9@0V9RH03@d=01_Kfl0MgMg04U9B@2EUID0Hf=S05QHF025QHD0HV9R07in
OP1=CDd0Bd];09nOW`1;Bd/0>CTi04U9B@0X:2P0;Bd]01/K6`1GEeL08B4Q03`l?013@d<0?clo04U9
B@14A4@08B4Q059BDP10@400O7al07QhN011@D40NGUi05YJFP0e=CD0DU9B03Lg=`0Z:RX0H61P0:VY
Z@1VIVH0IfMW06EUI@1:BTX0;Bd]03lo?`1hN7P0=cLg02`/;01CDe<0EUIF04i>CP0];Bd0C4a<0820
P01ADE40XJ6Q09:BTP0W9bL0De=C07AdM01;Bd/0@T920;Vi^@1?Cdl0=CDe03lo?`23Ph<0D51@04i>
CP1fMWH0RXZ:06a/K00N7Qh0_Kfm055AD@19BDT0RXZ:03`l?01XJ6P0CTi>07alO00k>c/0Hf=S05MG
E`0k>c/0A4A405EEE@1;Bd/0GEeM05IFEP1GEeL0@D5103lo?`1mOGd0;Rh^06a/K01WIfL0FUYJ05EE
E@1MGEd0;Bd]06][J`1ZJVX0DU9B05aLG01iNGT0O7al04m?C`1HF5P0?Shn096AT@25QHD0Fe]K07=c
L`20P8008R8R06a/K01OGel0?clo038b<P0[:b/0@41006i^KP1cLg<0?Shn03dm?@1@D500O7al0:RX
Z02RXZ80>SXj065QH@0[:b/0GEeM0:2PX01EEED0K6a/07AdM01=CDd0RXZ:075aL@1XJ6P0QhN70<G5
a@1=CDd0;bl_09>CT`1QHF40DU9B08b<S03Fe]H0?3`l03dm?@1YJFT0R8R80451@@2TY:@0VYZJ08n?
S`3Jf]X0Zj^[06UYJ@28R8P0De=C04=3@`18B4P0:BTY01lO7`1EEED0=SHf0;>c/`2RXZ80LG5a07al
O01oOgl0GemO0:JVYP1FEUH06a/K05eMG@0a<C40LG5a0<G5a@2XZ:P0QXJ602h^;P1BDU80@D5105aL
G00i>CT0Ph>30;Jf]P2@T900?Shn05QHF00a<C40>CTi09NGU`1GEeL0;Rh^04M7A`2NWYh0>CTi02`/
;02SXj<0HF5Q02l_;`1BDU80DE5A03De=@1WIfL0NGUi06MWI`19BDT0KVi^0492@P0j>SX0Kfm_06MW
I`0X:2P0;bl_04i>CP0f=SH0O7al03@d=00c<c<0CDe=079bLP1>CTh0820P05EEE@1kNg/002<0:BTY
04];B`1XJ6P0:2PX03Xj>P1QHF40][Jf07YjNP0U9BD0=cLg04A4A00/;2`0OGem05QHF00];Bd0H61P
03Ph>00K6a/0>3Ph07]kN`18B4P0T92@03Ti>@0k>c/0OWin07EeM@1ZJVX0:2PX04];B`1nOWh0?Cdm
05IFEP2SXj<0OWin04I6AP0Looooo`0W04A4A02NWYh0Ogmo03dm?@0n?Sh0ADE504=3@`0n?Sh0>c/k
04I6AP2FUYH0_;bl0::RXP1:BTX0WinO0:6QX@0a<C40;2`/05MGE`29RHT0`L710;fm_@3Fe]H0_;bl
0:ZZZP1MGEd0DU9B065QH@1MGEd0EEEE05YJFP16ATH0EEEE075aL@2NWYh0I6AT01`L700B4Q803@d=
00803Ph>00L03`l?00h>3P0J6QX0?Cdm07AdM01:BTX0=SHf0080<S8b02T0IVIV0:ZZZP27QhL0HV9R
03lo?`35aLD0ZZZZ0451@@10@400:2PX06m_K`2b/[806ATI00l?3`0i>CT0NWYj030`<00C4a<02PX:
00d=3@0C4a<051@D05]KF`0n?Sh0@41005iNGP1DE5@0BDU9051@D01DE5@0D51@08:2PP1DE5@08B4Q
03Xj>P2o_kl0H61P07AdM01GEeL09BDU01`L700201DE5@0`01<C4`0E5AD05aLG07=cL`2>SXh0MWIf
02XZ:P1gMgL0HF5Q0;6a/@0U9BD051@D010@400W9bL0AdM70451@@0Z:RX08B4Q01hN7P0Q8B407AdM
03Hf=P2IVIT0@T9202TY:@0f=SH0R8R808Z:RP2=SHd0F5QH01lO7`0N7Qh08B4Q01dM7@0d=3@0Ph>3
09NGU`1LG5`0aLG50<C4a01`L700=SHf03Ti>@31`L40b<S80=WIf@21PH406ATI1`0E5AD02`0H61P0
Zj^[09jNWP0M7Ad0?3`l05iNGP20P800Y:BT08>3P`2/[:`0<C4a00@03Ph>02T09BDU08>3P`17AdL0
8b<S01@D500E5AD04Q8B01TI6@1NGUh0XJ6Q092@T02^[Zh0ZJVY0<[:bP3>c/h0Fe]K01DE5@0b<S80
SHf=03@d=01IFET07QhN01DE5@0D51@05ADE01<C4`0T92@0K6a/08B4Q01IFET0EEEE08f=S@1mOGd0
Shn?09RHV039bLT0YZJV09RHV00K6a/04a<C018B4P0301TI6@0H01LG5`0l?3`09bLW02l_;`1dM7@0
L71`03@d=00I6AT06a/K06][J`1:BTX05ADE01LG5`0K6a/0EUIF024Q8@0Y:BT0<c<c0492@P2?Shl0
Fe]K0;jn_P2:RXX092@T0P0E5AD04@0G5aL071`L03De=@1fMWH0Ph>306][J`1CDe<0=3@d02d];@0/
;2`0IVIV03Ti>@1DE5@0S8b<0::RXP1gMgL0NWYj0080WYjN0100QhN707MgM`0E5AD04a<C01TI6@0Q
8B40]KFe0=;BdP3Hf=P0`L710:FUY@21PH40?3`l024Q8@0X:2P06ATI0P0E5AD0500G5aL0G5aL0:VY
Z@2ZZZX0d=3@0<_;b`1RHV80Lg=c09BDU033`l<0^[Zj08Z:RP0l?3`0>CTi04e=C@1jNWX0<30`03Hf
=P0g=cL0FEUI4Oooool000oooooo06D0a/K609BDU01BDU80ZZZZ08>3P`26QXH0LG5a0:RXZ02TY:@0
DE5A05IFEP1YJFT0CTi>08b<S01QHF40WIfM06EUI@1]KFd0QhN703@d=02WYjL0UYJF030`<01YJFT0
Lg=c04a<C01aLG40:b/[03Xj>P1[Jf/0LW9b05MGE`1DE5@0<30`09>CT`19BDT0=cLg059BDP0M7Ad0
E5AD02h^;P1[Jf/06ATI05]KF`1=CDd0>c/k04a<C013@d<0:b/[04i>CP0f=SH0B4Q807YjNP11@D40
R8R806i^KP0e=CD0EeMG03<c<`0M7Ad0=CDe06UYJ@1@D500MgMg06EUI@0];Bd0De=C071`L01iNGT0
E5AD03Ph>01CDe<0DE5A04Q8B01?Cdl0?Cdm07QhN01ADE40VIVI08B4Q00m?Cd0A4A406EUI@0T92@0
HV9R0;Rh^01MGEd0>c/k0492@P2=SHd0BTY:02@T900o?cl0OGem06m_K`0T92@0^KVi06EUI@0e=CD0
GemO04=3@`0205iNGP0Z096AT@0n?Sh0I6AT04];B`1MGEd0MGEe05UIF@1>CTh0E5AD03<c<`1HF5P0
=3@d03De=@1kNg/0G5aL05ADE01NGUh0FEUI05=CD`1VIVH0<c<c06IVIP1^KVh0Cdm?08:2PP1KFe/0
DU9B04a<C01ADE40;2`/05YJFP25QHD0DU9B07EeM@27QhL0<30`05]KF`1NGUh0=cLg04E5A@0d=3@0
BDU90P1ZJVX0R00_;bl0=cLg07EeM@1lO7`0HV9R09:BTP0f=SH0De=C03dm?@14A4@0T92@04e=C@1U
IFD0RHV9079bLP2GUiL0QhN706m_K`1oOgl0]kNg08B4Q00W9bL0Shn?061PH01IFET0W9bL0<c<c01h
N7P0E5AD08F5Q@2QXJ40Cdm?09RHV02RXZ80/[:b0<G5a@2/[:`0Hf=S07UiN@1GEeL0HV9R04Y:BP0d
=3@07alO05IFEP0_;bl0Ti>C08n?S`1KFe/0P82007inOP12@T80S8b<03dm?@0J6QX0De=C02<S8`0l
?3`0Hf=S05]KF`1XJ6P0=3@d05MGE`1;Bd/0Fe]K01/K6`1BDU80O7al08n?S`1GEeL0HV9R01dM7@0W
9bL0NGUi06][J`0h>3P0Bd];096AT@0P820061PH061PH00Y:BT0<S8b05IFEP1>CTh0G5aL065QH@1C
De<0DU9B0492@P1JFUX0<S8b01DE5@1HF5P0L71`03<c<`0g=cL0>CTi04I6AP2TY:@0HV9R061PH02D
U9@0[:b/03lo?`0m?Cd0P82008F5Q@0k>c/0KFe]08b<S01VIVH0AdM707=cL`2k^k/0OGem02DU9@18
B4P0DU9B03dm?@27QhL0>3Ph03lo?`2NWYh0H61P02d];@0j>SX0B4Q8030`<01aLG40De=C03hn?P1K
Fe/0K6a/02h^;P1JFUX209bLW005038b<P0];Bd0QhN7061PH00[:b/07?ooool06`1iNGT0_[jn0;^k
^`2>SXh0Bd];03`l?00[:b/0:2PX034a<@0g=cL0>3Ph06ATI03<c<`0b/[:08n?S`26QXH0T92@09:B
TP28R8P0QHF50;Zj^P3=cLd0eMGE09NGU`1mOGd05QHF01<C4`0201@D500801LG5`0Q8B40P82008J6
QP0f=SH0DU9B05ADE00a<C4200h>3P16010@400>3Ph03`l?00h>3P0A4A406a/K03/k>`2RXZ80FUYJ
04M7A`1;Bd/0PX:20:n_[`21PH40<C4a02<S8`2EUID0^k^k06e]K@0o?cl0ATI60;:b/P1kNg/04a<C
00h>3P0C4a<0Ng]k0=GEe@2_[jl0QXJ607moO`1kNg/0WinO09bLW02HV9P0I6AT05UIF@1ADE40AdM7
03<c<`0^;Rh0=CDe0451@@0h>3P05ADE02DU9@2XZ:P0?Cdm01LG5`1OGel0QhN703@d=00H61P05aLG
01DE5@0I6AT061PH05]KF`2l_;`0c/k>07EeM@2h^;P0^k^k0=cLg01MGEd0CDe=05aLG00o?cl0820P
01hN7P806a/K02808R8R02XZ:P0];Bd0VIVI06MWI`0P820092@T034a<@1WIfL0PX:2071`L02NWYh0
UYJF04Y:BP0d=3@0<C4a03Hf=P17AdL0Ogmo0:FUY@2n_[h0gmoO0=GEe@3>c/h0/k>c0=7Ad@2c/k<0
dM7A03@d=00M7Ad05ADE01@D500E5AD05QHF100E5AD09026QXH0FEUI01dM7@1BDU80:RXZ03Ti>@22
PX80[jn_08V9R@20P8004A4A00h>3P0?3`l05ADE07emO@1HF5P09RHV02TY:@0D51@04a<C02DU9@1]
KFd0LG5a034a<@1IFET0WYjN09>CT`11@D40R8R805UIF@0Y:BT0Ti>C02PX:00D51@0?Shn03`l?0<0
5ADE00h05QHF01TI6@1CDe<0dm?C0;:b/P2n_[h0TY:B08F5Q@2ATI40Fe]K07YjNP0g=cL0<S8b05MG
E`805aLG0P0E5AD0E00D51@0820P04A4A00Q8B40;bl_09NGU`12@T806ATI01LG5`0F5QH08b<S06i^
KP0L71`0;bl_07QhN02VYZH0:BTY01TI6@0Y:BT0=3@d0410@00W9bL0XZ:R05IFEP0E5AD04a<C01DE
5@0M7Ad0=cLg05IFEP1_Kfl0BDU9059BDP23Ph<0DU9B0410@01SHf<0]KFe09jNWP2VYZH0EUIF06UY
J@0L71`0:RXZ05]KF`2>SXh0_[jn0:>SX`0L71`05aLG02l_;`1mOGd0WIfM09^KV`36a/H0ZJVY0;>c
/`36a/H0X:2P07IfMP0/;2`05aLG01HF5P0I6AT07alO06e]K@1_Kfl0XZ:R0=3@d02i^KT0?Cdm06i^
KP1fMWH0VYZJ08N7Q`2FUYH0_;bl09FEU@2LW9`0[Zj^04M7A`0j>SX0?Shn04];Ba7ooooo000?oooo
o`3C0<71`@1dM7@0R8R80;Ng]`21PH40H61P06QXJ024Q8@0XJ6Q04U9B@1NGUh0MWIf05eMG@1lO7`0
IVIV05eMG@1=CDd0VIVI07QhN00e=CD0[Zj^07MgM`17AdL0QhN706i^KP0l?3`0V9RH05=CD`14A4@0
HV9R04Y:BP1SHf<0IVIV03Xj>P2QXJ40D51@03Ti>@1BDU80;Bd]03Xj>P0P8200H61P01LG5`0d=3@0
Bd];03De=@1@D500:b/[01/K6`1LG5`0ADE504];B`1EEED09bLW06=SH`1GEeL0<C4a05UIF@17AdL0
BDU903Ti>@1_Kfl0D51@07QhN01OGel0A4A4028R8P1LG5`0KVi^051@D00k>c/0EeMG03Xj>P1RHV80
BDU904=3@`1LG5`0=SHf09JFUP2UYJD0E5AD04=3@`1WIfL0<c<c0451@@2][Jd0?clo04I6AP1TI6@0
TY:B06YZJP0c<c<0FEUI07]kN`0h>3P0AdM70<[:bP1hN7P0=cLg061PH00m?Cd0JFUY05]KF`1fMWH0
<S8b071`L01;Bd/0;2`/059BDP1YJFT0=SHf05]KF`1BDU80HV9R03Ti>@0c<c<0PH61061PH01TI6@0
Lg=c05ADE01NGUh0N7Qh04M7A`1nOWh0JVYZ05QHF02DU9@0L71`06MWI`1DE5@0MgMg04e=C@1RHV80
Q8B405iNGP20P800Xj>S03dm?@1TI6@0JFUY03Ti>@1GEeL0>SXj0410@01VIVH0GEeM04];B`1[Jf/0
Ph>307moO`1IFET0QXJ602`/;01ZJVX0BTY:04];B`2DU9@0J6QX06][J`2>SXh0TY:B08N7Q`1ZJVX0
IVIV09BDU02k^k/0PH6102/[:`21PH40L71`05eMG@2j^[X0/K6a08:2PP1BDU80SHf=0:ZZZP17AdL0
];Bd0::RXP20P800^k^k0::RXP1@D500MGEe05YJFP1QHF40D51@02/[:`0M7Ad0PX:204Y:BP29RHT0
NWYj0410@02XZ:P0YJFU04M7A`2EUID0?3`l01lO7`1[Jf/0H61P05iNGP29RHT0Cdm?069RHP0[:b/0
EeMG04A4A00205MGE`0C06=SH`1UIFD0QhN702LW9`2GUiL0I6AT02/[:`1YJFT0DE5A03<c<`2DU9@0
Z:RX07EeM@0h>3P0L71`018B4P13@d<0UIFE08F5Q@0205]KF`0h06QXJ00j>SX0B4Q806UYJ@0`<300
8R8R06EUI@1XJ6P0=cLg04Q8B00c<c<09RHV07AdM00Q8B40K6a/09bLW02`/;00Cdm?01dM7@16ATH0
Hf=S01@D501?Cdl0UIFE06=SH`1?Cdl0Lg=c0;Jf]P1UIFD0=CDe065QH@1PH600@d=3079bLP0i>CT0
;2`/06EUI@0];Bd06QXJ03hn?P1<C4`0?Cdm06][J`1=CDd0C4a<06a/K01GEeL0:BTY02l_;`1?Cdl0
NWYj04i>CP0i>CT0UiNG05]KF`0c<c<Looooo`0V0;:b/P2l_;`0[Jf]04M7A`19BDT0=3@d02DU9@0Q
8B4071`L01dM7@0`<300Cdm?09RHV027QhL0a/K60=SHf02n_[h0TY:B08J6QP1LG5`0>CTi04i>CP1Y
JFT0/[:b08>3P`1KFe/06QXJ01<C4`0E5AD06ATI01LG5`1]KFd0Cdm?020P800o?cl0F5QH04Y:BP0B
4Q8200h>3P0S010@400>3Ph03Ph>00l?3`0G5aL09BDU08B4Q02`/;00Cdm?065QH@2QXJ40U9BD08F5
Q@0h>3P07QhN05ADE030`<00a<C40:2PX02k^k/0WIfM08V9R@23Ph<0M7Ad08n?S`3=cLd0fm_K0<o?
c`2ZZZX0Y:BT0;Rh^03Hf=P0UiNG05iNGP1^KVh00P1MGEd07P1KFe/0>c/k01XJ6P0D51@08b<S03Lg
=`0I6AT05QHF06][J`2@T9004A4A018B4P0h>3P0VYZJ04M7A`0g=cL0BDU905QHF01UIFD0Zj^[0<g=
c@3AdM40Rh^;0=7Ad@35aLD0i^KV0=kNgP2ZZZX0G5aL02l_;`807alO02@0820P02HV9P14A4@0>SXj
06YZJP2IVIT0=CDe02h^;P0Y:BT0@d=30820P02=SHd0BTY:065QH@1hN7P07AdM01PH600D51@04a<C
01DE5@0J6QX0R8R80=_Kf`2TY:@0PH61096AT@3@d=00dM7A0:n_[`1_Kfl08B4Q01dM7@0E5AD051@D
01HF5P0C4a<301DE5@0V01LG5`1PH600<S8b01TI6@19BDT06QXJ02HV9P1lO7`0UYJF08N7Q`28R8P0
?Shn00h>3P0E5AD0EUIF069RHP0[:b/0:BTY01<C4`0I6AT0>CTi04E5A@0e=CD0=SHf03Lg=`1iNGT0
Ng]k09fMW@12@T80MgMg0:NWY`34a<@0I6AT01LG5`0B4Q80=3@d06YZJP0Q8B4301DE5@0>01TI6@12
@T80UIFE09VIV@0_;bl0>3Ph07=cL`0_;bl071`L04Q8B00H61P07alO04m?C`18B4P301DE5@0H01<C
4`0[:b/0<C4a01hN7P0k>c/0^k^k02d];@0I6AT05aLG01DE5@0F5QH0QHF506a/K01BDU80>c/k06][
J`0^;Rh08B4Q02DU9@0S8b<09bLW038b<P2>SXh0NWYj0P0E5AD08P0M7Ad0=cLg05YJFP2ATI40:b/[
02<S8`1ADE40Fe]K08J6QP25QHD0ZJVY0:>SX`1mOGd0D51@04Y:BP1VIVH07alO01`L700Y:BT0?Cdm
08:2PP3Bd]80U9BD0861P@2JVYX0KFe]07inOP2d];@0WIfM09bLW02=SHd0=cLg01TI6@0];Bd201LG
5`0F01XJ6P0T92@0CTi>071`L018B4P0<c<c04Y:BP2m_Kd0@D5106MWI`2DU9@0Xj>S08^;R`1PH600
_[jn0=GEe@2CTi<0`<300:^[Z`1`L700K6a/07moOa7ooooo000?ooooo`040;jn_P1bLW80D51@096A
T@80PH6104d0I6AT07]kN`2LW9`0Bd];06UYJ@2LW9`0MWIf08f=S@1PH600WinO05UIF@1ADE40G5aL
038b<P2KVi/0ATI602DU9@1_Kfl0KFe]05UIF@2JVYX0ADE504];B`17AdL0>c/k08R8R01WIfL0=SHf
08V9R@0[:b/0De=C07IfMP13@d<0;bl_01lO7`1RHV80;Bd]03Ph>00i>CT0CTi>07EeM@12@T80:2PX
05ADE00o?cl0BTY:06a/K012@T80PH6105]KF`0_;bl0H61P04Y:BP15ADD0?3`l05ADE016ATH0Zj^[
069RHP11@D40<C4a04A4A01KFe/0BDU903`l?01`L700>SXj03`l?01>CTh0Fe]K06e]K@0X:2P0De=C
0861P@0n?Sh0L71`0:BTY00204a<C00Y0;fm_@0O7al0<30`03Ph>028R8P0Fe]K03Hf=P1FEUH0FEUI
04=3@`0O7al0Lg=c075aL@0Z:RX0GEeM03hn?P1`L700GemO05=CD`0[:b/0QhN705IFEP0g=cL0GEeM
05UIF@1<C4`0S8b<04];B`1IFET0@D5106QXJ02a/K40HF5Q06IVIP1@D500Jf][0:VYZ@22PX80@d=3
07EeM@11@D400P1lO7`0>@1`L700Hf=S061PH01eMGD0De=C06=SH`1;Bd/0A4A40:>SX`2BTY80>CTi
061PH01RHV80LG5a06m_K`0b<S80?3`l06QXJ00h>3P09BDU03De=@1WIfL0Jf][04E5A@0f=SH09RHV
08f=S@1VIVH0B4Q808B4Q01;Bd/0R8R809FEU@21PH40R8R8061PH00^;Rh0MGEe0:VYZ@1lO7`0@410
08V9R@1FEUH0ADE50<[:bP2d];@0MWIf05=CD`2<S8`0Shn?03De=@24Q8@0UiNG05YJFP2h^;P0MWIf
03dm?@020;Jf]P1=069RHP1>CTh09BDU03@d=02SXj<0Jf][09>CT`1fMWH0?Shn059BDP1ZJVX0>3Ph
08b<S00[:b/0E5AD0;2`/01PH600G5aL09JFUP1?Cdl0IFEU03Ph>023Ph<0Ti>C08Z:RP1TI6@0QXJ6
07EeM@2MWId0>c/k061PH01NGUh0<C4a06e]K@1GEeL071`L04];B`24Q8@0NGUi03Ti>@1nOWh0?clo
02`/;01[Jf/0LW9b05UIF@1EEED0GUiN04m?C`0a<C40PX:205QHF00m?Cd0Hf=S03Xj>P0H61P0MgMg
04i>CP0c<c<0OGem051@D011@D40K6a/09^KV`1<C4`08B4Q055AD@1`L700A4A404=3@`2HV9P0FEUI
04A4A01hN7P0Vi^K020P800G5aL00P1kNg/0600e=CD0R8R805=CD`0i>CT0Kfm_03Xj>P0f=SH0JVYZ
06e]K@11@D40GUiN04Q8B01TI6@0X:2P08>3P`1SHf<0:RXZ04E5A@1aLG40=SHf04M7A`2f][H0RXZ:
06ATI1cooooo00P0JFUY09^KV`2VYZH0Jf][055AD@1MGEd0FUYJ061PH080I6AT0180JFUY07inOP1O
Gel0KFe]0:^[Z`3IfMT0QHF502`/;00G5aL05ADE01<C4`0m?Cd0:b/[03dm?@2=SHd0L71`08V9R@0f
=SH201DE5@0:02<S8`1]KFd0>c/k01hN7P10@400EEEE05mOG`0Q8B404A4A010@408051@D02@04A4A
01@D500O7al09bLW07QhN01EEED0Shn?0<[:bP31`L40^k^k0:>SX`1YJFT0>CTi03/k>`38b<P0e]KF
0<;2`P1MGEd0<30`028R8P0^;Rh0<C4a03@d=00g=cL0B4Q806i^KP23Ph<0LW9b08V9R@2l_;`0QHF5
06ATI00e=CD0>3Ph03De=@0J6QX2010@400801DE5@0J6QX0;Bd]03hn?P0I6AT0;2`/09nOW`0Y:BT2
010@400U05MGE`3;bl/0Y:BT07YjNP1/K6`0MWIf09nOW`2/[:`0Lg=c0861P@3EeMD0g]kN0>;RhP2a
/K40c/k>0<c<c02UYJD0Ogmo05aLG028R8P0V9RH09:BTP2;Rh/0`l?305]KF`19BDT0@4100492@P1E
EED0O7al07IfMP0h>3P0:RXZ05QHF00];Bd07AdM01XJ6P0201<C4`0=01LG5`1_Kfl0dm?C0=GEe@3;
bl/0a<C40=[JfP2k^k/0QXJ609ZJVP0_;bl08B4Q028R8P0401DE5@0701PH600E5AD06ATI051@D00V
9RH071`L03hn?P0201LG5`0907MgM`1iNGT0Y:BT05iNGP1bLW804a<C051@D01oOgl0<S8b00807alO
01@0>c/k04Q8B00];Bd07QhN01/K6`0Q8B40=3@d09:BTP1FEUH0aLG50::RXP2j^[X0Ogmo061PH02P
X:00T92@06i^KP1jNWX0^;Rh04Q8B0805ADE00/051@D02@T901_Kfl0Shn?065QH@0T92@0KVi^03Xj
>P0F5QH06QXJ03/k>`0201DE5@0301lO7`1SHf<0DE5A00805ADE00d04a<C03Ti>@0d=3@0>SXj071`
L03@d=00:RXZ01TI6@0F5QH05ADE01HF5P1KFe/0820P00805ADE01L0B4Q803@d=00P8200A4A403@d
=00`<300CTi>0:n_[`2ATI407AdM02XZ:P0k>c/0D51@08B4Q00k>c/05ADE01PH600h>3P0]kNg08f=
S@1YJFT0UYJF07MgM`02092@T00/07emO@2:RXX0>3Ph03@d=00h>3P0@D5105IFEP37alL0fm_K0<[:
bP22PX80L71`09FEU@2i^KT0_Kfm0;bl_01[Jf/06ATI01`L700R8R80:BTY01hN7P0U9BD0?Cdm055A
D@2DU9@0BTY:038b<P0i>CT0ZJVY08Z:RP1LG5`0LW9b09^KV`2?Shl0ATI608Z:RP2EUID0:2PX03`l
?029RHT0XJ6Q0:j^[P34a<@Aooooo`003oooool0G030`<00Ng]k05QHF02:RXX0Ogmo07UiN@1kNg/0
Ti>C06i^KP18B4P0OGem09NGU`1WIfL0Q8B4055AD@2FUYH0GEeM05UIF@1<C4`0@41009nOW`22PX80
;Rh^05iNGP0c<c<0@d=309>CT`0f=SH0A4A404i>CP0o?cl0FUYJ07AdM00d=3@0TY:B04i>CP0l?3`0
E5AD02`/;00X:2P0;2`/05mOG`0_;bl0>3Ph024Q8@0_;bl0Bd];04i>CP0/;2`0Bd];02h^;P1KFe/0
NWYj0492@P1gMgL0;Bd]03Ti>@1oOgl0Hf=S0410@016ATH0GUiN04E5A@1lO7`0HV9R05=CD`0Y:BT0
CTi>06IVIP0W9bL0>CTi06i^KP1?Cdl0BDU902`/;013@d<0J6QX04Q8B020P800NGUi03Xj>P14A4@0
KVi^03hn?P1EEED0V9RH034a<@14A4@0@D51092@T010@400?clo0P1TI6@08P1FEUH0@d=309nOW`13
@d<0<30`07inOP0d=3@0Jf][06ATI01UIFD0:BTY07AdM012@T80@d=306YZJP1@D500=SHf04];B`0c
<c<0KVi^03Ph>010@400O7al03/k>`1JFUX0CTi>04];B`1CDe<0CDe=03De=@1hN7P0FUYJ04I6AP1B
DU8206UYJ@1m04e=C@1WIfL0CTi>07emO@1OGel0KVi^07MgM`1iNGT0:b/[07moO`1RHV80DE5A04A4
A00_;bl0CTi>06][J`1UIFD0<C4a038b<P1FEUH0M7Ad07IfMP1hN7P09BDU06QXJ013@d<0D51@09FE
U@1>CTh0Jf][07IfMP2=SHd0VIVI08J6QP1^KVh0K6a/0:^[Z`1XJ6P0=CDe09^KV`1OGel0?Shn09JF
UP2?Shl0D51@04m?C`2DU9@0WYjN05UIF@2;Rh/0MWIf04M7A`2m_Kd0XJ6Q04Y:BP1LG5`0JVYZ03<c
<`1PH600;bl_02<S8`1GEeL0@d=30;6a/@2LW9`0JVYZ079bLP2<S8`0>3Ph08b<S00e=CD08b<S06=S
H`0n?Sh0F5QH0:RXZ01fMWH0M7Ad02`/;01DE5@0CTi>07=cL`1ADE40OWin08^;R`2QXJ40FEUI06UY
J@1LG5`0>3Ph06a/K01bLW80CDe=065QH@2UYJD0JFUY03hn?P28R8P0G5aL03<c<`2=SHd0PH6103hn
?P1OGel0PX:207moO`10@400QHF503lo?`0e=CD0KVi^06UYJ@0Y:BT0L71`02d];@0h>3P0Shn?06IV
IP1?Cdl0HF5Q07AdM00j>SX0<30`06a/K01oOgl00P0l?3`08@1nOWh0@d=304e=C@2HV9P0UiNG05eM
G@0N7Qh0Ng]k05YJFP0`<300QHF505ADE00l?3`0Ti>C04Q8B00X:2P0Cdm?06e]K@1:BTX0O7al04M7
A`1@D500Q8B407YjNP1JFUX0<S8b04e=C@23Ph<0=3@d03Ti>@22PX80M7Ad04E5A@0Looooo`1<07em
O@2PX:00V9RH05=CD`0_;bl09bLW01dM7@0L71`06ATI01PH600N7Qh08b<S04M7A`1MGEd0DE5A06m_
K`1DE5@05aLG01DE5@0D51@0410@02d];@0m?Cd0:BTY04i>CP2SXj<0Ng]k07EeM@1kNg/0MGEe0:FU
Y@1;Bd/0@T9202l_;`19BDT0OGem0820P01_Kfl0<S8b01/K6`0G5aL061PH01lO7`0_;bl0:b/[02HV
9P0C4a<03`l?01LG5`1HF5P0;Rh^03Ti>@0X:2P06a/K03dm?@2_[jl0e=CD0=SHf03=cLd0Z:RX09:B
TP1/K6`0G5aL0492@P0c<c<0;Bd]03Xj>P16ATH0P820071`L01MGEd0Xj>S08J6QP0R8R805aLG00l?
3`@03Ph>00P0410@014A4@0Y:BT0>3Ph0410@00P8200=SHf09nOW`80?clo06h0GemO05QHF01:BTX0
De=C05UIF@1bLW80YJFU0:2PX02c/k<0clo?0>7Qh@3?cll0`/;20=gMg@25QHD0MWIf07alO02FUYH0
`/;2092@T00[:b/09RHV03Lg=`1[Jf/0SHf=04m?C`0g=cL0:BTY02HV9P0];Bd0FUYJ03Hf=P0R8R80
9RHV03/k>`0E5AD05aLG028R8P0/;2`0=cLg0451@@19BDT09bLW05=CD`0k>c/0G5aL06i^KP25QHD0
aLG508B4Q00_;bl0<C4a01lO7`0K6a/06ATI01PH600F5QH061PH01LG5`1:BTX06QXJ04A4A01SHf<0
;2`/02XZ:P1@D500[:b/0:j^[P2IVIT0R8R80:NWY`2VYZH0IFEU03dm?@0a<C40:BTY01hN7P0J6QX0
6ATI02<S8`0i>CT0DE5A09^KV`2c/k<0Rh^;04M7A`0V9RH0CTi>071`L00I6AT06QXJ02@T900_;bl0
>CTi04];B`2BTY80Q8B403Lg=`0d=3@0Cdm?08^;R`2YZJT0ZZZZ06QXJ01OGel06QXJ01/K6`0S8b<0
<S8b01DE5@805QHF01407QhN03`l?01;Bd/0C4a<051@D02<S8`0SXj>09fMW@3;bl/0h>3P04i>CP0R
8R807alO01LG5`0E5AD0Cdm?01PH600201DE5@1501/K6`1ADE40@T9202/[:`1CDe<0EeMG0;Ng]`3I
fMT0emOG08n?S`1DE5@0K6a/0861P@0d=3@06ATI03De=@0l?3`0@T9203Lg=`22PX80/;2`0:6QX@1e
MGD0HF5Q05YJFP0k>c/0PH6105MGE`1RHV80LW9b08f=S@2h^;P0Y:BT051@D021PH40S8b<08n?S`2^
[Zh0_;bl0=7Ad@2b/[80GEeM04=3@`0X:2P0;bl_03/k>`0/;2`0:2PX01hN7P0L71`0DU9B05EEE@0m
?Cd0=CDe08V9R@1XJ6P0N7Qh09NGU`2XZ:P0]kNg059BDP2;Rh/0R8R8034a<@0_;bl0>CTi05UIF@2=
SHd0bLW9017ooooo000?ooooo`3o0<;2`P1DE5@0HV9R08^;R`1gMgL0AdM705aLG01_Kfl0PX:2059B
DP2KVi/0RHV904U9B@2?Shl0LW9b08:2PP1XJ6P0QhN703lo?`16ATH0P82006EUI@1>CTh0QXJ6069R
HP0k>c/0J6QX02TY:@1aLG40KFe]04i>CP1TI6@0@D5104a<C02=SHd0DE5A04I6AP1;Bd/06a/K03<c
<`0e=CD0@T9201dM7@1;Bd/0;bl_0451@@1;Bd/0:b/[03<c<`1OGel0?Cdm04M7A`19BDT0=3@d0861
P@11@D40=3@d05YJFP0m?Cd0CDe=07emO@2ATI40DE5A09:BTP1BDU80@D5102HV9P1?Cdl0E5AD04];
B`1IFET0JVYZ055AD@1IFET0AdM705ADE01GEeL0>SXj09RHV02CTi<0C4a<055AD@1dM7@08b<S05]K
F`2KVi/0?clo04I6AP15ADD0T92@05ADE00f=SH0E5AD04i>CP0X:2P0Hf=S07=cL`1CDe<0<S8b08R8
R01ADE40L71`06][J`1VIVH0?3`l0861P@1@D500=SHf069RHP1kNg/0?Shn04U9B@13@d<0Rh^;04M7
A`1BDU80PX:2051@D01TI6@0ADE506UYJ@2BTY80NWYj04Q8B024Q8@0GEeM06i^KP1nOWh0J6QX07Qh
N01WIfL0RHV905ADE01MGEd0Fe]K07AdM02_[jl0PX:202d];@1kNg/0JVYZ07UiN@1lO7`0@41003Xj
>P1]KFd0De=C05EEE@21PH40Ogmo07inOP1QHF40MgMg02d];@1ZJVX0AdM703@d=027QhL0K6a/06AT
I01UIFD0E5AD079bLP1JFUX0?clo05IFEP2_[jl0?Shn02h^;P2:RXX0Hf=S03hn?P1dM7@0QhN7051@
D01:BTX0T92@09^KV`1DE5@0^k^k092@T019BDT0/;2`075aL@1GEeL0^;Rh0:f][@0n?Sh0CDe=03`l
?00M7Ad0ATI602TY:@2MWId0YJFU06EUI@1gMgL0RHV902DU9@1nOWh0@T9202<S8`1PH6007AdM03Xj
>P1UIFD0IVIV07YjNP11@D40Cdm?059BDP1dM7@04a<C03Lg=`1OGel0YJFU06i^KP2EUID0>CTi034a
<@1eMGD0Fe]K03Ph>02<S8`0_[jn051@D00V9RH0NWYj02TY:@0Z:RX0OGem07moO`1ADE40CTi>075a
L@11@D40@T92092@T01=CDd09bLW051@D01GEeL0=3@d09jNWP19BDT0<C4a0820P00k>c/0T92@0;6a
/@2QXJ40ATI602<S8`1CDe<0FUYJ000902TY:@15ADD0S8b<04i>CP0i>CT0LG5a0:NWY`1SHf<06QXJ
0080JFUY01P0;2`/06a/K01VIVH0=cLg06e]K@0X:2P08R8R059BDP1@D500=CDe06YZJP1IFET0O7al
09BDU01gMgL0@41007inOP2h^;P0WYjN03hn?P13@d<0QHF504i>CP0K6a/Looooo`0/04e=C@2JVYX0
][Jf04U9B@0V9RH07AdM01`L700J6QX05aLG01TI6@0n?Sh0<S8b096AT@2:RXX0M7Ad02l_;`1^KVh0
7alO01DE5@0D51@04a<C03`l?02<S8`0K6a/03Hf=P2ZZZX0Ng]k09FEU@2JVYX0MgMg08Z:RP26QXH0
EUIF06=SH`2BTY80/k>c0<71`@2YZJT0V9RH04U9B@1FEUH0J6QX04e=C@0E5AD300d=3@0G01<C4`0o
?cl0K6a/04=3@`1TI6@0IfMW06ATI02GUiL0clo?0;2`/02k^k/0W9bL02d];@0^;Rh0>c/k06e]K@1b
LW80Ng]k08F5Q@2;Rh/0PH610:FUY@2j^[X00P36a/H00`1?Cdl04a<C00d=3@0600d=3@0<010@400F
5QH0<S8b02/[:`10@4007QhN09jNWP3Ng]h0Ng]k02HV9P0G5aL061PH0P0E5AD06P16ATH0L71`01/K
6`0O7al0XJ6Q0<k>cP1lO7`0F5QH0=CDe02MWId0BTY:0492@P18B4P0AdM707QhN02GUiL0NWYj01@D
500];Bd0SHf=02HV9P0I6AT05ADE01TI6@0U9BD0Lg=c0P0c<c<0?00P8200:2PX05eMG@0m?Cd0:BTY
01/K6`0[:b/0@410014A4@0E5AD06ATI03hn?P0G5aL0GUiN0;Rh^023Ph<0^[Zj05ADE00V9RH09bLW
01dM7@0K6a/05QHF01DE5@0G5aL06a/K04M7A`0P8200LW9b07=cL`20P800X:2P0;>c/`3EeMD0c<c<
0;Rh^030`<00[jn_0:f][@0k>c/05QHF01LG5`0L71`0<S8b05=CD`1`L700GemO05EEE@1MGEd0EeMG
07UiN@1[Jf/0820P01hN7P0b<S80OWin034a<@0K6a/05aLG01DE5@8061PH0300=3@d0:FUY@35aLD0
Hf=S0:BTY01?Cdl0<C4a08>3P`2LW9`0BTY:01LG5`0Q8B40LG5a04Q8B00O7al08b<S02/[:`0c<c<0
@T92065QH@2TY:@0alO70;fm_@2<S8`0NWYj069RHP3:b/X0W9bL02l_;`0V9RH06ATI01DE5@1EEED0
61PH01DE5@0D51@04a<C01dM7@1KFe/0K6a/07alO02WYjL0_;bl0>;RhP3Ng]h0emOG0<?3``3EeMD2
02`/;00P05ADE00O7al04a<C01DE5@0F5QH0De=C08f=S@24Q8@0@d=305eMG@2WYjL0IFEU07=cL`0_
;bl06a/K02<S8`0a<C40YJFU0;Bd]02CTi<0N7Qh03Ti>@0d=3@0LG5a0492@P2?Shl0ZJVY0451@@1^
KVh0VIVI04a<C00Q8B4301`L700D028R8P1EEED0EeMG04I6AP0f=SH0HF5Q03@d=00Q8B40<S8b08j>
SP3Jf]X0e=CD0;Zj^P2/[:`0T92@0:RXZ030`<00_;bl0:n_[`2KVi/Aooooo`003oooool0M`3<c<`0
MgMg05]KF`1TI6@0R8R80820P01`L700MgMg03Xj>P12@T80RXZ:09BDU01CDe<0Kfm_06=SH`1oOgl0
@d=306ATI011@D40FUYJ0861P@12@T80;Rh^05MGE`0m?Cd0IFEU07emO@0S8b<0DE5A0451@@0m?Cd0
Ti>C06EUI@0h>3P0IVIV03/k>`1gMgL0PH6103Ti>@0W9bL0<c<c04i>CP0Q8B40=3@d02@T901BDU80
QHF504e=C@0m?Cd0G5aL04A4A01WIfL0HV9R03De=@1lO7`0BTY:030`<01RHV80?clo02`/;018B4P0
G5aL04];B`2HV9P0BTY:02PX:00R8R80A4A405iNGP11@D40G5aL06=SH`0/;2`0E5AD03`l?01`L700
Cdm?030`<01]KFd0QHF503hn?P1iNGT0Shn?03`l?01@D500S8b<02TY:@1KFe/0KFe]08R8R01NGUh0
?Cdm059BDP1JFUX0@d=304i>CP1gMgL0F5QH03@d=01mOGd0:RXZ06=SH`1TI6@0@T9206UYJ@2IVIT0
E5AD03hn?P1[Jf/0EEEE051@D01YJFT0@d=307UiN@0d=3@0FEUI07AdM010@400O7al0080ADE502X0
GemO05iNGP0h>3P0Kfm_03<c<`1HF5P0CTi>06a/K01MGEd0C4a<07IfMP1@D500GemO02`/;01?Cdl0
QXJ606EUI@0c<c<0N7Qh04Y:BP1jNWX0Fe]K03/k>`0i>CT0H61P02d];@0e=CD0B4Q805EEE@28R8P0
De=C0451@@0_;bl0QHF5059BDP0l?3`0QhN705aLG027QhL0Ph>308J6QP2JVYX204Y:BP1m061PH02a
/K40PH610410@02KVi/0A4A404=3@`2^[Zh0YJFU06YZJP0j>SX0OWin092@T01:BTX0_kno08N7Q`1?
Cdl0^[Zj0820P014A4@0FEUI071`L011@D40E5AD02h^;P1JFUX0PX:203dm?@1nOWh0QhN706UYJ@2G
UiL0V9RH03hn?P1kNg/0:b/[04a<C01mOGd0@d=305YJFP1gMgL0DE5A05iNGP0/;2`0MgMg08:2PP1k
Ng/0DU9B071`L01VIVH0SXj>02`/;01DE5@0CDe=038b<P1PH600@41002TY:@1PH600UiNG06MWI`0_
;bl0TI6A055AD@0c<c<0Shn?08F5Q@1FEUH0C4a<05ADE01/K6`0ADE507inOP16ATH0@d=306=SH`0h
>3P06ATI06YZJP0`<300;Bd]07IfMP1@D500CDe=05aLG01gMgL0@T92028R8P1DE5@0JVYZ03@d=00c
<c<0T92@051@D00h>3P0M7Ad0:VYZ@1_Kfl092@T08V9R@1eMGD0<S8b06=SH`1XJ6P0>CTi065QH@0l
?3`0<c<c05ADE01EEED0@D5105QHF017AdL0QhN709:BTP26QXH0>SXj02d];@1;Bd/0MWIf03lo?`0k
>c/0L71`065QH@0l?3`07?ooool06P1_Kfl0dM7A0<o?c`2QXJ40H61P03Hf=P0R8R807AdM02<S8`1<
C4`0Ng]k0:^[Z`3Cdm<0c/k>09^KV`13@d<0De=C06YZJP0g=cL0?Shn051@D01=CDd0Vi^K09bLW02<
S8`0C4a<0P0E5AD0;`15ADD0UiNG0=3@d035aLD0[jn_05YJFP18B4P0NGUi08R8R02f][H0dM7A0;Jf
]P1FEUH05ADE00`<300C4a<03Ph>00d=3@0B4Q806ATI05]KF`2QXJ40XZ:R09JFUP1lO7`0?3`l07em
O@2SXj<0CTi>03Lg=`1eMGD061PH00X:2P0=3@d06a/K024Q8@0Z:RX0>c/k05IFEP1XJ6P0]kNg0:n_
[`0l?3`092@T04=3@`0a<C403Ph>00<03@d=0`0>3Ph0<P0A4A405QHF02PX:00m?Cd0<C4a03Lg=`2j
^[X0]kNg02h^;P0G5aL06QXJ01DE5@0F5QH0>CTi0:VYZ@0h>3P08b<S02PX:02GUiL0GemO06QXJ00d
=3@0YjNW02`/;01SHf<0C4a<024Q8@0`<300I6AT09nOW`2NWYh0;2`/03@d=02IVIT0:RXZ02`/;01S
Hf<0M7Ad07=cL`2NWYh0PX:204Q8B00b<S80=3@d0451@@0F5QH06ATI02@T9013@d<0;Bd]0P0C4a<0
2`0E5AD09bLW03Xj>P17AdL0MGEe03`l?01dM7@0^;Rh0492@P0g=cL0:BTY0080:b/[02@071`L01dM
7@0P8200Cdm?0451@@0g=cL0<C4a03Ti>@0o?cl0AdM706][J`3AdM40b/[:0:n_[`2GUiL0UIFE0:BT
Y01KFe/0P82007emO@1eMGD0GEeM05ADE012@T80820P01`L700M7Ad0Hf=S096AT@0O7al07QhN024Q
8@1]KFd0Ogmo01/K6`0L71`301DE5@0d01/K6`18B4P0dM7A0<71`@20P8007alO05QHF025QHD0`<30
07alO01[Jf/0ZJVY0>OWi`3>c/h0/K6a0;Bd]02PX:00T92@08V9R@22PX80IVIV04];B`2>SXh0UIFE
05eMG@0R8R80Hf=S0;Bd]01RHV809bLW01`L700M7Ad0FEUI01DE5@0K6a/04a<C01DE5@0`<300Ph>3
0:^[Z`1hN7P0W9bL0<S8b02RXZ80TY:B0:VYZ@3Rh^80g]kN05QHF01VIVH07alO01HF5P805ADE01l0
5aLG05=CD`1^KVh0I6AT04M7A`1kNg/0F5QH03dm?@2GUiL0?Cdm04=3@`1JFUX0PH6108Z:RP2_[jl0
Y:BT0:JVYP2IVIT0V9RH07QhN00o?cl0OWin0<W9b@1UIFD0De=C05aLG01JFUX08B4Q01XJ6P0G5aL0
7AdM0080A4A40180EUIF03hn?P0^;Rh0CDe=065QH@0T92@0;Bd]05YJFP2e]KD0H61P065QH@1TI6@0
6QXJ03Ph>02g]kL0EeMG0492@P19BDTAooooo`003oooool0CP2IVIT0Fe]K05YJFP1ZJVX0Jf][079b
LP1RHV80OGem07=cL`10@400M7Ad09RHV01FEUH0NGUi05EEE@20P800ATI604E5A@0N7Qh0Fe]K08F5
Q@1TI6@0@41005UIF@0V9RH0=cLg06MWI`0P8200BTY:03Lg=`0c<c<0L71`06EUI@0m?Cd0EUIF030`
<00o?cl0DE5A03Hf=P0Q8B40>c/k05QHF00Y:BT0=CDe02TY:@0W9bL0?Shn04a<C00c<c<0A4A402d]
;@1WIfL0KFe]04=3@`28R8P0<C4a06UYJ@2DU9@0J6QX03/k>`1?Cdl0CDe=04a<C02n_[h0IfMW05QH
F00R8R80F5QH04Y:BP0`<300MgMg08R8R015ADD0B4Q802PX:01^KVh0G5aL05IFEP80Ng]k03@0;bl_
06UYJ@1mOGd0=SHf04];B`2>SXh07QhN03/k>`0l?3`0TI6A05MGE`0l?3`0EUIF04e=C@18B4P0DU9B
069RHP0m?Cd0>CTi08V9R@0^;Rh0GemO061PH00e=CD0>CTi07moO`18B4P0@41005MGE`1NGUh0BDU9
055AD@0g=cL0MWIf03`l?01FEUH0LW9b04Y:BP1TI6@0ADE505EEE@1SHf<0EeMG03hn?P1]KFd0Cdm?
07MgM`12@T80KFe]05iNGP1ADE40LG5a0P1DE5@0A@0o?cl0Ng]k08R8R01ADE40:RXZ06i^KP17AdL0
SHf=04e=C@0m?Cd0?Shn04i>CP0i>CT0?clo04a<C01?Cdl0QHF504];B`1IFET07alO07QhN00b<S80
<c<c06e]K@0o?cl0GUiN071`L027QhL0O7al03lo?`0h>3P0I6AT0:NWY`29RHT0=3@d09BDU01CDe<0
@41005eMG@2@T900I6AT03Xj>P1lO7`0RHV905iNGP2WYjL0R8R804];B`2f][H0Vi^K05=CD`1iNGT0
W9bL04I6AP14A4@05ADE02l_;`1[Jf/0>3Ph07IfMP1VIVH0?clo07IfMP1UIFD0=3@d07alO00R8R80
;2`/06QXJ00204U9B@0g06MWI`1CDe<0IFEU02l_;`1;Bd/0ATI608J6QP1LG5`0Q8B4065QH@21PH40
?Cdm06UYJ@1ADE40;bl_05ADE01?Cdl0A4A409>CT`2h^;P0O7al04=3@`2EUID0EeMG03Lg=`22PX80
QhN705aLG01<C4`0GUiN06UYJ@13@d<0R8R806ATI01>CTh0J6QX04Q8B00Z:RX0OWin03Ph>00V9RH0
OWin061PH01UIFD0KFe]07MgM`12@T806a/K05MGE`1SHf<08R8R03Hf=P2BTY80Hf=S05]KF`020;6a
/@0L071`L00a<C40V9RH061PH00^;Rh0KFe]07MgM`0m?Cd0HF5Q04m?C`0k>c/0L71`06i^KP10@400
ADE503<c<`22PX80`<3006UYJ@1CDe<0?clo05UIF@2<S8`0@41003dm?@1SHf<0Ogmo04e=CAcooooo
02`0]KFe0<k>cP3:b/X0Xj>S06UYJ@1NGUh0Fe]K05YJFP1NGUh0CTi>06YZJP2k^k/0dM7A08n?S`31
`L40/[:b0:NWY`3:b/X0NGUi059BDP16ATH0>CTi03<c<`1EEED0^[Zj05YJFP0h>3P0;bl_01`L700M
7Ad0RXZ:0<W9b@29RHT0I6AT06EUI@2@T900ZJVY09fMW@3GemL0Shn?04M7A`14A4@0=SHf024Q8@80
3Ph>01h05ADE02/[:`20P800ZJVY07alO01XJ6P0Lg=c04I6AP27QhL0CDe=03/k>`0M7Ad0De=C04i>
CP0B4Q803Ph>00d=3@0@41007AdM02DU9@0N7Qh07alO055AD@1hN7P0?clo01DE5@0a<C40DU9B014A
4@0@410200h>3P0d00d=3@0>3Ph03@d=00d=3@0D51@08B4Q03Hf=P1EEED0Hf=S0<G5a@2[Zj/0H61P
02PX:00U9BD0EEEE08j>SP2g]kL0][Jf03hn?P0^;Rh0@T920:NWY`1:BTX0XJ6Q0451@@1ZJVX04a<C
01@D500l?3`0C4a<02`/;00];Bd0MGEe06UYJ@2CTi<0^[Zj0<[:bP2VYZH0Y:BT05=CD`0g=cL0=SHf
06m_K`1DE5@0T92@07YjNP22PX80=CDe01dM7@0V9RH0=3@d05eMG@804A4A04<051@D01<C4`0E5AD0
>c/k03lo?`1kNg/0Bd];0451@@37alL0XJ6Q06EUI@1GEeL0PH6109^KV`10@400AdM708N7Q`1MGEd0
Bd];01`L700G5aL08b<S03<c<`15ADD0GUiN0;Ng]`2PX:00YjNW08V9R@2FUYH0f=SH0;Rh^01iNGT0
O7al08Z:RP1lO7`0GEeM04Q8B017AdL0=cLg03<c<`1IFET0VYZJ04e=C@0P82008B4Q05ADE02m_Kd0
<30`01hN7P0K6a/071`L02/[:`1?Cdl0AdM70:2PX03:b/X0?clo04i>CP1aLG40?Shn075aL@3Jf]X0
a/K60=GEe@3Bd]80XZ:R0080BDU905T0ATI604=3@`14A4@0BDU906UYJ@2o_kl0i>CT096AT@0Z:RX0
8B4Q02d];@2n_[h0RHV902h^;P0O7al0<30`061PH00M7Ad0;Bd]01@D500E5AD07QhN02/[:`1@D500
e]KF0<S8b031`L40UIFE0:JVYP3AdM40g=cL0;:b/P2EUID0EEEE04=3@`0H61P04a<C01DE5@0F5QH0
FUYJ05EEE@1RHV80De=C061PH00l?3`0F5QH08F5Q@19BDT0C4a<04M7A`10@400ATI608f=S@24Q8@0
T92@07YjNP1QHF40/K6a06e]K@1aLG40a/K609fMW@1IFET0BDU905mOG`1FEUH0:BTY01TI6@0k>c/0
?Shn04];B`1EEED0Bd];02XZ:P0o?cl0VYZJ030`<00m?Cd0N7Qh0=?Cd`1RHV80GEeM06MWI`0/;2`0
C4a<06IVIP0Z:RX0AdM704U9B@0Aooooo`003oooool0P033`l<0KFe]05EEE@2ATI40MWIf08B4Q01M
GEd0Ng]k0;6a/@1<C4`0Lg=c09nOW`1HF5P0S8b<05YJFP2;Rh/0>CTi05IFEP14A4@0EEEE09RHV01_
Kfl0>c/k07=cL`1OGel0=3@d07emO@0M7Ad0>CTi055AD@1LG5`0PX:207MgM`0o?cl0RHV905EEE@1>
CTh0E5AD030`<00N7Qh0C4a<059BDP0P8200=SHf02LW9`0g=cL0CTi>04E5A@0];Bd0ATI60410@01:
BTX0M7Ad0451@@2@T900@D5103<c<`1VIVH0FEUI03@d=01=CDd0DE5A03`l?01fMWH0CDe=03Hf=P0S
8b<0AdM704e=C@0h>3P0IfMW06i^KP13@d<0@41003Ph>01eMGD0@d=306UYJ@1mOGd0Q8B4051@D01D
E5@0MGEe038b<P14A4@0TY:B03Lg=`1DE5@0AdM709JFUP1IFET0?3`l06IVIP1^KVh0I6AT059BDP1P
H600>SXj03dm?@2@T900=SHf06QXJ01LG5`0CTi>05YJFP2CTi<0ATI60492@P1LG5`0IfMW055AD@18
B4P0;Bd]06m_K`0d=3@0H61P06][J`15ADD0FEUI04M7A`1BDU80H61P06IVIP12@T80MWIf05QHF028
R8P0DU9B0P1XJ6P07@1NGUh0PX:205iNGP1BDU80EeMG07inOP2@T900HF5Q02PX:01_Kfl0CTi>09ZJ
VP1WIfL0>c/k04Y:BP1NGUh0GEeM04I6AP1?Cdl0IVIV07inOP1DE5@0M7Ad02XZ:P1eMGD0@41002h^
;P1jNWX0HF5Q0080Ng]k0840O7al0861P@1YJFT0Fe]K04e=C@2JVYX0Hf=S03Ph>02@T900Kfm_04];
B`1gMgL0U9BD05aLG00h>3P0L71`096AT@1JFUX0WinO08>3P`1ADE40^k^k08^;R`1CDe<0O7al0:VY
Z@14A4@0?clo01XJ6P0a<C40HF5Q03@d=01hN7P0GemO03hn?P2WYjL0IVIV034a<@1hN7P092@T03<c
<`1TI6@092@T03hn?P1EEED0GUiN069RHP0j>SX0FUYJ04U9B@1[Jf/0Hf=S08b<S01MGEd0TY:B059B
DP1cLg<0EeMG02PX:01?Cdl0=cLg04=3@`1fMWH0/K6a07inOP1@D500U9BD04I6AP0j>SX0RHV907in
OP1NGUh0TY:B09FEU@1dM7@0@D5108j>SP14A4@0@41006m_K`1<C4`0;Bd]09BDU01<C4`0;2`/08R8
R01PH600Ti>C06e]K@1dM7@0>c/k02`/;025QHD0PH6104i>CP0e=CD0H61P02LW9`1EEED0Shn?09JF
UP1MGEd0>CTi0::RXP0Y:BT0<C4a08Z:RP1XJ6P0GEeM09nOW`1:BTX0:BTY07IfMP1jNWX0E5AD07Ad
M00X:2P0M7Ad0;jn_P1dM7@0FEUI05MGE`20P800[Jf]05MGE`1RHV80Z:RX07moO`0h>3P07?ooool0
?P26QXH0C4a<05IFEP2OWil0Zj^[06QXJ01=CDd0CTi>09RHV033`l<0B4Q802HV9P1cLg<0`l?30;Rh
^03=cLd0/K6a0<c<c02XZ:P0GEeM051@D01?Cdl0Ng]k08j>SP2OWil0Lg=c09>CT`34a<@0cLg=0:b/
[039bLT0gMgM0<C4a02a/K40/;2`0;Fe]@31`L40cLg=0=KFeP2n_[h0H61P01/K6`0J6QX07QhN014A
4@0Q8B40DE5A08B4Q02NWYh0];Bd0;fm_@2>SXh0Ogmo01hN7P0T92@0AdM703/k>`0L71`0;Rh^06=S
H`0I6AT0410@0`0>3Ph0300R8R80:b/[02LW9`1IFET0@41007QhN00j>SX0ATI6059BDP0_;bl071`L
01<C4`<04A4A03@0410@00h>3P0>3Ph0410@02l_;`1NGUh0];Bd0=CDe02OWil0PX:208J6QP2DU9@0
ZZZZ07=cL`1CDe<0Xj>S0:VYZ@2BTY80N7Qh0820P01gMgL0b/[:09ZJVP1mOGd0:b/[01lO7`0L71`0
8B4Q04Q8B015ADD0De=C0451@@0Z:RX0MgMg0>7Qh@3>c/h0O7al06][J`1^KVh0RHV90;2`/01hN7P0
SHf=09RHV02b/[80OWin04Q8B00i>CT0H61P02PX:00D51@04a<C0`0E5AD01`0[:b/0Bd];05MGE`1E
EED0DU9B09NGU`3Lg=`00P31`L402@3Bd]80];Bd07YjNP2IVIT0`l?305eMG@1=CDd06ATI01DE5@02
01TI6@1/028R8P1ADE40S8b<05mOG`25QHD0V9RH0=7Ad@3>c/h0aLG509>CT`1`L700DE5A03<c<`0M
7Ad061PH01/K6`0P8200:BTY02LW9`1NGUh0YJFU01hN7P0T92@0E5AD09VIV@2MWId09BDU02XZ:P1U
IFD0JVYZ034a<@0d=3@0EeMG0;bl_02KVi/0NGUi0451@@0^;Rh0R8R80=gMg@3QhN40MWIf0492@P2]
[Jd0DE5A04m?C`19BDT0DU9B069RHP26QXH0][Jf0>GUi@3Ogml0MWIf028R8P0P82008b<S08J6QP2_
[jl0GEeM02PX:00j>SX0K6a/01/K6`0L71`06ATI038b<P0S8b<09bLW07QhN02c/k<0i^KV09FEU@33
`l<0a<C40<71`@1JFUX0OWin0:RXZ01oOgl0DU9B03Ti>@0G5aL05ADE01PH601`L700Cdm?07MgM`1A
DE40DU9B02l_;`1^KVh0:b/[01XJ6P0R8R80:b/[03Ph>01YJFT0UIFE08J6QP2LW9`0M7Ad04e=C@2?
Shl0_kno0:f][@38b<P0QHF50P1dM7@06@1BDU80BTY:059BDP1SHf<0@41001hN7P0`<300ADE505aL
G01BDU80WIfM0<G5a@2BTY80K6a/0;>c/`24Q8@0Ti>C05ADE01JFUX0IVIV07emO@13@d<0CTi>06EU
I@1dM7@04Oooool000oooooo08h0c<c<06IVIP1EEED0SXj>07inOP22PX80Ogmo0::RXP2c/k<0C4a<
071`L02RXZ80G5aL09:BTP1QHF40SXj>03@d=01PH600?3`l07YjNP2RXZ80GemO0492@P23Ph<0JFUY
03dm?@1iNGT06ATI04E5A@1XJ6P0GEeM08R8R01cLg<0AdM708^;R`1@D500EEEE05=CD`0e=CD08R8R
05EEE@1CDe<09BDU03Xj>P0_;bl0?clo04];B`1=CDd0:RXZ059BDP14A4@0F5QH07AdM012@T80Ti>C
04Q8B00l?3`0KFe]05]KF`0_;bl0AdM705eMG@19BDT0P82003<c<`0W9bL0820P04U9B@1BDU80@d=3
07QhN01ZJVX0@D510492@P0j>SX0N7Qh03Lg=`1SHf<0Rh^;06a/K011@D40FEUI06i^KP0];Bd0AdM7
08R8R00[:b/0EeMG04Y:BP1oOgl0=CDe03`l?01EEED0KFe]0451@@1>CTh0MWIf01dM7@1^KVh0Ti>C
03Ph>01GEeL0Y:BT05YJFP1RHV80QXJ604A4A01EEED0MWIf06m_K`1EEED0CDe=03/k>`1nOWh0@d=3
05mOG`1TI6@0=cLg07UiN@1VIVH0De=C06YZJP1>CTh0DU9B09^KV`1CDe<0Q8B404A4A02ATI40RHV9
05aLG01]KFd0F5QH08F5Q@1ZJVX0R8R808J6QP1@D500;2`/09RHV01WIfL0X:2P0P0h>3P0:@1XJ6P0
X:2P0820P016ATH0DE5A04];B`2CTi<0]kNg08f=S@0X:2P0QhN70451@@0k>c/0Shn?069RHP1iNGT0
IfMW08J6QP2@T900ATI607UiN@1FEUH0SXj>04e=C@16ATH0Rh^;069RHP1ADE40M7Ad08f=S@0];Bd0
ADE50;Jf]P2NWYh0Hf=S0::RXP11@D40GEeM0<W9b@2NWYh0LW9b0080^k^k06L0?Cdm065QH@0^;Rh0
<c<c06ATI00m?Cd0[Zj^0861P@1EEED0Z:RX07moO`0f=SH0Ogmo03De=@0g=cL0LG5a01LG5`1SHf<0
T92@0:2PX01VIVH0;bl_06EUI@1>CTh0BDU903`l?02CTi<0UiNG08b<S00o?cl0KFe]061PH00g=cL0
Ogmo06UYJ@1?Cdl0L71`0:f][@0R8R80@T9208b<S01RHV80?Shn0:BTY01bLW80<S8b05QHF024Q8@0
Jf][0451@@2XZ:P0=3@d03<c<`28R8P0KVi^02XZ:P2VYZH071`L03De=@2KVi/0Fe]K08J6QP2JVYX0
NGUi01dM7@0T92@0Jf][0820P01BDU80JFUY09:BTP17AdL0E5AD08b<S01JFUX06a/K04m?C`1jNWX0
HV9R02h^;P1LG5`04a<C03Lg=`1cLg<0I6AT03@d=01VIVH0DE5A03<c<`1dM7@0D51@07inOP3?cll0
FUYJ01lO7`0l?3`0JVYZ08N7Q`16ATH0<C4a06UYJ@0i>CT05aLG01cooooo0140QhN70:b/[02:RXX0
DU9B08B4Q02>SXh0FUYJ06a/K01]KFd0UIFE07=cL`0_;bl0?Cdm0<k>cP3De=@0dm?C09jNWP020<K6
aP1U09jNWP24Q8@0Lg=c0410@00c<c<0;Rh^08>3P`2k^k/0c/k>0>WYj@3Ogml0Vi^K0:^[Z`35aLD0
V9RH07]kN`2DU9@0YZJV0<71`@2n_[h0Ogmo08n?S`1hN7P0AdM7059BDP2>SXh0Ph>3069RHP1VIVH0
YZJV08Z:RP1oOgl0R8R803`l?00Q8B405aLG05EEE@10@400:b/[02PX:00c<c<0B4Q8010@400=3@d0
3Ph>00d=3@0>3Ph071`L02@T901gMgL0@d=306YZJP1kNg/0YJFU0<K6aP2TY:@0NWYj06a/K01]KFd0
K6a/06e]K@1/K6`0EeMG03/k>`0_;bl0OWin0<S8b02_[jl0g=cL0:b/[02TY:@0b/[:05QHF00M7Ad0
71`L020P800^;Rh0IVIV06ATI02][Jd0NWYj0;Rh^00m?Cd0FUYJ06MWI`1dM7@0Vi^K05mOG`0i>CT0
9BDU04I6AP1PH600EEEE02PX:01YJFT0c/k>0:f][@2=SHd0QXJ608j>SP29RHT00P2LW9`0:`2HV9P0
a<C40;fm_@2KVi/0]kNg0;bl_02;Rh/05aLG018B4P0@41004Q8B01DE5@0G5aL0DU9B06YZJP0j>SX0
K6a/065QH@2ATI40WIfM071`L029RHT0bLW90::RXP37alL0fm_K0<30`01WIfL0B4Q801TI6@0G5aL0
71`L01hN7P0O7al0<c<c07IfMP0l?3`0F5QH04=3@`1_Kfl0Hf=S03Ph>00H61P0100E5AD0CP0D51@0
5ADE01DE5@0E5AD05QHF02h^;P2ATI40E5AD02@T901GEeL0QHF50=KFeP2^[Zh0ZZZZ06QXJ00e=CD0
>SXj06QXJ01RHV80SHf=0=OGe`2ATI40UYJF0<30`03WinL0h>3P0::RXP1/K6`0@d=309nOW`1gMgL0
KVi^07=cL`26QXH0/K6a0>3Ph036a/H0TY:B09fMW@2g]kL0SHf=024Q8@0N7Qh0CDe=0;>c/`2m_Kd0
Bd];0492@P1dM7@07AdM01`L700O7al0EeMG02PX:01WIfL0Zj^[06MWI`3Ogml0c<c<0=SHf03EeMD0
IfMW08B4Q03;bl/0;2`/03Ti>@1bLW80DE5A04A4A00Z:RX08R8R07inOP1NGUh0VIVI06EUI@11@D40
C4a<06EUI@8071`L02T07QhN028R8P0R8R80<S8b06m_K`2ATI40N7Qh08j>SP1OGel0I6AT096AT@3<
c<`0Ph>305=CD`1lO7`0XJ6Q06EUI@12@T80C4a<07YjNP1EEED0?3`l05MGE`2:RXX0Y:BT0<71`@2T
Y:@0e=CD0=[JfP3@d=00/k>c04A4A01aLG40WYjN08F5Q@1gMgL0Ti>C07YjNP1lO7`0HF5Q05eMG@0A
ooooo`003oooool0j038b<P0GemO07inOP20P800JVYZ04];B`1YJFT0PH6109FEU@15ADD0Fe]K05eM
G@1SHf<0Xj>S06UYJ@25QHD0>CTi06][J`0l?3`0Q8B4071`L011@D40HV9R08Z:RP1PH600C4a<04=3
@`0S8b<0PX:2071`L01NGUh0M7Ad0492@P1XJ6P0S8b<05IFEP1OGel0ADE502l_;`0n?Sh0GemO034a
<@0Y:BT0GemO03`l?017AdL0C4a<02LW9`19BDT0GUiN03Ti>@1HF5P0B4Q804U9B@2JVYX0BTY:03Ph
>01[Jf/0C4a<04Y:BP25QHD0QhN704i>CP2CTi<0>CTi01dM7@1?Cdl0NWYj05iNGP10@400M7Ad06a/
K019BDT0FUYJ0410@01mOGd0>3Ph05eMG@2CTi<0KFe]03dm?@1NGUh0JFUY03Ph>024Q8@0SXj>034a
<@1CDe<0AdM708R8R00/;2`0=SHf04];B`11@D40=CDe05MGE`1EEED0@D5106e]K@1nOWh0;2`/03hn
?P1ZJVX0H61P05]KF`1mOGd0:BTY06e]K@1kNg/0GemO05=CD`17AdL0<C4a0861P@0n?Sh0Hf=S04U9
B@0Q8B40KFe]06=SH`1>CTh0KFe]04=3@`0m?Cd0NWYj04U9B@1eMGD0:BTY05MGE`1[Jf/0J6QX0492
@P0k>c/0LG5a055AD@25QHD0X:2P034a<@0Z:RX0SHf=069RHP2^[Zh0;bl_02h^;P0l?3`0KVi^04Q8
B01KFe/0Rh^;02l_;`1;Bd/0N7Qh06e]K@0X:2P0TI6A01HF5P1NGUh0XJ6Q06EUI@1dM7@04a<C07If
MP2CTi<0JVYZ05MGE`1CDe<0UIFE03Lg=`1;Bd/0YZJV09BDU01EEED0VYZJ0:6QX@0X:2P0;Bd]06a/
K01iNGT0BTY:0;bl_01eMGD0>c/k09NGU`12@T80<S8b08j>SP2b/[80<C4a05MGE`17AdL0BTY:06=S
H`0d=3@0UiNG08Z:RP1?Cdl0];Bd08^;R`0];Bd0Jf][02TY:@1=CDd0N7Qh024Q8@0j>SX0D51@07Ee
M@1RHV80=SHf061PH01:BTX0BDU901TI6@1KFe/0Kfm_08N7Q`14A4@0Kfm_02/[:`0R8R80HF5Q05]K
F`0o?cl0JVYZ0:VYZ@1dM7@0K6a/07inOP1`L700EUIF0<71`@2;Rh/205iNGP0h05eMG@18B4P0F5QH
09nOW`1=CDd0?Cdm06QXJ00o?cl0?3`l0:ZZZP0m?Cd0=CDe075aL@0k>c/0WIfM0<?3``2YZJT0B4Q8
01XJ6P1VIVH0J6QX01DE5@0o?cl0N7Qh04A4A01YJFT0/k>c07=cL`0`<300=3@d07YjNP1/K6`0<30`
05ADE01JFUX0>c/k071`L01:BTX0>3Ph07AdM01@D500?Shn06][J`14A4@0MGEe0<c<c01gMgL0@410
03`l?01@D500MWIf04I6AP10@400WinO06][J`0/;2`Looooo`0n0=cLg02m_Kd0V9RH06UYJ@1=CDd0
IVIV0:6QX@1nOWh0HF5Q04m?C`24Q8@0]KFe0;Vi^@2j^[X0_;bl07MgM`1nOWh0^;Rh0;no_`1`L700
Hf=S05ADE00_;bl0820P01hN7P0Y:BT0Vi^K0=WIf@3Kfm/0cLg=0;Rh^02/[:`0b/[:08j>SP1hN7P0
K6a/061PH01UIFD0N7Qh04];B`12@T80QhN70;^k^`3;bl/0SXj>065QH@1mOGd0]kNg09JFUP1GEeL0
De=C07AdM01:BTX0:RXZ02l_;`22PX80ADE503/k>`0T92@08B4Q04U9B@0[:b/400h>3P1901PH601?
Cdl0RHV905UIF@1;Bd/0b<S808J6QP1nOWh0Vi^K04a<C00e=CD08R8R03De=@0n?Sh0AdM7051@D02;
Rh/0YJFU09^KV`3Hf=P0gmoO0>;RhP2IVIT0ZZZZ08>3P`16ATH0>3Ph02LW9`0T92@07alO02`/;01G
EeL0UYJF0:ZZZP2c/k<0BTY:030`<00e=CD04a<C02TY:@1XJ6P0Shn?08Z:RP1KFe/0F5QH07inOP1>
CTh0UYJF08N7Q`1^KVh0?Shn0492@P17AdL0MWIf06e]K@1mOGd0QhN708:2PP2RXZ80Y:BT0:VYZ@1U
IFD0De=C04U9B@0B4Q804A4A01<C4`0A4A40<30`07EeM@1/K6`0FUYJ08b<S0020:BTY00G04U9B@1N
GUh0NGUi05UIF@1@D500FUYJ0:j^[P2NWYh0L71`04E5A@0J6QX06a/K01dM7@0O7al0=cLg03De=@22
PX80;Bd]03@d=01CDe<0KFe]05ADE00I6AT00`0E5AD00`0C4a<051@D01@D500301DE5@1<01PH600Q
8B40CDe=0;Zj^P0i>CT0HF5Q0<g=c@3Hf=P0eMGE071`L01RHV80MgMg07emO@1@D500;Rh^09ZJVP3M
gMd0M7Ad04M7A`0c<c<0S8b<0:^[Z`2c/k<0b<S80:^[Z`27QhL09RHV01HF5P0H61P06ATI03<c<`2D
U9@0>CTi06a/K01HF5P0G5aL0;2`/01ZJVX0:RXZ02h^;P1lO7`0d=3@08n?S`1JFUX0OWin01dM7@0V
9RH0HF5Q09JFUP2EUID0cLg=08V9R@1bLW80b/[:0=GEe@2n_[h0ADE506IVIP0f=SH0FEUI02HV9P0J
6QX07AdM06MWI`15ADD0@d=307alO02KVi/0Shn?09^KV`1XJ6P0C4a<08B4Q00i>CT06a/K01`L7080
7AdM00P08R8R02LW9`1BDU80YZJV075aL@2<S8`0@41004e=C@80YZJV01T0OWin03Ti>@18B4P0N7Qh
0=WIf@3>c/h0aLG50<K6aP2j^[X0WYjN09:BTP2LW9`0WinO07IfMP21PH40dm?C0>CTi03Kfm/0e]KF
08J6QP2;Rh/0f][J0=3@d03Kfm/0S8b<0080@41000<0EEEE0861POooool04?ooool000oooooo01D0
e=CD05EEE@1IFET0Ogmo09:BTP25QHD0M7Ad08^;R`2[Zj/0AdM707IfMP26QXH0CTi>07EeM@1SHf<0
Kfm_06a/K02BTY80=CDe08Z:RP1cLg<00P10@400P@2=SHd0J6QX075aL@1ADE405aLG04];B`1BDU80
M7Ad092@T00k>c/0@41003Xj>P19BDT0PH6106a/K00e=CD061PH059BDP1JFUX08R8R03De=@0H61P0
Fe]K07MgM`0m?Cd0;bl_03lo?`0m?Cd0VYZJ05aLG00a<C40N7Qh03/k>`1>CTh0N7Qh02h^;P0W9bL0
BDU905iNGP17AdL0Y:BT0451@@0[:b/07QhN04e=C@1TI6@0>SXj08N7Q`1`L700;Bd]04m?C`0f=SH0
Kfm_03<c<`0];Bd0IfMW07emO@0l?3`0GUiN06MWI`0Q8B40BDU907inOP0e=CD0DE5A05UIF@1eMGD0
DU9B03dm?@1GEeL092@T02l_;`21PH40IVIV04=3@`22PX80NGUi03Hf=P1EEED0OGem055AD@1]KFd0
PH6103Lg=`1IFET0E5AD05MGE`1TI6@0L71`04=3@`1eMGD0<S8b07alO01fMWH0?Shn07=cL`0W9bL0
G5aL07=cL`1aLG40De=C07=cL`0o?cl0P82004Q8B01PH600<30`071`L01hN7P0HF5Q061PH00N7Qh0
I6AT096AT@1LG5`0;bl_0820P016ATH0UYJF05MGE`0n?Sh0B4Q806a/K00M7Ad0<c<c05aLG01HF5P0
H61P05ADE00203lo?`1S0:6QX@0n?Sh0>CTi07UiN@11@D40S8b<04a<C01]KFd0JVYZ03`l?01aLG40
TY:B0:VYZ@1KFe/0>SXj07emO@11@D40BDU90820P02KVi/0EeMG03@d=01_Kfl0N7Qh02`/;02ATI40
OGem04i>CP29RHT0I6AT04=3@`1FEUH0O7al03Hf=P1FEUH08R8R06m_K`1kNg/0EEEE08j>SP1eMGD0
8b<S06i^KP25QHD0?clo07IfMP0I6AT0GemO08^;R`1<C4`0CDe=05EEE@1JFUX0FEUI04U9B@27QhL0
IVIV0451@@18B4P0PX:205YJFP1gMgL07AdM06e]K@10@400;Bd]061PH010@400?Shn09FEU@2VYZH0
T92@08R8R01HF5P06QXJ06IVIP32`/80TI6A06EUI@1XJ6P0JFUY01`L7010@400TY:B069RHP0l?3`0
Q8B402PX:00m?Cd0Z:RX05QHF00j>SX0Ng]k01TI6@1<C4`0G5aL07AdM00g=cL06a/K0080IFEU00L0
=cLg03dm?@1[Jf/0B4Q807emO@33`l<0Q8B40080?Cdm01X0TI6A06UYJ@0n?Sh0QhN7079bLP1CDe<0
RHV904E5A@0o?cl0[Zj^06MWI`1ADE40NWYj03<c<`1fMWH0d=3@08B4Q01CDe<0EeMG06YZJP2BTY80
C4a<03`l?02c/k<0NWYj03hn?Qcooooo0400P82004m?C`1;Bd/0<C4a02LW9`0S8b<0;bl_06e]K@2G
UiL0TI6A08B4Q033`l<0fMWI09FEU@2e]KD0ZJVY05eMG@2WYjL0@T9202d];@0d=3@0B4Q805IFEP1Q
HF40?clo0492@P2PX:00fMWI0=cLg03Shn<0^[Zj09ZJVP2EUID0a/K60:>SX`2UYJD0KFe]03Ph>00V
9RH0?Cdm051@D01VIVH0ZZZZ0<30`01oOgl0GemO0:^[Z`2NWYh0OGem02LW9`0E5AD03`l?01hN7P15
ADD0L71`08f=S@1EEED0>SXj03<c<`0P82009RHV05IFEP0C4a<04A4A0P0@41002P0h>3P0GEeM0820
P01dM7@0DE5A0;Ng]`1aLG40D51@06a/K00G5aL3010@400d01hN7P0V9RH0;bl_03`l?01ADE40U9BD
0=3@d036a/H0b<S80;Rh^02?Shl0G5aL03/k>`0^;Rh04Q8B01<C4`0L71`05aLG07moO`27QhL0VIVI
061PH00o?cl0=CDe03Hf=P0A4A404a<C01DE5@0I6AT0?3`l08Z:RP2PX:00Ti>C0:FUY@2SXj<0Y:BT
07emO@13@d<0>SXj071`L01;Bd/0;bl_03Ph>01DE5@0MWIf05YJFP1/K6`0Fe]K06][J`0_;bl0;Bd]
03<c<`805ADE01l08B4Q04=3@`23Ph<0Hf=S04m?C`1:BTX0LW9b0:ZZZP2EUID0IVIV02/[:`0R8R80
>SXj04A4A01QHF40WIfM07EeM@11@D407AdM01hN7P0S8b<07AdM03Ph>01KFe/0DE5A04i>CP0[:b/0
Fe]K0861P@1MGEd06a/K00<05ADE00<05aLG01@D500D51@00`0E5AD0:@0F5QH092@T03Ti>@39bLT0
ZZZZ07IfMP2JVYX0[Zj^07YjNP2DU9@0[jn_08N7Q`1/K6`0OGem0861P@2a/K40e=CD06m_K`2=SHd0
W9bL0=[JfP2o_kl0DU9B0<?3``2>SXh0;2`/04i>CP0J6QX061PH020P801KFe/0@41003<c<`2OWil0
<C4a02DU9@1@D500YZJV0:6QX@1;Bd/0AdM70080d];B0280a<C409ZJVP29RHT0Zj^[0;no_`2TY:@0
emOG0;no_`1lO7`0Xj>S069RHP1PH600MGEe01DE5@0G5aL0>CTi02`/;01FEUH07AdM01LG5`0X:2P0
W9bL07QhN02j^[X0`<300<O7a`2YZJT0EeMG07AdM01lO7`08B4Q01`L700M7Ad071`L0P0N7Qh09P0R
8R80@T9207=cL`1aLG40RHV904E5A@1nOWh0VIVI071`L021PH40NWYj03/k>`1EEED0^[Zj08R8R02E
UID0Shn?0;2`/01bLW80Kfm_06][J`20P800[:b/0<k>cP3Shn<0i>CT0=KFeP2f][H0WYjN0=3@d03T
i>@0];Bd0=7Ad@1YJFT0GEeM0861P@2GUiL0SHf=4Oooool000oooooo0300_kno05aLG02;Rh/0Hf=S
07moO`2;Rh/0W9bL0:VYZ@1ADE40GemO0:^[Z`2OWil0IFEU079bLP1oOgl0E5AD03hn?P1ADE40>CTi
09FEU@23Ph<0>SXj05EEE@1PH600;Rh^04m?C`1QHF406QXJ0410@00R8R80?Cdm06UYJ@1MGEd0De=C
05IFEP0d=3@0@41004a<C00[:b/0820P05iNGP1TI6@092@T03/k>`0c<c<0>SXj0492@P0g=cL2034a
<@1a028R8P10@400DE5A03Lg=`1gMgL06a/K04M7A`1[Jf/0C4a<02LW9`1ADE40EUIF03@d=027QhL0
D51@04Q8B00c<c<0H61P059BDP0b<S80OGem08j>SP1@D500@D5103Ph>025QHD0ADE506a/K02ATI40
Ogmo059BDP2@T900VIVI02/[:`1ADE40R8R8028R8P10@400DE5A06MWI`1FEUH0>c/k059BDP14A4@0
:b/[04E5A@1=CDd0AdM707alO01_Kfl092@T05iNGP1TI6@0;Bd]05YJFP2<S8`0?Shn05ADE01nOWh0
;Rh^038b<P1>CTh0@T9207UiN@0W9bL0CDe=061PH00l?3`0Kfm_05EEE@16ATH0GemO07IfMP1JFUX0
PH6104E5A@1cLg<0De=C069RHP1aLG40EUIF071`L01HF5P0HV9R059BDP2LW9`0SHf=04Y:BP0a<C40
OWin04U9B@2JVYX0EeMG059BDP1XJ6P0O7al05aLG00_;bl0J6QX061PH02LW9`0VYZJ05EEE@0L71`0
OGem059BDP10@400MGEe02/[:`1QHF40IfMW09FEU@1aLG400P0n?Sh0D`10@400RXZ:079bLP0i>CT0
Ogmo05mOG`1:BTX0L71`07moO`12@T80=SHf06a/K01`L700A4A40:^[Z`1RHV80Hf=S0:>SX`1]KFd0
EEEE09>CT`2ZZZX0B4Q8061PH00/;2`0:2PX05ADE01:BTX0WinO07AdM01OGel0PX:206QXJ00e=CD0
JFUY02d];@1DE5@0MGEe03Ph>01CDe<0HF5Q06MWI`13@d<0>3Ph07moO`1hN7P0EeMG051@D02ATI40
GUiN0820P00U9BD0Vi^K04=3@`0b<S80Jf][03Ph>015ADD0[Zj^0:6QX@1gMgL0R8R806EUI@0l?3`0
C4a<0;fm_@1[Jf/0DU9B0;^k^`2YZJT0EeMG03Lg=`28R8P0ADE503Lg=`1nOWh0De=C03De=@22PX80
DE5A03lo?`2OWil0C4a<0080PX:202P0Ph>303<c<`0K6a/0Jf][065QH@0n?Sh0ATI6051@D00c<c<0
VIVI0;bl_01JFUX0:b/[055AD@2ATI40>CTi03@d=01OGel0:RXZ04Y:BP22PX80?clo020P801PH600
ADE505=CD`22PX80:2PX06IVIP34a<@0UIFE06EUI@1LG5`0NWYj0;2`/01@D500HF5Q0<30`01nOWh0
@D517?ooool0<P1[Jf/0CTi>0451@@0^;Rh09bLW024Q8@0N7Qh07AdM024Q8@15ADD0[Jf]09NGU`2S
Xj<0HV9R05]KF`1[Jf/0De=C07alO00J6QX051@D014A4@0?3`l0410@01<C4`0o?cl0/;2`09VIV@2X
Z:P0TI6A0<W9b@1eMGD0IFEU06IVIP2EUID0Jf][08:2PP2PX:00][Jf09:BTP1JFUX0>SXj092@T02P
X:00SHf=04i>CP2YZJT0T92@08N7Q`1bLW804a<C0P0>3Ph02`0?3`l06a/K08:2PP2KVi/0N7Qh03/k
>`1:BTX09BDU01/K6`0e=CD07QhN00804a<C02T0;bl_04E5A@18B4P0?clo03`l?01^KVh0UIFE09ZJ
VP1/K6`0@D5101XJ6P0E5AD05aLG02DU9@0g=cL0BDU90451@@0k>c/0BDU908f=S@3EeMD0g]kN09NG
U`2?Shl0][Jf08:2PP1JFUX0D51@055AD@1RHV80MWIf09VIV@2a/K40ZJVY059BDP16ATH0@d=303Lg
=`0m?Cd05ADE01@D500201DE5@0=01<C4`0T92@0AdM707]kN`2o_kl0`L7109jNWP29RHT0>c/k06MW
I`1XJ6P0<30`01/K6`0201DE5@07038b<P1HF5P0K6a/06MWI`1fMWH0?Shn020P800203Ti>@0C03Ph
>018B4P0Bd];08n?S`1/K6`0Hf=S06EUI@2JVYX0O7al05YJFP10@4007AdM01`L700X:2P0?3`l04Y:
BP1lO7`0NWYj0492@P0202XZ:P0;02DU9@0X:2P0D51@02PX:00E5AD0@T9204E5A@1NGUh0LW9b06m_
K`0b<S800P0E5AD0100G5aL05QHF01<C4`0B4Q8201<C4`0L010@400K6a/0820P02l_;`2HV9P0eMGE
0<S8b03Lg=`0X:2P0;Fe]@2c/k<0OGem0::RXP1^KVh0Fe]K05iNGP23Ph<0clo?096AT@28R8P0O7al
0:VYZ@3Ogml0Bd];061PH02;Rh/06ATI06MWI`807AdM0240@d=303Lg=`0K6a/08B4Q08V9R@0N7Qh0
71`L020P8016ATH0/;2`0=[JfP2@T900UIFE0>KViP3>c/h0e]KF09>CT`1[Jf/0QHF50861P@32`/80
]kNg0;6a/@2=SHd0>3Ph04E5A@1jNWX061PH01DE5@0G5aL08B4Q034a<@15ADD00P0G5aL00`0^;Rh0
[:b/0=?Cd`020;no_`060<71`@2ATI40RXZ:04E5A@0K6a/07AdM0P0L71`0:00M7Ad0820P024Q8@11
@D40GEeM071`L024Q8@0G5aL09bLW00c<c<0EeMG06a/K02IVIT0R8R808b<S01OGel0:b/[04Y:BP2]
[Jd0_[jn0<?3``22PX80ZJVY0<[:bP3?cll0aLG509NGU`3Ng]h0eMGE0;2`/01^KVh0PX:20:BTY03<
c<`0i>CT0:j^[P2DU9@0QHF506QXJ01NGUhAooooo`003oooool0702m_Kd0DE5A06e]K@1eMGD0MWIf
05MGE`27QhL0Ti>C07=cL`15ADD0IVIV06EUI@1nOWh0N7Qh05aLG01KFe/0Bd];05UIF@0S8b<0Kfm_
07emO@0e=CD0EEEE09:BTP1BDU80@d=306UYJ@0U9BD206i^KP1107MgM`1]KFd0G5aL079bLP1nOWh0
BTY:04=3@`1;Bd/0<S8b01dM7@1WIfL0Fe]K020P800m?Cd0<c<c04e=C@1>CTh0?clo03Lg=`1;Bd/0
:BTY04e=C@1EEED0>SXj09:BTP0j>SX0=SHf06QXJ01GEeL0:RXZ05=CD`1cLg<0ADE508j>SP0i>CT0
:2PX03Ti>@1EEED0HF5Q03Ph>01CDe<0HF5Q04];B`0h>3P0:2PX059BDP0f=SH0NWYj08J6QP1aLG40
:BTY03lo?`1GEeL07alO05YJFP1nOWh0:BTY03Ti>@1EEED0FEUI03/k>`1@D500IVIV06ATI012@T80
0P1bLW80300j>SX0H61P07QhN00/;2`0EUIF09RHV01aLG40GEeM08B4Q013@d<0I6AT07moO`80GUiN
07<0G5aL04Y:BP2;Rh/0>c/k06UYJ@1MGEd0ADE509:BTP1nOWh0BTY:07UiN@1aLG40JVYZ08J6QP1=
CDd0Ogmo05eMG@2EUID0SHf=05mOG`1GEeL0Kfm_096AT@1HF5P0`/;208^;R`0f=SH0C4a<09:BTP1D
E5@0V9RH034a<@1=CDd0IVIV09:BTP1aLG409RHV06=SH`13@d<0DU9B07MgM`1[Jf/0:RXZ09NGU`1C
De<0H61P07emO@1:BTX0MWIf07EeM@2][Jd0O7al04i>CP1QHF40F5QH0;>c/`2EUID0CDe=09BDU01[
Jf/0HF5Q0861P@2=SHd0?3`l0492@P1^KVh0O7al03`l?02f][H0MWIf04e=C@1mOGd0?Shn05QHF02B
TY80O7al02d];@1bLW80=SHf04=3@`1WIfL0AdM70:b/[02;Rh/0GUiN0:RXZ021PH40@T9207UiN@13
@d<0R8R807emO@0T92@0HF5Q08Z:RP2JVYX0IfMW0492@P1VIVH0A4A404M7A`1=CDd0XJ6Q08Z:RP2B
TY806QXJ05ADE01GEeL0>SXj07inOP0Y:BT071`L05ADE01mOGd0EUIF0080Ph>303h0C4a<08>3P`3A
dM40MGEe03`l?01CDe<0HV9R04i>CP12@T80Vi^K038b<P0h>3P0QHF504i>CP0m?Cd0Shn?04];B`1V
IVH0[:b/04Q8B02JVYX0[:b/09ZJVP0a<C40;bl_08:2PP1GEeL0>CTi06ATI01MGEd0=SHf08B4Q03>
c/h0HF5Q038b<P0i>CT0L71`06=SH`0c<c<0Fe]K04A4A00o?cl0MgMg04Y:BP0g=cL0MGEe03<c<`0m
?Cd0I6AT030`<016ATH0^;Rh07emO@17AdL0Lg=c0;6a/@2`/;00>c/k02PX:029RHT0A4A4024Q8Aco
oooo01@0UiNG051@D00e=CD0;Rh^02PX:00O7al07AdM020P800L71`06QXJ06m_K`10@400A4A405mO
G`12@T80KFe]09^KV`11@D405aLG01DE5@<04A4A02X0410@01@D501MGEd0WIfM065QH@0c<c<0EUIF
01/K6`0T92@0@d=306YZJP0Q8B403`l?014A4@0P8200>c/k07MgM`2OWil0X:2P0:j^[P24Q8@0e]KF
0<O7a`1eMGD092@T04e=C@0];Bd0410@00h>3P0@41004A4A02HV9P2<S8`0Ng]k061PH01TI6@0?Shn
01/K6`0O7al0<C4a00h>3P0/;2`204A4A00Y02TY:@0C4a<05aLG06ATI025QHD0X:2P08f=S@1FEUH0
HF5Q07EeM@1iNGT0RXZ:09FEU@2YZJT0XJ6Q09JFUP2>SXh0Rh^;0:b/[03:b/X0GEeM075aL@3:b/X0
f=SH0:6QX@2<S8`0PX:207EeM@1mOGd0[Zj^0=OGe`1GEeL07AdM04E5A@18B4P0=cLg04E5A@0E5AD0
4a<C01@D500C4a<00P0E5AD01`0F5QH0@D510:^[Z`2m_Kd0a<C40;>c/`1FEUH00P0Q8B4201DE5@0D
01LG5`0E5AD05ADE02LW9`0j>SX0OGem0;Jf]P2:RXX0@D5104E5A@1iNGT0Hf=S061PH01kNg/0IVIV
0861P@1BDU80FUYJ08:2PP1`L70205IFEP0W02d];@0M7Ad07AdM028R8P0g=cL0JVYZ09jNWP1/K6`0
?clo01lO7`0N7Qh0Cdm?02HV9P0C4a<05ADE01LG5`1`L700Hf=S065QH@1PH600AdM701lO7`0H61P0
5aLG010@400A4A404Q8B00h>3P0A4A40410@01PH600P8200?3`l0:b/[02HV9P0O7al0>OWi`2^[Zh0
F5QH00806a/K01P071`L01TI6@0H61P05QHF08:2PP1aLG40EeMG03<c<`0T92@0=3@d09nOW`2e]KD0
CTi>07UiN@0K6a/0H61P05IFEP15ADD0=CDe01lO7`0N7Qh09bLW05IFEP0O7al201`L700J01lO7`0g
=cL0WIfM0=oOg`2h^;P0gmoO0=gMg@2_[jl0?Shn03<c<`1KFe/0C4a<0;2`/03>c/h0[Zj^0:JVYP0K
6a/0A4A408n?S`0E5AD04A4A01@D500L71`09bLW04E5A@14A4@201/K6`0:04];B`2OWil0`<300<?3
``3:b/X0c/k>07IfMP0U9BD06QXJ01/K6`8071`L02P07QhN01lO7`0S8b<0@41006a/K01[Jf/0SXj>
0:VYZ@0`<3007alO02d];@1jNWX0Y:BT0;bl_01SHf<0BDU903Lg=`1;Bd/0HF5Q09VIV@3Ph>00f=SH
0=KFeP33`l<0YJFU08F5Q@2m_Kd0/;2`0:JVYP3Ph>00gmoO0=OGe`2QXJ40b/[:0=oOg`2YZJT0NGUi
06IVIP1@D500>CTi4Oooool000oooooo03X0a/K605IFEP27QhL0M7Ad09FEU@1KFe/0IFEU08B4Q01Y
JFT0G5aL08n?S`1YJFT0HV9R07YjNP1`L700BTY:065QH@1lO7`0=3@d08R8R01@D500?Cdm06][J`29
RHT0GemO06YZJP1<C4`07QhN055AD@14A4@0MGEe075aL@0k>c/0G5aL05IFEP1?Cdl0GEeM055AD@0f
=SH07AdM06IVIP0n?Sh0820P0410@00Q8B40E5AD05mOG`0U9BD0?Cdm04E5A@0h>3P0Jf][04E5A@12
@T80Rh^;03Hf=P0i>CT0IFEU0P0f=SH0X`1NGUh0OGem051@D023Ph<0=cLg02l_;`17AdL0G5aL05iN
GP0n?Sh0JFUY065QH@19BDT0AdM7030`<01gMgL0=cLg06EUI@2NWYh0IFEU03/k>`1WIfL0GEeM02l_
;`1dM7@0L71`03@d=015ADD0JFUY069RHP0o?cl0>c/k06EUI@1ADE40<S8b092@T01jNWX0FEUI03hn
?P1/K6`0=CDe055AD@1bLW80Cdm?06MWI`1fMWH0=CDe06MWI`1GEeL0@D5106IVIP1YJFT0BTY:07Ad
M00h>3P0LG5a04=3@`0a<C40MWIf05EEE@1@D500OGem04m?C`1]KFd0IFEU05=CD`22PX80BDU905AD
E01LG5`0Ogmo065QH@1;Bd/0FUYJ03Lg=`2JVYX0U9BD04I6AP0c<c<0Ph>304m?C`2NWYh0C4a<03dm
?@1>CTh0L71`03Hf=P0L71`0HV9R059BDP1cLg<0JVYZ04Y:BP0h>3P0RXZ:03hn?P1ADE40JFUY0451
@@1YJFT0>3Ph08R8R01GEeL0>CTi04I6AP28R8P0Rh^;05IFEP0g=cL0RXZ:055AD@1`L700XZ:R09fM
W@16ATH0>CTi07QhN02EUID0B4Q80;Vi^@1hN7P0E5AD096AT@1YJFT0Bd];07alO01BDU80;Rh^04M7
A`0d=3@0DU9B079bLP17AdL0VYZJ07MgM`19BDT0Zj^[06UYJ@0[:b/0BDU903Xj>P2ZZZX0EeMG03lo
?`14A4@0Hf=S05]KF`1DE5@0ATI608b<S01mOGd0D51@03lo?`1/K6`0IVIV0820P00];Bd0OWin03hn
?P0^;Rh0NWYj059BDP0m?Cd00P2;Rh/0@@1QHF40OWin07MgM`1]KFd0E5AD0<S8b01]KFd0DE5A09bL
W02CTi<0FUYJ04Q8B023Ph<0@T9202l_;`1bLW80BTY:04U9B@1PH600>c/k03Ph>024Q8@0=SHf07Mg
M`24Q8@0OWin03Ti>@0S8b<0NGUi05IFEP0j>SX0?clo03Lg=`0`<300QXJ60<K6aP1BDU809BDU03Lg
=`1nOWh0=cLg04a<C01TI6@0?Cdm0492@P1/K6`0=CDe03Lg=`2`/;00BTY:03dm?@1]KFd08R8R034a
<@2_[jl0TI6A05UIF@1aLG40M7Ad08R8R00`<300De=C09JFUP1`L700>CTi01cooooo00P0QXJ608>3
P`19BDT0<30`02DU9@0Q8B408R8R01lO7`8071`L00/0CTi>04E5A@0n?Sh0@T9207YjNP2e]KD0emOG
04];B`0W9bL05aLG01HF5P0301DE5@1C02@T9021PH40BDU903lo?`0j>SX0<30`01/K6`0J6QX0B4Q8
03hn?P0Q8B404Q8B00h>3P0?3`l03Ph>010@400^;Rh0WYjN09:BTP2c/k<0]kNg08n?S`0K6a/0820P
01PH6015ADD0EEEE02HV9P0T92@08b<S01hN7P29RHT0C4a<03dm?@1ADE40Hf=S065QH@1[Jf/0Lg=c
06i^KP1PH600?Shn01@D500?3`l05QHF03dm?@0c<c<0>c/k09>CT`2KVi/0Q8B404U9B@0e=CD0:RXZ
024Q8@0M7Ad092@T01dM7@0G5aL051@D01LG5`1OGel0V9RH0<k>cP2d];@0SHf=09>CT`23Ph<0@T92
03Xj>P0b<S80H61P0:NWY`2k^k/0EEEE04E5A@17AdL0DE5A03dm?@13@d<051@D01<C4`0E5AD00P0D
51@0300C4a<05ADE030`<01[Jf/0JVYZ08n?S`1XJ6P07alO01<C4`0G5aL05ADE01@D50805ADE0P0F
5QH0>@18B4P0KFe]061PH025QHD0O7al096AT@32`/80J6QX02l_;`0T92@08R8R02@T900[:b/0DU9B
04Y:BP0N7Qh0@D5104=3@`0h>3P0?Shn04I6AP1HF5P0IFEU08N7Q`2e]KD0Vi^K06IVIP1PH600HF5Q
07AdM00`<300;2`/034a<@0j>SX0RHV90<C4a02d];@0H61P05ADE00m?Cd05aLG01DE5@0@41004A4A
018B4P0C4a<05ADE01HF5P0Y:BT0>CTi07IfMP3De=@0f][J0:FUY@3;bl/0GEeM01hN7P0201HF5P80
71`L02406ATI01lO7`1eMGD08R8R03`l?00d=3@0820P02@T901IFET0LG5a09RHV01lO7`0@41005EE
E@0`<300>SXj03dm?@0h>3P0=SHf04Q8B01[Jf/0@41003De=@0g=cL0ATI605]KF`1kNg/0/;2`0=[J
fP3Rh^80j>SX0=;BdP29RHT00P1lO7`07P2_[jl0clo?0:6QX@1RHV80RXZ:01/K6`1^KVh0/k>c06EU
I@0/;2`05ADE01LG5`0T92@0;2`/03Lg=`16ATH0Cdm?075aL@1XJ6P0MGEe08R8R02a/K40^[Zj03lo
?`0N7Qh07AdM01`L700M7Ad08R8R02XZ:P80820P02D0?3`l07]kN`1IFET0[Zj^08>3P`12@T809BDU
02d];@2?Shl0bLW90=WIf@31`L40TY:B07moO`1cLg<0MgMg09jNWP33`l<0X:2P09RHV01eMGD0NGUi
08f=S@3>c/h0Vi^K0:JVYP38b<P0dM7A08Z:RP1iNGT0GUiN07alO01jNWX08R8R02@T900S8b<092@T
017ooooo000?ooooo`2L0<71`@1EEED0UiNG07inOP2/[:`0FUYJ07QhN02JVYX0UIFE05YJFP2OWil0
RXZ:06UYJ@1fMWH0Hf=S04A4A01TI6@0FEUI0492@P2NWYh0E5AD04=3@`1OGel0De=C03`l?01@D500
Fe]K01hN7P14A4@0?Cdm05mOG`1fMWH0?clo065QH@1FEUH0ATI603`l?00k>c/0@41002@T901VIVH0
FEUI01PH600h>3P0<C4a0410@01:BTX08B4Q02h^;P0];Bd0=3@d05]KF`14A4@0>CTi07YjNP0X:2P0
GemO06UYJ@10@4009bLW04Y:BP1JFUX0GEeM09>CT`0n?Sh0=cLg03Ti>@1>CTh0<S8b03De=@24Q8@0
IfMW04U9B@0i>CT09bLW05]KF`0c<c<0NGUi08R8R01EEED0A4A409^KV`1[Jf/08R8R06MWI`14A4@0
:RXZ05YJFP1dM7@0DE5A03De=@17AdL0M7Ad05=CD`0S8b<0U9BD05aLG00g=cL0>c/k071`L00[:b/0
CDe=05ADE013@d<0GEeM06e]K@0];Bd0DE5A03hn?P0m?Cd0De=C05eMG@1=CDd0MgMg03@d=01DE5@0
9RHV038b<P1bLW80EeMG0492@P1?Cdl0F5QH07IfMP1DE5@0MWIf07inOP1JFUX0GemO06i^KP21PH40
E5AD04m?C`0k>c/0:BTY0<K6aP26QXH0<S8b03dm?@1mOGd0A4A4092@T00o?cl0ATI605aLG01ZJVX0
>3Ph03<c<`1YJFT0EEEE08j>SP2<S8`0Cdm?03Ph>02<S8`0@4100P1IFET0900o?cl0Fe]K04U9B@2[
Zj/0AdM704I6AP1IFET0VIVI05IFEP19BDT0?Cdm096AT@1XJ6P0L71`08Z:RP2VYZH0E5AD06UYJ@3;
bl/0^[Zj05IFEP3;bl/0DU9B08N7Q`2b/[80J6QX06IVIP28R8P0G5aL02h^;P1DE5@0?Cdm04e=C@1Z
JVX0@d=309BDU080G5aL05h0ZZZZ04M7A`0a<C40D51@04e=C@2n_[h0@D5103Lg=`25QHD0a<C40<o?
c`1QHF40B4Q807inOP1aLG40@410051@D01fMWH0EeMG08B4Q00b<S80KVi^0451@@0X:2P0SXj>05YJ
FP1ADE40N7Qh071`L00^;Rh0Kfm_07YjNP20P800?Cdm0;Fe]@1`L700FEUI07=cL`1`L700G5aL04=3
@`1^KVh08B4Q03<c<`1hN7P0Fe]K03dm?@1eMGD0=SHf06][J`2VYZH0ADE506MWI`1kNg/0OWin03<c
<`0f=SH0NWYj061PH00l?3`0>3Ph034a<@0n?Sh0Ng]k0<k>cP1WIfL09RHV03De=@1?Cdl0D51@02/[
:`1]KFd0I6AT0492@P1CDe<0<C4a024Q8@2>SXh0:RXZ03@d=01LG5`0>c/k03Ph>02ATI40Shn?04Q8
B020P800NWYj07UiN@0o?cl0HF5Q09:BTP1kNg/0=3@d7?ooool05P38b<P0PX:207]kN`0f=SH08b<S
020P800O7al07AdM01/K6`0L71`0?clo06=SH`0o?cl0RHV90;Ng]`34a<@0U9BD0;Vi^@2WYjL0KFe]
03/k>`0Q8B4201DE5@0505YJFP1BDU80EeMG03dm?@19BDT00`0N7Qh00`0Q8B40;bl_03@d=00201DE
5@<03Ph>01X04A4A06YZJP18B4P0H61P075aL@1lO7`0=SHf03Xj>P0A4A40=3@d02/[:`0>3Ph04a<C
02LW9`1JFUX0b<S809:BTP1gMgL0MGEe09BDU027QhL0MWIf09nOW`2f][H0MgMg02LW9`803@d=02L0
BDU902TY:@0_;bl0ATI6055AD@1GEeL0Rh^;059BDP1?Cdl0?clo02LW9`0S8b<0De=C04a<C011@D40
;Rh^06EUI@0`<300<C4a0:NWY`2LW9`0@T9203dm?@0n?Sh08B4Q02HV9P0S8b<06ATI02LW9`13@d<0
Xj>S04a<C01=CDd0Ng]k05YJFP1@D5006QXJ01DE5@0C4a<00`0E5AD02P0D51@06a/K0:JVYP2MWId0
IfMW0:BTY01>CTh0820P01`L700G5aL301DE5@0:01XJ6P0O7al0NGUi05=CD`1BDU80GemO02HV9P1i
NGT0Shn?02/[:`805aLG01@061PH02d];@1>CTh0CTi>01TI6@0F5QH05ADE0492@P0];Bd04a<C010@
400C4a<0:BTY075aL@3>c/h0dM7A0;bl_01LG5`06a/K01TI6@807AdM00h092@T02l_;`1=CDd0^[Zj
0;fm_@1IFET0Ng]k06IVIP1@D50071`L00h>3P0C4a<05ADE02TY:@80<c<c01d0Cdm?08:2PP2o_kl0
d];B0:^[Z`1PH600KFe]05]KF`17AdL05aLG01HF5P0E5AD05aLG01PH600g=cL0AdM701DE5@0];Bd0
DU9B03Hf=P0V9RH0D51@06a/K02ATI40JFUY08J6QP0`<300=3@d01LG5`0201DE5@1101LG5`1BDU80
8B4Q01`L700H61P071`L01TI6@0N7Qh0DU9B04e=C@3@d=00inOW0=_Kf`3<c<`0[:b/0<O7a`3Lg=`0
i>CT0=3@d00d=3@0>c/k06i^KP1XJ6P0SXj>024Q8@1GEeL0Vi^K07AdM00_;bl06a/K038b<P0l?3`0
JFUY09RHV00e=CD0HF5Q05iNGP1?Cdl0IfMW0:NWY`39bLT0Y:BT07alO00i>CT0:RXZ0451@@1_Kfl0
DU9B05]KF`1OGel0Xj>S09RHV02JVYX0>3Ph03`l?025QHD0Vi^K08N7Q`1fMWH0Y:BT05MGE`15ADD0
CDe=04Y:BP1LG5`00P2i^KT04@2>SXh0UYJF0:FUY@2ZZZX0_Kfm096AT@2DU9@0_Kfm0;bl_02PX:00
>c/k069RHP1DE5@0@4100:RXZ01=CDd08b<S00809BDU4Oooool000oooooo03L0_;bl061PH02g]kL0
KVi^096AT@1ADE40Rh^;0:n_[`2;Rh/0HF5Q09VIV@27QhL0LG5a0820P01mOGd0@T9205YJFP1PH600
>SXj09JFUP1NGUh0ADE506EUI@2ATI40EUIF05EEE@1KFe/07AdM04e=C@1CDe<0Kfm_06UYJ@0h>3P0
IfMW06UYJ@19BDT0@D51034a<@17AdL08b<S06=SH`1JFUX06a/K03/k>`0Z:RX0A4A404i>CP0[:b/0
<C4a03/k>`0a<C40BDU903/k>`0n?Sh0UYJF0080=CDe00<0H61P03dm?@0S8b<00P1:BTX0S014A4@0
Ng]k05UIF@0n?Sh0@D5104i>CP1:BTX0CTi>07QhN01QHF40C4a<03De=@0b<S80H61P02LW9`1mOGd0
QHF5069RHP0[:b/0E5AD05aLG00S8b<0K6a/04Y:BP0f=SH0@d=307AdM019BDT0:2PX03Xj>P1TI6@0
B4Q802<S8`2VYZH0BTY:02/[:`1:BTX0Jf][02h^;P1FEUH0JFUY04M7A`1RHV80NWYj02d];@1ADE40
A4A404Y:BP1?Cdl0FEUI05iNGP20P800=CDe05UIF@0S8b<0@D5106e]K@1?Cdl0?clo05IFEP18B4P0
NGUi05]KF`2=SHd0IFEU05]KF`1gMgL0K6a/08Z:RP1<C4`0Kfm_05IFEP0e=CD0bLW908b<S00l?3`0
@T9208b<S018B4P0S8b<03/k>`17AdL0FEUI06i^KP0f=SH0;bl_079bLP1MGEd0IfMW07AdM01:BTX0
>3Ph08n?S`16ATH0SHf=08J6QP17AdL0HF5Q055AD@3;bl/0Ng]k055AD@1YJFT0UYJF04M7A`0j>SX0
@4100:b/[01LG5`0M7Ad096AT@2EUID0=cLg06UYJ@37alL0Shn?0492@P34a<@0GUiN05QHF028R8P0
IVIV065QH@1iNGT0D51@05eMG@1JFUX0@d=305QHF01ZJVX0A4A40:BTY01OGel0Kfm_0;Ng]`1>CTh0
?Cdm059BDP19BDT0XJ6Q0P0/;2`0B`0m?Cd0FEUI069RHP1SHf<0Bd];075aL@1hN7P0B4Q804Y:BP2Z
ZZX0/k>c08:2PP0g=cL0OGem03@d=01>CTh0XZ:R05=CD`11@D40HV9R08:2PP1@D500AdM706e]K@20
P800ADE508F5Q@1=CDd0IFEU08J6QP21PH40Kfm_0492@P1MGEd0DU9B02l_;`1RHV80Hf=S03@d=01F
EUH0<S8b03/k>`2@T900?3`l05YJFP1OGel0QHF503/k>`0M7Ad0KVi^071`L011@D40=cLg04e=C@11
@D40SHf=0=3@d01fMWH07alO03@d=01lO7`0GemO030`<01TI6@0ATI603hn?P18B4P09BDU02l_;`2I
VIT0=3@d03Ti>@1dM7@0KFe]03hn?P0208^;R`0904E5A@2;Rh/0MWIf06m_K`0];Bd0R8R80;2`/022
PX80<C4a01cooooo00P0_;bl0<?3``1dM7@0FEUI02h^;P0R8R807alO01`L70806a/K05l0=3@d09^K
V`2HV9P0T92@03`l?00m?Cd0A4A404Q8B01TI6@0S8b<0:b/[02OWil0P82006IVIP2JVYX0CDe=05=C
D`18B4P0?Cdm028R8P0T92@08B4Q00h>3P0S8b<0De=C01LG5`0@41003`l?010@400>3Ph04a<C071`
L018B4P0F5QH0;Bd]02WYjL0];Bd05iNGP1?Cdl0J6QX07inOP1FEUH0BTY:0410@01>CTh0SHf=09RH
V02OWil0S8b<09fMW@2JVYX0U9BD0:BTY01gMgL0?3`l02@T900?3`l08b<S04U9B@0/;2`0>CTi07Ad
M00e=CD0IfMW01<C4`0A4A4061PH02/[:`0i>CT0A4A405EEE@1aLG40XZ:R0;^k^`0m?Cd06ATI02TY
:@1EEED0YJFU09VIV@1lO7`0=3@d028R8P0N7Qh08b<S01dM7@0V9RH0ADE508^;R`1YJFT0H61P07Mg
M`2LW9`0QHF501dM7@0201<C4`0J01DE5@0D51@05ADE01DE5@0P8200bLW90;jn_P2?Shl0_[jn09bL
W024Q8@0JFUY05MGE`0h>3P0=3@d03Lg=`11@D40FUYJ0::RXP1MGEd0LG5a09NGU`1YJFT0SHf=079b
LP0G5aL201DE5@0501LG5`1EEED0@T9202DU9@0D51@00P0E5AD0>`0R8R80ATI601@D500>3Ph0410@
01<C4`0o?cl0_[jn0:BTY01oOgl0?clo01hN7P0R8R80:2PX03@d=00_;bl0:b/[04m?C`3Ng]h0Kfm_
08>3P`1@D500MWIf07=cL`1CDe<0<30`03dm?@0f=SH09RHV03<c<`1WIfL0Lg=c07AdM02GUiL0emOG
08V9R@23Ph<0DE5A08^;R`1HF5P08b<S01DE5@0G5aL05QHF01TI6@16ATH07QhN01DE5@0F5QH0;2`/
04];B`0f=SH0CDe=08R8R02CTi<0]KFe09VIV@0^;Rh05aLG00805ADE01T06a/K03<c<`1aLG4071`L
01TI6@0J6QX05aLG01TI6@0M7Ad0;Bd]04A4A02FUYH0d=3@09>CT`2PX:00C4a<08F5Q@3;bl/0/K6a
0=GEe@19BDT0Lg=c0;Vi^@3:b/X0:BTY00805ADE01407alO06ATI023Ph<0Hf=S03@d=00T92@0<30`
061PH00T92@0GUiN03`l?01EEED0UYJF0<;2`P1TI6@0CTi>08^;R`020;:b/P0Y09NGU`2c/k<0/K6a
0;Jf]P2UYJD0f=SH0<c<c01hN7P0820P0451@@2FUYH0Ti>C06a/K02HV9P0L71`03Ph>01<C4`0Bd];
05mOG`2BTY80YZJV03Ph>011@D40D51@05ADE01ADE40Ogmo07=cL`18B4P0I6AT09FEU@1kNg/08R8R
05]KF`1[Jf/0Cdm?09RHV038b<P0PX:203hn?P0j>SX04Oooool000oooooo06P0/[:b059BDP2SXj<0
N7Qh0::RXP1DE5@0IVIV0:BTY01nOWh0HF5Q07=cL`16ATH0RHV90820P01cLg<0CTi>08b<S01fMWH0
Cdm?09fMW@16ATH0HV9R08Z:RP2>SXh0D51@05iNGP1HF5P07alO05mOG`1CDe<0Hf=S06YZJP0b<S80
LG5a05mOG`17AdL0@41002`/;01GEeL0=SHf075aL@0];Bd0;2`/061PH00a<C40?Cdm051@D00U9BD0
B4Q804A4A00b<S80ATI603hn?P1GEeL0VYZJ03<c<`0f=SH0IVIV0451@@0Q8B40DE5A05mOG`1?Cdl0
O7al05=CD`0o?cl0BTY:06MWI`1SHf<0Cdm?08B4Q01BDU80BTY:04A4A00l?3`0J6QX01hN7P1bLW80
Y:BT05QHF00];Bd0Kfm_05]KF`0];Bd0S8b<05=CD`0i>CT0@d=307=cL`0m?Cd0:b/[03Ti>@1kNg/0
De=C02HV9P2DU9@0EeMG038b<P0l?3`0JVYZ02/[:`18B4P0IfMW03Hf=P80HF5Q01L0:2PX05=CD`0k
>c/0<c<c05=CD`1@D500FEUI06MWI`0a<C40D51@03Lg=`0n?Sh0IVIV04E5A@0m?Cd0JFUY06IVIP1i
NGT0@d=307=cL`1^KVh0Kfm_05aLG00207=cL`2O04];B`1@D500CTi>03hn?P3<c<`0SHf=0451@@1M
GEd0WIfM04a<C026QXH0C4a<04M7A`1ADE40H61P020P800S8b<0Ogmo05MGE`1ZJVX0P82003hn?P0h
>3P0O7al04A4A01QHF40LG5a0410@01>CTh0<S8b0:6QX@1gMgL0Fe]K07=cL`2KVi/0HV9R024Q8@1A
DE40];Bd06MWI`2>SXh0QXJ609BDU01DE5@0RXZ:0=7Ad@2>SXh0C4a<0<C4a01`L700NGUi09RHV01T
I6@0GEeM07QhN01DE5@0>CTi07=cL`15ADD0De=C0820P01hN7P0eMGE0:RXZ01[Jf/0_;bl07]kN`0f
=SH0>SXj04E5A@2=SHd0:RXZ03/k>`1=CDd0L71`07UiN@19BDT0@d=3061PH01LG5`0;bl_034a<@1K
Fe/0IFEU07inOP0g=cL0L71`03Ti>@0^;Rh0Ng]k038b<P17AdL0EUIF06i^KP1BDU80B4Q8059BDP1F
EUH0@41005MGE`0m?Cd0K6a/092@T01dM7@0IfMW0410@01VIVH0IfMW03<c<`1eMGD0IVIV02PX:01?
Cdl0FEUI05YJFP2UYJD0=SHf04M7A`1?Cdl0S8b<04I6AP0U9BD0OWin06EUI@0g=cL0=CDe0492@P1?
Cdl0SXj>0<_;b`1ZJVX06a/K03<c<`2;Rh/0J6QX03/k>`1ZJVX0BTY:03Ti>@12@T80<C4a03Ti>@22
PX80EeMG0410@01oOgl0PX:203Ph>020P800S8b<0451@@2CTi<0SHf=08J6QP0e=CD0V9RH0;Bd]01i
NGT0<C4a01cooooo02@0UIFE09^KV`39bLT0U9BD04=3@`0S8b<07QhN01dM7@0L71`08b<S06EUI@3@
d=00Kfm_02d];@0[:b/07AdM01`L7013@d<0BDU902PX:00a<C40?clo071`L02^[Zh0YZJV04M7A`1>
CTh0CDe=02h^;P0];Bd05QHF01<C4`0D51@06a/K03/k>`0/;2`2010@400V00h>3P0?3`l05aLG09bL
W01HF5P0EEEE0>3Ph03Ng]h0_;bl08:2PP1OGel0@T9204i>CP0X:2P08b<S02TY:@0R8R80<c<c05=C
D`1ZJVX0LW9b09bLW02/[:`0UIFE08b<S01aLG40<C4a02d];@0Y:BT0MWIf06QXJ012@T80EEEE09RH
V00o?cl0;bl_00h>3P0=3@d300h>3P0f018B4P0Q8B40;Rh^05IFEP23Ph<06a/K01LG5`0g=cL0@d=3
075aL@1nOWh0I6AT0451@@0j>SX0?3`l034a<@0j>SX0<S8b03lo?`1aLG40Ogmo06YZJP2DU9@0Q8B4
0<C4a01YJFT0=cLg02<S8`0P82008B4Q02DU9@0];Bd0I6AT0<o?c`2^[Zh0MGEe0;:b/P2PX:00Xj>S
05mOG`27QhL0WIfM069RHP1DE5@0FUYJ06YZJP2[Zj/0YJFU08^;R`2NWYh0NWYj0;Bd]01gMgL05aLG
0P0E5AD0=@14A4@0>CTi03lo?`0C4a<04Q8B01DE5@0D51@05aLG03@d=010@4005ADE02<S8`15ADD0
LW9b0<k>cP2TY:@0YJFU06i^KP17AdL0H61P04E5A@0i>CT0?clo04U9B@1WIfL0MgMg0;:b/P2CTi<0
R8R805YJFP1mOGd0YjNW06=SH`0];Bd0@T9205]KF`1?Cdl0=cLg024Q8@1CDe<0S8b<0>;RhP2KVi/0
Ogmo092@T03:b/X0DE5A03@d=00G5aL06QXJ01TI6@0J6QX0DU9B00<05ADE00T06QXJ03Lg=`1;Bd/0
CDe=08f=S@2BTY80/k>c069RHP0M7Ad00P0G5aL01@0R8R80D51@07alO01FEUH07AdM00@06a/K0180
8R8R03Ph>01EEED0][Jf08:2PP0O7al0S8b<01hN7P0Y:BT0MgMg07QhN03>c/h0`L710=;BdP2IVIT0
N7Qh01XJ6P0D51@201DE5@0k01LG5`0U9BD0J6QX09FEU@27QhL0D51@05=CD`1FEUH0GEeM03hn?P1d
M7@0Ph>30=OGe`29RHT0IVIV079bLP1iNGT0XZ:R0;^k^`35aLD0]kNg071`L01IFET0`<300<k>cP1_
Kfl07QhN02DU9@12@T80V9RH0<O7a`2PX:00HV9R059BDP0o?cl0Jf][09fMW@2OWil0?Cdm04Y:BP10
@400:2PX02HV9P0Z:RX0?Cdm08b<S01:BTX0HV9R09NGU`23Ph<08B4Q02h^;P1OGel0LW9b08B4Q02R
XZ80UYJF0:BTY01NGUh04Oooool000oooooo0?l0a/K605MGE`2h^;P0MGEe0;Ng]`1IFET0O7al0;Zj
^P21PH40KFe]09NGU`1hN7P0Ogmo07MgM`1lO7`0>c/k06EUI@1VIVH0Jf][09NGU`16ATH0=SHf06YZ
JP28R8P0BTY:069RHP0_;bl0?Shn092@T013@d<0GUiN05IFEP0R8R80Kfm_051@D00n?Sh0@d=30492
@P1IFET08b<S04i>CP1BDU8061PH03Ph>00[:b/0@D5104I6AP0M7Ad0=SHf02LW9`0k>c/0BDU903De
=@0o?cl0Lg=c02@T900e=CD0H61P02h^;P0d=3@0MWIf06MWI`1GEeL0Ng]k04=3@`0];Bd0ATI605=C
D`1EEED0?Cdm07IfMP1IFET0De=C04M7A`1>CTh0IFEU0410@01lO7`0Y:BT05QHF00X:2P0LW9b06UY
J@0T92@0LG5a0410@00j>SX0@41007QhN01ADE40:b/[03`l?01oOgl0F5QH04e=C@2>SXh0C4a<03Lg
=`17AdL0Kfm_038b<P1HF5P0D51@02d];@1YJFT0KFe]02TY:@0k>c/09RHV02h^;P1KFe/0FUYJ06YZ
JP1JFUX0<30`05UIF@0l?3`0@41005=CD`0f=SH0EeMG07AdM01QHF40N7Qh03Ti>@25QHD0P82006m_
K`1@D500?clo06IVIP1<C4`0EeMG02/[:`0g=cL0dm?C07YjNP0d=3@0AdM707inOP0l?3`0OWin04M7
A`1@D500AdM705eMG@0O7al08B4Q09FEU@1LG5`0IFEU071`L00i>CT0?clo08F5Q@16ATH0MWIf07in
OP0o?cl0G5aL04];B`2_[jl0HF5Q05aLG01XJ6P0WIfM06UYJ@1FEUH0@d=30:NWY`1OGel0SHf=07=c
L`2IVIT0B4Q809BDU03@d=00TI6A05eMG@2l_;`0Kfm_08N7Q`2?Shl0Cdm?05ADE01bLW80B4Q803@d
=01<C4`0:RXZ0410@011@D40C4a<0:b/[01fMWH0FUYJ0:VYZ@1OGel0@d=305ADE01BDU80S8b<04I6
AP18B4P0F5QH07EeM@24Q8@0EEEE04I6AP1JFUX0EEEE03lo?`10@400OGem0861P@1[Jf/09bLW06=S
H`14A4@0@41009:BTP15ADD0C4a<05eMG@26QXH0?3`l04i>CP1<C4`0EEEE05YJFP18B4P0A4A406i^
KP2XZ:P0Ogmo05iNGP0c<c<0E5AD04M7A`0];Bd0JVYZ04A4A00T92@0Fe]K061PH01KFe/0/;2`0410
@00b<S80<C4a08B4Q015ADD09bLW07YjNP1SHf<002<0=3@d03Ti>@14A4@0D51@08F5Q@39bLT0L71`
02@T9017AdL0SHf=06e]K@1:BTX0LW9b06][J`13@d<0E5AD05UIF@17AdL0QHF505aLG015ADD0TI6A
07AdM00j>SX0Ph>307IfMP0h>3P0PX:208F5Q@1oOgl0Fe]K0:NWY`2f][H0?clo02PX:00Looooo`09
09>CT`1PH600/k>c0;6a/@1]KFd0<c<c02DU9@0/;2`0BTY:0080L71`01<0WYjN07UiN@0[:b/0:BTY
02HV9P0K6a/06QXJ05=CD`0k>c/09bLW02<S8`0Q8B40?Cdm0;:b/P1;Bd/0E5AD05UIF@0e=CD08B4Q
00<05ADE01D08b<S02d];@0G5aL0:b/[01DE5@0D51@061PH05iNGP3>c/h0XJ6Q08Z:RP3Jf]X0[jn_
04E5A@0B4Q8051@D01TI6@0Y:BT04a<C010@400<30`00P0=3@d05@17AdL0DE5A0::RXP21PH40De=C
0861P@1gMgL0@d=307moO`1_Kfl0M7Ad09:BTP30`<00YjNW0<O7a`33`l<0VIVI02HV9P0@41003Ph>
010@400300h>3P0;01DE5@0a<C409bLW07emO@0W9bL05QHF04I6AP0h>3P0>c/k01`L700Q8B400P0>
3Ph0;`0C4a<04A4A014A4@0A4A404a<C04A4A022PX80?clo06MWI`2n_[h0b<S809VIV@1;Bd/0AdM7
04Y:BP1IFET0EUIF05ADE01GEeL0/K6a09:BTP1eMGD0X:2P0<;2`P2k^k/0WinO07moO`26QXH0FEUI
0492@P11@D40B4Q80:n_[`2b/[80QHF50:BTY01kNg/0QXJ608R8R01QHF408b<S02XZ:P18B4P0ATI6
01/K6`0E5AD04a<C00<05ADE00X07alO04a<C01cLg<0A4A402l_;`0b<S80e=CD09>CT`2UYJD0MgMg
0P19BDT02@23Ph<0Q8B406a/K01DE5@0@41006ATI03>c/h0Ogmo06YZJP0207inOP0509nOW`2EUID0
OGem04m?C`0K6a/00P0E5AD08`0H61P0NGUi0;Jf]P3WinL0_kno0<[:bP3Ph>00i>CT0;Ng]`1@D500
5aLG01DE5@0G5aL0<S8b03De=@0D51@05QHF01DE5@0I6AT07QhN06EUI@1`L700N7Qh0:n_[`2][Jd0
Kfm_034a<@0d=3@0Cdm?04e=C@0d=3@08B4Q03@d=00U9BD06a/K00<071`L00/0@D5104E5A@28R8P0
PX:205=CD`0N7Qh0O7al03<c<`0Y:BT0GEeM09jNWP020>3Ph00606i^KP0b<S80G5aL02@T900A4A40
4a<C0P0E5AD04P0I6AT08B4Q030`<01PH600XZ:R08n?S`2l_;`0NGUi05EEE@1PH600WIfM07QhN03:
b/X0fm_K0<30`02@T900PX:207moO`80Hf=S02H0FUYJ09NGU`2j^[X0fMWI0;Bd]028R8P0QHF508Z:
RP34a<@0emOG0;:b/P2HV9P0;bl_03lo?`1iNGT0Shn?0492@P0d=3@0<S8b02LW9`0Z:RX0;Rh^030`
<00g=cL0M7Ad04A4A01RHV80ZZZZ08>3P`0];Bd0?clo06m_K`1[Jf/0V9RH08Z:RP0o?cl0LG5a0;Bd
]17ooooo000?ooooo`3J0:j^[P1WIfL0a<C4059BDP2BTY80HF5Q08b<S02CTi<0A4A4071`L02IVIT0
GUiN07inOP1FEUH0Shn?04Y:BP1[Jf/0GUiN06IVIP2WYjL0IFEU04I6AP1`L700O7al05ADE01oOgl0
DE5A02@T901=CDd0<30`07MgM`1LG5`09BDU06IVIP0k>c/0Bd];051@D011@D40BDU901/K6`1<C4`0
E5AD01`L7013@d<0:BTY04M7A`16ATH07AdM03/k>`0U9BD0=CDe05ADE00];Bd0@T9206QXJ00S8b<0
=CDe055AD@12@T807AdM05aLG01TI6@0F5QH07IfMP0o?cl0:2PX03dm?@14A4@0D51@0410@01hN7P0
CTi>05MGE`0g=cL0<c<c06MWI`0c<c<0N7Qh09VIV@1QHF40;Rh^07AdM01MGEd09RHV07QhN016ATH0
?3`l05=CD`1mOGd0?Shn02DU9@18B4P0Ph>304I6AP13@d<0IfMW055AD@0o?cl0De=C06MWI`1:BTX0
IFEU05EEE@17AdL0Q8B408>3P`0Z:RX0Bd];03dm?@0^;Rh0CDe=05QHF01`L700De=C030`<01DE5@0
BDU904=3@`1LG5`0>CTi03`l?01UIFD0DU9B07YjNP18B4P0EeMG07IfMP1QHF40FEUI06e]K@1IFET0
Cdm?05EEE@0m?Cd0BTY:0=7Ad@21PH40?Cdm04a<C01oOgl0@41008V9R@1MGEd0D51@04=3@`1_Kfl0
?clo038b<P3:b/X0HF5Q04i>CP1SHf<0>CTi05mOG`2?Shl0A4A407emO@1JFUX0@D51071`L01;Bd/0
Z:RX065QH@0g=cL0P8200<S8b01[Jf/0D51@04I6AP2RXZ80H61P08V9R@2MWId0PH6105EEE@2PX:00
clo?09VIV@1?Cdl0]KFe034a<@1nOWh0/K6a04M7A`1CDe<0QXJ60451@@10@400De=C024Q8@0/;2`0
GemO055AD@2ZZZX0FEUI04e=C@2PX:00@D5103Ph>018B4P0@41007emO@0c<c<0>SXj06a/K01`L700
NWYj059BDP18B4P0Fe]K05YJFP18B4P0CTi>09:BTP1aLG40J6QX034a<@1QHF4204U9B@1608N7Q`0i
>CT0?Cdm05IFEP29RHT0>CTi04U9B@1BDU80@D51061PH00o?cl0=SHf06][J`2h^;P0NGUi04i>CP12
@T80EUIF04e=C@0`<300EEEE02d];@0Z:RX0?Cdm04a<C01EEED0/[:b04E5A@12@T80:BTY071`L00i
>CT09BDU08F5Q@1ADE40;2`/04e=C@0^;Rh0?Shn07=cL`2m_Kd0CTi>01TI6@11@D40Fe]K04=3@`1N
GUh0MGEe05iNGP1mOGd0R8R8059BDP11@D40TY:B04m?C`1GEeL0ZZZZ07emO@13@d<0Vi^K08n?S`0o
?cl0Ng]k071`L02ATI40JFUY0;Vi^@2m_Kd0PX:203Ti>Acooooo0100LG5a06MWI`2=SHd0fm_K0;6a
/@29RHT0OWin06MWI`19BDT092@T01LG5`0O7al0IfMW06i^KP0Z:RX0;Rh^0P0G5aL02`0g=cL0AdM7
03Hf=P0c<c<0;Rh^02TY:@2YZJT0Rh^;05]KF`1kNg/07QhN00805ADE0P0>3Ph0:`0M7Ad0ATI603dm
?@27QhL0MWIf04Q8B01BDU80E5AD07YjNP2IVIT0_;bl09fMW@1aLG404Q8B014A4@0B4Q806ATI04Q8
B00O7al04A4A00h>3P0=3@d03`l?034a<@0];Bd0G5aL0;:b/P1YJFT0FEUI04e=C@0l?3`0VYZJ079b
LP1ADE40AdM704E5A@2RXZ80VIVI0:j^[P23Ph<0EEEE03`l?00F5QH00P0>3Ph0400=3@d03Ph>01<C
4`10@400;2`/079bLP0k>c/05aLG05iNGP19BDT0:b/[01TI6@0T92@03@d=00h>3P0@410200h>3P0:
00d=3@0<30`07QhN034a<@22PX80CTi>0;fm_@3:b/X0^;Rh07alO080JFUY0580L71`065QH@1iNGT0
Jf][03dm?@0e=CD0?3`l07alO01/K6`0Hf=S07alO02KVi/0ZZZZ0:FUY@28R8P0IfMW04m?C`1KFe/0
PH6105YJFP2=SHd0/K6a07QhN02CTi<0[Zj^0;Bd]022PX80EEEE02DU9@0>3Ph04A4A00h>3P0@4100
51@D01<C4`0E5AD0FEUI059BDP0T92@0:RXZ038b<P3IfMT0f][J0<g=c@2n_[h0Z:RX096AT@1dM7@0
DU9B04i>CP1HF5P0=cLg03hn?P3Cdm<0];Bd03Lg=`1EEED0`l?30:VYZ@3AdM40;Bd]01HF5P0E5AD0
5aLG01TI6@0T92@0LW9b0=GEe@2k^k/0B4Q809VIV@21PH40Vi^K0:6QX@2h^;P0>3Ph01PH600M7Ad0
KFe]01hN7P0E5AD05aLG0P0E5AD09P0Y:BT0<C4a08B4Q01/K6`0`<300;:b/P28R8P0KVi^05UIF@0j
>SX09RHV01hN7P0L71`07alO04E5A@0N7Qh071`L01lO7`0];Bd0Bd];07inOP1OGel0P82002PX:00N
7Qh0Cdm?0:6QX@1@D500_[jn0>3Ph03Jf]X0b/[:01hN7P0Q8B40CTi>038b<P0E5AD04a<C0P0E5AD0
;00G5aL07AdM01lO7`0P8200Cdm?0::RXP3De=@0]kNg09JFUP2m_Kd0f][J0:f][@3AdM40d=3@07If
MP0o?cl0@41007IfMP2o_kl0d];B0<O7a`35aLD0][Jf0;^k^`3Rh^80]KFe0861P@2MWId0bl_;0=GE
e@39bLT0HV9R02HV9P1GEeL0WinO038b<P0L71`07AdM02/[:`0b<S80;Rh^02LW9`0_;bl0=SHf0P1H
F5P00`1ZJVX0];Bd07IfMP0203Lg=`07096AT@2TY:@0]KFe0<W9b@20P800R8R80;Jf]P0Aooooo`00
3oooool0N02KVi/0EUIF0;2`/01RHV80M7Ad06QXJ02TY:@0]KFe06EUI@1`L700MGEe04Y:BP2GUiL0
K6a/071`L01JFUX0PH61059BDP1kNg/0XJ6Q06i^KP15ADD0NWYj06EUI@0h>3P0IfMW04U9B@0n?Sh0
HF5Q02LW9`1?Cdl0DU9B02/[:`1kNg/0;Bd]03@d=016ATH0<c<c04M7A`0K6a/0DE5A03lo?`0a<C40
H61P02@T901JFUX0GEeM02XZ:P1IFET0=CDe0492@P1ZJVX0ADE504a<C01TI6@09RHV055AD@1MGEd0
?Shn01dM7@1OGel0BDU9065QH@2<S8`0=3@d02HV9P0i>CT0>c/k03dm?@0j>SX0QXJ605=CD`1?Cdl0
9bLW03Ti>@1/K6`0>3Ph071`L02LW9`0B4Q803/k>`2HV9P0EEEE02<S8`25QHD0;Rh^03<c<`16ATH0
JFUY028R8P0M7Ad0Cdm?09FEU@1CDe<0K6a/09nOW`0l?3`0=CDe0820P01/K6`0=SHf04m?C`1lO7`0
>c/k06UYJ@1JFUX0;2`/04m?C`19BDT0CDe=05UIF@11@D40OGem061PH00W9bL0GEeM028R8P1ADE40
LG5a04m?C`80=CDe0:P0@T92096AT@1EEED0J6QX065QH@1BDU80Fe]K06][J`1:BTX0@D5105=CD`13
@d<0AdM70=?Cd`1`L700>CTi04i>CP27QhL0EUIF0:6QX@1ADE40F5QH04i>CP1iNGT0:b/[034a<@3<
c<`0Fe]K08^;R`2>SXh0=SHf0451@@1eMGD0?Cdm08V9R@1FEUH0=SHf05IFEP11@D40]kNg071`L00k
>c/0ADE506e]K@1>CTh0<S8b05MGE`2j^[X0CDe=065QH@1dM7@0?Shn03Ti>@23Ph<0`l?308Z:RP1M
GEd0^;Rh06EUI@1OGel0Ogmo05YJFP1;Bd/0KVi^03Ph>01>CTh0JFUY02DU9@16ATH0IfMW05eMG@31
`L40IVIV04a<C02[Zj/0F5QH0492@P15ADD0:BTY05YJFP0];Bd0=CDe06i^KP1jNWX0SHf=03Ti>@15
ADD0MWIf06ATI00o?cl0BTY:08^;R`1`L700Ng]k03Hf=P2FUYH0EEEE04=3@`2DU9@0DE5A03Hf=P27
QhL0TI6A03Ph>01PH600Fe]K02<S8`0m?Cd0<C4a03De=@1FEUH0a<C408Z:RP0h>3P0G5aL06][J`1T
I6@0<30`06YZJP0o?cl0?3`l03hn?P10@400EEEE0:RXZ00h>3P0RHV907YjNP1SHf<0:RXZ02TY:@2?
Shl0>c/k01/K6`10@40071`L02l_;`24Q8@0^[Zj06][J`0g=cL0FUYJ06m_K`0U9BD0Cdm?06][J`0m
?Cd0ADE505=CD`0U9BD0?3`l09RHV01=CDd0C4a<07moO`0a<C40AdM70<71`@2MWId0ADE508j>SP1g
MgL0QhN704M7A`36a/H0_;bl08N7Q`0j>SXLooooo`0:05aLG01bLW80E5AD08^;R`3Ng]h0fMWI07Qh
N00X:2P071`L01HF5P805ADE00T06a/K05aLG019BDT0:2PX02HV9P0E5AD05aLG04E5A@0[:b/00P0W
9bL01@0X:2P0PH610<k>cP2SXj<0Jf][00@05ADE0P0M7Ad03P0l?3`07AdM030`<026QXH0/k>c07Ee
M@12@T8092@T06QXJ034a<@0Q8B4069RHP0e=CD0>CTi0P0o?cl0/`1UIFD0Fe]K04Q8B00^;Rh06QXJ
04M7A`0a<C408b<S02HV9P2NWYh0Zj^[0:n_[`0W9bL0F5QH07UiN@0k>c/0O7al07=cL`2>SXh0UYJF
08^;R`20P800Ogmo02XZ:P0e=CD0CDe=03Hf=P0H61P0410@014A4@0E5AD06QXJ0410@024Q8@0EEEE
01XJ6P1bLW80EeMG01`L700Q8B409RHV00l?3`0@41003Ph>010@400>3Ph03@d=00h>3P0Z:RX0ATI6
0;Fe]@1hN7P0bLW90=7Ad@32`/80XZ:R08J6QP2MWId0][Jf05aLG01PH600CTi>02@T900];Bd0Kfm_
08F5Q@0U9BD0A4A4059BDP1GEeL0RHV905YJFP1^KVh0JVYZ02h^;P17AdL0XJ6Q092@T034a<@0d];B
0:>SX`2TY:@0[Zj^0=7Ad@2i^KT0HV9R01<C4`0@410051@D01DE5@0D51@04a<C01@D500/;2`0=3@d
04A4A00T92@0?clo06YZJP3Hf=P0]KFe08F5Q@3>c/h0RXZ:04a<C01oOgl0QhN704A4A00i>CT0GEeM
06i^KP0k>c/0@T9208j>SP1^KVh0U9BD09JFUP1PH600MGEe024Q8@0L71`06a/K02`/;01JFUX0VIVI
0;fm_@3Kfm/0/K6a06ATI01XJ6P0D51@065QH@2?Shl0ZJVY03lo?`1nOWh0_kno02<S8`0F5QH07AdM
01PH600E5AD0:b/[02PX:010@400HV9R0::RXP2FUYH0AdM704m?C`0T92@07AdM01LG5`0J6QX061PH
01dM7@22PX80C4a<0492@P1LG5`0EeMG08^;R`1OGel0A4A405]KF`0K6a/071`L02h^;P3Cdm<0fm_K
0:NWY`2GUiL0Lg=c09JFUP0/;2`06ATI0451@@0l?3`051@D00<05ADE01h04a<C01LG5`0M7Ad092@T
034a<@1eMGD0Vi^K0<71`@28R8P0UiNG0<?3``1eMGD0EEEE03lo?`1dM7@0E5AD03Ph>013@d<0GUiN
0=?Cd`3Jf]X0RHV904A4A02=SHd0[Zj^0<K6aP2KVi/0b<S80<c<c03Hf=P20<71`@0307moO`20P800
>3Ph008071`L01D08B4Q02h^;P0`<3009BDU02@T900[:b/0=cLg05UIF@27QhL0KVi^0:RXZ01VIVH0
FEUI030`<01WIfL0/;2`0;Ng]`3Ph>00fMWI0<[:bP3Cdm<04Oooool000oooooo06d0^KVi05iNGP34
a<@0H61P092@T01EEED0FEUI0:BTY01IFET0PX:206UYJ@0[:b/0Kfm_06EUI@1QHF40?Cdm071`L011
@D40MgMg05mOG`1LG5`0Kfm_09jNWP2EUID0A4A4061PH00L71`0@d=307inOP11@D40HF5Q0492@P0I
6AT0L71`03@d=01:BTX0D51@02DU9@19BDT09RHV05EEE@0T92@05aLG03`l?00X:2P0@D5104e=C@0F
5QH0Bd];03`l?00_;bl0?clo01lO7`14A4@0Lg=c02HV9P0d=3@0EUIF03/k>`0[:b/0MGEe04];B`0b
<S80JFUY05ADE00e=CD0?Shn04e=C@0m?Cd0<c<c061PH018B4P0De=C03lo?`0k>c/0HV9R02h^;P2;
Rh/0YJFU04U9B@0W9bL0FUYJ03Ph>00];Bd0R8R804];B`0o?cl0@D5107emO@0[:b/06a/K0451@@1P
H600ADE509bLW037alL0J6QX0451@@1dM7@0Hf=S03`l?010@400K6a/0410@01eMGD0@T9201/K6`1?
Cdl0@4100080E5AD0140=SHf06=SH`1BDU80;Rh^04i>CP0L71`0?clo05UIF@0o?cl0;2`/02l_;`0h
>3P0L71`0492@P1HF5P0Bd];03Ph>00206MWI`2P04=3@`0Q8B40Jf][05ADE013@d<0dm?C07=cL`0]
;Bd0PH610::RXP0n?Sh0JVYZ01hN7P1@D500IfMW07emO@19BDT0A4A40=CDe013@d<0FUYJ08F5Q@0k
>c/0A4A4061PH00_;bl0NGUi061PH00m?Cd0Fe]K03dm?@1dM7@0DU9B04Y:BP1QHF40YZJV05EEE@0a
<C40>CTi09:BTP1TI6@0PX:207QhN02;Rh/0D51@08j>SP39bLT0PX:206i^KP2n_[h0FUYJ05QHF027
QhL0FUYJ09^KV`2ZZZX0GEeM02/[:`1ADE406ATI03/k>`11@D40EeMG0;Bd]01jNWX0CDe=0:j^[P1M
GEd0=cLg04e=C@0_;bl0@T9202h^;P0O7al0FEUI08>3P`2KVi/0BDU904=3@`1=CDd0BTY:01lO7`1=
CDd0[Jf]09jNWP1@D5008B4Q05QHF00o?cl0EEEE0:VYZ@12@T809bLW06IVIP1jNWX07QhN05=CD`1O
Gel0?clo05IFEP0T92@0=CDe05ADE02EUID0PH6105]KF`0k>c/0Hf=S02TY:@0/;2`0IVIV03Ph>00d
=3@0GUiN04A4A01QHF40[:b/02l_;`1@D500DU9B04U9B@0N7Qh0=SHf09fMW@1HF5P0<30`06a/K01A
DE40>c/k06=SH`2l_;`0?Cdm020P801VIVH0H61P04Q8B01SHf<0E5AD03Xj>P12@T80FEUI024Q8@0d
=3@0NGUi02XZ:P1VIVH0QhN704U9B@1:BTX0`L7108>3P`1KFe/0d];B0;fm_@27QhL07QhN09bLW02/
[:`0NWYj03Lg=acooooo00X0GEeM07QhN01RHV80IVIV0=OGe`34a<@0>SXj020P800I6AT05QHF0`0E
5AD0400H61P0GUiN03dm?@0a<C4071`L01TI6@0Y:BT0BTY:01LG5`0H61P06ATI05eMG@2?Shl0];Bd
05EEE@0I6AT301DE5@0m028R8P13@d<0Jf][04E5A@0m?Cd0=cLg05]KF`2`/;00^[Zj08n?S`36a/H0
PX:20<30`01hN7P0>CTi02DU9@0T92@08R8R01DE5@0B4Q806QXJ03De=@1YJFT0OGem03Hf=P0G5aL0
7AdM07emO@3Ogml0c<c<03lo?`0i>CT0F5QH03`l?02ZZZX0]kNg09JFUP1@D5004a<C02DU9@1MGEd0
NGUi02d];@0P8200=3@d05EEE@0f=SH06ATI01<C4`0E5AD0@T920;Fe]@2BTY80CDe=0:^[Z`2GUiL0
;Bd]02@T900C4a<03`l?00h>3P0201<C4`1201DE5@0>3Ph03`l?04A4A01NGUh0Zj^[092@T01gMgL0
Ti>C08F5Q@2<S8`0:b/[04I6AP2CTi<0YjNW07=cL`1lO7`0T92@0;Rh^03Lg=`0MGEe01@D500C4a<0
8B4Q03Xj>P1CDe<0LW9b03Xj>P1NGUh0SXj>09>CT`2n_[h0b<S80=GEe@33`l<0X:2P08R8R02h^;P0
b/[:0<71`@1hN7P04a<C010@400A4A404a<C01@D500A4A409BDU0410@00i>CT0;Bd]04I6AP1^KVh0
IfMW08J6QP21PH40TY:B08n?S`2_[jl0WinO06QXJ01^KVh0MWIf04Q8B00L71`06QXJ0P0E5AD0A00/
;2`0YJFU0<71`@2m_Kd0N7Qh08B4Q01=CDd0>CTi04a<C021PH40^[Zj09nOW`39bLT0SXj>0:NWY`2Z
ZZX0Lg=c06UYJ@1RHV80EeMG0;>c/`3MgMd0YJFU0;Zj^P2EUID09RHV01dM7@0Q8B407QhN01dM7@0Q
8B40>SXj06i^KP2PX:00ADE502h^;P0Z:RX0=3@d024Q8@0H61P05aLG01lO7`0_;bl0Cdm?03Hf=P11
@D40DU9B09:BTP1eMGD0De=C065QH@1JFUX071`L01dM7@0c<c<0^k^k06ATI00m?Cd0CTi>07inOP2@
T900EUIF01LG5`0^;Rh0@T9201DE5@0C4a<05ADE0P0C4a<08@0H61P07AdM028R8P0a<C40_Kfm0:^[
Z`2CTi<0FUYJ08Z:RP1YJFT07AdM02l_;`0^;Rh0<C4a092@T02BTY80FUYJ09nOW`38b<P0b/[:04M7
A`1:BTX0V9RH04A4A01VIVH0N7Qh0;>c/`3EeMD0h^;R0;2`/032`/80cLg=09fMW@0201`L700F01dM
7@0[:b/0;Bd]02TY:@0T92@09BDU02LW9`0f=SH0KVi^06MWI`1_Kfl0RHV906UYJ@0d=3@0BTY:065Q
H@2BTY80/K6a0=[JfP2WYjL0NWYj071`L17ooooo000?ooooo`3o0<G5a@1PH600/[:b07emO@2d];@0
J6QX05YJFP2TY:@0KFe]0;:b/P33`l<0IVIV07alO01PH600QXJ605EEE@1jNWX0@41008J6QP1VIVH0
@41003Ph>01lO7`0RXZ:03/k>`1`L700CTi>03lo?`1hN7P0Bd];05eMG@0h>3P07alO069RHP0Y:BT0
FUYJ05]KF`0o?cl0ATI601TI6@1:BTX0B4Q801lO7`0l?3`0:BTY04E5A@1;Bd/08b<S04M7A`0j>SX0
;Bd]05ADE013@d<0ADE506EUI@0G5aL0ADE503Hf=P0J6QX0<c<c07MgM`1]KFd0FEUI08B4Q00e=CD0
:BTY04a<C01]KFd0J6QX03lo?`1`L700@410038b<P1>CTh0?clo07EeM@0W9bL0Cdm?09^KV`1TI6@0
<30`07UiN@1HF5P092@T06i^KP10@400C4a<06][J`22PX80NGUi02l_;`14A4@0I6AT0451@@1PH600
M7Ad04m?C`18B4P0Hf=S069RHP1nOWh0DU9B05eMG@0l?3`0OWin055AD@0O7al0@D5103Hf=P1DE5@0
Fe]K055AD@1[Jf/0Cdm?03De=@1BDU80<c<c05=CD`1/K6`0ADE50410@012@T80D51@07IfMP16ATH0
YJFU07emO@1:BTX0HV9R05YJFP1>CTh0<C4a04i>CP0f=SH0?Cdm0=CDe01_Kfl09bLW051@D02@T900
@d=308B4Q00j>SX0Kfm_051@D01/K6`09bLW07YjNP2e]KD0J6QX04M7A`1gMgL0B4Q8079bLP21PH40
A4A4075aL@1XJ6P0BTY:07UiN@1JFUX0QHF507emO@1UIFD0Fe]K0;Rh^01gMgL0K6a/059BDP2JVYX0
L71`0:2PX02OWil0VYZJ05EEE@2ATI40^KVi08V9R@1mOGd0/[:b06EUI@1IFET0RHV904M7A`1LG5`0
U9BD05aLG012@T80F5QH01/K6`0l?3`0EeMG05UIF@2NWYh0OWin04m?C`2[Zj/0Kfm_04U9B@1>CTh0
;Bd]030`<014A4@0<S8b05MGE`1HF5P0KFe]04Q8B01?Cdl0BDU904Y:BP0Z:RX0>CTi05]KF`24Q8@0
I6AT03dm?@1JFUX07QhN04];B`26QXH0E5AD03Ph>01YJFT0R8R803/k>`1?Cdl0FUYJ04I6AP1RHV80
=SHf06YZJP1YJFT0Ti>C08b<S013@d<0Q8B407UiN@14A4@07AdM061PH01HF5P0;bl_0861P@0E5AD0
ATI609fMW@1:BTX0Jf][092@T01iNGT0>3Ph02TY:@2@T900?Shn004061PH0@1LG5`2034a<@0O061P
H02i^KT0GemO028R8P0n?Sh0GUiN04=3@`1bLW80C4a<01dM7@1]KFd0Ogmo04Y:BP0k>c/0MWIf01`L
701<C4`0NWYj059BDP1YJFT0cLg=06ATI00Z:RX0Ogmo0:2PX02:RXX0:b/[07EeM@2MWId0PX:203Hf
=P0Looooo`0c05eMG@2:RXX0GEeM0;Bd]03Ng]h0dm?C09VIV@13@d<06a/K01XJ6P0G5aL071`L02<S
8`0_;bl0=cLg06UYJ@12@T80:b/[01hN7P0L71`0FUYJ034a<@0H61P05ADE05QHF00k>c/0/k>c08f=
S@0];Bd0<C4a03/k>`12@T80JFUY09JFUP2/[:`0UIFE05ADE018B4P0?Cdm03Hf=P1MGEd0eMGE0;fm
_@1LG5`0Xj>S09>CT`1/K6`09bLW01XJ6P0I6AT05QHF00804Q8B02L05aLG01PH601OGel0=SHf01`L
7012@T80_Kfm0>CTi03Cdm<0LW9b05UIF@2NWYh0Ti>C092@T03;bl/0?Shn02PX:00J6QX05ADE01hN
7P1MGEd0RHV903lo?`0O7al0:b/[05QHF01^KVh0>3Ph01lO7`1mOGd0bl_;0;fm_@3>c/h0fMWI0<;2
`P1mOGd0=cLg010@400?3`l00P0@4100;00g=cL0F5QH01HF5P0C4a<071`L09NGU`2ZZZX0c/k>096A
T@2>SXh0X:2P0;Bd]01oOgl0ZJVY0:j^[P32`/80][Jf0:6QX@1WIfL0IVIV0=;BdP1eMGD07alO01XJ
6P0C4a<05ADE038b<P1TI6@0Ogmo05eMG@1SHf<0YjNW0<;2`P3Ph>00/k>c0451@@0H61P0;2`/08J6
QP2YZJT0aLG50::RXP11@D404a<C0P0A4A40?P0C4a<05QHF03dm?@0[:b/0Bd];05IFEP1YJFT0<30`
01XJ6P0c<c<0IfMW06e]K@2l_;`0dm?C0;jn_P2j^[X0[jn_03Ph>00S8b<07AdM01`L700I6AT07AdM
01hN7P1mOGd0[Jf]0;fm_@2YZJT0NGUi09VIV@1[Jf/0Kfm_08n?S`2RXZ80b/[:0:>SX`1ADE407alO
06e]K@3<c<`0[jn_0:^[Z`2i^KT0c<c<0>3Ph03<c<`0DE5A05UIF@1kNg/0<S8b02<S8`0m?Cd0;Rh^
02LW9`0l?3`0O7al09NGU`10@400:BTY024Q8@1<C4`07QhN0P0G5aL0EP0R8R80ADE502LW9`0T92@0
C4a<08>3P`1iNGT0FUYJ096AT@2:RXX0KFe]01`L700N7Qh0>SXj09fMW@0Y:BT0A4A4065QH@28R8P0
LW9b09>CT`0K6a/0820P04];B`0E5AD04a<C01DE5@0D51@05QHF01/K6`0O7al08R8R03/k>`2WYjL0
Ogmo09RHV01aLG40/k>c04M7A`0T92@0;Rh^04=3@`0m?Cd09RHV07]kN`36a/H0`/;20:6QX@2CTi<0
R8R809FEU@17AdL0@410059BDP1jNWX0U9BD0=GEe@2l_;`0NGUi0:b/[03Cdm<0RXZ:01`L700M7Ad0
820P02LW9`0U9BD09bLW02/[:`0V9RH0:2PX03De=@1[Jf/0HF5Q03Hf=P1mOGd0Ogmo02h^;P2_[jl0
Y:BT0;6a/@39bLT0Shn?06EUI@1YJFT0D51@4Oooool000oooooo0;40WYjN05UIF@2WYjL0Hf=S08V9
R@1ADE40De=C07UiN@1@D500RHV909>CT`1<C4`0Hf=S05ADE022PX80EEEE05iNGP0k>c/0Q8B407al
O01DE5@0?clo08>3P`1OGel0@T92079bLP10@400?Shn05]KF`0o?cl0PH6104a<C00N7Qh0FEUI03Hf
=P1QHF40Fe]K030`<00_;bl09BDU055AD@0f=SH0820P030`<00[:b/0JVYZ06QXJ00X:2P0@T92034a
<@1:BTX0Kfm_04M7A`1@D500DE5A01lO7`1]KFd0E5AD034a<@0P8200?3`l051@D01VIVH0Shn?04a<
C00a<C40EEEE04Y:BP0k>c/0>3Ph07YjNP1HF5P0<S8b02TY:@15ADD0NGUi04=3@`1^KVh0V9RH0492
@P0h>3P0NWYj05mOG`0Z:RX0M7Ad02DU9@0f=SH0@T9205iNGP0i>CT06ATI04Q8B01bLW80EEEE07mo
O`29RHT0DU9B03hn?P1?Cdl0@41006UYJ@1@D500@d=303Lg=`2CTi<0KFe]024Q8@1EEED0>SXj04];
B`1hN7P0DU9B06QXJ01;Bd/0EEEE06QXJ00i>CT0ATI606=SH`18B4P0De=C05YJFP0j>SX0JVYZ04Y:
BP27QhL0MWIf04E5A@1QHF40C4a<06YZJP0h>3P0EEEE04=3@`0i>CT0`l?30861P@16ATH0I6AT09RH
V01MGEd0Zj^[05YJFP1/K6`0Fe]K07UiN@0m?Cd0N7Qh06YZJP1`L700AdM7065QH@0c<c<0M7Ad06UY
J@0n?Sh0LG5a04e=C@1PH600OGem06][J`1jNWX0Lg=c04E5A@1?Cdl0VIVI06i^KP1=CDd0EeMG0861
P@1OGel0[:b/0:2PX027QhL0Cdm?08F5Q@2XZ:P00P2?Shl0802ZZZX0Fe]K05mOG`1mOGd0HF5Q09BD
U01aLG40>3Ph04a<C015ADD0=3@d05IFEP1VIVH0IfMW0::RXP1QHF40H61P0;no_`21PH40@T9203Ti
>@0^;Rh0@T9204];B`0`<300H61P05iNGP1RHV80@D5107IfMP1jNWX0F5QH0P1EEED0>P22PX80QXJ6
06EUI@0h>3P0QhN703hn?P1CDe<0TI6A04Q8B019BDT0OGem08n?S`0m?Cd0FUYJ04M7A`0P82009RHV
01lO7`0W9bL0EEEE09>CT`1ZJVX0A4A404e=C@1LG5`0ATI602DU9@1IFET0=cLg038b<P1`L700C4a<
04=3@`29RHT0?3`l08>3P`22PX80Lg=c04i>CP0Y:BT0TI6A05iNGP0T92@0F5QH02l_;`0`<300LG5a
0<W9b@20P800<30`05YJFP2;Rh/0GEeM079bLP1HF5P0Bd];04Q8B01<C4`203lo?`0A0861P@0_;bl0
HV9R09JFUP1KFe/0PX:20=GEe@2RXZ80AdM70:RXZ02=SHd0Kfm_03/k>`2BTY80b/[:09>CT`1:BTX0
7?ooool02`2e]KD0b/[:0::RXP30`<00S8b<08j>SP2SXj<0XJ6Q06EUI@0k>c/08b<S008071`L02H0
6a/K01lO7`13@d<0MgMg06e]K@17AdL0CDe=09JFUP2][Jd0GUiN065QH@2TY:@0U9BD0<g=c@3AdM40
[Jf]079bLP1GEeL0ADE50492@P1ZJVX0MWIf0:FUY@16ATH0>3Ph02PX:00W9bL0@D510<K6aP2o_kl0
Ogmo03<c<`0P8200>3Ph061PH01ADE408R8R01PH60804a<C02d05QHF028R8P1PH600MgMg08F5Q@2F
UYH0Q8B405QHF01>CTh0KVi^0<G5a@2WYjL0RHV902d];@0X:2P0?Shn03dm?@0b<S80;Rh^01HF5P0B
4Q809bLW06=SH`1mOGd0HV9R04A4A01HF5P0U9BD0;Ng]`2>SXh0Zj^[0;bl_02/[:`0dM7A0;no_`1k
Ng/0MGEe05mOG`19BDT0Hf=S04m?C`0h>3P092@T01TI6@0T92@00P1;Bd/01@0d=3@0S8b<0=WIf@3J
f]X0emOG0080d];B00/0b/[:0:n_[`2;Rh/0WYjN02/[:`0G5aL07AdM04M7A`1PH600DE5A02<S8`02
01/K6`2C01DE5@0T92@0EeMG0<[:bP2_[jl0Q8B408J6QP2/[:`0S8b<04Y:BP0T92@0<C4a059BDP1F
EUH0TI6A0:b/[01CDe<0DE5A03@d=00H61P07AdM051@D014A4@0@d=304];B`0b<S806a/K01HF5P0E
5AD05QHF07MgM`29RHT0_;bl08f=S@3AdM40P82006EUI@1=CDd0AdM70451@@1>CTh0DU9B05MGE`1;
Bd/0EEEE07IfMP1oOgl0bLW90<G5a@1jNWX0=SHf08B4Q02^[Zh0b/[:0<71`@1nOWh0>SXj01`L700N
7Qh0BTY:07AdM02XZ:P0e=CD0;Fe]@2d];@0UYJF06m_K`0n?Sh0Bd];06YZJP1bLW80PX:208>3P`2:
RXX0YZJV0<g=c@2^[Zh0N7Qh02/[:`0m?Cd0FEUI059BDP0U9BD09bLW03Hf=P15ADD08b<S04];B`1e
MGD0Hf=S0410@015ADD0V9RH0;6a/@1ZJVX0EUIF04];B`1>CTh0Jf][04i>CP16ATH0IVIV08>3P`2H
V9P0UIFE0451@@0P8200FEUI01HF5P0C4a<05ADE01LG5`0P82008R8R024Q8@0R8R80FEUI04E5A@17
AdL0ZJVY06m_K`0c<c<0<30`04A4A01FEUH0KFe]07MgM`1CDe<0M7Ad08^;R`27QhL0M7Ad06e]K@2S
Xj<0@d=303Ph>016ATH0Hf=S0:ZZZP24Q8@0@41004=3@`1?Cdl0JVYZ09BDU026QXH0:2PX0080820P
01D092@T02XZ:P0];Bd0<30`02d];@0e=CD0GUiN06QXJ01GEeL0Fe]K0;2`/03AdM40YJFU0;Zj^P3:
b/X0e]KF0:>SX`1OGel0Ng]k08b<S024Q8@04Oooool000oooooo09l0[Jf]06UYJ@36a/H0S8b<09FE
U@1PH600M7Ad0;6a/@1GEeL0T92@0:n_[`1=CDd0Ph>304Y:BP25QHD0GEeM08>3P`15ADD0S8b<09ZJ
VP1<C4`0=CDe092@T02BTY80@D5108Z:RP0j>SX0@D51071`L01?Cdl0UIFE05aLG00L71`0I6AT03hn
?P1SHf<0EUIF03dm?@0];Bd0:RXZ061PH00i>CT071`L03/k>`10@400De=C061PH00a<C40>c/k03lo
?`18B4P0GemO065QH@1DE5@0K6a/01hN7P1LG5`0LG5a01lO7`0G5aL0;Rh^05QHF00k>c/0IFEU05UI
F@0e=CD0G5aL04E5A@1IFET0?3`l04I6AP18B4P0;Bd]04M7A`11@D40Ogmo04a<C01XJ6P0RHV904E5
A@0_;bl0JFUY04U9B@0_;bl0Jf][01XJ6P0m?Cd0ATI606i^KP0R8R80=cLg08:2PP1kNg/0C4a<07mo
O`1jNWX0EeMG07MgM`2>SXh0EeMG08R8R01DE5@0De=C03Ti>@1mOGd0G5aL02<S8`1>CTh0@D5108:2
PP1gMgL0ADE505aLG00h>3P0FEUI05ADE00a<C40BTY:05MGE`13@d<0Fe]K06ATI01EEED0IVIV0451
@@28R8P0NWYj071`L01CDe<0BTY:06ATI01DE5@0PX:204i>CP0d=3@0bl_;08Z:RP1NGUh0Z:RX0:VY
Z@1MGEd0YJFU04=3@`1_Kfl0LW9b06EUI@0`<300NWYj08R8R01]KFd0HF5Q08>3P`0f=SH0P82004];
B`0i>CT0HV9R06EUI@1HF5P00P1XJ6P09P1lO7`0LW9b05QHF01XJ6P0X:2P04I6AP13@d<0C4a<08^;
R`24Q8@0Zj^[09NGU`1<C4`0K6a/0:FUY@2`/;00RXZ:09NGU`2][Jd0=SHf09VIV@2JVYX0JVYZ0;6a
/@2LW9`0EeMG04M7A`11@D40G5aL0;Zj^P2GUiL0EUIF09^KV`15ADD0?clo0:NWY`1UIFD0ATI60P0/
;2`0F@14A4@0820P038b<P1VIVH0MWIf06=SH`0m?Cd0Ogmo04Y:BP0e=CD0<S8b05]KF`1nOWh0QhN7
05IFEP0o?cl0KFe]0451@@14A4@0Q8B405MGE`12@T80PX:207moO`0m?Cd0De=C05EEE@1;Bd/0;2`/
02PX:00f=SH0EEEE0:n_[`2CTi<0Jf][071`L01ZJVX0@d=302/[:`1<C4`0A4A403Ti>@13@d<0?3`l
03Lg=`2PX:00?clo07emO@1jNWX0KVi^04e=C@0U9BD0WinO04A4A00Z:RX0E5AD01/K6`17AdL0XJ6Q
0<?3``1_Kfl0>SXj0820P02YZJT0E5AD08N7Q`1XJ6P0Bd];051@D01IFET08B4Q03<c<`2:RXX0C4a<
06i^KP21PH40;Rh^07moO`33`l<0Jf][03Ph>02XZ:P0[:b/0861P@0k>c/0EEEE0;Fe]@35aLD0N7Qh
01cooooo0700alO70<c<c03Cdm<0b<S80861P@15ADD0CDe=055AD@1NGUh0MWIf08N7Q`12@T80;2`/
02@T900O7al08B4Q03Hf=P3>c/h0`/;20::RXP2`/;00bLW90;:b/P2?Shl0M7Ad08>3P`1^KVh0`/;2
09jNWP2k^k/0V9RH08F5Q@2KVi/0clo?0=WIf@2/[:`0F5QH05EEE@1gMgL0QXJ608Z:RP2IVIT0XZ:R
05mOG`1eMGD08R8R00h>3P0G5aL0>3Ph07YjNP0_;bl06ATI01DE5@0N7Qh0G5aL0<W9b@2TY:@0Jf][
0451@@0J6QX06ATI01dM7@0c<c<0S8b<059BDP13@d<0DE5A01PH600E5AD0<c<c04Y:BP1CDe<0@410
02h^;P0K6a/05ADE038b<P2b/[80fMWI0<30`02_[jl0Y:BT09NGU`1IFET0RHV90<G5a@3Bd]80NWYj
06EUI@1bLW80GEeM069RHP2b/[80JFUY034a<@0P8200CDe=05EEE@0K6a/07AdM02PX:02HV9P0h>3P
0<o?c`2VYZH0JFUY07emO@2TY:@0LW9b02<S8`0m?Cd061PH0P0E5AD0<00D51@06ATI05QHF01CDe<0
>CTi01`L700F5QH05ADE01LG5`1hN7P0=CDe02LW9`0Z:RX0TI6A06UYJ@26QXH0;Rh^059BDP1oOgl0
BTY:05YJFP2RXZ80W9bL04I6AP24Q8@0PH6104];B`16ATH0?Shn03Ti>@19BDT06QXJ01TI6@0E5AD0
5aLG01HF5P0c<c<0emOG0;Jf]P1YJFT0Shn?04a<C00^;Rh08B4Q08F5Q@1PH6007AdM01LG5`<05ADE
04<09RHV06YZJP2FUYH0WinO0=gMg@32`/80_[jn0;fm_@2OWil0d];B0:2PX01NGUh0?clo01PH600L
71`0BDU906QXJ01aLG40FUYJ069RHP2j^[X0[Zj^07emO@1EEED0JFUY07inOP2GUiL0Y:BT096AT@2G
UiL0d=3@0=CDe02_[jl0_kno0<[:bP32`/80^KVi09VIV@2VYZH0SXj>06IVIP1JFUX0KFe]03Ph>00Z
:RX0?clo075aL@0b<S80820P05eMG@1ADE40Z:RX05EEE@0H61P0>CTi01dM7@0d=3@0YZJV0<30`024
Q8@0XJ6Q05aLG01iNGT0<S8b01/K6`0T92@0GemO0080GEeM03P0@D5103<c<`1kNg/0>3Ph06a/K02h
^;P0F5QH010@400C4a<05ADE03hn?P33`l<0dM7A0:RXZ01DE5@09RHV01/K6`0_;bl0Y:BT09FEU@1S
Hf<0=cLg06IVIP2f][H0TI6A01hN7P0M7Ad0=3@d05=CD`13@d<0Ph>308V9R@1QHF40:BTY01dM7@0e
=CD0<c<c03Ph>00i>CT0>c/k051@D02IVIT0Vi^K069RHP1oOgl0a/K60<k>cP1^KVh0VYZJ0<k>cP38
b<P0/k>c0<O7a`1PH600=SHf0410@17ooooo000?ooooo`3o09BDU028R8P0a<C4071`L01nOWh0LG5a
096AT@2IVIT0Bd];07=cL`1/K6`0DU9B0;>c/`1;Bd/0KFe]09jNWP2JVYX0@d=30:b/[02GUiL0AdM7
0492@P2LW9`0Shn?04Y:BP1mOGd0=CDe07emO@26QXH0EeMG09>CT`16ATH0:2PX07AdM00k>c/0Hf=S
059BDP0a<C40BTY:02/[:`13@d<09BDU03lo?`1SHf<0;2`/055AD@1HF5P071`L04m?C`0h>3P0BDU9
069RHP0b<S80Jf][06UYJ@0K6a/0Cdm?05]KF`0a<C40=3@d06a/K01YJFT0H61P07emO@1WIfL0=cLg
08N7Q`20P800Jf][03De=@0k>c/0?3`l04Q8B01;Bd/0?3`l06ATI00g=cL0TY:B0:f][@1SHf<0@D51
05MGE`0n?Sh0DU9B09JFUP14A4@0>SXj05IFEP27QhL0<c<c01LG5`1;Bd/0CDe=04Y:BP2<S8`0ZJVY
04i>CP18B4P0N7Qh04];B`2PX:00L71`07UiN@12@T80Shn?04I6AP0i>CT0LG5a05=CD`24Q8@0TI6A
04=3@`1/K6`0>CTi07IfMP16ATH0>3Ph07alO01UIFD0@d=308b<S00h>3P0HV9R079bLP18B4P0X:2P
06YZJP1PH600GUiN03Hf=P1`L700<S8b05IFEP0e=CD0>3Ph0<O7a`26QXH0>CTi06a/K02DU9@0KVi^
0:j^[P0Y:BT0CDe=08V9R@1[Jf/0>SXj09jNWP2_[jl0C4a<09^KV`28R8P0>SXj08n?S`1HF5P0JFUY
09RHV02?Shl0DU9B07=cL`2:RXX0aLG509nOW`1YJFT0L71`0:>SX`18B4P0>3Ph071`L02LW9`0SXj>
0;Ng]`2][Jd0JFUY059BDP2<S8`0Vi^K0410@027QhL0T92@03Xj>P1RHV80PX:205UIF@2o_kl0[Jf]
04i>CP1kNg/0JVYZ02@T901=CDd0Ogmo05]KF`2FUYH0O7al07=cL`2f][H0K6a/06m_K`1CDe<0?clo
05MGE`0T92@0F5QH08j>SP2YZJT0TY:B04e=C@2<S8`0AdM7038b<P0U9BD0NWYj0<71`@2a/K40@410
04i>CP1BDU80=CDe05IFEP1nOWh0CTi>065QH@2PX:00M7Ad04A4A01eMGD0LG5a05]KF`0e=CD0=SHf
02XZ:P0i>CT0[Jf]09^KV`1iNGT0RXZ:092@T013@d<0>c/k069RHP1EEED0>CTi04i>CP0l?3`0@410
0:BTY00f=SH0OWin08>3P`1/K6`0@T9203Lg=`2VYZH0DU9B000S03Lg=`1oOgl0>CTi02h^;P1_Kfl0
_Kfm02`/;00J6QX0DU9B07inOP19BDT0=3@d04M7A`0H61P0?clo08:2PP1=CDd0=SHf07MgM`0G5aL0
De=C08N7Q`1;Bd/0SHf=0=?Cd`0o?cl08b<S07EeM@20P800Hf=S02/[:`0e=CD0EEEE0:FUY@0n?Sh0
7?ooool01P3:b/X0e=CD0>7Qh@31`L40YjNW075aL@<0Cdm?08D0D51@061PH01gMgL0QXJ606MWI`16
ATH0@D5106e]K@3AdM40YZJV08b<S02BTY80a/K605]KF`0c<c<07alO07MgM`30`<00a/K60;2`/02W
YjL0alO70:2PX01hN7P0J6QX0:6QX@2MWId0Zj^[071`L01IFET0A4A4024Q8@0R8R80RHV903Ti>@15
ADD0HF5Q01lO7`0D51@05ADE05YJFP26QXH0=cLg034a<@1_Kfl0/[:b096AT@1cLg<0E5AD030`<00b
<S80:BTY02HV9P0_;bl09BDU05MGE`1DE5@0@41004Y:BP0K6a/092@T04a<C01EEED0=SHf01lO7`0`
<300:RXZ01PH601OGel0a/K609RHV02QXJ40][Jf0<G5a@2h^;P0S8b<03/k>`0V9RH0GemO07=cL`1D
E5@0IfMW09RHV02OWil0Xj>S0:RXZ02NWYh0IfMW01DE5@0l?3`0EEEE08b<S01=CDd0/;2`055AD@1O
Gel0;bl_028R8P0f=SH0NGUi04E5A@0O7al08R8R01DE5@0B4Q804a<C01DE5@0N7Qh0LG5a05iNGP0R
8R807QhN01DE5@0M7Ad0O7al03Lg=`0Q8B408R8R07emO@1ADE40<c<c06QXJ017AdL0[Zj^08R8R01=
CDd0V9RH0=CDe02GUiL0TI6A09BDU01HF5P0C4a<0080>c/k00L0<c<c01HF5P0F5QH05ADE01LG5`0F
5QH0;Rh^0080fMWI00L0Q8B407IfMP2EUID0>3Ph024Q8@1NGUh09BDU00@05ADE01P05aLG03lo?`1A
DE40Ogmo07emO@3Ti>@0]kNg08J6QP1JFUX0Cdm?0820P01kNg/0QXJ608:2PP0o?cl071`L03<c<`1^
KVh0EeMG05ADE010@400TY:B0=[JfP3GemL30;Zj^P0M0;bl_036a/H0^;Rh0;:b/P3Kfm/0inOW0=SH
f02@T900K6a/08:2PP2:RXX0LG5a08N7Q`2d];@0`l?30<g=c@1ZJVX0=SHf04I6AP1EEED09RHV01/K
6`0I6AT0:RXZ05QHF01jNWX0CTi>01HF5P0K6a/00P0M7Ad06P0f=SH0UYJF092@T02][Jd0PH61096A
T@1ZJVX0<c<c04M7A`0X:2P092@T0451@@1gMgL0YZJV0;Vi^@2HV9P0Z:RX0<O7a`0_;bl051@D01DE
5@0G5aL05QHF06a/K02_[jl0?Shn0`0J6QX09`0N7Qh0=cLg09VIV@2MWId0NGUi0:n_[`2WYjL0HF5Q
02DU9@0K6a/0:BTY061PH01?Cdl0HV9R09>CT`25QHD0BTY:03@d=02=SHd0N7Qh05EEE@1OGel0IFEU
09fMW@1dM7@0AdM706m_K`2UYJD0JVYZ0=3@d02;Rh/0^KVi09fMW@1cLg<0H61P0:BTY00i>CT0>c/k
04=3@`0Aooooo`003oooool0o`2VYZH0KFe]08b<S01aLG40XJ6Q06][J`1WIfL0NGUi04i>CP2/[:`0
ZZZZ05YJFP2QXJ40@D51061PH01eMGD0Ogmo04=3@`2j^[X0GUiN05EEE@1PH600Lg=c05mOG`1ADE40
Kfm_02PX:01DE5@0Fe]K04E5A@2>SXh0?clo020P801PH600AdM708n?S`1IFET0<c<c02/[:`0a<C40
>3Ph034a<@0R8R80=SHf034a<@1oOgl0G5aL028R8P0o?cl0:2PX06UYJ@1nOWh0<30`04];B`14A4@0
61PH05ADE012@T809BDU03De=@1DE5@0IVIV05eMG@23Ph<092@T01lO7`1LG5`0CTi>051@D011@D40
HV9R03Hf=P0d=3@08b<S04Y:BP1JFUX0=CDe06a/K02][Jd0CDe=069RHP2=SHd0C4a<02LW9`1]KFd0
9BDU03`l?01MGEd0Ogmo05QHF00I6AT0Fe]K04U9B@0e=CD0D51@06MWI`1DE5@0FEUI06ATI00V9RH0
JVYZ06=SH`1:BTX0820P08b<S01SHf<07alO05IFEP0E5AD0BDU906MWI`1LG5`0HF5Q02<S8`1=CDd0
L71`03lo?`1DE5@0@T9202<S8`18B4P0GUiN05IFEP1CDe<0>CTi06a/K01^KVh0JVYZ04=3@`0L71`0
QHF50451@@1IFET0<C4a02TY:@2EUID0U9BD04M7A`1^KVh0Shn?03@d=020P800CTi>05aLG01TI6@0
LW9b02h^;P1UIFD0G5aL051@D01MGEd0=CDe02LW9`2>SXh0CDe=03dm?@1SHf<0?Cdm06YZJP1gMgL0
IVIV07IfMP1DE5@0=CDe07QhN02RXZ80Rh^;04Y:BP1?Cdl0JFUY04=3@`1WIfL0Rh^;06YZJP1LG5`0
Vi^K09>CT`2;Rh/0TI6A08B4Q014A4@0MGEe06UYJ@0S8b<0Kfm_09:BTP1LG5`0=CDe05]KF`0Y:BT0
NWYj04U9B@1SHf<0W9bL06MWI`1fMWH0];Bd0451@@1FEUH0GUiN05]KF`2IVIT0De=C030`<01FEUH0
Kfm_06IVIP1CDe<0[jn_08B4Q012@T80>SXj04I6AP1EEED0QHF505]KF`1HF5P0HF5Q028R8P1PH600
P82004Q8B01/K6`0[:b/06QXJ00R8R80ATI605=CD`1KFe/0O7al06i^KP1KFe/0HF5Q0:VYZ@1oOgl0
<C4a09jNWP2>SXh0AdM702@T901UIFD0Jf][03dm?@1oOgl092@T06QXJ02KVi/0Bd];0;>c/`35aLD0
QHF503dm?@0M7Ad0Shn?038b<P008`0G5aL0Cdm?03Xj>P0i>CT0QXJ60<c<c01SHf<08B4Q04U9B@1k
Ng/0Fe]K03Hf=P1GEeL0?3`l02/[:`1EEED0C4a<03Ph>01VIVH0:BTY059BDP2ATI40Fe]K092@T03J
f]X0NWYj03lo?`2NWYh0Ti>C07]kN`0d=3@0KVi^07alO027QhL0BDU901cooooo01h0gMgM0=3@d031
`L40alO70;Bd]02c/k<0QXJ607alO01jNWX0GemO059BDP1>CTh0Hf=S08f=S@2KVi/0YjNW0=;BdP31
`L40NGUi04U9B@2NWYh0f][J07IfMP0o?cl0LW9b04Y:BP2OWil0bLW90<C4a036a/H20<;2`P0e0:JV
YP2?Shl0UYJF0:RXZ02JVYX0GUiN03/k>`0];Bd09BDU01hN7P1:BTX0RXZ:04a<C013@d<0KFe]02LW
9`0G5aL0HV9R0=;BdP2QXJ40^KVi0;Zj^P26QXH0FEUI07AdM01EEED0FEUI06EUI@1VIVH0MGEe01XJ
6P0F5QH0ADE505YJFP0U9BD0ADE506IVIP0^;Rh0:2PX061PH01=CDd06QXJ01hN7P0f=SH0DE5A06=S
H`1oOgl0<C4a05UIF@1ZJVX0Zj^[051@D00<30`00P0:2PX06@0A4A40>CTi06e]K@1QHF40Q8B40<K6
aP2i^KT0`L710=GEe@22PX80TI6A0=SHf02DU9@0<C4a01`L701jNWX06a/K04A4A01>CTh08b<S02@T
901:BTX0M7Ad02TY:@0V9RH01@0E5AD0;@0Z:RX0Ogmo0410@00T92@07AdM03Ph>01LG5`0<30`01hN
7P0Q8B40TI6A04];B`0F5QH0[Zj^075aL@1<C4`0][Jf09:BTP2QXJ40c<c<0=GEe@1XJ6P0NWYj0:b/
[01;Bd/0@T9207emO@0K6a/05aLG01DE5@0F5QH05ADE03Ph>02SXj<0inOW0>WYj@2h^;P0Y:BT0;bl
_01ADE40A4A4051@D00R8R805ADE01@D500201DE5@0`01`L700T92@0@T92030`<02g]kL0emOG08j>
SP0e=CD0?clo03dm?@12@T80IFEU051@D00o?cl0Jf][06IVIP11@D40RXZ:05eMG@1KFe/0CDe=05aL
G037alL0a/K608F5Q@1YJFT0GemO05ADE01_Kfl0De=C07=cL`3GemL0e]KF0:j^[P1aLG40B4Q804Y:
BP10@400@T9206QXJ01lO7`0]KFe0=GEe@1dM7@0Hf=S05eMG@0I6AT06QXJ0P0I6AT06`0H61P0@d=3
06a/K01GEeL05ADE01lO7`0M7Ad071`L02HV9P0e=CD0QXJ608:2PP2][Jd0XZ:R0=cLg02?Shl0Jf][
06e]K@1eMGD0PH6109:BTP2HV9P0PX:209JFUP2o_kl0Zj^[01LG5`0201<C4`0_01DE5@0N7Qh0MgMg
04E5A@0E5AD05QHF01DE5@0J6QX06a/K02d];@18B4P0Z:RX075aL@0[:b/0=3@d059BDP0^;Rh071`L
02h^;P25QHD0WinO0:NWY`2<S8`0QXJ607IfMP1?Cdl0UIFE0;Jf]P1kNg/0M7Ad08N7Q`1gMgL0HV9R
08N7Q`2a/K40OWin069RHP3Hf=P0YJFU08f=S@2XZ:P0SHf=075aL@2BTY80ATI602XZ:P0o?cl04Ooo
ool000oooooo0?l0Vi^K08j>SP2GUiL0CTi>08F5Q@1bLW80Hf=S0410@00c<c<0Ng]k08V9R@1OGel0
JFUY03Ti>@1cLg<0L71`04e=C@0f=SH0SXj>07MgM`13@d<0;bl_04a<C00[:b/0>c/k07MgM`0^;Rh0
HV9R02h^;P0T92@0Fe]K04I6AP0Y:BT0GemO02DU9@1:BTX0CDe=03<c<`0V9RH0<S8b04A4A00U9BD0
8R8R04A4A00G5aL0>SXj055AD@0f=SH0?3`l01LG5`0e=CD0EeMG04Q8B01TI6@092@T018B4P1QHF40
L71`02PX:00^;Rh0@T92034a<@0j>SX0IVIV04=3@`0M7Ad0J6QX03Ti>@0@4100=CDe07QhN015ADD0
@410010@4012@T80JFUY0451@@1/K6`0XJ6Q01LG5`0];Bd0?Shn03lo?`0X:2P0KVi^01DE5@0/;2`0
=cLg06m_K`0L71`061PH05eMG@1QHF40E5AD05QHF01RHV80E5AD061PH01HF5P0ADE508F5Q@1KFe/0
Hf=S03De=@1mOGd0DU9B01lO7`1QHF40CTi>079bLP1BDU80=3@d075aL@0j>SX0H61P06=SH`0m?Cd0
E5AD07moO`17AdL0CTi>06YZJP1WIfL0MgMg04m?C`25QHD0J6QX06e]K@1BDU80>c/k08B4Q00k>c/0
Kfm_07YjNP0m?Cd0T92@08J6QP0o?cl0LW9b0:6QX@1CDe<0T92@05QHF01dM7@0FEUI08F5Q@17AdL0
LG5a06a/K01CDe<0Fe]K04m?C`0X:2P0MGEe04Y:BP15ADD0LW9b04I6AP0i>CT0IFEU08J6QP1kNg/0
K6a/03`l?01LG5`0PX:205IFEP0d=3@0C4a<079bLP1oOgl0Rh^;09fMW@1^KVh0A4A40;jn_P2NWYh0
P8200:6QX@2@T900@41006MWI`1fMWH0FEUI06MWI`21PH40Bd];04E5A@0l?3`0BTY:0:NWY`1;Bd/0
EEEE08n?S`0g=cL0G5aL09fMW@1BDU80H61P02/[:`0e=CD0GemO030`<00e=CD0EEEE07moO`1OGel0
<c<c069RHP1`L700EeMG061PH01ADE40MWIf09^KV`0g=cL0Bd];08R8R00k>c/0FEUI07YjNP0I6AT0
@T9208f=S@1kNg/0@d=304m?C`0k>c/0>3Ph03<c<`19BDT0=CDe06IVIP2OWil0Ng]k059BDP1mOGd0
Jf][051@D00f=SH0IfMW02LW9`1:BTX0Shn?05]KF`0h>3P0PH6101TI6@1@D500LG5a079bLP1HF5P0
7AdM09:BTP13@d<002<08b<S05IFEP0J6QX0>CTi08^;R`3?cll0NWYj02PX:013@d<0QhN705UIF@0k
>c/0H61P06=SH`0^;Rh0DU9B061PH00l?3`0LG5a034a<@1CDe<0Ng]k0492@P2DU9@0fMWI07MgM`10
@400V9RH07moO`1JFUX09bLW09^KV`1gMgL0AdM705EEE@0Looooo`80e=CD02H0a/K609VIV@2UYJD0
XZ:R06a/K00m?Cd0=SHf03De=@14A4@0K6a/08b<S01hN7P0^;Rh0=OGe`3;bl/0f][J0=;BdP3EeMD0
TI6A07]kN`2^[Zh0Z:RX0<c<c02RXZ80`L710<k>cP2k^k/0d=3@0<30`031`L40];Bd07alO023Ph<0
S8b<07moO`1IFET0C4a<03Lg=`80:BTY01l0>SXj03@d=011@D40EUIF06MWI`2LW9`0Vi^K09fMW@1Y
JFT0@d=309>CT`2RXZ80Ph>307IfMP1VIVH0Cdm?02l_;`0c<c<0>c/k04m?C`0Y:BT05ADE03Lg=`1C
De<0@T9203@d=01VIVH0Ph>304A4A012@T80Jf][00807QhN00D0=3@d05eMG@2SXj<0I6AT08>3P`02
07YjNP1C06QXJ00I6AT03@d=00d=3@0>3Ph03@d=00h>3P0J6QX0H61P09jNWP2m_Kd0fm_K0=?Cd`3:
b/X0/[:b0:6QX@3@d=00>CTi00h>3P0E5AD0E5AD01dM7@0L71`0>c/k03Ti>@0T92@0:b/[06UYJ@1B
DU80<C4a01HF5P0E5AD05aLG01DE5@0C4a<05QHF03Hf=P22PX80<30`02`/;01PH600CDe=02DU9@0O
7al0;bl_092@T012@T8061PH03De=@0_;bl0@D5104e=C@34a<@0bl_;0;jn_P3Jf]X0WinO06m_K`2K
Vi/0GEeM07YjNP1RHV80:RXZ01dM7@0O7al0:2PX04E5A@2VYZH0TI6A0;bl_03QhN40b<S80;Zj^P2k
^k/0S8b<07inOP0`<3008R8R01DE5@0H61P05QHF01LG5`0V9RH00P0c<c<0;00Q8B40UiNG0=?Cd`2Q
XJ40>c/k02TY:@0e=CD0?Cdm04i>CP1OGel0I6AT04=3@`0n?Sh0RXZ:09ZJVP1VIVH0JFUY07alO02L
W9`0bl_;055AD@0^;Rh0@d=304M7A`1GEeL0WIfM0;Bd]02^[Zh0ZZZZ0=7Ad@2k^k/0Rh^;09jNWP29
RHT0OGem09^KV`2h^;P0PX:205mOG`2c/k<0ZZZZ05aLG00J6QX05ADE0P0G5aL08`0E5AD05aLG01LG
5`14A4@0DU9B01DE5@0K6a/09RHV01lO7`0R8R80:2PX0410@026QXH0_;bl0=3@d03Cdm<0VIVI06][
J`1FEUH0AdM704=3@`1FEUH0MGEe07]kN`2ZZZX0dM7A0;jn_P0Z:RX05ADE01LG5`0U9BD0IFEU0<W9
b@1QHF405aLG00<06a/K01@07alO02l_;`1@D500GemO01TI6@0N7Qh0:RXZ05ADE00W9bL0820P04Y:
BP18B4P0MgMg0861P@2;Rh/0Zj^[09nOW`2RXZ80_;bl08B4Q080MgMg0140QXJ609NGU`2WYjL0]KFe
0;Ng]`1GEeL0[Zj^0<G5a@2j^[X0TI6A0;^k^`2JVYX0`L710:j^[P1^KVh0=CDe07AdM00Aooooo`00
3oooool0DP2<S8`0LW9b09^KV`1VIVH0TI6A09FEU@1gMgL0TY:B04Y:BP2;Rh/0VYZJ06IVIP2LW9`0
>SXj07IfMP1GEeL0QHF50410@02BTY80S8b<04a<C00a<C40VIVI07YjNP11@D40Shn?02h^;P1QHF40
R8R804e=C@20P800@D5102DU9@1cLg<0@d=305eMG@1@D500<S8b02d];@0V9RH0@D5102HV9P0O7al0
ADE503<c<`1:BTX0DE5A02TY:@16ATH0;Rh^04U9B@1BDU80ATI606=SH`1<C4`05QHF04U9B@1HF5P0
:2PX030`<00X:2P0GUiN055AD@1IFET0<30`01XJ6P1IFET0?3`l051@D00l?3`0BTY:03De=@0c<c<0
820P04M7A`1?Cdl0AdM706a/K01hN7P0;Bd]04A4A010@40202/[:`3;065QH@0J6QX0<C4a03Xj>P1/
K6`06a/K02HV9P1nOWh0G5aL04I6AP1QHF40FUYJ04i>CP2>SXh0EeMG04A4A02ATI40D51@05iNGP0_
;bl0Ph>304E5A@0V9RH0EeMG0492@P1PH600DE5A02/[:`1fMWH0>c/k06a/K012@T80Bd];07=cL`1U
IFD0?Cdm04A4A00g=cL0OGem06MWI`1;Bd/0MgMg04Q8B01YJFT0@d=302XZ:P1TI6@0Fe]K08J6QP1D
E5@0;Bd]09JFUP1hN7P0De=C09nOW`2IVIT0D51@08R8R011@D40Rh^;08N7Q`1gMgL0ATI605iNGP1Z
JVX0IFEU09JFUP1GEeL09bLW06a/K00l?3`0ATI606i^KP1<C4`0DE5A07MgM`2?Shl0MgMg07AdM01C
De<0Ogmo0;Fe]@19BDT0<S8b04Y:BP1hN7P0Q8B408j>SP2SXj<0H61P04e=C@2RXZ80ZJVY07IfMP2N
WYh0Ph>304U9B@2QXJ40Jf][061PH01^KVh0WinO061PH011@D40D51@01PH601BDU80FUYJ06e]K@2Y
ZJT0@T9204i>CP2HV9P0Bd];06QXJ00e=CD0?clo05QHF00J6QX0?Shn05IFEP29RHT0E5AD03@d=01g
MgL0BDU9024Q8@0d=3@0BDU90861P@2GUiL0DE5A051@D01bLW80@T92069RHP2FUYH0F5QH05iNGP2N
WYh0S8b<04E5A@1?Cdl0DE5A05=CD`17AdL0GEeM04E5A@1OGel0/;2`09>CT`1DE5@0PH6105aLG01<
C4`0@d=305MGE`0o?cl0=3@d04Q8B01?Cdl0>3Ph0:VYZ@17AdL0GemO071`L01kNg/0M7Ad01dM7@1m
OGd0@T9202PX:01FEUH08R8R03`l?02:RXX0clo?06i^KP0c<c<0@T9207AdM01IFET0@41006EUI@1K
Fe/0=CDe05QHF018B4P0=SHf079bLP0T92@0BTY:06e]K@14A4@0U9BD0<o?c`1iNGT0@D5109:BTP1U
IFD0@D5102`/;01`L7000P1dM7@00`19BDWoooooooooo`0Jooooo`0?0<G5a@2f][H0V9RH06i^KP1@
D500/K6a0;:b/P25QHD0KVi^06EUI@1YJFT0FUYJ05EEE@1WIfL0/;2`0080dm?C04@0S8b<0:n_[`3:
b/X0@41001`L701;Bd/0_[jn05eMG@0o?cl0B4Q806IVIP2IVIT0^[Zj0<S8b033`l<0UIFE0492@P0X
:2P0;2`/06IVIP1WIfL0De=C04i>CP1;Bd/0B4Q803De=@0c<c<07QhN01`L700Q8B40PX:20;fm_@29
RHT0Cdm?04=3@`27QhL0HV9R03Ti>@0/;2`0H61P04m?C`0S8b<0820P01TI6@0k>c/0=SHf01DE5@0G
5aL0Fe]K04e=C@1@D500C4a<06ATI02[Zj/0Shn?09ZJVP0g=cL0<c<c09:BTP2m_Kd0[:b/075aL@30
`<00clo?04=3@`1IFET04Q8B00l?3`803@d=0`0>3Ph0B00B4Q80U9BD0=_Kf`3;bl/0[jn_09NGU`2O
Wil0:2PX06e]K@0h>3P04A4A01<C4`18B4P07AdM01XJ6P0H61P0G5aL02`/;00Q8B40@D5108R8R010
@400;Rh^01DE5@0F5QH04a<C01DE5@0I6AT05aLG06m_K`1DE5@0?3`l08j>SP0j>SX0;Bd]038b<P0j
>SX0Ti>C03Lg=`0_;bl051@D01<C4`0W9bL0>c/k08V9R@3Ti>@0^;Rh05=CD`20P800][Jf09^KV`2k
^k/0KFe]079bLP1BDU80?clo0492@P1kNg/0[:b/05aLG00J6QX0E5AD06YZJP39bLT0][Jf0<K6aP3K
fm/0TY:B02XZ:P0S8b<07alO01PH60806ATI02D0820P03`l?00K6a/07AdM08n?S`32`/80bLW908f=
S@0g=cL08B4Q02/[:`0`<300Bd];06=SH`1UIFD0FUYJ06a/K01iNGT0];Bd0<G5a@32`/80[:b/0;bl
_019BDT0C4a<05mOG`20P800[jn_0=?Cd`2i^KT0Fe]K09:BTP31`L40d=3@09^KV`2;Rh/0Ng]k0080
QhN700T0/[:b0;>c/`26QXH0`<300;>c/`0X:2P07QhN01XJ6P0C4a<00P0E5AD0?00G5aL04Q8B01HF
5P1EEED09BDU01TI6@0`<30092@T02HV9P0Y:BT0=3@d0:b/[034a<@0d];B0;6a/@1VIVH0CTi>05EE
E@1FEUH0EEEE04A4A00g=cL0NWYj0=GEe@3@d=00UYJF09:BTP1CDe<0Hf=S08B4Q02<S8`0]kNg08F5
Q@0F5QH071`L01/K6`0M7Ad0820P02LW9`10@400DE5A01/K6`0M7Ad09bLW06a/K00a<C40=SHf03lo
?`17AdL0CDe=07QhN01dM7@0UYJF0<G5a@25QHD0_Kfm0;no_`2e]KD0W9bL08^;R`80OGem00h0b<S8
0;Zj^P2HV9P0_[jn08B4Q01[Jf/0V9RH0;Zj^P0g=cL0ADE505aLG03:b/X0Xj>S06i^KQ7ooooo000?
ooooo`0k0:2PX024Q8@0^k^k069RHP1/K6`0MWIf092@T020P800BDU908N7Q`2>SXh0Lg=c0:>SX`0f
=SH0Jf][07=cL`2JVYX0B4Q809BDU022PX80Fe]K05MGE`2=SHd0KVi^04M7A`1BDU80<C4a07QhN01g
MgL0@D5107inOP0`<300>SXj07IfMP1?Cdl0G5aL04m?C`0j>SX0A4A402`/;00f=SH0;2`/0451@@1H
F5P0<C4a04M7A`1=CDd0:2PX04Q8B00a<C40F5QH07=cL`1JFUX0IVIV059BDP0I6AT0Cdm?05QHF00W
9bL00P0R8R80@01OGel0CDe=05QHF013@d<07AdM05MGE`17AdL0EeMG04E5A@18B4P0=cLg03Ph>00_
;bl0CDe=061PH01EEED0TI6A09ZJVP0k>c/0BTY:03lo?`0`<300BTY:07moO`0V9RH0<30`03`l?025
QHD06ATI02XZ:P1CDe<0D51@04];B`1RHV80EUIF03<c<`1OGel0EEEE03`l?02ATI40G5aL06IVIP0e
=CD0Ph>303De=@0n?Sh0JVYZ04U9B@1OGel0BTY:03@d=01^KVh0<S8b06][J`16ATH0>3Ph05MGE`1X
J6P0>SXj04I6AP1;Bd/0I6AT051@D00o?cl206IVIP1^05mOG`18B4P0:2PX05eMG@17AdL0CTi>02h^
;P0M7Ad0Q8B405eMG@0i>CT0Ogmo08Z:RP1LG5`0RHV902DU9@1RHV80K6a/04U9B@0c<c<0SXj>08J6
QP10@400L71`05=CD`0W9bL0R8R804a<C01bLW80Shn?06MWI`1NGUh0N7Qh0:ZZZP2HV9P0QHF506][
J`1`L700/[:b06i^KP0m?Cd0Cdm?08n?S`2:RXX0[:b/0:NWY`19BDT0Ng]k0:ZZZP28R8P0@d=30;Jf
]P1jNWX0<S8b08Z:RP1NGUh0EeMG06IVIP2UYJD0I6AT04A4A01DE5@0:BTY06e]K@1^KVh0KFe]09RH
V01VIVH0QHF50;no_`1LG5`0KVi^03lo?`10@400IVIV02/[:`1DE5@0PX:20;Bd]026QXH0?3`l07al
O014A4@06QXJ03De=@1GEeL0PH6109BDU00n?Sh0K6a/065QH@0f=SH0EeMG09FEU@1LG5`0O7al0:JV
YP1mOGd0Cdm?06EUI@1YJFT0Jf][04U9B@1[Jf/0?Cdm071`L03;bl/0WIfM059BDP22PX8205eMG@0c
04Q8B01>CTh0@D5105ADE00j>SX0@T9203Hf=P2[Zj/0>CTi069RHP1/K6`0LW9b065QH@0L71`0MGEe
0451@@0X:2P0GEeM01lO7`19BDT0Y:BT0;Zj^P1QHF40>c/k05YJFP29RHT0BDU906QXJ01^KVh0EeMG
02`/;01;Bd/071`L03Ti>@22PX80>SXj05MGE`1;Bd/0>SXj0:BTY030`<00KFe]03dm?@21PH40JVYZ
05QHF00n?Sh0CTi>08b<S03AdM40D51@01cooooo00d0`<300:b/[02FUYH0JFUY03hn?P1^KVh0d];B
0<O7a`2EUID0S8b<08N7Q`1mOGd0QHF50080NGUi00X0d];B0<_;b`20P800>3Ph06UYJ@1oOgl0CTi>
03<c<`2KVi/0<S8b0P0L71`03`0_;bl0@D5106QXJ02i^KT0a<C409>CT`0m?Cd08R8R01hN7P0];Bd0
JFUY07IfMP17AdL0=CDe030`<00204i>CP0Z020P800R8R80CTi>06EUI@1iNGT092@T010@400B4Q80
?Shn04M7A`1GEeL0:b/[04i>CP1GEeL0AdM702XZ:P0U9BD0A4A4038b<P11@D40<C4a04I6AP1KFe/0
E5AD05mOG`1[Jf/0Ogmo0;bl_02>SXh0OGem0:VYZ@2l_;`0@T9208R8R02QXJ40IFEU09NGU`0c<c<0
EEEE00d=3@0>3Ph03@d=0P0@410201<C4`0:00h>3P1SHf<0IfMW055AD@0h>3P0@41006a/K00J6QX0
>3Ph04I6AP804A4A00l0@d=302@T900Q8B40410@03`l?016ATH07AdM02<S8`1UIFD0H61P0820P013
@d<09bLW01`L700G5aL00P0E5AD03@0/;2`0QXJ606=SH`23Ph<0:RXZ038b<P0m?Cd0?clo09RHV00i
>CT0;2`/00h>3P0K6a/00P0E5AD03`1DE5@0/[:b0:n_[`10@400>3Ph059BDP30`<00g]kN0=3@d02Y
ZJT0UYJF0<[:bP3Ng]h0UiNG03Ph>00201DE5@0m04=3@`0n?Sh0L71`0;bl_034a<@0bl_;0<S8b012
@T808R8R04M7A`0I6AT05ADE01dM7@0/;2`0;bl_01LG5`15ADD0c/k>0;2`/02>SXh0XZ:R09FEU@1X
J6P0?Shn03@d=013@d<0MWIf09RHV02CTi<0`<300;jn_P33`l<0YJFU06ATI00o?cl0M7Ad01/K6`0H
61P0;bl_06=SH`2e]KD0N7Qh069RHP12@T80Zj^[0:NWY`2ZZZX0X:2P06=SH`1]KFd0Cdm?04a<C01o
Ogl0bl_;0:NWY`3@d=00XJ6Q04i>CP0N7Qh05aLG00l?3`0201DE5@1<01TI6@0E5AD04a<C04M7A`1G
EeL06QXJ02PX:00V9RH0=cLg069RHP1jNWX0VYZJ0=CDe03;bl/0RHV9075aL@1BDU80CTi>04A4A01<
C4`0EEEE06UYJ@3:b/X0^k^k0:NWY`1EEED0K6a/0<;2`P24Q8@0=SHf01lO7`0a<C40QHF502DU9@0I
6AT071`L01dM7@0Q8B40;Rh^0410@01?Cdl071`L01lO7`0Y:BT0K6a/04M7A`0l?3`0ATI604];B`1H
F5P0ADE506=SH`1kNg/0d];B0=WIf@2e]KD0`<300;bl_02ZZZX0P82009VIV@2a/K40/[:b0<C4a02o
_kl0FUYJ05iNGP1VIVH0Ogmo0;Zj^P1@D500?Cdm06MWI`2l_;`0;Bd]028R8Q7ooooo000?ooooo`1E
0:>SX`24Q8@0/;2`0820P02MWId0DE5A04i>CP1dM7@0BTY:08^;R`1DE5@0Kfm_0861P@0^;Rh0EEEE
0:>SX`1mOGd0?Shn08R8R00n?Sh0>c/k03Ti>@1/K6`0GEeM04];B`25QHD0820P06e]K@23Ph<0B4Q8
06i^KP0e=CD071`L05UIF@1VIVH0P82003`l?00U9BD0;Rh^03De=@0S8b<04a<C02PX:00k>c/0AdM7
05iNGP1?Cdl092@T04];B`0/;2`0F5QH07EeM@0c<c<0MWIf04M7A`0I6AT0DU9B0410@00j>SX0A4A4
069RHP1NGUh0Cdm?05mOG`0e=CD0;bl_07alO01SHf<0D51@04M7A`1@D5009bLW0410@00g=cL0IVIV
05MGE`0e=CD0HF5Q09:BTP0m?Cd0AdM703lo?`0^;Rh0=CDe05aLG00202d];@3;03`l?01kNg/0;Bd]
01TI6@1NGUh0BDU905aLG02>SXh0RXZ:04i>CP1UIFD0EeMG03/k>`2JVYX0HV9R05QHF00n?Sh0U9BD
04A4A00^;Rh0K6a/04m?C`1/K6`0DU9B04a<C01gMgL0?Shn08N7Q`1XJ6P0ATI606EUI@17AdL0@D51
07QhN01FEUH0FEUI04Y:BP1ADE40Vi^K06UYJ@1iNGT0GEeM02d];@1gMgL0IfMW05EEE@12@T808b<S
08N7Q`1iNGT0?Cdm07AdM01hN7P0EEEE0:JVYP18B4P0QXJ607=cL`1=CDd0<c<c04E5A@1eMGD0DU9B
06m_K`0V9RH09bLW0:n_[`0o?cl0Bd];07AdM010@400MWIf06e]K@2QXJ40WIfM07emO@1CDe<0Shn?
0<c<c01ZJVX0:b/[04Y:BP1GEeL0Jf][0:6QX@2HV9P0D51@05YJFP2m_Kd0R8R803Hf=P1oOgl0Lg=c
030`<027QhL0<C4a03lo?`2MWId0Zj^[04m?C`1eMGD0Cdm?02d];@1ZJVX0GEeM079bLP26QXH0D51@
07QhN02o_kl0@D5106a/K019BDT0?Cdm07EeM@0U9BD0?clo051@D01UIFD0Lg=c0492@P21PH40CTi>
02DU9@0o?cl0VYZJ0;6a/@2e]KD0A4A4065QH@1DE5@0;bl_07emO@1aLG40@41007YjNP2^[Zh0Cdm?
04a<C024Q8@0GemO059BDP1LG5`0Rh^;03Xj>P1GEeL0Rh^;06][J`15ADD0P820051@D00l?3`0KVi^
07QhN01DE5@0DE5A04m?C`18B4P0>c/k0:>SX`0e=CD0HF5Q079bLP1IFET0=cLg02XZ:P23Ph<0>3Ph
02h^;P1bLW808B4Q038b<P1dM7@0_kno03@d=018B4P0Vi^K08:2PP0l?3`0;bl_04a<C00L71`09bLW
06a/K01DE5@0<c<c071`L00B4Q80HF5Q0820P013@d<0U9BD0:RXZ00j>SX0>c/k08B4Q01_Kfl0@T92
04Q8B016ATH0=SHf08Z:RP0g=cL07?ooool0<P38b<P0bl_;0;Rh^01CDe<0>c/k08b<S02j^[X0][Jf
05EEE@0d=3@0:2PX01dM7@0I6AT05QHF01LG5`2TY:@0IVIV0820P01YJFT0>CTi04M7A`1^KVh0XJ6Q
0;Bd]00j>SX061PH01XJ6P12@T80AdM702@T901ZJVX0UiNG09fMW@1kNg/0=3@d02TY:@0Q8B40<c<c
09:BTP2ATI40NGUi071`L023Ph<0MWIf05ADE01lO7`0Vi^K05IFEP1HF5P05ADE0P0I6AT04P0g=cL0
DU9B07emO@0k>c/0>CTi01DE5@0`<300MgMg07=cL`1dM7@0EEEE05eMG@1YJFT0GemO07UiN@19BDT0
EeMG05YJFP80CDe=00`0@410020P801WIfL0ZJVY03Xj>P2OWil0?clo020P801?Cdl0DU9B05=CD`0=
3@d200h>3P1O00l?3`0>3Ph0410@010@400B4Q80C4a<03dm?@0U9BD0<C4a03dm?@1iNGT0AdM703`l
?01IFET05aLG01DE5@1DE5@0AdM7030`<00H61P0@D510::RXP0o?cl07QhN03<c<`2IVIT0MWIf069R
HP1<C4`0@d=303hn?P0k>c/0=CDe03`l?02:RXX0TI6A08^;R`1UIFD0I6AT04A4A00c<c<0[Jf]07Ad
M00K6a/05QHF030`<00b<S80@T9209FEU@2n_[h0U9BD01HF5P0Q8B40?3`l08:2PP3Bd]80CDe=04E5
A@0V9RH0ZZZZ071`L00K6a/05aLG024Q8@0_;bl0HV9R06m_K`29RHT0CDe=0<K6aP3:b/X0clo?08^;
R`0Y:BT09RHV02`/;00I6AT0;Bd]03Hf=P0P8200>SXj06m_K`3Jf]X0EEEE07moO`2ATI40Vi^K09BD
U02_[jl0Vi^K0:JVYP2JVYX0EUIF04];B`1cLg<00P2d];@01029RHT0<S8b03Xj>P1RHV8201DE5@0l
01dM7@11@D40KVi^069RHP1^KVh0AdM70;Rh^02HV9P0U9BD0;Rh^02GUiL0VYZJ08>3P`1jNWX0PH61
0;>c/`3UiND0`/;2096AT@1`L700>CTi01hN7P0@41004a<C01XJ6P0C4a<03`l?014A4@0m?Cd0Lg=c
03dm?@0Y:BT092@T04];B`2IVIT0ZJVY0<S8b033`l<0hn?S0<C4a02`/;00YjNW09^KV`2LW9`0UYJF
09^KV`3@d=00i>CT0;2`/02WYjL0_;bl0:j^[P1iNGT0Xj>S0:RXZ01CDe<0;2`/07AdM01oOgl0:BTY
0P0L71`09`0R8R80;2`/04Y:BP19BDT071`L02DU9@0n?Sh0R8R805eMG@1;Bd/0AdM704Q8B00[:b/0
7AdM04=3@`2ATI40b/[:0=cLg03>c/h0^KVi09JFUP2:RXX0NWYj07AdM03<c<`0b<S80;>c/`28R8P0
;2`/02PX:00a<C40B4Q8071`L02:RXX0?Shn06=SH`2<S8`07alO02PX:00Aooooo`003oooool0702L
W9`0RXZ:06i^KP1LG5`0Shn?04];B`17AdL0?3`l05mOG`2d];@0SXj>0820P01OGel0CTi>07IfMP1g
MgL0Kfm_05MGE`2WYjL0MGEe0492@P0k>c/0Fe]K0410@01SHf<0SHf=02<S8`1ZJVX2038b<P3o075a
L@0n?Sh0:2PX05IFEP0e=CD0F5QH051@D00j>SX0820P04E5A@1?Cdl07QhN038b<P0f=SH0;Bd]05EE
E@1QHF40:b/[03<c<`0U9BD0GemO08V9R@0m?Cd0DE5A02@T900d=3@0M7Ad0410@00M7Ad071`L03Lg
=`1CDe<0Cdm?05iNGP0R8R806a/K04U9B@0d=3@0=cLg04U9B@1SHf<0=3@d034a<@0Y:BT0NWYj05mO
G`1DE5@0MGEe071`L00f=SH0GEeM051@D00^;Rh0?Cdm06a/K00P8200?Cdm04e=C@1cLg<0:2PX01lO
7`1QHF407alO04Q8B01ZJVX0K6a/0451@@1SHf<0CDe=03lo?`1aLG40Cdm?030`<00Q8B40SXj>04U9
B@0c<c<0GemO01/K6`1BDU80FEUI04i>CP1DE5@09RHV07QhN01QHF40@T9206=SH`10@400<30`05]K
F`16ATH0E5AD04A4A00e=CD0L71`06QXJ01/K6`0:2PX03dm?@1nOWh0KFe]065QH@0[:b/0?3`l0:VY
Z@2BTY80D51@07QhN01eMGD0Bd];07emO@0i>CT0MGEe075aL@1/K6`0EUIF04];B`1JFUX0EEEE06=S
H`0];Bd071`L09RHV01>CTh0Bd];065QH@0E5AD0Lg=c07IfMP2CTi<0K6a/03Lg=`0F5QH0M7Ad0:BT
Y01YJFT0<S8b03/k>`1ADE40IfMW0861P@1fMWH0HF5Q06ATI032`/80ZJVY06a/K02?Shl0O7al03`l
?024Q8@0>3Ph02TY:@1<C4`0Q8B403hn?P0a<C40A4A403lo?`1lO7`0HV9R09BDU02MWId0DE5A07Yj
NP33`l<0ATI6061PH00Z:RX0GUiN0:2PX00c<c<0>c/k05=CD`2>SXh0J6QX03dm?@2QXJ40IfMW024Q
8@0/;2`0HF5Q06][J`2ATI40EUIF05ADE01UIFD0;2`/04];B`1MGEd0?Shn0861P@2][Jd0IVIV04I6
AP1KFe/0?3`l05IFEP1gMgL0VIVI06e]K@1jNWX0OGem05]KF`0K6a/0SXj>06YZJP1:BTX0?clo06QX
J00n?Sh0CTi>06=SH`0b<S80ADE508f=S@12@T80OGem09fMW@1]KFd0@41001/K6`1VIVH0<c<c02DU
9@1NGUh0=3@d03lo?`23Ph<0b/[:04Q8B00e=CD0N7Qh07emO@16ATH0@41005ADE00_;bl092@T05]K
F`1=CDd0=cLg07alO00S8b<0C4a<07YjNP1:BTX0XZ:R0;Rh^00N7Qh08R8R0820P02HV9P0MgMg0005
02`/;01GEeL0FUYJ06MWI`0c<c<07?ooool0?`2h^;P0/[:b0;Rh^01KFe/0GUiN07moO`2c/k<0D51@
02LW9`0O7al0820P02<S8`0R8R808B4Q01`L701CDe<0J6QX051@D01QHF40K6a/03Ph>00_;bl0PH61
0<K6aP11@D406QXJ01lO7`0g=cL06a/K01DE5@1=CDd0HF5Q02d];@2DU9@0^k^k06m_K`1=CDd0FUYJ
08n?S`2EUID0Ph>308:2PP20P800TI6A09bLW02c/k<0^KVi06m_K`1kNg/06a/K01lO7`0M7Ad08R8R
05UIF@20P800KFe]04I6AP0a<C40>CTi02d];@0[:b/0;bl_04e=C@0205eMG@0D02XZ:P1>CTh0IfMW
04a<C01VIVH0GEeM04i>CP0a<C4071`L04a<C02a/K40c/k>0;Vi^@1mOGd0?Cdm051@D02=SHd0KFe]
01@D500>3Ph200d=3@1U010@400>3Ph03Ph>01<C4`1LG5`0DE5A02XZ:P0h>3P0Bd];08N7Q`1IFET0
L71`08J6QP0f=SH0=cLg07]kN`1]KFd0E5AD0451@@14A4@0GUiN09^KV`1DE5@0EEEE0;:b/P2<S8`0
AdM703Ti>@0[:b/09RHV02`/;00];Bd0D51@08:2PP35aLD0WIfM0<[:bP1NGUh0P8200:FUY@37alL0
Z:RX07QhN01SHf<0HV9R05eMG@1WIfL0a/K60=SHf02KVi/07AdM00h>3P0B4Q80>SXj09fMW@16ATH0
:RXZ06e]K@2ZZZX0BDU903Ph>00c<c<0:b/[02l_;`23Ph<0W9bL0;Jf]P1]KFd0Fe]K0<c<c03@d=00
R8R806=SH`0j>SX0CTi>03@d=011@D407QhN0492@P1]KFd0bl_;0;>c/`0j>SX0?Cdm0:NWY`2DU9@0
EEEE0410@01ZJVX0[:b/05ADE00i>CT0;2`/05eMG@2NWYh0TY:B065QH@0];Bd0@D5104Q8B00D51@0
0P0E5AD06@0^;Rh0Hf=S06YZJP1@D500CDe=0<71`@2LW9`0RXZ:055AD@2YZJT0=CDe02l_;`0d=3@0
De=C08>3P`37alL0W9bL06MWI`24Q8@0Ti>C03<c<`0J6QX05ADE02PX:00C4a<00P0A4A40B@0K6a/0
VIVI09JFUP0a<C40C4a<04m?C`2ATI40a/K60=7Ad@2WYjL0`l?306e]K@10@400<c<c024Q8@0L71`0
6ATI01XJ6P27QhL0/;2`04m?C`1gMgL0UiNG09:BTP0o?cl0A4A40861P@2b/[80Xj>S06YZJP16ATH0
HF5Q03Ti>@0N7Qh07AdM02d];@1HF5P0@D5101lO7`0e=CD0Bd];07YjNP1^KVh0ADE504m?C`0b<S80
71`L01lO7`0h>3P0`l?30<30`03<c<`0V9RH07alO00m?Cd0:BTY038b<P1YJFT0c/k>09NGU`2HV9P0
Q8B402`/;00_;bl0=CDe04=3@`1@D500UYJF059BDP1hN7P0D51@02<S8`0Y:BT04Oooool000oooooo
02D0QHF509NGU`2PX:00FEUI08b<S01YJFT0IfMW04e=C@18B4P0IFEU07alO023Ph<0E5AD02HV9P1a
LG40IFEU02l_;`17AdL0UIFE06e]K@0m?Cd0?3`l05UIF@0d=3@0@T9208J6QP0[:b/0JVYZ07alO018
B4P0HV9R02l_;`0Q8B40KVi^04A4A01?Cdl0A4A40080;Rh^01<0@d=3034a<@0L71`0=SHf0410@00d
=3@0?clo05YJFP0Y:BT0ADE5034a<@1;Bd/0IFEU03dm?@1VIVH0A4A402<S8`19BDT0DU9B0080<C4a
0280De=C034a<@1QHF40LG5a03Xj>P0L71`0E5AD02TY:@0Q8B40FUYJ08R8R00n?Sh0?3`l01XJ6P1[
Jf/0LG5a069RHP2ATI40NWYj028R8P1OGel0JVYZ0410@012@T80K6a/01XJ6P0m?Cd0BDU907=cL`0c
<c<0;Bd]07UiN@1<C4`0F5QH0P1MGEd0;`10@400SXj>059BDP19BDT0K6a/05]KF`1OGel0?clo07If
MP0];Bd0=3@d04m?C`0/;2`0Fe]K04A4A00`<300G5aL03De=@1fMWH0Fe]K04U9B@1lO7`0I6AT03`l
?01>CTh0?Shn07QhN01GEeL0A4A407inOP1KFe/0Shn?04A4A00];Bd0IFEU07AdM01FEUH08R8R01hN
7P2;Rh/0LG5a059BDP2ATI40QhN705EEE@1XJ6P0;Bd]0080QXJ60940JFUY06EUI@1>CTh0FEUI06MW
I`2JVYX0B4Q802DU9@2=SHd0@d=30410@01OGel0?Cdm07AdM01/K6`0UIFE06a/K01QHF40D51@07mo
O`2h^;P0L71`03Xj>P10@400EEEE08F5Q@23Ph<0NWYj06ATI02SXj<0bl_;0:b/[01YJFT0UiNG05YJ
FP15ADD0[Zj^04E5A@10@400D51@08Z:RP1;Bd/0A4A403Ph>016ATH0QXJ604e=C@1`L700QXJ601XJ
6P1RHV80YjNW05]KF`1WIfL08b<S03Hf=P1SHf<0:b/[04A4A01WIfL0/;2`07inOP0T92@0Kfm_08B4
Q00l?3`0D51@08J6QP20P800[Jf]02l_;`1WIfL0SHf=03Lg=`1CDe<0LG5a02DU9@1IFET0ZJVY0820
P01=CDd0FEUI03Ti>@10@400EUIF07]kN`1SHf<0PH6107QhN01bLW80;Bd]075aL@1SHf<0BDU904Y:
BP1GEeL07alO04i>CP1UIFD0G5aL03Hf=P1fMWH07AdM06a/K029RHT0S8b<07MgM`0Q8B40K6a/05QH
F00Z:RX0Jf][034a<@16ATH0PX:20<[:bP1JFUX0;Rh^06][J`2MWId0GemO061PH01cLg<0GEeM02LW
9`1RHV80ATI603dm?@2ZZZX0>c/k065QH@1ADE40ADE50;Zj^P2m_Kd0Fe]K02HV9P16ATH0EeMG06a/
K01@D500DE5A04i>CP0R8R805ADE01cooooo00`0`l?30;2`/02[Zj/0J6QX08Z:RP2=SHd0Ogmo02`/
;00V9RH07AdM01`L700M7Ad201`L700]01dM7@0Z:RX0Jf][0410@00j>SX0FUYJ06=SH`0j>SX0@d=3
0::RXP1MGEd08B4Q02XZ:P0g=cL05aLG01DE5@1DE5@0BDU901/K6`1FEUH0OWin03Ti>@0f=SH0;bl_
02/[:`15ADD0IFEU055AD@1:BTX0CDe=09BDU026QXH0R8R80:f][@2=SHd0JFUY02h^;P0];Bd0:BTY
05iNGP2DU9@0T92@06IVIP0n?Sh08B4Q008071`L03H061PH02/[:`0o?cl0I6AT03Ph>00[:b/0DE5A
075aL@1^KVh0/;2`0:BTY01aLG40Vi^K0=3@d02e]KD0_Kfm0<W9b@2VYZH0/[:b08j>SP1/K6`0VIVI
065QH@1IFET0@d=303@d=00W9bL05aLG01PH600W9bL0TY:B0:NWY`1?Cdl0DE5A06QXJ01aLG40?Shn
051@D01mOGd08B4Q01/K6`1EEED0Rh^;03De=@0b<S80;Rh^02DU9@0n?Sh0XZ:R0:NWY`2IVIT0Zj^[
05]KF`0Y:BT2020P801602@T900Q8B409bLW06QXJ03Kfm/0g=cL0<W9b@3Kfm/0RXZ:07emO@2OWil0
Bd];03hn?P0l?3`0;Bd]04E5A@2h^;P0j^[Z0>WYj@2a/K40L71`01@D500@4100;bl_08B4Q01^KVh0
K6a/0<c<c01?Cdl07AdM028R8P0S8b<09RHV01dM7@1dM7@0Q8B403Hf=P0Y:BT0C4a<07YjNP3Ph>00
[Zj^07AdM01jNWX0OGem0492@P0N7Qh0BTY:07UiN@2FUYH0PH6109bLW012@T80?3`l04e=C@0Q8B40
LG5a03<c<`0P8200=SHf08V9R@1NGUh0Fe]K096AT@36a/H0UYJF05]KF`12@T80DE5A024Q8@805ADE
00d05aLG04];B`1ADE40R8R80:>SX`3AdM40/k>c05]KF`19BDT0>SXj06m_K`0K6a/05aLG00<05ADE
01/0JVYZ0<?3``1XJ6P0EUIF0861P@1NGUh06ATI01LG5`0_;bl08b<S02d];@0F5QH071`L05iNGP39
bLT0/k>c0=3@d03Cdm<0aLG50=WIf@3;bl/0SXj>092@T00D51@04a<C018B4P0C4a<00P0E5AD0>00T
92@0/K6a075aL@10@400UiNG07inOP27QhL0Kfm_04E5A@0h>3P0GUiN07QhN02ZZZX0KVi^03lo?`1G
EeL0BTY:02TY:@0k>c/0P82003Ti>@0W9bL0@4100492@P1IFET0Rh^;04m?C`16ATH07QhN01lO7`0P
8200G5aL05eMG@2VYZH0bLW90;Rh^01cLg<0?Shn06e]K@2SXj<0Y:BT0<g=c@0k>c/0H61P065QH@0V
9RH0<c<c03Ti>@0l?3`0AdM707QhN01/K6`0NWYj03Hf=P0h>3P0G5aL4Oooool000oooooo07h0T92@
08R8R02SXj<0KFe]07emO@26QXH0UIFE06QXJ01?Cdl0JFUY06=SH`2FUYH0OWin02/[:`1TI6@0TI6A
07]kN`1MGEd0WinO06=SH`1ADE40Fe]K08n?S`1VIVH0De=C06ATI00l?3`0LG5a0820P01IFET0GUiN
02PX:00];Bd0K6a/04Q8B01:BTX0>SXj03`l?00h>3P0>c/k02PX:00N7Qh0BDU904M7A`0m?Cd0@D51
04Y:BP0W9bL0De=C02`/;00n?Sh0FEUI03@d=01[Jf/0E5AD02PX:01?Cdl0?Cdm02`/;00l?3`0HV9R
05QHF012@T80HV9R03<c<`0/;2`0Jf][04e=C@0e=CD0B4Q8055AD@0R8R80ATI6038b<P1SHf<0E5AD
05YJFP2CTi<0Ogmo03<c<`1JFUX0ATI6034a<@1GEeL0KFe]01hN7P0k>c/0D51@06YZJP0V9RH0:BTY
05mOG`1;Bd/0M7Ad09ZJVP1VIVH0?Shn06=SH`17AdL0D51@07MgM`1OGel0HV9R04];B`22PX80<C4a
04A4A01OGel0?3`l05eMG@1=CDd0@T9206QXJ00h>3P0NGUi04A4A00l?3`0MgMg06=SH`10@400AdM7
02l_;`1HF5P0DE5A03`l?01[Jf/205aLG02R051@D00b<S80JFUY06=SH`1ZJVX0?Shn030`<022PX80
EUIF04Q8B02CTi<0SHf=05QHF01^KVh0>CTi07]kN`1^KVh0LW9b06QXJ01>CTh0DE5A04U9B@1dM7@0
>SXj024Q8@2<S8`0<S8b04i>CP1lO7`0DU9B07inOP1SHf<0UiNG09bLW020P800IFEU09^KV`2i^KT0
EUIF03Lg=`1YJFT0IFEU0:2PX02NWYh0NWYj04];B`23Ph<0`<3008B4Q01SHf<0Y:BT06QXJ00n?Sh0
Xj>S04i>CP18B4P0Hf=S08j>SP0o?cl0De=C04a<C00g=cL0KVi^05IFEP2LW9`0QHF5065QH@2XZ:P0
/;2`03/k>`1_Kfl0@T9203De=@1QHF408R8R03hn?P1VIVH0W9bL071`L00l?3`0M7Ad05MGE`0S8b<0
@d=309^KV`2PX:00Z:RX03Lg=`17AdL0EeMG02XZ:P1[Jf/0IFEU02l_;`1JFUX0VYZJ055AD@1FEUH0
MWIf061PH01/K6`0QXJ60:b/[01MGEd0KVi^096AT@23Ph<0?clo07YjNP1JFUX0?3`l05QHF01LG5`0
=SHf06QXJ01DE5@0?clo0492@P2KVi/0@d=307AdM02;Rh/0JFUY04E5A@0W9bL0LW9b03De=@0d=3@0
JVYZ01dM7@12@T80Ph>30:VYZ@0c<c<0>3Ph06e]K@1bLW80>SXj055AD@1MGEd0BDU9030`<01gMgL0
AdM70451@@2EUID0<c<c05mOG`1SHf<0@4100:VYZ@2VYZH0@D5103<c<`1VIVH0LG5a05eMG@15ADD0
NGUi09ZJVP1]KFd0;2`/7?ooool02@3=cLd0[Jf]09jNWP3De=@0YjNW096AT@15ADD0>3Ph02PX:002
020P8006028R8P0Q8B40820P01hN7P0L71`0Cdm?0P13@d<0100h>3P0FEUI06EUI@0^;Rh206YZJP0U
06MWI`1:BTX071`L020P800_;bl0GUiN06=SH`1RHV80QHF506e]K@0o?cl0?Cdm03Ph>00`<300;2`/
02/[:`18B4P0CDe=06YZJP2PX:00Z:RX0:j^[P31`L40[Zj^0;>c/`2a/K40UIFE07MgM`2HV9P0UIFE
08V9R@1UIFD0ATI602HV9P0Q8B40:BTY02HV9P0202<S8`0T04m?C`2SXj<0MGEe08R8R03EeMD0dM7A
0<K6aP2d];@0Y:BT07emO@1IFET0OGem0;Zj^P32`/80YZJV09nOW`2<S8`0Xj>S08J6QP0h>3P06a/K
02DU9@0Z:RX0>SXj03dm?@18B4P0Kfm_0:2PX02EUID0W9bL0:RXZ02o_kl0NGUi07inOP1_Kfl0EeMG
0P17AdL07`1hN7P0Z:RX055AD@1DE5@0=cLg034a<@0k>c/0Ng]k09fMW@1_Kfl0b/[:0<o?c`2ATI40
KVi^05EEE@16ATH0A4A40451@@1iNGT0e=CD0<?3``2TY:@0/[:b08:2PP2SXj<0?3`l05IFEP2DU9@0
RXZ:0;Zj^P2ZZZX00P24Q8@09@2m_Kd0Ph>309ZJVP22PX809bLW03<c<`26QXH0gmoO0<30`01DE5@0
9RHV01`L700K6a/08B4Q028R8P0N7Qh0PH6103dm?@0I6AT06a/K02PX:01?Cdl0dM7A0>;RhP2g]kL0
a/K60;Ng]`1aLG40TI6A08F5Q@14A4@08B4Q065QH@2IVIT0@41004a<C00M7Ad00P0G5aL0=P0o?cl0
DE5A04Y:BP1DE5@0O7al08^;R`2j^[X0H61P06m_K`2PX:00RHV908N7Q`11@D40:RXZ01/K6`19BDT0
O7al055AD@0b<S80=3@d06=SH`1[Jf/0;2`/03Ph>01CDe<0EEEE03/k>`0I6AT06a/K02`/;01FEUH0
LG5a07MgM`2@T900R8R806e]K@23Ph<08b<S01`L700Q8B40:2PX04i>CP0T92@0;2`/07inOP3:b/X0
e=CD0=3@d030`<00];Bd0=SHf03>c/h0W9bL07YjNP<051@D03/04a<C01DE5@0J6QX0KFe]0;Fe]@0j
>SX0?Shn05QHF00];Bd0EeMG07emO@1MGEd0@D510410@019BDT0QXJ606QXJ01mOGd0RXZ:09>CT`2Y
ZJT0[jn_0;Zj^P1^KVh0Hf=S04a<C01LG5`0EeMG06m_K`1VIVH0;Bd]02LW9`1=CDd0HF5Q04a<C01^
KVh0/k>c0=cLg03?cll0bLW90<K6aP2SXj<0=cLg01lO7`2=SHd0=SHf04U9B@18B4P08R8R038b<P0`
<300>c/k04A4A01FEUH0Ph>309JFUP1QHF40GemO069RHP0Aooooo`003oooool0?P2DU9@0UIFE07If
MP2@T900Ti>C09VIV@2PX:00I6AT05YJFP2>SXh0Ogmo0:JVYP27QhL0=cLg06ATI01hN7P0KVi^06=S
H`2HV9P0?clo04I6AP11@D40Ogmo05mOG`1GEeL0DU9B03Lg=`1YJFT0JVYZ06EUI@1LG5`0<S8b02LW
9`1/K6`0Hf=S05mOG`0e=CD0<S8b02l_;`0o?cl0<30`01dM7@1:BTX0?Cdm04E5A@1GEeL0EEEE02/[
:`1QHF40;Rh^04m?C`1DE5@0<30`06IVIP1:BTX0;Bd]04];B`0m?Cd0;Bd]03<c<`1DE5@0GUiN0P1I
FET09P0h>3P092@T05=CD`10@400<30`04i>CP1DE5@0:b/[03dm?@0T92@0J6QX051@D01`L700WinO
08B4Q00e=CD0Lg=c06i^KP12@T80Cdm?069RHP0L71`0=cLg04M7A`1ZJVX0<S8b030`<01SHf<0@T92
04Y:BP20P800Kfm_04=3@`1eMGD0ATI603hn?P1cLg<0FUYJ0P15ADD0QP1lO7`0@D5103`l?01LG5`0
=3@d06e]K@1OGel0F5QH055AD@1>CTh0R8R804i>CP14A4@0Ph>304Y:BP1KFe/0IFEU0410@01fMWH0
:b/[04m?C`2<S8`0K6a/06UYJ@0`<300?3`l08:2PP1YJFT0FEUI04E5A@1YJFT0[:b/06YZJP17AdL0
T92@071`L01bLW80P820059BDP2_[jl0VYZJ04e=C@1QHF40IFEU05MGE`1VIVH0Xj>S03Hf=P0j>SX0
RHV903`l?00k>c/0MWIf02l_;`1kNg/0MgMg0:RXZ02NWYh0FEUI03`l?02WYjL0^KVi07AdM00m?Cd0
NGUi05aLG01iNGT0JFUY07alO01@D500VIVI0<_;b`22PX80G5aL06m_K`0k>c/0Fe]K092@T01?Cdl0
>3Ph06a/K023Ph<0ATI604M7A`1?Cdl0E5AD08^;R`19BDT0YJFU08J6QP11@D40QHF509BDU01DE5@0
Q8B4038b<P19BDT0Jf][02TY:@1OGel0T92@0;fm_@2IVIT0@4100861P@1XJ6P07alO02l_;`28R8P0
/K6a0:BTY014A4@0Q8B405]KF`0T92@0HF5Q04E5A@0Y:BT0Kfm_0:6QX@1fMWH0MGEe07YjNP1IFET0
@d=305iNGP27QhL0?Shn07moO`31`L40WIfM05EEE@1kNg/0IFEU0P1;Bd/0<P17AdL0;bl_07EeM@1e
MGD0?Shn03/k>`26QXH0<30`05MGE`1LG5`0Lg=c06EUI@0J6QX0F5QH03De=@0S8b<0DU9B02XZ:P1I
FET0XJ6Q0;Zj^P0j>SX07alO03hn?P1GEeL0A4A408B4Q020P800HV9R02/[:`1@D5005ADE03Xj>P2A
TI40=SHf051@D00K6a/09bLW09BDU02UYJD0EUIF02@T900o?cl0FEUI0451@@17AdL0`/;20<k>cP0g
=cL0820P7?ooool0B02OWil0/K6a0<k>cP3Bd]80emOG08N7Q`0c<c<0;Rh^028R8P0M7Ad07alO01dM
7@0L71`06ATI01LG5`0F5QH0>CTi03`l?00^;Rh08B4Q03@d=02KVi/0WYjN08^;R`21PH40MgMg08F5
Q@2CTi<0DE5A020P800M7Ad061PH01XJ6P2ATI40UYJF0:>SX`27QhL0IfMW05QHF01EEED0D51@04E5
A@0g=cL0N7Qh0<?3``2c/k<0^;Rh0=3@d02l_;`0[:b/0<30`02g]kL0U9BD08^;R`2RXZ80`l?30;Bd
]02JVYX0T92@06][J`0g=cL09BDU01XJ6P0M7Ad0=CDe0<k>cP2g]kL0Ogmo05mOG`1XJ6P0SXj>0;jn
_P80^KVi00d0a/K60=KFeP3Vi^H0a/K60:j^[P17AdL0?Shn034a<@0j>SX0LW9b05aLG00E5AD03Ph>
00<05ADE00@09RHV09fMW@3Kfm/0d];B0P2i^KT09@3?cll0V9RH05]KF`13@d<0=CDe02l_;`0W9bL0
@4100:RXZ01UIFD0B4Q805ADE022PX80QhN703Ti>@2TY:@0cLg=0:NWY`1mOGd0MGEe08R8R02BTY80
TI6A07inOP1=CDd0^k^k06ATI02KVi/0b/[:0<c<c01@D500410@01<C4`0Y:BT0IfMW04i>CP0H61P0
0P0E5AD08P0Y:BT0X:2P05YJFP2l_;`0/K6a03`l?03:b/X0[Jf]06YZJP0k>c/08B4Q01dM7@0Q8B40
8R8R03Xj>P1eMGD0a/K608n?S`0i>CT0:b/[028R8P0a<C40fMWI0=gMg@3EeMD0g=cL0>?Sh`3Zj^X0
`l?302XZ:P0I6AT07QhN0820P01FEUH203Lg=`0k01PH600E5AD05ADE01dM7@0n?Sh0KFe]06EUI@1C
De<0W9bL0<71`@15ADD0>c/k0<C4a023Ph<0OWin03Ti>@1>CTh0MWIf0:NWY`0i>CT0:b/[02h^;P0g
=cL0KVi^092@T00f=SH08b<S03`l?016ATH0LG5a05EEE@1cLg<0G5aL02h^;P0R8R80:BTY05mOG`1W
IfL0[jn_0;Ng]`1YJFT0;Rh^04A4A00g=cL0IFEU03De=@10@400Xj>S0<_;b`2EUID0[Jf]0=SHf03P
h>00aLG50:^[Z`3Ti>@0Ti>C01@D500C4a<00P0E5AD08P0H61P0ADE50<30`01@D5006ATI04i>CP1P
H6007QhN01XJ6P0I6AT0FUYJ05IFEP0a<C40<S8b0820P00j>SX0=SHf069RHP2XZ:P0[Jf]0<[:bP3C
dm<0b/[:0:JVYP2g]kL0Z:RX05iNGP0o?cl0HF5Q04i>CP2TY:@0Fe]K02DU9@1FEUH20;>c/`08065Q
H@1mOGd0JFUY02h^;P1WIfL0];Bd0;Zj^P3AdM4205QHF00<03Lg=`0Q8B40;Bd]02TY:@1@D500Hf=S
06EUI@1nOWh0d=3@0=WIf@2g]kL0a/K64Oooool000oooooo0?l0Ph>309NGU`29RHT0GemO08F5Q@2j
^[X0Xj>S04M7A`2=SHd0/k>c07YjNP2[Zj/0CDe=05aLG01^KVh0H61P02h^;P1NGUh0Vi^K051@D01K
Fe/0EeMG04E5A@0l?3`0D51@03@d=01JFUX0Ogmo038b<P0d=3@0GUiN02TY:@0_;bl0GUiN03Ti>@1=
CDd0DE5A03@d=00V9RH0?clo03dm?@0M7Ad0CDe=03De=@0m?Cd0De=C05mOG`0b<S80De=C02HV9P0m
?Cd0De=C030`<01YJFT0=cLg04m?C`1dM7@0DE5A02PX:00a<C40DU9B05=CD`1]KFd0N7Qh03Ti>@0X
:2P0EeMG03<c<`0Q8B40HV9R06i^KP0b<S80>3Ph03Hf=P2CTi<0FUYJ06ATI02h^;P0KVi^02<S8`1K
Fe/0C4a<03Lg=`1JFUX0E5AD01LG5`0T92@0C4a<06UYJ@0_;bl0@T9206MWI`1IFET0C4a<08Z:RP1E
EED0=3@d08>3P`1KFe/0BDU906QXJ01SHf<0IfMW03/k>`1hN7P0<c<c04m?C`1GEeL0<30`04E5A@1;
Bd/0@d=305mOG`0d=3@0KFe]030`<016ATH0MWIf051@D00[:b/0=SHf02LW9`1TI6@0DE5A02d];@1G
EeL0>c/k07]kN`13@d<0:BTY05=CD`1lO7`0IFEU02l_;`0o?cl0VYZJ03lo?`1GEeL0[Jf]07=cL`1E
EED0ATI603@d=01jNWX0OWin069RHP1ZJVX0BTY:04M7A`19BDT0M7Ad03lo?`0R8R80LW9b02@T901M
GEd0OWin034a<@1RHV80Hf=S0:BTY02g]kL0Kfm_03Ph>01]KFd0[:b/061PH017AdL0VIVI079bLP2^
[Zh0Lg=c04E5A@10@400U9BD0;Fe]@24Q8@0N7Qh07MgM`1[Jf/0B4Q8096AT@1FEUH0?Shn05MGE`1M
GEd0?Cdm07moO`1DE5@0>CTi061PH00h>3P0[jn_09BDU01YJFT0WIfM0::RXP0Y:BT0Q8B404e=C@0]
;Bd0EEEE01HF5P12@T80DU9B07AdM01TI6@0A4A408J6QP1ADE404A4A018B4P2FUYH0d];B09nOW`0`
<300?Shn05iNGP0i>CT0MGEe05iNGP0_;bl0A4A407UiN@14A4@0FEUI08b<S01KFe/0=SHf04i>CP24
Q8@0Bd];05mOG`1TI6@0PX:204];B`2@T900E5AD02XZ:P1`L700Kfm_03Xj>P1cLg<0@T92030`<01R
HV80[Jf]051@D01UIFD0K6a/07AdM01NGUh08B4Q05EEE@0_;bl002<0:b/[05YJFP0D51@0=cLg06a/
K02TY:@0=CDe02DU9@0i>CT0EeMG02TY:@10@400FEUI06QXJ00W9bL0Jf][04A4A00m?Cd0O7al03Xj
>P1FEUH0KFe]03dm?@2QXJ40/;2`05MGE`0T92@0@T9206ATI01SHf<0?3`l069RHP1nOWh0J6QX01hN
7P0Looooo`0;09VIV@3AdM40emOG09nOW`1SHf<0Ph>30:BTY01@D5009RHV01lO7`0L71`00P0I6AT3
01DE5@0=01lO7`1BDU80;Rh^030`<01ADE40ZZZZ09BDU02IVIT0_kno0<S8b02k^k/0MWIf01TI6@03
01DE5@1=01HF5P1ADE40:b/[02@T900g=cL0G5aL08N7Q`2BTY80QXJ606=SH`1EEED0N7Qh0:6QX@3R
h^80e=CD0;Rh^02TY:@0Shn?0;:b/P2f][H0HF5Q05MGE`1jNWX0][Jf08>3P`2NWYh0Xj>S08F5Q@1h
N7P0KFe]06UYJ@1]KFd0UYJF0=CDe01HF5P0De=C04a<C013@d<0=cLg09BDU01YJFT0ATI604U9B@1I
FET0];Bd0:VYZ@1oOgl09bLW01XJ6P0E5AD08R8R02h^;P1>CTh0FUYJ02/[:`0H61P07AdM04a<C01/
K6`0Ph>309bLW034a<@0eMGE0>3Ph03Fe]H0V9RH06ATI01BDU80CDe=05UIF@1aLG40MWIf06a/K02T
Y:@0<C4a01`L700M7Ad00P0o?cl05P20P800Ti>C02TY:@0L71`0410@01<C4`0E5AD0:RXZ05eMG@2g
]kL0[jn_06][J`2a/K40b/[:0>3Ph015ADD0<S8b04I6AP0g=cL0?3`l028R8P0G5aL301DE5@1B05IF
EP2NWYh0Q8B40<c<c02LW9`0eMGE09NGU`2^[Zh0P82006ATI01BDU80@D51079bLP2WYjL0JVYZ03Lg
=`1eMGD0[:b/07YjNP1aLG40W9bL0861P@1jNWX0UIFE0<_;b`3Jf]X0iNGU0=oOg`2GUiL0=cLg02@T
902FUYH0:b/[0410@00c<c<061PH01LG5`0H61P08R8R020P800K6a/0F5QH0861P@2SXj<0/K6a08f=
S@0n?Sh0clo?09FEU@1XJ6P07QhN02HV9P1CDe<0BDU9059BDP0f=SH0ADE506EUI@2YZJT0g]kN08R8
R00R8R80;Bd]05IFEP2>SXh0R8R804E5A@0e=CD08b<S028R8P0X:2P0E5AD0820P02GUiL0/[:b0;6a
/@2:RXX0TY:B06UYJ@2/[:`0YZJV0:b/[080iNGU00T0XJ6Q09^KV`2m_Kd0gmoO0>3Ph03MgMd0hn?S
0;Ng]`0P82000P0E5AD07@0K6a/0:b/[0:VYZ@2IVIT08B4Q01TI6@0d=3@0O7al01DE5@0J6QX05aLG
01XJ6P1TI6@0E5AD030`<01BDU80QHF503dm?@1bLW80UiNG0;^k^`3AdM40d=3@0;Ng]`35aLD0UYJF
0;jn_P2e]KD0MgMg00808b<S01`0B4Q801hN7P0U9BD0Ogmo0;2`/026QXH0;bl_06i^KP1IFET0:BTY
02d];@0e=CD0BDU90:BTY02][Jd0KFe]02HV9P0N7Qh092@T02`/;014A4@0Bd];05ADE01oOgl0dM7A
0=_Kf`3Fe]H0emOG4Oooool000oooooo0?l0Lg=c08n?S`2DU9@0MGEe06a/K01SHf<0RXZ:04];B`1B
DU80D51@04Q8B02[Zj/0HF5Q05QHF01WIfL0PX:206i^KP1LG5`0UYJF04Q8B01WIfL0LG5a07QhN01H
F5P0B4Q802/[:`14A4@0M7Ad05QHF00l?3`0C4a<028R8P0[:b/0HF5Q04Q8B01@D500:b/[04A4A00m
?Cd0<S8b02<S8`0W9bL0EUIF0492@P1FEUH0BTY:02TY:@0[:b/0FEUI02DU9@0f=SH0ATI601`L701S
Hf<0?Shn03@d=01ADE4092@T03<c<`1>CTh0Ng]k0492@P0e=CD0I6AT03/k>`0d=3@0GEeM05IFEP0b
<S80AdM704i>CP0`<300Cdm?02/[:`1UIFD0Cdm?06IVIP2n_[h0LW9b03<c<`1WIfL0De=C02h^;P1e
MGD0Fe]K01LG5`0P8200DE5A04U9B@0O7al0=3@d04Q8B01EEED0C4a<08>3P`1CDe<0@d=306ATI019
BDT0C4a<06][J`1MGEd0IFEU03Ph>01UIFD09bLW04i>CP1MGEd0>c/k0492@P1ADE40B4Q805EEE@0f
=SH0JFUY04a<C00o?cl0O7al05UIF@0Z:RX0CTi>0410@01OGel0DE5A03Ti>@1WIfL0LW9b075aL@19
BDT0<S8b05IFEP1=CDd0K6a/0410@01;Bd/0YJFU0492@P0k>c/0S8b<07QhN01SHf<0G5aL05eMG@2F
UYH0MgMg06IVIP2:RXX0I6AT04Q8B01?Cdl0LW9b03hn?P0Y:BT0MGEe034a<@0k>c/0QhN704i>CP1W
IfL0@41007inOP2FUYH0MgMg04a<C028R8P0];Bd03<c<`0h>3P0^[Zj06e]K@2LW9`0OWin07YjNP1@
D500VYZJ0;Jf]P1mOGd0MGEe09^KV`1YJFT0GEeM08V9R@1WIfL0Bd];06e]K@1nOWh0B4Q804];B`1A
DE40?clo08B4Q01FEUH0SHf=07YjNP1MGEd0Zj^[08f=S@0k>c/0N7Qh03hn?P0_;bl0EeMG02/[:`1S
Hf<0IVIV09JFUP1]KFd0ATI608R8R01EEED0=CDe03lo?`1]KFd0/;2`0:>SX`1>CTh0@D5104=3@`0`
<300L71`06YZJP0j>SX0De=C07moO`1MGEd0Jf][06=SH`1DE5@0=cLg05EEE@1bLW80GemO08J6QP1h
N7P0Vi^K065QH@2>SXh0FUYJ038b<P1ADE40CTi>03Xj>P1iNGT0>CTi01TI6@0m?Cd0WIfM04A4A01[
Jf/0NGUi038b<P0G5aL0>SXj07IfMP1DE5@002<0;Bd]05MGE`0V9RH0CDe=07IfMP2ZZZX0<c<c02TY
:@13@d<0Hf=S04A4A01>CTh0F5QH05mOG`0h>3P0QHF504a<C017AdL0P82003Ti>@1HF5P0JVYZ0451
@@2TY:@0[:b/04Y:BP0Q8B40@41004m?C`19BDT0EEEE09RHV02DU9@0O7al02@T900Looooo`1A06EU
I@2QXJ40RHV907AdM01IFET0?Cdm04e=C@2;Rh/0Lg=c02h^;P0M7Ad06ATI01HF5P0E5AD061PH03Lg
=`1?Cdl0PH6108f=S@2OWil0IVIV03Ph>00l?3`0GEeM07EeM@20P800KVi^05ADE00P82006ATI01DE
5@0F5QH06a/K04I6AP0Y:BT0;Rh^02DU9@0P82007QhN02HV9P0h>3P0Hf=S08>3P`2f][H0i>CT0>;R
hP3:b/X0F5QH04e=C@1<C4`0Jf][092@T019BDT0<c<c03Xj>P2k^k/0][Jf07alO02a/K40TI6A08:2
PP2BTY80Ng]k06m_K`2BTY80`L7107moO`1<C4`0:2PX02<S8`17AdL0M7Ad01`L700E5AD04a<C03Ti
>@1HF5P0[Zj^07alO00P820071`L00807AdM0P0T92@0600m?Cd0K6a/07IfMP1dM7@0HV9R04M7A`1a
LG40/K6a0;Vi^@3;bl/0TI6A06][J`21PH40VYZJ08J6QP1`L700Hf=S05QHF01LG5`0820P06a/K01d
M7@0:b/[01hN7P80@D5100H0UYJF03hn?P0F5QH071`L01@D500B4Q82014A4@0O010@4019BDT0cLg=
0;^k^`2a/K40Zj^[0<W9b@3:b/X0?Cdm01TI6@0D51@07QhN04A4A00T92@05QHF01TI6@0E5AD05aLG
06=SH`2VYZH0a/K60=kNgP3EeMD0`l?30;^k^`2ATI40SXj>09>CT`1mOGd0P82003De=@0301DE5@0m
038b<P1aLG40QHF50:FUY@0V9RH0N7Qh08F5Q@39bLT0MgMg0=;BdP28R8P0Vi^K0;no_`2RXZ80/;2`
01lO7`1fMWH0Fe]K04];B`0];Bd08B4Q034a<@0d=3@0:RXZ02l_;`1_Kfl0MgMg0;2`/02k^k/0^;Rh
0>7Qh@3<c<`0CDe=01dM7@0V9RH0?clo02DU9@1@D500MGEe06QXJ02<S8`0TI6A0<c<c032`/80IFEU
03<c<`1]KFd0Vi^K05aLG01:BTX0=cLg02h^;P10@400B4Q805=CD`2QXJ40^KVi05IFEP1nOWh0`l?3
0<_;b`020=CDe01:0<o?c`3Cdm<0fMWI0<[:bP1oOgl0UiNG09FEU@2NWYh0e=CD0>KViP3YjNT0e]KF
06m_K`1:BTX0Bd];051@D01XJ6P0b/[:04=3@`0e=CD0IVIV0;Jf]P2n_[h06a/K01HF5P0E5AD05aLG
01TI6@1XJ6P0GEeM03De=@2VYZH0YJFU0:>SX`2d];@0[Zj^0<K6aP39bLT0b/[:0;Fe]@2XZ:P0`L71
0;fm_@1mOGd0Ph>307UiN@1eMGD0@D5104e=C@2UYJD0^KVi03@d=014A4@0Kfm_05ADE00W9bL0;2`/
034a<@0j>SX0F5QH0<S8b02WYjL0:BTY02/[:`0a<C40>CTi04E5A@1<C4`0Jf][08F5Q@2j^[X0GemO
03Xj>P0f=SHAooooo`003oooool0202?Shl0V9RH071`L02<S8`0UYJF07moO`1dM7@0E5AD0P2KVi/0
I@1DE5@0XZ:R07YjNP1fMWH0@T9208N7Q`1OGel0KFe]07emO@0o?cl0C4a<079bLP2DU9@0M7Ad06YZ
JP14A4@0EEEE06UYJ@1CDe<0IfMW07=cL`0g=cL08R8R05MGE`1dM7@0HF5Q02HV9P0o?cl0<S8b03De
=@0K6a/071`L0451@@0^;Rh0C4a<05iNGP0k>c/0;2`/05eMG@0Y:BT0Bd];055AD@0Z:RX0H61P03Xj
>P0e=CD0D51@02d];@0K6a/0<c<c05IFEP1KFe/0@d=306UYJ@0[:b/0<c<c04U9B@1;Bd/0=3@d07If
MP1bLW808b<S03Xj>P0o?cl0[:b/04M7A`16ATH0U9BD07emO@13@d<0S8b<08V9R@0d=3@0F5QH04a<
C00Q8B40<c<c05]KF`17AdL0=SHf04M7A`1<C4`0F5QH05IFEP2CTi<0I6AT04Y:BP1LG5`0<c<c079b
LP21PH40IFEU02h^;P1LG5`0L71`03hn?P1IFET0AdM70410@023Ph<0HV9R0080De=C0880GemO092@
T01=CDd0@T92061PH016ATH0Jf][07YjNP15ADD0K6a/02l_;`1PH600O7al07IfMP1hN7P0<C4a05=C
D`1]KFd0KVi^06a/K019BDT0MgMg0;^k^`1TI6@0@D5109fMW@1lO7`0LW9b061PH023Ph<0SHf=07Qh
N00U9BD0LG5a08j>SP1[Jf/0G5aL07=cL`0c<c<0H61P09:BTP0g=cL0@T9206m_K`0n?Sh0Ng]k071`
L02LW9`0OWin07AdM01:BTX0S8b<0:f][@1bLW80MGEe0<k>cP1gMgL0[Jf]08j>SP21PH40CTi>0:2P
X02k^k/0ADE506m_K`2`/;00MGEe06EUI@1gMgL0DE5A06QXJ02BTY80I6AT04U9B@1LG5`0D51@05YJ
FP2NWYh0Fe]K09jNWP1JFUX0CTi>0<W9b@2ATI40?clo07UiN@10@400GemO06m_K`0`<300M7Ad06i^
KP2DU9@0KFe]059BDP2WYjL0Xj>S02DU9@1FEUH0RXZ:0<S8b02GUiL0?Cdm04U9B@1HF5P0?clo06m_
K`1VIVH0ADE5059BDP29RHT0LW9b071`L01VIVH0Bd];02l_;`1DE5@0KVi^04U9B@29RHT0Ogmo08J6
QP1PH600Rh^;06QXJ00k>c/0Jf][05MGE`0j>SX0KVi^0P1:BTX09P1/K6`0X:2P03/k>`1cLg<0SHf=
05]KF`0^;Rh0:2PX05iNGP0O7al0:RXZ05EEE@0R8R80EUIF07=cL`2RXZ80;2`/04i>CP27QhL0JFUY
0410@01DE5@0DU9B01LG5`19BDT0MGEe04E5A@0o?cl0LG5a02@T901TI6@0GemO03hn?P2WYjL0YZJV
03`l?00R8R80@d=30P1<C4`01@1IFET0OGem05IFEP1ZJVX0AdM701cooooo00H0>SXj05MGE`27QhL0
Ph>305iNGP11@D4204E5A@0>04Q8B01eMGD0EUIF02DU9@0M7Ad0<c<c0492@P0f=SH0<C4a0410@00l
?3`0?clo05QHF01?Cdl2051@D01=07QhN01;Bd/0FUYJ06][J`12@T807AdM01XJ6P0G5aL06ATI0492
@P0d=3@09BDU02/[:`0`<300<c<c01lO7`0L71`07AdM02d];@1nOWh0clo?0<c<c02d];@0De=C03Ti
>@0o?cl0B4Q807YjNP17AdL0DE5A04A4A02g]kL0YZJV0861P@2g]kL0^[Zj05iNGP16ATH0OGem0;Jf
]P2UYJD0S8b<0;jn_P1WIfL07alO02TY:@1^KVh0>CTi020P800O7al0;2`/05ADE00Z:RX0P8200=7A
d@11@D4071`L01dM7@0L71`09bLW03Hf=P0i>CT0EUIF0<G5a@1XJ6P0Hf=S08n?S`2GUiL0/k>c051@
D023Ph<09BDU030`<00m?Cd0?clo05ADE01`L7000P1mOGd02P1^KVh0CTi>0451@@2l_;`0Jf][04M7
A`1PH600D51@0:ZZZP0j>SX201XJ6P0=01DE5@0D51@04Q8B01@D500A4A40B4Q80492@P0`<300Hf=S
075aL@1iNGT0UYJF01hN7P0201DE5@04028R8P0_;bl0ADE503<c<`806QXJ00h06a/K01lO7`2b/[80
eMGE0=gMg@3QhN40fm_K0<W9b@2@T900KVi^03Ph>00R8R805aLG01@D50805ADE00@061PH01TI6@0U
9BD0UYJF0P29RHT05@3>c/h0cLg=0<k>cP0f=SH0[jn_04Y:BP0Z:RX0<C4a05mOG`2g]kL0G5aL08>3
P`1NGUh0O7al06EUI@1QHF40LG5a06YZJP1UIFD0GUiN05QHF00209bLW01]0=KFeP3Lg=`0inOW0=SH
f022PX808b<S03Hf=P1EEED0DU9B06i^KP1nOWh0PH6104Y:BP0e=CD0DU9B0;Vi^@2CTi<0Ng]k08J6
QP1[Jf/0B4Q8061PH015ADD0CDe=04Q8B01HF5P0Fe]K06QXJ02LW9`0OGem06=SH`26QXH0`<300>OW
i`37alL0X:2P0::RXP2JVYX0Z:RX0;2`/02ZZZX0Q8B4065QH@0n?Sh0eMGE0>3Ph03UiND0d=3@09FE
U@2=SHd0RXZ:0<W9b@2EUID0DE5A05IFEP16ATH0PH61071`L01>CTh06ATI01DE5@0G5aL05QHF01hN
7P1YJFT0BDU90:BTY02j^[X0Kfm_065QH@1mOGd0f][J0=CDe02TY:@0PX:20<O7a`3AdM40XZ:R06i^
KP1MGEd0Hf=S075aL@2b/[80_;bl0:ZZZP1?Cdl0<C4a04e=C@1gMgL0?3`l02HV9P0U9BD0;Bd]03`l
?019BDT0M7Ad0<o?c`1TI6@09bLW038b<P0g=cL0A4A404a<C020P800T92@08R8R00R8R8071`L02<S
8`0Aooooo`003oooool0902>SXh0UiNG065QH@1YJFT0SHf=07AdM01YJFT0@41004m?C`1[Jf/0GUiN
08f=S@1=CDd0Ti>C05mOG`1bLW80ATI608j>SP2LW9`0H61P051@D01hN7P0<c<c03Ti>@1OGel0=SHf
06ATI01>CTh05aLG03lo?`1ADE40;bl_02HV9P11@D40<c<c05EEE@80Cdm?0?`07QhN05aLG013@d<0
7AdM0492@P0^;Rh0KVi^07QhN01ADE40<C4a04A4A00k>c/0QHF506i^KP0];Bd0GemO03Lg=`1_Kfl0
K6a/03@d=00O7al0>CTi05EEE@1KFe/0BTY:075aL@11@D40=CDe03`l?00^;Rh0410@03hn?P1GEeL0
=CDe038b<P0X:2P0Lg=c05MGE`1/K6`0[jn_06a/K00I6AT0ATI606=SH`0n?Sh0I6AT03dm?@0E5AD0
>c/k07UiN@18B4P0:b/[04Q8B012@T80=cLg07moO`2CTi<0KFe]0451@@1CDe<0>c/k04];B`1XJ6P0
Fe]K03Ph>00m?Cd0Hf=S03Xj>P1KFe/0ADE501hN7P0n?Sh0GemO05]KF`11@D40>3Ph07moO`15ADD0
@41007AdM01?Cdl0<S8b059BDP0m?Cd0FUYJ03`l?011@D40LG5a06a/K01UIFD08b<S03Lg=`1UIFD0
J6QX05IFEP0M7Ad0IVIV0;:b/P1NGUh0?3`l0:NWY`1>CTh0P82007alO021PH40T92@06a/K01:BTX0
LG5a05iNGP17AdL0G5aL06YZJP0W9bL0>SXj07alO00c<c<0@D51061PH00Q8B40A4A405]KF`2:RXX0
LG5a03<c<`1;Bd/0XZ:R0:^[Z`1TI6@0SHf=0=?Cd`1YJFT0c<c<0;Zj^P23Ph<0D51@0:ZZZP2c/k<0
B4Q803Ti>@1[Jf/0H61P06i^KP1PH6008R8R06=SH`2JVYX0Fe]K04Y:BP1YJFT0>CTi05]KF`2JVYX0
DU9B0:ZZZP1:BTX0@T9208f=S@1kNg/0@D51071`L00U9BD0Fe]K075aL@0c<c<0J6QX06IVIP25QHD0
L71`03De=@24Q8@0SHf=051@D01]KFd0QXJ60=;BdP2DU9@0>3Ph08:2PP1NGUh0ADE507EeM@1QHF40
>SXj04e=C@2?Shl0OWin06e]K@1VIVH0E5AD03@d=024Q8@0V9RH05eMG@25QHD0K6a/075aL@0d=3@0
VYZJ04m?C`0_;bl0KFe]059BDP1;Bd/0WIfM05YJFP1BDU80LW9b09jNWP1DE5@0_;bl0<W9b@1MGEd0
=CDe02h^;P1nOWh071`L0451@@2?Shl0:2PX05MGE`1fMWH0W9bL01/K6`17AdL0Lg=c04m?C`0j>SX0
C4a<04i>CP1KFe/0=SHf07=cL`1>CTh0A4A406MWI`0d=3@0@T9205=CD`0e=CD0Xj>S0;:b/P0d=3@0
<30`07EeM@2@T900Ng]k051@D01ZJVX0B4Q804];B`0k>c/Looooo`0?03dm?@13@d<0UYJF06i^KP1U
IFD0;bl_02d];@0h>3P0=cLg03Ti>@1FEUH0QhN705MGE`0d=3@092@T00807AdM01808b<S01XJ6P0E
5AD07AdM04E5A@1RHV80F5QH09JFUP1cLg<0CDe=05MGE`23Ph<0;Rh^01/K6`0G5aL061PH04i>CP1?
Cdl202<S8`0>020P800T92@0;2`/02HV9P0_;bl0FEUI05EEE@3EeMD0S8b<06IVIP1]KFd0G5aL0492
@P0o?cl206i^KP0F051@D00h>3P0HV9R0::RXP2][Jd0IFEU04A4A021PH40_;bl055AD@0[:b/0;Bd]
04Y:BP1lO7`0YJFU07moO`21PH40QXJ601DE5@0B4Q8092@T05]KF`80;bl_00H0A4A40=[JfP2n_[h0
EUIF024Q8@0O7al201/K6`1Q02/[:`1>CTh0_;bl09fMW@28R8P0BDU905IFEP18B4P0G5aL07emO@0U
9BD092@T01hN7P0I6AT06a/K01dM7@14A4@0Lg=c08J6QP2JVYX0XJ6Q0>7Qh@3<c<`0`L710;Bd]036
a/H0T92@03Ph>00J6QX071`L01TI6@0E5AD04Q8B01DE5@0L71`0S8b<02<S8`0L71`07QhN06][J`2/
[:`0P82006ATI00G5aL04a<C020P800Q8B40=cLg09FEU@2=SHd0HF5Q05aLG01CDe<0];Bd0=oOg`3P
h>00fm_K0;Jf]P2=SHd0Cdm?06EUI@25QHD0QXJ607EeM@0g=cL06ATI01DE5@0G5aL0:2PX07MgM`0Y
:BT09RHV034a<@26QXH0Ph>30<W9b@0g=cL0Q8B407alO00h>3P0=3@d04Q8B02KVi/0_Kfm07emO@1b
LW80CTi>03dm?@0c<c<0<C4a02HV9P0R8R808B4Q01lO7`0V9RH0JVYZ0=gMg@020>[ZjP0j0>KViP2W
YjL0De=C0:FUY@26QXH0PX:2079bLP1IFET0=SHf03Lg=`0];Bd0;bl_06EUI@32`/80Y:BT0<c<c01<
C4`0?Cdm071`L01=CDd0EeMG06MWI`1NGUh0KFe]079bLP0d=3@0;bl_069RHP2LW9`0e=CD0<[:bP3A
dM40/K6a0;bl_036a/H0^k^k071`L012@T80>CTi04I6AP1JFUX0];Bd0<71`@3?cll0f][J0:b/[01k
Ng/0RXZ:0:j^[P1fMWH09RHV02LW9`10@400JVYZ04U9B@1OGel0Bd];01LG5`805ADE02h05QHF01`L
702TY:@0]KFe08F5Q@21PH40[:b/0=OGe`3Rh^80gMgM0=?Cd`2=SHd0WinO0:RXZ02ZZZX0UIFE04e=
C@1FEUH0RXZ:0=gMg@3De=@0[Jf]02LW9`1>CTh0MWIf07]kN`0e=CD08B4Q02DU9@0X:2P0=CDe04];
B`1LG5`0bl_;0<G5a@22PX80ATI603dm?@13@d<0EUIF0:2PX02QXJ40W9bL03Ti>@17AdL0L71`4Ooo
ool000oooooo01d0RXZ:0:BTY02<S8`0Q8B4096AT@1JFUX0Ng]k05ADE01^KVh0VIVI06a/K024Q8@0
DU9B09bLW01YJFT0F5QH024Q8@1WIfL0QXJ604];B`19BDT0O7al05MGE`17AdL0Cdm?03@d=01YJFT0
MWIf04Y:BP0208N7Q`3o03Lg=`0U9BD0FEUI04m?C`1LG5`0C4a<04E5A@0/;2`0B4Q803/k>`0L71`0
@41003<c<`0e=CD0EeMG05EEE@0/;2`0CTi>02XZ:P15ADD0FEUI02`/;01NGUh08b<S03De=@1OGel0
ATI601/K6`0l?3`0EUIF02PX:00R8R80L71`0492@P0b<S80<30`02@T900R8R80De=C05UIF@0/;2`0
;Bd]03Xj>P1mOGd0CTi>06YZJP2g]kL0De=C024Q8@1^KVh0EeMG030`<01VIVH0<C4a014A4@0H61P0
CTi>04M7A`0Q8B40C4a<03hn?P0M7Ad0JFUY06e]K@1TI6@0?Cdm051@D014A4@0Hf=S05]KF`1ZJVX0
E5AD03lo?`0f=SH0<c<c05mOG`13@d<0>CTi04A4A01BDU80@41005=CD`0n?Sh0L71`03lo?`10@400
Kfm_05IFEP1:BTX0H61P04U9B@1ADE40:2PX05UIF@1iNGT0Hf=S059BDP0W9bL0@41005YJFP1YJFT0
L71`04A4A01MGEd0^KVi04a<C00o?cl0W9bL0492@P1[Jf/0BTY:08^;R`2GUiL0BTY:065QH@2WYjL0
KFe]02DU9@1RHV80Hf=S03/k>`1:BTX0FEUI03<c<`1CDe<0QHF504m?C`1LG5`0IFEU08f=S@1WIfL0
BTY:03Xj>P1YJFT0VIVI05YJFP2JVYX0f][J03De=@25QHD0S8b<05aLG01KFe/0/K6a0;bl_01]KFd0
O7al06a/K01_Kfl0MGEe075aL@1FEUH0F5QH08F5Q@1DE5@0Cdm?06a/K018B4P0BDU909>CT`1>CTh0
YJFU07]kN`1`L700_kno09JFUP1?Cdl0LG5a02/[:`10@400CDe=01lO7`1RHV80FUYJ06YZJP1<C4`0
=3@d08:2PP1XJ6P08b<S059BDP1nOWh0f=SH09>CT`0X:2P0CTi>06IVIP11@D40M7Ad04i>CP0j>SX0
MGEe09bLW01VIVH0IFEU05]KF`1@D500=3@d04m?C`1cLg<0I6AT07MgM`1dM7@0L71`03Hf=P20P800
Hf=S03<c<`1BDU80@410030`<01XJ6P0Cdm?04A4A01RHV80Shn?038b<P1PH600MGEe061PH013@d<0
=3@d09bLW00[:b/09RHV051@D00a<C40CTi>07moO`2JVYX0<C4a04e=C@2CTi<0G5aL038b<P14A4@0
D51@061PH010@400G5aL03Ph>01FEUH0R8R803De=@1@D5009bLW02PX:02IVIT0YjNW0410@00O7al0
>SXj04E5A@10@400>SXj000405mOG`1:BTX0EUIF03De=Acooooo01<0>SXj03dm?@2XZ:P0LG5a08B4
Q00f=SH0;Bd]02XZ:P0`<300?clo04Y:BP2GUiL0BTY:02HV9P0H61P051@D01<C4`0E5AD05aLG00<0
5ADE02H0:2PX06IVIP2WYjL0Xj>S06ATI024Q8@0UYJF08F5Q@0^;Rh06a/K01`L701RHV80Shn?03Lg
=`0V9RH07alO01dM7@0R8R808B4Q02`/;01ADE40Kfm_0;Rh^01;Bd/0Lg=c028R8P1JFUX0OWin07Mg
M`2<S8`0EUIF06ATI01gMgL0L71`065QH@2MWId0O7al03hn?P80=SHf02@0;bl_010@400>3Ph0410@
01TI6@0a<C40Xj>S0=gMg@1]KFd04Q8B01@D500Q8B40?Cdm01dM7@0V9RH0J6QX07YjNP16ATH0NGUi
06e]K@0U9BD06a/K01LG5`0E5AD0;2`/0;jn_P0m?Cd0=3@d03De=@1FEUH0;bl_09ZJVP1kNg/09RHV
02DU9@0`<30301TI6@0302DU9@0c<c<0=cLg0080=SHf00P0KFe]08n?S`2=SHd0dm?C0>OWi`1`L700
CDe=01PH60806ATI010071`L01dM7@0/;2`0A4A40:>SX`0N7Qh092@T03`l?01:BTX0U9BD09nOW`2N
WYh0JFUY055AD@10@400D51@0P1KFe/05@1JFUX0HF5Q06MWI`15ADD0P8200:^[Z`3Bd]80e]KF0;fm
_@1ZJVX0>c/k03@d=00g=cL0?Cdm0410@01RHV80NGUi061PH00c<c<0HF5Q02d];@0301DE5@0I030`
<01mOGd0c/k>0:RXZ01ZJVX0`/;209NGU`20P800[Jf]0:RXZ01jNWX0Ph>307inOP22PX80M7Ad07em
O@1SHf<0?Shn02XZ:P0];Bd0:BTY01lO7`0d=3@0dM7A0>OWi`030>WYj@080>OWi`32`/80IfMW03/k
>`0G5aL09BDU06MWI`0o?cl2034a<@0=04A4A027QhL0[jn_0<G5a@2^[Zh0JVYZ08n?S`27QhL0K6a/
07QhN01eMGD0W9bL03`l?00301`L70090492@P2GUiL0QHF50<O7a`3EeMD0/[:b071`L00_;bl092@T
00807alO04<0=cLg04Q8B020P800[Zj^0=?Cd`3?cll0Kfm_03Xj>P0d=3@0?clo0:BTY00d=3@0<c<c
04E5A@1>CTh0>CTi030`<01EEED0G5aL02PX:00I6AT071`L01XJ6P2GUiL0eMGE0=;BdP38b<P0[:b/
08j>SP2TY:@0dM7A0<?3``37alL0dM7A04e=C@1cLg<0Zj^[09NGU`1TI6@0L71`0<c<c03IfMT0`l?3
08>3P`1RHV80ZJVY0;Jf]P0j>SX09BDU02TY:@0U9BD0<30`04=3@`2FUYH0emOG0=?Cd`3GemL0/K6a
06i^KP1GEeL0Q8B40<G5a@2n_[h0clo?092@T01/K6`0AdM7017ooooo000?ooooo`3R07QhN02NWYh0
Ogmo0820P025QHD0H61P09JFUP1CDe<0KFe]0:6QX@1SHf<0WYjN08J6QP2l_;`0IVIV07QhN01KFe/0
L71`09bLW01KFe/0CDe=092@T02ATI40LG5a05iNGP0d=3@0J6QX08b<S01EEED0Vi^K092@T00h>3P0
;2`/055AD@1:BTX0GEeM03dm?@0o?cl0<S8b02/[:`0P82007AdM0410@00j>SX0DE5A06=SH`1IFET0
=SHf05ADE011@D40F5QH07EeM@0d=3@0Hf=S04I6AP0n?Sh0F5QH03Ti>@0I6AT0<c<c05]KF`1JFUX0
;bl_06=SH`0i>CT0<c<c03`l?00i>CT0;Rh^06m_K`1SHf<0<S8b03Lg=`10@400Ng]k05]KF`1SHf<0
X:2P05=CD`0S8b<0MWIf05MGE`0`<300I6AT02h^;P0E5AD07QhN07inOP0e=CD09BDU05iNGP1@D500
=cLg07moO`1iNGT0H61P059BDP1mOGd0?clo06m_K`19BDT0PX:205ADE019BDT0@D5103Lg=`1/K6`0
?clo03Xj>P19BDT0DE5A04E5A@1=CDd0>c/k06YZJP1=CDd0KFe]07AdM01RHV80LG5a05MGE`1IFET0
IFEU03Xj>P1mOGd0PX:2055AD@1[Jf/0>SXj04Y:BP1ADE40OGem06MWI`0m?Cd0L71`0;Zj^P0j>SX0
De=C0;Bd]01<C4`0TI6A03lo?`1PH600MGEe051@D01HF5P0WYjN08Z:RP1CDe<0HF5Q05eMG@15ADD0
LW9b04m?C`0];Bd0F5QH07IfMP1EEED0JVYZ06UYJ@2SXj<0PX:206m_K`1[Jf/0UIFE0:b/[01GEeL0
ZZZZ0<g=c@1aLG40XJ6Q09:BTP1=CDd0GUiN0;no_`2h^;P0IFEU09VIV@2KVi/0BDU907inOP2NWYh0
H61P07=cL`2XZ:P0MGEe05UIF@1dM7@0Fe]K05IFEP2OWil0EeMG09nOW`1^KVh0L71`0<71`@2CTi<0
ATI607UiN@15ADD0Bd];06=SH`0_;bl0F5QH055AD@1gMgL0Fe]K03/k>`1nOWh0I6AT02/[:`1BDU80
Jf][0=SHf020P800:b/[05EEE@17AdL0=SHf07IfMP11@D407alO05QHF01iNGT0J6QX05EEE@80C4a<
03h0=SHf05MGE`1bLW80GEeM07]kN`27QhL0Shn?06a/K01gMgL0R8R803Lg=`1:BTX0GemO04=3@`1j
NWX0K6a/04Q8B01OGel0ZZZZ059BDP2GUiL0_;bl08n?S`1IFET0B4Q8092@T00c<c<0;bl_06EUI@0_
;bl0BDU907EeM@2OWil0>CTi05mOG`2ATI40JFUY0451@@1WIfL0Ogmo06EUI@1?Cdl0Kfm_03`l?01C
De<0PX:203/k>`1MGEd0C4a<02DU9@25QHD0YjNW04Y:BP0[:b/0C4a<05aLG00d=3@0<C4a08^;R`2>
SXh0HV9R03Lg=acooooo00P0?3`l04];B`3@d=00/K6a0;Vi^@12@T80=SHf02TY:@809BDU00@092@T
05ADE00V9RH06ATI0`0E5AD00`0I6AT05aLG01DE5@0301DE5@0Z02PX:030`<00bLW90:^[Z`2l_;`0
KFe]0:f][@1NGUh0ADE504=3@`27QhL0QXJ60861P@19BDT09bLW01hN7P0P8200>c/k05UIF@19BDT0
E5AD0=3@d02<S8`0Rh^;02d];@0O7al0Ogmo0<o?c`2/[:`0UiNG05IFEP0O7al05ADE024Q8@1jNWX0
>3Ph02TY:@15ADD0>CTi04M7A`0E5AD04a<C0P0E5AD0400^;Rh0IFEU0:b/[02b/[80:2PX01lO7`17
AdL0G5aL034a<@0/;2`0QXJ6024Q8@0>3Ph04Q8B05QHF01KFe/201TI6@0601DE5@0];Bd0Y:BT04E5
A@0U9BD0=CDe0P1UIFD0?`2g]kL0Shn?04];B`0];Bd0820P01LG5`0I6AT05ADE01TI6@0S8b<0:b/[
02d];@0^;Rh092@T07inOP1FEUH0N7Qh0<?3``2HV9P0N7Qh01dM7@0K6a/08R8R03Ph>01mOGd0G5aL
09RHV02j^[X0:b/[0410@01ADE40>CTi03`l?02n_[h0bl_;0<O7a`1QHF40:b/[03dm?@13@d<0>CTi
030`<00f=SH0CDe=069RHP2LW9`0^[Zj0=7Ad@2CTi<0^[Zj08n?S`1JFUX0ADE503lo?`0l?3`0?Shn
03dm?@0o?cl0GEeM0;6a/@1JFUX05ADE01HF5P0201DE5@0c01dM7@2JVYX0_[jn0=_Kf`2o_kl0g=cL
0<k>cP2i^KT0Zj^[0:VYZ@1KFe/0A4A406MWI`1FEUH0>CTi03/k>`1UIFD0Rh^;07emO@1ADE40;Bd]
020P801gMgL0cLg=0=SHf031`L40G5aL09NGU`3Ng]h0@T92030`<00I6AT05aLG028R8P26QXH0G5aL
04Y:BP1<C4`0H61P0861P@2XZ:P0MgMg0;Fe]@3AdM40WinO0;Fe]@2NWYh0Hf=S03dm?@1@D500:BTY
00807AdM00P06QXJ02/[:`1EEED0KVi^0:^[Z`2`/;00WinO01LG5`<05ADE04@05aLG01DE5@0H61P0
>3Ph0<[:bP3Hf=P0/[:b05MGE`0O7al08B4Q03<c<`2MWId0HF5Q02TY:@1DE5@0?clo03Ti>@0`<300
;Rh^03Lg=`1LG5`0C4a<030`<00W9bL0_[jn0<71`@2@T900C4a<03Lg=`14A4@0XJ6Q09BDU035aLD0
_Kfm0<K6aP15ADD0=cLg07moO`2m_Kd0]kNg0<C4a03De=@0eMGE0<W9b@3?cll0bl_;0=KFeP3:b/X0
F5QH03Hf=P0h>3P0=3@d03`l?01cLg<0WIfM06m_K`2TY:@0dm?C0<c<c03GemL0alO70<_;b`3EeMD0
_[jn08b<S00g=cL0B4Q807inOQ7ooooo000?ooooo`2@07YjNP2MWId0I6AT0:NWY`1fMWH0RHV909bL
W01?Cdl0Lg=c0:^[Z`1SHf<0YJFU08Z:RP30`<00IVIV09JFUP1KFe/0SXj>07AdM00i>CT0IfMW08^;
R`20P800Ogmo07QhN00T92@0Kfm_08F5Q@1>CTh0UYJF04];B`0/;2`0BTY:059BDP1QHF40EEEE02TY
:@1<C4`0;bl_03/k>`0M7Ad0=3@d05YJFP1=CDd0PX:207inOP0j>SX0D51@055AD@0k>c/0JFUY07al
O00];Bd0GemO03dm?@13@d<0Cdm?02/[:`0H61P0?3`l05eMG@1WIfL0=CDe06QXJ013@d<0MgMg06e]
K@0c<c<07alO065QH@1iNGT0Bd];04=3@`19BDT0Shn?05eMG@2=SHd0^KVi075aL@0W9bL0LG5a06AT
I017AdL0Ti>C04Q8B00N7Qh0;bl_08R8R019BDT07alO04E5A@11@D40>c/k0:6QX@2[Zj/0J6QX03lo
?`1>CTh0>3Ph08Z:RP1>CTh0GUiN059BDP1PH600FUYJ03Hf=P25QHD0C4a<04A4A01^KVh0Jf][04U9
B@1?Cdl0F5QH071`L00g=cL0De=C04a<C01;Bd/0FEUI06][J`14A4@0GemO030`<01NGUh0Jf][0451
@@1BDU80=3@d071`L01DE5@0GUiN05UIF@17AdL0[:b/0;Fe]@0h>3P0@D5109RHV015ADD0HV9R05EE
E@2DU9@0M7Ad0P1YJFT0T01dM7@0G5aL04M7A`1VIVH0De=C02`/;01fMWH0KFe]038b<P1ADE40@D51
03<c<`22PX80FEUI07YjNP2<S8`0LW9b09jNWP2h^;P0UYJF055AD@37alL0_[jn06e]K@2j^[X0[Jf]
079bLP1KFe/0`l?30;2`/00i>CT0KFe]05mOG`1:BTX0KVi^079bLP18B4P0WIfM0;Fe]@1FEUH0GEeM
09FEU@1EEED0LW9b0861P@1KFe/0Zj^[04i>CP16ATH0/K6a08:2PP0Q8B40Lg=c03`l?01ADE40HF5Q
02DU9@1]KFd0OWin0:^[Z`1aLG40BTY:06QXJ01HF5P0?clo06a/K01SHf<0gMgM07QhN00g=cL0L71`
05MGE`0];Bd0G5aL03@d=00X:2P0E5AD07moO`1QHF40DE5A04U9B@1;Bd/0@41005eMG@1hN7P0FUYJ
08N7Q`2UYJD0SHf=05EEE@1DE5@0F5QH028R8P1>CTh0AdM704A4A01mOGd0BDU903De=@1SHf<0Xj>S
05ADE02ZZZX0^KVi08n?S`1LG5`0O7al0:RXZ01EEED0=CDe06EUI@0b<S80?Shn07MgM`2VYZH0<30`
04m?C`2WYjL0Lg=c038b<P15ADD0IVIV03hn?P20P800Ph>304I6AP1LG5`0TI6A028R8P1DE5@0EUIF
02<S8`24Q8@0UiNG02LW9`0m?Cd0LG5a07=cL`1DE5@0<S8b05eMG@1bLW80Bd];04M7Aacooooo01@0
M7Ad0;Ng]`3EeMD0emOG08j>SP1QHF40Shn?065QH@1;Bd/0?clo03Lg=`1IFET0;2`/02d];@0Y:BT0
820P01/K6`0H61P06ATI01PH60806QXJ02d061PH01/K6`2j^[X0gMgM0<c<c02BTY80PH6109:BTP12
@T80=CDe04A4A01NGUh05aLG02d];@24Q8@0Hf=S03hn?P1ADE40GUiN07IfMP1QHF40Cdm?09ZJVP2W
YjL0W9bL08:2PP14A4@0JVYZ0:j^[P0j>SX07alO01HF5P0J6QX06ATI02LW9`1/K6`09BDU01<C4`0E
5AD09RHV04i>CP0^;Rh05ADE01TI6@0O7al00P1aLG40602][Jd0f=SH0;^k^`20P800Ph>308f=S@26
QXH0UiNG0;:b/P0E5AD03Ph>010@400B4Q80QhN704E5A@0^;Rh092@T03dm?@2_[jl0Lg=c03Xj>P1W
IfL0RHV90:NWY`80:2PX00X0IfMW059BDP0M7Ad06QXJ01/K6`0H61P06ATI01hN7P0W9bL0:RXZ0P0R
8R805`1?Cdl0WinO05MGE`2[Zj/0`L710<c<c01mOGd0Fe]K04e=C@0k>c/0;Bd]04=3@`2OWil0WIfM
05iNGP2HV9P0De=C07AdM01@D500UIFE07=cL`2IVIT0e=CD0080MGEe0180Kfm_06QXJ01OGel0IVIV
06e]K@22PX80`<300<c<c02i^KT0RXZ:03@d=02b/[80BTY:034a<@0Y:BT08R8R02<S8`0Q8B4201dM
7@80DE5A0`0E5AD09P0G5aL08B4Q07]kN`2?Shl0hN7Q0<30`03Xj>P0c<c<0<O7a`2QXJ40^KVi055A
D@28R8P0?3`l020P800N7Qh07alO02LW9`0U9BD0>SXj079bLP1OGel0CDe=08^;R`3?cll0V9RH09VI
V@1?Cdl0CTi>0<[:bP0k>c/0K6a/04E5A@0_;bl0?Shn075aL@31`L40][Jf0P2l_;`05@2@T900E5AD
0:JVYP3AdM40g=cL0<71`@2JVYX0Ph>303hn?P0N7Qh0@41002LW9`0a<C409RHV028R8P1DE5@0ATI6
05MGE`1XJ6P0=SHf04e=C@0301DE5@0B01LG5`0K6a/05QHF01PH600k>c/0clo?0;>c/`2`/;00T92@
03hn?P0S8b<0:b/[05MGE`2HV9P0>3Ph05EEE@0W9bL0;2`/0P0d=3@0<@0_;bl0<S8b03Lg=`1`L700
/;2`07emO@1OGel0;2`/03Hf=P1?Cdl0De=C04Y:BP0b<S80H61P0:b/[03=cLd0[Jf]03hn?P1JFUX0
/k>c0=KFeP3Lg=`0emOG0<_;b`2a/K40dM7A0=CDe03Kfm/0h>3P0<71`@2:RXX0AdM7030`<00^;Rh0
Ogmo02l_;`1OGel0L71`0::RXP3>c/h0aLG50=cLg03Kfm/0`/;20;Zj^P2][Jd0QhN70;6a/@25QHD0
4Oooool000oooooo0140MgMg09NGU`1EEED0N7Qh06e]K@1JFUX0Cdm?06i^KP2GUiL0RXZ:06MWI`2A
TI40UYJF0<G5a@1<C4`0L71`03`l?00207alO01;03dm?@18B4P0L71`03lo?`14A4@0G5aL028R8P17
AdL0E5AD03Lg=`1WIfL0H61P02TY:@0j>SX0@D5105mOG`1RHV80<S8b03Lg=`0N7Qh0@T92028R8P0J
6QX0?Shn02h^;P1CDe<0GemO051@D00i>CT0>c/k04E5A@27QhL0GUiN038b<P1bLW80?Cdm04I6AP1L
G5`0<S8b02/[:`1RHV80Ogmo061PH017AdL0JVYZ02d];@1;Bd/0@41001lO7`0Y:BT0N7Qh061PH00l
?3`0=cLg04I6AP24Q8@0@D5106QXJ02d];@0GemO03Ph>02NWYh0SXj>03Ti>@1TI6@0<S8b01DE5@0Q
8B40Kfm_02PX:00L71`0Cdm?03Xj>P0Y:BT0Ph>30080IVIV0;X0BTY:04];B`0d=3@0Hf=S055AD@1G
EeL0>CTi06QXJ01;Bd/0<c<c079bLP15ADD0CDe=04A4A01ADE40@d=304A4A00d=3@0H61P03Ph>01I
FET0M7Ad05iNGP10@400J6QX04e=C@1YJFT0>SXj06YZJP1dM7@0C4a<04e=C@0n?Sh0MWIf06ATI01M
GEd0Kfm_0451@@20P800[Zj^03Lg=`0o?cl0TY:B04];B`1eMGD0FEUI0;no_`1VIVH0DE5A07UiN@28
R8P0Fe]K03dm?@1OGel0A4A40492@P1kNg/0E5AD030`<01]KFd0N7Qh04U9B@1LG5`0IfMW06i^KP1o
Ogl0E5AD05QHF02WYjL0OWin0451@@38b<P0X:2P04M7A`2_[jl0W9bL05ADE01OGel0d=3@0:VYZ@1B
DU80UiNG055AD@1?Cdl0KVi^065QH@0e=CD0J6QX08J6QP0j>SX0ADE5071`L00h>3P0PH6108b<S01T
I6@0Zj^[04M7A`0];Bd0]kNg09FEU@15ADD0MgMg02d];@1nOWh0I6AT01/K6`17AdL0A4A407UiN@1X
J6P0?Cdm059BDP1LG5`0?Shn05aLG01OGel0fm_K075aL@11@D40M7Ad06e]K@0c<c<0GemO03Xj>P0i
>CT0H61P07alO016ATH0GemO08B4Q01QHF40?Shn06ATI01hN7P0?3`l071`L01[Jf/0Q8B407AdM01A
DE40Hf=S02@T901_Kfl0IFEU04U9B@1kNg/0@d=303Lg=`1SHf<0Ti>C05UIF@2a/K40]KFe09>CT`1F
EUH0UIFE0;Fe]@1aLG40=cLg06QXJ00I6AT0?Shn07]kN`2;Rh/0=CDe06EUI@3:b/X0QXJ603De=@12
@T80H61P0451@@1LG5`0M7Ad05=CD`1XJ6P0YJFU038b<P1;Bd/0ATI602<S8`1kNg/0Vi^K03/k>`0/
;2`204M7A`0606ATI00i>CT0EUIF06e]K@12@T80;bl_7?ooool0>`25QHD0IFEU0:NWY`3Hf=P0Vi^K
04];B`1LG5`0KVi^05mOG`1IFET0Kfm_08>3P`1_Kfl0[Jf]0;bl_01`L700>c/k03<c<`0j>SX0?3`l
03dm?@1;Bd/0CDe=05mOG`3GemL0g=cL0>7Qh@3=cLd0/[:b0:NWY`2?Shl0R8R80<G5a@1TI6@0:b/[
02<S8`0V9RH0UIFE0<[:bP2/[:`0Zj^[09^KV`2NWYh0NWYj05EEE@2k^k/0];Bd0<S8b02VYZH0f][J
0<O7a`1:BTX0:2PX02LW9`0b<S80>3Ph03hn?P1dM7@0<S8b00<05ADE02D0=SHf06i^KP0n?Sh0B4Q8
08V9R@2YZJT0RXZ:0;Bd]03Fe]H0QhN7069RHP22PX80UiNG096AT@2NWYh0YjNW03Ph>00C4a<0410@
014A4@23Ph<0e=CD0:n_[`2NWYh0[:b/0<K6aP34a<@0][Jf0<o?c`3;bl/0<30`01dM7@0O7al071`L
04e=C@1CDe<07alO008071`L03D06a/K01dM7@0Q8B407AdM024Q8@0M7Ad0820P09FEU@3=cLd0fm_K
0>OWi`3Vi^H0gmoO0=CDe02HV9P0PH61092@T02f][H0g=cL07YjNP1ADE40Ogmo0;Bd]03>c/h0YZJV
08:2PP0W9bL0;Bd]06MWI`18B4P0;bl_02`/;00N7Qh07AdM01TI6@0G5aL092@T07MgM`2:RXX0bLW9
06IVIP0e=CD0=cLg0;6a/@0c<c<07AdM01/K6`0L71`07AdM02DU9@0R8R809RHV05]KF`0201DE5@0@
01XJ6P0m?Cd0BTY:03Ph>03<c<`0g=cL0=7Ad@3Ti>@0dM7A0=GEe@2EUID0`l?30;Jf]P1=CDd0@410
024Q8@807QhN0680820P01hN7P0V9RH092@T06YZJP2d];@0/[:b06EUI@1kNg/0Ti>C05IFEP26QXH0
`L710<C4a01/K6`0DE5A07alO02l_;`0JVYZ05]KF`24Q8@0aLG50<30`01OGel0=cLg02PX:025QHD0
X:2P0:^[Z`1lO7`0IVIV01dM7@0N7Qh0>CTi03<c<`1>CTh0ADE504a<C01nOWh0G5aL05IFEP1HF5P0
;2`/03<c<`0G5aL05ADE01HF5P0H61P05QHF01PH600I6AT0;bl_09fMW@20P800[Zj^0:FUY@1mOGd0
=CDe03@d=015ADD0YJFU06a/K01FEUH0:2PX02d];@0g=cL0@T9203hn?P0i>CT0Cdm?0;Jf]P2ATI40
RXZ:04U9B@0g=cL0De=C06=SH`1:BTX0@d=303/k>`0b<S80=CDe09^KV`3Ogml0[jn_0<;2`P3;bl/0
][Jf0=cLg038b<P0MWIf0:RXZ033`l<0d=3@0=gMg@3IfMT0]kNg08n?S`80Vi^K0100RHV906IVIP1:
BTX0NGUi07IfMP1bLW80`L710=_Kf`3IfMT0eMGE0=_Kf`3?cll0W9bL0<W9b@3EeMD0OGem4Oooool0
00oooooo0200M7Ad0:VYZ@1_Kfl0UiNG06m_K`1jNWX0T92@04m?C`1CDe<0VIVI06YZJP2GUiL0OWin
0<;2`P1XJ6P0P82005mOG`2ATI40WinO04Y:BP1=CDd0TI6A092@T01MGEd0IfMW02<S8`1>CTh0OWin
04E5A@1UIFD0SXj>03@d=080ATI603h0C4a<04Y:BP0^;Rh0Bd];02LW9`0X:2P0:BTY01hN7P19BDT0
?clo05iNGP1[Jf/0De=C0451@@0n?Sh0;Bd]05YJFP1?Cdl0:BTY05MGE`0[:b/0CTi>06ATI00[:b/0
6a/K04Q8B01TI6@0EeMG0410@01DE5@0;bl_04a<C01;Bd/0;Rh^03@d=01`L700Hf=S0410@00f=SH0
ATI607]kN`1@D500RXZ:09^KV`1GEeL092@T06=SH`1JFUX0=CDe06i^KP0f=SH05aLG02<S8`1iNGT0
7QhN02XZ:P1SHf<0BDU903@d=02_[jl0JFUY05EEE@80Fe]K0<00>CTi06UYJ@18B4P0GUiN03/k>`1C
De<0?Shn03<c<`1^KVh0BTY:07alO01BDU80?Cdm03/k>`12@T80?Shn04e=C@0^;Rh0HF5Q06EUI@1F
EUH0AdM705ADE01KFe/0HV9R02d];@1LG5`0Hf=S05=CD`1=CDd09BDU07=cL`1RHV80GUiN05eMG@10
@400TY:B09JFUP0a<C40A4A40861P@0_;bl0Kfm_03Ti>@2g]kL0F5QH04=3@`24Q8@0N7Qh05iNGP0`
<300KVi^03/k>`10@400QhN703hn?P0];Bd0OGem07inOP1BDU80Jf][071`L01^KVh0U9BD07AdM01o
Ogl0[Zj^08n?S`1ADE40b/[:0:RXZ01^KVh0Zj^[09VIV@16ATH0K6a/0=;BdP2^[Zh0EUIF08N7Q`1R
HV80FEUI09:BTP23Ph<0EUIF08N7Q`2OWil0C4a<05EEE@25QHD0DU9B06e]K@2<S8`0M7Ad0:b/[01Q
HF40J6QX0:NWY`1kNg/0<C4a07IfMP0^;Rh0Fe]K05IFEP0Z:RX0@41004I6AP1gMgL0FUYJ03<c<`1W
IfL0NGUi02`/;01:BTX0C4a<0<g=c@1RHV80=cLg071`L01LG5`0>3Ph075aL@1^KVh0EEEE08n?S`2N
WYh0HV9R04i>CP1NGUh0ADE504];B`1eMGD0L71`05YJFP1iNGT0G5aL079bLP1@D500H61P06ATI00Y
:BT0De=C05ADE017AdL0Ogmo03Ti>@0Y:BT0IFEU096AT@1LG5`0][Jf0:NWY`1LG5`0>c/k0:f][@2V
YZH0Bd];04A4A01oOgl0;bl_03Ti>@1bLW80QhN7024Q8@0d=3@0SHf=07IfMP0e=CD0DE5A06EUI@1C
De<0H61P07QhN018B4P0DE5A0:f][@0d=3@0Cdm?051@D00R8R80NGUi09>CT`0l?3`0=SHf05EEE@1A
DE40D51@03De=@1FEUH0JFUY06MWI`0];BdLooooo`0607MgM`1RHV80GUiN06=SH`1MGEd0KFe]0P1X
J6P0=01IFET0GUiN06=SH`22PX80KVi^06YZJP1^KVh0PX:2079bLP1VIVH0EUIF04M7A`1<C4`0CDe=
065QH@1kNg/0YJFU0<?3``3Kfm/0cLg=0<W9b@35aLD0/;2`06m_K`1XJ6P0Hf=S04a<C019BDT0Lg=c
09NGU`1ZJVX0Bd];04i>CP1RHV80S8b<08N7Q`1oOgl0_[jn0=[JfP3De=@0`<300=WIf@35aLD0[jn_
09^KV`1jNWX0Kfm_08N7Q`29RHT0OWin03/k>`0U9BD202@T901A03@d=01[Jf/0RHV90410@00f=SH0
FUYJ04U9B@1KFe/0`<3006UYJ@0R8R80@41006a/K01DE5@0AdM703lo?`1gMgL0NGUi05]KF`1oOgl0
Ng]k05eMG@1EEED0D51@05aLG02n_[h0Ng]k06QXJ02UYJD0Zj^[05=CD`0J6QX04a<C018B4P0F5QH0
<C4a07]kN`1EEED0?3`l030`<00[:b/0:2PX02XZ:P0a<C40@T9205mOG`1hN7P0Jf][0:ZZZP2k^k/0
`<3006m_K`1BDU80C4a<04A4A01@D500MGEe0;bl_035aLD0?Shn0410@01^KVh0Ti>C0;Ng]`24Q8@0
=CDe038b<P16ATH0A4A401DE5@0G5aL06ATI01LG5`0F5QH06ATI02LW9`1kNg/0Xj>S0:ZZZP2?Shl0
Q8B40080>CTi0180JFUY04];B`0R8R807alO01`L700P82009BDU03<c<`1KFe/0E5AD02l_;`0`<300
:RXZ024Q8@0a<C40QXJ608>3P`2LW9`209nOW`0408^;R`2c/k<0Zj^[09NGU`80?Cdm00<0GUiN02h^
;P0T92@00P0O7al0;P0N7Qh08R8R04];B`2d];@0FUYJ038b<P2XZ:P0`l?309NGU`2j^[X0^;Rh0<k>
cP21PH40MGEe0:RXZ032`/80Zj^[06e]K@13@d<09bLW028R8P0/;2`0ATI607=cL`2XZ:P0XJ6Q0:FU
Y@2CTi<0MGEe0492@P14A4@0<c<c051@D02CTi<0P8200:RXZ01PH600K6a/061PH01HF5P0=SHf0410
@00J6QX06ATI01XJ6P0H61P201/K6`1201dM7@1IFET0@d=306UYJ@2IVIT0/;2`0::RXP2:RXX0PH61
096AT@2PX:00alO70:BTY01?Cdl0?Cdm03Hf=P1:BTX0MWIf092@T02PX:00Vi^K07MgM`1OGel0X:2P
07inOP1SHf<0Cdm?04Y:BP14A4@0=3@d03Ph>00c<c<0CTi>0=KFeP3Lg=`0TY:B0492@P1;Bd/0YZJV
0:2PX038b<P0d=3@0<_;b`3Fe]H0];Bd07alO025QHD0PH6108B4Q01nOWh0R8R80:6QX@2SXj<0^[Zj
0;fm_@2l_;`0^k^k08^;R`3Bd]80bl_;0<O7a`2l_;`0YJFU0:n_[`27QhL0VIVI4Oooool000oooooo
0<l0Ng]k0:VYZ@1bLW80Z:RX06e]K@1CDe<0IVIV04M7A`1FEUH0NWYj08Z:RP2YZJT0K6a/0;fm_@1j
NWX0V9RH055AD@2UYJD0G5aL0492@P28R8P0P82006MWI`1=CDd0I6AT0410@02@T900Q8B405eMG@1V
IVH0?Shn03Xj>P1bLW80C4a<04Y:BP18B4P0=SHf05YJFP0a<C40=cLg02h^;P13@d<0PH6104I6AP1O
Gel0J6QX055AD@1^KVh0B4Q802/[:`1RHV80IFEU0492@P1nOWh0>c/k03hn?P1JFUX0>CTi03hn?P20
P800Kfm_06EUI@1BDU80FUYJ02<S8`1/K6`0NWYj03Xj>P11@D40HF5Q06][J`1OGel0D51@04i>CP1i
NGT0H61P0:FUY@2VYZH0LW9b02TY:@1/K6`0HV9R05UIF@2LW9`0FEUI01`L700a<C40R8R8020P800N
7Qh0BDU903Ti>@0h>3P0]KFe05QHF01FEUH0>c/k051@D00_;bl0IFEU034a<@1aLG40<30`04U9B@10
@400EEEE09:BTP1KFe/0IFEU055AD@1<C4`0GUiN04A4A01:BTX0AdM7055AD@2>SXh0N7Qh04M7A`14
A4@0@41007moO`20P800:RXZ05YJFP1:BTX0MGEe07moO`0c<c<0LW9b069RHP26QXH0IVIV03/k>`27
QhL0T92@03Ti>@1bLW80WYjN04];B`1ZJVX0=CDe0;Vi^@2FUYH0KFe]075aL@1`L700HF5Q02/[:`2J
VYX0G5aL03lo?`22PX80E5AD05MGE`2][Jd0OWin05YJFP1oOgl0QXJ60:VYZ@2RXZ80MgMg08V9R@2c
/k<0S8b<06ATI02d];@0XJ6Q07moO`2UYJD0[jn_06UYJ@1GEeL0f=SH0:BTY01CDe<0NWYj055AD@0^
;Rh0O7al07moO`1<C4`0SXj>09^KV`14A4@0F5QH08n?S`1DE5@0MGEe03dm?@1QHF40VYZJ07AdM01Y
JFT0YjNW08J6QP0Q8B40QXJ60451@@1JFUX0CDe=02DU9@1LG5`0RHV90<30`01oOgl00P0i>CT0CP1H
F5P0<30`05eMG@14A4@0/k>c05MGE`15ADD0NWYj05aLG00c<c<0LG5a02PX:00^;Rh0LW9b05aLG01K
Fe/0IVIV061PH01SHf<0@410051@D01eMGD0;Rh^06EUI@2LW9`0Shn?06UYJ@1cLg<0K6a/038b<P1W
IfL0?Shn03Ti>@21PH40FUYJ03hn?P1`L700J6QX04e=C@1oOgl0L71`08f=S@1EEED0c<c<08F5Q@1Z
JVX0=3@d06MWI`0T92@0B4Q809fMW@2HV9P08R8R02HV9P1YJFT0EEEE055AD@2UYJD0MgMg04a<C01/
K6`0JFUY03lo?`1NGUh0]KFe03Hf=P1CDe<06a/K02<S8`1jNWX0QhN703Ph>00j>SX0JVYZ03lo?`0R
8R80>CTi07emO@80FUYJ00<0;2`/ooooooooool06_ooool0QP1@D500Bd];04Q8B011@D40<c<c034a
<@0i>CT0BDU907AdM02?Shl0Z:RX0:n_[`2LW9`0Lg=c03dm?@0l?3`0@D5104M7A`1DE5@0L71`09ZJ
VP2g]kL0U9BD08F5Q@2TY:@0bLW90<K6aP1WIfL0Hf=S0<G5a@2JVYX0Kfm_05EEE@1NGUh0H61P06i^
KP2k^k/0a<C409nOW`22PX80^;Rh06i^KP1=CDd0>3Ph055AD@2j^[X0b/[:0=7Ad@2d];@0OWin0:6Q
X@2@T900ZJVY09ZJVP36a/H0Zj^[06][J`0N7Qh05ADE01@D500F5QH05ADE01TI6@1CDe<0MWIf061P
H018B4P0@T9205iNGP1WIfL0YJFU08B4Q01EEED0<S8b01DE5@0V9RH0LW9b05QHF01ADE40gmoO0=_K
f`1nOWh08B4Q01PH600G5aL061PH02XZ:P2^[Zh0ATI60451@@1`L700HV9R05mOG`1DE5@05ADE018B
4P0D51@0;Rh^0<G5a@2d];@0YJFU08F5Q@1nOWh0Ng]k075aL@1kNg/0N7Qh07IfMP1SHf<0Fe]K09nO
W`3Ogml0h^;R0>OWi`3>c/h0NWYj05eMG@1@D500BTY:04e=C@2a/K40@41001DE5@0G5aL09BDU05EE
E@1OGel0DU9B02TY:@10@400EeMG010@400I6AT071`L0P0I6AT0?@1?Cdl0Lg=c08B4Q02^[Zh0Fe]K
06e]K@1_Kfl0Ogmo01lO7`0G5aL0FUYJ07QhN00j>SX092@T01TI6@0R8R80?clo07emO@1SHf<0>CTi
01XJ6P0O7al0820P055AD@1RHV80ZZZZ065QH@0P8200BDU90<30`02LW9`0Ogmo0861P@2>SXh0KVi^
08R8R02>SXh0SHf=06e]K@1:BTX0=CDe02XZ:P1IFET0GEeM075aL@2MWId0hN7Q0=kNgP3AdM40`l?3
09jNWP3Hf=P0aLG50=7Ad@3>c/h0HV9R0410@01@D500;Bd]01dM7@0F5QH00P0E5AD05`0Y:BT0QHF5
05=CD`2XZ:P0W9bL05eMG@0h>3P0RXZ:0820P01LG5`0;Rh^02/[:`1XJ6P0GUiN055AD@1_Kfl0@D51
03<c<`1;Bd/071`L01XJ6P0K6a/06ATI008071`L0P0];Bd0?P0L71`0J6QX09:BTP2?Shl0XZ:R04e=
C@1?Cdl0E5AD08j>SP2j^[X0cLg=0<C4a02SXj<0Z:RX0;bl_02@T900Vi^K0;2`/01BDU80HV9R09:B
TP1RHV80BDU905UIF@1ADE40BTY:04=3@`0m?Cd0=CDe04A4A01UIFD0emOG0:n_[`2RXZ80c/k>0=WI
f@25QHD0R8R80=KFeP34a<@0UiNG0<[:bP0g=cL071`L03/k>`1SHf<0Jf][051@D00n?Sh0SXj>0<?3
``31`L40]KFe0<K6aP1eMGD0V9RH0<_;b`2b/[80Xj>S04i>CP2/[:`0Ti>C0P0o?clAooooo`003ooo
ool0H01cLg<0UYJF05UIF@2f][H0Kfm_05QHF01oOgl0AdM706i^KP1RHV80IFEU0820P01TI6@0Rh^;
04A4A02:RXX0ADE50::RXP1hN7P0>SXj05IFEP23Ph<0IfMW05MGE`1XJ6P09BDU065QH@1iNGT0L71`
08V9R@1dM7@09BDU06=SH`12@T80F5QH04I6AP0`<300DU9B03Xj>P0o?cl09RHV028R8P1=CDd0>SXj
075aL@1RHV80<C4a05YJFP0h>3P0<C4a061PH00/;2`0>3Ph06MWI`0b<S80ATI6055AD@0P82008B4Q
05]KF`1PH600F5QH05iNGP1EEED0:BTY04Q8B014A4@08R8R0492@P1IFET0=CDe04M7A`18B4P0FEUI
06e]K@0h>3P0O7al0:>SX`1XJ6P0<C4a07inOP1aLG40>c/k07UiN@16ATH09RHV05aLG01bLW80<c<c
01hN7P1BDU80@T9203Ti>@2n_[h0IfMW05iNGP80D51@01/0;Bd]065QH@0e=CD0EeMG02HV9P1<C4`0
ATI6038b<P1fMWH0BDU904e=C@1lO7`0BDU904i>CP0l?3`0FUYJ04e=C@0Z:RX0JFUY05]KF`1BDU80
FEUI05IFEP1MGEd0G5aL02d];@1VIVH00P1LG5`0X`1>CTh0:BTY08B4Q015ADD0Ng]k05mOG`1<C4`0
Y:BT06][J`0k>c/0NGUi07inOP13@d<0MWIf0492@P2RXZ80GEeM03lo?`1oOgl0U9BD079bLP12@T80
JVYZ03@d=01>CTh0W9bL03Lg=`10@400OWin05aLG01]KFd0Ph>305UIF@1XJ6P0IFEU06=SH`2@T900
]KFe06][J`17AdL0PX:20820P01/K6`0alO70;Ng]`1HF5P0FEUI0=;BdP1mOGd0=SHf08f=S@1cLg<0
@D5108b<S01UIFD0DE5A09fMW@26QXH0=CDe069RHP2@T900Bd];07moO`1XJ6P0NGUi09:BTP1FEUH0
GEeM0;2`/01/K6`0;Bd]06QXJ00j>SX0FUYJ04a<C00Q8B40;2`/03Ti>@1MGEd0JFUY04M7A`14A4@0
EUIF02<S8`0l?3`0@D510;:b/P1oOgl0BDU908j>SP1OGel0EUIF08Z:RP1ZJVX0Jf][08R8R01SHf<0
=CDe06YZJP22PX80DU9B04E5A@1NGUh0JFUY06ATI01RHV80GemO06IVIP1cLg<0Ogmo05UIF@15ADD0
WYjN06e]K@16ATH0EeMG04e=C@10@400VIVI07moO`1dM7@0MgMg05QHF01RHV80Hf=S0=SHf02a/K40
Kfm_03`l?01/K6`08b<S034a<@1fMWH0Ng]k01dM7@1EEED0^;Rh07QhN00c<c<0DE5A03dm?@0R8R80
Shn?07UiN@0S8b<0@41009fMW@0U9BD0NGUi05IFEP0O7al0KFe]07]kN`0U9BD0DU9B0;Zj^P1kNg/0
>c/k03Hf=P23Ph<0H61P05IFEP0];Bd07?ooool01@1@D500AdM703/k>`0^;Rh09RHV00<08B4Q0480
:2PX05aLG03<c<`0/K6a0<C4a02XZ:P0EeMG08:2PP24Q8@0LW9b06MWI`1EEED0Bd];05aLG02a/K40
gMgM09RHV02EUID0VYZJ04E5A@21PH40PX:208b<S01aLG40=SHf02<S8`0/;2`0@D5108B4Q02VYZH0
HF5Q03/k>`1QHF40M7Ad02LW9`0Z:RX0ZZZZ09bLW01<C4`0@41006MWI`2ZZZX0_kno0;>c/`2g]kL0
YjNW09jNWP2^[Zh0Xj>S07AdM01ADE40;2`/01`L700I6AT06QXJ04a<C01jNWX0@D5101hN7P0K6a/0
@41004Y:BP2DU9@0MWIf069RHP0G5aL201DE5@0I02XZ:P28R8P0[jn_0=OGe`2e]KD0?clo01PH600G
5aL05QHF01hN7P14A4@0T92@02/[:`0W9bL0J6QX05EEE@0f=SH0Hf=S03`l?00R8R80GEeM071`L00e
=CD0820P024Q8@0202HV9P0e02d];@0j>SX0Lg=c07=cL`25QHD0^;Rh0;jn_P3Jf]X0aLG50=oOg`3S
hn<0Ng]k02DU9@0I6AT05aLG01<C4`0A4A409bLW06e]K@0Q8B4061PH01LG5`0m?Cd0H61P055AD@0m
?Cd0<C4a06QXJ00L71`0820P02LW9`13@d<0G5aL04a<C010@400UYJF09ZJVP1IFET0EeMG06YZJP1f
MWH0IfMW02@T900N7Qh0Cdm?0820P017AdL0?clo04e=C@12@T80@D51055AD@1eMGD00P0W9bL02@13
@d<0Hf=S05YJFP21PH40FUYJ0492@P0W9bL0RXZ:0<W9b@020:b/[00K096AT@1LG5`0:2PX02PX:013
@d<0PH6109>CT`1TI6@0GemO08F5Q@2][Jd0_Kfm0=7Ad@1cLg<0De=C0;Bd]02h^;P0aLG50>7Qh@3N
g]h0gMgM05aLG00U9BD08R8R03Ti>@14A4@061PH00805aLG01H061PH02HV9P1iNGT0QhN7061PH02G
UiL0ZZZZ02HV9P0T92@0?Cdm03/k>`0X:2P0<C4a051@D01IFET0E5AD06EUI@0c<c<0>CTi0451@@0I
6AT071`L0P0J6QX0;P0L71`07alO04e=C@0O7al09BDU07inOP1JFUX0T92@09FEU@10@400ADE505=C
D`28R8P0SXj>07moO`2>SXh0a<C40=CDe02WYjL0/[:b0;Bd]01`L700MgMg092@T01kNg/08R8R02TY
:@0];Bd0ADE5055AD@17AdL0Bd];04Y:BP1;Bd/0TY:B0:6QX@1DE5@0=CDe06YZJP2`/;00Xj>S08j>
SP2o_kl0QhN708>3P`2EUID201LG5`8061PH018092@T04a<C024Q8@0KVi^075aL@2?Shl0_[jn0;Rh
^02/[:`0emOG09>CT`36a/H0GemO04m?C`2=SHd0Ti>C04E5A@0^;RhAooooo`003oooool0H01[Jf/0
XJ6Q05=CD`1lO7`0Jf][05QHF00n?Sh0GUiN08J6QP1kNg/0Kfm_04i>CP1]KFd0WYjN05QHF01;Bd/0
A4A409RHV01bLW80>SXj06][J`13@d<0<30`06QXJ01_Kfl0:2PX065QH@0Y:BT0AdM706e]K@1KFe/0
92@T07=cL`0i>CT0N7Qh06ATI017AdL0@T9204=3@`1>CTh0=3@d02XZ:P1ADE407alO06a/K01kNg/0
@41006=SH`0I6AT0ADE508b<S01]KFd0<c<c05QHF00[:b/0NGUi0820P00b<S8092@T05QHF00g=cL0
5aLG079bLP1mOGd0=3@d04m?C`13@d<05ADE05mOG`29RHT0I6AT055AD@0[:b/0EEEE08N7Q`1PH600
W9bL0;Jf]P0];Bd0;Rh^05mOG`26QXH0@41007EeM@0@41004Q8B05ADE01VIVH0?clo024Q8@1JFUX0
>3Ph020P802GUiL0SXj>05mOG`80De=C0<00;Rh^096AT@1GEeL0A4A402XZ:P1_Kfl0Lg=c03/k>`1j
NWX051@D03Hf=P1fMWH0M7Ad04Q8B00H61P0IfMW07QhN00f=SH0L71`01@D500d=3@0EUIF061PH01N
GUh0>SXj02<S8`1kNg/0NWYj05MGE`17AdL07alO092@T01XJ6P0G5aL024Q8@1FEUH0^k^k0:>SX`11
@D40SHf=06MWI`0O7al0K6a/04m?C`2UYJD0G5aL028R8P1GEeL0Bd];05=CD`0f=SH0NWYj01`L700g
=cL0RXZ:05MGE`19BDT0OGem01/K6`13@d<0UIFE08J6QP1ZJVX0<c<c01hN7P11@D40Vi^K09NGU`1D
E5@0QhN707alO010@400QhN707alO01;Bd/0RHV90=_Kf`2KVi/0BDU9051@D01FEUH0@T9209ZJVP19
BDT0FUYJ0:f][@26QXH0BDU904E5A@27QhL0Cdm?08R8R01dM7@0VYZJ09VIV@1<C4`0K6a/0<C4a01`
L700=3@d06=SH`11@D40RXZ:05QHF00_;bl0@410038b<P1SHf<0IFEU04Y:BP1<C4`0K6a/03<c<`18
B4P09RHV07UiN@1VIVH0@T9206m_K`11@D40>CTi07QhN01SHf<0GUiN06m_K`1NGUh0C4a<059BDP1P
H600A4A405YJFP2:RXX0GUiN06i^KP1UIFD0HV9R05=CD`1ADE40S8b<04e=C@0S8b<0EEEE04Y:BP1/
K6`0Ph>302XZ:P0J6QX0O7al06a/K02<S8`0_;bl08Z:RP0o?cl0GEeM0:^[Z`1JFUX0@T9205QHF02C
Ti<0CTi>0451@@23Ph<0MWIf01<C4`0o?cl0VYZJ07YjNP0g=cL0EEEE0492@P0L71`0GemO08:2PP10
@400BTY:09FEU@0E5AD0J6QX059BDP0I6AT0O7al06MWI`0@4100<C4a06MWI`1[Jf/0L71`03Ph>01D
E5@0=SHf01XJ6P0h>3PLooooo`1g04a<C00m?Cd0=CDe03<c<`0[:b/09RHV020P800M7Ad06a/K03hn
?P3=cLd0BTY:07UiN@2j^[X0`/;204Q8B012@T80EEEE06EUI@2<S8`0b/[:0<C4a02@T900Z:RX07in
OP2KVi/0_Kfm08Z:RP0g=cL05aLG02LW9`16ATH0LG5a02DU9@0L71`06ATI02TY:@1oOgl0V9RH03Ti
>@0_;bl0KFe]02d];@1jNWX0Shn?075aL@0f=SH0=cLg03Xj>P1oOgl0JVYZ08j>SP2f][H0];Bd092@
T028R8P0AdM703Hf=P1HF5P0MGEe06m_K`1GEeL0;bl_03Xj>P2<S8`0:RXZ01dM7@0K6a/0;2`/04];
B`2FUYH0MWIf02`/;00W9bL05ADE01LG5`0Y:BT0`L710<S8b02@T900Z:RX03Ti>@0E5AD06QXJ02h^
;P1GEeL0/[:b0<S8b01RHV80=3@d06YZJP1YJFT0>c/k05UIF@2d];@0XJ6Q04i>CP0M7Ad05QHF01DE
5@0C4a<05ADE01/K6`0J6QX05aLG01/K6`0o?cl0?Cdm04M7A`1<C4`0YjNW0;Bd]02m_Kd0c/k>0;Rh
^00];Bd06ATI01DE5@0J6QX00P0E5AD0H@1UIFD0DU9B01/K6`0E5AD0:2PX05EEE@17AdL0DE5A034a
<@1oOgl0MgMg05eMG@1IFET0@41002h^;P1?Cdl0EEEE0=;BdP2=SHd0IVIV04Y:BP2/[:`0UYJF0:j^
[P1_Kfl0?Cdm02`/;01<C4`0Rh^;03/k>`0Q8B406a/K02LW9`0i>CT0MWIf08J6QP1RHV80JVYZ05AD
E015ADD06QXJ01PH601FEUH0CDe=08R8R01iNGT0JFUY08j>SP2=SHd0KFe]075aL@0h>3P092@T03/k
>`2GUiL0N7Qh06ATI02WYjL0a/K60<O7a`1aLG40=3@d05iNGP2GUiL0H61P04a<C02o_kl0cLg=0<k>
cP1>CTh0=SHf02d];@0O7al0C4a<01LG5`0I6AT0820P02XZ:P0m?Cd0O7al0:BTY00i>CT0O7al0:ZZ
ZP17AdL0@D5103<c<`0j>SX0:2PX03`l?01?Cdl0IFEU06YZJP1ADE40<c<c030`<010@4000P0O7al2
01`L701401dM7@0g=cL0EUIF02d];@0k>c/0T92@04a<C01MGEd0MgMg04a<C01:BTX0CTi>05aLG02_
[jl0R8R80=7Ad@3Jf]X0a<C40<K6aP3Jf]X0^;Rh0:JVYP2WYjL0W9bL055AD@0L71`08R8R02PX:00W
9bL0<C4a05YJFP12@T80AdM7055AD@2g]kL0LW9b05mOG`0l?3`0D51@09JFUP3;bl/0U9BD0=?Cd`31
`L40`l?307emO@0E5AD05aLG01PH600F5QH061PH01`L701EEED0<30`02LW9`0g=cL0IfMW061PH022
PX80[Zj^04Y:BP26QXH0=cLg05EEE@2KVi/0PH6106e]K@1JFUXAooooo`003oooool0h01aLG40/K6a
05aLG02UYJD0M7Ad09>CT`1cLg<0?Shn065QH@1oOgl0N7Qh06e]K@1ADE40WinO065QH@1oOgl0?Cdm
09NGU`2>SXh0@T9206i^KP25QHD0HV9R05ADE01VIVH0;Rh^08F5Q@1eMGD0FUYJ06YZJP1`L7009BDU
0861P@1?Cdl0BDU905EEE@0h>3P0Bd];03Ti>@0m?Cd0;Rh^02HV9P16ATH0;Rh^0492@P1nOWh0@d=3
06m_K`0c<c<0;Rh^05aLG01IFET0>3Ph05]KF`0L71`0?clo05QHF00U9BD092@T05EEE@0m?Cd0<30`
069RHP1MGEd09bLW04a<C00h>3P06ATI038b<P1KFe/0C4a<04Y:BP0];Bd0@d=307YjNP1SHf<0XJ6Q
09^KV`1@D50092@T04e=C@1VIVH0?Shn09BDU012@T806a/K06YZJP1EEED0:BTY01dM7@1LG5`0CTi>
04A4A02JVYX0JVYZ059BDP1@D500FEUI030`<01/K6`0A4A405]KF`0Y:BT0ADE5055AD@0d=3@0NWYj
04i>CP1DE5@0Fe]K065QH@1@D500:b/[05QHF01JFUX0>CTi07IfMP1RHV80<S8b04A4A01KFe/0JFUY
06=SH`0_;bl0HF5Q06EUI@1CDe<0AdM702TY:@2:RXX0HF5Q055AD@0g=cL0A4A40:JVYP1hN7P0:b/[
07QhN01NGUh0<C4a05QHF00g=cL0YjNW06m_K`1QHF40Ogmo05MGE`13@d<0>CTi08Z:RP14A4@0>c/k
08F5Q@10@400Cdm?09NGU`1QHF40B4Q808b<S024Q8@0NWYj08N7Q`1TI6@0F5QH0;>c/`2<S8`0HV9R
08j>SP2=SHd0NWYj0:>SX`1oOgl08b<S06MWI`3;bl/0SXj>04U9B@1MGEd0JVYZ04i>CP2RXZ80Lg=c
04A4A01]KFd0Rh^;04E5A@11@D40EUIF04a<C02<S8`0Kfm_0:BTY02=SHd0>c/k05=CD`2OWil0IFEU
034a<@1aLG409RHV055AD@1UIFD0@T9203hn?P0j>SX0KFe]071`L00V9RH0HV9R08F5Q@17AdL0JVYZ
030`<01GEeL0FEUI04E5A@21PH40HV9R03hn?P26QXH0LW9b07MgM`2ATI40FUYJ0P1FEUH0601YJFT0
<c<c0410@01LG5`0Lg=c06IVIP21PH40V9RH04=3@`0Y:BT0M7Ad05aLG00f=SH0Lg=c02@T900^;Rh0
CDe=04M7A`0/;2`0RHV904I6AP19BDT0D51@06QXJ080Ng]k02H0ZZZZ05QHF015ADD0<C4a06m_K`1L
G5`0DE5A09:BTP2YZJT0820P03`l?02/[:`0MgMg05iNGP2KVi/0NWYj03lo?`1NGUh0Ng]k03dm?@1I
FET0YjNW03dm?@1[Jf/0@41001lO7`24Q8@0QhN703Xj>P0a<C40M7Ad04a<C00g=cL0EeMG0:2PX01<
C4`0<C4a02HV9Qcooooo01D0ATI60410@00e=CD0=SHf034a<@0Y:BT0820P01lO7`0/;2`0V9RH0=;B
dP28R8P0QHF507moO`1nOWh06a/K01DE5@0D51@05aLG04m?C`2k^k/00P2_[jl01`2PX:00^k^k08B4
Q01mOGd0JFUY01DE5@0A4A400P0C4a<06P0U9BD0@d=303Ph>00[:b/06a/K0492@P1eMGD0QhN703<c
<`1mOGd0F5QH08f=S@1hN7P0:2PX01`L700M7Ad07alO04Y:BP1XJ6P0Kfm_07]kN`2NWYh0_;bl0<S8
b02PX:00Cdm?0P0n?Sh0501ADE40IVIV05]KF`24Q8@0[jn_06e]K@1JFUX0?Cdm04A4A02QXJ40_[jn
0820P00G5aL0@D5102TY:@0M7Ad0Q8B409fMW@1iNGT0Rh^;0P2DU9@0K@0m?Cd0ADE506e]K@1aLG40
>c/k05EEE@2SXj<0N7Qh06YZJP1eMGD0=SHf055AD@3>c/h0IVIV01hN7P0I6AT05ADE02/[:`0F5QH0
5aLG01DE5@0F5QH05aLG01dM7@0];Bd0C4a<06IVIP2=SHd0_;bl0=7Ad@38b<P0Z:RX0=3@d02VYZH0
J6QX04Q8B00];Bd061PH01DE5@0];Bd0Ph>303De=@0G5aL06a/K06ATI011@D40C4a<05]KF`2EUID0
De=C04Q8B015ADD0CDe=06EUI@26QXH0W9bL0>3Ph030`<00Xj>S05UIF@2TY:@0b<S808Z:RP1`L700
IFEU08F5Q@2FUYH0UiNG07inOP1EEED0F5QH05=CD`1KFe/0LW9b0<g=c@2e]KD0GEeM03Ti>@0O7al0
4Q8B01@D500G5aL0F5QH08Z:RP1GEeL0H61P08Z:RP1iNGT0Shn?06][J`1dM7@0DU9B03De=@2VYZH0
TI6A06i^KP2`/;00`L71069RHP1SHf<0Ogmo08>3P`1>CTh09BDU02<S8`1JFUX0][Jf08b<S01[Jf/0
0P0g=cL06`0P8200BTY:03Hf=P0Z:RX0@41004e=C@0m?Cd0>CTi09BDU01KFe/0GEeM0:JVYP1fMWH0
M7Ad06IVIP1:BTX0>CTi05UIF@1TI6@0M7Ad07emO@12@T80?3`l03Ti>@1>CTh08B4Q028R8P0201lO
7`0_028R8P1:BTX0<C4a02XZ:P1NGUh0Shn?04i>CP1@D500<C4a01dM7@0_;bl0A4A405iNGP2>SXh0
[Jf]09:BTP3EeMD0_[jn0<O7a`32`/80YJFU0<O7a`3>c/h0[Jf]02XZ:P0N7Qh08B4Q02PX:00c<c<0
:b/[03Lg=`1OGel0C4a<08N7Q`2QXJ40/K6a04a<C017AdL0DE5A092@T033`l<0bLW909fMW@2l_;`0
fm_K07UiN@0G5aL00P0I6AT04`0N7Qh09bLW03Ph>01JFUX0;2`/02TY:@0d=3@0H61P05QHF01kNg/0
HV9R03/k>`1OGel0:2PX02h^;P27QhL0ATI604A4A01KFe/04Oooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`003oooool0]02[Zj/0GUiN05iNGP1k
Ng/0X:2P06i^KP0i>CT0G5aL07inOP26QXH0]kNg04I6AP0`<300DU9B06QXJ02a/K40KVi^02/[:`1>
CTh0Ph>305YJFP2VYZH0c<c<04i>CP18B4P0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1]
KFd0?Cdm03De=@1WIfL0Ph>305EEE@1/K6`0Ogmo01TI6@19BDT0IFEU0451@@1SHf<0Lg=c02@T901@
D500JFUY065QH@0k>c/0OWin059BDP1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT03/k>`1Z
JVX0=CDe059BDP1VIVH0Q8B403Ph>00l?3`0DU9B04=3@`1QHF40YZJV03<c<`0o?cl0Ng]k0492@P0^
;Rh0MGEe0;no_`13@d<0?3`l04e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0PX:206ATI00[
:b/0EUIF05MGE`1dM7@0JFUY09VIV@0o?cl0=CDe05aLG01TI6@0[jn_05EEE@0W9bL0De=C06e]K@1E
EED0K6a/0:BTY00`<300ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>CP1OGel0Z:RX0<?3``0i
>CT0@d=305]KF`1ZJVX0EeMG0:^[Z`1oOgl0@T9206YZJP1eMGD0I6AT0<g=c@1FEUH0ADE5065QH@2V
YZH0NWYj0:j^[P1TI6@0>SXj07UiN@1lO7`0J6QX0:2PX037alL0;bl_05iNGP2LW9`0UiNG0:FUY@2A
TI40;Bd]05iNGP1aLG40`L7108B4Q01nOWh0@T9207MgM`2>SXh0Vi^K05aLG02ATI40<S8b04Y:BP1V
IVH0QXJ605aLG02e]KD0E5AD051@D01eMGD0X:2P055AD@1mOGd0JFUY05QHF080HF5Q06`0<C4a07Mg
M`18B4P0Cdm?05ADE01dM7@0?Shn05=CD`0f=SH0Cdm?079bLP1hN7P0BDU907MgM`1JFUX0BTY:09nO
W`19BDT0ADE506=SH`0o?cl0OWin0<?3``1/K6`0@d=305mOG`1ZJVX0^k^k09>CT`0k>c/0N7Qh06MW
I`28R8P0/[:b0;bl_01GEeL0QXJ6055AD@2RXZ80LW9b02XZ:P1GEeL0Jf][05ADE01RHV80PH61034a
<@1lO7`0RXZ:05ADE02b/[80]KFe04U9B@1:BTX0Ph>307IfMP39bLT0K6a/0492@P1@D500N7Qh07Ad
M01aLG40Z:RX04E5A@1BDU80HF5Q079bLP2ZZZX0SXj>034a<@0k>c/0CDe=06e]K@2_[jl0JFUY034a
<@15ADD0LW9b0820P02FUYH0e]KF06YZJP0m?Cd0NWYj07AdM01QHF40`/;204M7A`0n?Sh0JVYZ06m_
K`1VIVH0^KVi04m?C`0Z:RX0KFe]0:FUY@1gMgL0VIVI0=?Cd`1IFET071`L07inOP1BDU80DE5A0;Jf
]P1SHf<Looooo`0;04U9B@1TI6@0Ti>C0:VYZ@2TY:@0Bd];06UYJ@1OGel0EEEE07IfMP1ADE400P1C
De<0B@1KFe/0LG5a075aL@1/K6`0_;bl0:6QX@21PH40IVIV05UIF@0`<300B4Q80451@@0h>3P0EUIF
02/[:`1?Cdl0>3Ph05IFEP1OGel0GUiN03Ti>@14A4@0?clo05MGE`1FEUH0B4Q803dm?@1=CDd0@410
03Ti>@0m?Cd0De=C04m?C`0o?cl0EUIF051@D01[Jf/0Cdm?03<c<`0];Bd0B4Q8051@D01=CDd0D51@
0451@@1GEeL0Ti>C04m?C`1=CDd0Bd];055AD@1HF5P0<30`04Y:BP1>CTh0NGUi05QHF01UIFD0UiNG
04Q8B01PH600EEEE06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`1HF5P0QHF508B4Q027QhL00P1A
DE40201=CDd0LG5a071`L01_Kfl0CDe=061PH01jNWX0IFEU0P1dM7@0W`23Ph<0MgMg059BDP1SHf<0
NWYj08B4Q01YJFT0Ng]k07EeM@2:RXX0J6QX09^KV`1XJ6P0QXJ60:2PX01kNg/0Y:BT071`L01jNWX0
Xj>S06ATI02=SHd0Rh^;0:n_[`1GEeL0MWIf05mOG`1SHf<0G5aL06YZJP1RHV80PH6106i^KP1dM7@0
Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@11@D40Bd];05aLG01<C4`0?clo05mOG`16ATH0
@T9205ADE01[Jf/0Cdm?04Y:BP18B4P0KVi^07MgM`0o?cl0HV9R04i>CP1JFUX0CTi>065QH@1RHV80
GEeM061PH00O7al0IfMW06ATI01SHf<0LW9b04Q8B01?Cdl0OWin079bLP28R8P0[:b/02<S8`0[:b/0
BDU905]KF`1YJFT0A4A405iNGP1BDU80C4a<04U9B@1?Cdl0HV9R02XZ:P1VIVH0F5QH06IVIP0a<C40
ATI605MGE`0g=cL0Cdm?069RHP1CDe<0MgMg0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0
KFe]08:2PP16ATH0YJFU08R8R010@400Kfm_06=SH`1JFUX0Q8B405YJFP1LG5`0D51@065QH@1ZJVX0
EEEE06QXJ016ATH0OGem04M7A`1FEUH0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/02:RXX0
LG5a08n?S`2QXJ40KFe]09ZJVP1TI6@0LG5a07UiN@1jNWX0Rh^;05ADE01QHF40MgMg07IfMP1lO7`0
OGem08j>SP1MGEd0LG5a0861P@0208B4Q00O059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007=cL`1YJFT0
YjNW09jNWP0/;2`0IfMW079bLP0c<c<0Z:RX0:>SX`1=CDd0ADE5065QH@27QhL0RHV909nOW`23Ph<0
N7Qh08B4Q01FEUH0L71`0:FUY@2=SHd0[Zj^0:n_[`0Aooooo`003oooool0<P1kNg/0PX:207IfMP1O
Gel0JFUY0820P019BDT0MWIf03hn?P15ADD0HF5Q071`L01UIFD0MWIf02PX:02@T900X:2P04A4A01C
De<0BDU901hN7P0l?3`0UIFE06QXJ010@400=cLg05UIF@1YJFT0RXZ:055AD@0g=cL0P82004];B`23
Ph<0IFEU02LW9`12@T80Kfm_038b<P1jNWX0^KVi02d];@0S8b<0PX:205EEE@2?Shl0/[:b02/[:`0_
;bl0MGEe0P1RHV80kP3@d=00Cdm?03dm?@1oOgl0DE5A071`L029RHT0:b/[03hn?P1PH600G5aL0;6a
/@0_;bl0=3@d069RHP1XJ6P0Cdm?07YjNP21PH408B4Q04E5A@25QHD0O7al0820P02h^;P092@T03hn
?P1=CDd0MWIf08B4Q02BTY80<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`13@d<0FEUI051@
D02j^[X0Ph>3028R8P1DE5@0MWIf079bLP1NGUh0I6AT03Xj>P1iNGT0Shn?04];B`1DE5@0FUYJ02PX
:00o?cl0LG5a08F5Q@1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03Xj>P1FEUH0XZ:R07Yj
NP1NGUh0QhN70410@00n?Sh0Rh^;0:JVYP1HF5P0L71`04];B`15ADD0ZJVY0=3@d01=CDd0IfMW06][
J`12@T80IfMW0:j^[P0j>SX0Rh^;05ADE00i>CT0@d=309FEU@1eMGD0Cdm?034a<@1ADE40HV9R09ZJ
VP1QHF40De=C05YJFP0`<300N7Qh08n?S`0k>c/0F5QH08f=S@12@T80H61P0<_;b`2?Shl0<C4a06AT
I01`L700M7Ad0=cLg01WIfL0>SXj06a/K01hN7P0K6a/0<K6aP2?Shl0=CDe07AdM01]KFd0EUIF0<[:
bP2XZ:P0<30`06IVIP1^KVh0OGem0<k>cP13@d<0AdM706a/K02@T900S8b<0<o?c`2NWYh09bLW07Mg
M`1YJFT0];Bd0;Ng]`0a<C40=SHf08f=S@2m_Kd0YZJV08V9R@0c<c<0CDe=0;^k^`24Q8@0_[jn05iN
GP0e=CD0K6a/0:FUY@2DU9@0J6QX04A4A01MGEd0Ogmo04];B`2_[jl0XJ6Q0410@017AdL0RXZ:06][
J`1eMGD0:b/[0492@P1VIVH0V9RH08R8R033`l<0Rh^;04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn
?P1?Cdl0OGem08B4Q02^[Zh0<S8b05ADE01HF5P0Vi^K06a/K021PH40`L7103/k>`20P800];Bd06AT
I02JVYX0Xj>S04e=C@1ADE40WinO0:^[Z`1NGUh0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451
@@1ADE40M7Ad0861P@0g=cL0DE5A04m?C`0a<C40CDe=09RHV02/[:`0D51@05UIF@0m?Cd0Jf][071`
L01MGEdLooooo`0m04i>CP1GEeL0bl_;0=7Ad@30`<00E5AD07EeM@28R8P0Jf][07IfMP1OGel0MGEe
07AdM01TI6@0LG5a07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A05]KF`17AdL0Hf=S
04Y:BP1RHV80C4a<06QXJ01/K6`0Ogmo04=3@`1XJ6P0>3Ph05mOG`1GEeL0IfMW03Hf=P1[Jf/0Bd];
034a<@1BDU80IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_;bl0I6AT02XZ:P1=CDd0NWYj
07IfMP1PH600De=C04I6AP02051@D02=059BDP1NGUh0BDU904=3@`1RHV80H61P07AdM02ATI40]kNg
05YJFP2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19BDT0]KFe0:ZZZP1oOgl0/[:b0;2`/02RXZ80JVYZ
07=cL`1LG5`0RHV908B4Q01?Cdl0=3@d05]KF`1RHV80@41003lo?`1TI6@0J6QX04m?C`0`<300De=C
04=3@`1ADE40CTi>05iNGP17AdL0De=C051@D01VIVH0?Cdm06i^KP1PH600De=C05EEE@0o?cl0M7Ad
07inOP1aLG40X:2P07QhN02QXJ40Shn?0:2PX01dM7@0R8R808^;R`23Ph<0De=C06m_K`1FEUH0Kfm_
09ZJVP2e]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0W9bL06MWI`1JFUX0LG5a04Q8B01/K6`0DU9B
05EEE@1ADE40B4Q804e=C@15ADD0>c/k06MWI`2>SXh0;Rh^05YJFP1<C4`0HV9R04=3@`1@D50051@D
06][J`1bLW808B4Q08:2PP1oOgl0@T9205YJFP1DE5@0=cLg055AD@1>CTh0Bd];06MWI`0O7al0>SXj
06m_K`1KFe/0N7Qh06EUI@22PX80HF5Q05MGE`1PH600?Shn05IFEP0b<S80TI6A05EEE@1_Kfl0F5QH
05mOG`25QHD0DE5A069RHP1_Kfl0LW9b071`L02?Shl0RXZ:04e=C@1bLW80LG5a0080MWIf02/0AdM7
07EeM@2^[Zh0B4Q80:n_[`1WIfL0<C4a07=cL`1UIFD0ADE504i>CP14A4@0EeMG05iNGP1RHV80IFEU
06QXJ01eMGD0G5aL07YjNP1LG5`0IVIV06UYJ@1>CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0][Jf
079bLP2<S8`0[jn_096AT@2NWYh0FUYJ07QhN01eMGD0/[:b09:BTP1RHV80RHV90080[jn_02L0IFEU
04I6AP1OGel0De=C07QhN02>SXh0EeMG07AdM01SHf<0ZZZZ05aLG02;Rh/0Ogmo09JFUP2ZZZX0LW9b
05=CD`1cLg<0>3Ph0:j^[P2FUYH0A4A40;jn_P2m_Kd0J6QX04E5A@12@T80JFUY07inOP2;Rh/0GEeM
07emO@1OGel0ADE506ATI02HV9P0K6a/08Z:RP2[Zj/04Oooool000oooooo00h0MWIf079bLP2PX:00
NGUi04a<C01oOgl0Rh^;0861P@14A4@0;2`/04e=C@1UIFD0N7Qh0:BTY080;Rh^01h0Lg=c07alO01d
M7@0D51@01/K6`0X:2P0De=C07EeM@2OWil0Cdm?03hn?P1ZJVX0O7al07inOP2OWil0][Jf03Ti>@1@
D500XJ6Q059BDP2UYJD0GemO02d];@0l?3`0LW9b07UiN@1FEUH0P820024Q8@1=CDd207EeM@0U06a/
K027QhL0=CDe024Q8@1HF5P0MWIf06QXJ014A4@071`L02l_;`1_Kfl0Hf=S04M7A`1PH6008B4Q05=C
D`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q803lo?`1>CTh0ADE505IFEP2DU9@0>SXj02d]
;@1[Jf/0DU9B03De=@1cLg<0FEUI02/[:`0205IFEP1206a/K027QhL0XZ:R05MGE`1KFe/0>SXj05MG
E`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700P82002/[:`1mOGd0Ng]k05EEE@22PX80YZJV03<c
<`0e=CD0GUiN06e]K@2DU9@0MGEe02TY:@19BDT0@T9208B4Q01iNGT0_kno0451@@17AdL0N7Qh06AT
I01mOGd0^;Rh05YJFP0N7Qh0FUYJ09jNWP1cLg<0UiNG03Hf=P0[:b/0Kfm_0;Jf]P1kNg/0R8R808b<
S00`<300FUYJ09>CT`1]KFd0Z:RX06m_K`0e=CD0KFe]08B4Q01YJFT0YjNW02d];@0j>SX0IfMW0P1[
Jf/0Q`2@T900XJ6Q02/[:`1BDU80R8R808>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<30
06IVIP1=CDd0WIfM0=gMg@1cLg<0WIfM0451@@1OGel0MWIf0<G5a@1VIVH0TI6A04=3@`1^KVh0GUiN
09FEU@1ZJVX0OGem08>3P`14A4@0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`L700Ti>C
03Ph>01>CTh0W9bL06e]K@1NGUh0Ogmo03Hf=P1RHV80TY:B04i>CP1jNWX0?clo06ATI03=cLd0WinO
04i>CP2BTY80GUiN07]kN`31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o_kl0Cdm?03dm?@1IFET0QhN7
0<O7a`1aLG40>3Ph09>CT`1RHV80=3@d075aL@2^[Zh0K6a/071`L01VIVH0FEUI08B4Q02i^KT0I6AT
065QH@1lO7`0GUiN0=;BdP1WIfL0ADE506YZJP1^KVh0GemO08b<S03@d=00FUYJ05mOG`1iNGT0M7Ad
09BDU03Bd]80GUiN03Ti>@1gMgL0U9BD0:NWY`1YJFT0:BTY04U9B@1aLG40XJ6Q06MWI`35aLD0LW9b
0410@01RHV80Zj^[06e]K@2UYJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0QXJ601/K6`0];Bd0BDU9
05=CD`0Looooo`1O051@D01MGEd0Q8B406e]K@28R8P0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad
061PH01GEeL0PH6107IfMP1WIfL0IVIV079bLP1nOWh0GUiN04U9B@0h>3P0HV9R04M7A`0i>CT0K6a/
055AD@0g=cL0;Rh^06a/K02>SXh0E5AD04=3@`2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];
03Ti>@1?Cdl0Lg=c04m?C`1<C4`0IVIV04=3@`1iNGT0J6QX07QhN00Y:BT0TY:B04Y:BP1^KVh0UiNG
07alO02LW9`0FUYJ075aL@26QXH0JFUY04i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02JVYX0Zj^[
03dm?@27QhL0`l?307]kN`1<C4`0Bd];051@D01YJFT0YJFU07EeM@1ADE40OGem0;Rh^01iNGT0?clo
05MGE`1CDe<0Cdm?059BDP1;Bd/0>SXj04M7A`1EEED00P1FEUH0=01fMWH0IFEU05iNGP0h>3P0G5aL
051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE092@T02UYJD0EEEE07YjNP11@D40LW9b
07alO017AdL0K6a/07QhN01`L700Cdm?06QXJ01MGEd0Bd];0410@01KFe/0D51@09:BTP1SHf<0MWIf
07QhN02i^KT0>3Ph079bLP29RHT0>CTi069RHP2@T900Hf=S05QHF01?Cdl0Kfm_07alO01eMGD0F5QH
08j>SP1NGUh206i^KP1`05UIF@11@D40MWIf0::RXP11@D40JFUY05=CD`1GEeL0EEEE06a/K00i>CT0
IVIV06i^KP1EEED0bLW90<;2`P1RHV80G5aL05QHF00R8R80JFUY06a/K01LG5`0T92@01XJ6P0S8b<0
?Cdm04M7A`1QHF40@41008j>SP1lO7`0@T9204Y:BP1HF5P0Kfm_01dM7@1EEED0N7Qh0:BTY016ATH0
@D51051@D00d=3@0PH61096AT@1PH600JVYZ06][J`1cLg<0FUYJ04Y:BP1@D500IVIV06m_K`1EEED0
HV9R08F5Q@1dM7@0bLW90861P@1<C4`0SHf=06m_K`0o?cl0Fe]K05ADE01_Kfl0DU9B05IFEP24Q8@0
IFEU06i^KP1PH600UIFE05UIF@1WIfL0LG5a05]KF`1QHF40IFEU08f=S@1oOgl0BTY:06a/K025QHD0
Shn?09jNWP2[Zj/0FUYJ07IfMP0e=CD0IVIV06YZJP1_Kfl0Ph>308n?S`2DU9@0FUYJ06i^KP1<C4`0
R8R808j>SP0n?Sh0NWYj0861P@2DU9@0T92@08^;R`2MWId0[Jf]0:b/[080KFe]01T0SXj>08:2PP1S
Hf<0IfMW05EEE@1fMWH0Lg=c04Q8B02a/K40Shn?05YJFP1TI6@0@T9206m_K`1[Jf/0QXJ606a/K02S
Xj<0Shn?04M7A`2<S8`0^[Zj07MgM`2QXJ40b<S8017ooooo000?ooooo`3o0:VYZ@1QHF40SHf=0:f]
[@1oOgl0NGUi03`l?02PX:00/k>c07inOP1`L7008B4Q05EEE@1UIFD0GemO07alO016ATH0@d=306m_
K`2LW9`0@41008:2PP24Q8@0;Bd]06][J`2][Jd0>3Ph069RHP1]KFd0BTY:07MgM`2j^[X0TI6A04e=
C@1FEUH0=3@d07alO025QHD0:BTY02h^;P1EEED0CTi>04=3@`2@T9008b<S03@d=01NGUh0Bd];05QH
F02g]kL0H61P034a<@11@D40G5aL0:BTY02KVi/092@T03Ti>@18B4P0@D5108>3P`2WYjL0<S8b04U9
B@1@D500H61P09FEU@2<S8`08b<S04E5A@1IFET0FUYJ07UiN@1TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0e=CD0Lg=c07inOP2f][H0H61P01lO7`1;Bd/0G5aL06e]K@2=SHd0?Cdm01dM
7@1;Bd/0LG5a04M7A`1iNGT0XZ:R038b<P16ATH0Ng]k05iNGP37alL0EEEE04=3@`1=CDd0MWIf09:B
TP1ZJVX0MWIf051@D01KFe/0Ng]k05YJFP1[Jf/0N7Qh02h^;P1DE5@0J6QX07MgM`1bLW80S8b<03<c
<`1KFe/0JFUY07YjNP1IFET0N7Qh07IfMP1;Bd/0P82007AdM01:BTX0O7al04U9B@1DE5@0KVi^0820
P01LG5`0LG5a02`/;01NGUh0P82008:2PP14A4@0Bd];08R8R00k>c/0LW9b09bLW01@D500IVIV07]k
N`0^;Rh0H61P08R8R01nOWh0C4a<07MgM`1FEUH0N7Qh0<W9b@1oOgl0@41008b<S01IFET0>CTi09bL
W01nOWh0@41006EUI@1ADE40G5aL0<[:bP28R8P0?Cdm05EEE@1cLg<0TY:B0=cLg01[Jf/0?3`l075a
L@1MGEd0HF5Q0;Bd]03=cLd0<C4a079bLP1NGUh0QXJ60<;2`P1=CDd0;2`/04i>CP2IVIT0NWYj0<[:
bP0i>CT0Ng]k0:RXZ01^KVh0Rh^;0>7Qh@1LG5`0:RXZ0820P01mOGd0]KFe04Q8B014A4@0L71`0:^[
Z`1[Jf/0bLW905=CD`1=CDd0a/K607MgM`2MWId0O7al04a<C01HF5P0R8R80:^[Z`26QXH0MGEe04M7
A`23Ph<0WIfM04i>CP2c/k<0N7Qh03Lg=`11@D40VYZJ09VIV@2WYjL0=SHf05MGE`21PH40Y:BT08b<
S02?Shl0/K6a03lo?`2UYJD0RXZ:07]kN`2k^k/0QHF504U9B@1gMgL0SHf=000S09nOW`22PX80D51@
04M7A`1WIfL0V9RH09JFUP1bLW80XZ:R05IFEP1VIVH0S8b<03dm?@19BDT0LG5a04e=C@0k>c/0GEeM
0:NWY`1GEeL0IFEU02l_;`1OGel0Lg=c07AdM015ADD0HF5Q06e]K@0l?3`0>c/k0:>SX`0m?Cd0;Bd]
061PH014A4@07?ooool05P1?Cdl0F5QH0:NWY`2f][H0[Zj^04U9B@1GEeL0IFEU051@D01PH600L71`
065QH@1ADE40EEEE05YJFP1IFET0LW9b08b<S01nOWh0DU9B03Hf=P1=CDd203Lg=`2Y0451@@13@d<0
FUYJ034a<@0k>c/0@410059BDP14A4@0Fe]K03/k>`14A4@0@T9204U9B@1DE5@0@D5103/k>`13@d<0
B4Q803dm?@0h>3P0Bd];05IFEP18B4P0DU9B04E5A@28R8P0Lg=c05eMG@0W9bL0De=C05ADE01GEeL0
CDe=05ADE020P800JFUY05IFEP1fMWH0G5aL059BDP1FEUH0E5AD03dm?@1=CDd0GEeM07UiN@1lO7`0
S8b<05ADE01QHF40Kfm_09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P2<S8`0Q8B409BDU029RHT0
GemO04a<C01JFUX0IFEU06UYJ@1SHf<0BTY:05IFEP1/K6`0H61P05eMG@1NGUh0I6AT06=SH`11@D40
?Cdm05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`061PH01QHF40K6a/07YjNP10@400
=cLg05]KF`1fMWH0X:2P07MgM`28R8P0LG5a07IfMP1VIVH0EeMG04M7A`1BDU80BTY:09>CT`1WIfL0
GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0NWYj05QHF01CDe<0GEeM04=3@`1IFET0
DU9B092@T024Q8@0JFUY05mOG`1^KVh0HF5Q08f=S@2MWId0IfMW07=cL`1HF5P0HV9R03Lg=`1FEUH0
CTi>06MWI`22PX80E5AD061PH01@D500E5AD05QHF023Ph<0@D5107QhN01dM7@0NGUi08R8R00a<C40
=3@d04=3@`1PH600JVYZ05EEE@1bLW80HV9R05=CD`19BDT0<C4a04m?C`0O7al0QHF504];B`1@D500
E5AD04M7A`0205IFEP0U05aLG026QXH0OGem09ZJVP1ZJVX0RXZ:04m?C`1KFe/0Jf][06EUI@2EUID0
Lg=c08^;R`27QhL0Ogmo0<30`02IVIT0FEUI05]KF`1SHf<0Jf][0:FUY@1bLW80F5QH05MGE`1WIfL0
GemO06i^KP1`L700IFEU07alO01=CDd0H61P06IVIP1dM7@0TY:B07]kN`020:n_[`0h08f=S@22PX80
XJ6Q05UIF@2MWId0QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06m_K`1HF5P0K6a/05mOG`1dM7@0
Hf=S04e=C@1LG5`0HF5Q07]kN`1dM7@0Ph>308Z:RP1JFUX0LW9b05iNGP2HV9P0CTi>09>CT`2WYjL0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0HF5Q06QXJ01MGEd0XZ:R092@T01mOGd0
FEUI055AD@1?Cdl0BDU9071`L022PX80PH610:>SX`2GUiLAooooo`003oooool0o`25QHD0RHV907em
O@1gMgL0K6a/07moO`11@D40KVi^04=3@`1OGel0OWin04i>CP0n?Sh0JVYZ03hn?P2?Shl0Q8B403<c
<`1PH600K6a/030`<01MGEd0WinO06][J`1?Cdl0L71`06i^KP2=SHd0PH6104A4A01LG5`0P82006UY
J@26QXH0CTi>02h^;P13@d<0MGEe04e=C@22PX80W9bL03/k>`0e=CD0Fe]K059BDP28R8P0[Zj^03Xj
>P0k>c/0GUiN07=cL`1]KFd0UYJF0492@P1=CDd0KVi^051@D02:RXX0PX:203<c<`0k>c/0HF5Q05=C
D`1oOgl0?clo030`<01BDU80Lg=c05eMG@1FEUH0UIFE03hn?P10@400RXZ:05aLG01QHF40VYZJ01`L
700];Bd0EEEE07emO@1jNWX0WYjN01dM7@0U9BD0LG5a08F5Q@1;Bd/0Ng]k09:BTP0T92@0CTi>0820
P01?Cdl0Vi^K06YZJP0T92@0D51@09>CT`1FEUH0H61P04Q8B00];Bd0FUYJ08f=S@1;Bd/0N7Qh061P
H00];Bd0Cdm?0820P01TI6@0Shn?065QH@0o?cl0K6a/092@T01SHf<0EEEE08^;R`1EEED0QhN70:6Q
X@1:BTX0EUIF08J6QP1FEUH0E5AD079bLP2MWId0HV9R07moO`1>CTh0I6AT08N7Q`1]KFd0C4a<07Yj
NP24Q8@0A4A409BDU026QXH0C4a<08R8R01^KVh0E5AD07alO02j^[X0Lg=c05YJFP1GEeL0GEeM08j>
SP2MWId0CDe=055AD@1]KFd0GUiN05eMG@2EUID0E5AD07alO02MWId0PH6107IfMP3:b/X0HV9R04U9
B@1dM7@0OWin08^;R`3<c<`0De=C04Q8B02?Shl0PH61055AD@2MWId0Ph>304Q8B02@T900MGEe05=C
D`2/[:`0OWin03dm?@1CDe<0QXJ608B4Q01oOgl0ATI605UIF@1bLW80RHV906MWI`2=SHd0SXj>03De
=@1gMgL0Vi^K08:2PP2VYZH0HF5Q04];B`1lO7`0Y:BT07UiN@23Ph<0Bd];08j>SP2BTY80GemO09JF
UP1CDe<0Cdm?09RHV02DU9@0Q8B406QXJ01:BTX0KFe]0:6QX@1HF5P0V9RH08:2PP0e=CD0Bd];09ZJ
VP1DE5@0NGUi03Xj>P0l?3`0OWin0:BTY01WIfL0MWIf06MWI`1NGUh0Ogmo0820P01UIFD0TY:B08Z:
RP16ATH0Kfm_0:JVYP1nOWh0T92@04M7A`15ADD0LG5a08J6QP1ZJVX0KFe]0;:b/P008`14A4@0LW9b
09ZJVP13@d<0IfMW06YZJP1GEeL0Kfm_0<30`02=SHd0GEeM07alO013@d<0HV9R0<S8b01dM7@0DU9B
069RHP1SHf<0CTi>0:>SX`1bLW80AdM707MgM`20P800=cLg071`L02QXJ40MgMg03Ti>@1SHf<0@d=3
05IFEP2KVi/0Hf=S01cooooo05d0Bd];06=SH`2k^k/0[:b/0;Jf]P1LG5`0JVYZ08Z:RP1QHF40Ogmo
06MWI`1nOWh0LW9b05YJFP1bLW80QXJ608V9R@2FUYH0Vi^K07emO@1UIFD0HF5Q03@d=01CDe<0ADE5
03`l?01KFe/0;Bd]03/k>`0b<S80GemO065QH@1/K6`0@D5108R8R01WIfL0EEEE06IVIP1gMgL0A4A4
07AdM012@T80;Rh^04M7A`1LG5`0FUYJ04=3@`1MGEd0;bl_05aLG01TI6@0Kfm_02<S8`1_Kfl0?Shn
05MGE`1fMWH0Fe]K079bLP1IFET0E5AD06UYJ@1=CDd0BTY:04m?C`16ATH0A4A405=CD`1<C4`0IFEU
0861P@2VYZH0HF5Q09FEU@2VYZH0Kfm_065QH@1OGel0Jf][04Y:BP2d];@0`<30059BDP1kNg/0]kNg
09VIV@1GEeL0EUIF04A4A01RHV80JVYZ04];B`0c<c<00P1FEUH07@19BDT0ADE505QHF01CDe<0AdM7
03Lg=`13@d<0@T92055AD@1DE5@0EeMG04Y:BP1IFET0De=C05YJFP14A4@0G5aL06IVIP1<C4`0F5QH
051@D01VIVH0H61P04e=C@1RHV80BTY:04A4A01UIFD0H61P0080EEEE06L0FUYJ05mOG`1GEeL0MWIf
05]KF`19BDT0L71`0:>SX`15ADD0OWin07alO00g=cL0BTY:051@D01WIfL0@T9203dm?@13@d<0De=C
06QXJ01FEUH0BDU9061PH01JFUX0GemO051@D01OGel0OWin08Z:RP1SHf<0MWIf05mOG`1/K6`0DE5A
05mOG`0n?Sh0CTi>05iNGP1=CDd0Vi^K096AT@1MGEd0K6a/05mOG`1?Cdl0NGUi08N7Q`1NGUh0KVi^
05=CD`12@T80?Shn06i^KP20P800Ogmo08R8R01]KFd0HF5Q06=SH`1JFUX0GemO04Y:BP1QHF40I6AT
07UiN@1UIFD0De=C061PH01GEeL0MWIf07moO`1[Jf/0MGEe0:NWY`22PX80C4a<09RHV02ATI40M7Ad
08J6QP1TI6@0Q8B40:VYZ@2=SHd0J6QX04Q8B01JFUX0P82007emO@1ADE40FUYJ065QH@1OGel0Jf][
07alO01nOWh0MWIf07YjNP1ZJVX0Ng]k05eMG@1bLW80LG5a0080J6QX00@0KVi^0:b/[01dM7@0CTi>
0P28R8P01`1EEED0YjNW09ZJVP24Q8@0QhN705QHF01iNGT00P21PH40;02;Rh/0LW9b08F5Q@2IVIT0
XJ6Q069RHP1=CDd0LW9b07]kN`21PH40Ng]k05mOG`2BTY80GUiN08b<S021PH40_Kfm07moO`2:RXX0
Y:BT0861P@2<S8`0UiNG05aLG028R8P0Z:RX07=cL`2ZZZX0Z:RX06EUI@1RHV80DU9B06QXJ01gMgL0
OGem05EEE@1bLW80FEUI04Y:BP1lO7`0UIFE06a/K025QHD0U9BD4Oooool000oooooo0380RHV906IV
IP1cLg<0UiNG05aLG01KFe/0CTi>09^KV`1HF5P0;bl_04U9B@1>CTh0GEeM09fMW@0c<c<0;Bd]061P
H019BDT0QXJ6092@T00Y:BT0@D51055AD@2;Rh/0ZJVY04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[
Z`0Y:BT0EUIF06e]K@1KFe/0UYJF079bLP0^;Rh0<C4a05EEE@1]KFd0Hf=S08B4Q00k>c/0Bd];07Mg
M`2>SXh0PX:20;Ng]`80<c<c0;T0GUiN069RHP1oOgl0Lg=c01TI6@11@D40UIFE05=CD`1SHf<0Jf][
02PX:01ADE40CTi>04A4A01YJFT0JVYZ01@D500o?cl0BDU907inOP1RHV80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0OWin0:>SX`17AdL0U9BD03@d=00f=SH0@41009NGU`1=CDd0DU9B
03@d=00l?3`0MWIf09nOW`1PH600DU9B05YJFP0l?3`0B4Q806a/K01JFUX0MWIf03Hf=P0n?Sh0IVIV
07]kN`1:BTX0CTi>06a/K014A4@0O7al06i^KP0g=cL0C4a<069RHP0a<C40?Shn0861P@2>SXh0Ogmo
08Z:RP19BDT0GEeM07UiN@1CDe<0A4A405iNGP1@D500IFEU0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q8
0:JVYP2UYJD0?Cdm05mOG`1XJ6P0Jf][0;Jf]P1/K6`0;Bd]04I6AP1BDU80I6AT0861P@0d=3@0=SHf
0410@02>SXh0NGUi096AT@2n_[h0:b/[03Xj>P1]KFd0JFUY0;jn_P3Ng]h0AdM704U9B@1PH600Shn?
08B4Q03IfMT0J6QX07emO@2`/;00TI6A07AdM02ZZZX0Bd];030`<026QXH0UYJF09NGU`2i^KT0=cLg
0451@@1lO7`0R8R80861P@2j^[X0SHf=03De=@2YZJT0QhN707moO`2VYZH0CTi>0410@01<C4`0clo?
08^;R`2BTY80;2`/065QH@2CTi<0TI6A079bLP2DU9@0@D5104Y:BP2CTi<0H61P0::RXP10@400Fe]K
08j>SP2CTi<0LG5a0:6QX@19BDT0MWIf0;Jf]P1YJFT0XJ6Q07UiN@0a<C40MGEe0:VYZ@1BDU80SHf=
07AdM01_Kfl0Zj^[06][J`1TI6@0QHF505=CD`15ADD0H61P0:>SX`0207EeM@0I04i>CP19BDT0Rh^;
0<g=c@1KFe/0Rh^;06a/K01LG5`0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01kNg/0Fe]K
06i^KP1bLW80`l?30;Ng]`1<C4`0E5AD069RHP0208V9R@0H0;Vi^@0k>c/0<C4a0820P01JFUX0P820
0=GEe@1_Kfl0>SXj06YZJP1kNg/0IFEU0:>SX`2h^;P0<S8b0410@01QHF40GUiN07inOP2JVYX08R8R
02TY:@0l?3`0HV9R7?ooool03P1MGEd0EEEE0;Zj^P2FUYH0QhN706EUI@1aLG40D51@04=3@`1DE5@0
I6AT06MWI`1EEED0Bd];0P1_Kfl04P1EEED0?clo03dm?@1IFET0GEeM0410@00f=SH0CDe=04E5A@0g
=cL0FEUI055AD@0f=SH0=cLg055AD@1MGEd0DE5A03dm?@80GemO04L0GUiN06UYJ@1YJFT0C4a<05MG
E`0a<C40=CDe04i>CP1WIfL0EUIF04m?C`1UIFD0>CTi06a/K01SHf<0HV9R01hN7P1^KVh0A4A404I6
AP1LG5`0HF5Q06][J`1>CTh0>CTi07emO@1SHf<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820
P02k^k/0FEUI08F5Q@2f][H0U9BD07IfMP1GEeL0GemO05eMG@10@400QhN705YJFP2@T900aLG50<;2
`P1QHF40MgMg05=CD`2ATI40R8R806IVIP1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d
=01JFUX0De=C079bLP1DE5@0KFe]04e=C@0205UIF@0A07emO@1HF5P0I6AT08>3P`1HF5P0NWYj051@
D01HF5P0PH61055AD@1XJ6P0GEeM07YjNP1;Bd/0EUIF0410@01UIFD00P1BDU80E@15ADD0MWIf06QX
J01_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01PH600;bl_03Ti>@0e=CD0<c<c06][
J`1NGUh0ADE505mOG`1QHF40@T9204Y:BP1<C4`0Ng]k06e]K@0o?cl0C4a<05ADE01bLW80;Rh^04];
B`0M7Ad0>3Ph04];B`0U9BD0Hf=S05]KF`1MGEd0FUYJ06UYJ@17AdL0Ng]k065QH@1=CDd0JFUY014A
4@10@400I6AT05YJFP1/K6`0NGUi06][J`1bLW80Fe]K04m?C`1@D500OGem0492@P1dM7@0OGem0:RX
Z01iNGT0BTY:04e=C@1PH600Ogmo08b<S01MGEd0OWin0:2PX01gMgL0AdM7079bLP2:RXX0WinO096A
T@1MGEd0NGUi06=SH`1NGUh0GEeM055AD@15ADD00P1>CTh08P15ADD0Xj>S06MWI`1VIVH0De=C075a
L@1]KFd0Hf=S06QXJ01DE5@0KVi^04m?C`1=CDd0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[
Z`1iNGT0EeMG08V9R@1kNg/0FUYJ061PH01nOWh0RXZ:06m_K`1PH600P82007UiN@1WIfL2065QH@0W
06IVIP1eMGD0T92@05EEE@2VYZH0PH6108>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0Hf=S
05IFEP2:RXX0RHV906i^KP2UYJD0VYZJ05YJFP2JVYX0Kfm_04I6AP0g=cL0?clo06i^KP2EUID0V9RH
05MGE`1[Jf/0IFEU05mOG`1/K6`0PX:20861P@1ZJVX0PH61017ooooo000?ooooo`1A0<C4a01LG5`0
LG5a08V9R@2=SHd0C4a<04U9B@1@D500N7Qh05aLG01hN7P09RHV04Q8B01?Cdl0L71`07QhN010@400
=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a07=cL`2m_Kd0HF5Q07EeM@1KFe/0?Shn05MGE`2^[Zh0
[jn_05ADE018B4P0<30`059BDP2HV9P0Bd];0451@@1RHV80=3@d02PX:01]KFd0<S8b075aL@0h>3P0
;bl_0451@@2GUiL0RXZ:03De=@1MGEd0E5AD07]kN`2DU9@0F5QH03hn?P1HF5P0ATI6075aL@2ATI40
;bl_04Y:BP19BDT0Bd];07emO@2j^[X0HF5Q02@T9019BDT0CTi>05UIF@2;Rh/0=SHf02DU9@1>CTh0
E5AD03lo?`2QXJ40TY:B0080>3Ph0<l0PH6106UYJ@3>c/h0IVIV03Ti>@11@D40E5AD07MgM`2>SXh0
?Cdm03@d=00o?cl0Kfm_04i>CP29RHT0VIVI024Q8@16ATH0GEeM07YjNP2a/K40<C4a03De=@1PH600
HV9R04e=C@1lO7`0_Kfm04U9B@24Q8@0Rh^;04I6AP2KVi/0[Zj^03De=@0];Bd0F5QH06i^KP2ATI40
_;bl03`l?017AdL0KFe]08f=S@2;Rh/0YjNW06ATI01EEED0GemO0861P@1HF5P0_[jn05YJFP0_;bl0
KVi^0;jn_P2=SHd0R8R804I6AP1:BTX0H61P0;:b/P1WIfL0SHf=08J6QP0L71`0LW9b08N7Q`1JFUX0
OGem06][J`0g=cL0Cdm?0:JVYP2TY:@0D51@07UiN@0c<c<0CTi>09NGU`2XZ:P0I6AT09fMW@0/;2`0
@d=30:^[Z`2DU9@0MgMg0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP1QHF40Cdm?0<[:bP2/[:`0
CTi>05aLG01QHF40BTY:061PH02n_[h0AdM705aLG01<C4`0HF5Q09jNWP28R8P0@d=305iNGP1LG5`0
GUiN0<K6aP10@400G5aL071`L01FEUH0Ng]k0;jn_P1LG5`0Bd];071`L01eMGD0c<c<08Z:RP0k>c/0
QXJ607inOP27QhL0e]KF06MWI`1:BTX0UiNG06i^KP30`<00UYJF02h^;P1IFET0Fe]K04i>CP2GUiL0
YJFU06IVIP1?Cdl0AdM708B4Q02l_;`0DE5A03`l?01PH600N7Qh0:JVYP2f][H0@T9205IFEP1XJ6P0
ZZZZ06EUI@3EeMD0UYJF04Y:BP1aLG40XJ6Q07emO@2l_;`0IfMW04=3@`1RHV80TY:B0;Vi^@2a/K40
/[:b03@d=01iNGT0dm?C08j>SP1kNg/0];Bd061PH01CDe<0/k>c09BDU01SHf<0clo?05UIF@0j>SX0
FUYJ0::RXP1_Kfl0SHf=02XZ:P1<C4`0JFUY065QH@1OGel0L71`0<;2`P1JFUX07AdM09NGU`1?Cdl0
BTY:05iNGP1@D5007?ooool01`1eMGD0EEEE0;Ng]`35aLD0_[jn051@D01CDe<00P1YJFT03`1RHV80
CTi>05iNGP1iNGT0HV9R05]KF`1NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D002061P
H00;05MGE`0c<c<0EUIF05iNGP1BDU80C4a<05eMG@1EEED0AdM705]KF`1GEeL00P1HF5P0IP0i>CT0
G5aL03dm?@0f=SH0?Cdm04E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1BDU80>CTi079bLP16ATH0
DE5A05IFEP19BDT0K6a/05=CD`1@D500IVIV04];B`1:BTX0C4a<05QHF00m?Cd0C4a<051@D01TI6@0
E5AD06i^KP1IFET0G5aL08:2PP26QXH0K6a/0861P@2g]kL0[Jf]03lo?`2;Rh/0EeMG07YjNP1NGUh0
L71`05UIF@1=CDd0De=C06m_K`1[Jf/0J6QX04m?C`1cLg<0EUIF05QHF01@D500O7al06i^KP1JFUX0
@41005=CD`1BDU80Hf=S05MGE`1LG5`0ATI604i>CP1<C4`0GUiN05IFEP1/K6`0RHV908^;R`2SXj<0
LW9b06UYJ@1_Kfl0D51@06ATI01LG5`0QhN706ATI01dM7@0IFEU07MgM`1FEUH0Fe]K04U9B@22PX80
CDe=05IFEP27QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ08>3P`80EEEE04T0Ph>304M7A`1Y
JFT0>c/k04=3@`1=CDd0@d=30451@@13@d<0>3Ph03Xj>P14A4@0:BTY05YJFP0i>CT0Cdm?03Lg=`1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?01DE5@0CTi>07alO01KFe/0MgMg08N7Q`0>
3Ph09BDU03dm?@1?Cdl0M7Ad04e=C@1PH600GEeM05YJFP1QHF40GUiN069RHP1=CDd0UiNG06YZJP1M
GEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c07MgM`1EEED0DU9B034a<@29RHT0M7Ad05aLG01j
NWX0Hf=S07MgM`2c/k<0IfMW07=cL`0c<c<0ADE508F5Q@1TI6@0?3`l0080D51@00T0HV9R06=SH`1Z
JVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX00P1RHV80?@1iNGT0QXJ6079bLP3>c/h0SHf=04i>CP1R
HV80ZJVY08F5Q@2UYJD0QhN707AdM02EUID0K6a/06i^KP1QHF40T92@09nOW`1HF5P0Rh^;09FEU@2G
UiL0AdM704I6AP19BDT0DE5A08>3P`2:RXX0UYJF07UiN@1fMWH0JVYZ03/k>`1aLG40MGEe07alO02@
T900>SXj04U9B@1QHF40A4A409>CT`25QHD0DE5A0:^[Z`1fMWH0JVYZ04=3@`0h>3P0DE5A05IFEP1`
L700IVIV06][J`1nOWh0@T92079bLP2SXj<0IFEU09>CT`2k^k/04Oooool000oooooo0;P0TY:B08N7
Q`1nOWh0OWin06=SH`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@1<C4`0QHF507Mg
M`0P8200=SHf05YJFP1DE5@0IfMW07moO`0g=cL0@D5109VIV@1gMgL0Zj^[08b<S012@T80=cLg05eM
G@2OWil0V9RH03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b04=3@`1?Cdl0c/k>0:2P
X00E5AD0@T9205ADE01OGel0Ph>30<[:bP0l?3`0BTY:079bLP1ADE40/[:b04M7A`0P8200BTY:05eM
G@1RHV80/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh0:BTY07UiN@1fMWH0Q8B40;:b
/P0T92@0:b/[03/k>`2@T900W9bL09FEU@0R8R80<S8b04m?C`1iNGT0JFUY07MgM`25QHD09bLW059B
DP1]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO05IFEP16ATH0C4a<0:NWY`2c/k<0Cdm?06IV
IP1TI6@08b<S05aLG02CTi<0M7Ad075aL@1LG5`0?3`l05UIF@2VYZH0H61P03`l?01XJ6P0AdM707=c
L`2LW9`0DE5A04Q8B01TI6@0ATI608R8R02`/;00S8b<04Y:BP20P800E5AD06e]K@3Bd]80[Jf]0410
@011@D40JFUY04a<C02MWId0E5AD0451@@1ZJVX0GemO06m_K`2GUiL0f][J06EUI@1<C4`0Jf][06IV
IP28R8P0X:2P03lo?`0b<S80GEeM06EUI@1IFET0V9RH03Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=C
D`0n?Sh0ATI607emO@2^[Zh0hn?S04e=C@14A4@0AdM70:^[Z`1[Jf/0[:b/07UiN@1OGel0HV9R09:B
TP28R8P0];Bd0P17AdL0A@1/K6`0S8b<08N7Q`1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0RHV9
03hn?P1aLG40Ogmo0<g=c@2b/[80BTY:06IVIP29RHT0Ogmo08R8R01aLG40AdM709JFUP3WinL0T92@
0:RXZ01YJFT0@41008n?S`3;bl/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0YJFU05QHF00d=3@0CTi>
08j>SP1>CTh0RXZ:02l_;`19BDT0UIFE08^;R`1OGel0L71`051@D02MWId0]KFe09JFUP1LG5`0VYZJ
04Q8B015ADD0P8200:f][@1JFUX0Rh^;03Ti>@1?Cdl0I6AT07]kN`0e=CD0H61P05MGE`02059BDP0Q
09^KV`1EEED0Bd];05EEE@1eMGD0OWin09ZJVP1nOWh0?3`l04m?C`1[Jf/0F5QH0<[:bP1XJ6P0>CTi
055AD@11@D40LW9b0<G5a@1fMWH0;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P1EEED0EUIF
065QH@1cLg<0?clo01cooooo08l0N7Qh05aLG023Ph<0LW9b0:FUY@1BDU80FUYJ05MGE`0g=cL0IfMW
055AD@1gMgL0G5aL05MGE`1[Jf/0P82006ATI014A4@0HV9R05QHF01GEeL0H61P04I6AP1DE5@0@d=3
03lo?`1ADE40>c/k0451@@1=CDd0Cdm?059BDP12@T80<S8b05eMG@1/K6`0QhN7096AT@1`L700@d=3
06][J`1PH600>SXj06a/K01gMgL0CDe=04Y:BP1CDe<0AdM704a<C01?Cdl0C4a<03/k>`1SHf<0<C4a
04M7A`1RHV80O7al06i^KP0h>3P0FEUI075aL@1DE5@0ADE50492@P1FEUH0BDU904=3@`0o?cl0MWIf
07alO02IVIT0B4Q80::RXP32`/80QXJ60492@P1aLG40e=CD0;2`/01oOgl0KVi^03lo?`26QXH0`/;2
096AT@1;Bd/0E5AD04M7A`1OGel0HF5Q0451@@16ATH0Fe]K04e=C@1<C4`0@d=3069RHP1HF5P0De=C
03Hf=P0o?cl0?Cdm04];B`13@d<0DE5A0492@P1;Bd/0?Cdm055AD@11@D40I6AT07]kN`1FEUH0FUYJ
05EEE@1CDe<0IVIV055AD@1OGel0GUiN06][J`2DU9@0TI6A05IFEP1WIfL0NWYj07IfMP1EEED0OWin
05QHF01bLW80Rh^;0<c<c00h>3P0^[Zj08j>SP0h>3P0HV9R09fMW@1YJFT0Kfm_05MGE`0207AdM01M
07YjNP1DE5@0De=C04m?C`1IFET0DE5A05aLG017AdL0HV9R065QH@0e=CD0Xj>S04i>CP1]KFd0A4A4
06EUI@0E5AD0D51@05eMG@0Q8B40Jf][07inOP0d=3@0D51@05aLG00/;2`0C4a<03lo?`1DE5@0GEeM
04=3@`1FEUH0F5QH05MGE`1`L700EUIF06EUI@1BDU80Jf][06ATI014A4@0C4a<03lo?`1IFET0G5aL
071`L01IFET0ATI604Q8B00g=cL0OWin096AT@1nOWh0L71`08n?S`2@T900ATI605=CD`1JFUX0KFe]
07QhN01LG5`0HF5Q06ATI01nOWh0PH6103hn?P10@400BTY:04];B`12@T80GemO05YJFP1ZJVX0Cdm?
069RHP1VIVH0GemO06UYJ@1NGUh0Kfm_04Y:BP1UIFD0G5aL05MGE`1UIFD0JFUY06e]K@1TI6@0CDe=
071`L01]KFd0CTi>0080Ph>300`0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0LW9b0820P01bLW80GemO
06UYJ@1eMGD208^;R`0T05EEE@1OGel0B4Q808F5Q@27QhL0DU9B05IFEP1PH600Vi^K05]KF`1cLg<0
T92@05UIF@1NGUh0DU9B0492@P1OGel0Rh^;06m_K`2CTi<0EeMG059BDP12@T80>SXj079bLP26QXH0
Shn?05mOG`2FUYH0EUIF04Q8B02<S8`0^KVi07moO`2_[jl0`l?34Oooool000oooooo0900MgMg08B4
Q028R8P0Y:BT04i>CP25QHD0UiNG0;2`/00o?cl0?Shn05eMG@1]KFd0Kfm_0:>SX`0k>c/0FUYJ079b
LP1ADE40QHF504i>CP0^;Rh0@T9207MgM`27QhL0J6QX02l_;`10@400G5aL09JFUP1aLG40NGUi05UI
F@0X:2P0NGUi07YjNP16ATH0KFe]0451@@0b<S80G5aL07inOP29RHT0B4Q805]KF`0[:b/0F5QH08R8
R01GEeL0GUiN07moO`0h>3P0=SHf07YjNP1bLW80QhN7034a<@0T92@0Cdm?08B4Q015ADD0=cLg04Q8
B00g=cL0HV9R04e=C@0X:2P0@T9205]KF`13@d<0?3`l069RHP20P800DU9B04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R071`L015ADD0:BTY04A4A00i>CT0EEEE09>CT`2=SHd0:RXZ0492
@P1:BTX0UIFE0<O7a`1GEeL07AdM03Xj>P1bLW80IVIV08F5Q@1FEUH0<S8b04A4A01fMWH0JFUY09JF
UP1XJ6P0;bl_04E5A@1FEUH0PX:20;2`/01GEeL0;bl_04];B`1NGUh0Ng]k07UiN@3Ph>00CDe=05eM
G@2QXJ40Lg=c0::RXP35aLD0BDU902/[:`28R8P0^;Rh08:2PP2VYZH0D51@03Lg=`22PX80dM7A08N7
Q`2d];@0W9bL04e=C@1TI6@0Y:BT07inOP2l_;`20410@02@06m_K`20P800TY:B0:NWY`17AdL0@T92
05MGE`27QhL0LW9b071`L02RXZ80DE5A03lo?`2OWil0TI6A09RHV020P800@41005ADE020P800NWYj
05mOG`27QhL0EUIF05eMG@2/[:`0YZJV07EeM@2QXJ40?Shn055AD@1nOWh0PH61059BDP25QHD0:2PX
04e=C@2`/;00WYjN04];B`18B4P0MGEe05EEE@2QXJ40Cdm?04A4A01YJFT0>c/k05EEE@2GUiL0]KFe
04i>CP1kNg/0A4A405mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP25QHD0>CTi07EeM@1_Kfl0I6AT
0<[:bP2:RXX0ADE505eMG@1_Kfl0SHf=0820P018B4P0AdM70861P@11@D40_[jn0:BTY00g=cL0CTi>
07alO01iNGT0`l?303Lg=`15ADD0P82008>3P`2=SHd0Vi^K06ATI016ATH0RXZ:06e]K@23Ph<0[jn_
03De=@0c<c<0CDe=08Z:RP28R8P0_[jn02TY:@0o?cl0PH6108R8R01<C4`0YJFU0;Jf]P0[:b/0De=C
07IfMP1lO7`0/[:b0;jn_P0T92@0A4A407=cL`1_Kfl0R8R808B4Q00J6QX0EUIF0;:b/P2^[Zh0I6AT
09jNWP1_Kfl08b<S08b<S03GemL0FUYJ07MgM`0o?cl0=cLg03`l?01FEUH0Xj>S06EUI@1fMWH0;Bd]
05=CD`1=CDd0JFUY7?ooool0T@1?Cdl0IFEU0=WIf@3Ph>00dm?C09>CT`2<S8`0TI6A061PH01mOGd0
I6AT05EEE@1=CDd0CTi>06ATI01VIVH0Q8B406i^KP2<S8`0Ng]k06YZJP1WIfL0ADE504];B`1FEUH0
Cdm?07YjNP1HF5P0D51@06a/K01eMGD0JVYZ06UYJ@1EEED0KVi^07YjNP1QHF40Jf][06i^KP13@d<0
KVi^04i>CP0_;bl0@d=305eMG@15ADD0AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn071`L00k>c/0
ATI604Q8B00a<C40AdM703/k>`1IFET0HV9R05eMG@1=CDd0@41004Y:BP1@D500@D5104Q8B00i>CT0
=cLg06=SH`15ADD0FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0ADE508F5Q@2c/k<0
Xj>S04m?C`1PH600IVIV05ADE01NGUh0IfMW04E5A@1BDU80De=C069RHP1BDU80JVYZ079bLP1cLg<0
?clo04A4A01>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0NGUi08V9R@2KVi/0
Jf][05QHF01TI6@0GEeM06m_K`19BDT0GemO07EeM@1DE5@0BDU905ADE01]KFd0MGEe03hn?P1WIfL0
Fe]K06QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q09JFUP0j>SX0?Shn04e=C@1cLg<0
0P1DE5@0<P0l?3`0FUYJ03lo?`16ATH0F5QH05iNGP1`L700Bd];04A4A01DE5@0FEUI06EUI@1BDU80
MGEe02l_;`1<C4`0GemO04E5A@2GUiL0^;Rh04m?C`1CDe<0O7al061PH01jNWX0N7Qh065QH@1VIVH0
>3Ph03dm?@0S8b<0@D5105IFEP1SHf<0T92@07=cL`1HF5P0Bd];0492@P1VIVH0@T9206UYJ@1[Jf/0
KVi^04i>CP19BDT0BTY:04I6AP15ADD0G5aL0P1TI6@08@10@400@T9204e=C@2WYjL0IVIV05MGE`1X
J6P0GEeM07inOP27QhL0Ogmo096AT@22PX80@d=3061PH01KFe/0I6AT08:2PP1UIFD0F5QH04m?C`1O
Gel0CTi>05QHF01bLW80EeMG069RHP1:BTX0E5AD05EEE@1OGel0IFEU08B4Q00209nOW`0h069RHP1m
OGd0Ti>C06ATI021PH40Hf=S0492@P1lO7`0C4a<07alO01^KVh0Hf=S06IVIP1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01LG5`0VYZJ0820P01BDU80IfMW05MGE`1kNg/0PH6106a/K02C
Ti<0RHV906YZJP22PX80IfMW08V9R@2c/k<0QHF50:RXZ01FEUH0E5AD03/k>`1RHV80M7Ad08B4Q01n
OWh0@T9204i>CP1<C4`0CTi>08R8R01PH600Kfm_0:2PX02EUIDAooooo`003oooool0FP2SXj<0DE5A
06UYJ@21PH40UiNG03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0Cdm?04I6AP10@400>CTi
024Q8@12@T80IfMW020P800S8b<0?Shn0410@01aLG40BDU902`/;00b<S80B4Q804e=C@1ZJVX0S8b<
02l_;`0m?Cd0LG5a04Q8B022PX80TI6A02@T9016ATH0BTY:07alO01LG5`0UYJF02`/;018B4P0CDe=
04m?C`24Q8@0fMWI04a<C00X:2P0?clo05aLG03<c<`0QhN702PX:01GEeL0GUiN05EEE@1fMWH0UIFE
02@T901CDe<0Fe]K04I6AP2FUYH0^KVi024Q8@0i>CT0Lg=c06IVIP2[Zj/0U9BD03@d=00g=cL0FEUI
07moO`1QHF40][Jf08R8R00j>SX0EEEE0:VYZ@22PX80]kNg079bLP0K6a/0G5aL0;Ng]`80Ng]k05h0
;Bd]03lo?`1eMGD0XJ6Q04U9B@1nOWh0IfMW01`L701WIfL0MWIf06ATI02;Rh/0A4A402/[:`1MGEd0
R8R803lo?`1JFUX0OGem02d];@23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al08:2PP1kNg/0
SXj>04=3@`1:BTX0UYJF0:RXZ01;Bd/0LG5a079bLP1=CDd0_[jn08F5Q@13@d<0EeMG04M7A`0e=CD0
HV9R0;Vi^@1]KFd0Fe]K055AD@1?Cdl0XZ:R08^;R`14A4@0C4a<07AdM01VIVH0JFUY05iNGP0c<c<0
B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo06m_K`1BDU80T92@0:j^[P10@400ATI606m_K`1ZJVX0
MGEe0:n_[`1[Jf/0GEeM08j>SP2BTY80_kno0=KFeP2=SHd0;bl_06YZJP2BTY80V9RH0=7Ad@1@D500
:b/[05EEE@1`L700S8b<0P2PX:003@0l?3`0S8b<06IVIP2>SXh0^;Rh03dm?@0Y:BT0K6a/0;^k^`1Q
HF40^k^k038b<P1IFET00P2RXZ80E`2e]KD0c<c<05iNGP1QHF40YJFU07QhN02][Jd0EUIF03dm?@2R
XZ80YZJV06ATI02WYjL0LW9b05]KF`2`/;00TY:B0:2PX01nOWh0?clo07alO02QXJ40FUYJ08N7Q`1M
GEd0@D5107YjNP1lO7`0EEEE07moO`0];Bd0?clo08J6QP1ZJVX0Kfm_07YjNP12@T80DU9B0:JVYP2m
_Kd0Hf=S09ZJVP29RHT0LG5a0<W9b@2TY:@0B4Q807QhN01EEED0B4Q8071`L03Lg=`0];Bd07EeM@1>
CTh0<S8b06m_K`34a<@0VYZJ05QHF02;Rh/0H61P06][J`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P16ATH0Q8B406MWI`2c/k<0LG5a028R8P0o?cl0JFUY069RHP1TI6@0M7Ad02d];@0`
<300KVi^07EeM@0Looooo`0F04e=C@1WIfL0gmoO0??cl`2@T900JFUY05IFEP1bLW80M7Ad08b<S01E
EED0N7Qh06IVIP1ADE40N7Qh08V9R@2RXZ80Shn?09bLW01WIfL0EEEE05=CD`80BDU900H0Cdm?05AD
E01FEUH0?3`l055AD@1;Bd/204a<C01O051@D01?Cdl0D51@061PH02@T900V9RH06QXJ00j>SX0Fe]K
05YJFP12@T80HV9R07]kN`1KFe/0De=C06QXJ00i>CT0?3`l04e=C@1VIVH0I6AT07AdM00c<c<0@T92
04e=C@18B4P0HV9R04m?C`1NGUh0HF5Q05ADE01HF5P0AdM706ATI010@400C4a<05=CD`1QHF40LW9b
0;Ng]`1PH600XZ:R0;Fe]@2GUiL0FUYJ04e=C@1JFUX0B4Q806ATI01LG5`0ADE507UiN@2FUYH0WinO
055AD@1TI6@0F5QH06IVIP1[Jf/0DE5A03@d=01PH600G5aL04Q8B011@D40M7Ad06IVIP1EEED0>3Ph
06EUI@0e=CD0ADE504I6AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01RHV80NWYj05=CD`1?Cdl0B4Q8
07EeM@1cLg<0CDe=06=SH`1OGel0FUYJ02HV9P1WIfL0<C4a03Ph>00`<3000P1<C4`0X@1PH600DE5A
065QH@2:RXX0];Bd04U9B@1OGel0Bd];03De=@17AdL0ADE504];B`0i>CT0>SXj03/k>`10@400>c/k
04M7A`1BDU80QHF504Y:BP0l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI075aL@1DE5@0DE5A
07EeM@1hN7P0Ph>306EUI@1>CTh0FUYJ05=CD`1LG5`0IFEU04Y:BP1lO7`0OGem03`l?01XJ6P03@d=
02DU9@0n?Sh0CTi>05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S07EeM@1CDe<0L71`
051@D01PH600LW9b07MgM`1RHV80IFEU07MgM`1cLg<0KVi^05iNGP1>CTh0De=C04m?C`2DU9@0JVYZ
06UYJ@2RXZ80U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a07YjNP2h^;P0MGEe061PH01eMGD0N7Qh
07EeM@1iNGT0KVi^06YZJP2=SHd0F5QH0410@01aLG40RHV907IfMP23Ph<0X:2P08Z:RP1IFET0WYjN
09NGU`2BTY80W9bL07emO@1XJ6P0NGUi07moO`2DU9@0MWIf09nOW`2=SHd0IfMW08B4Q02BTY80Xj>S
0451@@15ADD0Fe]K03<c<`2MWId0Fe]K08N7Q`2IVIT0F5QH08J6QP1GEeL0OGem07alO02;Rh/0VIVI
04M7A`1aLG40UYJF069RHP2@T900SXj>05]KF`2DU9@0EEEE04e=C@0/;2`0ATI606][J`1nOWh0Ph>3
08:2PP2IVIT0HF5Q055AD@2ATI40TY:B06UYJ@23Ph<0P820017ooooo000?ooooo`1=0;fm_@2EUID0
FEUI06UYJ@2ZZZX0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0DE5A09JFUP1dM7@0
51@D04Q8B01FEUH0ADE507MgM`2FUYH0=3@d05UIF@2JVYX0L71`0:BTY01DE5@0>CTi04a<C01nOWh0
SXj>06ATI00Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1iNGT0GEeM06QXJ01;Bd/0
:b/[03/k>`1jNWX0Vi^K05]KF`1PH600:BTY059BDP2FUYH0CTi>04a<C00o?cl0:b/[03De=@1aLG40
DE5A03lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY05IFEP2YZJT0I6AT04I6AP1dM7@0
0P0c<c<0d`1jNWX0Zj^[03lo?`1<C4`0<30`03Xj>P2TY:@0Ti>C03<c<`0g=cL0GUiN06UYJ@1jNWX0
?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf=P10@400HV9R05YJFP2YZJT0R8R802PX:012@T80
FEUI0410@02QXJ40^KVi02`/;01<C4`0MWIf051@D032`/80alO703@d=00m?Cd0GUiN06ATI02FUYH0
cLg=03Ph>00n?Sh0De=C08j>SP1NGUh0YZJV08B4Q00o?cl0Hf=S09BDU01bLW80_kno071`L012@T80
Cdm?08>3P`35aLD0];Bd02l_;`1NGUh0Lg=c0:ZZZP2CTi<0];Bd09jNWP0i>CT0IfMW08R8R024Q8@0
NWYj09FEU@0X:2P0E5AD0820P021PH40FUYJ09>CT`1;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0
?Shn0861P@2FUYH0XZ:R0;Zj^P0n?Sh0IfMW09:BTP35aLD0V9RH0:NWY`1cLg<0NWYj08Z:RP2;Rh/0
K6a/08j>SP0e=CD0ATI608N7Q`2ZZZX0HF5Q08R8R00a<C40@T9209fMW@2>SXh0F5QH05MGE`1KFe/0
@T920:j^[P1KFe/0NGUi07AdM00h>3P0De=C0:>SX`28R8P0@d=307inOP15ADD0PH610:2PX010@400
TI6A08V9R@1eMGD0[jn_0:VYZ@13@d<0G5aL04];B`2YZJT0^;Rh03/k>`17AdL0N7Qh05=CD`26QXH0
Ng]k04U9B@1:BTX0@D5108f=S@3>c/h0DU9B02HV9P1KFe/0G5aL08n?S`30`<00E5AD03/k>`1nOWh0
QHF507EeM@2UYJD0YjNW04];B`2FUYH0/;2`08B4Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`39bLT0
N7Qh04E5A@12@T80I6AT08N7Q`1gMgL0[:b/059BDP1;Bd/0Ph>309BDU02ATI40_[jn03lo?`0g=cL0
Hf=S0:ZZZP1DE5@0V9RH03lo?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l06IVIP1PH600
J6QX061PH00l?3`07?ooool03011@D40GemO05UIF@2a/K40b/[:059BDP1VIVH0GUiN03Xj>P1MGEd0
LG5a061PH080@T920700LW9b07UiN@1_Kfl0G5aL07AdM01bLW80AdM704E5A@0];Bd0BTY:03Xj>P0h
>3P0M7Ad03De=@0o?cl0>SXj06QXJ01aLG40D51@04E5A@25QHD0GemO05ADE01PH600O7al06=SH`1h
N7P0H61P0451@@1OGel0Ng]k05=CD`1=CDd0JFUY03/k>`1UIFD0J6QX06=SH`0n?Sh0HF5Q04E5A@1D
E5@0IVIV05iNGP1oOgl0?Shn04M7A`1cLg<0DE5A04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q804m?C`1V
IVH0WIfM038b<P2;Rh/0]kNg08B4Q01`L700N7Qh08>3P`0_;bl0@D51059BDP1bLW80Q8B40=7Ad@2V
YZH0De=C05iNGP1XJ6P0EeMG06MWI`1LG5`0BTY:04e=C@1WIfL0DE5A05IFEP1;Bd/0GEeM06UYJ@1:
BTX0A4A405EEE@1]KFd0BTY:05=CD`13@d<0AdM703lo?`12@T80EEEE06QXJ022PX80GUiN06EUI@1E
EED0EUIF08J6QP1/K6`0Ogmo04];B`1JFUX0DU9B05aLG015ADD0IfMW0P1CDe<0XP13@d<0P82005MG
E`1]KFd0MWIf0;>c/`11@D40bLW907EeM@0_;bl0K6a/06m_K`1?Cdl0EeMG05mOG`17AdL0DE5A05MG
E`0k>c/0D51@04E5A@0h>3P0BTY:0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0HV9R08^;
R`18B4P0?Shn059BDP1VIVH0];Bd0:f][@1SHf<0H61P07=cL`18B4P0Rh^;07EeM@1/K6`0QHF502PX
:00[:b/0@D5105aLG02>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1EEED0Fe]K07Mg
M`1QHF40Hf=S06e]K@16ATH0LG5a06=SH`1=CDd0LW9b07AdM011@D40E5AD09JFUP1lO7`0SHf=06UY
J@1NGUh0PX:20;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05IFEP1^KVh0J6QX06][
J`26QXH0JFUY06m_K`1ZJVX0L71`05EEE@0o?cl0H61P071`L01iNGT0IFEU0:j^[P1jNWX0O7al0<71
`@2NWYh0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0LG5a061PH01RHV80IFEU07Ui
N@1MGEd0EUIF05ADE01FEUH0LG5a04e=C@24Q8@0MgMg07EeM@1/K6`0FEUI07=cL`1@D500TY:B0:RX
Z01fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<06QXJ01NGUh0C4a<05=CD`1FEUH0GUiN05aL
G01JFUX0EEEE059BDP17AdL0IFEU04M7A`1JFUX0UYJF0:BTY17ooooo000?ooooo`3:071`L02UYJD0
S8b<07moO`1WIfL0`/;205]KF`27QhL0;Bd]03@d=01cLg<0UYJF03lo?`1TI6@0;Rh^05ADE02XZ:P0
J6QX05]KF`1=CDd07QhN03Xj>P24Q8@0DU9B04i>CP0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0
E5AD075aL@1nOWh0820P04I6AP1MGEd0FEUI08:2PP2n_[h0@d=3038b<P13@d<0DU9B08n?S`2a/K40
8b<S0410@01=CDd0Fe]K06ATI02c/k<0Bd];05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0
CDe=0861P@0Y:BT04Q8B03Ti>@1BDU80Ph>307inOP3IfMT0;Rh^02d];@1RHV80QhN706QXJ030`<00
;bl_01LG5`0k>c/0YZJV09ZJVP2ATI40:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN7P1GEeL0
B4Q8065QH@1XJ6P0A4A402LW9`1CDe<0QXJ606][J`1]KFd0DE5A0492@P1EEED0S8b<05MGE`1jNWX0
O7al03<c<`10@400TY:B05EEE@2;Rh/0@d=303De=@1TI6@0[Jf]08n?S`1bLW80Zj^[038b<P1OGel0
PH6106ATI01HF5P0XJ6Q04=3@`1=CDd0GUiN08f=S@1WIfL0OWin02h^;P17AdL0GemO09RHV00m?Cd0
Jf][05eMG@13@d<0Ti>C05MGE`14A4@0S8b<03hn?P0g=cL0Lg=c08F5Q@1_Kfl0GemO03`l?01WIfL0
QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861P@0`<300DU9B06a/K01DE5@0LW9b0<c<c01^KVh0
<30`05mOG`1SHf<0O7al0>3Ph01EEED0ATI606=SH`1bLW80Kfm_07QhN024Q8@0ADE508j>SP1GEeL0
Ti>C0;no_`1WIfL0:2PX04A4A01fMWH0Ph>309bLW00e=CD0?Cdm05YJFP1QHF40PX:20=GEe@2BTY80
;Rh^08b<S01RHV80`/;20:j^[P80@D5105H0PX:208Z:RP20P800UYJF069RHP2XZ:P0`<30065QH@32
`/80LG5a03lo?`2CTi<0_Kfm071`L01XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2J
VYX0T92@069RHP0c<c<0?3`l06i^KP2k^k/0HV9R07EeM@0o?cl0FEUI08J6QP2GUiL0VYZJ0<K6aP0o
?cl0EEEE06UYJ@2ATI40P82009^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0<30`06QXJ02C
Ti<0D51@075aL@1_Kfl0?clo06QXJ022PX80WIfM06IVIP1FEUH0:BTY05IFEP3Bd]80XZ:R04=3@`1d
M7@0BDU903Ph>01hN7P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0QHF509>CT`0g=cL0G5aL038b<P1[
Jf/0N7Qh05MGEacooooo05H0?Shn06][J`2BTY80H61P0;:b/P1KFe/0EEEE06YZJP15ADD0IfMW04a<
C01DE5@0B4Q805ADE01fMWH0T92@0;>c/`2GUiL0Zj^[06e]K@1IFET0EeMG02XZ:P1IFET0B4Q803/k
>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0@41006YZJP1ADE40I6AT06QXJ01/K6`0ATI606a/
K01ADE40@d=304a<C01SHf<0F5QH059BDP1FEUH07QhN04Y:BP1RHV80F5QH03hn?P1PH600=3@d04Q8
B01=CDd0?Cdm05mOG`1eMGD0Kfm_08N7Q`1OGel0JVYZ04m?C`1^KVh0CTi>05ADE01LG5`0HF5Q071`
L02GUiL0EEEE09FEU@2KVi/0YjNW08^;R`1NGUh0MWIf08N7Q`1LG5`0?Cdm04I6AP1bLW80WinO0;2`
/080EEEE00T0EUIF06MWI`1cLg<0L71`04e=C@1HF5P0N7Qh06MWI`1IFET00P1[Jf/01P1ZJVX0@410
05EEE@1@D500E5AD04a<C080G5aL02`0De=C04Q8B01XJ6P0Jf][06i^KP24Q8@0Lg=c07EeM@1[Jf/0
K6a/08N7Q`1ZJVX0SHf=05=CD`1/K6`0P82006UYJ@1]KFd0N7Qh065QH@1@D500@d=307alO01XJ6P0
RXZ:08J6QP2/[:`0I6AT08j>SP1nOWh0<30`05eMG@15ADD0R8R804U9B@0h>3P0DU9B05aLG01QHF40
ADE507MgM`1VIVH0A4A404U9B@80B4Q80680AdM70:FUY@1@D500IFEU04M7A`1KFe/0?3`l05eMG@0m
?Cd0GEeM06YZJP1OGel0UYJF0861P@14A4@0De=C06IVIP12@T80HF5Q04M7A`10@400D51@02TY:@0Z
:RX0=cLg04U9B@1SHf<0F5QH07inOP1QHF40CDe=05UIF@1BDU80JVYZ04i>CP1YJFT0HV9R06a/K01M
GEd0Bd];04i>CP1=CDd0RHV907moO`1YJFT0Rh^;07EeM@1PH600;2`/06EUI@13@d<0F5QH059BDP1A
DE40KVi^08:2PP1NGUh0MgMg06=SH`10@400BTY:04i>CP1bLW80ZJVY065QH@1EEED0FEUI07=cL`1N
GUh0Fe]K07YjNP1HF5P0EEEE05UIF@1BDU80Fe]K06=SH`1]KFd0Hf=S0:j^[P1mOGd0SHf=0:j^[P2D
U9@0LW9b09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0Lg=c065QH@1[Jf/0XJ6Q09fMW@80
D51@02D0C4a<06a/K02/[:`0Jf][08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0L71`05IF
EP1VIVH0E5AD04I6AP2LW9`0Ogmo06UYJ@2HV9P0EEEE04];B`12@T80@41006YZJP21PH40Shn?06UY
J@1LG5`0MgMg05mOG`26QXH0Q8B408:2PP1eMGD0Ogmo017ooooo000?ooooo`2D06=SH`1oOgl0UiNG
08f=S@1;Bd/0UIFE069RHP2LW9`0EEEE02TY:@0g=cL0QhN704m?C`2FUYH0?clo04=3@`1NGUh0H61P
09fMW@2OWil05aLG04I6AP1IFET0K6a/096AT@0i>CT0:BTY06=SH`2IVIT0N7Qh05ADE02HV9P06a/K
04Q8B025QHD0F5QH05mOG`1=CDd092@T03hn?P0m?Cd0D51@06a/K01RHV80;Bd]03lo?`1^KVh0HF5Q
07IfMP2b/[80=3@d02LW9`1ADE40MWIf08N7Q`1lO7`0:b/[030`<01BDU80J6QX05mOG`23Ph<09BDU
0861P@1kNg/0;Bd]05MGE`1iNGT09BDU034a<@2>SXh0QHF505mOG`12@T80<c<c05eMG@2>SXh0QhN7
03lo?`1iNGT0CDe=0451@@20P800Hf=S02l_;`1OGel0<S8b05MGE`1fMWH0Zj^[04E5A@16ATH0D51@
06e]K@26QXH0Bd];03<c<`1;Bd/0AdM704];B`26QXH0IFEU04A4A01UIFD0HV9R05MGE`2MWId0TI6A
0410@017AdL0GUiN05mOG`2[Zj/0BTY:030`<016ATH0De=C05aLG01kNg/0]kNg03Xj>P1PH600QXJ6
05MGE`1aLG40d];B08B4Q00[:b/0TI6A07]kN`1hN7P0h^;R061PH00g=cL0GEeM06QXJ01BDU80XZ:R
0;jn_P10@400G5aL07moO`1kNg/0g]kN05eMG@0i>CT0G5aL07alO080TY:B03D0=CDe0410@01hN7P0
YJFU0:ZZZP1XJ6P0V9RH03Ph>01EEED0U9BD09RHV02b/[80R8R8034a<@19BDT0Fe]K0:VYZ@1dM7@0
VYZJ06EUI@1:BTX0PX:20820P01RHV80[jn_04Q8B01FEUH0FEUI07IfMP1ADE40ZZZZ03hn?P0g=cL0
RHV90;:b/P1jNWX0^;Rh06ATI010@400aLG508>3P`1XJ6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0
MgMg0410@01QHF40b<S809ZJVP0207EeM@0Q03/k>`16ATH0UiNG051@D02i^KT0PH6104i>CP3?cll0
^;Rh05mOG`2MWId0QXJ6065QH@2/[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1VIVH0
UYJF0:BTY00i>CT0ATI6055AD@1mOGd0Jf][08Z:RP11@D40DE5A0080HV9R00@0K6a/0<c<c02CTi<0
?Cdm0P1[Jf/08`1iNGT0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0LW9b092@T01T
I6@0TI6A0:^[Z`0c<c<0=cLg0:RXZ02f][H0T92@07emO@0V9RH0;Rh^07QhN02a/K40Ng]k0<C4a01g
MgL0=CDe05aLG020P800RXZ:0<?3``2IVIT0:2PX0080EEEE00L0FEUI05QHF02MWId07alO02l_;`1_
Kfl0J6QX01cooooo0280?Shn05UIF@31`L40_kno092@T01CDe<0FEUI08B4Q01[Jf/0MGEe05eMG@1W
IfL0IFEU06][J`1^KVh0RXZ:0;Vi^@2JVYX0OGem06e]K@1OGel0HF5Q04=3@`1PH600De=C04M7A`1b
LW80>SXj05ADE01;Bd/0Hf=S05mOG`1/K6`0De=C0P27QhL0:@1iNGT0J6QX0861P@1?Cdl0W9bL051@
D00m?Cd0EEEE06e]K@1OGel0GUiN06QXJ00V9RH0F5QH06][J`20P800?clo06UYJ@0Z:RX0FUYJ06i^
KP1:BTX0JFUY04U9B@16ATH0Fe]K03/k>`1BDU80FUYJ05IFEP12@T80De=C05YJFP1CDe<0GemO09NG
U`18B4P0NWYj08^;R`1WIfL0DE5A0080GemO08l0BTY:06i^KP1EEED0OGem07alO036a/H0Ti>C04a<
C01FEUH0BTY:05eMG@1dM7@0Fe]K04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07Ui
N@1KFe/0HV9R061PH01`L700EeMG06IVIP1KFe/0HF5Q04=3@`1iNGT0UiNG05eMG@1SHf<0HV9R0:RX
Z02CTi<0E5AD06e]K@2;Rh/0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0E5AD06a/
K02LW9`0e=CD04E5A@29RHT0OGem05YJFP2`/;00Hf=S069RHP0j>SX0N7Qh05EEE@25QHD0Ng]k06YZ
JP12@T80IfMW051@D01OGel0De=C0410@01/K6`0SXj>04e=C@1KFe/0DE5A06a/K00n?Sh0CDe=05MG
E`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0FUYJ04e=C@25QHD0Jf][04];B`17AdL09bLW02XZ
:P0n?Sh0CTi>08V9R@1IFET0IfMW05mOG`1WIfL0P82005ADE01^KVh0DE5A08F5Q@1=CDd0FEUI07Ad
M01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1DE5@0NGUi05MGE`1EEED0UIFE05UIF@1OGel0G5aL06EU
I@28R8P0Ogmo04E5A@1oOgl0KFe]03lo?`1gMgL0J6QX03@d=00n?Sh0?clo05]KF`1_Kfl0Lg=c06UY
J@0206][J`0505YJFP1FEUH0DE5A04A4A01DE5@00P1bLW80>`1FEUH0U9BD06ATI017AdL0G5aL07em
O@1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?Cdl0HF5Q06EUI@1ZJVX0EEEE05ADE012@T80GUiN04i>
CP1;Bd/0DU9B04M7A`0l?3`0BTY:0:2PX01mOGd0J6QX05iNGP1^KVh0QXJ606YZJP1gMgL0Ph>307Qh
N026QXH0K6a/05aLG01nOWh0H61P04M7A`1OGel0E5AD06=SH`1WIfL0NGUi07EeM@1GEeL0LG5a07Yj
NP1XJ6P0EEEE03Ph>02:RXX0[Jf]05iNGP2GUiL0YjNW017ooooo000?ooooo`1`0;Vi^@1HF5P0FEUI
09^KV`2YZJT0EEEE04Y:BP1]KFd0Y:BT04m?C`1HF5P0=cLg03@d=01OGel0H61P08^;R`1WIfL0=3@d
04a<C01ZJVX0?Cdm034a<@1KFe/0=cLg09RHV01nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
03Xj>P18B4P0@d=309jNWP1nOWh0>SXj04I6AP1EEED0>c/k04];B`2VYZH0;Bd]04A4A018B4P0<c<c
0820P03/k>`0QHF502<S8`0j>SX0F5QH09BDU02h^;P0<c<c0410@016ATH0FEUI06YZJP2k^k/0<S8b
03/k>`1_Kfl0B4Q805eMG@1mOGd0;2`/024Q8@17AdL0M7Ad07YjNP2<S8`071`L02TY:@1KFe/0]kNg
06i^KP2UYJD0Rh^;03Lg=`1YJFT0ZZZZ05ADE02YZJT0=CDe04I6AP1cLg<0/[:b08Z:RP1TI6@0;bl_
05mOG`29RHT0T92@051@D02OWil0?clo0451@@1>CTh0M7Ad06e]K@2NWYh0=SHf03<c<`17AdL0PX:2
08>3P`1lO7`0OWin0492@P80ZZZZ03X0Cdm?0861P@1aLG40:BTY05UIF@1hN7P0RHV90:NWY`2ATI40
<C4a04i>CP20P800V9RH061PH03Bd]80O7al04I6AP1mOGd0WIfM075aL@38b<P0>3Ph0410@01CDe<0
Zj^[09RHV01kNg/0=cLg04a<C01YJFT0Zj^[051@D02MWId0F5QH03Xj>P1VIVH0U9BD038b<P1SHf<0
J6QX03hn?P1;Bd/0MWIf05=CD`1]KFd0GemO04U9B@1]KFd0WIfM05MGE`12@T80Ph>303dm?@1ZJVX0
VIVI07moO`1LG5`0TY:B0P1PH600M03De=@0Lg=c03Lg=`1PH600IVIV08:2PP2YZJT0DU9B034a<@1G
EeL0HF5Q06ATI02c/k<0QHF503hn?P21PH40V9RH0:RXZ03IfMT0GEeM02`/;015ADD0TI6A08F5Q@30
`<00?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1oOgl0R8R80<30`01JFUX0>3Ph05EEE@1l
O7`0LW9b0;>c/`24Q8@0ADE508R8R01OGel0Ogmo07emO@0R8R80@D51079bLP1MGEd0Xj>S061PH01Q
HF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k07emO@2KVi/0PH6104e=C@1SHf<0YJFU0=OGe`1Y
JFT0WIfM08:2PP1?Cdl0WIfM0;Bd]01UIFD0Ph>3075aL@19BDT0H61P08Z:RP1jNWX0Kfm_05=CD`12
@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0C4a<08n?S`17AdL0@d=305UIF@17AdL0EEEE06a/K02?
Shl0=SHf05IFEP0j>SX0D51@061PH02LW9`0>3Ph02l_;`1YJFT0ATI602/[:`1oOgl0G5aL03dm?@1P
H600>c/k7?ooool0A@19BDT0HV9R05MGE`1TI6@0JFUY05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EU
I@10@400AdM707alO01bLW80IVIV06QXJ01nOWh0GEeM05ADE00i>CT0<30`05IFEP0n?Sh0<c<c06][
J`1?Cdl0@D5103dm?@1RHV80IfMW05YJFP12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061P
H015ADD0M7Ad08:2PP1MGEd0IfMW06UYJ@1LG5`0Lg=c07AdM024Q8@0G5aL071`L00c<c<0EUIF07Yj
NP1QHF40PX:2051@D018B4P0U9BD065QH@1[Jf/0AdM7061PH00c<c<0F5QH071`L00205aLG03K0<71
`@1<C4`0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0DU9B0::RXP3?cll0]kNg05YJ
FP1LG5`0C4a<0861P@20P800GEeM04=3@`1IFET0QHF504M7A`1fMWH0JVYZ07AdM01GEeL0G5aL04I6
AP1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1GEeL0HV9R04];B`1@D500HF5Q04U9
B@1XJ6P0EEEE06IVIP13@d<0CDe=055AD@1IFET0PH6108B4Q01ADE40CTi>06=SH`29RHT0G5aL06AT
I01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1IFET0Lg=c08J6QP0i>CT0DU9B03@d=01<C4`0O7al07Mg
M`1FEUH0QHF504A4A00m?Cd0Lg=c04A4A00o?cl0KVi^03@d=01kNg/0=CDe06][J`1JFUX0R8R803Xj
>P1^KVh0KFe]02l_;`1nOWh0LW9b02XZ:P1=CDd0MGEe03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b
<P1JFUX0C4a<04m?C`15ADD0MgMg05=CD`13@d<0Fe]K05YJFP1WIfL0CTi>04a<C01NGUh0K6a/05AD
E018B4P0DU9B03Hf=P1kNg/0Lg=c0492@P1`L700RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b
<P1WIfL0a/K60820P027QhL0AdM705=CD`1PH600CTi>05mOG`2ATI40O7al08>3P`1_Kfl0K6a/071`
L01PH600MGEe059BDP1OGel0A4A407YjNP1FEUH0ATI60410@012@T80]KFe07emO@26QXH0_Kfm07Yj
NP1GEeL0GemO05UIF@14A4@0G5aL06YZJP1aLG40OGem06UYJ@1RHV80MWIf06IVIP1aLG40RHV906][
J`1oOgl0Rh^;06][J`2:RXX0Hf=S065QH@1NGUh0JFUY06m_K`1BDU80MgMg06MWI`2:RXX0VYZJ03<c
<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C04e=C@0o?cl0BDU906=SH`1TI6@0QXJ608f=
S@25QHD0GUiN05EEE@2ATI40UIFE092@T02NWYh0X:2P017ooooo000?ooooo`0308n?S`2OWil0Jf][
0080JVYZ07/0Xj>S055AD@1eMGD0B4Q8079bLP1fMWH0CTi>03<c<`1GEeL0>c/k06MWI`1cLg<0>CTi
05aLG01WIfL0@T9206IVIP1`L700>c/k05UIF@20P800Fe]K08J6QP1UIFD0?3`l06MWI`2>SXh0JVYZ
06MWI`14A4@0<c<c069RHP1cLg<0D51@0861P@2NWYh0:2PX03Ph>01LG5`0Fe]K08b<S020P800;2`/
03dm?@1:BTX0LG5a061PH02ZZZX0BTY:06=SH`1dM7@0GemO075aL@1iNGT092@T04M7A`1eMGD0NGUi
08B4Q00W9bL0820P0410@01/K6`0LW9b05ADE02UYJD0A4A404=3@`25QHD0EUIF07alO02m_Kd09BDU
04I6AP1^KVh0MWIf04I6AP2KVi/0<C4a0410@01UIFD0Ogmo04=3@`2OWil0G5aL038b<P1_Kfl0C4a<
07alO022PX80<C4a03/k>`1FEUH0Ng]k051@D01WIfL0De=C055AD@1jNWX0Vi^K05MGE`20P800Ng]k
034a<@1mOGd0_;bl05YJFP1gMgL0G5aL04U9B@27QhL0/;2`05eMG@1EEED0KFe]04];B`2LW9`0_Kfm
05=CD`1BDU80Ogmo055AD@18B4P00P2a/K40201SHf<0IVIV05IFEP1]KFd0^;Rh09FEU@16ATH0P820
0P1TI6@0O@2NWYh0IVIV06EUI@1UIFD0G5aL05UIF@2PX:00Zj^[04m?C`1WIfL0FUYJ05UIF@1_Kfl0
WIfM04=3@`1VIVH0I6AT04e=C@1YJFT0QHF504=3@`1^KVh0UYJF05YJFP20P800c<c<06IVIP0_;bl0
Ph>307emO@2KVi/0bl_;06YZJP1:BTX0P82009fMW@1cLg<0[:b/08B4Q01=CDd0Rh^;07moO`1EEED0
[Zj^06QXJ00o?cl0Fe]K079bLP1hN7P0ZJVY04=3@`1HF5P0GUiN09RHV01YJFT0a/K608B4Q00i>CT0
RXZ:07UiN@2RXZ80SHf=02h^;P16ATH0RHV90<30`01XJ6P0RXZ:04A4A02@T900YZJV06][J`2n_[h0
?clo04M7A`1nOWh0];Bd09FEU@1oOgl0Bd];08V9R@2n_[h0Jf][06YZJP1<C4`0@T9206YZJP2>SXh0
R8R805YJFP0f=SH0G5aL08N7Q`2][Jd0M7Ad079bLP1=CDd0IFEU07emO@1EEED0SXj>0;:b/P2PX:00
JFUY08J6QP2DU9@0GUiN096AT@16ATH0B4Q806i^KP2IVIT0D51@06IVIP1iNGT0ATI607IfMP24Q8@0
@D5105YJFP1gMgL0DE5A06EUI@2/[:`0RXZ:0080Hf=S01L0Cdm?065QH@2LW9`0MGEe04E5A@1XJ6P0
JFUY0451@@27QhL0EEEE04m?C`26QXH0IFEU05aLG01DE5@0RHV906YZJP0h>3P0H61P04a<C01VIVH0
Rh^;06EUI@0Looooo`0a04=3@`1JFUX0EEEE075aL@3GemL0BDU904i>CP1[Jf/0HF5Q05YJFP1GEeL0
G5aL06ATI01QHF40GEeM04Y:BP2;Rh/0P82005aLG01ADE40ATI605QHF00m?Cd0>SXj03Hf=P0j>SX0
BTY:03Ph>015ADD0@D5103`l?00n?Sh0GUiN04=3@`1cLg<0E5AD05mOG`1TI6@0GEeM04];B`1LG5`0
Cdm?03Xj>P17AdL0Hf=S04];B`19BDT0FEUI02d];@0204a<C00404m?C`1DE5@0BTY:03Lg=`80@d=3
03P0@D5105EEE@1?Cdl0AdM7079bLP12@T80C4a<04];B`1HF5P0A4A405aLG01SHf<0IVIV06ATI02<
S8`0DU9B071`L020P800Ng]k08:2PP1fMWH0NGUi05=CD`23Ph<0=SHf05iNGP27QhL0SHf=07UiN@1=
CDd0EEEE04Q8B01SHf<0N7Qh05aLG01;Bd/0I6AT061PH01:BTX0IVIV07alO01iNGT0KFe]04e=C@1G
EeL0CTi>061PH01?Cdl0IFEU0492@P16ATH0E5AD06IVIP1;Bd/0IfMW08J6QP80FUYJ06d0GemO06MW
I`1XJ6P0CDe=069RHP1BDU80KVi^05mOG`1YJFT0IFEU08N7Q`1OGel0I6AT04Y:BP1hN7P0EeMG07Yj
NP2ZZZX0^k^k04i>CP2@T900GUiN05QHF02=SHd0KVi^09ZJVP1fMWH0NWYj07inOP1KFe/0Shn?06EU
I@1WIfL0De=C05YJFP13@d<0BDU90451@@1YJFT0Q8B404e=C@1OGel0Fe]K07]kN`19BDT0D51@03Hf
=P1KFe/0HV9R05eMG@2:RXX0NWYj051@D01/K6`0GemO04e=C@2@T900KFe]05EEE@29RHT06QXJ03Lg
=`1GEeL0E5AD0861P@1JFUX0U9BD06][J`1HF5P0H61P04E5A@1XJ6P0<S8b06QXJ01UIFD0Q8B404a<
C01VIVH0N7Qh04e=C@2KVi/0T92@05eMG@1bLW80N7Qh02d];@0o?cl0De=C04a<C01aLG40D51@05YJ
FP1aLG40X:2P055AD@2b/[80DE5A0492@P21PH40GEeM05aLG01]KFd0IfMW07UiN@1GEeL0IFEU07Ad
M01HF5P0M7Ad0080DE5A03L0D51@06m_K`1BDU80MWIf06i^KP1IFET0VYZJ0820P01RHV80NGUi08^;
R`1LG5`0KVi^07alO01WIfL0IVIV06m_K`1hN7P0PH6107=cL`21PH40JFUY06e]K@2;Rh/0OWin04Y:
BP1GEeL0IfMW06IVIP2LW9`0Bd];08N7Q`1ZJVX0F5QH079bLP13@d<0XZ:R096AT@2[Zj/0QhN7055A
D@1fMWH0MGEe04I6AP28R8P0Ph>309:BTP24Q8@0ADE5075aL@0o?cl0AdM705aLG01eMGD0QhN70080
H61P00L0Hf=S05ADE01gMgL0S8b<06MWI`2@T900YjNW017ooooo000?ooooo`3o07moO`1TI6@0TI6A
09fMW@1HF5P0FEUI05eMG@2f][H0QhN7034a<@1BDU80EeMG04E5A@2QXJ40De=C05IFEP19BDT0<S8b
09JFUP2`/;008b<S03<c<`1^KVh0F5QH08R8R01QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
04U9B@29RHT0CTi>0;fm_@1/K6`0>c/k059BDP21PH40Hf=S07MgM`1]KFd0:2PX06i^KP2EUID0JVYZ
08^;R`2=SHd09BDU03Xj>P15ADD0LG5a0;jn_P1eMGD0<30`05=CD`1PH600JVYZ06ATI02<S8`0:BTY
04a<C01CDe<0<S8b08>3P`1lO7`09BDU03Hf=P14A4@0K6a/051@D01JFUX07alO02DU9@1=CDd0=cLg
04U9B@1fMWH0ATI603De=@1HF5P0DE5A03@d=01eMGD0BDU9030`<01_Kfl0T92@02XZ:P1JFUX0=SHf
069RHP2PX:00QHF502`/;024Q8@0CTi>03`l?01=CDd0H61P0410@01LG5`0?Cdm038b<P1GEeL0YZJV
04m?C`0c<c<0GemO06=SH`2XZ:P0FEUI02l_;`17AdL0FEUI05eMG@2_[jl0][Jf04a<C01=CDd0Ph>3
08:2PP24Q8@0W9bL04I6AP0j>SX0L71`09fMW@23Ph<0Z:RX04=3@`0n?Sh0OWin0;:b/P1RHV80fMWI
05mOG`0h>3P0LG5a061PH02OWil0/;2`0410@00/;2`0Jf][0:BTY01QHF40]KFe04Y:BP0a<C40NWYj
09nOW`1]KFd0^[Zj08R8R00_;bl0?clo07MgM`1LG5`0YJFU09BDU00f=SH0?clo08F5Q@2SXj<0SHf=
0;bl_01CDe<0EeMG0;Bd]02MWId0alO70=oOg`1^KVh0?Shn05eMG@2_[jl0[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0EeMG08b<S02RXZ80NGUi0;Jf]P0];Bd0CDe=08Z:RP3<c<`0Q8B4
09ZJVP0d=3@0T92@0=OGe`2EUID0PX:20861P@1=CDd0@41009FEU@1]KFd0_;bl02l_;`12@T80dm?C
0:ZZZP1=CDd0Y:BT06ATI01GEeL0c/k>07QhN02JVYX0R8R80492@P2FUYH0SXj>0492@P1`L700Lg=c
08j>SP2PX:00DU9B05EEE@1_Kfl0CTi>055AD@1[Jf/0Ng]k0451@@1jNWX0;2`/03Xj>P1IFET0WIfM
08B4Q02ATI40[:b/08B4Q036a/H0R8R803Hf=P1SHf<0H61P04=3@`25QHD0b<S8000P04];B`1>CTh0
L71`075aL@2SXj<0[jn_03lo?`0h>3P0EEEE08b<S02BTY80IFEU02h^;P18B4P0MgMg07]kN`1SHf<0
_;bl05=CD`0];Bd0Cdm?07AdM01@D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:6QX@0W9bL2
04a<C00308>3Pooooooooooo01[ooooo02<0C4a<04e=C@1LG5`0De=C0:6QX@1iNGT0PX:2059BDP0i
>CT0>3Ph07=cL`1JFUX0@41003Ti>@1_Kfl0E5AD05YJFP1<C4`0I6AT04e=C@1:BTX0>CTi02LW9`1?
Cdl0?Cdm04=3@`1HF5P0<c<c04i>CP14A4@0De=C06EUI@19BDT0@d=307=cL`0207emO@0808j>SP1b
LW80C4a<05aLG01@D500=cLg04I6AP1SHf<204I6AP2D05MGE`10@400DU9B04M7A`14A4@0De=C06MW
I`0[:b/0DE5A06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`13@d<0<c<c059BDP1EEED0@T9203<c
<`17AdL0FUYJ09FEU@0i>CT0KVi^09RHV01jNWX0Fe]K04A4A013@d<0FUYJ06m_K`19BDT0CTi>09ZJ
VP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0C4a<02HV9P0^;Rh0?Cdm04M7A`0e=CD0?3`l04E5
A@1ADE40>3Ph02TY:@14A4@0Bd];02TY:@0d=3@0@T9203Ph>00];Bd0<30`03`l?00j>SX0C4a<04=3
@`1>CTh0@d=30492@P1/K6`0QXJ606EUI@0g=cL0=CDe03Lg=`0m?Cd0E5AD06QXJ01YJFT0HV9R05eM
G@1TI6@0?Cdm051@D01nOWh0Ti>C05mOG`2<S8`0;Bd]04i>CP1]KFd0IVIV06EUI@1SHf<0UIFE07in
OP2MWId0Jf][07=cL`1jNWX0J6QX07moO`1UIFD0Cdm?05aLG024Q8@0Ti>C05UIF@2OWil0FUYJ06AT
I01GEeL0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0U9BD04=3@`1XJ6P0N7Qh04E5A@1QHF40M7Ad05iN
GP1dM7@0<30`04I6AP10@400FEUI07QhN01LG5`0QhN707AdM01SHf<0C4a<04=3@`1CDe<08b<S07mo
O`1OGel0E5AD05IFEP1<C4`0DU9B05aLG080I6AT01H0G5aL07MgM`1TI6@0MWIf069RHP1BDU80HF5Q
061PH01dM7@0J6QX07EeM@21PH40Shn?0::RXP0k>c/0CTi>04e=C@1FEUH0ATI605mOG`1WIfL0HV9R
0P1EEED06P1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0j>SX0BTY:06m_K`1^KVh0>3Ph07UiN@1PH600
Fe]K09FEU@1nOWh0E5AD09>CT`29RHT0GUiN08:2PP1DE5@0MgMg069RHP1iNGT0HF5Q0P1DE5@0:@1X
J6P0WinO04e=C@1BDU80Kfm_05mOG`2LW9`0B4Q806=SH`1EEED0EeMG075aL@1hN7P0SXj>06EUI@23
Ph<0aLG5079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM05YJFP0d=3@0BTY:07inOP29
RHT0Shn?071`L01XJ6P0KFe]055AD@20P800Ti>C08^;R`2][Jd0/K6a017ooooo000?ooooo`3o0:^[
Z`1/K6`0KVi^0;Vi^@2HV9P0@T9205IFEP29RHT0a/K605iNGP2][Jd0:b/[04U9B@1UIFD0Rh^;0=OG
e`1/K6`0?Cdm04I6AP1]KFd0GUiN06UYJ@2>SXh0;2`/07AdM02@T900De=C08:2PP1WIfL08b<S05QH
F02WYjL0[Zj^08>3P`0K6a/0@41004a<C01`L700ADE5069RHP1/K6`09bLW051@D01`L700>c/k05UI
F@1;Bd/0BTY:07]kN`2ZZZX0K6a/03<c<`1TI6@0@D5108f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJ
FP2JVYX0ATI604E5A@0m?Cd0A4A407IfMP2<S8`0;Bd]02DU9@0n?Sh0DU9B05eMG@2MWId0=SHf03@d
=01>CTh0ADE5065QH@2k^k/0IfMW02<S8`1HF5P0MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6
AP2ATI40=SHf03De=@1ADE40SXj>055AD@38b<P0Q8B403Ti>@0b<S80I6AT08^;R`2WYjL0BDU9038b
<P1>CTh0N7Qh06EUI@1TI6@0Ti>C038b<P1nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0XZ:R07Ui
N@3<c<`0SXj>03Xj>P1FEUH0QhN708>3P`1CDe<0Ti>C06ATI01DE5@0SXj>09BDU01gMgL0Lg=c03Ti
>@0m?Cd0MgMg0<c<c01nOWh0Rh^;04e=C@10@400TY:B0;Jf]P1FEUH0XZ:R03dm?@1EEED0MWIf0:6Q
X@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/06ATI00Y:BT0MWIf07moO`1_Kfl0MGEe09fM
W@0a<C40=SHf0;Ng]`2;Rh/0RHV90<C4a012@T80?Shn0::RXP2o_kl0EUIF06EUI@1>CTh0C4a<0:^[
Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900?Cdm07inOP1FEUH0Lg=c0<?3``2<S8`0;bl_05eM
G@2DU9@0Rh^;0;Zj^P0e=CD0Cdm?06i^KP1XJ6P0NGUi0;2`/00l?3`0BTY:06e]K@1cLg<0iNGU05IF
EP0[:b/0QXJ609BDU01eMGD0e]KF06MWI`16ATH0T92@07AdM030`<00YjNW02`/;01jNWX0Ng]k06EU
I@2=SHd0IfMW03`l?023Ph<0Kfm_08n?S`2<S8`0=cLg0410@01?Cdl0M7Ad075aL@36a/H0nOWi0>c/
k03Ng]h0kno_0>;RhP3/k>`0WinO05IFEP1`L700e]KF07AdM02i^KT0FUYJ04I6AP1JFUX0IfMW000S
08Z:RP23Ph<0CTi>03Hf=P1GEeL0QHF506ATI01fMWH0XZ:R030`<01ADE40UiNG069RHP2FUYH0UIFE
0451@@1ADE40YjNW0;jn_P12@T80Hf=S05=CD`11@D40PX:20:n_[`1UIFD0BTY:08:2PP10@400?Shn
06IVIP10@400@T9205UIF@0n?Sh07?ooool0I019BDT0DU9B09>CT`1PH600][Jf0492@P1FEUH0KFe]
04A4A01ADE40C4a<04Q8B019BDT0Bd];05QHF00m?Cd0Hf=S06e]K@1RHV80Fe]K04Y:BP1?Cdl0<c<c
04E5A@0_;bl0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0f=SH0IFEU061PH01DE5@0EeMG
05QHF01DE5@0Jf][05]KF`1>CTh0@d=305=CD`1MGEd0Fe]K05mOG`0O7al0J6QX05iNGP1ADE40<S8b
03<c<`18B4P0AdM702h^;P0j>SX0AdM704m?C`1DE5@0Fe]K051@D018B4P0>c/k04e=C@1;Bd/0?clo
04M7A`22PX80Jf][0820P015ADD0@T9206YZJP1jNWX0LW9b061PH01UIFD0?3`l08b<S01JFUX0IfMW
07emO@1hN7P0Q8B4051@D01FEUH0I6AT05aLG01ADE40DU9B03Ti>@15ADD0BTY:05YJFP18B4P0I6AT
04];B`1UIFD20492@P0604E5A@1@D500C4a<04M7A`0n?Sh0ATI60P17AdL0>01;Bd/0EEEE075aL@1L
G5`0Hf=S05UIF@1DE5@0I6AT055AD@18B4P0ATI603dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn0492@P1ADE40UIFE0820P01DE5@0T92@02DU9@0m?Cd0I6AT05UIF@2`/;00ATI604E5A@12
@T80B4Q803De=@0U9BD0LG5a08:2PP1dM7@0B4Q808J6QP1OGel0Kfm_069RHP1HF5P0ZZZZ05UIF@1Y
JFT0A4A405=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0P1@D500NP1RHV80RXZ:04e=C@1mOGd0KFe]04Y:
BP2CTi<0N7Qh03lo?`1@D500De=C07AdM01fMWH0QXJ608R8R01MGEd0Hf=S07IfMP2=SHd0KVi^07]k
N`1jNWX0JVYZ06e]K@1<C4`0EeMG04Q8B01cLg<0GemO04m?C`2:RXX0MgMg04=3@`17AdL0E5AD061P
H01bLW80Ph>3061PH021PH40WinO08V9R@2SXj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0K6a/051@
D016ATH0J6QX07QhN01RHV80MGEe06EUI@1>CTh0ATI605eMG@10@400MgMg07EeM@16ATH0UIFE07Yj
NP10@400KFe]079bLP13@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@1hN7P0LW9b05=C
D`23Ph<0R8R805IFEP1NGUh0QXJ609jNWP3Ng]h0BDU906i^KP1=CDd0De=C06][J`0m?Cd0Kfm_05iN
GP1gMgL0H61P05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY07QhN01<C4`0Bd];07]k
N`25QHD0U9BD075aL@1mOGd0IfMW051@D02BTY80MgMg079bLP2;Rh/0Q8B44Oooool000oooooo01<0
N7Qh0:BTY01/K6`0K6a/09:BTP1_Kfl0?Shn09ZJVP1<C4`0EUIF071`L028R8P0=CDe06MWI`0_;bl0
KVi^08Z:RP0b<S80>3Ph0080CDe=02L0OWin09JFUP10@400@T9207MgM`1JFUX0[:b/09nOW`0Y:BT0
9RHV06=SH`2FUYH0/;2`05=CD`0V9RH0HF5Q075aL@1?Cdl0XJ6Q09>CT`0X:2P0:RXZ06ATI01]KFd0
^k^k05ADE00`<300BDU908J6QP1nOWh0L71`0:VYZ@0i>CT0K6a/09>CT`1YJFT0KVi^05eMG@0X:2P0
0P1CDe<0D@1`L700Xj>S03Ph>00T92@0C4a<05iNGP1KFe/0H61P0:j^[P0i>CT0?clo09FEU@1lO7`0
Ti>C0:RXZ00R8R80?clo079bLP2ATI40IVIV09fMW@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0
820P06i^KP2ATI40HV9R07emO@0W9bL0?Cdm051@D02CTi<0GUiN05mOG`1>CTh0@T9209JFUP2SXj<0
Bd];08f=S@1>CTh0=cLg0410@023Ph<0B4Q804m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0
FUYJ09nOW`2a/K40@41004U9B@1]KFd0?clo06EUI@3@d=00`<3005MGE`2;Rh/0?clo06e]K@3@d=00
KVi^03/k>`1kNg/0I6AT05iNGP2WYjL0Fe]K04I6AP0204i>CP1L08f=S@3=cLd0P820030`<01EEED0
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0MgMg01lO7`1SHf<0Lg=c07AdM02GUiL0
jn_[04Q8B00W9bL0NGUi0;Bd]02VYZH0m?Cd04e=C@1CDe<0E5AD0:FUY@2QXJ40[jn_05aLG01KFe/0
Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q02IVIT0]KFe028R8P1;Bd/0Q8B40<S8b01gMgL0
bl_;069RHP0g=cL0Vi^K07MgM`2FUYH0[Zj^03<c<`0o?cl0Y:BT0820P01XJ6P0JFUY03/k>`33`l<0
aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7071`L01=CDd0>SXj06i^KP2e]KD0OGem07QhN01JFUX0
?clo07EeM@1mOGd0H61P05iNGP0O7al0FEUI0861P@1kNg/0>3Ph07alO018B4P204E5A@0c04Q8B01b
LW80L71`05]KF`2>SXh0^[Zj09NGU`1BDU80MgMg04Y:BP1FEUH0VYZJ07]kN`0g=cL0EeMG06][J`1E
EED0SXj>09FEU@0Z:RX0IFEU05eMG@1<C4`0O7al0<[:bP1RHV80A4A4059BDP12@T80NGUi0<o?c`1l
O7`0;Rh^05YJFP28R8P0J6QX07QhN00e=CD0=3@d04m?C`1nOWh0WYjN09FEU@2c/k<0?Shn03Ti>@1G
EeL0Hf=S07EeM@2NWYh0@T9201cooooo00`0GEeM04m?C`2QXJ40T92@08>3P`1HF5P0MgMg07]kN`15
ADD0<c<c06ATI01]KFd205MGE`1A06i^KP1<C4`0S8b<092@T029RHT0KVi^04a<C01EEED0;Rh^04U9
B@0n?Sh0@d=306=SH`0e=CD0?Shn04=3@`1YJFT0DE5A06=SH`0k>c/0CTi>05YJFP1KFe/0IFEU05QH
F00c<c<0De=C03lo?`0/;2`0B4Q806YZJP17AdL0>SXj05iNGP0N7Qh0?3`l04Y:BP1WIfL0CTi>06IV
IP0_;bl0@D5104i>CP10@400ADE504a<C011@D40CTi>03Ti>@1EEED0F5QH055AD@10@400F5QH04];
B`1BDU80=CDe05mOG`1ADE40HF5Q071`L01aLG40H61P06YZJP1DE5@0A4A406UYJ@1BDU80Fe]K09jN
WP2<S8`0Hf=S05]KF`1IFET0ADE505=CD`1MGEd0?Cdm03Hf=P1GEeL0?3`l0080>CTi03P0MgMg04M7
A`16ATH0BDU9069RHP0i>CT0E5AD04U9B@1IFET0>CTi04];B`14A4@0AdM703`l?01EEED0Jf][04I6
AP0f=SH0Bd];08B4Q01hN7P0KFe]05]KF`1PH600>3Ph03Ti>@10@400EUIF061PH01]KFd0IfMW0492
@P19BDT0De=C07IfMP3:b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];07AdM01?Cdl0GUiN04U9
B@1cLg<0Fe]K0410@015ADD0@d=306m_K`1QHF40H61P05QHF080SHf=02H0De=C071`L01CDe<0QXJ6
05UIF@1FEUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1?Cdl0A4A407=cL`2=SHd0L71`
08F5Q@1>CTh0DE5A05=CD`1EEED0M7Ad05aLG01oOgl0MWIf04Q8B01FEUH0GEeM08j>SP1OGel0MGEe
06ATI01dM7@0JFUY055AD@80O7al05l0NWYj06e]K@1BDU80KFe]07UiN@1LG5`0F5QH08j>SP1QHF40
NGUi04M7A`1KFe/0MgMg09>CT`1EEED0Ti>C06IVIP1LG5`0L71`069RHP1OGel0IfMW06=SH`1LG5`0
IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1TI6@0CTi>08j>SP1TI6@0FEUI0::RXP1LG5`0
BTY:07emO@1jNWX09BDU05EEE@1TI6@0FUYJ07AdM01iNGT0K6a/06QXJ01RHV80HF5Q069RHP1PH600
KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03/k>`21PH40I6AT07]kN`1nOWh0C4a<09>CT`2UYJD0
YjNW09NGU`1SHf<0NGUi08F5Q@14A4@0P82009RHV02JVYX0OGem04U9B@1RHV80HF5Q0820P01/K6`0
M7Ad07IfMP1>CTh0D51@04e=C@1`L700Kfm_07=cL`25QHD0/;2`0:ZZZP0Aooooo`003oooool0B@1N
GUh0YZJV0;Ng]`20P800EeMG0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG50410@01>
CTh0K6a/05YJFP25QHD0FEUI01<C4`0i>CT0UiNG06=SH`26QXH0C4a<03<c<`1IFET0_Kfm07MgM`1^
KVh0Ogmo0451@@1eMGD0];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Cdm?04M7A`2D
U9@0/k>c04A4A01[Jf/0S8b<04A4A017AdL0UIFE06QXJ01hN7P0I6AT04A4A02<S8`0_kno061PH00k
>c/0HF5Q02`/;01kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0/;2`00P1SHf<0@P2;
Rh/0e]KF038b<P0h>3P0H61P065QH@1SHf<0Shn?02/[:`0/;2`0DU9B06IVIP1NGUh0Rh^;08V9R@0R
8R80?3`l05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0NGUi071`L00j>SX0BDU908:2PP1m
OGd0]kNg07EeM@0Y:BT0DE5A061PH01JFUX0WIfM04Y:BP0S8b<0F5QH061PH01YJFT0K6a/08>3P`0e
=CD0PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0=3@d06i^KP31`L40OGem0;Ng]`1GEeL0Hf=S092@T03J
f]X0MGEe0<O7a`19BDT0@T9207moO`80P82009<0Rh^;03Ti>@0_;bl0Ph>30;>c/`1HF5P0Lg=c055A
D@19BDT0PX:20:VYZ@1>CTh0Kfm_061PH014A4@0HF5Q0:n_[`1FEUH0QhN7079bLP0e=CD0De=C05iN
GP26QXH0EUIF08b<S014A4@0Hf=S09:BTP3Jf]X0UiNG0;Jf]P1bLW80?Shn092@T02KVi/0RHV908:2
PP0f=SH0P8200;bl_02c/k<0Bd];0820P01SHf<0HF5Q0<W9b@1dM7@0Bd];05QHF01;Bd/0?3`l0;jn
_P2TY:@0=3@d061PH01XJ6P0Rh^;0<;2`P1UIFD0@D510;fm_@1JFUX0O7al09NGU`0m?Cd0J6QX08Z:
RP2<S8`0][Jf051@D00`<300NGUi07]kN`2SXj<0Rh^;03Hf=P1<C4`0PH6106=SH`2a/K40X:2P01/K
6`0f=SH0Ng]k0:j^[P2;Rh/0;2`/03dm?@1WIfL0YJFU05UIF@2OWil0I6AT034a<@0i>CT0?Cdm02/[
:`1?Cdl0QHF507alO02/[:`0^[Zj09RHV037alL0?Shn0451@@2CTi<0Ph>304a<C02<S8`0RXZ:024Q
8@1HF5P0VYZJ04];B`2YZJT0FEUI03dm?@0l?3`0Rh^;0;>c/`1cLg<0?clo02TY:@1=CDd0P8200:RX
Z01/K6`0V9RH04a<C016ATH0H61P08:2PP0n?Sh0JFUY08Z:RP0S8b<0H61P09bLW01kNg/0CTi>07Mg
M`0c<c<0EeMG07EeM@1bLW807?ooool0LP1[Jf/0C4a<0:FUY@1ZJVX0Jf][06QXJ01gMgL0P82006YZ
JP0m?Cd0KVi^061PH01DE5@0ADE5061PH014A4@0Cdm?04a<C01IFET0I6AT065QH@1BDU80>3Ph059B
DP1:BTX0ATI606YZJP0o?cl0De=C03dm?@1cLg<0Ng]k06ATI015ADD0EUIF05YJFP1^KVh0LG5a071`
L01>CTh0MgMg0492@P0o?cl0GemO05]KF`1@D500Fe]K071`L00Y:BT0K6a/07AdM02@T900DE5A07Ui
N@0c<c<0G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj04e=C@1HF5P0@d=304i>CP14A4@0Bd];03dm
?@19BDT0F5QH09BDU011@D40MgMg08j>SP2EUID0G5aL04m?C`1CDe<0F5QH08b<S01EEED0F5QH0:ZZ
ZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0EUIF034a<@12@T80Bd];03/k>`18B4P0BDU904A4
A01BDU80A4A403<c<`0l?3`0BTY:03@d=01<C4`0<C4a0492@P0n?Sh0=3@d04=3@`1GEeL0Fe]K0410
@080BTY:0680IfMW06i^KP1lO7`0ADE505mOG`0P8200BTY:04e=C@1JFUX0H61P03/k>`16ATH0Cdm?
05mOG`0b<S80?Cdm09bLW02CTi<0Hf=S065QH@0];Bd0E5AD0;bl_00j>SX0Q8B403`l?028R8P0?Shn
05YJFP0m?Cd0;Bd]06ATI02@T900?3`l0451@@1YJFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A
06YZJP1jNWX0;2`/05MGE`1=CDd0BTY:0<c<c02@T900>CTi03`l?01RHV80ATI607UiN@1^KVh0Ng]k
07EeM@0X:2P0>CTi059BDP28R8P0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40OWin
06m_K`1gMgL0Rh^;08J6QP25QHD0H61P0:JVYP1eMGD0A4A4071`L02<S8`0MgMg06ATI01iNGT0Jf][
0820P01SHf<0IfMW09FEU@38b<P0CTi>08:2PP1OGel0Lg=c07alO080B4Q804X0Hf=S05IFEP1YJFT0
DE5A05aLG01eMGD0E5AD061PH01eMGD0FUYJ04U9B@2BTY80HF5Q05]KF`1>CTh0HV9R092@T01NGUh0
G5aL0:6QX@1CDe<0?3`l06ATI01cLg<0KVi^06e]K@1DE5@0HF5Q07emO@1eMGD0KFe]07=cL`1UIFD0
YjNW096AT@1`L700MgMg08J6QP2GUiL0Rh^;04a<C025QHD0GEeM09:BTP2<S8`0DU9B06m_K`1`L700
S8b<09RHV01iNGT0N7Qh0;bl_01mOGd0/[:b0;Jf]P2b/[80V9RH05=CD`1^KVh0<30`04I6AP1KFe/0
P82006YZJP1VIVH0JVYZ05IFEP10@400Q8B406e]K@1XJ6P0/[:b09>CTa7ooooo000?ooooo`290:NW
Y`1GEeL0MGEe0;Vi^@27QhL0AdM704i>CP26QXH0TI6A04M7A`1nOWh0@D510492@P1^KVh0GemO04a<
C019BDT0@T9206i^KP1_Kfl08b<S02l_;`1KFe/0CTi>08b<S00h>3P08R8R03dm?@1OGel0KVi^08Z:
RP20P800<30`04A4A01fMWH0LG5a09bLW01CDe<08B4Q03dm?@1fMWH0@T9207inOP1^KVh0?Cdm04E5
A@20P800JVYZ08B4Q02SXj<09bLW05YJFP25QHD0Ogmo0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NW
Y`2FUYH0;Rh^061PH01cLg<0GemO08b<S01HF5P0=3@d03lo?`1mOGd0RHV908N7Q`1dM7@092@T055A
D@2b/[80Rh^;065QH@2_[jl0ATI6020P802NWYh0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05AD
E01gMgL09RHV04=3@`1XJ6P0b<S805ADE01fMWH0@41002XZ:P1[Jf/0P82005EEE@2GUiL0;bl_03<c
<`2DU9@0/k>c05]KF`1@D500NWYj0410@02_[jl0UiNG03hn?P1PH600Jf][04e=C@1mOGd0XJ6Q04M7
A`1GEeL0Fe]K04e=C@1UIFD0J6QX06EUI@1>CTh0IVIV05eMG@1^KVh0[Jf]05MGE`17AdL0Hf=S04Q8
B01ZJVX00P2IVIT06`1?Cdl0NGUi05iNGP2][Jd0WIfM061PH011@D40HF5Q05MGE`0n?Sh0WYjN03lo
?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@07alO01BDU80W9bL0;^k^`0];Bd0C4a<07em
O@0205iNGP1j0<K6aP1MGEd0De=C061PH02MWId0V9RH0<_;b`2NWYh0BDU907QhN027QhL0cLg=0;Ng
]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01UIFD0BDU90:BTY02/[:`0WIfM0<G5a@16ATH0?clo051@
D02^[Zh0S8b<096AT@0T92@0DE5A08b<S02SXj<0O7al0;bl_01IFET0>SXj08Z:RP2BTY80WIfM02d]
;@1DE5@0Shn?08F5Q@2NWYh0WinO04e=C@12@T80cLg=06=SH`2a/K40DE5A04M7A`1WIfL0UiNG04e=
C@1NGUh0CTi>05IFEP2n_[h0OWin06ATI020P800?Shn04I6AP1?Cdl0E5AD07AdM021PH40Z:RX0:b/
[02a/K40Ph>30:JVYP3;bl/0MWIf04I6AP29RHT0IVIV059BDP20P800>SXj034a<@1hN7P0^;Rh05QH
F01:BTX0EUIF0492@P28R8P0Ng]k038b<P11@D40HV9R03/k>`2;Rh/0Hf=S02LW9`0`<300KVi^05mO
G`1VIVH0/k>c08B4Q00Y:BT0DU9B051@D00c<c<0UYJF0<S8b00/;2`071`L06EUI@1`L700FUYJ08b<
S00S8b<0;Bd]04];B`1bLW8Looooo`0<05aLG010@400MgMg06ATI01WIfL0S8b<0::RXP1@D500<C4a
02XZ:P1>CTh0BDU90P1<C4`0101YJFT0=3@d05ADE01YJFT208B4Q00_06ATI01OGel0?3`l04i>CP0o
?cl0=CDe04i>CP0n?Sh0>c/k03@d=01KFe/0ATI605aLG015ADD0GemO04m?C`1>CTh0AdM7061PH01B
DU80Fe]K0492@P10@400DE5A06m_K`1FEUH0GUiN06m_K`0c<c<0P82006YZJP1gMgL0Hf=S06i^KP0d
=3@0CDe=06i^KP1mOGd0QHF505IFEP1;Bd/0S8b<069RHP1HF5P0A4A405eMG@18B4P00P1JFUX0=@1V
IVH0EeMG0;>c/`1>CTh0Lg=c07MgM`1oOgl0KVi^06e]K@1eMGD0>SXj09VIV@1ZJVX0De=C09ZJVP3F
e]H0][Jf05eMG@1eMGD0FUYJ079bLP1`L700I6AT04E5A@1NGUh0MWIf05ADE01IFET0Jf][07=cL`1P
H600HV9R04U9B@1ADE40De=C04A4A01SHf<0@T92055AD@1;Bd/0De=C04e=C@1GEeL0Kfm_04U9B@1E
EED0De=C06a/K01nOWh0L71`0492@P1@D5007AdM0080BTY:0700BDU906EUI@1GEeL0A4A403De=@1<
C4`0Bd];06=SH`29RHT0Ph>307IfMP1nOWh0:b/[04E5A@1[Jf/0J6QX09bLW019BDT0Jf][01/K6`1=
CDd0BDU904M7A`0g=cL0@d=303hn?P0d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0?Shn055AD@0i
>CT0@41002DU9@1NGUh0DE5A03Ph>01]KFd0DU9B03/k>`1>CTh0HF5Q03@d=01UIFD0>c/k051@D01f
MWH0=3@d03Ti>@1;Bd/0CTi>04];B`1YJFT0VYZJ08F5Q@1@D500HF5Q06YZJP1oOgl0C4a<04];B`1c
Lg<0MGEe059BDP13@d<0BTY:03/k>`17AdL0EEEE04Q8B020P800De=C05EEE@11@D40DU9B051@D01l
O7`0DE5A059BDP1LG5`0FUYJ05QHF02XZ:P0DU9B04M7A`1FEUH0AdM7061PH02FUYH0EEEE0451@@1@
D500GEeM059BDP1CDe<0K6a/04a<C014A4@0Cdm?04];B`1@D500O7al05EEE@0/;2`0OGem055AD@1C
De<0Kfm_0P1ZJVX00`2KVi/0PX:204a<C00205]KF`0G069RHP1KFe/0N7Qh079bLP1GEeL0Fe]K09:B
TP1lO7`0DU9B05EEE@1WIfL0[Zj^0>?Sh`1;Bd/0Ng]k04a<C01_Kfl0MWIf08:2PP2KVi/0OGem07mo
O`2b/[800P28R8P01`1lO7`0FUYJ07alO02TY:@0gMgM09:BTP0k>c/00P1JFUX03@1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:061PH01NGUh0PX:206QXJ01kNg/04Oooool000oooooo00`0WYjN
07emO@1GEeL0IfMW0:BTY01ZJVX0B4Q805QHF01@D500Ng]k0;fm_@13@d<203lo?`3T06=SH`2m_Kd0
MWIf03@d=01CDe<0I6AT07YjNP1YJFT0OWin01TI6@1SHf<0alO707UiN@2][Jd0Shn?02DU9@1?Cdl0
Xj>S08B4Q02VYZH07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0RHV905IFEP1oOgl0
@41001hN7P1<C4`0EEEE04i>CP14A4@0NGUi03dm?@1kNg/0Y:BT04m?C`1EEED0A4A403<c<`1ADE40
IVIV05IFEP1OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0LW9b04A4A01iNGT0QHF503De=@0h>3P0
F5QH03<c<`1KFe/0]KFe05mOG`0W9bL0D51@06IVIP1XJ6P0clo?05eMG@0g=cL0CTi>05YJFP1:BTX0
NWYj03lo?`0^;Rh0AdM705MGE`2>SXh0]kNg069RHP0N7Qh0=SHf06UYJ@1`L700bLW906MWI`0H61P0
>c/k08N7Q`1QHF40RXZ:0:RXZ00h>3P0GEeM08>3P`1VIVH0ZZZZ0861P@0d=3@0B4Q807AdM02:RXX0
[Jf]071`L00n?Sh0NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0A4A40;Vi^@2?Shl0VIVI0:VYZ@0`<300
@d=3071`L02g]kL0PX:20:NWY`10@400EUIF092@T02ZZZX0L71`0;Fe]@1OGel0?Cdm06UYJ@2ZZZX0
Ng]k0<K6aP15ADD0?clo0861P@2e]KD0NWYj07emO@1CDe<0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0L71`08B4Q029RHT0:BTY06MWI`1PH600T92@06MWI`25QHD0Cdm?08F5Q@3Ti>@0
YjNW06EUI@27QhL0BDU903Lg=`20P800`L7106][J`20P800=CDe04i>CP1`L700XJ6Q059BDP26QXH0
@T9204];B`2a/K40?3`l05QHF02;Rh/0BDU906EUI@3?cll0OGem04A4A01kNg/0IVIV0;Zj^P1^KVh0
@d=309bLW01MGEd0QhN70;Vi^@1JFUX0@d=308:2PP1JFUX0_[jn08^;R`0U9BD0IfMW06ATI011@D40
Q8B407UiN@0[:b/0OWin05QHF01oOgl0^KVi03De=@1HF5P0/K6a06e]K@20P800^k^k09bLW02GUiL0
^;Rh0P2LW9`08@3IfMT0Rh^;04i>CP1XJ6P0CDe=05iNGP2k^k/0H61P02<S8`19BDT0WinO051@D01W
IfL0;bl_03Xj>P1RHV80[Zj^06YZJP2<S8`0P82003dm?@1>CTh0P82006m_K`22PX80QXJ604];B`11
@D40MgMg09^KV`1>CTh0PX:202d];@0203<c<`0;08n?S`27QhL0MGEe0:6QX@0h>3P0?clo05EEE@1J
FUX0J6QX07inOP0_;bl07?ooool0>017AdL0ATI60861P@1>CTh0Bd];04i>CP1IFET0NWYj06][J`0R
8R80DE5A05mOG`1^KVh0J6QX06][J`0e=CD0H61P07]kN`1ZJVX0E5AD04E5A@1OGel0?Cdm05=CD`12
@T80@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1>CTh0EEEE06=SH`1QHF40EeMG06UYJ@0[
:b/0DU9B03dm?@0l?3`0A4A405]KF`1<C4`0A4A405MGE`0Y:BT0D51@05QHF01PH600JVYZ06=SH`0f
=SH0?clo0P16ATH0;@19BDT0F5QH05UIF@1FEUH0CTi>04Y:BP10@400G5aL05mOG`1<C4`0BTY:07Mg
M`1WIfL0QHF505MGE`1aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0VYZJ07inOP1fMWH0TY:B09bL
W027QhL0IVIV05QHF017AdL0Fe]K065QH@1@D500=cLg05aLG00n?Sh0>c/k04=3@`1cLg<0C4a<03hn
?P15ADD0CDe=0410@00204M7A`1>05IFEP13@d<0@41004m?C`1>CTh0A4A4051@D01_Kfl0G5aL05UI
F@1<C4`0Ogmo07inOP1oOgl0EEEE06=SH`0c<c<0C4a<05]KF`1CDe<0QHF505eMG@1EEED0@T9206EU
I@1KFe/0ADE507AdM02XZ:P0XJ6Q0;Ng]`0c<c<0Jf][0:2PX02=SHd0Xj>S06i^KP1OGel06ATI055A
D@1cLg<0OGem04Q8B01KFe/0ATI602TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][04M7
A`18B4P06ATI06YZJP1IFET0:2PX08N7Q`1XJ6P0@D5106EUI@0k>c/0>CTi07QhN01:BTX0De=C051@
D00L71`08B4Q04M7A`19BDT0LW9b04e=C@1GEeL0DE5A0P1BDU807@0k>c/0G5aL03Ph>02<S8`0AdM7
05aLG011@D40H61P06i^KP0n?Sh0GEeM05MGE`17AdL0LG5a06i^KP1dM7@0J6QX0;Rh^01FEUH0KFe]
03De=@1RHV80MgMg07YjNP0h>3P0JVYZ05mOG`1>CTh0GUiN0080>3Ph04X0Bd];04E5A@1CDe<0LG5a
06=SH`1ZJVX0C4a<07IfMP1EEED0?Cdm061PH01KFe/0@d=308^;R`1RHV80ATI608^;R`1LG5`0AdM7
06IVIP1eMGD0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075aL@1VIVH0MWIf06ATI01BDU80MgMg
0;:b/P1_Kfl0LW9b09^KV`1_Kfl0Fe]K04I6AP1kNg/0F5QH08V9R@1SHf<0>c/k06][J`1jNWX0L71`
07IfMP2ATI40];Bd09JFUP1IFET0MWIf08Z:RP26QXH0S8b<05ADE01OGel0>CTi055AD@1YJFT0VIVI
07UiN@16ATH0De=C05QHF01UIFD0RHV909NGU`20P800VYZJ09FEUA7ooooo000?ooooo`0a075aL@2Y
ZJT0Y:BT08N7Q`1WIfL0Shn?08j>SP2h^;P0>SXj04A4A025QHD0KVi^05eMG@1oOgl0;Bd]06=SH`2S
Xj<0GemO06UYJ@0m?Cd0BTY:08^;R`2CTi<0F5QH04A4A00n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o
?cl0ATI60:BTY014A4@0=CDe05aLG00n?Sh0<30`09RHV035aLD0>3Ph03Lg=`1LG5`0H61P0=SHf02[
Zj/07AdM03De=@0205IFEP2107AdM03;bl/0>CTi059BDP2JVYX0N7Qh09BDU01FEUH0<C4a0492@P1M
GEd0JVYZ0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE50410@02PX:00LG5a08^;R`2T
Y:@0?clo02l_;`24Q8@0Y:BT06a/K02ATI40=cLg04=3@`1RHV80Jf][0861P@2n_[h0Jf][030`<01N
GUh0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0LG5a02/[:`1_Kfl0[Jf]065QH@26
QXH0M7Ad04I6AP19BDT0YJFU05mOG`2MWId0A4A402TY:@24Q8@0YZJV04e=C@1KFe/0LW9b04m?C`2@
T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi^@1oOgl0MGEe03`l?01RHV80c/k>09jNWP12
@T80Q8B405iNGP12@T80WinO05iNGP17AdL0Jf][0492@P1]KFd0U9BD08F5Q@0k>c/0EeMG05UIF@24
Q8@0`<300::RXP13@d<0@T9206e]K@1WIfL0SHf=08N7Q`0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j
>SX0<C4a07=cL`1]KFd0Vi^K0<o?c`17AdL0>SXj08N7Q`1cLg<0HV9R0:VYZ@1_Kfl0?clo0080YJFU
0240Ti>C0;Jf]P14A4@0>CTi04a<C02IVIT0QXJ608Z:RP0R8R80ATI605EEE@1lO7`0N7Qh0=;BdP1^
KVh0;2`/096AT@1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`08B4Q01JFUX0JFUY0;:b/P1l
O7`0c<c<03Lg=`14A4@00P3;bl/0B@2IVIT0Ogmo055AD@1?Cdl0W9bL05ADE02TY:@0GEeM03hn?P1l
O7`0TI6A069RHP1aLG40:b/[03Lg=`29RHT0QXJ606ATI038b<P0A4A402PX:00j>SX0FEUI06m_K`1G
EeL0HV9R08^;R`27QhL0RHV9059BDP27QhL0;Rh^07AdM027QhL0MgMg04=3@`1lO7`0Vi^K04M7A`2;
Rh/0IFEU03Lg=`1HF5P0BDU904m?C`20P800`l?3061PH01;Bd/0@41004M7A`1]KFd0ZJVY08f=S@13
@d<0DE5A04Y:BP19BDT0JVYZ02l_;`0S8b<0B4Q804m?C`1ADE40D51@0:6QX@1XJ6P0;Rh^05]KF`1F
EUH0HV9R09^KV`1>CTh07?ooool04019BDT0@T920820P01NGUh0HV9R07EeM@25QHD0IVIV04=3@`0N
7Qh0BDU904i>CP1@D500@d=305EEE@0j>SX205mOG`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU904Y:
BP15ADD0Fe]K02h^;P1CDe<0>c/k06ATI01MGEd0FUYJ04i>CP1KFe/0MgMg08F5Q@1iNGT0JFUY02h^
;P1NGUh0Bd];03<c<`1FEUH0MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0DE5A02LW
9`0o?cl0EEEE069RHP1^KVh0CDe=03De=@1XJ6P0EeMG059BDP0o?cl0De=C055AD@1DE5@0CDe=04m?
C`1GEeL0Rh^;03`l?02CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP1EEED0[Jf]0=CD
e02/[:`0BDU906UYJ@1GEeL0GEeM05UIF@1KFe/0>SXj05YJFP18B4P0>SXj03/k>`1CDe<0C4a<04Q8
B012@T80@41003/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:04m?C`1QHF40>c/k059B
DP1=CDd0DE5A05mOG`1_Kfl0EUIF06m_K`0c<c<0HV9R05YJFP1>CTh0MWIf07EeM@1LG5`0@T9205IF
EP1CDe<0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0[Jf]05eMG@29RHT0G5aL05QH
F01]KFd0C4a<055AD@1PH600BTY:03dm?@1FEUH0BTY:08J6QP1iNGT0C4a<05eMG@1>CTh0GUiN04I6
AP1ADE40>CTi06][J`1aLG40FUYJ08j>SP1^KVh0Bd];0451@@1XJ6P0De=C08N7Q`1@D500De=C05]K
F`0i>CT0ATI6065QH@1SHf<0X:2P07UiN@2:RXX0Hf=S06QXJ01iNGT0@T92055AD@0[:b/0DU9B05QH
F01XJ6P0FEUI03dm?@19BDT0@D5109RHV01@D500:2PX06i^KP2;Rh/0NGUi05ADE01IFET0F5QH08>3
P`0f=SH0ADE506m_K`2g]kL0Fe]K07AdM01=CDd0Hf=S08Z:RP15ADD0@d=3061PH01JFUX0JVYZ04E5
A@1WIfL0RHV905aLG01_Kfl0JFUY04a<C01VIVH0I6AT05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];
B`1_Kfl0L71`05MGE`1gMgL0KFe]0820P027QhL0E5AD065QH@1aLG40Hf=S06e]K@2EUID0LW9b07Qh
N02WYjL0W9bL09nOW`2d];@0Xj>S0;Vi^@10@400SXj>051@D01OGel0IFEU04m?C`1dM7@0Ti>C07in
OP25QHD0K6a/08V9R@2d];@0HV9R09>CT`2MWId0`<30000508n?S`13@d<0KVi^04=3@`1CDe<00P1R
HV8207EeM@0805iNGP18B4P0A4A408F5Q@2a/K40TI6A0:JVYP2=SHdAooooo`003oooool0`@1^KVh0
GemO07MgM`2UYJD0E5AD04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069RHP2KVi/0eMGE0410@01<C4`0
Lg=c06m_K`2ZZZX0=cLg02XZ:P12@T80WYjN08>3P`1YJFT0<C4a04M7A`0o?cl0Zj^[0:2PX02b/[80
QHF501HF5P1FEUH0MWIf06YZJP2PX:00>3Ph03Lg=`0d=3@0Lg=c05mOG`1^KVh0Bd];03De=@18B4P0
T92@05eMG@1UIFD0GEeM01hN7P1:BTX0M7Ad079bLP25QHD0>SXj030`<01EEED0RXZ:05IFEP1JFUX0
M7Ad03/k>`1YJFT0XJ6Q04M7A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@1DE5@0G5aL02@T901GEeL0
XJ6Q05UIF@15ADD0GEeM04E5A@0c<c<0RHV90451@@1@D500IFEU02`/;00k>c/0JFUY0:j^[P15ADD0
CTi>05=CD`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B0820P010@400De=C06i^KP17AdL0
MgMg08F5Q@0e=CD0>c/k05iNGP1ADE40ZJVY069RHP0[:b/0D51@07emO@1:BTX0VYZJ09>CT`0l?3`0
C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0[Zj^0;Bd]00k>c/0>3Ph07QhN02MWId0
Ogmo0<[:bP1_Kfl0?3`l07MgM`1mOGd0TY:B0;^k^`0`<300>SXj08n?S`2^[Zh0K6a/0:f][@19BDT0
De=C08V9R@3De=@0IFEU09ZJVP1hN7P0@d=307AdM02^[Zh0EEEE0=?Cd`1]KFd0:2PX061PH035aLD0
Rh^;06QXJ02^[Zh0F5QH08J6QP36a/H0`<3006UYJ@3>c/h0CDe=05MGE`1mOGd0Z:RX07inOP22PX80
@T9209>CT`37alL0^[Zj06=SH`1iNGT0D51@071`L03=cLd0MgMg059BDP2][Jd00P1<C4`0G`2l_;`0
[Zj^05QHF01kNg/0D51@08n?S`38b<P0QHF505]KF`1`L700@d=304i>CP2?Shl0B4Q807UiN@1BDU80
MWIf0<S8b02:RXX0>c/k07EeM@1@D500T92@09>CT`15ADD0N7Qh06UYJ@1?Cdl0a/K60;Jf]P0[:b/0
De=C08Z:RP27QhL0UYJF02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^04A4A00O7al08b<S03De=@0c<c<0
>CTi03hn?P0a<C40KVi^09^KV`1hN7P0_[jn03`l?015ADD0V9RH0;Bd]01DE5@0Y:BT0<G5a@1GEeL0
IVIV07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0T92@04M7A`0^;Rh0G5aL04e=C@1jNWX0
G5aL0;2`/016ATH0:BTY069RHP1QHF40E5AD092@T01_Kfl08b<S03lo?`1@D500IfMW05ADE01[Jf/0
9bLW04m?C`2LW9`0NGUi01cooooo07/0ATI604E5A@1mOGd0DU9B06][J`1>CTh0De=C06][J`1ADE40
;2`/06m_K`1YJFT0FUYJ04a<C021PH40LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c05=CD`1LG5`0
De=C055AD@1jNWX0D51@0410@00o?cl0@D5104Y:BP1IFET0Bd];05mOG`1dM7@0KFe]05EEE@1bLW80
:2PX05eMG@0c<c<0:2PX0492@P1?Cdl0Bd];04m?C`1GEeL09BDU06i^KP1UIFD0Vi^K05ADE01iNGT0
:b/[04U9B@1fMWH0@T9205QHF01:BTX0?3`l05YJFP1?Cdl0DU9B03Xj>P1IFET0IfMW04e=C@16ATH0
Ph>308V9R@2i^KT0D51@06QXJ01lO7`0ZJVY07MgM`27QhL0OGem05UIF@1RHV80Jf][08>3P`2OWil0
m?Cd0:RXZ01<C4`0MgMg07AdM01]KFd0JFUY06EUI@0i>CT0GemO06][J`1BDU80CTi>071`L01aLG40
EeMG05YJFP12@T80EEEE079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80E5AD06UYJ@1CDe<0
IFEU04m?C`1SHf<0MWIf07YjNP1KFe/0IFEU03Ph>011@D400P1<C4`06P1WIfL0ATI604e=C@19BDT0
H61P04E5A@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1eMGD0LG5a092@T01YJFT0
Xj>S07alO01HF5P0J6QX07EeM@12@T80EeMG0P1IFET0E@2HV9P0P82007QhN02EUID0KFe]06m_K`23
Ph<0PH6104];B`2EUID0P82003Xj>P2a/K40UIFE03<c<`1EEED0GEeM05ADE01oOgl0FUYJ05]KF`1W
IfL0G5aL03lo?`11@D40Bd];03lo?`1VIVH0Z:RX0820P00m?Cd0EUIF05aLG021PH40CTi>0861P@1n
OWh0NGUi05=CD`17AdL0Cdm?03De=@1?Cdl0E5AD03@d=01VIVH0Jf][075aL@0c<c<0EUIF04m?C`1j
NWX0BDU906EUI@1LG5`0OGem04E5A@2=SHd0<c<c04Q8B01ADE40CDe=03hn?P1`L700H61P06QXJ01D
E5@0JFUY079bLP1]KFd0JVYZ07IfMP1VIVH0GEeM096AT@1TI6@0R8R805iNGP1PH600RHV905IFEP1?
Cdl0Q8B408R8R01UIFD00P2@T900<P1PH600IfMW09>CT`1dM7@0G5aL06YZJP1bLW80LG5a05aLG02B
TY80WIfM05mOG`1NGUh0SHf=0:6QX@31`L40>3Ph0:2PX010@400IVIV061PH01aLG40Vi^K0820P02:
RXX0[:b/09>CT`2b/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>071`L019BDT0GEeM07QhN02>
SXh0PH6107=cL`26QXH0GemO051@D02TY:@0RXZ:09:BTP37alL0Vi^K4Oooool000oooooo0480b/[:
06MWI`1SHf<0]kNg09:BTP1;Bd/0D51@07AdM02:RXX0V9RH0:j^[P0f=SH0<c<c06i^KP2MWId0SHf=
04i>CP11@D40A4A407IfMP0e=CD0HF5Q06ATI01;Bd/0EUIF06QXJ00i>CT0KFe]038b<P0n?Sh0Fe]K
09RHV01<C4`0@d=30451@@1?Cdl0TY:B08^;R`0c<c<0GUiN04E5A@18B4P0HV9R07EeM@0d=3@0GUiN
04];B`1KFe/0R8R80;bl_00m?Cd0;2`/07alO01WIfL0];Bd07UiN@0a<C40>SXj051@D01NGUh0NGUi
07EeM@0c<c<0@D5107QhN01IFET207emO@0602PX:00d=3@0<c<c08R8R02SXj<0TI6A0P0i>CT0H01<
C4`0HV9R08:2PP2FUYH0?clo02DU9@1CDe<0F5QH0861P@3?cll0<30`038b<P10@400HV9R061PH02K
Vi/092@T04e=C@19BDT0Q8B407=cL`2DU9@0QhN702HV9P1@D500IFEU04];B`26QXH0=SHf034a<@1S
Hf<0S8b<06=SH`22PX80OWin04M7A`1gMgL0[jn_06=SH`2SXj<0MgMg034a<@11@D40OGem06EUI@1n
OWh0Ogmo04=3@`1BDU80Hf=S079bLP1MGEd0PX:204M7A`1>CTh0RHV90861P@1[Jf/0XJ6Q04Q8B011
@D40Z:RX0<g=c@1TI6@0QXJ604];B`1EEED0`L710<K6aP1IFET0MGEe05aLG019BDT0N7Qh06=SH`1G
EeL0Ogmo051@D01IFET0IfMW07inOP12@T80HF5Q05aLG01:BTX0`L710:6QX@0j>SX0@41006IVIP13
@d<0LW9b0:FUY@15ADD0BTY:05EEE@80FEUI05X0^k^k06m_K`10@400De=C079bLP2WYjL0]kNg03lo
?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0a<C40RHV906YZJP2<S8`0iNGU08:2PP0];Bd0C4a<09bL
W01TI6@0^[Zj02XZ:P1^KVh0O7al079bLP2IVIT0g]kN05QHF00Y:BT0VYZJ08J6QP2MWId0?clo03dm
?@2=SHd0YZJV07UiN@2WYjL0@D5105mOG`31`L40QHF509bLW01[Jf/0;2`/065QH@2f][H0L71`09RH
V01SHf<0@T920:f][@2?Shl0GemO092@T00[:b/0?Cdm06ATI01ZJVX0IfMW09VIV@3]kNd0d];B0:n_
[`1IFET0IFEU0:6QX@1IFET0Cdm?06YZJP1>CTh0E5AD0:RXZ01SHf<0A4A405eMG@1`L700GemO08B4
Q00o?cl0=SHf06YZJP1]KFd0?3`l061PH02DU9@205aLG00H069RHP0c<c<0CDe=0861P@18B4P0DU9B
09FEU@2l_;`0>SXj05IFEP0o?cl0B4Q808N7Q`2^[Zh0E5AD03`l?027QhL0>SXj04i>CP1YJFT0>3Ph
04Q8B01jNWX0EUIF7?ooool204E5A@2?0:b/[01aLG40JFUY05MGE`1NGUh0QXJ60820P01HF5P0Bd];
05]KF`1HF5P0B4Q805aLG00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1:BTX0AdM7
06i^KP0m?Cd0>SXj02l_;`1bLW80D51@06YZJP1IFET0H61P07=cL`1MGEd0E5AD06=SH`0m?Cd0C4a<
038b<P0/;2`0?clo05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE065QH@16ATH0F5QH
05aLG01:BTX0GEeM05QHF01ADE40De=C051@D01RHV80GUiN06m_K`1JFUX0P82005IFEP1GEeL0FUYJ
08J6QP1LG5`0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1mOGd0Bd];06i^KP2RXZ80OWin
06][J`1KFe/0D51@06QXJ01WIfL0DE5A03Xj>P1ZJVX0>3Ph0492@P0n?Sh0Ogmo04m?C`0k>c/0?clo
05IFEP0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1BDU80BDU903/k>`1YJFT0I6AT03/k>`19BDT0AdM7
05mOG`1SHf<0GEeM065QH@1^KVh0BDU906QXJ01RHV80?3`l06UYJ@1OGel0CTi>04E5A@1OGel0H61P
04=3@`21PH40M7Ad04m?C`2[Zj/071`L04E5A@1fMWH0BDU907]kN`13@d<0EeMG04a<C01cLg<00P1F
EUH0S`2@T900TY:B05ADE01>CTh0NGUi05EEE@2ZZZX0JVYZ055AD@1/K6`0IFEU06=SH`12@T80Bd];
02d];@1kNg/0GemO03lo?`23Ph<0LG5a05EEE@1_Kfl0NGUi03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A4
02HV9P1:BTX0De=C06IVIP1YJFT0MgMg06ATI01;Bd/0Cdm?03hn?P1SHf<0@d=306m_K`1:BTX0IVIV
0410@01UIFD0JVYZ02DU9@2@T900DU9B03`l?01XJ6P0P82008^;R`1OGel0Q8B404i>CP1RHV80>c/k
07UiN@1fMWH0QXJ604a<C01iNGT0BTY:04e=C@1TI6@0ATI6069RHP23Ph<0IFEU05mOG`1ADE40Kfm_
07inOP1IFET0KVi^06][J`1QHF40G5aL069RHP1BDU80SHf=03Ph>00e=CD0VIVI03Lg=`1;Bd/0RXZ:
07MgM`1VIVH0PH61069RHP1QHF40KFe]05=CD`1YJFT0M7Ad07QhN023Ph<0R8R806=SH`1ZJVX0Ogmo
06UYJ@1dM7@0Zj^[0=_Kf`3_knl0@4100:6QX@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0]kNg
08>3P`24Q8@0Shn?06e]K@2EUID0XJ6Q0;Vi^@2g]kL0EUIF069RHP1TI6@0MgMg05aLG02DU9@0OWin
05]KF`1CDe<0LG5a06EUI@1^KVh0MWIf08R8R02HV9P0XJ6Q017ooooo000?ooooo`3o07EeM@2KVi/0
Ph>3061PH01UIFD0MgMg06a/K01^KVh0=SHf04Q8B01_Kfl0DU9B05MGE`1eMGD0>SXj06YZJP23Ph<0
Fe]K06UYJ@10@400De=C07MgM`2YZJT0J6QX04a<C00m?Cd0FEUI08j>SP27QhL0AdM703lo?`1KFe/0
E5AD08:2PP0n?Sh0E5AD061PH018B4P0E5AD08f=S@2CTi<0:b/[04U9B@1FEUH0Fe]K0:j^[P1WIfL0
?clo055AD@1SHf<0FUYJ071`L02>SXh0>3Ph04I6AP1YJFT0J6QX09BDU01PH6009BDU03lo?`1<C4`0
GemO0;Zj^P0b<S80820P05]KF`1lO7`0MGEe07QhN02i^KT0<30`04e=C@23Ph<0NGUi08B4Q02][Jd0
;2`/03hn?P1jNWX0S8b<069RHP22PX80<30`0410@027QhL0QHF507emO@2>SXh0@41003Ph>01eMGD0
NGUi04];B`2IVIT0IVIV038b<P1JFUX0KVi^04m?C`1OGel0Hf=S04];B`1gMgL0O7al0451@@1bLW80
IfMW03@d=01IFET0QhN706IVIP2;Rh/0B4Q804];B`1XJ6P0T92@059BDP1LG5`0JFUY04Y:BP20P800
[Jf]04=3@`1eMGD0Jf][04m?C`1PH600WIfM0:NWY`1OGel0M7Ad05]KF`1[Jf/0Y:BT08:2PP1MGEd0
LG5a06EUI@1VIVH0SXj>06UYJ@1>CTh0LG5a07MgM`1dM7@0VYZJ0:BTY01GEeL0QHF505QHF01JFUX0
UYJF0:JVYP1MGEd0PH6109FEU@13@d<0IFEU07UiN@11@D40O7al0::RXP1YJFT0P8200:>SX`16ATH0
?Cdm07AdM01nOWh0VIVI0:n_[`1@D500CDe=079bLP2GUiL0QHF50:n_[`1EEED0IVIV09RHV025QHD0
KFe]0:>SX`1DE5@0>CTi06e]K@2ZZZX0OGem08:2PP0k>c/0BDU908^;R`2CTi<0L71`0:NWY`1/K6`0
=SHf0:NWY`1RHV80[Jf]08b<S00a<C40BDU909VIV@2b/[80MWIf065QH@1>CTh0QhN707alO01MGEd0
Shn?04a<C01LG5`0][Jf06m_K`1jNWX0Cdm?05UIF@2EUID0ZJVY04a<C01VIVH0GUiN03Ph>01TI6@0
SHf=05iNGP1eMGD0Bd];075aL@2:RXX0B4Q805IFEP1lO7`0B4Q8079bLP1nOWh0MgMg0:BTY02WYjL0
Q8B408F5Q@2PX:00P82005MGE`21PH40BTY:06e]K@2GUiL0NGUi07=cL`27QhL0Shn?000S05eMG@2F
UYH0QHF503/k>`1OGel0K6a/04I6AP1_Kfl0R8R8061PH01SHf<0CDe=04E5A@1UIFD0Y:BT06UYJ@0h
>3P0N7Qh07inOP1;Bd/0OWin03Xj>P0d=3@0CTi>06EUI@17AdL0GemO0<30`01fMWH0?3`l079bLP0k
>c/0FEUI08n?S`1KFe/07?ooool04P1@D500GemO07AdM01DE5@0FUYJ05]KF`1TI6@0S8b<05YJFP0[
:b/0F5QH05MGE`1OGel0De=C07inOP1SHf<0HF5Q051@D080IFEU00X0Bd];04i>CP0j>SX0De=C04I6
AP1;Bd/0JVYZ0451@@18B4P0?clo0P1RHV80?@1XJ6P0EUIF06IVIP1aLG40IFEU05MGE`1VIVH0?3`l
05MGE`0h>3P0;bl_04M7A`1JFUX0CTi>059BDP1[Jf/0;Rh^05iNGP1RHV80O7al05EEE@1WIfL0<30`
04Y:BP1UIFD0ATI605mOG`1DE5@0@T9206UYJ@1ADE40CTi>03Ph>01NGUh0De=C06UYJ@1@D500EUIF
06ATI02FUYH0CDe=06][J`25QHD0/k>c07IfMP1/K6`0Rh^;05eMG@1kNg/0PH6106=SH`2UYJD0dm?C
0:RXZ01?Cdl0I6AT04m?C`1XJ6P0GemO05IFEP0j>SX00P1IFET0TP1:BTX0@T92065QH@1OGel0DE5A
04m?C`14A4@0BTY:06ATI01:BTX0EeMG0492@P1;Bd/0BDU903`l?01;Bd/0D51@06ATI011@D40D51@
04e=C@1/K6`0Hf=S06YZJP1KFe/0CTi>03Ph>015ADD0Fe]K0451@@1WIfL0Hf=S05QHF01:BTX0B4Q8
04i>CP0g=cL0Vi^K07AdM00n?Sh0][Jf02l_;`19BDT0SXj>04A4A023Ph<0HV9R075aL@0i>CT0Hf=S
05MGE`1KFe/0CDe=079bLP17AdL0>c/k05iNGP0o?cl0PX:204I6AP1>CTh0KVi^05aLG01[Jf/0FEUI
06=SH`0l?3`0P82006m_K`1DE5@0ZJVY08>3P`0m?Cd0E5AD05aLG01HF5P0Q8B405]KF`1OGel0QHF5
04Q8B00m?Cd0EUIF04U9B@1mOGd0JFUY08j>SP1XJ6P0EeMG069RHP12@T80QhN703Ti>@1nOWh0K6a/
075aL@0n?Sh0HV9R05eMG@0b<S80GUiN02LW9`0_;bl0HV9R07QhN01SHf<0@41005MGE`1CDe<0P820
0451@@1IFET0IfMW092@T01GEeL0Ng]k038b<P1EEED0LG5a04e=C@13@d<0MGEe05MGE`1VIVH0H61P
079bLP2OWil0Q8B409^KV`25QHD0GEeM06IVIP1jNWX0JVYZ09RHV019BDT0G5aL0:j^[P12@T80Fe]K
07alO021PH40DE5A07EeM@1[Jf/0H61P0P1mOGd03`1oOgl0KFe]07alO01lO7`0R8R806UYJ@2=SHd0
YJFU08R8R025QHD0U9BD09ZJVP2k^k/0EeMG0:2PX00208V9R@0N075aL@1cLg<0Ti>C09JFUP2>SXh0
a<C40:RXZ02[Zj/0b<S808>3P`2XZ:P0YJFU0;fm_@2OWil0Bd];06QXJ019BDT0GUiN04a<C01_Kfl0
IVIV06UYJ@1bLW80?Cdm04E5A@22PX80LG5a07moO`2l_;`0YjNW4Oooool000oooooo03L0YZJV05=C
D`2RXZ80[:b/079bLP19BDT0EeMG0:f][@1[Jf/0@D5105iNGP0/;2`0=SHf075aL@17AdL0BTY:030`
<01;Bd/0GemO06MWI`0S8b<0@T9206=SH`13@d<0WIfM03De=@0`<300C4a<06e]K@1/K6`0RHV906e]
K@0^;Rh0CDe=04];B`2EUID0alO702/[:`0_;bl0MGEe0:NWY`1=CDd0NGUi06UYJ@13@d<0EEEE065Q
H@1kNg/0[jn_09:BTP0L71`0@d=305ADE020P800W9bL0080=CDe0:T0Bd];079bLP2<S8`0MgMg07Ui
N@0/;2`0NGUi096AT@1ADE40U9BD05UIF@0U9BD0ATI608V9R@2MWId0Ti>C04=3@`0k>c/0De=C09bL
W02<S8`0EeMG06m_K`0V9RH0>c/k07alO01KFe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05YJ
FP0V9RH0ATI605IFEP22PX80?3`l05EEE@1aLG40;Rh^079bLP2o_kl0Cdm?05eMG@1=CDd0:BTY04Q8
B01hN7P0Bd];05QHF016ATH0@T92092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80>SXj04m?
C`1FEUH0GEeM08J6QP2g]kL0EUIF03Ti>@1QHF40FUYJ07AdM02e]KD0Cdm?04M7A`1OGel0LG5a07]k
N`2MWId0WYjN03Ti>@1OGel0LW9b0;^k^`2a/K40EEEE03/k>`1GEeL0Cdm?03`l?02f][H0BTY:04a<
C01ADE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40IFEU069RHP37alL0MgMg03/k>`19BDT0M7Ad07Mg
M`1jNWX0b<S806QXJ015ADD0SHf=09:BTP2_[jl0]KFe04E5A@1MGEd0IFEU08f=S@2a/K40RHV904M7
A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`1GEeL0`<300<G5a@24Q8@0bl_;06EUI@15ADD0Hf=S0;Vi
^@1KFe/0S8b<04E5A@17AdL0RXZ:05YJFP1`L700Ng]k03/k>`1;Bd/0TY:B05EEE@2o_kl0BTY:04A4
A02SXj<0UiNG06a/K022PX80>c/k06ATI02MWId0EeMG075aL@17AdL0DU9B0:f][@2LW9`0=SHf0080
FEUI0340J6QX09fMW@0f=SH0HF5Q06e]K@19BDT0Fe]K0:RXZ00[:b/0>c/k04U9B@0P8200>c/k059B
DP0e=CD0EeMG05ADE01mOGd0SHf=0:VYZ@0Z:RX0Bd];06IVIP1UIFD0DE5A08j>SP2`/;00:RXZ04m?
C`2:RXX0J6QX0:BTY01XJ6P0:b/[051@D01VIVH0RHV909^KV`1EEED08R8R04i>CP1VIVH0^KVi071`
L02YZJT0Ng]k03dm?@1GEeL0JFUY0080MGEe00/0CDe=03De=@0_;bl0DE5A09FEU@1OGel0K6a/03/k
>`16ATH0EeMG07YjNP0Looooo`0505=CD`1iNGT0VYZJ06e]K@1[Jf/00P1LG5`0M`2;Rh/0Hf=S03lo
?`1>CTh0EEEE07UiN@1XJ6P0TY:B05eMG@1kNg/0Kfm_07]kN`1hN7P0DE5A06e]K@17AdL0D51@04U9
B@1?Cdl0GEeM04Y:BP18B4P0DE5A075aL@1JFUX0HF5Q061PH01[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0m?Cd0E5AD04=3@`10@400GEeM02TY:@1;Bd/0Fe]K07MgM`1>CTh0HV9R03<c
<`14A4@0G5aL04=3@`1ADE40EeMG04Y:BP1=CDd0BTY:05YJFP1LG5`0GemO059BDP1^KVh0IVIV07em
O@21PH40Ti>C05MGE`1CDe<0GEeM07UiN@1KFe/0GUiN09fMW@1HF5P0K6a/08b<S023Ph<0T92@0;Ng
]`2?Shl0LG5a05]KF`1:BTX0IFEU06=SH`1EEED0>c/k061PH00n?Sh0C4a<04Y:BP21PH40Bd];04E5
A@1?Cdl0DU9B04=3@`1EEED0B4Q805QHF012@T80A4A405=CD`11@D40DE5A05MGE`1UIFD0DU9B05QH
F01<C4`0O7al06QXJ01CDe<0BDU905EEE@0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B07/0?clo059B
DP1RHV80ATI60<71`@1hN7P06QXJ0:6QX@0e=CD0DE5A09NGU`0h>3P0Rh^;061PH01UIFD0BDU9059B
DP1ZJVX0Lg=c03lo?`1FEUH0DE5A02PX:01=CDd0<c<c0:>SX`0X:2P0=cLg059BDP1`L700KVi^05=C
D`1KFe/092@T0;jn_P2@T900AdM707inOP1hN7P0@T92061PH01`L700C4a<06a/K01SHf<0A4A4069R
HP1;Bd/0;Rh^04I6AP1ADE40TI6A06ATI01GEeL0GEeM059BDP1[Jf/0=CDe06QXJ00f=SH0MWIf04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l061PH01aLG40I6AT05aLG025QHD0CDe=055A
D@0/;2`0O7al04m?C`1ZJVX0A4A406MWI`0g=cL0Cdm?065QH@0e=CD0?clo04e=C@0m?Cd0DE5A06MW
I`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0EUIF07alO02[Zj/0DU9B061PH01gMgL0BTY:08>3
P`2LW9`0L71`069RHP2][Jd0Kfm_04a<C01UIFD0KVi^08b<S01PH600O7al07MgM`1WIfL0HF5Q05aL
G01cLg<00P1GEeL0301oOgl0/k>c0<o?c`1EEED0XJ6Q07YjNP2=SHd0N7Qh04a<C01XJ6P0O7al0820
P080XJ6Q01L0Z:RX07alO028R8P0Zj^[08f=S@2/[:`0^[Zj05=CD`1PH600B4Q805mOG`1aLG40[:b/
09JFUP25QHD0Q8B405UIF@1HF5P0Shn?08B4Q01_Kfl0UiNG0:>SX`0Aooooo`003oooool0R02a/K40
NWYj05eMG@2DU9@0Vi^K04I6AP0k>c/0KVi^08:2PP1]KFd0QXJ603Hf=P0V9RH0E5AD07MgM`1hN7P0
;2`/02h^;P1LG5`0YjNW07moO`2`/;00Xj>S05=CD`1GEeL0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0
SHf=04M7A`1cLg<09RHV05UIF@1^KVh0QhN702XZ:P1VIVH0Ogmo03Hf=P0j>SX0De=C034a<@1^KVh0
=CDe01dM7@1MGEd0ZZZZ05EEE@0o?cl0L71`03<c<`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B403Lg=`1FEUH0E5AD03lo?`2DU9@0SXj>02/[:`0];Bd0EEEE0410@01NGUh0Lg=c02DU9@11@D40
DU9B05ADE01PH600YZJV03Hf=P0L71`0GUiN03dm?@1VIVH0WIfM024Q8@0d=3@0Ng]k0861P@1=CDd0
S8b<01hN7P1BDU80VIVI09^KV`1PH600WYjN07EeM@0f=SH0<C4a07EeM@1DE5@0W9bL04i>CP0W9bL0
De=C05]KF`1YJFT0Ph>30:RXZ00a<C40Ph>30;Bd]01PH600/[:b08F5Q@0`<300FUYJ06e]K@1kNg/0
VIVI06QXJ015ADD0DE5A09NGU`2EUID0Lg=c0:BTY00m?Cd0CTi>08Z:RP2<S8`0PH6109JFUP0P8202
06QXJ02<09NGU`1YJFT0TY:B02/[:`1HF5P0Q8B408F5Q@1`L700]KFe05ADE00d=3@0OWin09NGU`1S
Hf<0VYZJ03<c<`0g=cL0Rh^;0;Jf]P26QXH0Hf=S06i^KP0/;2`0KFe]0;fm_@1XJ6P0IfMW079bLP0]
;Bd0?Shn07UiN@1`L700GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@16ATH0LG5a0;Fe]@1J
FUX0?clo07UiN@1]KFd0FEUI07YjNP2SXj<0>SXj05YJFP1OGel0T92@0<W9b@1aLG40@D5109NGU`1^
KVh0D51@0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06m_K`1NGUh0fMWI071`L00n
?Sh0M7Ad07inOP2=SHd0c/k>04Y:BP1HF5P0T92@08R8R02d];@0HF5Q03Hf=P1SHf<0Xj>S061PH02_
[jl0K6a/04e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Jf][07]kN`1SHf<0A4A405EEE@1F
EUH0B4Q805ADE030`<00EeMG04U9B@1kNg/0IFEU08R8R02m_Kd0>3Ph03dm?@1KFe/0Ph>306MWI`2=
SHd0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P1DE5@0Y:BT04m?C`1MGEd0PH6105=CD`1I
FET0H61P09>CT`0o?cl0JVYZ02h^;P1<C4`2069RHP0:0410@01DE5@0Hf=S02l_;`0h>3P0HV9R020P
8013@d<0EeMG03Ph>1cooooo07h0DE5A06IVIP1bLW80IVIV06EUI@1HF5P0FUYJ0:FUY@1DE5@0>c/k
04e=C@1FEUH0M7Ad04U9B@1ZJVX0De=C05YJFP17AdL0F5QH07IfMP1ZJVX0EUIF02/[:`1ADE40@D51
03lo?`1XJ6P0>SXj03Lg=`11@D40M7Ad07emO@1iNGT0EUIF069RHP27QhL0OGem06MWI`1dM7@0ATI6
05eMG@0h>3P09bLW051@D01PH600BTY:059BDP1_Kfl0;bl_05UIF@1[Jf/0OWin04a<C01WIfL0<C4a
04Y:BP1GEeL0A4A405YJFP17AdL0?Shn06i^KP1DE5@0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE
06][J`2TY:@0Bd];07IfMP1JFUX0PH61059BDP1HF5P0Vi^K09:BTP1oOgl0RHV9065QH@2OWil0f][J
0:6QX@1ADE40Hf=S04Y:BP1SHf<0IfMW05EEE@0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@D500Cdm?
055AD@17AdL0@41005aLG00i>CT0CTi>04M7A`0m?Cd0@T92038b<P14A4@0DE5A06EUI@0l?3`0D51@
04m?C`1SHf<0EeMG06MWI`1VIVH0JFUY04m?C`1GEeL0IVIV04];B`17AdL2069RHP1K04Y:BP18B4P0
Hf=S0410@02l_;`0Ogmo024Q8@2QXJ40CDe=05YJFP2TY:@0>c/k08N7Q`1]KFd0MgMg04A4A01WIfL0
BDU904a<C019BDT0NGUi03dm?@0`<300E5AD04I6AP1fMWH09bLW04i>CP1CDe<0AdM705QHF01:BTX0
GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QHF01fMWH0L71`069RHP2EUID0MWIf05IFEP1eMGD0
QHF50410@01<C4`0Fe]K05mOG`1`L700FEUI075aL@1YJFT0EeMG03Xj>P1]KFd0BTY:08B4Q01NGUh0
OWin05]KF`1=CDd0D51@03Ph>01hN7P0<C4a04=3@`1UIFD0SHf=05]KF`0m?Cd0DE5A05MGE`1^KVh0
<C4a06UYJ@1WIfL0X:2P04a<C01UIFD0;Bd]06=SH`1gMgL0?clo03hn?P1ADE40CDe=06EUI@02061P
H00>08R8R02d];@0]kNg08n?S`1FEUH0G5aL08:2PP1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd2
06QXJ00e05=CD`1mOGd0NWYj08B4Q02BTY80MGEe08J6QP1/K6`0P82008V9R@26QXH0IVIV07AdM02=
SHd0I6AT061PH01`L700WIfM0<o?c`2;Rh/0UYJF08R8R027QhL0R8R805=CD`2@T900/;2`0<71`@39
bLT0Vi^K0:RXZ02SXj<0QHF50::RXP2h^;P0fMWI0;>c/`1GEeL0OGem04m?C`1GEeL0C4a<06=SH`1/
K6`0Lg=c07MgM`0h>3P0BDU907UiN@1`L700T92@08j>SP2i^KT04Oooool000oooooo04h0NWYj0::R
XP1fMWH0MgMg06EUI@24Q8@0K6a/06][J`0d=3@0D51@05]KF`1EEED0F5QH06m_K`12@T80UiNG05EE
E@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0ATI603dm?@1WIfL0][Jf09bLW00`<300?Cdm05QH
F00j>SX0UiNG028R8P0o?cl0E5AD04i>CP0a<C40X:2P0;Ng]`0Y:BT0?3`l059BDP1RHV80[Jf]06IV
IP0];Bd0ATI606m_K`1eMGD0LG5a08:2PP0j>SX0De=C071`L01[Jf/0JFUY04i>CP0G5aL0GEeM07mo
O`1RHV80SHf=02`/;00Q8B40G5aL0;Zj^P2YZJT0IVIV08R8R00Q8B40DU9B09NGU`1]KFd0S8b<0:2P
X00T92@204Y:BP0O07]kN`14A4@0NGUi04e=C@1;Bd/0GEeM05]KF`1NGUh0OGem02d];@1?Cdl0LG5a
05mOG`1fMWH0KVi^030`<01:BTX0GemO08b<S01=CDd0HV9R0451@@15ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L00204M7A`2a030`<016ATH0De=C06m_K`0n?Sh0A4A4069RHP0/;2`0T92@
09JFUP0k>c/0ADE504U9B@1:BTX0CDe=0:>SX`2FUYH0>SXj059BDP1SHf<0GEeM0<o?c`1VIVH0=CDe
06=SH`1KFe/0KFe]0:>SX`1@D500>CTi06m_K`1GEeL0GemO0;Jf]P2c/k<0<c<c05eMG@1aLG40MWIf
0<o?c`25QHD09bLW051@D02NWYh0Jf][079bLP25QHD0=3@d04I6AP2<S8`0FEUI09^KV`2l_;`08R8R
04I6AP1QHF40N7Qh0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi05mOG`2d];@0DE5A065QH@23Ph<0JVYZ
08N7Q`2QXJ40DE5A04U9B@1bLW80QhN708J6QP23Ph<08R8R06QXJ02SXj<0XZ:R07YjNP2][Jd0PX:2
02/[:`2YZJT0LG5a09nOW`1?Cdl0=3@d05]KF`3EeMD0UiNG07AdM01=CDd0@D5107moO`34a<@0K6a/
0:ZZZP0h>3P0Jf][08N7Q`2@T900TI6A04m?C`1DE5@0[Jf]09FEU@1@D500HV9R05iNGP11@D40NWYj
09FEU@1MGEd0@D5104];B`1QHF40S8b<05=CD`14A4@0M7Ad055AD@2<S8`0X:2P05ADE01[Jf/0PX:2
05iNGP18B4P0/[:b09ZJVP1<C4`0KVi^04e=C@1UIFD0Xj>S079bLP0f=SH0JFUY04a<C01IFET0UiNG
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0=SHf06ATI01<C4`0Jf][0:VYZ@0a<C40=cLg
05QHF01cLg<0De=C08J6QP0R8R80=CDe055AD@1kNg/0DU9B07moO`2^[Zh0;bl_02d];@1TI6@0Cdm?
0820P01kNg/0>SXj01cooooo02/0AdM7065QH@22PX80JFUY07IfMP1JFUX0GEeM0::RXP1CDe<0?clo
061PH01?Cdl0K6a/04i>CP1nOWh0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A03Xj>P1?Cdl0>3Ph
03hn?P1SHf<0C4a<03Hf=P14A4@0FUYJ04];B`1SHf<0CTi>04e=C@1YJFT0EEEE05MGE`1PH600@D51
055AD@0j>SX0BDU90080DE5A0300Hf=S05eMG@1LG5`0?clo05YJFP1hN7P0KVi^04I6AP1@D50092@T
04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1QHF40BTY:04=3@`1/K6`0E5AD06e]K@1EEED0H61P
07IfMP2e]KD0CTi>09nOW`1QHF40Ng]k061PH01]KFd0RHV905EEE@1NGUh0Q8B407moO`2g]kL0h^;R
0<71`@1IFET0L71`06=SH`1?Cdl0Kfm_06e]K@0f=SH3061PH00P059BDP1`L700K6a/05IFEP1XJ6P0
GemO061PH01VIVH0CTi>061PH01DE5@0H61P051@D00e=CD0EEEE05aLG01SHf<0ATI605]KF`1@D500
IVIV05IFEP1YJFT0Shn?06m_K`1FEUH0B4Q8059BDP1KFe/0D51@04Y:BP1JFUX2059BDP1I05mOG`0j
>SX0`/;209NGU`0T92@0Q8B40820P01UIFD0Vi^K06QXJ02PX:00H61P05YJFP15ADD0E5AD04m?C`16
ATH0@41006QXJ00m?Cd09RHV05QHF011@D40XJ6Q01lO7`12@T80E5AD05UIF@1[Jf/0AdM705MGE`0`
<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI06YZJP0m?Cd0EEEE05QHF01>CTh0QhN707=cL`13
@d<0LW9b051@D01bLW80JVYZ0;2`/02k^k/0QhN705IFEP0c<c<0RHV90410@01gMgL0?3`l05UIF@0n
?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400G5aL05UIF@1FEUH0ADE504a<C01@D500PX:204E5A@1e
MGD0DU9B06IVIP1XJ6P0I6AT01lO7`17AdL0F5QH02l_;`0c<c<0HV9R03Lg=`17AdL00P1IFET0=P1m
OGd0JVYZ08B4Q01PH600?Cdm051@D01>CTh0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01_
Kfl0GemO06ATI01OGel0DU9B05mOG`1?Cdl0KFe]06a/K01]KFd0SHf=08V9R@1MGEd0JFUY07=cL`28
R8P0SXj>08:2PP2;Rh/0];Bd0:6QX@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<c<c026
QXH0SXj>0;Bd]03AdM40emOG08j>SP2GUiL0Zj^[04i>CP80DE5A00d0JFUY04Y:BP26QXH0LW9b08R8
R01nOWh0?clo05ADE02;Rh/0NWYj092@T02?Shl0^KVi017ooooo000?ooooo`1?08f=S@1iNGT0QHF5
08f=S@1?Cdl0NGUi07alO02LW9`0:BTY04U9B@1GEeL0GUiN07IfMP2c/k<0;bl_07=cL`2RXZ80J6QX
0::RXP1JFUX0ADE503Hf=P26QXH0SXj>0:JVYP0j>SX0:b/[02PX:02BTY80QHF50:2PX01`L700;bl_
04];B`1GEeL0Kfm_0:BTY00_;bl06ATI02h^;P25QHD0IVIV059BDP18B4P0<S8b0410@01YJFT0C4a<
06m_K`1nOWh07AdM051@D02PX:00C4a<079bLP1>CTh09RHV051@D02<S8`0B4Q802h^;P1>CTh0@D51
05iNGP0h>3P0:2PX03dm?@1FEUH0?Shn06EUI@1cLg<0BTY:059BDP1NGUh0;bl_08V9R@3Ng]h0J6QX
030`<00206ATI02d05eMG@2PX:00;bl_03`l?01SHf<0E5AD06UYJ@2UYJD0CDe=02d];@1BDU80F5QH
09ZJVP3;bl/0<S8b03Hf=P1^KVh0L71`05ADE02IVIT0LG5a01hN7P1ADE40T92@08V9R@1iNGT0GUiN
02LW9`15ADD0FUYJ06e]K@2LW9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[03De=@1KFe/0K6a/
04m?C`28R8P0PH6103<c<`1;Bd/0DU9B08J6QP2;Rh/0Kfm_03/k>`18B4P0/;2`09ZJVP1[Jf/0Y:BT
04e=C@0l?3`0KFe]0;Vi^@26QXH0VIVI02HV9P1:BTX0JFUY08n?S`2FUYH0NGUi02`/;01HF5P0L71`
0:n_[`1_Kfl0I6AT07MgM`1<C4`0FUYJ08>3P`1@D500OWin0451@@0n?Sh0DE5A09^KV`1KFe/0EUIF
07=cL`0o?cl0IfMW0:BTY01MGEd0IfMW08b<S00o?cl0BDU907alO01kNg/0>c/k06e]K@15ADD0EEEE
0:BTY02IVIT0=cLg04m?C`1IFET0H61P0<_;b`1WIfL0IFEU0:6QX@1PH600J6QX0;Bd]02HV9P0<C4a
07alO02DU9@0YZJV0:ZZZP0g=cL0ATI6071`L01oOgl0WinO06IVIP18B4P0MGEe06QXJ01dM7@0fm_K
05eMG@10@400UIFE06EUI@2QXJ40K6a/03dm?@1GEeL0N7Qh051@D02FUYH0Hf=S03`l?01PH600PH61
0:ZZZP1OGel0;2`/05UIF@20P800I6AT096AT@2YZJT0<30`06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c
0451@@1cLg<0Y:BT07emO@1MGEd0>3Ph05=CD`25QHD0X:2P04U9B@2LW9`0IfMW02d];@1`L700Y:BT
05EEE@2:RXX0HV9R0P15ADD06`23Ph<0Q8B405YJFP0W9bL0?3`l04U9B@23Ph<0M7Ad05EEE@1/K6`0
=SHf0492@P1jNWX0HF5Q0410@02BTY80@4100451@@1UIFD0Ogmo071`L01FEUH0GEeM02DU9@1ZJVX0
TI6A061PH00Looooo`3^04=3@`1TI6@0L71`05mOG`1XJ6P0HF5Q06][J`2>SXh0Bd];02`/;01<C4`0
BDU907MgM`1/K6`0M7Ad08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU903@d=00l?3`0
Hf=S04e=C@0l?3`0FUYJ07emO@1KFe/0MGEe05iNGP1XJ6P0Ti>C06m_K`1MGEd0MGEe03dm?@1GEeL0
9bLW02@T9012@T80FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40M7Ad03lo?`19BDT0
P8200410@01TI6@0BDU903lo?`1aLG40EEEE05=CD`1>CTh0GEeM04E5A@1cLg<0J6QX07emO@1MGEd0
W9bL05]KF`2EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`1JFUX0W9bL0=gMg@2PX:00
IFEU06=SH`1CDe<0Q8B407]kN`1IFET0F5QH07alO019BDT0Cdm?04=3@`28R8P0AdM704i>CP1KFe/0
HF5Q04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017AdL0CDe=06UYJ@1aLG40DU9B065QH@1ADE40
L71`06EUI@24Q8@0Kfm_06MWI`0e=CD0C4a<071`L01>CTh0Fe]K07YjNP1XJ6P0D51@06UYJ@1WIfL0
=CDe0;jn_P2EUID0<c<c08J6QP2OWil0KVi^09jNWP1HF5P0Vi^K065QH@1HF5P0AdM7065QH@1MGEd0
E5AD03dm?@1YJFT0GUiN04I6AP1EEED0HF5Q0;no_`13@d<0Bd];05ADE01UIFD0DU9B05UIF@1VIVH0
8B4Q05UIF@1GEeL0?clo0;Zj^P25QHD0?3`l06i^KP1GEeL0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0
;Bd]03dm?@0l?3`0I6AT04U9B@1]KFd0TY:B06IVIP17AdL09RHV06][J`0m?Cd0Shn?04m?C`1cLg<0
BTY:05iNGP1UIFD0@d=308Z:RP17AdL0?Cdm06ATI01oOgl0EEEE051@D01UIFD0De=C06=SH`19BDT0
LW9b061PH01iNGT0Hf=S07IfMP0b<S80D51@05iNGP0n?Sh0CTi>07YjNP13@d<0ATI607emO@1WIfL0
I6AT04U9B@1mOGd0JFUY04m?C`1@D500IFEU07]kN`1XJ6P0DE5A08j>SP2i^KT0C4a<05EEE@1hN7P0
L71`04a<C080Ng]k02T0E5AD08:2PP1/K6`0Ti>C07IfMP2GUiL0SHf=08N7Q`2?Shl0Y:BT07alO01J
FUX0GemO06ATI01/K6`0[jn_07IfMP2?Shl0PH6107]kN`1OGel0GEeM09NGU`2VYZH0Xj>S0;Rh^02D
U9@0VYZJ0:^[Z`2>SXh0]kNg09FEU@2DU9@0][Jf05eMG@1IFET0EUIF05YJFP1?Cdl0R8R806MWI`02
05EEE@0704U9B@1LG5`0Jf][0861P@2:RXX0OWin0:2PX00Aooooo`003oooool07031`L40CTi>07=c
L`2EUID0QXJ603lo?`1HF5P0J6QX06ATI011@D40BDU902/[:`1CDe<0KFe]06a/K00m?Cd08b<S04I6
AP1UIFD0VIVI05QHF01ADE40HF5Q03<c<`1UIFD0Z:RX03lo?`1KFe/203Hf=P3S08j>SP2/[:`0=3@d
03hn?P17AdL0GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@1nOWh0:BTY059BDP1?Cdl0<S8b
09NGU`30`<00<c<c01dM7@1nOWh0HF5Q08f=S@16ATH06a/K03<c<`1dM7@0?Cdm08N7Q`1hN7P08B4Q
05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q07YjNP27QhL0>c/k04=3@`1KFe/0QhN7
07inOP33`l<0<c<c03Xj>P1hN7P0Hf=S07EeM@2QXJ40<C4a03`l?01SHf<0X:2P06EUI@1cLg<0@D51
04Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0S8b<051@D01fMWH0Bd];02`/;01`L700YjNW
04=3@`1FEUH0GEeM0410@01cLg<0IfMW03lo?`1cLg<0M7Ad02/[:`1VIVH0`L7107YjNP2>SXh0HV9R
02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1_Kfl0`/;205ADE01>CTh0TI6A06IVIP0n?Sh0TY:B
0;2`/00h>3P0HF5Q04i>CP1gMgL0ZJVY06=SH`0c<c<0I6AT08F5Q@0g=cL0[Jf]05YJFP0h>3P0Kfm_
07AdM01@D500NGUi0<?3``1DE5@0>3Ph06][J`1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al
0=;BdP12@T80MGEe08f=S@1aLG40VIVI0<o?c`1DE5@0CTi>06QXJ024Q8@0WinO0::RXP0h>3P0HF5Q
05]KF`2e]KD0Ti>C09bLW01CDe<0A4A407AdM01fMWH0XJ6Q0<g=c@0S8b<0FUYJ096AT@2n_[h0DU9B
0:BTY00f=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:JVYP1jNWX0YJFU03Lg=`0l?3`0O7al
08f=S@1YJFT0Rh^;03@d=017AdL0Z:RX05]KF`1hN7P0Cdm?034a<@1LG5`0NWYj04Y:BP2:RXX0EUIF
06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80GemO06=SH`1XJ6P0=CDe08N7Q`2SXj<0DU9B
04Q8B01VIVH0@d=308:2PP2CTi<0=cLg0451@@1TI6@0Bd];05UIF@2UYJD0^KVi03Ph>01DE5@00P1F
EUH07`2KVi/0Z:RX04Q8B015ADD0SXj>065QH@25QHD0IfMW02l_;`1MGEd0Jf][06QXJ01HF5P0TI6A
06m_K`0S8b<0GemO069RHP1GEeL0YZJV09FEU@0P8200>c/k092@T01XJ6P0AdM708B4Q00X:2P0>CTi
05UIF@1GEeL07?ooool02`10@400IfMW07EeM@1[Jf/0KVi^04a<C01>CTh0JFUY05eMG@0a<C40Cdm?
0080CTi>01P0?Shn04Y:BP1fMWH0Jf][07moO`1ZJVX0GEeM059BDP1PH600BTY:059BDP0k>c/0B4Q8
05EEE@0[:b/0?clo055AD@1LG5`0HF5Q05=CD`1GEeL0HF5Q06EUI@1cLg<207QhN01304E5A@1KFe/0
=CDe02TY:@1OGel0L71`04e=C@1BDU80NWYj03@d=01LG5`0MGEe0:6QX@1CDe<0NWYj02/[:`1DE5@0
MWIf03Ti>@1UIFD0CDe=04M7A`1gMgL0G5aL055AD@0m?Cd0HV9R04=3@`1RHV80FUYJ06=SH`1TI6@0
WYjN04i>CP2LW9`0K6a/07MgM`1VIVH0HF5Q09fMW@2PX:00RXZ:08>3P`1UIFD0U9BD0<o?c`2i^KT0
MgMg06i^KP1CDe<0I6AT0861P@1JFUX0@T9205EEE@0f=SH0E5AD04U9B@1fMWH0A4A4065QH@1@D500
CDe=04M7A`1ADE40BDU904E5A@0204U9B@1C05mOG`0d=3@0EEEE051@D01EEED0@D5105EEE@1?Cdl0
Rh^;0492@P1NGUh0B4Q805]KF`10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0FEUI069RHP24Q8@0
Fe]K0<[:bP2PX:00=3@d07inOP3@d=00OWin0:RXZ01DE5@0];Bd06QXJ01_Kfl0BDU905UIF@15ADD0
Cdm?059BDP1dM7@0BDU903dm?@1FEUH0EEEE0:FUY@15ADD0IfMW07EeM@1UIFD0H61P04Q8B01?Cdl0
8R8R06=SH`1/K6`0@T9209^KV`1kNg/0?clo05QHF01MGEd0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0
=3@d06ATI016ATH0P82004Q8B021PH40`L7106a/K01QHF40;2`/07UiN@0d=3@0D51@06QXJ025QHD0
0P14A4@01@19BDT0;bl_079bLP1=CDd0=3@d0080GUiN05X0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0
Lg=c06a/K027QhL0HF5Q07UiN@0`<300IfMW06][J`0m?Cd0>3Ph05UIF@14A4@0F5QH061PH01KFe/0
NWYj07EeM@1JFUX0IFEU05EEE@1LG5`0KVi^071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0
Fe]K05ADE01[Jf/0JFUY05MGE`1XJ6P0De=C079bLP1]KFd0P82007QhN01mOGd0DE5A05MGE`1IFET0
I6AT06QXJ01KFe/0I6AT0:f][@1oOgl0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2l_;`0
YjNW0;6a/@31`L40X:2P0<C4a027QhL0b/[:0<71`@1UIFD0IVIV05mOG`1NGUh0ADE507MgM`1OGel0
J6QX06IVIP18B4P0F5QH06IVIP1MGEd0RHV905iNGP2WYjLAooooo`003oooool0;P29RHT0N7Qh069R
HP1mOGd0PH610492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T9206e]K@2XZ:P0?clo01hN
7P13@d<0C4a<07QhN02h^;P0alO702LW9`1=CDd0Jf][07alO039bLT0GemO03Hf=P1hN7P0PH6104e=
C@2=SHd04A4A0492@P1<C4`0IVIV04M7A`2a/K40MWIf024Q8@1=CDd0Jf][05ADE01nOWh2038b<P1i
059BDP1^KVh0UYJF051@D01hN7P0>3Ph07YjNP2BTY80Fe]K05mOG`0n?Sh07QhN061PH02g]kL0KFe]
06m_K`0Q8B40:BTY07EeM@1fMWH0[:b/06e]K@2_[jl0;Bd]059BDP1/K6`0A4A406][J`1/K6`0>SXj
05eMG@1SHf<0KFe]03<c<`1LG5`0>c/k04A4A02LW9`0G5aL04I6AP1JFUX0<C4a07emO@2;Rh/0<c<c
05EEE@1^KVh0C4a<051@D031`L40WYjN03<c<`0`<300@D5107IfMP21PH40J6QX034a<@13@d<0HF5Q
06MWI`1gMgL0R8R803Ti>@1;Bd/0LW9b06IVIP2b/[80UiNG03lo?`1<C4`0I6AT06MWI`3>c/h0Rh^;
03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1FEUH0RHV908B4Q01LG5`0Z:RX03De=@1GEeL0GUiN
07MgM`1nOWh0QhN703<c<`1/K6`0JVYZ07YjNP1eMGD0Vi^K08Z:RP1KFe/0M7Ad0:>SX`1oOgl0`/;2
04i>CP0e=CD0HV9R07EeM@2UYJD0Ng]k08V9R@0k>c/0IVIV0:>SX`1FEUH0N7Qh075aL@10@400>3Ph
07UiN@0208F5Q@1g06a/K00k>c/0GemO071`L02ATI40D51@0<71`@10@400M7Ad0:2PX01kNg/0Kfm_
08V9R@18B4P0G5aL071`L02d];@0HV9R08n?S`12@T80IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE5
0;2`/01DE5@0EEEE05IFEP1PH600XZ:R0:6QX@0l?3`0GEeM07]kN`2[Zj/0b<S805=CD`10@400KFe]
04e=C@1lO7`0dM7A071`L01ADE40M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40I6AT
05]KF`2XZ:P0Hf=S08F5Q@2LW9`0;Bd]03Ti>@2:RXX0MWIf06m_K`1MGEd0=cLg05UIF@2>SXh0SHf=
06EUI@2OWil0Cdm?04];B`2h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@2RXZ80CTi>
065QH@1bLW80TI6A06m_K`2BTY80/k>c0410@01fMWH0Ti>C04M7A`2/[:`0Z:RX05]KF`1;Bd/0H61P
08V9R@17AdL0Cdm?02h^;P16ATH0Bd];0861P@1DE5@0Hf=S06YZJP0_;bl0ADE506a/K00Z:RX0?clo
06e]K@14A4@07?ooool06P0n?Sh0J6QX06QXJ01?Cdl0C4a<059BDP1HF5P0IfMW04I6AP17AdL0CDe=
04U9B@1EEED0@d=305UIF@1eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?C`0];Bd0<c<c
0P1@D5001@12@T80HV9R06i^KP1PH600IVIV0080E5AD02L0N7Qh069RHP1=CDd0FUYJ03hn?P1?Cdl0
;Rh^02HV9P0o?cl0A4A403dm?@18B4P0H61P03@d=01;Bd/0M7Ad08:2PP1XJ6P0R8R803Ti>@19BDT0
LG5a05aLG01hN7P0BTY:04I6AP1mOGd0Fe]K059BDP19BDT0H61P04=3@`1WIfL0JVYZ07MgM`1cLg<0
/;2`051@D02OWil00P2FUYH07@1/K6`0Fe]K07=cL`1jNWX0OWin05]KF`1LG5`0O7al0>3Ph02[Zj/0
EUIF06ATI01LG5`0PH6108V9R@1[Jf/0ADE506m_K`1eMGD0Hf=S03/k>`1bLW80K6a/069RHP1QHF40
FUYJ05ADE01QHF40ADE50080DU9B09T0BTY:05iNGP10@400Fe]K05YJFP1KFe/0B4Q8061PH01HF5P0
IFEU04M7A`1[Jf/0H61P06m_K`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1NGUh0
CTi>0=7Ad@1oOgl0=CDe09JFUP30`<00MWIf0:f][@1GEeL0RHV906i^KP1lO7`0<C4a051@D01IFET0
JFUY059BDP1WIfL0@d=303@d=01IFET0F5QH0:j^[P19BDT0C4a<06][J`1bLW80L71`04Y:BP1SHf<0
?Cdm0:BTY02:RXX0FUYJ0;Vi^@2OWil0IfMW06EUI@1aLG40@T92092@T01oOgl0CDe=075aL@1LG5`0
=3@d03lo?`13@d<0N7Qh04m?C`1KFe/0QHF5051@D01KFe/0:BTY07MgM`0c<c<0L71`05=CD`1YJFT0
=cLg05iNGP1RHV8092@T07IfMP1WIfL0CTi>06][J`1jNWX0GUiN05UIF@1cLg<0E5AD05mOG`0V9RH0
QHF505eMG@1bLW80ADE505QHF00S8b<0IfMW05EEE@0W9bL0G5aL08:2PP0n?Sh0Bd];05IFEP1GEeL0
KVi^05aLG01IFET0EUIF03Ph>01ADE40GemO065QH@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0
MWIf05iNGP1HF5P0J6QX03lo?`1FEUH0BDU9075aL@1gMgL0JVYZ07inOP2>SXh0De=C06MWI`1EEED0
L71`07YjNP1NGUh0Bd];0:NWY`1fMWH0XJ6Q08J6QP2;Rh/00P1`L7007026QXH0SHf=0:NWY`2o_kl0
QhN707MgM`2;Rh/0ZJVY0<;2`P1eMGD0^KVi0<K6aP1cLg<0EEEE03@d=01<C4`0GUiN09:BTP1RHV80
FUYJ05EEE@1DE5@0DE5A07AdM01]KFd0KVi^06IVIP2YZJTAooooo`003oooool0k@22PX80WIfM0;6a
/@1GEeL0GEeM07AdM01YJFT0W9bL02l_;`15ADD0IfMW04M7A`18B4P0LG5a02TY:@1NGUh0SHf=059B
DP1gMgL0?Cdm030`<00j>SX0NWYj06EUI@1ADE4092@T055AD@1LG5`0RXZ:03/k>`1BDU80FUYJ04];
B`1bLW80@41003@d=01aLG40<S8b04=3@`21PH40Xj>S03/k>`0b<S80HF5Q04E5A@2TY:@0HF5Q02LW
9`1@D500KVi^03Ph>01eMGD0b<S803dm?@1IFET0J6QX05ADE02^[Zh0F5QH01@D500P8200EeMG06UY
J@2e]KD0;Bd]020P800[:b/0BDU907UiN@1bLW80e=CD02/[:`1CDe<0NWYj075aL@2TY:@0_[jn02@T
900l?3`0UiNG07AdM01>CTh0UiNG020P801EEED0Ogmo075aL@2<S8`0[jn_03dm?@0g=cL0UIFE07em
O@2FUYH0Vi^K04];B`0h>3P0KFe]0;fm_@2;Rh/0LG5a04M7A`12@T80Ph>3071`L01OGel0QXJ607Ui
N@0K6a/0G5aL09:BTP1IFET0K6a/02d];@10@400MgMg0:FUY@1HF5P0B4Q805iNGP0b<S80CTi>08n?
S`19BDT0GemO07AdM00d=3@0D51@075aL@25QHD0IFEU0861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820
P016ATH0<S8b0:n_[`10@400AdM7071`L00a<C40C4a<0:ZZZP2CTi<0>c/k05ADE01GEeL0LW9b0<K6
aP1bLW80;Rh^05=CD`1PH600DE5A061PH01cLg<0?Cdm05MGE`1MGEd0Jf][09fMW@2IVIT0>3Ph03Hf
=P1@D500JFUY0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80E5AD04=3@`1HF5P0Kfm_09jN
WP3:b/X0Lg=c03`l?019BDT0X:2P09VIV@2VYZH0A4A405YJFP1MGEd0WinO09fMW@36a/H0Jf][04A4
A01iNGT0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP1JFUX0Bd];07moO`1/K6`0S8b<0<G5
a@1>CTh0:b/[08^;R`2j^[X0WinO059BDP0m?Cd0C4a<0;Vi^@2=SHd0Ti>C06UYJ@0e=CD0Ph>309jN
WP2?Shl0GEeM04e=C@1CDe<0PH6106YZJP1mOGd0PX:204Y:BP020:NWY`0c03dm?@1/K6`0O7al05mO
G`1LG5`0Y:BT09fMW@1MGEd0Bd];05QHF01NGUh0`<3007EeM@0k>c/0HF5Q05QHF00l?3`0PH6107in
OP0d=3@0FUYJ05ADE011@D40DE5A0<O7a`2BTY80@d=3061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=
C@1[Jf/0FEUI08J6QP0^;Rh0>c/k05EEE@1<C4`0E5AD09>CT`2b/[80>CTi02d];@1BDU80;bl_06a/
K02FUYH0DE5A01cooooo0?D0AdM705EEE@1cLg<0GemO05YJFP1NGUh0Hf=S0820P019BDT0=cLg05iN
GP1CDe<0GUiN05YJFP1LG5`0I6AT075aL@1TI6@0G5aL05]KF`1@D500Cdm?03dm?@1?Cdl0>3Ph03Lg
=`1EEED0CTi>04E5A@1:BTX0GEeM06=SH`1MGEd0De=C05IFEP1/K6`0HV9R06MWI`1/K6`0AdM704E5
A@0m?Cd0<c<c05]KF`1OGel0BDU904i>CP22PX8092@T03Ph>01RHV80Shn?04Y:BP19BDT0@D5104Q8
B01DE5@0;2`/04A4A013@d<0@D5106a/K01VIVH0AdM704A4A01WIfL0JVYZ05aLG01HF5P0QXJ606YZ
JP1BDU80Cdm?059BDP0m?Cd0IFEU06UYJ@1NGUh0M7Ad0451@@1ADE40HF5Q05mOG`1PH600SXj>0820
P01LG5`0E5AD0451@@1UIFD0FUYJ05=CD`19BDT0EUIF059BDP1[Jf/0AdM706UYJ@10@400<30`0451
@@1BDU80>3Ph03dm?@15ADD0Bd];05]KF`16ATH0EeMG05ADE01NGUh0C4a<06QXJ01QHF40OGem04M7
A`1`L700?clo09RHV01BDU80BDU904i>CP1SHf<0I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05aL
G00S8b<0W9bL079bLP0g=cL0M7Ad0:f][@1aLG40[Zj^05aLG02OWil0Hf=S05EEE@16ATH0DE5A07Ad
M023Ph<0DU9B05eMG@1?Cdl0>SXj03dm?@15ADD0VYZJ0410@01<C4`0D51@07=cL`1PH600AdM7059B
DP0j>SX0PH61075aL@1[Jf/0_kno09JFUP27QhL0Ph>308f=S@1RHV80QhN708J6QP1DE5@0VIVI08B4
Q011@D40CDe=04i>CP1SHf<0IfMW04Y:BP1RHV80Bd];06QXJ00];Bd0P8200451@@1OGel0E5AD07Ee
M@0n?Sh0CTi>051@D01;Bd/0VIVI07inOP18B4P0EEEE06EUI@1/K6`0D51@04a<C01[Jf/0TY:B034a
<@1TI6@0EEEE06UYJ@1QHF40Ogmo03@d=01JFUX0IfMW02XZ:P1<C4`0CTi>04A4A015ADD0L71`05]K
F`1`L700H61P06][J`1]KFd0FEUI06IVIP1_Kfl0R8R8092@T01lO7`0Kfm_0;:b/P1:BTX0RHV908:2
PP1SHf<0ADE507IfMP1^KVh0@41006=SH`1IFET0NWYj06UYJ@0207UiN@0[08j>SP1_Kfl0YZJV07Ee
M@1QHF40IFEU05MGE`13@d<0Zj^[07]kN`2YZJT0M7Ad09BDU01`L700DU9B09nOW`2/[:`0/;2`0:n_
[`2@T900SXj>096AT@2>SXh0UYJF04=3@`1dM7@0[:b/096AT@1lO7`0BTY:05IFEP1SHf<0Q8B406EU
I@1aLG40GEeM04I6AP1GEeL0NGUi04a<C01`L700J6QX0;2`/00Aooooo`003oooool04P2BTY80Kfm_
0861P@2HV9P0Fe]K06UYJ@1NGUh0XJ6Q0410@011@D40DE5A04Q8B01EEED0Vi^K02LW9`0`<300B4Q8
0410@080Ti>C00d0;Bd]04A4A01CDe<0IFEU0:2PX00X:2P0:BTY0451@@2<S8`0Fe]K0<30`01lO7`0
820P0080C4a<00@0NGUi0<71`@0m?Cd0;Bd]0P1UIFD0n@1TI6@0Ph>307YjNP0d=3@0J6QX07moO`15
ADD0OWin08N7Q`0V9RH0;Rh^07UiN@1dM7@0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0Z
:RX0?3`l06ATI012@T80[jn_04E5A@0F5QH0;Rh^05EEE@22PX80EEEE0492@P0d=3@0MgMg08Z:RP1J
FUX0CTi>06i^KP0k>c/0:BTY075aL@0d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm04=3@`0]
;Bd0@d=305iNGP1@D500;bl_05MGE`1=CDd0?Cdm08b<S01lO7`0=3@d061PH01;Bd/0=3@d08b<S029
RHT0;bl_02d];@1ADE40HF5Q0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO07QhN02f][H0?Shn06EUI@1X
J6P0D51@09:BTP30`<00CTi>0492@P1kNg/0LG5a07YjNP3Fe]H0=CDe04i>CP2MWId0QHF507IfMP37
alL0JFUY02DU9@2:RXX0Q8B407emO@2DU9@0?clo034a<@1JFUX0clo?07YjNP2JVYX08R8R06IVIP2S
Xj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Ph>305=CD`34a<@0IFEU034a<@1jNWX0KVi^06=SH`1X
J6P0^;Rh03Hf=P1eMGD0[Jf]08>3P`1nOWh0Shn?03Ph>01@D500Rh^;08Z:RP1dM7@0HV9R038b<P1U
IFD0U9BD0<;2`P1SHf<0]kNg04A4A01IFET0/;2`07EeM@1lO7`0P82002/[:`1^KVh0W9bL0:ZZZP1C
De<0Rh^;04M7A`2@T900d];B06ATI01BDU80EUIF0410@01aLG40UIFE04=3@`1]KFd0?Shn06i^KP3A
dM40PH6103Lg=`1CDe<0F5QH06i^KP27QhL0?Shn04U9B@1>CTh0LG5a0<71`@2LW9`0:RXZ05UIF@1/
K6`0[jn_0;6a/@0k>c/0EeMG08b<S01QHF40Ng]k0<G5a@1<C4`0E5AD0:NWY`1HF5P0Ph>309ZJVP0h
>3P0?Cdm05]KF`2BTY80U9BD05YJFP0b<S80AdM7069RHP1lO7`0LW9b0;jn_P2ATI40@41004U9B@2K
Vi/0OGem0:JVYP1^KVh0?Cdm03lo?`2e]KD0bLW90:VYZ@0o?cl0<30`04];B`2WYjL0/K6a07EeM@2G
UiL0F5QH024Q8@1OGel0PX:207YjNP2c/k<0FEUI034a<@0f=SH0Fe]K07alO018B4P0GUiN030`<00_
;bl0@D5105eMG@0Looooo`0B04a<C015ADD0MGEe06YZJP1/K6`0H61P06e]K@29RHT0EeMG04U9B@1J
FUX0Bd];055AD@10@400M7Ad08b<S01nOWh0KFe]0P1fMWH0A@1_Kfl0I6AT03Ti>@1FEUH0=cLg04=3
@`1NGUh0<c<c04e=C@1WIfL0Jf][06=SH`1ZJVX0JFUY05UIF@2>SXh0M7Ad05mOG`1lO7`0ATI6051@
D00i>CT0<c<c05MGE`1RHV80BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1^KVh08R8R0410
@01NGUh0?Shn05UIF@1ADE40CDe=05mOG`1FEUH0BDU905YJFP1FEUH0A4A406e]K@1YJFT0NWYj079b
LP29RHT0BDU908Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B07IfMP1gMgL0h>3P0:BT
Y01HF5P0IFEU04m?C`0205iNGP0T05IFEP1@D500Jf][04Q8B01QHF40A4A407AdM00h>3P0>c/k04m?
C`1RHV80>CTi05EEE@18B4P0?Cdm04M7A`1:BTX0F5QH03hn?P1=CDd0L71`05IFEP1;Bd/0D51@05EE
E@1_Kfl0BTY:03Ti>@1@D500H61P05mOG`1EEED0KVi^04M7A`1HF5P0O7al0P1FEUH0X@0l?3`0J6QX
024Q8@2QXJ40D51@02TY:@2j^[X0alO707MgM`2@T900CDe=09NGU`1LG5`0EEEE0451@@1LG5`0DE5A
07EeM@1/K6`0IfMW0451@@0f=SH0DE5A03Ti>@2UYJD0>c/k06=SH`1`L700KFe]04i>CP1SHf<0LG5a
03`l?01WIfL0D51@065QH@3Lg=`0W9bL04=3@`1HF5P0JFUY04U9B@2^[Zh0[Jf]0492@P2=SHd0GUiN
03Hf=P1@D500JVYZ07emO@2DU9@0IFEU075aL@1:BTX0Hf=S02XZ:P1[Jf/0<C4a061PH01ZJVX0XJ6Q
04M7A`1:BTX0CTi>03@d=01YJFT0NGUi04=3@`1EEED0LW9b05YJFP0e=CD0E5AD05eMG@1RHV80CTi>
06i^KP1KFe/0EeMG06e]K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0LW9b05]KF`1?Cdl0I6AT
08F5Q@1DE5@0Bd];05iNGP0m?Cd0CTi>06IVIP1NGUh0IfMW04e=C@1bLW80[Jf]04M7A`1QHF40IFEU
079bLP0k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`1kNg/0U9BD06MWI`1CDe<0ADE5
05EEE@1LG5`0ATI605ADE02JVYX0JFUY08>3P`1UIFD0F5QH07AdM01OGel0HV9R07EeM@22PX80a<C4
09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06=SH`1>CTh0EeMG04m?C`1gMgL0N7Qh
0:BTY02ATI40De=C05mOG`1lO7`0BTY:07moO`2>SXh0[Zj^017ooooo000?ooooo`0I0:RXZ01^KVh0
Ogmo06][J`2DU9@0DE5A06YZJP2<S8`0G5aL07QhN02CTi<0>SXj04A4A01^KVh0F5QH09>CT`1@D500
;Bd]05ADE01oOgl0De=C08>3P`2a/K40@d=305ADE002075aL@2j0:>SX`1DE5@09bLW04Y:BP2?Shl0
CDe=08:2PP0U9BD0=3@d06m_K`2ATI40CTi>08N7Q`1WIfL08B4Q04Q8B01aLG40DU9B08j>SP18B4P0
;bl_05iNGP1`L700EEEE075aL@1YJFT0>c/k07UiN@24Q8@0?Shn06e]K@1NGUh0?Shn05ADE01OGel0
Bd];05aLG00^;Rh0=CDe08^;R`2EUID0?Shn059BDP1QHF40>CTi05mOG`20P800?3`l05YJFP1PH600
<c<c061PH02d];@0MgMg03hn?P1CDe<0?clo06m_K`2i^KT0HF5Q03/k>`1HF5P0?Cdm06i^KP2DU9@0
A4A405IFEP1SHf<0BDU904e=C@23Ph<0VYZJ04A4A012@T80EUIF04m?C`1dM7@0N7Qh03Ti>@1GEeL0
De=C0410@027QhL0QXJ603Ti>@1JFUX0Jf][04Q8B02<S8`0TY:B04E5A@12@T80DE5A04e=C@29RHT0
PH6102l_;`18B4P0J6QX06a/K01SHf<0][Jf07emO@14A4@0MgMg08B4Q022PX80Z:RX03Xj>P12@T80
I6AT07UiN@17AdL0SXj>038b<P1CDe<0JFUY07IfMP18B4P0TI6A071`L00o?cl0KFe]05YJFP1UIFD0
]KFe0451@@1=CDd0Ng]k09fMW@1jNWX0LW9b071`L01DE5@0P82009FEU@14A4@0LG5a07MgM`16ATH0
KFe]0:2PX01]KFd0JVYZ06=SH`1HF5P0L71`08V9R@2?Shl0GEeM07IfMP1bLW80Vi^K09NGU`14A4@0
EEEE071`L01OGel0HF5Q09NGU`2RXZ80IFEU09BDU01EEED0TY:B09fMW@1?Cdl0Jf][0:j^[P1`L700
F5QH0:JVYP0o?cl0L71`08f=S@24Q8@0W9bL08j>SP0o?cl0I6AT06m_K`23Ph<0^KVi04a<C013@d<0
KFe]0P1/K6`0;P2VYZH0G5aL06=SH`2OWil0LW9b0:JVYP1lO7`0;2`/07emO@2][Jd0EEEE09NGU`1E
EED0Bd];09BDU027QhL0Q8B408V9R@0h>3P0EeMG07UiN@2=SHd0Zj^[08^;R`11@D40DU9B06][J`20
P800GUiN0:ZZZP1EEED0CDe=08N7Q`1<C4`0F5QH0:FUY@1=CDd0<S8b04];B`2;Rh/0EUIF07]kN`1;
Bd/0@d=3069RHP2?Shl205eMG@0K09FEU@1?Cdl0J6QX07moO`0m?Cd0KVi^06EUI@0l?3`0DE5A0820
P01jNWX0EeMG05]KF`0^;Rh0De=C08R8R02BTY80EEEE06][J`1TI6@0>CTi02l_;`24Q8@0=CDe0451
@@1jNWX0EeMG01cooooo00h0HF5Q05UIF@1hN7P0IFEU065QH@1NGUh0IFEU07inOP17AdL0?clo05mO
G`18B4P0H61P05UIF@80GUiN0700Kfm_051@D01WIfL0J6QX051@D012@T80;bl_05]KF`0n?Sh0?Cdm
06IVIP10@400?3`l05EEE@1TI6@0Hf=S061PH01DE5@0IVIV06][J`1LG5`0EeMG06e]K@1?Cdl0C4a<
03Ti>@0m?Cd0E5AD065QH@1BDU80De=C05iNGP0h>3P0>c/k05YJFP1_Kfl0CTi>05]KF`0d=3@0C4a<
05UIF@17AdL0EUIF05aLG01=CDd0IfMW065QH@1GEeL0G5aL05MGE`13@d<0IVIV06YZJP20P800KVi^
0:j^[P1QHF40XZ:R09RHV02EUID0MGEe05UIF@1cLg<0ADE505QHF01bLW80JFUY05aLG036a/H0[Jf]
06YZJP1UIFD0FUYJ08J6QP1eMGD0Fe]K0410@01VIVH0EeMG05UIF@0h>3P0GemO03@d=01?Cdl0CDe=
05EEE@1>CTh0JFUY04];B`1DE5@0H61P04=3@`1ADE40F5QH05]KF`1EEED0Bd];05YJFP1cLg<0AdM7
07MgM`14A4@0J6QX051@D01TI6@0>SXj04U9B@1QHF40IfMW06a/K01XJ6P0FUYJ0P1DE5@0K@1FEUH0
CDe=09BDU01LG5`0<S8b071`L029RHT0Kfm_09FEU@1OGel0Ogmo07UiN@1jNWX0ATI605ADE01HF5P0
GUiN05UIF@1_Kfl0AdM703Lg=`1CDe<0:BTY08F5Q@19BDT0FEUI069RHP1eMGD0DE5A04U9B@1;Bd/0
6a/K07]kN`1ADE40@41009bLW01OGel0?Cdm06=SH`1HF5P09RHV07alO01]KFd0?3`l07moO`1GEeL0
>CTi05QHF018B4P0IfMW05iNGP1_Kfl0LG5a0492@P1PH600A4A408>3P`1<C4`0K6a/05mOG`1cLg<0
?Shn04i>CP1CDe<0>SXj071`L01aLG40FUYJ06m_K`1oOgl0GemO055AD@1_Kfl0EeMG06=SH`0U9BD0
K6a/04Q8B017AdL0F5QH08b<S00^;Rh0Jf][05aLG00Q8B40D51@05IFEP0i>CT0ATI6065QH@1>CTh0
M7Ad04a<C01JFUX0HF5Q03hn?P1>CTh0HF5Q07AdM025QHD0CTi>07inOP2OWil0?Cdm07EeM@1UIFD0
I6AT03dm?@1EEED00P15ADD08`1IFET0F5QH05UIF@22PX80NGUi08>3P`2EUID0GUiN07IfMP1VIVH0
Hf=S06QXJ01UIFD0LW9b0;:b/P1iNGT0U9BD07emO@24Q8@0IfMW06][J`1lO7`0UYJF09bLW030`<00
WinO09bLW02QXJ40RHV90;>c/`25QHD0_;bl0<71`@1GEeL0G5aL0080FEUI00`0FUYJ071`L018B4P0
OWin061PH016ATH0DE5A07UiN@1<C4`0I6AT07inOP26QXHAooooo`003oooool0101ZJVX0Lg=c0<;2
`P1LG5`206=SH`0:08F5Q@37alL0<C4a04I6AP2JVYX0SXj>08^;R`2LW9`0<30`04Y:BP80O7al00l0
V9RH03@d=010@400@D5104A4A01^KVh0U9BD03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0
0P1>CTh0;P10@400Jf][034a<@0P8200TI6A09RHV00f=SH0?Cdm051@D00V9RH0L71`09ZJVP0j>SX0
Jf][04e=C@0e=CD0ATI609^KV`10@400Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@1@D500
SXj>034a<@0J6QX0>c/k03Ph>00j>SX0UIFE0=7Ad@0d=3@0?3`l04M7A`16ATH0Z:RX0<O7a`0Q8B40
6ATI05UIF@23Ph<206EUI@0K02TY:@0m?Cd0JVYZ07QhN021PH40Zj^[034a<@0];Bd0F5QH05aLG02V
YZH0[jn_04i>CP0X:2P0@T9207YjNP1[Jf/0XZ:R055AD@14A4@0Cdm?09RHV01UIFD0_;bl07=cL`0S
8b<0=3@d0080Fe]K0;80KVi^02h^;P1>CTh0ATI6079bLP2>SXh0W9bL0<;2`P13@d<0L71`09bLW01R
HV80Vi^K0<[:bP10@400Bd];06][J`2YZJT0RHV90861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]
KFd0BDU906][J`2>SXh0NWYj06m_K`0Y:BT0B4Q806ATI02QXJ40GEeM07MgM`0h>3P0CTi>05aLG02;
Rh/0De=C0<30`01nOWh0?3`l06=SH`2DU9@0@d=306QXJ01IFET0>SXj06a/K02SXj<0;Bd]03Lg=`1b
LW80CDe=09^KV`2b/[80;Rh^03dm?@1]KFd0EEEE059BDP2MWId0HF5Q05mOG`21PH40KFe]0;Ng]`2L
W9`0<S8b03dm?@18B4P0MgMg08j>SP2f][H0ATI604];B`1hN7P0Kfm_07alO02e]KD0GemO02`/;01K
Fe/0Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]01]KFd0BTY:07MgM`1^KVh0TY:B08>3P`0Z
:RX0BDU90820P02LW9`0V9RH059BDP0g=cL0GemO0;Ng]`1CDe<0[:b/06UYJ@19BDT0XJ6Q09fMW@1a
LG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL03hn?P1<C4`0VYZJ06ATI02EUID0[Jf]034a<@1;
Bd/0Kfm_08n?S`1/K6`0FUYJ02h^;P0i>CT0OGem0:2PX01:BTX0N7Qh06a/K00U9BD0Hf=S08j>SP0m
?Cd0Jf][0410@00g=cL0EEEE08j>SP2ZZZX0DE5A04];B`1ADE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k
>c/0D51@07MgM`0^;Rh0:RXZ05aLG01OGel0GUiN0861P@2KVi/0@T92024Q8@1IFET0E5AD04a<C02;
Rh/0TI6A7?ooool0S@1LG5`0AdM709:BTP1lO7`0LG5a05=CD`1LG5`0KVi^06a/K01:BTX0FUYJ05EE
E@1LG5`0A4A406UYJ@1dM7@0MGEe07=cL`2@T900M7Ad04Y:BP1MGEd0?Shn059BDP1>CTh0BDU905eM
G@0d=3@0CDe=069RHP1bLW80J6QX07EeM@1ZJVX0F5QH08b<S01SHf<0EEEE096AT@1:BTX0@d=302DU
9@0X:2P0EeMG065QH@1MGEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@0BDU906QXJ00T92@0@41006UY
J@14A4@0EUIF03Ti>@0U9BD0E5AD05UIF@0a<C40:2PX04A4A00k>c/0@d=303<c<`1EEED0EeMG065Q
H@0a<C40FEUI071`L024Q8@0?Cdm03Lg=`1jNWX0C4a<065QH@1?Cdl0>c/k06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0BTY:034a<@16ATH0A4A404Y:BP0c<c<0IVIV02/[:`1@D500BDU906MW
I`14A4@0IfMW061PH01@D500KFe]03<c<`1PH600B4Q805aLG01HF5P0>SXj051@D01`L700CTi>07al
O010@400J6QX04Q8B01WIfL0=3@d05EEE@1aLG40FUYJ07=cL`20P800G5aL04i>CP0f=SH0>SXj02HV
9P2TY:@0K6a/03lo?`1nOWh0WYjN06a/K02NWYh0Bd];0;Bd]00207YjNP1:05mOG`1YJFT0H61P05YJ
FP1SHf<0Jf][04I6AP19BDT0Hf=S02@T902=SHd0G5aL061PH01HF5P0FUYJ05=CD`11@D40Bd];02TY
:@2NWYh0IVIV05iNGP3Bd]80QXJ603Hf=P1VIVH0MWIf03Ti>@2CTi<0NGUi04I6AP1BDU80>CTi03Lg
=`1CDe<0CDe=07EeM@16ATH0Ogmo061PH00l?3`0DU9B02DU9@1aLG40B4Q806][J`1KFe/0J6QX03Hf
=P1RHV80GUiN04I6AP1eMGD0MgMg051@D01NGUh0N7Qh06e]K@15ADD0CDe=051@D01YJFT0;2`/059B
DP1=CDd0O7al07IfMP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D50203lo?`0804];B`1@D500IfMW
04A4A01=CDd0EeMG03dm?@15ADD205aLG00605QHF00j>SX0IVIV08N7Q`13@d<0HV9R0P1VIVH03@16
ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1HF5P0LW9b05QHF01JFUX00P1?Cdl09P1K
Fe/0Hf=S05]KF`23Ph<0GUiN07moO`1SHf<0TI6A06a/K01CDe<0G5aL05ADE01HF5P0VYZJ06EUI@1@
D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>05MGE`1<C4`0E5AD051@D01aLG40@41008b<S01T
I6@0@410055AD@26QXH0H61P05IFEP25QHD0OGem4Oooool000oooooo08T0WYjN05QHF01KFe/0XJ6Q
071`L012@T80ADE508R8R02LW9`0MGEe05EEE@0Y:BT0G5aL08N7Q`1BDU80J6QX051@D00k>c/0QHF5
0;2`/00k>c/0?Shn04=3@`1:BTX0Ng]k065QH@0_;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0@410
03Lg=`1fMWH0bl_;06MWI`0D51@0?clo08:2PP14A4@0NGUi08J6QP0[:b/0EUIF0:BTY017AdL0^;Rh
08n?S`0^;Rh0?3`l06a/K01hN7P0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0T92@0GemO
06IVIP1DE5@0WYjN04A4A00U9BD0=CDe06a/K01mOGd0HF5Q04U9B@0O7al0Cdm?09NGU`1QHF40C4a<
09FEU@0b<S80:b/[06i^KP0o?cl0H61P0:BTY00k>c/0EUIF092@T022PX80EUIF06UYJ@0i>CT0A4A4
06UYJ@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1JFUX0?clo06m_K`0n?Sh0=CDe051@D01cLg<0=CDe
0492@P1=CDd0DU9B0:NWY`1?Cdl0:2PX06MWI`1[Jf/092@T04m?C`2JVYX0@41005MGE`1;Bd/0A4A4
05QHF02VYZH0EeMG03dm?@1UIFD0CDe=07]kN`2k^k/0B4Q804A4A01JFUX0JFUY06MWI`0209nOW`0^
03`l?01>CTh0@D5109NGU`2[Zj/0;Rh^03Ph>01FEUH0MGEe05ADE02h^;P0B4Q8051@D01`L700Ti>C
06a/K02^[Zh0W9bL03<c<`1>CTh0N7Qh096AT@2YZJT0BTY:04E5A@1ADE40JVYZ05iNGP1_Kfl0[Zj^
0492@P1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY07moO`2b/[80Xj>S04=3@`1CDe<0V9RH
08J6QP80Ph>306L0CDe=04i>CP2HV9P0NGUi05iNGP1kNg/06QXJ04M7A`2WYjL0T92@05=CD`1lO7`0
>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0@41006YZJP2[Zj/0DE5A08:2PP0^;Rh0I6AT0;fm_@2IVIT0
B4Q807UiN@0k>c/0N7Qh08b<S00g=cL0GemO04Q8B01GEeL0Shn?07MgM`0i>CT0IVIV071`L02QXJ40
WYjN04M7A`1IFET0HF5Q04];B`1VIVH0/K6a055AD@1iNGT0XZ:R06m_K`2ATI40clo?04M7A`18B4P0
IFEU05ADE01jNWX0V9RH02l_;`11@D40EUIF065QH@1JFUX0S8b<08^;R`0Z:RX0G5aL08V9R@2PX:00
aLG5061PH00j>SX0HF5Q05YJFP1OGel0Y:BT03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g=cL0
?Cdm06][J`1DE5@0NGUi0;Ng]`1DE5@0>3Ph05]KF`1hN7P0De=C05QHF022PX807AdM02d];@0l?3`0
LG5a01cooooo02@0A4A404Q8B01kNg/0De=C06m_K`1<C4`0EeMG09VIV@19BDT0IFEU06QXJ01BDU80
IFEU04I6AP1LG5`0HV9R05mOG`15ADD0GEeM06i^KP1CDe<0A4A4030`<01EEED0@41003dm?@1SHf<0
BTY:03Xj>P1QHF40Hf=S0861P@1PH600CTi>06IVIP1WIfL206m_K`3107]kN`15ADD0F5QH0492@P0X
:2P0F5QH07]kN`1<C4`0A4A405=CD`0o?cl0EEEE07UiN@1/K6`0CDe=06MWI`0n?Sh0AdM7061PH01>
CTh0GUiN0451@@0b<S80H61P065QH@0o?cl0AdM705]KF`14A4@0Lg=c05YJFP1XJ6P0G5aL0:6QX@1:
BTX0MgMg06ATI02UYJD0G5aL04I6AP1IFET0@41005]KF`1PH600D51@07YjNP3Fe]H0UIFE051@D01[
Jf/0F5QH06EUI@1YJFT0IFEU04=3@`1VIVH0N7Qh06i^KP0f=SH0I6AT02h^;P1gMgL0EUIF04];B`1:
BTX0GEeM0410@01<C4`0DE5A03dm?@1OGel0EUIF065QH@0e=CD0?3`l07IfMP1kNg/0H61P07]kN`1J
FUX0N7Qh05IFEP1dM7@0=cLg04A4A01KFe/0IFEU05iNGP1VIVH0H61P05aLG012@T80C4a<02`/;02Y
ZJT0MGEe01`L701XJ6P0IVIV071`L02WYjL0KFe]0:b/[025QHD0V9RH05EEE@1SHf<0AdM705QHF01c
Lg<0TI6A03Xj>P0f=SH0F5QH02/[:`1eMGD0Bd];05=CD`1UIFD0K6a/07AdM01GEeL0F5QH04M7A`21
PH40Ti>C07UiN@3inOT0]KFe04Y:BP1UIFD0M7Ad0492@P1lO7`0MgMg05iNGP1PH600MGEe05QHF01E
EED0CDe=04m?C`1@D500XZ:R07]kN`1ADE40EeMG02h^;P1NGUh0<C4a09BDU01CDe<0IVIV03Xj>P0o
?cl0FEUI06i^KP1eMGD0EeMG07IfMP24Q8@0Ogmo06m_K`1@D500G5aL06QXJ01QHF40BDU904];B`1@
D500M7Ad06IVIP2@T900>3Ph09ZJVP1YJFT06a/K04m?C`1ADE40=3@d04Q8B01CDe<0B4Q806i^KP19
BDT0AdM706IVIP1<C4`0DU9B06YZJP1[Jf/0OGem06i^KP0209BDU00f04a<C01UIFD0HF5Q0820P00b
<S80Shn?05YJFP1RHV80KVi^05UIF@1ADE40MgMg07alO026QXH0TI6A04E5A@1GEeL0BTY:04m?C`1J
FUX0G5aL06MWI`2LW9`0De=C08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0YJFU07MgM`1m
OGd0IFEU05eMG@1lO7`0KVi^0:BTY02ATI40>SXj061PH01:BTX0DU9B05ADE01[Jf/0:RXZ08:2PP1A
DE40ADE506EUI@1lO7`0CDe=0P1gMgL00`2@T93oooooooooo`0?ooooo`003oooool0402h^;P0EEEE
05aLG01jNWX0WIfM04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307moO`2VYZH203hn
?P1S05=CD`2OWil0PX:20<o?c`27QhL0=3@d05IFEP2a/K40IfMW0:ZZZP0m?Cd0?Shn05eMG@2NWYh0
NWYj08^;R`0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P25QHD0?3`l06QXJ00g=cL0
71`L04=3@`2=SHd0Jf][06ATI02:RXX0?3`l0:ZZZP2NWYh0CTi>07EeM@0n?Sh0?3`l05]KF`2DU9@0
A4A404Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<06a/K01NGUh0=cLg05eMG@1IFET0
BDU904M7A`2i^KT0Ph>3034a<@19BDT0=CDe075aL@2/[:`0;Rh^038b<P1UIFD0EEEE05eMG@2KVi/0
;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017AdL0CDe=06UYJ@2c/k<0AdM703De=@1KFe/0
Hf=S04U9B@1gMgL0J6QX02@T901dM7@0NWYj051@D02b/[80Vi^K0080:2PX03l0Bd];05]KF`2i^KT0
NWYj038b<P1PH600QHF509BDU01kNg/0/;2`06][J`1ADE40Rh^;07MgM`1RHV80Ti>C02`/;013@d<0
OGem075aL@1TI6@0RXZ:03`l?01ADE40/k>c0:>SX`1KFe/0Y:BT05ADE011@D40LW9b09>CT`1LG5`0
QhN703Lg=`1OGel0KVi^09bLW01oOgl0QhN705aLG00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300
Cdm?0::RXP1IFET0Hf=S03`l?014A4@0HV9R0:j^[P26QXH0?Cdm08B4Q014A4@0K6a/09RHV00l?3`0
0P1<C4`0B@0c<c<0SHf=0;bl_013@d<0Bd];07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27QhL0
GEeM0:NWY`0S8b<0HV9R08N7Q`1cLg<0WYjN07emO@0/;2`0?Shn06QXJ02IVIT0clo?02l_;`0b<S80
GEeM09BDU02JVYX0bLW90451@@14A4@0Rh^;06m_K`2k^k/0QXJ60451@@1VIVH0NGUi051@D02IVIT0
MWIf03<c<`1lO7`0LW9b0:6QX@1jNWX0<30`05EEE@1WIfL0QXJ60:BTY01`L700?Shn079bLP1gMgL0
PH61075aL@3>c/h0B4Q806e]K@2k^k/0EEEE065QH@2c/k<0@41004Q8B01PH600Z:RX08:2PP2JVYX0
0P0l?3`07`2CTi<0Xj>S04a<C02>SXh0ZJVY03lo?`1BDU80LW9b030`<01IFET0OWin04Q8B01TI6@0
WinO08V9R@0j>SX0KVi^04M7A`0m?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<09fMW@1:BTX0
Cdm?08J6QP1DE5@07?ooool0@013@d<0BDU907alO01OGel0NWYj04a<C01@D500Q8B404a<C01DE5@0
HF5Q05EEE@1XJ6P0EUIF06e]K@1ZJVX0TY:B06a/K01fMWH0HF5Q04a<C01ADE40:2PX04i>CP0f=SH0
:BTY04Q8B00L71`0@D5104a<C01IFET0F5QH07YjNP1SHf<0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0
FUYJ03/k>`0n?Sh0Bd];05ADE01ADE40EeMG06EUI@10@400?Shn04U9B@1_Kfl0@T9204A4A00o?cl0
CDe=05ADE00k>c/0EeMG05IFEP0c<c<0IFEU061PH016ATH304e=C@0F05aLG01BDU80T92@07QhN02_
[jl0A4A408J6QP24Q8@0UYJF06m_K`1VIVH0Hf=S03De=@1CDe<0NGUi05UIF@1GEeL0XJ6Q08J6QP1G
EeL0EUIF059BDP80KFe]00h0AdM703Xj>P1UIFD0CDe=05mOG`15ADD0LW9b04E5A@14A4@0Bd];04i>
CP1<C4`0De=C05MGE`80GemO0400@d=306YZJP15ADD0DU9B061PH01NGUh0CTi>06=SH`1BDU80MWIf
06ATI02:RXX0E5AD06EUI@0d=3@0Bd];05]KF`1iNGT0MWIf06][J`1bLW80SHf=079bLP1hN7P0@d=3
08b<S01aLG40=3@d04M7A`1FEUH0I6AT08n?S`1ADE40O7al05EEE@1^KVh0?Cdm04E5A@1YJFT0Lg=c
05=CD`1IFET0BTY:038b<P1CDe<061PH08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B01QHF40DE5A
0;Ng]`1mOGd0QHF50=KFeP2SXj<0DE5A06UYJ@1cLg<0A4A40P1mOGd0M@12@T80Kfm_04m?C`0f=SH0
CTi>04e=C@22PX80CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1BDU80H61P079bLP1CDe<0
DU9B05eMG@1;Bd/0IFEU04a<C01HF5P0E5AD061PH01SHf<0EeMG07UiN@1RHV80MgMg04A4A01RHV80
JVYZ06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]06ATI01PH600DU9B05MGE`1VIVH0
Hf=S04];B`1MGEd0?3`l04e=C@1EEED0L71`07=cL`19BDT0HF5Q06e]K@0k>c/0K6a/05iNGP1VIVH0
E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0MgMg09BDU01<C4`0DE5A01/K6`1:BTX0
Hf=S05iNGP1VIVH0T92@06][J`2HV9P0RHV9096AT@1eMGD0De=C07alO02=SHd0Ph>309jNWP1eMGD0
QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D01mOGd0AdM7051@D01[Jf/0TI6A05iNGP1aLG40
GemO05EEE@1?Cdl0LW9b05iNGP1_Kfl0TI6A08F5Q@0Aooooo`003oooool0<@2IVIT0Rh^;0:^[Z`1>
CTh0KVi^06QXJ019BDT0P82002XZ:P1RHV80[Zj^08:2PP1JFUX0PX:202h^;P2DU9@0/[:b05EEE@20
P800D51@04Y:BP1WIfL0ZJVY059BDP1GEeL0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1m
OGd0>c/k01lO7`0j>SX0MWIf06MWI`2EUID0Ogmo034a<@0[:b/0G5aL04i>CP2IVIT0LG5a028R8P0]
;Bd00P1IFET0_01SHf<0/;2`02<S8`0^;Rh0LW9b06MWI`2>SXh0>CTi02DU9@1<C4`0IVIV05MGE`2Q
XJ40820P038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1BDU80KFe]04a<C02PX:00MGEe02`/;00j
>SX0ADE507YjNP1@D500Ph>3034a<@0W9bL0M7Ad08f=S@1>CTh0OWin03<c<`0i>CT0MWIf09:BTP23
Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q0451@@18B4P0CDe=07inOP1GEeL0Ph>306EUI@0_
;bl0I6AT096AT@1EEED0IfMW038b<P0m?Cd0IfMW0:ZZZP1;Bd/0:RXZ014A4@0X:2P0GemO09JFUP0k
>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0EUIF08^;R`1HF5P0OWin0=WIf@2OWil0=CDe06a/K01W
IfL0?3`l08n?S`0i>CT0@41005IFEP1RHV80KVi^09FEU@1TI6@0:b/[06YZJP20P800KFe]09VIV@1J
FUX0>c/k0::RXP2GUiL0IVIV0:j^[P1jNWX0?Shn065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2F
UYH0MGEe0:VYZ@0k>c/0AdM70492@P20P800XJ6Q06UYJ@2n_[h0>3Ph06EUI@2IVIT0Ng]k07moO`1b
LW80?clo04m?C`24Q8@0SHf=08J6QP1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@02R
XZ80Kfm_06QXJ01BDU80=cLg06IVIP2OWil0IFEU06ATI01LG5`0BTY:0;Vi^@2ATI40De=C04Y:BP0X
:2P0FEUI08>3P`29RHT0OGem059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX08B4Q01L
G5`0Bd];038b<P2FUYH0`<3005EEE@19BDT0FUYJ059BDP2^[Zh0ZZZZ0P0o?cl0<@1WIfL0A4A4065Q
H@2/[:`0GEeM03hn?P1`L700LG5a07UiN@2n_[h0GUiN03Ti>@1EEED0DE5A06UYJ@2LW9`0FEUI02HV
9P1GEeL0K6a/04Y:BP2SXj<0e]KF04=3@`16ATH0IFEU071`L02PX:00T92@030`<00/;2`0Hf=S08>3
P`1ZJVX0UIFE04I6AP0l?3`0A4A408J6QP1hN7P0Ng]k0:6QX@0Y:BT0@41009>CT`1XJ6P0Ph>30:f]
[@1EEED07?ooool0P@14A4@0IFEU08:2PP1ZJVX0K6a/04];B`1<C4`0L71`06][J`1NGUh0T92@07]k
N`1JFUX0@T9207alO01[Jf/0Fe]K04M7A`1PH600EEEE04e=C@1LG5`0BTY:06IVIP1FEUH0DE5A05AD
E00Y:BT0?Shn04m?C`1ADE40FUYJ05eMG@1=CDd0Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d
=00V9RH0BTY:05aLG01:BTX0ATI608j>SP1<C4`0De=C05aLG02<S8`0>SXj06m_K`0l?3`0?clo061P
H01FEUH0FEUI05EEE@10@400E5AD05UIF@0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079b
LP19BDT0FEUI05mOG`1/K6`0H61P04m?C`24Q8@0@d=305]KF`1PH600De=C06e]K@2j^[X0QHF505UI
F@1JFUX0De=C05]KF`1TI6@0D51@03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804Y:
BP1;Bd/0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`1[Jf/0AdM705YJFP1`L700Fe]K09VI
V@1DE5@0Jf][05MGE`1PH600?3`l06QXJ01VIVH0?3`l06a/K02JVYX0Kfm_06ATI00208B4Q00B05iN
GP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60;6a/@1LG5`0EEEE065QH@1MGEd0;bl_0492
@P1FEUH0GemO0P0j>SX0L@1KFe/0<30`069RHP1UIFD0GUiN06MWI`1:BTX0E5AD06=SH`1RHV80?clo
07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@1JFUX0?clo0:JVYP1ZJVX0?clo07EeM@1=CDd0<C4a
05=CD`0k>c/0HF5Q04];B`1hN7P0Bd];0492@P13@d<07alO05IFEP0k>c/0LG5a05iNGP1ZJVX0<S8b
07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=3055AD@1cLg<0IVIV03<c<`1ADE40ATI605MGE`19BDT0PH61
06=SH`1UIFD0Hf=S07emO@1MGEd0XJ6Q07EeM@0^;Rh0E5AD04A4A00n?Sh0Cdm?06a/K01GEeL0L71`
05QHF01:BTX0Fe]K05IFEP1=CDd0FUYJ05UIF@2CTi<0CTi>06YZJP1[Jf/07AdM05MGE`1EEED0IFEU
05aLG02NWYh0G5aL05EEE@1MGEd0Fe]K03/k>`1EEED0O7al07QhN02<S8`0FUYJ05QHF00n?Sh0E5AD
05]KF`0c<c<0HV9R07emO@1LG5`0V9RH05iNGP2GUiL0R8R8059BDP1HF5P0NWYj0080Zj^[00T0F5QH
0820P01mOGd0S8b<0;6a/@1mOGd0Zj^[07inOP15ADD00P1TI6@03@1UIFD0H61P05iNGP18B4P0QXJ6
05ADE013@d<0ATI606][J`1TI6@0N7Qh06UYJ@2<S8`04Oooool000oooooo07@0PX:208F5Q@2ZZZX0
QXJ606MWI`1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0j>SX0EeMG07inOP1RHV80
`l?308F5Q@0L71`0HF5Q0:2PX01mOGd0Vi^K03De=@1=CDd0F5QH0:ZZZP29RHT0JVYZ06][J`0e=CD0
FEUI07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO05YJFP0_;bl0Hf=S069RHP1BDU80
PX:205aLG00S8b<0@D510::RXP1iNGT0IVIV01TI6@0m?Cd0F5QH05ADE01>CTh0IFEU06][J`0c<c<0
Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD0:^[Z`1BDU80B4Q803Ti>@0X:2P0K6a/0;Rh^012@T80
@41004E5A@0];Bd0=3@d08>3P`0`<300>SXj04M7A`1RHV80LW9b08Z:RP19BDT0;Rh^04I6AP1ZJVX0
Ogmo09JFUP15ADD0<S8b04e=C@17AdL0I6AT09fMW@1KFe/0Bd];05UIF@1?Cdl0H61P0;Zj^P2:RXX0
;2`/0492@P1RHV80FEUI0;Vi^@0m?Cd0<C4a04m?C`80LG5a07T0>SXj01`L700M7Ad0DE5A065QH@1V
IVH0XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0SHf=0;Zj^P0e=CD0De=C09>CT`2m_Kd0JVYZ0;Rh^01Z
JVX0>3Ph08:2PP2ATI40QXJ607emO@0S8b<0C4a<06a/K02QXJ40MWIf09VIV@0o?cl0H61P05iNGP2>
SXh0IVIV0;Bd]02FUYH0@4100492@P27QhL0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0F5QH0492@P2H
V9P0C4a<07AdM02KVi/0BDU905QHF01NGUh0>c/k04Q8B02CTi<0EeMG05QHF01JFUX0@D5109RHV01i
NGT0?clo05=CD`1nOWh0CDe=06e]K@2PX:00BTY:05QHF01QHF40Jf][06YZJP2VYZH0DE5A02`/;01J
FUX0N7Qh09fMW@1[Jf/0=3@d04a<C01KFe/0Jf][08Z:RP23Ph<0:b/[05eMG@1KFe/0MgMg08f=S@12
@T80?Shn05UIF@1kNg/0ZJVY05iNGP0o?cl0Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI08Z:RP2G
UiL0Ogmo04m?C`16ATH0Ti>C08Z:RP1oOgl0WIfM03Ph>02ATI40Z:RX0080VIVI0340Xj>S03<c<`1D
E5@0Shn?07moO`1VIVH0De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0Ng]k0;^k^`1R
HV80UYJF05QHF00o?cl0C4a<079bLP2GUiL0GEeM03`l?00W9bL0C4a<07QhN01DE5@0Bd];05UIF@0h
>3P08b<S05IFEP1@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@1:BTX08R8R0410@02j
^[X0Ng]k01cooooo06<0@D51075aL@2NWYh0LG5a06MWI`1[Jf/0JFUY07UiN@14A4@0@d=304];B`1A
DE40De=C0410@01?Cdl0BTY:051@D01?Cdl0LW9b0861P@1]KFd0BDU903De=@1_Kfl0?Shn03Ti>@24
Q8@07AdM04E5A@1TI6@0MgMg08>3P`1ZJVX0G5aL05iNGP1]KFd0CTi>03`l?01IFET0IFEU07alO018
B4P0=SHf04e=C@1VIVH0Cdm?04Y:BP1QHF40DE5A051@D01ZJVX0Ph>3065QH@1lO7`0?Cdm04A4A01R
HV80I6AT06YZJP1DE5@0<30`06UYJ@1`L700@4100492@P1IFET0D51@06YZJP1EEED0I6AT05]KF`2a
/K40@41008V9R@1jNWX0YJFU061PH01>CTh0Jf][04A4A01`L700HF5Q05eMG@2:RXX0`L7109NGU`1C
De<0J6QX065QH@1XJ6P0NGUi05EEE@0i>CT0Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0FP1<
C4`0Hf=S06ATI01OGel0>3Ph06][J`0j>SX0De=C0492@P1dM7@0H61P04a<C01OGel0LW9b05IFEP2=
SHd0IFEU07YjNP1[Jf/0R8R802l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k09:BTP1F
EUH0Y:BT07moO`0^;Rh0Ogmo09JFUP1_Kfl0X:2P06m_K`2HV9P0M7Ad06MWI`11@D40FUYJ02h^;P13
@d<0EUIF069RHP0n?Sh0<30`04a<C00A4A40Ph>3055AD@1UIFD0Ng]k05mOG`1EEED0?3`l04e=C@0a
<C40SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P06MWI`0P8200Bd];03Xj>P1NGUh0TI6A05aLG01=
CDd0Jf][04=3@`1gMgL0>3Ph09VIV@1MGEd0DE5A05]KF`0S8b<0EEEE02XZ:P1ZJVX0IFEU07YjNP80
Bd];02l0DU9B06YZJP1fMWH0>c/k06=SH`1[Jf/0HF5Q06m_K`1fMWH0QHF505ADE024Q8@08B4Q05mO
G`1_Kfl0GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0BDU904a<C01FEUH0DU9B06UY
J@19BDT0ADE505aLG00h>3P0?clo06QXJ015ADD0T92@055AD@2OWil0Ogmo02l_;`1ZJVX0GemO08R8
R010@400LG5a03`l?00206a/K009079bLP1ZJVX0IVIV07YjNP1JFUX0JVYZ04a<C01JFUX0@D510080
DU9B02D0>SXj06=SH`1_Kfl0DE5A07=cL`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0]kNg05AD
E02;Rh/0HF5Q08>3P`2TY:@0FUYJ0=cLg03?cll0Kfm_06YZJP11@D40Cdm?07EeM@2CTi<0@410071`
L01FEUH0F5QH04e=C@1aLG40Hf=S04E5A@1mOGd0IVIV017ooooo000?ooooo`2N0=3@d01JFUX0JVYZ
0:ZZZP28R8P0Bd];04I6AP2ZZZX0T92@06m_K`1UIFD0@D5103Hf=P1UIFD0NWYj08j>SP17AdL0>CTi
04E5A@2MWId0EeMG05]KF`1XJ6P0;bl_05YJFP1]KFd0AdM709:BTP0i>CT0EEEE06ATI01]KFd0>c/k
06m_K`0O7al0@41008j>SP2FUYH0<c<c04A4A01NGUh0=SHf05YJFP1eMGD09RHV04E5A@1`L700@410
09RHV02][Jd0;2`/028R8P1>CTh0NWYj09>CT`0d=3@09BDU06IVIP1EEED0DU9B09fMW@1gMgL07QhN
059BDP1EEED0GEeM09JFUP1EEED0;Bd]02h^;P1ZJVX0IVIV08^;R`18B4P0>CTi0492@P1FEUH0KFe]
07]kN`2NWYh09bLW04a<C01dM7@0MgMg07inOP2<S8`0<S8b04=3@`1HF5P0PX:205=CD`1jNWX092@T
04M7A`1hN7P0Xj>S05QHF02LW9`0>c/k01`L701CDe<0MgMg07IfMP24Q8@0@D5103Ph>01`L700_kno
06a/K01bLW80BTY:038b<P1GEeL0P8200451@@2o_kl0EUIF02d];@0^;Rh0AdM7059BDP1RHV80Lg=c
038b<P1gMgL0ZJVY05]KF`0g=cL0NWYj05eMG@1ZJVX0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>
07emO@0h>3P0Cdm?05IFEP1eMGD0V9RH04A4A00h>3P0HF5Q03De=@1ZJVX0VIVI06UYJ@0j>SX0DU9B
05]KF`1WIfL0Xj>S0:b/[00b<S8204a<C02206MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0
cLg=0451@@1FEUH0EEEE07EeM@33`l<0_[jn03`l?01ADE40HF5Q05mOG`2l_;`0Xj>S02PX:01;Bd/0
UIFE04m?C`2GUiL0`l?304Q8B01CDe<0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
NWYj0410@01nOWh0_;bl06][J`2g]kL0AdM70451@@1XJ6P0];Bd06QXJ02MWId0;Rh^05mOG`2j^[X0
P82006i^KP1VIVH0>3Ph092@T02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0CDe=08F5Q@1SHf<0
M7Ad0:f][@1^KVh0GemO08f=S@1ADE40G5aL0;2`/01ZJVX0O7al0:>SX`1BDU80GemO0<C4a01mOGd0
Cdm?07]kN`1BDU80FEUI08>3P`0f=SH0@D5105eMG@17AdL0@41007YjNP2HV9P0:RXZ04i>CP1fMWH0
CTi>07moO`2JVYX0<S8b05QHF01ZJVX0PH6109NGU`1NGUh0>3Ph05=CD`1QHF40De=C0820P02SXj<0
=SHf03Lg=`15ADD0De=C05EEE@1mOGd0D51@020P800e=CD0JFUY08j>SP1FEUH0JFUY03Lg=`0^;Rh0
KFe]09^KVacooooo0400>SXj06YZJP1HF5P0B4Q805mOG`13@d<0AdM708R8R013@d<0C4a<06MWI`1V
IVH0CDe=04I6AP1]KFd0Kfm_05mOG`1WIfL0FUYJ04A4A00l?3`0@T9202l_;`1@D500?Cdm03Ph>01<
C4`09bLW03<c<`17AdL0@d=303`l?01?Cdl0B4Q803`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b
<S80ATI604a<C01@D500FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`1CDe<0BDU9061PH01K
Fe/0=cLg05=CD`1UIFD0Bd];05aLG01GEeL0@D510P1IFET08P18B4P0DU9B05mOG`2ATI40Q8B40;Vi
^@16ATH0Ph>308F5Q@2PX:00Ng]k069RHP26QXH0>3Ph06UYJ@1bLW80JFUY075aL@2BTY80OWin05AD
E01CDe<0FEUI08J6QP1]KFd0Fe]K0492@P1^KVh0MWIf06EUI@0/;2`0VIVI04e=C@1TI6@204e=C@1Y
06UYJ@1LG5`0DU9B04e=C@1KFe/0>SXj051@D012@T80Fe]K06YZJP1^KVh0RHV907UiN@1NGUh0Y:BT
06m_K`2>SXh0L71`08B4Q01:BTX0Cdm?08R8R01FEUH0OWin08F5Q@2FUYH0JFUY05eMG@2a/K40M7Ad
0;^k^`2=SHd0=cLg06MWI`1cLg<0FUYJ08j>SP0n?Sh0TI6A05UIF@1TI6@0HF5Q05=CD`0l?3`0EeMG
09FEU@2=SHd0AdM704Q8B01PH600=CDe08>3P`1_Kfl0E5AD07emO@1]KFd0@41004E5A@1@D500<c<c
09FEU@1YJFT0GEeM0;2`/01SHf<0?clo05]KF`1CDe<0;Bd]05mOG`1DE5@0BTY:06IVIP1KFe/0>c/k
04];B`0i>CT0Ng]k05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0KVi^06e]K@1XJ6P0>c/k
04i>CP1<C4`0Cdm?05IFEP0`<300H61P05]KF`1IFET0G5aL05IFEP1[Jf/0DE5A0492@P0m?Cd0Jf][
0080CTi>02L0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00_;bl0?clo05QHF016ATH0De=C
05mOG`1<C4`0De=C04M7A`13@d<0BTY:06=SH`1oOgl0DU9B05MGE`1=CDd0A4A408b<S01DE5@0EeMG
04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad08V9R@28R8P00P1fMWH07@1XJ6P0EUIF
06UYJ@1KFe/0Ng]k07YjNP1FEUH0YZJV08F5Q@2_[jl0PH6108N7Q`1aLG40Y:BT07MgM`2VYZH0OWin
0;6a/@2<S8`0Ng]k08f=S@1mOGd0X:2P06IVIP16ATH0NWYj04Q8B017AdL0GUiN0080H61P00T0S8b<
05ADE013@d<0CTi>07emO@1JFUX0De=C065QH@1jNWX04Oooool000oooooo01<0/[:b061PH01ZJVX0
H61P08R8R01JFUX0>c/k04a<C01[Jf/0UIFE09bLW00k>c/0<C4a04=3@`1KFe/0/[:b05MGE`11@D40
EUIF0080Fe]K0780UYJF09:BTP0/;2`0CTi>065QH@1^KVh0b/[:05aLG00^;Rh0?Cdm06UYJ@17AdL0
][Jf02XZ:P11@D40DU9B061PH01JFUX0Zj^[0:f][@0K6a/0?Cdm0861P@1/K6`0T92@075aL@0a<C40
?Shn07IfMP22PX80Q8B408n?S`0`<300QHF509>CT`1SHf<0Ogmo04M7A`0T92@0CDe=08^;R`1DE5@0
H61P028R8P0X:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0EEEE05IFEP0/;2`0GUiN06IVIP0`<300
PH61096AT@1QHF40>SXj04I6AP1ADE40GemO09:BTP1MGEd0;Rh^04e=C@0i>CT0B4Q809BDU01:BTX0
B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01CDe<0O7al0;Fe]@16ATH0=CDe04I6AP1]KFd0
FEUI0820P02:RXX0=3@d04I6AP1@D500Bd];0<;2`P1^KVh09RHV0451@@1BDU80HV9R0;Jf]P1eMGD0
@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=055AD@28R8P0J6QX08F5Q@3AdM4203`l?01L092@T02_
[jl0IFEU08^;R`17AdL0Jf][0:2PX01eMGD0L71`0;>c/`1iNGT0:2PX0861P@2/[:`0PX:209fMW@0T
92@0A4A40:2PX02g]kL0R8R80:ZZZP1@D500B4Q809jNWP2c/k<0LG5a08R8R01MGEd07alO04i>CP2]
[Jd0KVi^0;6a/@1QHF40>CTi05=CD`33`l<0ZZZZ05=CD`26QXH0@D5105UIF@2[Zj/0TI6A07QhN01K
Fe/0:b/[04];B`1YJFT0Kfm_06i^KP0l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2d
];@0>c/k05QHF012@T80GUiN08V9R@1nOWh0Bd];04i>CP1QHF40TI6A0>c/k024Q8@0=cLg05eMG@1]
KFd0LW9b07moO`0b<S80FUYJ061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@04Y:BP14
A4@206e]K@0k09jNWP2j^[X0BDU903Xj>P1HF5P0PX:20<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU9059BDP1eMGD0EeMG09ZJVP2RXZ80@41003Xj>P1>CTh0F5QH06YZJP2CTi<0>c/k03dm
?@1JFUX0Vi^K06][J`2KVi/0V9RH02h^;P1UIFD0MWIf07QhN02TY:@0XJ6Q04A4A011@D40DU9B06][
J`13@d<0HV9R03<c<`13@d<0De=C07moO`0h>3P0>CTi04M7A`0g=cL0FUYJ08N7Q`0d=3@0A4A406][
J`1>CTh07?ooool0o`11@D40L71`08^;R`1PH600NGUi05eMG@1JFUX0W9bL051@D01?Cdl0Jf][061P
H01ZJVX0FEUI06EUI@1`L700LG5a07EeM@1dM7@0Lg=c05IFEP1CDe<09RHV05QHF00o?cl0>c/k06AT
I00K6a/0C4a<06m_K`2<S8`0MWIf065QH@1EEED0CDe=07QhN01YJFT0D51@08V9R@1DE5@0DU9B028R
8P0_;bl0?Cdm051@D013@d<0>SXj06YZJP14A4@0C4a<04m?C`1UIFD0<30`05eMG@0a<C40@d=306AT
I01<C4`0EEEE05MGE`0m?Cd0DE5A04e=C@1:BTX0NWYj05MGE`18B4P0Fe]K05IFEP1?Cdl0BDU906MW
I`1VIVH0Hf=S06YZJP1GEeL0@d=304U9B@17AdL0?Shn06ATI01GEeL0GemO07moO`2[Zj/0NWYj05YJ
FP1HF5P0Bd];05MGE`1QHF40ATI605UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05YJ
FP1ADE40E5AD06ATI01;Bd/0F5QH04a<C01JFUX0FEUI06a/K023Ph<0AdM704i>CP1bLW80TI6A0;2`
/01lO7`0T92@09FEU@2@T900G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800YjNW04Y:
BP1]KFd0Ng]k04A4A02GUiL0P82007emO@2WYjL0NWYj0;Fe]@2=SHd0TY:B05ADE01YJFT0GEeM06EU
I@1JFUX0IfMW04];B`0n?Sh0CTi>01hN7P2>SXh0Jf][05iNGP25QHD0KVi^075aL@1@D500HF5Q04A4
A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0MgMg04E5A@1^KVh0R8R805UIF@2?Shl0FEUI0492
@P1>CTh0FEUI08N7Q`18B4P0PX:2055AD@1CDe<0DE5A02d];@1=CDd0<C4a05iNGP1IFET0I6AT03dm
?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1PH600G5aL06IVIP1?Cdl0QXJ606YZJP1SHf<0=CDe06e]
K@1LG5`0?Shn06YZJP1WIfL0>3Ph05YJFP1BDU808R8R05iNGP0g=cL0=3@d04Y:BP1^KVh0DE5A05QH
F01IFET0DU9B055AD@1@D500ATI605MGE`1BDU80M7Ad04U9B@1OGel0JFUY03Ti>@1hN7P0F5QH061P
H01KFe/0QXJ604E5A@1EEED0F5QH08>3P`0j>SX0ATI6065QH@1jNWX0P82004a<C01CDe<0Cdm?07mo
O`1kNg/0BDU9061PH0008`1]KFd0Hf=S08b<S01eMGD0YJFU05QHF01[Jf/0M7Ad0:VYZ@1mOGd0^;Rh
07UiN@2g]kL0Xj>S0<71`@2l_;`0Fe]K09fMW@1fMWH0@D5106ATI01bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN01mOGd0BTY:05ADE01[Jf/0MGEe017ooooo000?ooooo`3X08f=S@29RHT0
/k>c06EUI@1aLG40/k>c0861P@2=SHd0>3Ph05UIF@2?Shl0/K6a07UiN@2d];@0>SXj07=cL`2][Jd0
IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S08N7Q`0_;bl0EUIF07alO02EUID0@d=305EEE@1;Bd/0
=cLg06m_K`1QHF40=cLg05IFEP0m?Cd0?3`l06MWI`24Q8@0Fe]K03Ph>00d=3@0@4100;jn_P2[Zj/0
<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0C4a<04Q8B00c<c<0=cLg07IfMP1_Kfl08R8R03<c<`1@D500
Hf=S0;fm_@0U9BD0;Bd]04E5A@1FEUH0@T9209^KV`2g]kL07alO04Q8B01UIFD0?Cdm08Z:RP2DU9@0
9RHV02PX:025QHD0Shn?06IVIP2FUYH0;Bd]03@d=027QhL0/K6a08J6QP2NWYh0<30`04Y:BP1^KVh0
P82008Z:RP37alL0>SXj05IFEP1BDU80WIfM05aLG01lO7`0Cdm?05IFEP25QHD0Shn?06IVIP2KVi/0
B4Q804=3@`1GEeL0Hf=S05eMG@1`L700;Rh^04e=C@1;Bd/0NWYj05aLG020P800O7al03Lg=`1BDU80
Rh^;04=3@`1cLg<0KVi^034a<@1;Bd/0O7al0;fm_@29RHT0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0
QHF504E5A@0j>SX0UIFE04Y:BP1RHV80MGEe038b<P1=CDd0G5aL09NGU`19BDT0Jf][03Ph>02ATI40
[jn_07inOP18B4P0I6AT065QH@1?Cdl0]kNg065QH@0g=cL0T92@05UIF@1:BTX0UiNG08^;R`0Q8B40
AdM7075aL@1VIVH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0c<c<0GEeM06QXJ01GEeL0
]KFe0;Ng]`0U9BD0B4Q807]kN`1MGEd0WYjN07MgM`0I6AT0GUiN0:n_[`1iNGT0K6a/0<;2`P0g=cL0
=SHf09jNWP1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A05]KF`1?Cdl0WinO09FEU@1SHf<0
VYZJ03/k>`1ADE40Vi^K07moO`1YJFT0Fe]K04Y:BP1SHf<0/;2`0820P02b/[80Kfm_04I6AP22PX80
KFe]06ATI01<C4`0?Shn05mOG`80XJ6Q02H0JFUY08:2PP0h>3P0CTi>09:BTP24Q8@0Ng]k09fMW@0e
=CD0@D510:VYZ@2a/K40Hf=S05=CD`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI607AdM023
Ph<0;2`/06QXJ019BDT0=cLg07emO@2k^k/0F5QH05mOG`1EEED0EUIF09JFUP3?cll0FEUI0410@080
H61P0100ADE509bLW011@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1SHf<0EUIF075a
L@3?cll0DU9B7?ooool0BP19BDT0LW9b08n?S`20P800Ogmo05=CD`1LG5`0I6AT04U9B@1=CDd0K6a/
07EeM@1BDU80ADE507YjNP1gMgL0Jf][05EEE@1RHV80KVi^05EEE@1<C4`0:2PX06=SH`1DE5@0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`17AdL0BDU9051@D01PH600IFEU0861P@1<C4`0GUiN
04U9B@0l?3`0BTY:06m_K`1BDU80ADE506e]K@17AdL0BTY:06MWI`1SHf<0>c/k075aL@0f=SH0CDe=
06][J`1DE5@0Hf=S05iNGP12@T80M7Ad06=SH`0k>c/0GUiN04Y:BP1;Bd/0DE5A05YJFP1IFET0EEEE
0:>SX`13@d<0MWIf0P28R8P0;`1;Bd/0BDU90451@@15ADD0Kfm_05EEE@1QHF40RHV90;6a/@2;Rh/0
FEUI06=SH`1ADE40Ng]k08b<S01FEUH0CDe=05iNGP1bLW80Hf=S05MGE`1oOgl0@D5104M7A`1NGUh0
BTY:05IFEP1cLg<0M7Ad04m?C`1VIVH0GEeM069RHP16ATH0NWYj06=SH`1ADE40E5AD07AdM01IFET0
KVi^05aLG01HF5P0Jf][08>3P`1ADE40BDU90080M7Ad0180T92@0:VYZ@1^KVh0E5AD05QHF02EUID0
De=C0<G5a@29RHT0=3@d05eMG@1[Jf/0HV9R08b<S01;Bd/0Jf][04e=C@1NGUh204U9B@2A05=CD`1=
CDd0L71`08B4Q01MGEd0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0Lg=c071`L01E
EED0T92@09nOW`2a/K40^KVi07EeM@1OGel0NGUi07alO01IFET0VIVI08:2PP1MGEd0R8R805mOG`0o
?cl0De=C0410@02>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@23Ph<0IfMW06EUI@15
ADD0BTY:05mOG`1YJFT0MgMg04];B`1TI6@0IfMW06ATI01ADE40?3`l08B4Q01QHF40NWYj05QHF01Z
JVX0LW9b04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A03/k>`1EEED0IfMW059BDP1b
LW80KVi^06EUI@1_Kfl0JFUY04Y:BP1LG5`0HV9R06a/K01@D500WIfM07inOP12@T80H61P04a<C01V
IVH0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2GUiL0LW9b04e=C@1>CTh0KVi^0451@@0a
<C40>SXj02d];@2LW9`0Ti>C06MWI`22PX80AdM707alO01_Kfl0OGem08V9R@2;Rh/0JVYZ0;6a/@1[
Jf/0Zj^[08b<S01jNWX0SXj>04];B`30`<00WinO07MgM`1OGel0C4a<05eMG@1hN7P0PX:206MWI`1]
KFd0IFEU07=cL`1[Jf/0O7al061PH01OGel0IfMW07UiN@0Aooooo`003oooool08@20P800F5QH06EU
I@25QHD0De=C055AD@1;Bd/0QHF503Ph>00g=cL0A4A4069RHP1gMgL0TY:B03Lg=`0o?cl0De=C0861
P@2@T900FUYJ01/K6`18B4P0E5AD03Xj>P2i^KT0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH
600206IVIP1308B4Q02n_[h0LW9b01TI6@1aLG40WIfM08B4Q02BTY80M7Ad02<S8`1FEUH0cLg=05=C
D`1oOgl0Jf][01lO7`10@400UIFE09BDU020P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][038b
<P1^KVh0Q8B403dm?@20P800A4A402d];@16ATH0Ng]k07EeM@1PH600=SHf02@T900e=CD0Kfm_069R
HP1ZJVX0P82003`l?016ATH0GemO04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R09>CT`0j>SX0FEUI0410
@01OGel0YJFU0820P015ADD0EEEE0451@@1:BTX0IFEU09BDU00204M7A`2W04I6AP1bLW80S8b<07]k
N`0];Bd0C4a<04m?C`1VIVH0_[jn05=CD`0_;bl0EeMG05=CD`15ADD0SHf=096AT@0i>CT0FUYJ07Mg
M`1YJFT0Rh^;0;:b/P14A4@0:RXZ06YZJP1eMGD0OGem0<O7a`0m?Cd0=SHf07emO@2:RXX0KFe]0<[:
bP1:BTX09bLW06QXJ01_Kfl0VIVI08N7Q`0Y:BT0@d=304];B`1jNWX0Kfm_0:6QX@0m?Cd0D51@07in
OP23Ph<0Vi^K0<o?c`2MWId07AdM075aL@2LW9`0P8200>o_k`1[Jf/0;bl_07AdM02/[:`0De=C07Ee
M@2BTY80?clo07]kN`3Fe]H0QXJ606m_K`2KVi/0?3`l059BDP1kNg/0LW9b09RHV01jNWX08B4Q04m?
C`2][Jd0HF5Q05eMG@1_Kfl0;Bd]05iNGP2RXZ80ADE504m?C`1VIVH0>CTi06][J`2RXZ80Ng]k03hn
?P1_Kfl0A4A40:VYZ@2[Zj/0C4a<08B4Q01iNGT0;Rh^07UiN@2GUiL0CDe=06e]K@1SHf<0KVi^0<_;
b`1JFUX0>c/k04M7A`1LG5`0[:b/08j>SP1>CTh0MgMg03De=@1?Cdl0bl_;0;2`/00];Bd0J6QX07in
OP1iNGT0MWIf02TY:@12@T80Lg=c05IFEP1`L700f][J0410@01<C4`0HF5Q06EUI@2IVIT0ZZZZ03@d
=019BDT0NGUi09:BTP2FUYH0RHV903Ph>016ATH0Hf=S09VIV@1OGel0UIFE0::RXP0n?Sh0Kfm_07mo
O`1OGel0_;bl08>3P`0`<300C4a<0:2PX029RHT0QXJ604=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0
4@0W9bL0Fe]K05]KF`1dM7@0CDe=06UYJ@11@D40>c/k06EUI@1cLg<0IVIV03dm?@1DE5@0:BTY04Q8
B01kNg/0UIFE01cooooo0400CTi>06IVIP1bLW80DU9B051@D01CDe<0EeMG06MWI`1=CDd0BDU904Y:
BP18B4P0EUIF05UIF@1=CDd0E5AD08j>SP2DU9@0FEUI061PH01FEUH0Bd];03Lg=`1EEED0@41004A4
A01UIFD0=3@d04m?C`1OGel0FEUI065QH@1?Cdl0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5
A@0e=CD0<S8b02/[:`1:BTX0Cdm?04Y:BP1[Jf/0CDe=065QH@2?Shl0LW9b03`l?01FEUH0<c<c04A4
A01ADE40?clo04M7A`15ADD0@D5106=SH`1KFe/0<C4a0P1HF5P0B`1IFET0D51@05eMG@1dM7@0I6AT
08F5Q@19BDT0NGUi075aL@20P800CDe=05IFEP1;Bd/0>c/k06EUI@1<C4`0CTi>06e]K@2SXj<0MgMg
051@D01<C4`0CTi>06=SH`1NGUh0DU9B04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1BDU80BDU9
04e=C@1SHf<0HV9R07QhN01kNg/0Kfm_04];B`1WIfL0NWYj06IVIP1dM7@0LW9b07inOP1eMGD0J6QX
092@T02CTi<0WYjN09VIV@1kNg/0Bd];04Y:BP1OGel0RXZ:06m_K`1EEED0LW9b08F5Q@1IFET0SHf=
04=3@`24Q8@0Lg=c04A4A027QhL0];Bd07inOP2MWId0RXZ:0:^[Z`0206=SH`2C04M7A`1IFET0Ng]k
05mOG`1@D500OWin05eMG@0e=CD0De=C01XJ6P2XZ:P0B4Q804a<C01LG5`0VIVI07YjNP1=CDd0AdM7
0451@@3@d=00Shn?09VIV@3Kfm/0R8R804I6AP1/K6`0M7Ad02DU9@1VIVH0E5AD055AD@29RHT0?3`l
04Y:BP1IFET0=cLg08F5Q@0f=SH0Ogmo04A4A00o?cl0GUiN04Q8B01WIfL0?3`l055AD@1EEED0Hf=S
055AD@1<C4`0GUiN06YZJP2>SXh0:b/[059BDP1XJ6P0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c
06e]K@1lO7`0EUIF07IfMP1@D500=CDe059BDP1ADE40=cLg06QXJ00l?3`0FEUI06IVIP1YJFT0IVIV
06][J`1JFUX0IfMW069RHP15ADD0?clo05mOG`1QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<
05aLG01MGEd0M7Ad05MGE`1?Cdl0EeMG08J6QP1WIfL0H61P07MgM`1[Jf/0GUiN05YJFP1dM7@0EEEE
05UIF@1SHf<0EUIF06EUI@1EEED0GUiN07inOP1@D500W9bL07YjNP1lO7`0IVIV09bLW02JVYX0/;2`
06MWI`2<S8`0LG5a0=WIf@2g]kL0Vi^K0=CDe02DU9@0Bd];0820P01gMgL0H61P05]KF`21PH40JVYZ
06IVIP1@D500CTi>04Y:BP25QHD0Hf=S07EeM@1YJFT0SHf=017ooooo000?ooooo`030:f][@1QHF40
IfMW0080OWin0?l0HV9R061PH01]KFd0F5QH06e]K@22PX80>c/k04A4A01nOWh0Hf=S09^KV`1KFe/0
?3`l07=cL`1aLG40D51@0820P02LW9`0<C4a05YJFP1OGel0JFUY08b<S00a<C40=CDe04m?C`1TI6@0
>c/k07emO@0L71`07QhN04i>CP1gMgL0F5QH06=SH`23Ph<09bLW03hn?P1OGel0@41008F5Q@1PH600
<c<c05ADE01fMWH0>c/k059BDP1XJ6P0?clo07MgM`1KFe/0?clo06IVIP0i>CT0<S8b05eMG@2=SHd0
DE5A06e]K@0l?3`0;Bd]07YjNP2;Rh/0?clo06=SH`1VIVH0@41006UYJ@2ATI40@41004i>CP1<C4`0
?3`l061PH02DU9@0Shn?03@d=01NGUh0?Cdm06IVIP2NWYh0LG5a03`l?01eMGD0IVIV04e=C@20P800
CDe=04Q8B028R8P0Jf][075aL@2@T900CTi>038b<P1MGEd0IfMW07EeM@2EUID0>SXj03/k>`1jNWX0
OGem04e=C@26QXH0UiNG03De=@1mOGd0MGEe05QHF02EUID0DU9B034a<@1>CTh0LG5a07=cL`1hN7P0
YZJV03Hf=P1@D500GEeM06=SH`1OGel0`L7106YZJP1:BTX0NGUi07AdM01mOGd0S8b<03lo?`1:BTX0
QHF50861P@1ZJVX0MgMg03<c<`1CDe<0QHF507IfMP1WIfL0Shn?04=3@`11@D40NWYj07inOP1^KVh0
WinO03<c<`1<C4`0UYJF0<C4a01bLW80Ph>305MGE`1BDU80][Jf0;Fe]@1HF5P0P82006UYJ@16ATH0
IfMW0:FUY@1KFe/0RHV9055AD@0l?3`0Kfm_0<g=c@1hN7P0BDU907UiN@12@T80Ogmo0=7Ad@1nOWh0
EUIF0820P01ADE40KFe]0:6QX@1EEED0I6AT05]KF`19BDT0Ng]k0<;2`P1TI6@0AdM707IfMP1XJ6P0
E5AD0:ZZZP1HF5P0IVIV06ATI01DE5@0UiNG0:BTY01CDe<0JVYZ06UYJ@1_Kfl0WinO05IFEP1CDe<0
RXZ:06QXJ01nOWh0OGem03dm?@1GEeL0LG5a06][J`2][Jd0CDe=03<c<`1GEeL0UYJF061PH02MWId0
EeMG051@D01ZJVX0LG5a06UYJ@2=SHd0GEeM03hn?P1GEeL0K6a/09NGU`2UYJD0>c/k0451@@1mOGd0
BTY:05ADE02BTY80D51@0451@@1cLg<0De=C05eMG@2WYjL0A4A4030`<01@D500PH6106MWI`2@T900
AdM703Hf=P1kNg/001h0[Jf]06a/K01mOGd0TI6A04a<C01MGEd0LW9b04];B`22PX80N7Qh04Q8B01Y
JFT0SHf=05=CD`0k>c/0Cdm?04M7A`1HF5P0QhN7092@T011@D40@41006MWI`11@D40DU9B07]kN`0h
>3P0@D5106ATI01YJFTLooooo`0D03hn?P1eMGD0PX:206=SH`1YJFT0Bd];04m?C`1NGUh0@T9205]K
F`1SHf<0H61P05UIF@1CDe<0MGEe06i^KP1NGUh0Cdm?05]KF`1QHF4204i>CP3Q03Ti>@1HF5P0C4a<
04e=C@1SHf<0A4A403hn?P1ZJVX0HV9R06a/K01FEUH0AdM704m?C`1JFUX0CTi>05EEE@1OGel0A4A4
04Q8B00c<c<0;2`/03<c<`1NGUh0ADE503lo?`1BDU80@T920451@@1GEeL0C4a<03Lg=`1BDU80?Shn
04Y:BP1=CDd0De=C05YJFP1@D500@41005EEE@1>CTh0?Cdm065QH@1MGEd0EUIF04Y:BP1IFET0EeMG
065QH@1`L700C4a<07]kN`2HV9P0P82006QXJ01=CDd0Bd];0492@P1;Bd/0De=C05MGE`29RHT0[Zj^
05YJFP1CDe<0BDU904A4A01=CDd0F5QH04Y:BP0Z:RX0ADE503`l?01<C4`0?Shn05UIF@0n?Sh0EeMG
04A4A015ADD0HF5Q059BDP1?Cdl0B4Q804];B`0[:b/0?3`l03<c<`1BDU80KFe]04U9B@1NGUh0EEEE
05]KF`1VIVH0AdM707]kN`1KFe/0JFUY0410@01DE5@0Lg=c06ATI01nOWh0OGem07MgM`1=CDd0KVi^
09fMW@1MGEd0W9bL07emO@1FEUH0Kfm_07UiN@1dM7@0VYZJ08F5Q@2NWYh0NGUi06e]K@1ZJVX0EUIF
03De=@17AdL0OGem06i^KP1>CTh0EEEE04e=C@0V9RH0RHV904];B`1NGUh0E5AD05IFEP1GEeL0IFEU
04a<C00g=cL0L71`06ATI01nOWh0^[Zj06IVIP1WIfL0KFe]055AD@11@D40QhN705mOG`1;Bd/0H61P
03`l?01CDe<0HV9R04m?C`1cLg<0DU9B0:NWY`1MGEd0IVIV05aLG00m?Cd0Cdm?05aLG01]KFd0HV9R
05]KF`0c<c<0GEeM06EUI@1mOGd0QHF504a<C01KFe/0Hf=S08J6QP1/K6`0EUIF069RHP1>CTh0MWIf
034a<@1jNWX0Lg=c04I6AP1XJ6P0Bd];04a<C01gMgL0F5QH04E5A@1]KFd0DE5A04a<C016ATH0Fe]K
05EEE@1/K6`0FEUI05aLG01MGEd0B4Q804a<C01mOGd0GEeM07AdM01QHF40Zj^[07MgM`18B4P0Ng]k
06m_K`1bLW80GemO06YZJP1NGUh0FUYJ05mOG`1WIfL0FUYJ07AdM02>SXh0HF5Q0080IVIV01T0Ogmo
05MGE`1TI6@0DU9B04];B`1^KVh0HF5Q06ATI01aLG40DE5A09>CT`1RHV80MgMg04e=C@1`L700G5aL
09nOW`0a<C40Shn?07inOP2ZZZX0Xj>S06e]K@2ZZZX0FUYJ0080GEeM00h0BTY:03/k>`1SHf<0MGEe
05EEE@1^KVh0BDU905]KF`1FEUH0PX:206IVIP1YJFT0PH61071`L17ooooo000?ooooo`0D0820P01a
LG40ZJVY04i>CP1RHV80Hf=S08:2PP2MWId0?Shn04=3@`1NGUh0GEeM07moO`2CTi<0BDU9071`L028
R8P0Fe]K0<[:bP1RHV82038b<P3o07alO01OGel0Ng]k0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MG
E`11@D40HV9R08n?S`1DE5@0Ng]k05MGE`0Q8B40GemO08F5Q@1=CDd0BDU904E5A@0/;2`0Hf=S0:6Q
X@1>CTh0EUIF04e=C@0f=SH0>SXj07EeM@1JFUX0EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055A
D@0[:b/0MGEe04U9B@0Q8B40=SHf04Y:BP0Y:BT0CDe=09NGU`0/;2`0<C4a04i>CP1:BTX0WIfM0:f]
[@0X:2P0<S8b0492@P1bLW80D51@07QhN00Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1MGEd0=CDe0451
@@1OGel0Lg=c0;Jf]P0j>SX0=CDe05mOG`1VIVH0FEUI0:>SX`1NGUh0B4Q808>3P`29RHT0H61P09fM
W@16ATH08B4Q04i>CP2LW9`0MGEe092@T00f=SH0:b/[06ATI02JVYX0IfMW08J6QP2^[Zh0;Bd]05UI
F@25QHD0IFEU07moO`29RHT0<C4a03Ti>@2TY:@0[Jf]075aL@23Ph<08b<S06EUI@29RHT0MgMg06e]
K@2GUiL0=cLg02TY:@20P800OWin05eMG@1hN7P09RHV04a<C01WIfL0XZ:R059BDP1`L700@D5104i>
CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[Jf/0O7al04U9B@2DU9@0EUIF04A4A01UIFD0T92@03<c
<`1SHf<0WYjN04];B`2TY:@0IfMW030`<01MGEd0XZ:R04i>CP1]KFd0[:b/03hn?P1DE5@0Fe]K04U9
B@1SHf<0YjNW055AD@12@T80FEUI05YJFP26QXH0WYjN02LW9`16ATH0QXJ6079bLP1eMGD0];Bd05mO
G`0K6a/0KFe]09:BTP2l_;`0>3Ph034a<@1=CDd0Ogmo061PH02c/k<0EeMG05QHF02>SXh0OGem08N7
Q`36a/H0AdM705IFEP23Ph<0I6AT09NGU`13@d<0EeMG0:ZZZP2a/K40CDe=07IfMP12@T80BDU905mO
G`2TY:@0RXZ:04e=C@0];Bd0LW9b09^KV`2_[jl0MgMg09bLW00`<300P8200<[:bP2:RXX0LW9b07in
OP0e=CD0=3@d06i^KP2i^KT0JVYZ04];B`0k>c/0F5QH07EeM@1lO7`0?clo07inOP1HF5P0?3`l07Ad
M01oOgl0>SXj05ADE00_;bl0BDU905YJFP2QXJ40GUiN051@D00l?3`0Jf][07MgM`2=SHd0De=C02`/
;01ADE40HF5Q06=SH`23Ph<09bLW000902HV9P0l?3`0BTY:07QhN01jNWX0WYjN02/[:`0W9bL0I6AT
0080OGem00<0W9bL03dm?Oooool06oooool04010@400EEEE05EEE@1KFe/0EEEE05eMG@1JFUX0Jf][
04=3@`15ADD0CDe=03/k>`1LG5`0EeMG08Z:RP2?Shl206a/K00[05MGE`1aLG40MGEe04e=C@0Y:BT0
O7al03/k>`0l?3`0RXZ:061PH00n?Sh0EeMG06e]K@1dM7@0FEUI04E5A@1eMGD0EeMG059BDP1NGUh0
EEEE05MGE`16ATH0=CDe05=CD`18B4P0ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400
GEeM04Y:BP1GEeL0E5AD02l_;`0l?3`0AdM704E5A@0204Q8B01g03@d=01VIVH0<S8b04E5A@1DE5@0
EEEE06MWI`1:BTX0GUiN04m?C`0o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1?Cdl0
De=C04e=C@0m?Cd0AdM702h^;P0k>c/0Bd];04A4A00d=3@0>CTi04I6AP0n?Sh0AdM704a<C01EEED0
>3Ph03hn?P0k>c/0@41004i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7065QH@1=CDd0
F5QH04e=C@13@d<0CDe=06IVIP1lO7`0DU9B04E5A@1LG5`0MgMg07]kN`2DU9@0RXZ:08F5Q@1oOgl0
N7Qh0861P@2FUYH0JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0WIfM04Q8B01OGel0
Kfm_07MgM`0m?Cd0@41005MGE`1lO7`0D51@06YZJP1^KVh0CTi>09jNWP1fMWH0MGEe09BDU01[Jf/0
I6AT059BDP2?Shl0UiNG07moO`21PH40W9bL096AT@1XJ6P0DU9B06ATI027QhL0EeMG09:BTP2;Rh/0
MgMg06m_K`24Q8@0CDe=04m?C`1HF5P0PX:204a<C01ADE400P18B4P01`1;Bd/0N7Qh05]KF`1BDU80
N7Qh08n?S`1oOgl00P14A4@02@1=CDd0E5AD05iNGP0g=cL0E5AD06ATI01SHf<0ATI603De=@0205UI
F@1F06IVIP1KFe/0KVi^06QXJ01GEeL0Lg=c03De=@15ADD0EEEE04i>CP0c<c<0G5aL03De=@0j>SX0
@T92059BDP1;Bd/0IfMW05IFEP1OGel0IfMW03/k>`1<C4`0Zj^[06QXJ01aLG40?Shn069RHP1?Cdl0
C4a<06m_K`1GEeL0GemO06UYJ@1`L700@d=305=CD`1FEUH0Ogmo04Y:BP1LG5`0N7Qh059BDP13@d<0
GUiN06YZJP0f=SH0?clo05mOG`1<C4`0FUYJ05QHF01NGUh0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0
dM7A06a/K02;Rh/0GEeM07AdM01TI6@0Ti>C09BDU01fMWH0fMWI06EUI@1IFET0I6AT08B4Q00c<c<0
D51@06MWI`1oOgl0QXJ604Y:BP1=CDd0EUIF08b<S01HF5P0JFUY07UiN@1]KFdAooooo`003oooool0
A02a/K40EEEE08f=S@2BTY80MgMg0451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m?Cd0Lg=c04U9
B@25QHD0?3`l04m?C`20P800[:b/04U9B@1LG5`0LG5a030`<01cLg<0HF5Q04Q8B01IFET0EeMG04i>
CP2c/k<0J6QX02TY:@0g=cL0@T9204I6AP1ZJVX0EEEE01dM7@0`<300N7Qh05iNGP1[Jf/0H61P02XZ
:P11@D40ATI606a/K02b/[80W9bL02LW9`0k>c/0D51@05ADE02a/K40ADE502/[:`0/;2`0PX:205IF
EP2;Rh/0TI6A02PX:00l?3`0RHV905EEE@2KVi/0IfMW0P0Z:RX0N01PH600LW9b08^;R`1[Jf/07QhN
03lo?`1JFUX0F5QH075aL@1nOWh0=cLg03/k>`1YJFT0L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[
05QHF01TI6@0:BTY051@D02ATI40NWYj04E5A@28R8P0=cLg03Ti>@1WIfL0Lg=c061PH01jNWX0>SXj
05MGE`1nOWh0P8200451@@1HF5P0@D51051@D01oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi
065QH@1kNg/0Jf][03<c<`1FEUH0NWYj059BDP11@D40QhN706UYJ@1JFUX0Xj>S04m?C`19BDT0N7Qh
03Ti>@1ZJVX0XZ:R06UYJ@0[:b/0F5QH03Xj>P1TI6@0TI6A0410@00h>3P0I6AT06EUI@1>CTh0`<30
02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI06][J`1nOWh0^[Zj05iNGP10@400Rh^;
0:FUY@1^KVh0P8200=3@d00m?Cd0L71`06QXJ01TI6@0UIFE0>?Sh`0n?Sh0=CDe08J6QP1kNg/0f=SH
06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80De=C09jNWP80IVIV05`0TI6A02@T901ADE40
FUYJ07alO01IFET0I6AT04=3@`2>SXh0Rh^;03dm?@1EEED0J6QX02h^;P1aLG40^KVi06EUI@1VIVH0
=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe07=cL`2=SHd0>SXj05=CD`1;Bd/0Fe]K07alO01VIVH0
=CDe04E5A@1>CTh0I6AT0861P@0f=SH0=3@d07MgM`16ATH0OWin0=7Ad@0c<c<0CDe=07inOP1IFET0
QHF50<71`@0k>c/0<c<c0410@01WIfL0R8R80:n_[`0_;bl0CDe=08f=S@1kNg/0E5AD0:JVYP2FUYH0
<30`05QHF028R8P0S8b<0;^k^`1GEeL0=cLg04e=C@1iNGT0Ng]k0:>SX`0b<S80DU9B06i^KP2][Jd0
X:2P07]kN`2HV9P0?clo04E5A@24Q8@0NGUi05iNGP1nOWh0@D5103`l?01HF5P0ZZZZ08J6QP80>CTi
00@0<C4a06MWI`2j^[X0SXj>7?ooool05@0n?Sh0MgMg096AT@1_Kfl0IFEU04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q805aLG01PH600GUiN04];B`1NGUh0NGUi05QHF0020410@01B04M7
A`16ATH0>CTi04A4A00n?Sh0?Cdm05QHF01/K6`0G5aL05=CD`19BDT0D51@05IFEP1HF5P0HF5Q08N7
Q`1:BTX0Cdm?030`<00e=CD0?Shn059BDP14A4@0DU9B051@D014A4@0?3`l02`/;01GEeL0?clo05=C
D`0n?Sh0B4Q804I6AP1@D500HF5Q06=SH`1PH600IVIV04m?C`18B4P0KVi^04Y:BP0o?cl0FEUI06MW
I`1CDe<0EEEE06QXJ01YJFT0L71`096AT@2RXZ80C4a<05MGE`0b<S80=cLg05EEE@1bLW80NGUi0;Ng
]`2:RXX0C4a<06IVIP17AdL0>SXj05ADE019BDT0<C4a0492@P1EEED0<c<c03De=@1XJ6P0KVi^034a
<@19BDT0C4a<061PH00g=cL0GEeM06][J`80<S8b0380Bd];04M7A`0_;bl0A4A408:2PP10@400>SXj
03`l?01SHf<0J6QX0492@P18B4P0DE5A07=cL`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?
059BDP2UYJD0EUIF09bLW01BDU80=SHf06YZJP1/K6`0Fe]K069RHP0`<300L71`07EeM@1gMgL0WinO
08:2PP2HV9P0PH6106e]K@1WIfL0JFUY061PH01SHf<0?clo0::RXP1eMGD0LG5a06EUI@80UYJF00<0
Ng]k07MgM`1eMGD00P2QXJ40303>c/h0c<c<0:ZZZP1PH600EEEE061PH01>CTh0QXJ608V9R@2^[Zh0
YjNW075aL@80D51@02`0J6QX09JFUP1JFUX0PX:2069RHP1IFET0G5aL04a<C01@D500IFEU06ATI01L
G5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1^KVh0Ogmo06i^KP19BDT0CTi>04I6AP1V
IVH0<c<c07UiN@1`L700GUiN08b<S01ADE40C4a<05YJFP18B4P0@D5106a/K010@400ADE504I6AP1c
Lg<0EEEE05aLG080H61P0240HF5Q055AD@17AdL0KVi^09bLW02WYjL0=cLg07MgM`1nOWh0F5QH0::R
XP22PX80EUIF04i>CP1<C4`0:2PX04e=C@0l?3`0I6AT07YjNP1HF5P0EeMG04E5A@1BDU80ZJVY09ZJ
VP1DE5@0DE5A059BDP1WIfL0TI6A06IVIP1BDU800P0d=3@07`1NGUh0B4Q8069RHP17AdL0EeMG04];
B`2GUiL0LG5a09^KV`1^KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80IFEU04e=C@1JFUX0QhN707Ee
M@1[Jf/0HF5Q03/k>`1fMWH0Cdm?0820P01mOGd0TI6A0:f][@2;Rh/04Oooool000oooooo08T0_;bl
06EUI@1NGUh0QXJ608B4Q012@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1eMGD0cLg=
04A4A00d=3@0HV9R09^KV`1bLW80PH610;fm_@0k>c/0HF5Q0<;2`P25QHD0^;Rh034a<@14A4@0CTi>
0:2PX01YJFT0Shn?01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A09RHV01@D500YJFU
06IVIP0X:2P0A4A40:f][@1ZJVX0CDe=065QH@0/;2`0HF5Q09BDU018B4P0Kfm_02`/;00_;bl0?clo
06e]K@1PH600Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300KVi^0:NWY`1;Bd/0ADE5
065QH@0_;bl0BTY:09>CT`1aLG40:b/[03Ti>@15ADD0DE5A09JFUP1eMGD0:b/[05iNGP15ADD0ATI6
0:2PX00Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0;Rh^04U9B@1^KVh0N7Qh0;^k^`0`<300;bl_
04Q8B01dM7@0BTY:08n?S`1dM7@0=SHf05]KF`1bLW80E5AD0:n_[`1cLg<0:RXZ02l_;`1OGel0Kfm_
0=GEe@2NWYh0>3Ph03@d=021PH40SHf=06UYJ@39bLT0LW9b04Q8B02VYZH0MgMg08V9R@2LW9`0;bl_
03`l?00206EUI@1W04a<C01aLG40@T9205ADE02MWId0IVIV061PH01]KFd0GUiN04M7A`2XZ:P0WinO
07emO@2;Rh/0>CTi04U9B@20P800cLg=07=cL`20P800C4a<05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG
02`/;01QHF40RHV907EeM@2YZJT0FEUI02d];@1BDU80/;2`08Z:RP1:BTX0Jf][03@d=01OGel0Rh^;
03lo?`14A4@0GEeM03De=@1fMWH0SXj>03`l?00j>SX0DE5A03dm?@1gMgL0c/k>0451@@0e=CD0LW9b
05YJFP1YJFT0_;bl02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0S8b<0;Rh^02][Jd0:RXZ
02h^;P1PH600NWYj0;Fe]@2SXj<0:2PX04Q8B02CTi<0UYJF0;2`/014A4@0:BTY05YJFP1oOgl0JVYZ
09RHV010@400H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`1mOGd0a<C406m_K`16ATH0Fe]K
07UiN@0206MWI`0^09BDU011@D40De=C09NGU`1SHf<0EeMG0::RXP0a<C40>c/k04a<C01mOGd0B4Q8
06i^KP11@D40:b/[05aLG025QHD0=CDe059BDP1^KVh0<S8b05mOG`1XJ6P0;2`/05UIF@1WIfL0B4Q8
04m?C`1YJFT0F5QH02d];@1<C4`0@D51069RHP1kNg/0FUYJ02<S8`0b<S80EeMG051@D018B4P0IfMW
02<S8`1bLW80EeMG04];Bacooooo06L0@41009:BTP24Q8@0FEUI05MGE`1=CDd0EUIF06IVIP0o?cl0
FUYJ04M7A`1BDU80FUYJ05mOG`1cLg<0QXJ607inOP1KFe/0LW9b05EEE@14A4@0@41003/k>`1jNWX0
C4a<04i>CP1bLW80G5aL03Ti>@1;Bd/0K6a/07YjNP1IFET0C4a<069RHP1JFUX0DE5A05]KF`1YJFT0
Hf=S05MGE`0`<300B4Q805YJFP1QHF40AdM704I6AP1gMgL0>3Ph05YJFP1^KVh0Ng]k04m?C`1/K6`0
@D5104a<C017AdL0DU9B05YJFP0m?Cd0=CDe069RHP1JFUX0=CDe07=cL`1:BTX0D51@04U9B@1fMWH0
F5QH05YJFP2CTi<0E5AD07AdM02KVi/0/;2`05QHF01GEeL0;Rh^03/k>`1dM7@0E5AD07UiN@3:b/X0
UYJF065QH@1;Bd/0ADE504m?C`17AdL0Hf=S04A4A00i>CT0C4a<03hn?P14A4@0=3@d03hn?P0g=cL0
AdM702TY:@0e=CD0CTi>0080?Shn07<0@d=303lo?`0f=SH0ATI60492@P1ADE40FUYJ038b<P1=CDd0
A4A4059BDP1QHF40ATI605UIF@18B4P0?Cdm03hn?P11@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0
BTY:07YjNP1TI6@0/k>c05QHF00a<C40H61P07emO@2ATI40[Zj^05eMG@1iNGT0De=C06][J`1>CTh0
@T9204I6AP1>CTh0UIFE07alO00c<c<0EEEE04e=C@0_;bl0Q8B404e=C@1hN7P0GemO05=CD`1<C4`0
?clo04E5A@18B4P0Q8B407UiN@3=cLd0kno_09bLW023Ph<0R8R806QXJ01BDU80X:2P04];B`1@D500
GemO028R8P1@D500FEUI059BDP1/K6`0EeMG0820P01BDU80Jf][07QhN00n?Sh0:RXZ07EeM@1kNg/0
J6QX05EEE@1<C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0JFUY08b<S01XJ6P0GemO08f=S@1aLG40
SXj>061PH02FUYH0ZJVY06=SH`1dM7@0DE5A05MGE`1IFET0BTY:04I6AP18B4P0?Cdm04I6AP1>CTh0
F5QH00<0HV9R01T0Fe]K06ATI01NGUh0JFUY0:^[Z`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mOG`1IFET0
EeMG05YJFP1KFe/0FEUI03Lg=`1NGUh0BDU906YZJP1aLG40HF5Q06YZJP1SHf<0@4100080EUIF02P0
@D5106m_K`11@D40@d=305mOG`0e=CD0IfMW04=3@`14A4@0HF5Q04U9B@2?Shl0@T9207]kN`0i>CT0
WYjN04Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_08J6QP2DU9@0=cLg05=CD`1BDU80
Rh^;05IFEP11@D40A4A4069RHP2CTi<0Kfm_08Z:RP1nOWh0KFe]4Oooool000oooooo0:l0[jn_0:ZZ
ZP2j^[X0DE5A079bLP2?Shl0QXJ604e=C@1<C4`0IfMW08:2PP1fMWH0Ogmo06=SH`1?Cdl0U9BD07Qh
N012@T80O7al0451@@0n?Sh0Fe]K08^;R`1?Cdl0DE5A034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=
C@0Y:BT0[jn_06EUI@0/;2`0CTi>03Xj>P0K6a/0J6QX0;Ng]`1<C4`0EUIF06][J`0j>SX0QHF508:2
PP0O7al0>3Ph061PH01BDU80Shn?0:JVYP0];Bd0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=S
H`1KFe/0a<C403dm?@0D51@0<C4a06][J`1>CTh0UIFE09bLW00V9RH0C4a<0;Ng]`1YJFT0S8b<0:NW
Y`0R8R80<30`06m_K`2HV9P0Fe]K08N7Q`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE506UY
J@1KFe/0XZ:R09VIV@0_;bl0EEEE05MGE`2:RXX0MgMg0<k>cP1;Bd/0D51@06m_K`1YJFT0GemO0:b/
[01@D500<30`06=SH`2CTi<0HV9R092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9R@1hN7P0?Shn06QX
J02_[jl0KVi^071`L01cLg<0?clo03/k>`1fMWH0]kNg05eMG@1?Cdl0?Shn04e=C@2KVi/0VYZJ05IF
EP2EUID0A4A403`l?024Q8@0;bl_0451@@1aLG40G5aL05eMG@2RXZ80DU9B03`l?01KFe/0Cdm?065Q
H@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800H61P03/k>`1eMGD0Ph>3069RHP2d];@0VYZJ01XJ
6P0h>3P0IFEU05YJFP39bLT0Xj>S02PX:011@D40E5AD0080G5aL0740^;Rh0410@01EEED0GEeM05YJ
FP2FUYH0Zj^[02LW9`0k>c/0EEEE05IFEP1SHf<0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti
>@0f=SH0];Bd06m_K`1jNWX0;bl_03<c<`1BDU80UiNG07=cL`1`L700CTi>07IfMP2TY:@0FUYJ06EU
I@1JFUX0@D5105MGE`2=SHd0GUiN0861P@0m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>C
T`1kNg/0EUIF061PH01=CDd0Lg=c0:NWY`1BDU80<30`06i^KP17AdL0WinO0<o?c`1OGel0A4A407If
MP1MGEd0C4a<09VIV@1LG5`0=cLg05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K08f=
S@1dM7@0;bl_055AD@1?Cdl0Hf=S092@T038b<P0?Cdm069RHP1XJ6P0I6AT0;Rh^033`l<0@d=304a<
C01UIFD0Kfm_051@D02IVIT0;2`/03`l?01EEED0P820059BDP21PH40][Jf03dm?@1DE5@0Ogmo04Q8
B02?Shl0LW9b03Hf=P0Looooo`0k04A4A01bLW80O7al05UIF@1PH600Bd];055AD@2DU9@0Bd];06YZ
JP1KFe/0FEUI0451@@1;Bd/0J6QX07=cL`1nOWh0LW9b08:2PP1cLg<0EeMG04Y:BP0V9RH0Bd];04Q8
B01EEED0FUYJ05ADE00a<C40FUYJ06a/K01RHV80EEEE059BDP18B4P0I6AT059BDP1=CDd0J6QX04M7
A`1ADE40AdM703`l?018B4P0DE5A05UIF@1PH600EEEE03Hf=P1JFUX0QXJ606][J`18B4P0GEeM05IF
EP1RHV80E5AD03hn?P1;Bd/00P1cLg<0:01aLG40G5aL05]KF`2FUYH0E5AD05=CD`1HF5P0O7al06UY
J@1LG5`0Rh^;059BDP1[Jf/0QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2GUiL0V9RH0::R
XP29RHT0J6QX04i>CP1ADE40Hf=S05iNGP1:BTX0AdM705iNGP0m?Cd0E5AD05aLG01`L700AdM705eM
G@17AdL205]KF`1h05UIF@1_Kfl0BTY:05=CD`1<C4`0D51@04Q8B01CDe<0IFEU05YJFP1CDe<0AdM7
05UIF@1`L700ADE506YZJP1JFUX0Fe]K04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0>CTi
06UYJ@1HF5P0g]kN08J6QP0k>c/0I6AT04m?C`15ADD0HV9R03hn?P2:RXX0LG5a06YZJP1UIFD0IfMW
09FEU@1JFUX0D51@06ATI01@D500ATI604E5A@0Q8B40d=3@03Lg=`1;Bd/0EeMG08f=S@1UIFD0A4A4
03dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=0820P01ADE40Bd];0492@P1kNg/0Ph>3
04a<C01jNWX0Ng]k06ATI02:RXX0J6QX09jNWP25QHD0EeMG07AdM01>CTh0KFe]05=CD`1NGUh0O7al
07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0M7Ad08J6QP1NGUh0Bd];05UIF@1BDU80Q8B4
06YZJP1oOgl0FEUI07]kN`2>SXh0E5AD05IFEP1MGEd0@41003`l?01XJ6P0@d=304e=C@1;Bd/0IFEU
05ADE01:BTX0FEUI0P1=CDd0@@1ADE40C4a<06YZJP1YJFT0HV9R02h^;P1QHF40CDe=038b<P1iNGT0
CTi>04U9B@1CDe<0ATI603Ph>01GEeL0J6QX0861P@1@D500DU9B06YZJP17AdL0=SHf05mOG`1KFe/0
ADE5055AD@0m?Cd0F5QH07=cL`0f=SH0>c/k02d];@1FEUH0SXj>04I6AP1<C4`0?clo092@T01EEED0
MgMg06EUI@29RHT0Jf][06i^KP1]KFd0Ng]k0?7al@1TI6@0XZ:R05EEE@1HF5P0?Cdm071`L01]KFd0
QHF507UiN@21PH40Ti>C06a/K01kNg/0OGem05]KF`1bLW80RHV9017ooooo000?ooooo`0K08Z:RP1U
IFD0R8R8071`L01NGUh0GemO09fMW@1[Jf/09BDU04Q8B01FEUH0?3`l096AT@2XZ:P0=3@d05ADE013
@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD08Z:RP10@400;bl_0080DU9B01h0MGEe0:FUY@1j
NWX061PH04m?C`1hN7P0EEEE08R8R00h>3P09bLW03De=@26QXH0QhN705aLG02<S8`0>SXj051@D01Y
JFT0BTY:06][J`2OWil0>c/k0410@01lO7`0LG5a07inOP0_;bl0;Bd]03Ph>01lO7`2051@D02c05iN
GP0T92@0Cdm?08^;R`14A4@0FEUI055AD@0X:2P0?Shn07QhN01OGel0?Cdm04];B`0f=SH0BTY:09NG
U`1JFUX0?clo05=CD`0j>SX0EEEE08B4Q00f=SH0=cLg05ADE01?Cdl0AdM7092@T02SXj<0;bl_04a<
C012@T80KFe]0:b/[010@400@T9207AdM019BDT0Cdm?0:6QX@2ATI40A4A405QHF018B4P0EUIF0:n_
[`1dM7@0=CDe03dm?@1/K6`0KFe]0<?3``1DE5@0=CDe05MGE`1UIFD0Bd];096AT@2n_[h0>CTi0492
@P1`L700EEEE096AT@36a/H0CDe=04Q8B01RHV80WYjN09NGU`2@T900=CDe05YJFP1YJFT0GemO07Qh
N03@d=00N7Qh03hn?P2;Rh/0QhN70820P02@T900A4A40492@P2FUYH0^k^k05]KF`29RHT0>c/k04A4
A02QXJ40`L71065QH@2QXJ40QXJ603dm?@23Ph<0IFEU05mOG`2FUYH0=CDe04A4A021PH40^KVi06i^
KP1jNWX0PX:204A4A01PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG09VIV@1hN7P0IVIV038b
<P1OGel0bLW909fMW@1UIFD0OWin034a<@1WIfL0/[:b055AD@1DE5@0PH6104U9B@1=CDd0XZ:R06e]
K@0g=cL0F5QH07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27QhL0Kfm_04=3@`1WIfL0LW9b09bL
W02/[:`0ATI604a<C02>SXh0FEUI0;bl_01=CDd0>c/k04I6AP1UIFD0NGUi0<C4a01kNg/0:b/[06m_
K`20P800Zj^[09NGU`0N7Qh0BDU90;6a/@2JVYX0H61P0;Rh^019BDT0DE5A0:BTY01jNWX00P2>SXh0
7`0[:b/0Fe]K08V9R@1hN7P0NWYj071`L00M7Ad0ATI608j>SP2CTi<0CDe=09>CT`1gMgL0;Bd]06a/
K023Ph<0EUIF09RHV00g=cL0;Bd]06UYJ@2BTY80S8b<06m_K`15ADD0=cLg04M7A`29RHT0OGem04m?
C`25QHD00P0m?Cd03`1OGel0IfMW03Hf=P1/K6`0@T9202h^;P0Z:RX0H61P0820P00d=3@0ADE502`/
;01^KVh0T92@05]KF`0Looooo`110492@P2CTi<0UIFE06MWI`1TI6@0E5AD05=CD`1LG5`0@410059B
DP1gMgL0DU9B0492@P1ADE40SXj>08R8R01MGEd0B4Q805=CD`1MGEd0EEEE04e=C@0g=cL0EEEE04Q8
B012@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH05IFEP1IFET0MGEe071`L01TI6@0SXj>04i>
CP1ADE408R8R03`l?01>CTh0DE5A05ADE014A4@0PH6104A4A01RHV80IfMW07]kN`1BDU80JVYZ03De
=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0E5AD04Q8B01WIfL00P0o?cl0:@16ATH0IfMW051@
D01<C4`0LG5a06][J`1NGUh0Lg=c07UiN@1/K6`0EeMG03dm?@1NGUh0HF5Q03dm?@1bLW80f][J09NG
U`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00o?cl0?Shn05QHF00k>c/0ADE5051@D01<C4`0?Shn04A4
A00d=3@0ADE504U9B@1ADE40J6QX03/k>`15ADD0BTY:0080?Cdm00l0Cdm?07IfMP0o?cl0D51@05AD
E01kNg/0Jf][04M7A`1LG5`0Bd];05iNGP12@T80EUIF07]kN`1/K6`00P1^KVh05P1IFET0Hf=S04E5
A@1fMWH0CDe=09fMW@1cLg<0>SXj07moO`1>CTh0R8R809jNWP0d=3@0T92@09JFUP28R8P0LW9b07in
OP2FUYH0OWin069RHP1<C4`205IFEP1:0492@P13@d<0L71`05=CD`1NGUh0De=C04];B`1GEeL0EUIF
03/k>`0i>CT0MWIf055AD@2LW9`0/K6a05ADE01iNGT0Ng]k04];B`0g=cL0JVYZ03De=@1DE5@0FEUI
02LW9`13@d<0?Cdm05QHF01kNg/0GEeM08N7Q`0_;bl0C4a<07AdM01jNWX0Fe]K075aL@1SHf<0CTi>
04=3@`0g=cL0E5AD04I6AP12@T80E5AD03@d=01=CDd0Cdm?06QXJ012@T80?Shn07inOP1:BTX0EUIF
03Lg=`2DU9@0GemO03lo?`1QHF40EEEE04U9B@1<C4`0H61P05]KF`1GEeL0ADE50410@00j>SX0EeMG
0492@P1ADE40HV9R05MGE`1NGUh205YJFP0`05ADE01^KVh0KVi^04Q8B01hN7P0?Shn02`/;01IFET0
B4Q8079bLP1cLg<0Fe]K05ADE01`L700E5AD05=CD`1UIFD0G5aL05QHF01@D500?Shn0820P01]KFd0
;Rh^04m?C`0i>CT0HV9R096AT@15ADD0De=C03@d=010@400IfMW05MGE`2=SHd0FUYJ06i^KP1:BTX0
ZJVY05mOG`2c/k<0F5QH0;^k^`23Ph<0JVYZ09bLW01JFUX0Vi^K0P1BDU803@1;Bd/0Rh^;079bLP1U
IFD0EEEE05=CD`12@T80CTi>09RHV01WIfL0G5aL0861P@23Ph<04Oooool000oooooo02H0a<C405IF
EP1jNWX0Zj^[07moO`11@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1[Jf/0Xj>S03dm
?@13@d<0IVIV0:ZZZP1HF5P0SXj>07QhN00/;2`0HV9R075aL@1FEUH0P82003Hf=P0S8b<0Hf=S08V9
R@0o?cl0?Cdm04U9B@15ADD0Q8B40861P@80:2PX0?X0@T9204U9B@1;Bd/0IfMW01lO7`1DE5@0A4A4
034a<@1WIfL0^[Zj0492@P0X:2P0GemO05=CD`2l_;`0L71`01dM7@0o?cl0@T9204Y:BP26QXH0UiNG
02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01bLW80IVIV02/[:`1EEED0JFUY
06ATI01/K6`0`l?303Ti>@0_;bl0Lg=c069RHP1cLg<0^KVi03<c<`10@400I6AT0:n_[`1eMGD0EUIF
02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K08R8R02ZZZX0LW9b02d];@0g=cL0G5aL
09NGU`1XJ6P0PX:2059BDP0b<S80RHV909:BTP1ADE40QHF50410@00[:b/0>CTi06MWI`1cLg<0RHV9
05aLG00e=CD0B4Q808>3P`27QhL0De=C07AdM00m?Cd0HF5Q09bLW01JFUX0Fe]K06=SH`0n?Sh0>SXj
07AdM01lO7`0@D5105YJFP0j>SX0AdM709JFUP1GEeL0?clo059BDP0i>CT0@T9207moO`13@d<0>SXj
08F5Q@11@D40QHF50:2PX02OWil0>3Ph051@D01SHf<0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO
09bLW038b<P0?3`l04M7A`1aLG40TY:B0:ZZZP3MgMd0CDe=03lo?`2CTi<0VIVI0;6a/@1lO7`0:2PX
04Q8B02^[Zh0OGem09^KV`31`L40:RXZ04Q8B02n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7
071`L02;Rh/0?Cdm09:BTP2NWYh0GUiN09>CT`1XJ6P0=cLg04I6AP2RXZ80NWYj07moO`0i>CT0Ogmo
0;2`/01kNg/0RHV906IVIP0k>c/0R8R80:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;b`1UIFD0Q8B4
06=SH`1@D500aLG506e]K@22PX80Shn?04E5A@1>CTh0Hf=S05UIF@1bLW80Kfm_0451@@1XJ6P0/k>c
05eMG@0g=cL0I6AT06IVIP1gMgL0/K6a03<c<`0V9RH0J6QX07moO`1=CDd0MWIf0:VYZ@0k>c/0BTY:
06QXJ01=CDd0XJ6Q069RHP0N7Qh0>CTi05eMG@1CDe<0VIVI051@D00^;Rh0AdM705ADE01KFe/0GemO
0:BTY01ZJVX0?Cdm06IVIP1OGel0IFEU0:BTY028R8P0<30`04=3@`1CDe<0Ng]k07IfMP1cLg<06QXJ
02/[:`2?Shl0PH617?ooool0o`1:BTX0UiNG08:2PP1GEeL0G5aL06=SH`1bLW80MgMg0451@@1<C4`0
Bd];03/k>`0o?cl0DE5A065QH@1DE5@0HF5Q05aLG020P800K6a/04i>CP13@d<0=SHf05=CD`1GEeL0
DE5A05IFEP1CDe<0@T9205]KF`1MGEd0M7Ad05=CD`17AdL0HV9R06QXJ01@D500EeMG05aLG01?Cdl0
LG5a0451@@13@d<0EUIF075aL@1MGEd0FEUI092@T018B4P0IFEU08>3P`1YJFT0Bd];06YZJP1EEED0
FUYJ065QH@1YJFT0Lg=c06QXJ01=CDd0JVYZ07EeM@1CDe<0VYZJ03lo?`1CDe<0BTY:07alO01GEeL0
BDU907MgM`1GEeL0LG5a096AT@2?Shl0@410059BDP0T92@0<c<c06IVIP1MGEd0Ti>C0:JVYP2BTY80
JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0B4Q803De=@1UIFD0=SHf04a<C017AdL0M7Ad04a<C01LG5`0
?3`l04I6AP1;Bd/0JVYZ05iNGP13@d<0BDU904A4A00o?cl0=cLg04a<C01QHF40B4Q804];B`1?Cdl0
EUIF06ATI018B4P0K6a/07]kN`1>CTh0@41004Q8B01^KVh0QhN7075aL@20P800L71`08j>SP1FEUH0
PH6104m?C`2i^KT0P82004=3@`1_Kfl0F5QH05aLG01hN7P0De=C096AT@1FEUH0HV9R05iNGP1GEeL0
EEEE04Y:BP1PH600FEUI03Ph>01MGEd0Hf=S038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D01BDU80
IFEU04];B`1oOgl0FEUI0:^[Z`3;bl/0>3Ph04=3@`0b<S80GEeM04I6AP2FUYH0JFUY06][J`2@T900
?Cdm071`L01PH600DE5A04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^07QhN01YJFT0
CDe=04Y:BP13@d<0@41008V9R@23Ph<0>3Ph061PH01]KFd0WYjN05UIF@1DE5@0MGEe04a<C01HF5P0
?clo05aLG021PH40E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0De=C0410@00j>SX0
F5QH061PH018B4P0CDe=05MGE`18B4P0?Shn0492@P1aLG40^KVi04a<C02VYZH0FUYJ04Q8B01PH600
De=C03`l?01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1iNGT0F5QH0;:b/P1lO7`0
>CTi04M7A`0k>c/0GUiN06ATI0008`1>CTh0QHF5069RHP1SHf<0N7Qh04m?C`1;Bd/0H61P09BDU01]
KFd0LG5a04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem04U9B@1CDe<0B4Q806=SH`1i
NGT0OGem06EUI@14A4@0De=C07EeM@2ATI40M7Ad08F5Q@1iNGT0RXZ:017ooooo000?ooooo`2909NG
U`1[Jf/0Ogmo051@D020P800C4a<05EEE@1?Cdl0?clo07UiN@2KVi/0=SHf03Ti>@1CDe<0GUiN0:>S
X`0j>SX0820P03lo?`1NGUh0Rh^;0;6a/@2FUYH0:RXZ0451@@20P800EeMG0;6a/@0b<S80:b/[0451
@@1jNWX0E5AD08F5Q@0/;2`0>CTi05=CD`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;02:RXX0?clo0:BT
Y01UIFD0=CDe0451@@2OWil0QHF505aLG02ZZZX0:b/[0492@P2g]kL0J6QX08Z:RP0d=3@0<c<c04=3
@`1iNGT0NWYj08J6QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW05ADE01/K6`0=cLg05EE
E@2>SXh09RHV034a<@1dM7@0RHV903<c<`1RHV80=3@d04=3@`1`L700IVIV03<c<`1gMgL0=cLg03lo
?`1GEeL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0ADE508j>SP2j^[X0;Bd]02XZ
:P0l?3`0DU9B03lo?`2:RXX0QhN702XZ:P1CDe<0EeMG05=CD`2_[jl0Ng]k02DU9@0m?Cd0ADE506AT
I038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@11@D40WIfM06m_K`2DU9@0V9RH02`/
;010@4000P1kNg/07P1aLG40Vi^K02@T9011@D40IFEU06][J`1XJ6P0WinO03`l?00f=SH0O7al0<g=
c@1VIVH0bLW902h^;P19BDT0TI6A09BDU01nOWh0QhN705EEE@1>CTh0X:2P08n?S`1CDe<0Shn?04a<
C00Y:BT0C4a<0:j^[P80NWYj07L0<30`059BDP1IFET0/[:b09fMW@1KFe/0Kfm_0451@@1IFET0][Jf
06IVIP1[Jf/0I6AT03dm?@0o?cl0TY:B079bLP10@400De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi
05IFEP19BDT0a<C403Lg=`16ATH0@41003hn?P1OGel0Shn?03@d=00g=cL0DU9B0:FUY@2][Jd0<30`
04A4A024Q8@0M7Ad0<S8b02OWil0:RXZ055AD@1]KFd0Vi^K0;Bd]00n?Sh0<C4a06=SH`2IVIT0RHV9
0:BTY01PH600GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO01`L700Z:RX09JFUP0o?cl0EeMG
065QH@2KVi/0Jf][0;>c/`1MGEd0Bd];08Z:RP2c/k<0NWYj0::RXP1RHV80?3`l04i>CP1lO7`0PH61
08j>SP1=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo06=SH`2j^[X0EEEE08b<S025QHD0>c/k
0451@@1hN7P0XJ6Q04U9B@1jNWX0;Bd]03De=@1PH600W9bL05ADE01EEED0PH61038b<P0[:b/0WinO
030`<01PH600;2`/03lo?`0Looooo`0j04];B`1FEUH0H61P059BDP1<C4`0?Cdm04Q8B027QhL0De=C
06a/K01ADE40F5QH05EEE@1CDe<0I6AT07MgM`2;Rh/0NWYj07EeM@1dM7@0IFEU04];B`0f=SH0LG5a
0451@@17AdL0LW9b05iNGP0h>3P0C4a<0410@00g=cL0D51@04M7A`0a<C40Fe]K051@D01NGUh0Hf=S
05aLG01?Cdl0<c<c04Y:BP1DE5@0S8b<06IVIP1]KFd0F5QH04I6AP1NGUh0TI6A07YjNP1=CDd0H61P
04U9B@1HF5P0CDe=03lo?`80Cdm?00H0Bd];06QXJ01hN7P0QhN70:RXZ01BDU8205iNGP1g08:2PP1^
KVh0HV9R07EeM@1fMWH0E5AD075aL@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0GEeM04U9B@2Z
ZZX0J6QX069RHP13@d<0CDe=05]KF`1QHF40CTi>05=CD`1bLW80ATI604a<C01KFe/0HV9R051@D01Q
HF40=3@d04m?C`1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1aLG40FEUI059BDP1F
EUH0LW9b0820P01CDe<0TI6A07MgM`1DE5@0?3`l04Q8B028R8P0MgMg07UiN@1XJ6P0F5QH06=SH`18
B4P0Ogmo08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09JFUP27QhL0KVi^06=SH`1V
IVH0][Jf0820P01TI6@0De=C059BDP1ADE40@T92034a<@2PX:00;2`/059BDP0c<c<0L71`05YJFP1@
D500CDe=075aL@38b<P0E5AD09RHV02c/k<0GUiN051@D01BDU80KFe]04m?C`1TI6@0@D5107=cL`2B
TY80Fe]K06a/K01^KVh0DE5A065QH@1^KVh0^k^k06a/K01CDe<0I6AT08J6QP1?Cdl00P1IFET0I@1b
LW80LG5a04A4A00o?cl0>SXj051@D018B4P08B4Q06][J`1HF5P0CTi>04a<C017AdL0D51@06MWI`2=
SHd0IfMW07QhN01TI6@0GEeM08>3P`0^;Rh0?clo03Xj>P0d=3@0@d=305=CD`0o?cl0ADE504M7A`13
@d<0BDU904M7A`1CDe<0CTi>051@D016ATH0BDU905MGE`15ADD0GEeM06MWI`1CDe<0ATI604E5A@1Y
JFT0=3@d0492@P1RHV80E5AD0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1IFET0EEEE07AdM01W
IfL0M7Ad07inOP1LG5`0EeMG05aLG00_;bl0Fe]K05=CD`1NGUh0P82004m?C`1<C4`0GUiN08n?S`1T
I6@0Q8B404a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH08n?S`21PH40I6AT069RHP2:
RXX0WinO06YZJP1BDU80Lg=c075aL@2>SXh0R8R808Z:RP29RHT0QhN7017ooooo000?ooooo`0e075a
L@21PH40aLG505=CD`1dM7@0MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80@d=307Ee
M@21PH40RXZ:09:BTP1IFET0MWIf069RHP2RXZ80JFUY06a/K00R8R80=CDe06EUI@2WYjL0?clo0820
P01UIFD08b<S061PH01aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg=`1PH600>CTi08B4
Q029RHT0:RXZ05=CD`18B4P0ADE505MGE`26QXH00P0k>c/0X@0i>CT0@d=309BDU01LG5`07AdM04A4
A01>CTh0CDe=08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06ATI02i^KT0ATI603@d=01lO7`0CTi>079b
LP33`l<0;bl_02`/;00k>c/0MGEe05EEE@2>SXh0<30`04];B`1HF5P0Jf][04];B`38b<P0HF5Q030`
<01FEUH0DE5A09ZJVP2MWId08B4Q02h^;P1UIFD0LG5a059BDP1`L700E5AD051@D01NGUh0LG5a05]K
F`1mOGd0>3Ph055AD@1NGUh0Kfm_04Q8B01jNWX0;Rh^03<c<`1RHV80SXj>04I6AP1PH600GemO02l_
;`1QHF40R8R804Q8B01QHF40Lg=c03/k>`17AdL0P8200<S8b01LG5`0B4Q803De=@1=CDd0P82007Ad
M018B4P0JFUY02HV9P16ATH0OWin05YJFP1`L700PH6102d];@1FEUH0Ng]k07MgM`0/;2`0EEEE04A4
A01HF5P0/[:b05EEE@0U9BD0G5aL079bLP1DE5@0Jf][06m_K`0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF01gMgL0ZZZZ06UYJ@0_;bl0Cdm?059BDP2:RXX0L71`0;fm_@0l?3`0Cdm?07]k
N`1YJFT0WinO0:6QX@0_;bl0EeMG05aLG02?Shl0RXZ:07inOP0g=cL0Ogmo09JFUP2d];@0QhN70<K6
aP1ADE40=3@d0:FUY@29RHT0`l?303hn?P0a<C40EeMG0;bl_02=SHd0VYZJ04e=C@1?Cdl0R8R8092@
T022PX80HF5Q0410@01eMGD0Xj>S0080R8R802X0<S8b05QHF02YZJT0NGUi04i>CP1WIfL0FUYJ03<c
<`25QHD0UYJF08F5Q@1DE5@0<C4a051@D02_[jl0XJ6Q055AD@1/K6`0DE5A06m_K`2SXj<0JVYZ05]K
F`1fMWH0<C4a04U9B@2JVYX0]kNg05MGE`1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451
@@1oOgl0WIfM04E5A@1TI6@204=3@`0L08f=S@2i^KT0ADE505IFEP1jNWX0K6a/09ZJVP2LW9`0ATI6
02`/;014A4@0Lg=c04Q8B02JVYX0?3`l02LW9`0e=CD0Ogmo05UIF@1ZJVX0/K6a03`l?00d=3@0EeMG
04m?C`2e]KD0YjNW03dm?Acooooo00D0CDe=06QXJ028R8P0K6a/06IVIP0204e=C@0304A4A00e=CD0
AdM70080Bd];02/0<c<c038b<P1EEED0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0
E5AD04U9B@14A4@0CTi>0410@01LG5`0@D5104=3@`14A4@0ATI604M7A`1=CDd0D51@05mOG`1YJFT0
@T92059BDP0W9bL0@d=30492@P1cLg<0F5QH05ADE01ZJVX0CTi>05IFEP1^KVh0TY:B05YJFP1iNGT0
Bd];0080J6QX09/0Bd];05iNGP15ADD0@41004i>CP1KFe/0EeMG07]kN`0i>CT0@T9204E5A@1UIFD0
Cdm?04a<C01bLW80DE5A06ATI024Q8@0Shn?04];B`1bLW80EUIF07=cL`1ZJVX0B4Q805YJFP1=CDd0
]KFe06][J`1<C4`0Bd];04m?C`18B4P0DE5A04];B`0n?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300
BDU904E5A@1?Cdl0ATI6061PH026QXH0EUIF05ADE01;Bd/0B4Q804M7A`1EEED0N7Qh04I6AP1CDe<0
Cdm?07AdM01fMWH0J6QX07emO@1SHf<0DU9B04=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0
RHV90:NWY`2h^;P0]kNg07moO`1<C4`0NGUi04E5A@1lO7`0ZZZZ02h^;P2>SXh0W9bL0:2PX01FEUH0
IFEU05ADE01KFe/0GemO0451@@13@d<0Fe]K05ADE01EEED0Shn?06=SH`1<C4`08b<S06][J`1>CTh0
NGUi020P8018B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP0m?Cd0Vi^K02l_;`1TI6@0
MGEe034a<@1BDU80D51@04a<C01^KVh0=CDe05MGE`0^;Rh0@d=305QHF01SHf<0FUYJ06][J`1IFET0
ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0GUiN06e]K@0m?Cd0DE5A06IVIP0o?cl0
Fe]K051@D02?Shl0HV9R04E5A@1eMGD0E5AD04I6AP0204i>CP0[04e=C@1ADE40>c/k03Xj>P0e=CD0
ADE503`l?014A4@0E5AD04M7A`1ADE40?clo0410@015ADD0NWYj07inOP0];Bd0Hf=S02l_;`0c<c<0
JFUY03hn?P0j>SX0GEeM04I6AP1:BTX0H61P08N7Q`2h^;P0H61P07=cL`25QHD0JVYZ06MWI`2TY:@0
QHF504A4A00g=cL0E5AD05aLG01NGUh0G5aL09^KV`0205EEE@0O07=cL`1:BTX0TI6A05YJFP2EUID0
EeMG0:BTY01GEeL0Kfm_07YjNP2/[:`0MGEe09BDU03UiND0Ph>309JFUP1ZJVX0KVi^05EEE@1`L700
W9bL08^;R`1RHV80FEUI069RHP1dM7@0QhN705aLG01cLg<0OGem07=cL`0Aooooo`003oooool0202V
YZH0GemO07=cL`3Hf=P0R8R805EEE@1^KVh0Ph>30P1EEED0o`1UIFD0;Rh^07AdM02a/K40=3@d05QH
F00l?3`0EUIF06EUI@1;Bd/0;bl_04E5A@1CDe<0EeMG0;Fe]@0e=CD0<S8b05EEE@1BDU80C4a<0;:b
/P1lO7`08b<S038b<P1?Cdl0EeMG0:2PX014A4@0820P03`l?01CDe<0L71`075aL@2TY:@0:BTY04a<
C02=SHd0F5QH0<71`@2EUID071`L02`/;01FEUH0HF5Q08Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh09BDU04E5A@25QHD0A4A407QhN01DE5@05ADE02h^;P1PH600PX:206YZJP1=CDd09BDU04A4
A01/K6`0NGUi059BDP1FEUH0<S8b02`/;01BDU80De=C04m?C`1RHV80:RXZ02/[:`1=CDd0OGem04A4
A01IFET07alO04m?C`23Ph<0EUIF0492@P1VIVH0=SHf02h^;P1iNGT0FUYJ04I6AP1NGUh0=cLg04M7
A`26QXH0IfMW020P801;Bd/0I6AT069RHP2CTi<0CDe=034a<@1ADE40Fe]K05YJFP1XJ6P0Shn?02h^
;P15ADD0HF5Q06ATI020P800Y:BT04];B`0m?Cd0Fe]K08N7Q`2=SHd0KVi^02d];@1GEeL0FUYJ059B
DP1MGEd0][Jf06EUI@0O7al0KVi^061PH02KVi/0`/;203lo?`0^;Rh0IVIV0:VYZ@19BDT0TI6A02TY
:@1BDU80UYJF0<71`@1LG5`0/[:b07=cL`1?Cdl0De=C06m_K`1PH600LG5a028R8P12@T80EUIF05=C
D`1:BTX0JFUY07]kN`0i>CT0QHF50:ZZZP1FEUH0Ogmo079bLP15ADD0M7Ad09BDU01`L700HF5Q05IF
EP0h>3P0J6QX0:j^[P1mOGd0E5AD07alO010@400BTY:0:6QX@1KFe/0K6a/07YjNP0a<C40CDe=06m_
K`1nOWh0F5QH06=SH`15ADD0Xj>S09:BTP0^;Rh0@d=303dm?@1;Bd/0Ng]k07inOP1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`2^[Zh0CDe=03lo?`1hN7P0R8R8075aL@33`l<0UIFE02DU
9@10@400MgMg0;Fe]@1jNWX092@T055AD@1kNg/0L71`07QhN037alL0?clo05aLG02ATI40OGem08R8
R03:b/X0?Cdm01`L701IFET0[:b/07EeM@27QhL0:RXZ02TY:@1ADE40Zj^[06IVIP2ZZZX0RXZ:02DU
9@1GEeL0Ph>3079bLP2YZJT0EUIF02TY:@1BDU80VYZJ06QXJ0006@1kNg/0>3Ph04E5A@1iNGT0SXj>
07UiN@1HF5P0MGEe04Q8B00/;2`0Cdm?06e]K@1EEED0MgMg061PH00c<c<0?Cdm06MWI`1jNWX0CTi>
06MWI`0X:2P0JFUY09BDU01RHV807?ooool09`1=CDd0IVIV06=SH`11@D40FEUI04U9B@1ADE40NWYj
0492@P1VIVH0KVi^04e=C@11@D40G5aL06m_K`1hN7P0Hf=S04e=C@1TI6@0C4a<04I6AP0b<S80;bl_
04];B`0_;bl0@D5104];B`0j>SX07AdM04A4A01ADE40B4Q804I6AP15ADD0ATI605]KF`1:BTX0>c/k
04i>CP0204I6AP1302DU9@12@T80>CTi04e=C@12@T80CDe=04i>CP0i>CT0FEUI06EUI@1MGEd0De=C
06EUI@18B4P0Jf][05ADE00U9BD0J6QX04I6AP0h>3P0H61P07MgM`1BDU80S8b<051@D01MGEd0BTY:
08J6QP1ZJVX0IFEU09JFUP1GEeL0N7Qh09ZJVP2DU9@0FUYJ059BDP0g=cL0BTY:05UIF@1:BTX0EeMG
06MWI`1`L700>c/k04];B`0o?cl0@T9204A4A01:BTX0Cdm?04A4A01@D500=cLg04];B`16ATH0E5AD
04m?C`1SHf<0BDU903lo?`1QHF40BDU904i>CP1?Cdl0EUIF04=3@`0203lo?`1204U9B@1FEUH0>SXj
059BDP1?Cdl0V9RH05UIF@1GEeL0PX:205iNGP1DE5@0?clo0451@@1[Jf/0MGEe07=cL`26QXH0M7Ad
05MGE`0o?cl0LW9b07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:RXX0H61P09^KV`1MGEd0KVi^
07]kN`1eMGD0H61P07YjNP1]KFd0Jf][04m?C`1HF5P0GemO05ADE037alL0BTY:06i^KP1;Bd/0Shn?
065QH@1^KVh0BTY:065QH@2EUID0PH610>7Qh@3Cdm<0?Cdm05=CD`18B4P0IFEU05EEE@1iNGT0=CDe
06=SH`1ZJVX0EeMG0P2<S8`0I@1<C4`0JVYZ03`l?01kNg/0:b/[051@D01CDe<0@d=302@T901WIfL0
De=C07IfMP1=CDd0@D5104Q8B011@D40EEEE05iNGP1<C4`0KFe]061PH01OGel0C4a<038b<P1GEeL0
>SXj05]KF`1QHF40Q8B409bLW01MGEd0MgMg03@d=01OGel0LW9b034a<@0c<c<0Cdm?02l_;`0m?Cd0
:BTY04Y:BP14A4@0C4a<05IFEP1?Cdl0EEEE04U9B@12@T80@d=3061PH01ADE40<S8b08f=S@0`<300
<C4a05iNGP0m?Cd0Bd];06EUI@1<C4`0?Cdm04A4A01hN7P0RHV905ADE01ZJVX0MgMg06m_K`1?Cdl0
P82006a/K01XJ6P0IVIV05ADE01TI6@0IfMW03De=@1HF5P0FUYJ05eMG@1KFe/0CDe=04Y:BP1PH600
QHF509BDU02c/k<0Shn?0:j^[P1ZJVX0WIfM0;2`/02XZ:P0g]kN09>CT`2c/k<0E5AD05MGE`18B4P0
LG5a0080MgMg00T0LW9b04a<C01@D500F5QH07YjNP1bLW80E5AD08>3P`2EUID04Oooool000oooooo
06d0/K6a06IVIP23Ph<0PH6109BDU01FEUH0GEeM05mOG`1CDe<0KVi^09VIV@0o?cl0EUIF06m_K`1Q
HF40Ogmo03`l?00a<C40ATI606EUI@1ADE40Ph>309jNWP0_;bl0K6a/06ATI01KFe/0VYZJ04U9B@0N
7Qh0CTi>07YjNP1>CTh0Jf][02<S8`0`<300D51@096AT@16ATH0TI6A09fMW@0U9BD0;Rh^069RHP1B
DU80Ng]k059BDP0`<300EUIF079bLP1HF5P0Hf=S09NGU`11@D40OWin07alO01>CTh0KFe]05YJFP0]
;Bd0G5aL08>3P`1IFET0RXZ:04A4A00h>3P0IFEU0820P012@T80Fe]K05mOG`1:BTX0DU9B075aL@0k
>c/0GUiN07YjNP11@D40DE5A07alO01oOgl0?Shn06YZJP17AdL0GEeM08Z:RP1QHF40?Cdm05iNGP16
ATH0?clo07MgM`16ATH0B4Q805UIF@1ADE40G5aL075aL@1OGel0?Shn04];B`1<C4`0Kfm_08N7Q`0l
?3`0=3@d04a<C01:BTX0ATI60080SXj>07P0=cLg04Q8B01?Cdl0CDe=09bLW02=SHd0=SHf04A4A01L
G5`0DE5A09nOW`23Ph<0;bl_04];B`1JFUX0IfMW06UYJ@2i^KT0MgMg05EEE@1oOgl0DE5A0861P@1m
OGd0>c/k03hn?P1eMGD0SHf=05EEE@1jNWX0;2`/04Q8B02JVYX0SHf=055AD@22PX80EUIF03Xj>P21
PH40Jf][06EUI@2PX:00>c/k0492@P1mOGd0XZ:R065QH@1cLg<0ATI605YJFP2e]KD0O7al0410@01_
Kfl0Fe]K0410@01RHV80ZZZZ05ADE01LG5`0JVYZ03lo?`1dM7@0QHF5055AD@1EEED0NWYj065QH@23
Ph<0SHf=04e=C@1@D500HV9R04m?C`1ZJVX0W9bL06e]K@1@D500DU9B04Y:BP2HV9P0/K6a04E5A@1B
DU80PX:204e=C@1<C4`0VIVI03hn?P1]KFd0MWIf04=3@`1fMWH0Hf=S03`l?01FEUH0Ng]k07MgM`28
R8P0=CDe04i>CP2<S8`0IVIV08f=S@2<S8`0?3`l05iNGP1_Kfl0OGem09JFUP1>CTh0?3`l05eMG@2?
Shl0LW9b0:2PX01^KVh0G5aL08R8R01PH60208n?S`0i03`l?010@400GUiN07emO@28R8P0P820038b
<P18B4P0Ph>308F5Q@1EEED0VYZJ061PH01FEUH0[Jf]07]kN`1EEED0Ph>306IVIP0l?3`0Hf=S0:NW
Y`1jNWX0P82004Y:BP1=CDd0O7al0:j^[P2BTY80NGUi069RHP0i>CT0K6a/05YJFP0n?Sh0IFEU0820
P00e=CD0G5aL09ZJVP23Ph<0>3Ph05MGE`0l?3`0?clo08:2PP2ZZZX0EEEE04a<C01YJFT0>CTi04];
B`29RHT0=cLg069RHP1QHF40Bd];01cooooo00T0ADE505=CD`1_Kfl0D51@05=CD`0o?cl0C4a<05eM
G@19BDT00P18B4P204E5A@0C04A4A01;Bd/0B4Q805IFEP19BDT0CDe=0492@P10@400Bd];030`<01K
Fe/0@D5103dm?@1GEeL0DU9B04=3@`1;Bd/0A4A404=3@`0204Y:BP0S03dm?@1GEeL0EeMG05UIF@1N
GUh0C4a<04];B`0f=SH0=cLg04i>CP1QHF40AdM704e=C@1VIVH0CDe=05QHF01JFUX0J6QX04m?C`1F
EUH0CDe=04i>CP1=CDd0@41005mOG`12@T80?Cdm051@D01SHf<0DE5A05iNGP0n?Sh0F5QH04=3@`1R
HV800P1FEUH0f`1mOGd0GEeM05mOG`1ZJVX0JFUY06QXJ01aLG40=SHf0451@@1TI6@0H61P07EeM@2@
T900F5QH03/k>`1IFET0@d=30451@@10@400B4Q804A4A00k>c/0EeMG03hn?P1=CDd0DU9B06=SH`1>
CTh0E5AD03Ti>@19BDT0DE5A05eMG@1ZJVX0BDU9055AD@19BDT0De=C04Y:BP1FEUH0MgMg04i>CP1K
Fe/0D51@05MGE`1CDe<0HV9R07]kN`19BDT0B4Q804A4A01EEED0FEUI06EUI@1hN7P0Shn?05YJFP1d
M7@0F5QH09ZJVP2ATI40];Bd06UYJ@1HF5P0V9RH06MWI`1iNGT0Ng]k04E5A@2<S8`0JFUY06YZJP20
P800G5aL07]kN`1XJ6P0KFe]05mOG`1BDU80H61P05]KF`1YJFT0[:b/04m?C`1`L700C4a<0820P01<
C4`0I6AT03lo?`1[Jf/0UiNG06=SH`2d];@0^k^k05EEE@1cLg<0IFEU05mOG`13@d<0VIVI04];B`1j
NWX0SHf=059BDP1CDe<0CTi>05MGE`1fMWH0FEUI08N7Q`0m?Cd0HF5Q05UIF@1ZJVX0Bd];06e]K@1G
EeL0LG5a05EEE@15ADD0AdM703lo?`1fMWH0EEEE030`<01MGEd0F5QH071`L01@D500CTi>05iNGP1>
CTh0IFEU06YZJP2OWil0Hf=S0492@P1PH600D51@06=SH`1LG5`0@D5104];B`1SHf<0>c/k0451@@0n
?Sh0Cdm?04Q8B014A4@0F5QH059BDP1IFET0@D51059BDP18B4P0Ph>305UIF@1?Cdl0SHf=03Hf=P0h
>3P0EEEE030`<01?Cdl0IfMW04a<C00n?Sh0ADE506=SH`1fMWH0CTi>05mOG`25QHD0G5aL05UIF@1/
K6`0HF5Q0410@012@T80C4a<05aLG01TI6@0ADE507UiN@19BDT0DU9B06MWI`0k>c/0DU9B04U9B@2>
SXh0DE5A08>3P`1OGel0L71`07YjNP2?Shl0QhN70;6a/@2e]KD0M7Ad0:FUY@1/K6`0JVYZ04Q8B01^
KVh0S8b<08>3P`1TI6@0@41005YJFP1^KVh0OGem08Z:RP1WIfL0NGUi09bLW00Aooooo`003oooool0
HP1cLg<0PX:209bLW01EEED0HV9R08F5Q@1lO7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<04E5
A@1YJFT0OGem07MgM`1SHf<071`L04I6AP1gMgL0YJFU05YJFP27QhL09bLW04Y:BP22PX80X:2P051@
D02OWil0DE5A03@d=01QHF40G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0Lg=c02@T
901`L700YZJV03hn?P19BDT0FEUI030`<00o?cl0[Jf]069RHP19BDT0>SXj02@T901BDU80M7Ad03@d
=00[:b/0?Cdm038b<P2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0j>SX0BTY:03<c
<`1ADE40WYjN04Y:BP0S8b<0?clo03/k>`0m?Cd0MWIf03<c<`0m?Cd0@410051@D01bLW80XZ:R04U9
B@0U9BD0Cdm?05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0:@2YZJT0CTi>05]KF`1dM7@0GUiN
051@D02MWId0?Shn02`/;01CDe<0GUiN08F5Q@27QhL0=cLg04Q8B01KFe/0KVi^05UIF@1kNg/0YJFU
03hn?P1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FEU@2d];@0UiNG0451@@14A4@0SXj>
092@T01gMgL0S8b<04A4A010@400NWYj0080Lg=c07X0NGUi04M7A`1:BTX0GEeM0:ZZZP0o?cl0JVYZ
030`<01CDe<0RHV909fMW@12@T80PX:206YZJP1:BTX0O7al05eMG@11@D40H61P03/k>`1IFET0Q8B4
06m_K`0P8200:BTY05aLG01ZJVX0RHV906m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP16ATH0EEEE
07moO`21PH40UIFE08j>SP0_;bl0:2PX05UIF@1YJFT0OGem06][J`0];Bd0<C4a05aLG01WIfL0N7Qh
0;Rh^00j>SX09RHV071`L01iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO069RHP15ADD0R8R8
08>3P`2?Shl0WYjN051@D00o?cl0Q8B409NGU`2TY:@0@d=304E5A@1EEED0R8R806e]K@2TY:@0<C4a
03hn?P1ADE40M7Ad0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0AdM705MGE`2^[Zh0UYJF
05UIF@1aLG40>CTi03lo?`1UIFD0Q8B405]KF`1HF5P0=SHf038b<P1]KFd0R8R803lo?`1EEED0Cdm?
02`/;01UIFD0Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@80Bd];01L0E5AD08f=S@2/[:`0
C4a<024Q8@18B4P0FEUI04Y:BP1jNWX0:BTY030`<012@T80HV9R051@D01fMWH0c<c<04U9B@0Q8B40
BTY:04M7A`28R8P0RHV903`l?00Looooo`1?05EEE@1YJFT0FUYJ03dm?@0j>SX0EEEE06ATI012@T80
7alO03lo?`1mOGd0@D5102PX:00h>3P0MGEe05iNGP0b<S809BDU0451@@15ADD0?Shn030`<00X:2P0
B4Q804A4A01=CDd0D51@02/[:`0D51@0@T9204Y:BP1=CDd0ADE503Lg=`1:BTX0CDe=03Hf=P0_;bl0
CTi>04Y:BP1>CTh09bLW03@d=01;Bd/0GUiN04=3@`1ADE40De=C05EEE@1VIVH0IfMW06EUI@1IFET0
IFEU0451@@1BDU80GemO05=CD`1JFUX0:2PX03<c<`1<C4`0HF5Q04M7A`1ADE40C4a<05ADE00n?Sh0
GEeM06EUI@1WIfL0Kfm_04];B`1gMgL0QhN705mOG`15ADD0Jf][05IFEP02079bLP2[03lo?`1DE5@0
Fe]K04A4A00U9BD0Cdm?04Y:BP1DE5@0Bd];04U9B@14A4@0;Bd]04=3@`0R8R80>SXj04M7A`1@D500
CTi>04a<C00_;bl0AdM705MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04m?C`0o?cl0
DU9B05UIF@1VIVH0A4A406EUI@1eMGD0CTi>04a<C011@D40CDe=069RHP1jNWX0Cdm?04a<C01QHF40
K6a/034a<@1@D500IVIV09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0R8R804Y:BP1EEED0
G5aL0492@P0k>c/0Fe]K05iNGP1]KFd0=cLg06i^KP1aLG40Cdm?0;Jf]P1kNg/0Xj>S07EeM@1/K6`0
CDe=09VIV@1bLW80MgMg08>3P`2ATI40kNg]0=SHf01DE5@0H61P05EEE@1TI6@0De=C0:VYZ@0c<c<0
L71`075aL@10@400N7Qh05QHF01QHF40IFEU06YZJP22PX80ADE505UIF@1KFe/0FEUI03Hf=P2;Rh/0
GemO07YjNP1HF5P0JFUY075aL@1VIVH0W9bL05iNGP1?Cdl0RHV905=CD`1JFUX0Bd];04a<C01KFe/0
CDe=05iNGP14A4@0K6a/05ADE01@D500G5aL03/k>`1:BTX0D51@0492@P0l?3`0C4a<04=3@`14A4@0
>SXj04U9B@1OGel0BDU905ADE01OGel0L71`03hn?P1=CDd0BDU9065QH@15ADD0D51@0:NWY`0_;bl0
GUiN06EUI@1ZJVX0ATI608n?S`1QHF40DU9B07emO@1^KVh0LW9b05ADE01@D500MGEe05YJFP1WIfL0
JVYZ07QhN01HF5P0CDe=0080FUYJ02@0I6AT04E5A@1`L700:RXZ04Y:BP1WIfL0=3@d04m?C`19BDT0
XJ6Q061PH024Q8@0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0GEeM06][J`0`<300
G5aL05UIF@1VIVH0H61P05MGE`1CDe<0SXj>07inOP1RHV80ZJVY07alO01]KFdAooooo`003oooool0
F02RXZ80DE5A069RHP2=SHd0PX:204A4A01JFUX0WIfM07QhN01BDU80Bd];03/k>`1GEeL0LW9b0492
@P2;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`1[Jf/0BDU902h^;P1>CTh0BTY:03hn
?P2GUiL0OWin03/k>`10@400;bl_03Xj>P25QHD0ADE502<S8`0f=SH0>c/k03Ti>@1IFET0V9RH02<S
8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ0820P02^[Zh0<C4a01/K6`0`<300Vi^K071`
L01dM7@0O7al01`L7013@d<0[Zj^065QH@2GUiL0KFe]02@T900P8200:b/[06m_K`1cLg<0De=C03Hf
=P14A4@0=CDe08>3P`1LG5`0NGUi03De=@0X:2P0Bd];04U9B@1FEUH0R8R803Xj>P0c<c<208^;R`38
03Lg=`1JFUX0<c<c04a<C02EUID0F5QH03hn?P1dM7@0<S8b030`<01CDe<0JFUY04E5A@1UIFD09bLW
04U9B@1fMWH0Fe]K038b<P1EEED0IfMW03dm?@2_[jl0MGEe02`/;01SHf<0CDe=02d];@0n?Sh0UYJF
04A4A01UIFD0@T9203dm?@2BTY80ZJVY04e=C@0o?cl0HF5Q0492@P1gMgL0a<C404e=C@12@T80Cdm?
04];B`1BDU80/k>c07]kN`0];Bd0BDU905YJFP1dM7@0Zj^[03<c<`0/;2`0@D5105QHF01QHF40RHV9
02DU9@0n?Sh0FUYJ06=SH`1PH600];Bd08n?S`0T92@0Hf=S08F5Q@23Ph<0PX:203<c<`0/;2`0Jf][
0;bl_01UIFD0Kfm_09JFUP0m?Cd0MGEe0:FUY@1EEED0X:2P06YZJP10@400H61P0:f][@2TY:@0`/;2
04m?C`1LG5`0M7Ad0;>c/`2@T900JFUY08:2PP0n?Sh0LG5a0820P01FEUH0Ph>308n?S`0K6a/0Hf=S
0=;BdP2`/;00DU9B05IFEP1>CTh0UiNG0<K6aP1MGEd0IFEU03Xj>P0o?cl0J6QX09FEU@1>CTh0CDe=
02h^;P1LG5`0`L7107moO`1`L700EeMG03lo?`1lO7`0Rh^;04e=C@1YJFT0?Cdm07AdM02e]KD0TI6A
03lo?`2NWYh0Hf=S0:VYZ@2OWil0?Shn04M7A`1VIVH0JVYZ06=SH`32`/80IVIV04M7A`1NGUh0MWIf
0:FUY@3:b/X0=CDe034a<@1RHV80G5aL08B4Q03:b/X09bLW01lO7`1^KVh0NGUi04m?C`2[Zj/0YjNW
02l_;`1GEeL0RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1`L7009BDU02h^;P1EEED0WinO
07UiN@1TI6@0MGEe04a<C00`<300L71`08j>SP1:BTX0U9BD05IFEP0N7Qh0>3Ph07]kN`1fMWH0ADE5
04a<C00_;bl0CTi>08N7Q`1_KflLooooo`0;05QHF01VIVH0J6QX03hn?P14A4@0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl00`1FEUH0Bd];05IFEP0305UIF@1F06EUI@1FEUH0=cLg03Ti>@1YJFT0
>CTi05=CD`29RHT0Bd];03Ti>@1BDU80EUIF07QhN01GEeL0ADE505ADE01VIVH0Fe]K04a<C01IFET0
JVYZ05EEE@0_;bl0HF5Q04m?C`1:BTX0C4a<05eMG@11@D40?3`l04Y:BP16ATH0@D51038b<P0h>3P0
FEUI051@D00n?Sh07alO03hn?P0l?3`0@T9205ADE01BDU80Cdm?04Q8B00l?3`0?clo03<c<`1:BTX0
A4A404I6AP1OGel0NGUi03lo?`1LG5`0D51@04i>CP1=CDd09BDU038b<P1>CTh0A4A404I6AP0i>CT0
>SXj02PX:014A4@0@D510410@01BDU80A4A403Ti>@19BDT0DE5A04=3@`1=CDd0FEUI051@D00k>c/0
ADE503De=@0j>SX0?clo05ADE01[Jf/205IFEP1m04a<C01HF5P0C4a<04];B`1iNGT0De=C05eMG@1D
E5@0Hf=S06e]K@1aLG40O7al06YZJP1/K6`0CDe=05=CD`1LG5`0@T92065QH@1mOGd0?clo06IVIP0h
>3P0NGUi06e]K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0:6QX@1RHV80JFUY079bLP1N
GUh0Hf=S065QH@1TI6@0K6a/05EEE@1CDe<0A4A407moO`2k^k/0AdM706ATI01ADE40WYjN05EEE@1U
IFD0FEUI09JFUP2[Zj/0NGUi08^;R`2:RXX0IfMW05MGE`1:BTX0KVi^04M7A`1fMWH0Jf][0:JVYP2A
TI40AdM7079bLP19BDT0?3`l04M7A`0n?Sh0GemO04=3@`2MWId0N7Qh06IVIP1CDe<0LW9b07AdM02c
/k<0NWYj04I6AP18B4P0Cdm?09FEU@1KFe/0:b/[05YJFP1KFe/0Ng]k0410@01KFe/0I6AT069RHP1j
NWX0LG5a09:BTP1LG5`0Bd];075aL@1GEeL0Cdm?05=CD`0e=CD0EeMG06QXJ00d=3@0?3`l03Ph>01<
C4`0ADE504Y:BP1TI6@0D51@04i>CP18B4P0AdM704E5A@1eMGD0?Cdm05iNGP2][Jd00P1DE5@0>01M
GEd0;2`/04=3@`1`L700CDe=04m?C`1SHf<0QhN707emO@1/K6`0EUIF06IVIP1RHV80CDe=0820P01f
MWH0@T92059BDP11@D40GEeM06EUI@0Z:RX0KFe]04E5A@28R8P0Rh^;07EeM@1nOWh0GEeM079bLP1]
KFd0ZJVY06][J`1kNg/0IVIV0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG07AdM02WYjL0H61P0:NWY`2P
X:00XZ:R06MWI`1>CTh0DE5A06EUI@1cLg<0PX:207=cL`22PX80Q8B44Oooool000oooooo04D0`/;2
05ADE01HF5P0K6a/09bLW010@400AdM705=CD`23Ph<0UiNG09VIV@0Z:RX0AdM7065QH@1aLG40V9RH
03@d=01@D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0E5AD06i^KP1PH600WYjN02LW9`0^;Rh0>3Ph
06a/K00i>CT0K6a/018B4P0e=CD0Cdm?05QHF019BDT0Vi^K0;2`/00I6AT0>CTi06][J`1EEED0De=C
051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0S8b<0IfMW0:6QX@0m?Cd0@T920451@@0i>CT0@d=3
07IfMP1:BTX0B4Q802`/;015ADD0CDe=079bLP0];Bd00P0j>SX0J00a<C40?Shn05QHF00[:b/0?Shn
05EEE@0c<c<0GemO06a/K010@40061PH059BDP0^;Rh0G5aL0:FUY@18B4P0820P04=3@`1VIVH0AdM7
06YZJP0Z:RX0=CDe05EEE@1`L700IfMW09fMW@0_;bl0;2`/03Xj>P1fMWH0QhN70:n_[`0S8b<09BDU
05UIF@27QhL0F5QH06YZJP21PH409RHV06m_K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0O7al
0:JVYP1>CTh09RHV05ADE02QXJ40U9BD07=cL`1iNGT0<30`05IFEP2<S8`0Q8B407]kN`20P8008B4Q
05ADE01nOWh0NWYj06IVIP1dM7@09bLW05eMG@1SHf<0Ng]k05mOG`26QXH09BDU02d];@1_Kfl0@d=3
04a<C025QHD0<S8b02h^;P29RHT0]kNg05MGE`1DE5@0DE5A04I6AP2TY:@0Fe]K02/[:`1DE5@0EUIF
02PX:013@d<0WYjN03/k>`1SHf<0A4A4034a<@1_Kfl0Zj^[0P0h>3P0H`19BDT0DU9B07AdM01mOGd0
>CTi05ADE01KFe/0>SXj09BDU02n_[h0@d=304U9B@29RHT0Cdm?09>CT`34a<@0<C4a02`/;021PH40
RHV9071`L01]KFd0<S8b07moO`2g]kL0GUiN09FEU@0m?Cd07QhN04A4A02?Shl0NWYj05=CD`0O7al0
BDU908V9R@21PH40UiNG07MgM`0Y:BT0NGUi096AT@27QhL0T92@02l_;`1:BTX0O7al0:RXZ01YJFT0
`L7104U9B@28R8P0Vi^K07emO@29RHT0NGUi03lo?`10@400L71`0:ZZZP2[Zj/0UYJF03`l?01MGEd0
ZZZZ07moO`1?Cdl0MWIf04E5A@0n?Sh0YJFU06i^KP0a<C40RXZ:06MWI`0l?3`0ADE508R8R01ADE40
HF5Q04E5A@16ATH0KFe]0820P015ADD0LG5a05ADE00l?3`0Q8B4055AD@0e=CD0K6a/06=SH`1GEeL0
?Shn08V9R@2:RXX09bLW038b<P0205IFEP0<08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@23Ph<0
7alO03`l?016ATH0HF5Q7?ooool0gP1NGUh0C4a<06e]K@11@D40G5aL04M7A`1CDe<0GemO04U9B@1K
Fe/0CTi>059BDP15ADD0Cdm?05=CD`1NGUh0H61P069RHP1DE5@0@D5103hn?P1:BTX0;bl_055AD@0o
?cl0>c/k0451@@1=CDd0@D5105]KF`1RHV80GemO04m?C`1>CTh0ADE506a/K01CDe<0BTY:055AD@17
AdL0Bd];01dM7@0h>3P0AdM705iNGP11@D40G5aL071`L01?Cdl0Ng]k07alO01nOWh0I6AT05UIF@0c
<c<0?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04m?C`1_Kfl0I6AT03hn?P1;Bd/0IFEU07EeM@17
AdL0?clo04U9B@1>CTh0D51@05eMG@1FEUH0IFEU08B4Q00i>CT0@d=307]kN`1MGEd0F5QH02XZ:P0]
;Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;Bd]05ADE01LG5`0<c<c0410@01^KVh0F5QH03Ph>014
A4@0FEUI04i>CP0h>3P0Hf=S06EUI@0g=cL0ADE504m?C`0l?3`0<S8b04I6AP23Ph<0>c/k051@D01B
DU80KFe]03@d=016ATH0LW9b04i>CP1RHV80DU9B06UYJ@1IFET0JVYZ07emO@2?Shl0BTY:07moO`1=
CDd0WYjN071`L02:RXX0EeMG04=3@`1[Jf/0IFEU08Z:RP24Q8@0Cdm?079bLP1RHV80J6QX09>CT`1[
Jf/0IVIV07IfMP1XJ6P0<S8b0492@P1IFET0EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1e
MGD0=CDe04=3@`1ADE40ATI60>SXj02TY:@0?Cdm07moO`1LG5`0Ogmo05eMG@2CTi<0B4Q8079bLP1Z
JVX0Cdm?04Y:BP15ADD0Ng]k08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo065QH@1N
GUh0CDe=04Y:BP1CDe<0B4Q805iNGP1SHf<0ATI608b<S017AdL0BDU904];B`1UIFD0J6QX03dm?@0o
?cl0D51@07AdM01cLg<0De=C06=SH`0m?Cd0Ng]k07emO@17AdL0GEeM05IFEP1;Bd/0?Shn03Xj>P1A
DE40ADE504A4A080E5AD0480EUIF04I6AP1?Cdl0Cdm?0:b/[01HF5P0MWIf096AT@0S8b<0F5QH05eM
G@18B4P0JFUY07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04M7A`1EEED0Shn?07Ui
N@1TI6@0EUIF065QH@2GUiL0Ph>306ATI01mOGd0FEUI07AdM01jNWX0@T9204U9B@1]KFd0T92@06QX
J02:RXX0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h^;P0Ogmo09fMW@1/K6`0Kfm_05EE
E@1DE5@0IFEU061PH01QHF40Kfm_07alO01LG5`0NGUi08N7Q`1bLW8Aooooo`003oooool07`1lO7`0
RXZ:0;Fe]@1;Bd/0Rh^;08F5Q@1lO7`0K6a/02d];@1cLg<0OWin05aLG01`L700Kfm_04a<C02YZJT0
MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K607MgM`1<C4`0<C4a05EEE@25QHD0IFEU03Lg=`1ADE40
0P17AdL0o`1]KFd0<c<c02d];@1eMGD0?Cdm03@d=02JVYX0QHF504Q8B00k>c/0DE5A06a/K01oOgl0
JFUY02LW9`0[:b/0?Shn04m?C`1XJ6P0Z:RX03<c<`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80
P82006IVIP2VYZH0?Shn028R8P1OGel0JFUY04E5A@23Ph<0^;Rh02<S8`10@400De=C04A4A01lO7`0
`<3003Ph>00W9bL0D51@05iNGP19BDT0YZJV02PX:00i>CT0HF5Q08b<S01IFET0T92@03@d=00b<S80
KVi^05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^04Q8B01@D500LW9b05UIF@0k>c/0
GemO03De=@0n?Sh0CDe=05]KF`1JFUX0LG5a03Xj>P0n?Sh0F5QH0820P00j>SX0CDe=05eMG@0k>c/0
Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0ADE507]kN`17AdL0NGUi0<K6aP1TI6@0
?Cdm07EeM@1TI6@0C4a<09VIV@0f=SH0?Cdm06EUI@1LG5`0HF5Q0;6a/@2IVIT09RHV06IVIP1KFe/0
Jf][0<30`01SHf<0:BTY06e]K@2XZ:P0Kfm_07QhN01MGEd0;Bd]08R8R02ATI40D51@096AT@1FEUH0
=3@d051@D01nOWh0PX:209ZJVP0o?cl0DE5A08B4Q02XZ:P0LG5a07EeM@26QXH0=cLg08F5Q@3>c/h0
JVYZ08^;R`2FUYH0>3Ph03/k>`1kNg/0[Zj^06a/K01WIfL0CTi>06][J`1hN7P0KVi^069RHP1jNWX0
>CTi04I6AP2^[Zh0:b/[05ADE00n?Sh0?clo05EEE@1eMGD0<C4a051@D01>CTh0Ti>C0:NWY`0o?cl0
BDU9061PH012@T80JFUY0:>SX`19BDT0H61P04Q8B01XJ6P0Q8B404Q8B00e=CD0Jf][0410@01BDU80
_[jn05YJFP16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706e]K@2TY:@0T92@03Ph>01;Bd/0
Lg=c03lo?`1DE5@0a<C406e]K@10@400DE5A06e]K@14A4@0SHf=07YjNP0i>CT0@d=306=SH`1fMWH0
R8R806IVIP0n?Sh0H61P06e]K@1CDe<0YJFU07inOP10@400H61P09ZJVP1@D500RHV906QXJ013@d<0
@T9206IVIP24Q8@0CTi>06ATI00G5aL0@41004];B`1VIVH0LW9b06i^KP2MWId0=SHf04];B`1SHf<0
BTY:06EUI@0104i>CP40;2`/7?ooool0IP1GEeL0EUIF06UYJ@1CDe<0B4Q804M7A`1:BTX0@T9202TY
:@1FEUH0C4a<02l_;`0a<C40Bd];05eMG@1GEeL0BDU9059BDP1PH600EEEE04Q8B00e=CD09BDU059B
DP1?Cdl0Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C01=CDd0De=C05MGE`1FEUH0CTi>05EE
E@1CDe<0L71`02DU9@18B4P0F5QH06i^KP19BDT0K6a/079bLP1DE5@0RXZ:09JFUP1kNg/0GUiN07Ee
M@19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0CDe=05ADE01OGel0F5QH04M7A`16ATH0?clo06IV
IP1GEeL0D51@05MGE`1SHf<0HF5Q06][J`1dM7@0Bd];05QHF00d=3@0ADE505UIF@10@400C4a<03hn
?P0S8b<0:b/[059BDP0k>c/0ADE504e=C@1CDe<0@41003/k>`1EEED0;Rh^0410@00i>CT0AdM704E5
A@11@D409BDU03dm?@80CTi>08P0J6QX04Y:BP1=CDd0CDe=04a<C013@d<0De=C0410@00b<S80CTi>
061PH029RHT0;2`/05EEE@1NGUh0EeMG05]KF`0c<c<0ATI605mOG`27QhL0CDe=069RHP1>CTh0Fe]K
04I6AP1UIFD0Ng]k0=[JfP2DU9@0LG5a07alO017AdL0UiNG08J6QP1?Cdl0KVi^07AdM027QhL0GEeM
04=3@`0m?Cd0De=C0861P@18B4P0?3`l051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[Jf/0?Shn
0;Rh^00h>3P0MWIf06IVIP1KFe/0Xj>S09VIV@0/;2`0DU9B0451@@1ZJVX0KVi^08B4Q00[:b/0PH61
07EeM@1=CDd0LW9b04e=C@1FEUH0GEeM09FEU@1OGel0@D51092@T01GEeL0D51@04Q8B02`/;00QHF5
07MgM`1SHf<0LG5a06QXJ018B4P0YJFU0820P00d=3@0GEeM04m?C`1_Kfl0<30`03Xj>P1:BTX0C4a<
05=CD`1[Jf/0U9BD06ATI01:BTX0QHF5038b<P1<C4`0Bd];03@d=01:BTX0EUIF03@d=018B4P0?clo
04U9B@1GEeL0CDe=05=CD`1HF5P0JVYZ04i>CP1KFe/0GemO06EUI@0m?Cd0GEeM06YZJP0m?Cd0Ph>3
06YZJP1EEED0B4Q805]KF`10@400EeMG0P1KFe/05P1?Cdl0EUIF05MGE`1SHf<0EEEE06i^KP2NWYh0
KVi^06a/K01cLg<0G5aL06UYJ@1gMgL0@T9206QXJ00/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P2
07EeM@0H06MWI`1lO7`0UiNG0<o?c`2<S8`0UYJF0:2PX01VIVH0SHf=055AD@1IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`28R8P0OGem09VIV@2?Shl0O7al4Oooool000oooooo08@0PX:2
05aLG01cLg<0FUYJ05MGE`1VIVH0Q8B408V9R@0k>c/0De=C07YjNP1`L700N7Qh096AT@0e=CD0Lg=c
08V9R@2RXZ80U9BD03@d=015ADD0Fe]K06][J`2;Rh/0YJFU02l_;`13@d<0G5aL08b<S01NGUh0X:2P
055AD@0f=SH0Kfm_06ATI01CDe<0bLW9061PH00N7Qh0?Shn075aL@1DE5@0LW9b07alO00S8b<0JFUY
0:JVYP1NGUh0Vi^K09RHV00^;Rh0?clo07YjNP24Q8@0P82004U9B@0X:2P0Cdm?08n?S`1=CDd0A4A4
05=CD`0a<C40HF5Q08:2PP1@D500FUYJ04e=C@0/;2`0@D5108N7Q`1RHV80AdM70451@@0_;bl0ADE5
075aL@1dM7@0?Cdm05iNGP0b<S80?3`l08V9R@1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q
0451@@1<C4`0JFUY09FEU@0f=SH0;Rh^05=CD`12@T80CDe=08N7Q`1>CTh0@d=305mOG`1QHF40IFEU
0;>c/`1PH6008B4Q05iNGP1IFET0GemO0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT0?Shn
05IFEP1hN7P0ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<3007IfMP2BTY8204Q8B00>08:2PP20P800
JVYZ0;Fe]@1ADE40Cdm?07MgM`1]KFd0Ng]k07YjNP0Z:RX0@d=306QXJ03Cdm<208n?S`1f03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907QhN012@T80MWIf03lo?`1@D500LG5a07UiN@0e
=CD0D51@08B4Q00n?Sh0RXZ:08B4Q00^;Rh0DU9B07alO01PH600NGUi0<k>cP1^KVh0CTi>08N7Q`15
ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0LG5a08n?S`0g=cL0Cdm?08B4Q01nOWh0RXZ:0;fm_@1:
BTX0<S8b07EeM@1oOgl0^KVi06=SH`0b<S80F5QH07MgM`1FEUH0WYjN06][J`1:BTX0YJFU05eMG@2K
Vi/0FUYJ028R8P0i>CT0OGem06EUI@2XZ:P0<C4a04E5A@1]KFd0Hf=S06m_K`2/[:`0ATI603Ti>@2<
S8`0TI6A0:6QX@1:BTX0<30`04Y:BP2TY:@0^[Zj069RHP2OWil0;2`/07UiN@2PX:00EUIF07AdM02h
^;P0AdM703Hf=P1/K6`0YJFU07IfMP1GEeL0;bl_04M7A`1<C4`0JFUY04Q8B01gMgL0GemO01PH601L
G5`0NWYj03Ti>@1hN7P0FEUI03dm?@1^KVh0b<S806IVIP0j>SX0B4Q8038b<P80Ng]k01@0<c<c03Ph
>01CDe<0EeMG0410@025QHD0Fe]K03Ph>01fMWH0@41003lo?`1GEeL0T92@04Y:BP0a<C40Bd];05=C
D`2PX:00/k>c03dm?Acooooo02/0De=C06IVIP1mOGd0@D5104i>CP1BDU80GUiN055AD@0f=SH0EeMG
04m?C`15ADD0EEEE05YJFP1CDe<0FUYJ08^;R`1]KFd0GEeM06IVIP1OGel0@410034a<@1MGEd0@D51
04Y:BP1CDe<0@41003Ph>01EEED0FUYJ08:2PP1LG5`0Bd];06=SH`1PH600AdM703Xj>P1:BTX0GUiN
04E5A@0W9bL0DU9B0080BDU90?D0De=C06MWI`18B4P0ADE506MWI`2/[:`0J6QX04A4A016ATH0A4A4
059BDP1ADE40H61P07inOP1ADE40GEeM065QH@1LG5`0HV9R04m?C`15ADD0@d=306EUI@1MGEd0CDe=
04i>CP1XJ6P0IFEU08b<S026QXH0NWYj04U9B@1OGel0=CDe06=SH`1PH600HF5Q05UIF@12@T80<S8b
04];B`18B4P0>SXj03De=@1FEUH0FUYJ04U9B@1ADE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO
04I6AP1?Cdl0EUIF069RHP1aLG40B4Q804a<C017AdL0@D51034a<@0d=3@0FUYJ03/k>`1FEUH0ATI6
04];B`0W9bL0JFUY08B4Q01;Bd/0NWYj04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l
07inOP1GEeL0dm?C071`L01QHF40NGUi034a<@23Ph<0KVi^03hn?P2>SXh0Fe]K065QH@2<S8`0IfMW
09RHV01VIVH0ATI604A4A01KFe/0Cdm?03Ph>01LG5`0Lg=c03<c<`1]KFd0>3Ph07alO00e=CD0G5aL
04A4A02JVYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C06QXJ01BDU80JFUY02XZ:P2][Jd0S8b<
03lo?`18B4P0:b/[05EEE@1<C4`0GUiN034a<@0^;Rh0EeMG04I6AP2@T9008B4Q07alO01IFET0QXJ6
05EEE@1:BTX0FEUI04=3@`1GEeL0DE5A05YJFP1LG5`0Bd];05=CD`0f=SH0N7Qh075aL@12@T80=3@d
04I6AP1OGel0KVi^04I6AP1CDe<08b<S051@D01CDe<07QhN061PH01cLg<0>SXj0451@@1JFUX0GemO
04a<C013@d<0Jf][065QH@1:BTX0=SHf04I6AP12@T80JVYZ03/k>`21PH40/K6a04Q8B01<C4`0@T92
02@T9019BDT0Lg=c03@d=01BDU80IFEU08b<S01JFUX0CTi>04U9B@1WIfL0CTi>04I6AP1[Jf/0DE5A
03Lg=`1=CDd0Bd];05IFEP1LG5`0;2`/07EeM@0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k
06m_K`1bLW80NGUi051@D01/K6`0Jf][0;^k^`2MWId0N7Qh07emO@1ADE40Kfm_03`l?01OGel0DE5A
04e=C@1@D500FEUI05IFEP1VIVH0M7Ad071`L01WIfL0LG5a08V9R@0Aooooo`003oooool0o`2^[Zh0
D51@05aLG01eMGD0VIVI03/k>`1ADE40GUiN05aLG02_[jl0O7al03@d=018B4P0IFEU069RHP1]KFd0
9BDU04m?C`1]KFd0Jf][03<c<`1SHf<0>c/k02XZ:P1SHf<0Cdm?03lo?`1]KFd0B4Q803hn?P1QHF40
PX:203Lg=`17AdL09bLW02<S8`1iNGT0QXJ602`/;011@D40GemO01/K6`0[:b/0PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad04Q8B02LW9`0LG5a02<S8`0V9RH0GUiN059BDP1/K6`0
QXJ603@d=019BDT0Jf][04m?C`2ATI40H61P03Lg=`0h>3P0Hf=S07QhN01kNg/0TI6A01lO7`16ATH0
MWIf061PH01HF5P0YjNW03hn?P0e=CD0LG5a0820P01VIVH0c<c<03lo?`10@400CDe=07inOP1GEeL0
Hf=S03Hf=P17AdL0MgMg09BDU01XJ6P0QXJ603<c<`12@T80De=C06QXJ01SHf<0LW9b03Lg=`10@400
GUiN08V9R@1DE5@0IFEU059BDP0e=CD0M7Ad06a/K00h>3P0HV9R03Ti>@0Y:BT0C4a<07EeM@1SHf<0
NWYj0451@@0T92@0Bd];08R8R01SHf<0CDe=07]kN`12@T80?clo07alO01DE5@0GEeM05IFEP0l?3`0
CTi>06YZJP28R8P0AdM705aLG00a<C40QHF50<c<c01ZJVX0<S8b06QXJ01IFET0;2`/08J6QP0c<c<0
=SHf04i>CP17AdL0@D510:2PX02c/k<0<C4a04M7A`1NGUh0Ogmo08V9R@1IFET0:b/[06IVIP1OGel0
EeMG0:FUY@3Rh^80<30`07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0Zj^[0;>c/`2PX:00
AdM70451@@2OWil0TI6A09VIV@3De=@0Bd];05EEE@2JVYX0Ogmo09NGU`2m_Kd08B4Q06MWI`38b<P0
^KVi09VIV@1XJ6P0?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D02SXj<0JFUY07QhN015ADD0
K6a/09FEU@1DE5@0MgMg06=SH`0`<300KVi^05MGE`10@400FUYJ034a<@1GEeL0N7Qh06m_K`18B4P0
H61P04A4A027QhL0V9RH034a<@0h>3P0C4a<05mOG`1WIfL0XJ6Q03lo?`1@D500G5aL07MgM`2EUID0
_Kfm04a<C00Y:BT0C4a<071`L01kNg/0QXJ601hN7P0];Bd0M7Ad06MWI`1NGUh0XJ6Q0;Vi^@008`0`
<300C4a<08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1dM7@0Q8B402l_;`17AdL0BDU908f=S@1L
G5`0I6AT096AT@1iNGT07AdM05=CD`1[Jf/0J6QX0;no_`25QHD0820P034a<@1]KFd0L71`06EUI@1b
LW80=SHf0410@01UIFD0I6AT01cooooo03H0G5aL04e=C@1^KVh0@d=304a<C00e=CD0CTi>06][J`1>
CTh0GEeM04U9B@0l?3`0<C4a061PH01=CDd0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1R
HV80ADE504A4A01@D500CDe=04Y:BP1LG5`0E5AD05aLG01BDU80De=C04M7A`1ZJVX0N7Qh065QH@1F
EUH0ADE5051@D00V9RH0?Cdm04a<C01QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1F
EUH2061PH00=03Ph>00e=CD0E5AD06i^KP1dM7@0?Cdm0410@020P800I6AT03/k>`0o?cl0A4A404m?
C`0204=3@`0303Xj>P1PH600>c/k0080Bd];00/0KFe]05aLG00[:b/0=cLg04];B`0_;bl0ATI603/k
>`0W9bL0<S8b0451@@0202d];@3905ADE00m?Cd0;bl_05MGE`1JFUX0@41004U9B@1jNWX0G5aL03<c
<`0k>c/0HV9R04I6AP0T92@0J6QX06e]K@0T92@0>c/k03`l?014A4@0=3@d03hn?P1nOWh0ATI604E5
A@1ADE40Ogmo04Q8B015ADD0IfMW07QhN023Ph<0DU9B05QHF01CDe<0L71`06QXJ01_Kfl0>3Ph05QH
F00_;bl0Ng]k05=CD`3Bd]80R8R807AdM02SXj<0EEEE0;Vi^@2=SHd0C4a<05ADE01GEeL0F5QH03lo
?`0n?Sh0GemO069RHP1JFUX0=CDe04Q8B01]KFd0;bl_06][J`2>SXh0>SXj04];B`0o?cl0OWin05EE
E@2HV9P0DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0P82009RHV01[Jf/0GEeM08N7Q`2RXZ80F5QH06IV
IP1HF5P0De=C05IFEP1GEeL0HF5Q07UiN@22PX80Bd];04Q8B020P800FEUI05YJFP0b<S80d];B071`
L01mOGd0Bd];08:2PP27QhL0IFEU06][J`1eMGD0L71`0:FUY@1ADE40D51@0410@00k>c/0De=C06a/
K01jNWX0FUYJ069RHP2GUiL0NGUi07AdM01JFUX0GUiN05YJFP15ADD0DE5A04U9B@0l?3`0>CTi03Xj
>P13@d<0DE5A03Xj>P1BDU80IfMW061PH019BDT0DU9B05QHF029RHT0=CDe065QH@1IFET09BDU07Ee
M@1_Kfl0=3@d06ATI00n?Sh0=CDe04e=C@1:BTX0Bd];04A4A01IFET0ATI605IFEP1>CTh0Hf=S09fM
W@1ADE40E5AD079bLP1>CTh0MgMg07IfMP0Q8B40NGUi04I6AP2=SHd0IVIV06e]K@1[Jf/0EeMG071`
L02n_[h0Kfm_07IfMP1KFe/0QhN70:>SX`1SHf<0NGUi079bLP1EEED0Zj^[04i>CP1^KVh0M7Ad08Z:
RP1MGEd0EEEE04Q8B013@d<0FUYJ06YZJP1^KVh0MWIf08f=S@1iNGT0MWIf017ooooo000?ooooo`0L
08j>SP1UIFD0MgMg051@D024Q8@0F5QH05=CD`1>CTh0A4A407MgM`2ATI40=3@d04U9B@18B4P0GUiN
09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU04a<C01>CTh0KVi^08^;R`<0>SXj0?l0
FUYJ05ADE01aLG4092@T01LG5`10@400HV9R05=CD`2ATI40aLG501TI6@0/;2`0@T9205YJFP2][Jd0
Lg=c02<S8`0i>CT0E5AD05mOG`1NGUh0^[Zj034a<@1>CTh0NWYj05aLG01RHV80Hf=S01LG5`18B4P0
LW9b04=3@`1SHf<06a/K02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P11@D40OWin04a<C01>CTh0
LG5a03Lg=`16ATH0Hf=S05]KF`0R8R80CDe=02h^;P0h>3P0Fe]K04Y:BP0];Bd0C4a<02PX:012@T80
J6QX03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04a<C021PH40OWin02`/;00j>SX0
Bd];04m?C`1bLW80RXZ:06e]K@0`<300Hf=S06YZJP1aLG40Shn?09^KV`0M7Ad0>CTi03lo?`1XJ6P0
`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0HF5Q07inOP1jNWX0[jn_0;Fe]@0W9bL0
@d=306YZJP1hN7P0FUYJ0:n_[`0j>SX0ADE509BDU02GUiL0KVi^0<30`01EEED09bLW0861P@2<S8`0
MgMg0<;2`P1;Bd/0=cLg06YZJP2IVIT0WinO07]kN`1ADE40?Cdm07MgM`2MWId0GUiN0:b/[01TI6@0
8B4Q03<c<`2h^;P0Jf][08j>SP1?Cdl0=CDe03lo?`2JVYX0FUYJ051@D01_Kfl0@d=305UIF@2;Rh/0
FEUI05iNGP1XJ6P0?Shn03lo?`21PH40UYJF04];B`1@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0
CDe=09^KV`2BTY80;2`/05MGE`2BTY80EEEE09>CT`25QHD0:b/[04U9B@1NGUh0Xj>S0:JVYP0T92@0
CDe=079bLP1UIFD0XZ:R09NGU`0e=CD0Hf=S079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0
Zj^[05MGE`1EEED0WinO07inOP2OWil0Z:RX02PX:018B4P0YjNW06EUI@31`L40S8b<02TY:@1JFUX0
^[Zj07=cL`1CDe<0KVi^03Ph>01HF5P0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0
NGUi06a/K017AdL0MGEe0;Bd]015ADD0IfMW08J6QP0o?cl0GEeM07=cL`13@d<0SHf=0:NWY`11@D40
:RXZ07EeM@2a/K40Cdm?05UIF@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0;bl_04];B`2VYZH0
00@0<C4a0492@P1PH600CDe=7?ooool0>01IFET0GUiN0820P01JFUX0IVIV04U9B@1>CTh0BDU903`l
?01SHf<0BDU903Ti>@0m?Cd0Hf=S05iNGP22PX80CDe=04m?C`1;Bd/0AdM704U9B@14A4@0;bl_055A
D@1EEED0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1DE5@0AdM706=SH`1?Cdl0GemO05=C
D`1@D500Hf=S02h^;P12@T80De=C079bLP16ATH0G5aL06UYJ@1?Cdl0HV9R08>3P`1VIVH0@41006a/
K00n?Sh0GemO0P1<C4`0C`1nOWh0FUYJ06ATI01=CDd0FUYJ05eMG@1eMGD0ADE507IfMP1=CDd0NWYj
06QXJ01CDe<0Fe]K04i>CP1=CDd0G5aL04A4A00o?cl0NWYj05UIF@1iNGT0LW9b04E5A@1EEED0?3`l
04U9B@13@d<0G5aL03/k>`0X:2P0F5QH03lo?`12@T80>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6
065QH@14A4@0AdM704Q8B01ADE40IVIV03hn?P1;Bd/0@D5104M7A`19BDT0F5QH05ADE013@d<0CTi>
05EEE@1eMGD0@d=304M7A`1VIVH0D51@06IVIP0k>c/0@D5106i^KP2=SHd0LG5a07]kN`0Z:RX0HF5Q
04e=C@2ZZZX0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX0NP1=CDd0K6a/05iNGP1TI6@0De=C
04Q8B01KFe/0DU9B0820P00n?Sh0@D5104Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0@410
05QHF01PH600MgMg06m_K`1`L700j^[Z0<71`@0o?cl0CDe=038b<P1UIFD0PH610820P00g=cL0TI6A
06][J`1GEeL0Q8B402LW9`13@d<0BDU905QHF01WIfL0>SXj04e=C@1LG5`0WIfM05iNGP23Ph<0JVYZ
096AT@1RHV80AdM704Y:BP1>CTh0JVYZ03/k>`0c<c<0De=C03dm?@1LG5`09RHV04Q8B01KFe/0IVIV
05mOG`1FEUH0Hf=S051@D01OGel0UYJF06EUI@2OWil0R8R804Q8B01DE5@0Fe]K04M7A`1;Bd/0>SXj
04A4A01KFe/0Bd];05ADE01KFe/0EeMG04Y:BP1CDe<0D51@04U9B@0/;2`0JVYZ069RHP0`<300Bd];
04I6AP1PH600CTi>04M7A`0U9BD0=SHf0492@P1KFe/0G5aL05ADE01FEUH0EeMG05iNGP1=CDd0GemO
05aLG00a<C40DU9B05UIF@1EEED0I6AT03`l?024Q8@0Bd];069RHP1ADE40ADE50P1PH6000`2>SXh0
MWIf06IVIP0207QhN00B06i^KP2>SXh0LG5a08^;R`1_Kfl0H61P096AT@1KFe/0FUYJ04E5A@1OGel0
Cdm?05iNGP0n?Sh0BDU9055AD@1fMWH0PX:20P2:RXX00`1bLW80P820ooooo`0@ooooo`003oooool0
o`21PH40Kfm_0<K6aP1CDe<0LG5a07QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R803Lg
=`2;Rh/0LW9b07UiN@28R8P0:RXZ04I6AP1FEUH0UYJF07MgM`2:RXX09BDU03dm?@1DE5@0Q8B40492
@P1FEUH0Cdm?02@T901IFET0D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<C4`0AdM701TI
6@1FEUH0X:2P03/k>`1=CDd0HV9R02TY:@0j>SX0Vi^K051@D00f=SH0@41002l_;`1>CTh0MWIf02h^
;P0g=cL0DU9B04Y:BP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<S8`0[Jf]01lO7`0];Bd0EEEE05QH
F01/K6`0[:b/03Lg=`0_;bl0B4Q807AdM01ADE40Q8B402LW9`0^;Rh0FUYJ07EeM@1[Jf/0U9BD03Xj
>P0X:2P0HV9R06UYJ@28R8P0RXZ:01/K6`0j>SX0D51@079bLP1IFET0Q8B403/k>`1DE5@0HV9R06MW
I`1DE5@0Ng]k03De=@0];Bd0GemO05aLG01CDe<0SXj>01XJ6P0e=CD0FUYJ06e]K@1:BTX0FEUI06][
J`0e=CD0EEEE08Z:RP16ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0G5aL06IVIP15ADD0JVYZ09FE
U@2?Shl0AdM705mOG`0^;Rh0>c/k06ATI013@d<0A4A405MGE`0`<300?clo09JFUP2IVIT0>CTi04=3
@`0l?3`0D51@065QH@1ZJVX0<S8b05=CD`17AdL0Hf=S0:VYZ@1VIVH0:RXZ04e=C@0o?cl0Cdm?0;Vi
^@2LW9`0:RXZ03`l?01RHV80DE5A0;jn_P1_Kfl0;Bd]04M7A`1EEED0FEUI09NGU`39bLT0CDe=05MG
E`1WIfL0IVIV0:6QX@3EeMD0A4A404=3@`1CDe<0TI6A09bLW02:RXX0<30`07emO@2BTY80LW9b08B4
Q02f][H0=3@d034a<@2HV9P0HV9R09bLW011@D40>3Ph05aLG033`l<0G5aL0:BTY012@T80A4A40:j^
[P1GEeL0MGEe04Y:BP0c<c<0Bd];07moO`1WIfL0S8b<03@d=01PH600O7al055AD@1?Cdl0Ogmo04U9
B@1>CTh0N7Qh07MgM`29RHT0JFUY04U9B@1mOGd0V9RH061PH01=CDd0VYZJ05IFEP2JVYX0UIFE03lo
?`1>CTh0VYZJ06YZJP1`L700OWin04M7A`0j>SX0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?
C`008`1NGUh0QHF506m_K`0`<300EeMG04e=C@1YJFT0XJ6Q0<71`@1EEED0D51@04U9B@0o?cl0U9BD
0;jn_P0n?Sh0>3Ph04i>CP2:RXX0HF5Q09bLW00o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG
02HV9P1ZJVX0E5AD07inOP1aLG40>3Ph01cooooo09<0EUIF07alO01hN7P0BTY:059BDP1PH600KFe]
079bLP11@D40LG5a065QH@0i>CT0ATI6055AD@12@T80Cdm?06IVIP1IFET0EeMG05eMG@1UIFD0>SXj
02XZ:P1KFe/0ATI604m?C`1MGEd0ATI603dm?@1VIVH0M7Ad0:6QX@1FEUH0EeMG05iNGP1/K6`0EUIF
05ADE01@D500FUYJ04Y:BP0W9bL0Cdm?05]KF`1QHF40BDU904Y:BP0j>SX0=3@d05IFEP28R8P0OWin
04a<C01OGel0B4Q8059BDP1RHV80IfMW069RHP1OGel0LW9b065QH@1bLW80HF5Q061PH00o?cl0L71`
04a<C01YJFT0MgMg06EUI@12@T80H61P05MGE`1/K6`0MWIf04Y:BP1;Bd/09RHV03/k>`1JFUX0@T92
04M7A`1NGUh0=3@d03`l?018B4P0DU9B03lo?`1KFe/0EEEE04Y:BP1FEUH0I6AT03<c<`1?Cdl0L71`
06QXJ00k>c/0GUiN04M7A`1@D500B4Q806UYJ@25QHD0C4a<04Q8B01;Bd/0@d=306ATI00m?Cd0LG5a
03hn?P1HF5P0D51@07IfMP17AdL0C4a<061PH00j>SX0Ogmo03lo?`1?Cdl0CTi>05YJFP10@400EEEE
05aLG02LW9`0CDe=06UYJ@1OGel0Y:BT08>3P`1jNWX0Ph>3051@D02CTi<0OWin05eMG@20P800IVIV
08J6QP1SHf<0HV9R0;Zj^P1nOWh00P1CDe<0LP1]KFd0GEeM04=3@`1eMGD0OGem04e=C@1hN7P0=SHf
07emO@0a<C40LG5a06QXJ02c/k<0IFEU03hn?P1kNg/0EUIF03De=@2?Shl0BDU905UIF@1lO7`0RXZ:
01dM7@2OWil0GUiN03<c<`1HF5P08b<S04];B`0h>3P0FUYJ05EEE@0d=3@0KVi^04U9B@1EEED0@410
092@T01MGEd0N7Qh04e=C@1@D500DE5A04m?C`1/K6`0=SHf04];B`2;Rh/0>SXj05]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0N7Qh0451@@1EEED0@D5105aLG017AdL0@41007EeM@1]KFd0=cLg
0492@P14A4@0?3`l04];B`14A4@0BTY:059BDP19BDT0<30`051@D017AdL0EeMG02PX:02PX:00Y:BT
055AD@1IFET0DE5A03@d=012@T80M7Ad03<c<`18B4P0IFEU096AT@1:BTX0EeMG05=CD`1EEED0BTY:
055AD@1]KFd0IfMW061PH01iNGT0De=C05MGE`1IFET0@d=307YjNP13@d<0Hf=S04Y:BP0o?cl0CTi>
07AdM080UiNG01T0E5AD05EEE@1JFUX0K6a/07UiN@1@D500IfMW07EeM@15ADD0MgMg04=3@`1NGUh0
CDe=06i^KP0e=CD0JFUY0410@01<C4`0FEUI065QH@1RHV80SXj>06YZJP21PH40QHF5017ooooo000?
ooooo`0B0::RXP1DE5@0MgMg07AdM01nOWh0@41005EEE@2CTi<0G5aL07YjNP1:BTX0AdM706=SH`2J
VYX0E5AD07=cL`1ADE40CDe=0P1mOGd09@1?Cdl0Ogmo051@D00f=SH0NWYj07EeM@12@T80IVIV05MG
E`1LG5`0N7Qh07MgM`0g=cL0ATI604Y:BP1>CTh0V9RH07EeM@0Z:RX0>3Ph06=SH`12@T80E5AD07em
O@0b<S80BDU904];B`14A4@0Jf][08b<S00k>c/0=cLg04I6AP1@D500PX:208R8R00b<S800P1<C4`0
M00n?Sh0F5QH08V9R@1=CDd0E5AD04Y:BP11@D40KVi^07]kN`0o?cl0?3`l069RHP1LG5`0I6AT07If
MP0T92@0>3Ph065QH@1^KVh0BDU908F5Q@0k>c/0=3@d05ADE014A4@0HV9R08n?S`0k>c/0@d=305EE
E@1nOWh0?Shn06EUI@0`<300Bd];071`L01FEUH0CTi>08J6QP0^;Rh0>3Ph05YJFP1OGel0G5aL07in
OP0e=CD0De=C07AdM01jNWX0ADE506UYJ@1RHV80Cdm?0:VYZ@1dM7@0>c/k07alO01DE5@0=CDe06UY
J@2MWId0GEeM06QXJ01BDU80A4A407moO`2g]kL0H61P051@D02@T900G5aL065QH@2QXJ40BTY:06=S
H`1mOGd0@d=307IfMP2OWil0GUiN03Ph>01VIVH0?clo06ATI027QhL0BTY:0451@@1dM7@0MgMg05QH
F02MWId0@d=304Y:BP1MGEd0Kfm_05MGE`2GUiL0SHf=04I6AP1@D500MgMg06=SH`2BTY80@41002h^
;P1JFUX0Ph>305YJFP2>SXh0RHV903De=@1UIFD0SXj>05ADE028R8P0PH610P0n?Sh0L@1_Kfl0N7Qh
09VIV@2@T900>c/k04A4A01ZJVX0S8b<05mOG`2e]KD0GEeM04];B`1nOWh0ADE509nOW`23Ph<0:RXZ
05EEE@1kNg/0KFe]07inOP1`L700BTY:09^KV`2QXJ40BTY:08:2PP1PH600>c/k08n?S`22PX80GUiN
09:BTP1FEUH0SXj>09fMW@1GEeL0IVIV05MGE`17AdL0V9RH05]KF`1MGEd0R8R804I6AP1GEeL0WYjN
06IVIP1FEUH0Kfm_059BDP2@T900XJ6Q059BDP1VIVH0Shn?05eMG@1]KFd0[jn_059BDP1TI6@0O7al
04M7A`1UIFD0^[Zj04Q8B01BDU80Vi^K06MWI`1]KFd0N7Qh03<c<`19BDT0Ph>305MGE`17AdL0UYJF
0:^[Z`0m?Cd0FUYJ07alO01HF5P0YjNW07AdM00];Bd0De=C08N7Q`1]KFd0RXZ:06ATI00S8b<0@D51
06YZJP1fMWH0GUiN09nOW`1;Bd/0;2`/05IFEP1/K6`0E5AD07]kN`0l?3`0;Rh^04A4A01/K6`0GemO
04a<C01/K6`0<C4a05MGE`1oOgl0ADE501cooooo06/0GUiN06QXJ01ZJVX0CDe=051@D015ADD0Cdm?
05QHF012@T80GUiN04M7A`16ATH0@41005=CD`1JFUX0Kfm_04e=C@1EEED0FEUI04e=C@1;Bd/0B4Q8
03lo?`1DE5@0@d=304Q8B01CDe<0BTY:04e=C@1NGUh0GemO075aL@1=CDd0De=C051@D01]KFd0F5QH
06YZJP1LG5`0C4a<05ADE00f=SH0@T9204e=C@1UIFD0ATI6051@D01BDU80AdM705]KF`1UIFD0I6AT
04Q8B01VIVH0BDU905aLG01GEeL0EUIF05iNGP17AdL0GEeM04];B`1QHF40GEeM06EUI@19BDT0M7Ad
04=3@`1bLW80SHf=065QH@0S8b<0CDe=06YZJP1eMGD0GemO05YJFP1_Kfl0?clo059BDP1RHV80?Shn
04m?C`1SHf<0@T920451@@10@400AdM702XZ:P1EEED0<C4a04A4A01?Cdl0ATI603<c<`15ADD0E5AD
061PH01CDe<0Bd];03lo?`17AdL0DU9B05MGE`1MGEd0C4a<04e=C@0304Y:BP2d04=3@`1`L700E5AD
06m_K`1=CDd0Q8B405MGE`1^KVh0QHF504];B`1fMWH0DU9B06IVIP1MGEd0Ph>306][J`2DU9@0C4a<
06IVIP1BDU80TI6A08:2PP2g]kL0NWYj08V9R@2][Jd0I6AT09:BTP1`L700HV9R07QhN01eMGD0JFUY
06e]K@1FEUH0FEUI07alO01aLG40A4A404Q8B01fMWH0=3@d08^;R`23Ph<0ADE506QXJ017AdL0Ogmo
02XZ:P25QHD0B4Q806QXJ01>CTh0F5QH0<c<c02SXj<0@T9206UYJ@1>CTh0HF5Q08R8R02FUYH0BTY:
06UYJ@1CDe<0F5QH07]kN`17AdL0EeMG03hn?P1XJ6P0P8200410@01RHV80?Shn06MWI`10@400/[:b
06m_K`2BTY80BDU904e=C@1ADE40De=C05mOG`1=CDd0@d=3059BDP1IFET0PH6103Ti>@1GEeL0BTY:
05=CD`1DE5@0FUYJ04Y:BP1EEED0Ng]k071`L00/;2`0JVYZ05mOG`0H61P0D51@04U9B@0X:2P0@D51
04a<C00m?Cd0CDe=03hn?P1<C4`0FUYJ04i>CP0n?Sh0GEeM0410@01OGel07QhN06MWI`1MGEd06a/K
05mOG`1;Bd/0D51@05YJFP1]KFd0Fe]K05ADE01<C4`0Hf=S05YJFP1FEUH0CTi>04Q8B01NGUh0HV9R
07QhN014A4@0?Shn06MWI`1GEeL0M7Ad0861P@0o?cl0Jf][03<c<`1_Kfl0DU9B05YJFP1MGEd0EEEE
07=cL`2ZZZX0K6a/06i^KP1UIFD0Hf=S07MgM`1SHf<0O7al07MgM`17AdL0OGem059BDP1NGUh0FUYJ
06EUI@0j>SX0E5AD04m?C`1ADE40Hf=S07UiN@1mOGd0Kfm_07=cL`1XJ6P0I6AT4Oooool000oooooo
0<@0QXJ606=SH`2DU9@0C4a<06UYJ@1SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0j
>SX0IfMW055AD@12@T80GUiN03@d=01IFET0Fe]K06a/K00a<C40Cdm?03@d=00n?Sh0JVYZ05=CD`0_
;bl0<C4a03hn?P0g=cL0HV9R02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f=SH07alO05MGE`1D
E5@0Ng]k09JFUP0V9RH0Cdm?07AdM01>CTh0MWIf0;Ng]`0Y:BT0Fe]K09RHV01KFe/0/k>c06i^KP0W
9bL07alO06EUI@2CTi<0Lg=c04e=C@0W9bL0ATI6075aL@1mOGd0QXJ60:NWY`0O7al0>SXj0861P@1`
L700I6AT09:BTP0d=3@0<30`04I6AP1UIFD0De=C06IVIP0T92@0>c/k0410@01MGEd0CDe=04m?C`0U
9BD0<30`071`L01@D500CDe=04];B`0V9RH0B4Q806ATI024Q8@0>c/k055AD@0i>CT0Kfm_07IfMP18
B4P0=3@d04e=C@10@400@D5107=cL`29RHT0;bl_04A4A00f=SH0<S8b0861P@1lO7`09bLW02l_;`0m
?Cd0CTi>0:NWY`1nOWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH03`l?018B4P0FUYJ08j>SP2c
/k<0>SXj038b<P1RHV80Jf][06e]K@2NWYh0=SHf04E5A@1`L700KFe]09FEU@37alL0K6a/02@T901M
GEd0GUiN09^KV`2][Jd0>SXj05mOG`1VIVH0VIVI0861P@2PX:00KVi^04A4A02NWYh0Lg=c05iNGP2I
VIT0FUYJ02DU9@12@T80[jn_07emO@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03<c<`1:
BTX0Ph>307]kN`1VIVH0MgMg055AD@0m?Cd0CDe=0861P@1hN7P0JVYZ03Hf=P2:RXX0[:b/05iNGP1A
DE40N7Qh0P0l?3`01@2CTi<0>SXj06ATI01nOWh0@D510080M7Ad0380=CDe04];B`1NGUh0OWin0:ZZ
ZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0G5aL05MGE`1dM7@0[jn_03Lg=`0M7Ad0HV9R06EU
I@1hN7P0d=3@04M7A`0h>3P0N7Qh06e]K@2=SHd0Ti>C030`<019BDT0KFe]07moO`3Cdm<0VYZJ024Q
8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0e=CD0V9RH04e=C@1cLg<0`/;204i>CP0h>3P0C4a<08Z:
RP80MgMg0240B4Q804m?C`1cLg<0SHf=0410@023Ph<0KVi^03Hf=P1[Jf/0_kno04Y:BP1RHV80Ogmo
02h^;P17AdL0N7Qh09RHV016ATH0HF5Q02TY:@13@d<0De=C09RHV00h>3P0FUYJ055AD@0a<C40@410
08Z:RP16ATH0IVIV04A4A015ADD07?ooool0E01ADE40I6AT06i^KP14A4@0EeMG06UYJ@1OGel0AdM7
03@d=01:BTX0@T9204=3@`0h>3P0IFEU059BDP21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[
03lo?`0m?Cd0ADE5059BDP0o?cl0A4A404e=C@14A4@0CDe=04U9B@1@D500IfMW05iNGP1EEED0GUiN
05EEE@1VIVH0Fe]K02d];@1BDU80E5AD06MWI`1VIVH0J6QX05EEE@1>CTh0IfMW08J6QP1mOGd0@D51
06IVIP11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF07=cL`1RHV80Hf=S0410@02<S8`0?Cdm
079bLP1iNGT0MGEe03dm?@1OGel0IfMW09RHV01/K6`0Bd];07emO@10@400C4a<06][J`1RHV80EeMG
05YJFP80CDe=0P1HF5P0PP0e=CD0I6AT051@D01ADE40:b/[02h^;P0l?3`0?clo034a<@19BDT0HV9R
04E5A@0Y:BT0@T9205mOG`0l?3`0BDU905]KF`17AdL0=SHf04i>CP1/K6`0@d=304m?C`0o?cl0DE5A
04Y:BP25QHD0DE5A061PH01eMGD0?Cdm051@D01WIfL0MgMg05UIF@1^KVh0Cdm?07AdM012@T80HV9R
02XZ:P2HV9P0IFEU096AT@1@D500NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0Ng]k04e=C@1GEeL0IfMW
06=SH`1VIVH0LG5a06=SH`19BDT0=cLg04e=C@0C4a<0O7al06MWI`0i>CT0IVIV03dm?@20P80092@T
06ATI014A4@0Ph>305eMG@28R8P0j>SX09^KV`0];Bd0MGEe065QH@1eMGD0T92@08J6QP11@D40RXZ:
07IfMP1<C4`0JFUY034a<@1>CTh0Bd];05MGE`1SHf<0ATI6055AD@18B4P0QhN705EEE@22PX80M7Ad
09FEU@1SHf<0CTi>05eMG@1KFe/0J6QX04e=C@1<C4`0LG5a05eMG@1lO7`0:2PX04U9B@0c<c<0>c/k
04E5A@1aLG40Cdm?06a/K02QXJ40SHf=03/k>`1ZJVX0Hf=S02XZ:P1CDe<0E5AD02l_;`10@40203dm
?@0=051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D015ADD0IVIV02PX:02b/[80RHV901hN7P0204e=
C@0?04];B`1FEUH0Fe]K07IfMP1HF5P0>SXj04e=C@1dM7@0IfMW05MGE`1PH600EUIF05EEE@1=CDd0
DE5A0080MgMg02H0AdM703Xj>P1=CDd0<S8b06a/K00X:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0
XZ:R05eMG@1UIFD0FUYJ09fMW@2QXJ40CDe=04E5A@1OGel0J6QX08>3P`1LG5`0HF5Q05QHF01VIVH0
<S8b09VIV@1[Jf/0C4a<05eMG@2:RXX0L71`08f=S@1hN7P0IVIV06MWIa7ooooo000?ooooo`1a079b
LP1kNg/0bLW905EEE@1LG5`0FUYJ06m_K`1mOGd0=SHf05mOG`20P800EUIF08^;R`2?Shl0@d=305iN
GP1HF5P0Ogmo0;6a/@1<C4`0=CDe0410@01eMGD0JVYZ09ZJVP0i>CT092@T05MGE`2UYJD0G5aL08B4
Q01FEUH0:BTY04E5A@1XJ6P0GemO09bLW010@400>3Ph04U9B@1VIVH0JFUY051@D01?Cdl0<30`04A4
A01OGel0HF5Q051@D01EEED07AdM0451@@1UIFD0AdM703Ti>@0l?3`0:RXZ051@D01ZJVX0BDU903hn
?P16ATH0=cLg07UiN@1lO7`0<C4a04Q8B011@D40@T92061PH02KVi/0ADE502`/;013@d<0@T9205YJ
FP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP24Q8@08B4Q0410@01@D500DE5A06IVIP2>SXh0BTY:01TI
6@18B4P0E5AD09JFUP2>SXh09BDU02`/;01:BTX0LW9b05QHF02JVYX0E5AD03Ph>01mOGd0LW9b05YJ
FP2LW9`0=CDe02h^;P0f=SH0JFUY06][J`2/[:`00P0Y:BT0[`1CDe<0KFe]06ATI02TY:@0QhN703/k
>`1GEeL0QhN7051@D02FUYH0Ph>303Ph>01@D500R8R80;6a/@2=SHd0JVYZ03Xj>P1TI6@0YjNW0:6Q
X@1;Bd/0IfMW02/[:`0o?cl0L71`06e]K@1`L700G5aL01lO7`12@T80O7al08N7Q`1DE5@0V9RH02h^
;P13@d<0RXZ:051@D00f=SH0LW9b03`l?00n?Sh0FEUI06][J`1OGel0Kfm_03Ph>00W9bL0MGEe0:ZZ
ZP0h>3P0DE5A05iNGP1=CDd0OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP0n?Sh0AdM704Y:
BP1gMgL0ZJVY0:2PX00m?Cd0>CTi05=CD`10@400RXZ:092@T00b<S80ADE506][J`28R8P0a<C40;no
_`0k>c/0BTY:06][J`1iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW04Q8B01fMWH0/[:b07If
MP1]KFd0KVi^04U9B@1;Bd/0ZZZZ07emO@2=SHd0=CDe051@D02<S8`0OGem06a/K01VIVH0>CTi051@
D02[Zj/0Ti>C07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80AdM705EEE@2i^KT0MWIf04e=
C@2;Rh/0De=C04];B`2=SHd0WYjN05UIF@18B4P0?Cdm04Y:BP1cLg<0JVYZ02TY:@18B4P0A4A404E5
A@1^KVh0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP14A4@0MWIf065QH@2OWil0Ph>3038b
<P0e=CD0D51@061PH017AdL0YjNW02d];@0i>CT0Bd];061PH01BDU80XJ6Q0:b/[00Y:BT0;Bd]06i^
KP1CDe<0WinO05ADE00j>SX07?ooool0o`1KFe/0LG5a07alO016ATH0DU9B03dm?@1BDU80C4a<03@d
=01DE5@0ATI60451@@0m?Cd0HF5Q055AD@2:RXX0D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];
B`0m?Cd0A4A403Ph>017AdL0B4Q807inOP1EEED0MWIf05MGE`1LG5`0F5QH06][J`1DE5@0L71`06EU
I@1>CTh0D51@02@T900c<c<0Cdm?05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@410055A
D@1IFET0IfMW04M7A`16ATH0O7al04m?C`1UIFD0D51@06UYJ@1aLG40IFEU04Q8B01FEUH0@T92051@
D01TI6@0EeMG04a<C01nOWh0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0?clo04E5
A@13@d<0<S8b03<c<`10@400>CTi061PH00j>SX0CDe=069RHP1DE5@0@T9204m?C`1WIfL0EEEE04I6
AP1@D500>CTi04I6AP1LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1SHf<0JVYZ07em
O@19BDT0L71`061PH025QHD0N7Qh03dm?@1JFUX0BTY:069RHP19BDT0C4a<06a/K01nOWh0E5AD08b<
S00I6AT0KVi^04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18B4P0Jf][06EUI@1HF5P0Cdm?07]k
N`1SHf<0EeMG06UYJ@1RHV80ADE5055AD@1RHV80>CTi08F5Q@1ZJVX0H61P07UiN@19BDT0EeMG0451
@@1XJ6P0LW9b08N7Q`17AdL0>c/k08B4Q01UIFD0<C4a079bLP1ADE40JVYZ08J6QP1jNWX0@41009RH
V01JFUX0>3Ph06a/K00n?Sh0M7Ad02XZ:P1ZJVX0MGEe04E5A@1RHV80D51@079bLP1dM7@0UYJF05eM
G@2JVYX0F5QH04];B`1LG5`0E5AD06ATI00C4a<0A4A406EUI@1=CDd0PX:203Ti>@1JFUX0BTY:059B
DP1IFET0VYZJ08B4Q01YJFT0GemO075aL@13@d<0J6QX05mOG`0[:b/0EUIF051@D00Z:RX0?clo03Ti
>@0Z:RX0DE5A0492@P1VIVH0FUYJ04I6AP0n?Sh0Fe]K0492@P1:BTX0;Bd]06YZJP1UIFD0?Shn05=C
D`15ADD0FEUI03`l?01;Bd/0Rh^;05eMG@1FEUH0T92@07EeM@1FEUH0H61P075aL@1DE5@0>c/k05IF
EP1CDe<0=SHf05mOG`1=CDd0G5aL06m_K`008`0^;Rh0JVYZ04Y:BP1PH600Cdm?04Y:BP1CDe<0RHV9
09JFUP2QXJ40CTi>051@D01OGel0UiNG09BDU01/K6`0GEeM07moO`19BDT0M7Ad0492@P1HF5P0De=C
05UIF@19BDT0N7Qh05iNGP1LG5`0D51@07UiN@1gMgL0Jf][071`L025QHD0S8b<017ooooo000?oooo
o`0d08f=S@1EEED0Q8B409jNWP2QXJ40B4Q805IFEP1fMWH0O7al09JFUP1[Jf/0ATI6055AD@1aLG40
N7Qh092@T00/;2`0?Cdm05IFEP1fMWH0;Bd]04Y:BP18B4P09BDU05QHF01_Kfl08R8R05ADE01PH600
AdM705IFEP1VIVH08b<S04i>CP0T92@0@41009FEU@1OGel07alO03Ph>01UIFD0>3Ph05aLG026QXH0
71`L0451@@17AdL0Cdm?07alO02?Shl0:b/[01dM7@80EeMG0180HF5Q05mOG`0M7Ad0;bl_07inOP1H
F5P0N7Qh09BDU00Y:BT0ATI609JFUP1BDU80Zj^[07UiN@0O7al0;bl_07moO`2IVIT206][J`3H01/K
6`0i>CT0QhN707AdM01PH600HV9R020P800W9bL0QhN704i>CP1PH600KFe]02d];@10@400F5QH07Mg
M`18B4P0BTY:03<c<`0m?Cd0KFe]05]KF`1GEeL0IFEU02@T900a<C40GEeM0820P01HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0`<300R8R804a<C00^;Rh0HF5Q03lo?`0`<300IFEU0;:b
/P1;Bd/0C4a<03/k>`1=CDd0N7Qh0:j^[P11@D40AdM706UYJ@1TI6@0GemO09>CT`10@400F5QH071`
L01PH600TI6A0:b/[00l?3`0:b/[069RHP13@d<0OGem08>3P`0[:b/0;Bd]04e=C@1oOgl0FUYJ0:6Q
X@0j>SX0=SHf05iNGP1bLW80Cdm?0;Jf]P1cLg<06a/K05EEE@1]KFd0O7al0;Zj^P1;Bd/0>3Ph04M7
A`2?Shl0KFe]09nOW`23Ph<0B4Q80861P@1kNg/0IVIV09bLW01>CTh08b<S069RHP23Ph<0Hf=S07em
O@1?Cdl06a/K06m_K`2PX:00NGUi06IVIP2@T900@D5105EEE@3?cll0SXj>0:^[Z`1gMgL08B4Q05AD
E02l_;`0QhN704a<C01EEED0;Rh^06QXJ02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP1WIfL0Lg=c06e]
K@0c<c<0N7Qh09fMW@0n?Sh0BTY:04i>CP1<C4`0VYZJ03/k>`17AdL0FUYJ05aLG01EEED0UiNG0492
@P0c<c<0CDe=07IfMP32`/80VYZJ03dm?@1CDe<0RXZ:04a<C028R8P0cLg=05ADE01RHV80MGEe0820
P01dM7@0_;bl04M7A`1DE5@0Lg=c06e]K@2NWYh0WinO01TI6@0e=CD0C4a<055AD@1EEED0V9RH09:B
TP0L71`0F5QH05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80Jf][04E5A@0_;bl0IVIV0;6a
/@26QXH0H61P0:b/[01QHF40:b/[08N7Q`1cLg<0JFUY08J6QP0o?cl0>3Ph05IFEP2EUID0TI6A075a
L@1=CDd0@41006QXJ028R8P0C4a<7?ooool0?01NGUh0NWYj08n?S`1HF5P0GemO04a<C01/K6`0F5QH
04E5A@1BDU80C4a<04Q8B00b<S80CDe=04i>CP1MGEd0D51@05EEE@1ADE40DU9B06ATI00e=CD0A4A4
05QHF017AdL0CTi>04E5A@1BDU80B4Q808N7Q`1KFe/0PX:205UIF@1RHV80G5aL06MWI`1iNGT0MGEe
04m?C`1DE5@0D51@01hN7P15ADD0EeMG079bLP1=CDd0IfMW05QHF016ATH0I6AT06m_K`1fMWH0@D51
05aLG00e=CD0F5QH0410@011@D40G5aL02PX:080?Cdm0>@0CDe=03Lg=`1RHV80@T9206e]K@0f=SH0
CTi>0861P@20P8009RHV04];B`1aLG40L71`06a/K014A4@0P82003De=@1FEUH0L71`04Q8B01GEeL0
@D5105=CD`16ATH0A4A404Y:BP0f=SH0H61P02XZ:P0f=SH0=cLg03De=@0c<c<0@410038b<P0n?Sh0
EEEE02d];@0/;2`0@41005QHF00n?Sh0Cdm?05IFEP15ADD0@T920410@01CDe<0D51@07moO`1IFET0
VIVI04=3@`1oOgl0?clo06i^KP2DU9@0GUiN06QXJ01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2MWId0KVi^0:6QX@1fMWH0N7Qh07EeM@15ADD0Rh^;075aL@1iNGT0Lg=c07moO`1aLG40
DU9B03dm?@0h>3P0FUYJ06YZJP0n?Sh0?Cdm08j>SP13@d<0TY:B05ADE01@D500M7Ad03hn?P1TI6@0
71`L08Z:RP1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A01^KVh0N7Qh05IFEP10@400
Q8B4071`L01OGel0M7Ad03Hf=P1>CTh0ADE506MWI`1nOWh0Fe]K079bLP0l?3`0PX:207IfMP2i^KT0
Q8B409fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0VIVI04=3@`1WIfL0=SHf07UiN@1/K6`0
F5QH03hn?P1bLW80ADE506MWI`1eMGD0CDe=03Ph>01LG5`0E5AD03dm?@2;Rh/0LW9b02DU9@0g=cL0
FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0?3`l0451@@1CDe<0BTY:05eMG@0T92@0MgMg0820P00S8b<0
DU9B02l_;`1=CDd0IFEU08V9R@1VIVH0BTY:034a<@1^KVh0HF5Q05YJFP1BDU80DE5A04e=C@1ADE40
HV9R05=CD`0g=cL0Kfm_05=CD`1OGel0M7Ad04i>CP1TI6@0?Shn07QhN00_;bl0A4A403hn?P1hN7P0
L71`09ZJVP1]KFd0GemO07alO021PH40I6AT04Y:BP1SHf<0Jf][03Hf=P1VIVH0DE5A05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<0Jf][05mOG`2CTi<0XJ6Q06a/K02SXj<Aooooo`003oooool0
J02YZJT0FUYJ05eMG@1EEED0Q8B4051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ05]K
F`3Ogml0F5QH02@T901NGUh0SHf=07IfMP2@T900LW9b03De=@1?Cdl0X:2P05aLG02HV9P0NGUi030`
<00f=SH0Lg=c05YJFP2VYZH0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH6103<c<`0N7Qh0R8R80451
@@1nOWh0Ogmo02PX:01QHF40ZZZZ08b<S01MGEd0O7al03Xj>P1CDe<0J6QX059BDP1YJFT0@T92020P
800c<c<0QHF507alO02DU9@0?Shn0492@P1CDe<0X:2P06QXJ01TI6@0NGUi03Lg=`1:BTX0TY:B02l_
;`10@400GEeM04U9B@1ADE40HV9R03Hf=P0Z:RX0AdM704Q8B01SHf<0TI6A03Lg=`0S8b<0<S8b04I6
AP1TI6@0QHF502DU9@0];Bd0?clo04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04U9B@2<S8`0alO70P0b
<S804`1EEED0M7Ad05UIF@2OWil0Rh^;02XZ:P1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?
0861P@2VYZH0>c/k03Ti>@0h>3P00P23Ph<0X`1dM7@0V9RH03Xj>P1=CDd0HF5Q05EEE@2YZJT0YZJV
03`l?00k>c/0KVi^07alO01@D500N7Qh0451@@0o?cl0KFe]08:2PP1aLG40QXJ602HV9P0i>CT0MWIf
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM04Y:BP1@D500VIVI09:BTP17AdL0M7Ad
04E5A@1;Bd/0JFUY0:2PX01>CTh0NWYj04E5A@1gMgL0UYJF0<?3``1FEUH0>c/k07YjNP1`L700[:b/
08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0=CDe05MGE`1jNWX0[Zj^0;Vi^@0X:2P0?clo
05=CD`1JFUX0OWin07EeM@0n?Sh0G5aL0861P@22PX80gmoO04Q8B00S8b<0IfMW05mOG`2XZ:P0ZZZZ
024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1iNGT0TI6A0:ZZZP2[Zj/0>3Ph059BDP28R8P0UYJF
05QHF02BTY80=3@d08>3P`2a/K40R8R80;Rh^02o_kl0B4Q804=3@`2QXJ40QHF507YjNP1KFe/0>c/k
05ADE026QXH0HV9R04i>CP2FUYH0@41005iNGP2o_kl0B4Q804e=C@1cLg<0>SXj02`/;01]KFd0[jn_
04e=C@19BDT0ADE505UIF@2GUiL0IFEU02d];@1<C4`0HV9R04U9B@1jNWX0GEeM02HV9P0n?Sh0HV9R
03Ti>@1gMgL0bl_;07emO@0W9bL0@d=305IFEP1WIfL0S8b<05aLG00];Bd0?3`l07moO`1bLW80Vi^K
08:2PP0c<c<0@T9206ATI01DE5@07?ooool0D`1IFET0Lg=c05YJFP19BDT0C4a<04m?C`1EEED0C4a<
0451@@15ADD0I6AT0492@P0h>3P0Fe]K06a/K01VIVH0ATI605=CD`1NGUh0P82006MWI`11@D40>c/k
04=3@`1=CDd0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`1EEED0QHF506][J`1;Bd/0Hf=S
05IFEP1TI6@0@41002HV9P19BDT0BTY:04e=C@1;Bd/0EEEE04I6AP0m?Cd0CDe=06m_K`1RHV80ADE5
06=SH`0m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU9061PH01BDU80H61P04m?C`1[Jf/0?Shn
03/k>`1;Bd/0K6a/03<c<`1IFET0Ph>308b<S02BTY80DE5A08Z:RP12@T80MGEe07alO01@D500DE5A
0080EUIF00L0BDU905MGE`1IFET0>3Ph06i^KP0k>c/0ATI60080CDe=00D0@d=305QHF01IFET0Cdm?
04I6AP020410@01m04i>CP1VIVH0E5AD06YZJP1ADE40@41005IFEP1IFET0Jf][05ADE01_Kfl0De=C
05YJFP11@D40MgMg04];B`28R8P0GemO03Xj>P1EEED0C4a<065QH@20P800Kfm_06ATI01[Jf/0CDe=
09>CT`0W9bL0LW9b05mOG`25QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_05aLG019BDT0HF5Q
06e]K@1MGEd0KFe]061PH01kNg/0ADE505IFEP1hN7P0BTY:09JFUP1YJFT0IVIV07MgM`1NGUh0F5QH
02l_;`1NGUh0JFUY09VIV@1?Cdl0QhN70?Cdm02SXj<0DU9B05=CD`1LG5`0QHF5069RHP1;Bd/0EUIF
08:2PP1DE5@0DU9B05IFEP0g=cL0OGem04Q8B01QHF40D51@05]KF`2<S8`0D51@07=cL`1hN7P0`/;2
07IfMP2:RXX0EEEE08^;R`1ZJVX0Fe]K05mOG`0n?Sh0K6a/08B4Q01QHF40NGUi02l_;`1BDU80@D51
051@D01DE5@0PX:208>3P`1bLW80Vi^K065QH@1@D500KVi^05MGE`0Z:RX0BDU904I6AP0`<300=cLg
04I6AP1/K6`0EEEE02l_;`1DE5@0EeMG04=3@`16ATH00P1DE5@0?P1`L700>3Ph07MgM`1nOWh0<S8b
09FEU@1CDe<0JVYZ05YJFP1OGel0CTi>04M7A`0Z:RX0I6AT05ADE01@D500Hf=S05MGE`1>CTh0Kfm_
08Z:RP0_;bl0=3@d07AdM01SHf<0K6a/07QhN00`<300De=C03<c<`1OGel0>3Ph05QHF01MGEd0DU9B
07=cL`2<S8`0BDU906ATI01XJ6P0][Jf0:6QX@22PX80bLW907emO@1ADE40V9RH04I6AP0g=cL0AdM7
04Y:BP0_;bl0MGEe055AD@1;Bd/0KFe]09VIV@2?Shl0UIFE07AdM01LG5`0VIVI4Oooool000oooooo
0:40KFe]09FEU@3:b/X0EeMG04e=C@20P800Ti>C065QH@0i>CT0AdM707=cL`1fMWH0WIfM06IVIP0k
>c/0RHV909RHV01hN7P0I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0Kfm_02XZ:P0Q8B40F5QH09RHV014
A4@0BTY:034a<@0T92@0AdM705]KF`11@D40B4Q802l_;`10@400Bd];07QhN017AdL0=3@d04E5A@0]
;Bd0JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a00d=3@0CDe=05mOG`1CDe<0UYJF07EeM@0U
9BD061PH04a<C01SHf<0_[jn04I6AP0[:b/0<S8b05eMG@1`L700XJ6Q0;:b/P0N7Qh0@d=306i^KP1Y
JFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF06MWI`0P8200C4a<09:BTP1ZJVX0HF5Q07QhN00g
=cL0<C4a0:6QX@1MGEd0L71`069RHP0Q8B40<C4a06MWI`37alL0DE5A07=cL`0b<S80>SXj06UYJ@24
Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0Cdm?07=cL`0Y:BT0>3Ph0;Zj^P2FUYH0;bl_0410@00n
?Sh0ATI60;6a/@1gMgL0=cLg05=CD`1HF5P0C4a<06a/K02l_;`0HF5Q04i>CP1IFET0>SXj08R8R039
bLT0KVi^03Hf=P1NGUh0?clo05=CD`2=SHd0?clo05UIF@1PH600;bl_069RHP3:b/X0G5aL02l_;`1D
E5@0>SXj07]kN`3?cll0@41002LW9`1VIVH0MGEe079bLP2?Shl0KVi^02@T900206IVIP1E075aL@2O
Wil0Ogmo02XZ:P1JFUX0HV9R071`L02`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03lo?`2E
UID0d=3@06][J`27QhL0SHf=03De=@0[:b/0Ng]k08f=S@1[Jf/0=CDe0451@@1UIFD0UYJF06ATI01^
KVh0VYZJ03Ph>00k>c/0RHV906EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0ADE507=cL`2d
];@0IVIV05]KF`1MGEd0B4Q809JFUP2JVYX0A4A405EEE@0i>CT0KFe]0:>SX`1:BTX0=3@d05MGE`10
@400JVYZ09RHV00m?Cd0F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP22PX80YjNW07MgM`0Z
:RX0CDe=079bLP1nOWh0NGUi0:^[Z`0o?cl0@D5107IfMP0208f=S@0X0:j^[P0o?cl0>c/k04];B`1j
NWX0W9bL09FEU@0`<300=3@d065QH@2LW9`0FEUI07inOP2:RXX0<30`069RHP2i^KT0C4a<079bLP2>
SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1PH6008B4Q0410@01ADE40Ng]k04Q8B01[Jf/0N7Qh02/[:`0c
<c<0LW9b03Ph>021PH40<30`0451@Acooooo0240GemO07QhN01mOGd0AdM705ADE01GEeL0HV9R04I6
AP0o?cl0Cdm?04];B`1?Cdl0@D5105ADE01EEED0MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3
@`1@D500>SXj04i>CP0i>CT0Cdm?04];B`1KFe/0IVIV08R8R01LG5`00P1>CTh02@1VIVH0DU9B06MW
I`1ADE40Bd];04Y:BP0T92@0ATI604a<C00205eMG@3505MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_
;`1?Cdl0@D5105EEE@0l?3`0?clo065QH@1:BTX0DU9B03@d=01<C4`0HF5Q05IFEP0e=CD0GUiN06EU
I@1QHF40J6QX09JFUP1QHF40LG5a05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`0E5AD04Y:
BP0k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg0451@@1gMgL0EEEE0410@01>CTh0JVYZ04Q8
B00d=3@0>c/k05mOG`1;Bd/0BTY:07YjNP1OGel0DU9B04Q8B01ADE40B4Q805aLG017AdL0PH61071`
L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0M7Ad04i>CP1kNg/0JVYZ07YjNP1PH600HV9R034a
<@1VIVH0?Shn08b<S02@T900_Kfm05eMG@2_[jl0Z:RX055AD@22PX80CTi>08F5Q@1]KFd0Q8B404m?
C`1JFUX0Cdm?03lo?`1FEUH0H61P03Ti>@1<C4`0MgMg03<c<`2HV9P0Hf=S06a/K028R8P0Bd];065Q
H@0l?3`0JVYZ071`L01_Kfl0Fe]K07MgM`2WYjL0V9RH04a<C01OGel0AdM7075aL@1dM7@0Kfm_03dm
?@24Q8@0>SXj0492@P1YJFT0?Cdm05EEE@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b
/P2<S8`0`<3006e]K@1gMgL0J6QX04Q8B017AdL0;Bd]05YJFP1VIVH0Cdm?065QH@1<C4`0HV9R05YJ
FP1VIVH0ADE508F5Q@1TI6@0J6QX08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03`l
?01RHV80LG5a04=3@`16ATH0FUYJ05MGE`0k>c/0H61P04];B`15ADD0C4a<02TY:@2][Jd0VYZJ04i>
CP1JFUX0De=C04=3@`12@T80De=C04i>CP12@T80ADE505iNGP1SHf<00P1JFUX0:028R8P0=cLg06QX
J01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k06e]K@1PH600O7al03Ti>@10@400H61P06QX
J02CTi<0^[Zj05IFEP1]KFd0MGEe09RHV01`L700Hf=S0820P01eMGD0DU9B05eMG@1VIVH0GEeM04Q8
B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`209FEU@0308f=S@1GEeL0MGEe017ooooo000?oooo
o`2]0820P01EEED0QXJ609NGU`1jNWX0?Cdm065QH@2HV9P0?clo065QH@1JFUX0>c/k08B4Q02_[jl0
=SHf059BDP0g=cL0?3`l09^KV`1=CDd0;bl_02XZ:P1CDe<0EEEE08j>SP0l?3`0:b/[03/k>`1kNg/0
L71`0;>c/`1YJFT04Q8B03`l?01FEUH0MWIf0:j^[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`21PH40
8B4Q04A4A01OGel0C4a<06MWI`2NWYh0:b/[01lO7`1BDU80K6a/06QXJ00[:b/0;Bd]04Y:BP1`L700
Kfm_04m?C`1/K6`07alO05MGE`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]05]KF`0n?Sh0
:2PX04E5A@2;Rh/0CDe=03De=@1;Bd/0:2PX02d];@1dM7@0?clo02TY:@1:BTX0=CDe079bLP2PX:00
Bd];01XJ6P1@D500CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0>SXj03Hf=P14A4@0
EUIF069RHP2KVi/0Cdm?01TI6@1CDe<0Fe]K06QXJ01cLg<0?3`l02XZ:P1JFUX0SHf=05IFEP2CTi<0
@41003/k>`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@2BTY80IVIV02h^;P1ZJVX0
^KVi0;no_`2<S8`0YJFU03Ph>00k>c/0PH6105eMG@27QhL0TI6A03@d=00g=cL0GUiN09>CT`1?Cdl0
S8b<02XZ:P1;Bd/0U9BD08j>SP1bLW80MgMg03lo?`0i>CT0FEUI08V9R@1JFUX0QXJ603<c<`1:BTX0
KVi^096AT@1<C4`0IFEU07MgM`1?Cdl0VYZJ09NGU`10@4000P1RHV80L`0g=cL0D51@0:j^[P1cLg<0
BDU905=CD`1>CTh0DE5A08F5Q@1NGUh0:RXZ05EEE@1<C4`0Ti>C071`L00a<C40JFUY06=SH`1<C4`0
SHf=0<_;b`0o?cl0@41006QXJ01[Jf/0/k>c07EeM@0b<S80Hf=S06][J`1ADE40];Bd05UIF@1MGEd0
T92@07moO`2KVi/0Hf=S01hN7P16ATH0Ti>C05UIF@2=SHd0;Bd]04Q8B01/K6`0LG5a07YjNP2EUID0
:BTY04=3@`1iNGT0M7Ad09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80AdM708>3P`2WYjL0
DU9B04Q8B02CTi<0=cLg06QXJ02f][H0UiNG05mOG`1GEeL0=3@d06m_K`1YJFT0M7Ad03dm?@1TI6@0
@T9204A4A01hN7P0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP1;Bd/0?3`l03lo?`1?Cdl0
RHV904e=C@0i>CT0AdM703dm?@17AdL0SXj>02d];@15ADD0AdM705=CD`1[Jf/0Shn?09NGU`13@d<0
@D5105UIF@1<C4`0[:b/04m?C`0a<C407?ooool0:`1LG5`0DE5A06UYJ@1MGEd0G5aL04E5A@1TI6@0
EUIF04a<C011@D40EeMG0492@P0e=CD0FUYJ06ATI01^KVh0Bd];05eMG@1<C4`0D51@06=SH`1DE5@0
BDU903Ti>@0j>SX0ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1_Kfl0EeMG05mOG`1LG5`0
K6a/05IFEP1BDU80ATI602PX:019BDT00P1PH600C`11@D40H61P04U9B@15ADD0Cdm?04U9B@1FEUH0
?clo04i>CP0k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0=CDe05=CD`1>CTh0HF5Q0410@01PH600
<c<c04];B`1KFe/0PX:203lo?`1=CDd0I6AT07IfMP1ADE40?3`l05aLG00g=cL0EEEE03`l?00j>SX0
?Shn03Xj>P13@d<0?Cdm03@d=01ADE40CTi>04e=C@0X:2P0>CTi04=3@`0h>3P0=cLg04Q8B019BDT0
?Shn03De=@12@T80?Shn03lo?`1=CDd0Bd];05IFEP1@D500@d=303`l?01CDe<0F5QH04];B`1hN7P0
>3Ph05IFEP1hN7P0SXj>03lo?`1HF5P0LW9b07MgM`23Ph<0LW9b07QhN01ZJVX00P1/K6`0KP25QHD0
De=C07=cL`15ADD0SHf=08j>SP33`l<0EeMG05QHF01XJ6P0DU9B09ZJVP1OGel0P82004];B`0o?cl0
AdM704i>CP14A4@0C4a<08:2PP25QHD0>3Ph03@d=01mOGd0=SHf0:NWY`10@400GUiN06EUI@18B4P0
H61P02PX:020P800KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0LG5a08>3P`1OGel0
C4a<08N7Q`1ADE40HF5Q05ADE00I6AT0I6AT04];B`1RHV80BTY:055AD@1cLg<0@T9205YJFP1TI6@0
h>3P07AdM01DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1IFET0Fe]K055AD@1dM7@0
@d=304];B`1:BTX0M7Ad03lo?`1mOGd0T92@05IFEP13@d<0]kNg07MgM`0X:2P0FEUI05EEE@0V9RH0
;Bd]0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:BTX0>SXj04a<C01SHf<0:RXZ075aL@1NGUh0
;2`/06MWI`1<C4`0BTY:0P1MGEd0=014A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad051@D01[
Jf/0I6AT04I6AP0j>SX0E5AD07]kN`29RHT0MWIf051@D01?Cdl0;bl_06QXJ01?Cdl0IfMW06QXJ01c
Lg<0X:2P0>3Ph025QHD0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0E5AD05mOG`1W
IfL0PH6105iNGP23Ph<0FEUI04Q8B01GEeL0_;bl08:2PP1lO7`0Ti>C08R8R023Ph<Aooooo`003ooo
ool0DP2a/K40DU9B06IVIP1bLW80/k>c03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>3
06i^KP2UYJD0>CTi02XZ:P1JFUX0SHf=07inOP1oOgl0I6AT01dM7@1HF5P0PH6104a<C02e]KD0MWIf
02d];@15ADD0RHV90492@P1@D500>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a<C40OGem
03/k>`1_Kfl0C4a<02/[:`1RHV80^[Zj065QH@0f=SH0B4Q80410@01gMgL0LG5a028R8P0g=cL0?3`l
05iNGP1WIfL0VYZJ03Lg=`11@D40IVIV05MGE`1eMGD0Lg=c01`L700`<300ATI607IfMP2=SHd0MGEe
02/[:`1DE5@0Hf=S055AD@1UIFD0Ng]k020P800K6a/205YJFP0Z07EeM@2:RXX0;bl_02`/;01]KFd0
WinO05MGE`19BDT0820P0492@P2GUiL0S8b<059BDP2SXj<0;bl_02d];@1GEeL0Kfm_051@D01]KFd0
8B4Q03De=@1eMGD0LW9b04i>CP1DE5@0?3`l03@d=025QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0
OGem055AD@1RHV80=cLg05ADE01PH600NWYj0P0h>3P0C`1bLW80Hf=S06e]K@2UYJD0@T9204E5A@1C
De<0:b/[05IFEP2j^[X0KFe]02XZ:P13@d<0=3@d09NGU`2QXJ40>c/k034a<@1ADE40ATI604E5A@2Z
ZZX09bLW02d];@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0JVYZ08B4Q02_[jl0<S8b030`<01Z
JVX0IVIV05ADE02OWil0b/[:03/k>`29RHT0X:2P07moO`2a/K40Lg=c03Lg=`0n?Sh0NGUi09BDU03:
b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP1PH600KFe]05EEE@2MWId0EeMG03Ti>@1U
IFD0b<S808Z:RP2?Shl0F5QH04=3@`1VIVH0^k^k05aLG02DU9@0;Rh^04Y:BP1QHF400P1WIfL0B01F
EUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@07emO@12@T80CTi>06=SH`0k>c/0DE5A0:RXZ02Z
ZZX0ATI606][J`1?Cdl0Ti>C08>3P`0e=CD0EUIF0820P00m?Cd0RHV90<c<c017AdL0FUYJ06=SH`1Y
JFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0QhN70;Bd]00X:2P0=cLg051@D01QHF40I6AT0:FUY@2A
TI408R8R04m?C`1UIFD0ADE50:RXZ01>CTh0:b/[04a<C02?Shl0Ogmo09jNWP19BDT0;bl_05ADE02@
T900JVYZ079bLP1mOGd0?Shn03/k>`21PH40De=C06e]K@1SHf<0;2`/02TY:@80EEEE00L0FUYJ06IV
IP1EEED0<c<c04];B`2^[Zh0BDU901cooooo02l0EEEE05QHF01PH600A4A404a<C01JFUX0F5QH04E5
A@13@d<0BDU904Y:BP14A4@0=cLg05=CD`1@D500H61P04];B`1YJFT0C4a<04U9B@1GEeL0;Rh^03Hf
=P1FEUH0BTY:05EEE@10@400ATI604Q8B01HF5P0GUiN07AdM01@D500DU9B069RHP1QHF40E5AD06YZ
JP1MGEd0DU9B0451@@0T92@0?Shn03`l?016ATH0CDe=04Q8B00203De=@2M0492@P1KFe/0EUIF03/k
>`1MGEd0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1MGEd0G5aL04e=C@10@400GEeM04=3
@`1EEED0De=C08N7Q`0_;bl0GemO07alO02;Rh/09RHV0492@P1XJ6P0EeMG07QhN00o?cl0>c/k04I6
AP11@D40C4a<04A4A00f=SH0E5AD04e=C@1?Cdl0:b/[03<c<`1@D500?Shn04=3@`18B4P0EUIF03/k
>`15ADD09bLW0451@@0n?Sh0Cdm?061PH01KFe/0LW9b04I6AP17AdL0J6QX07moO`0j>SX0KVi^04Y:
BP1KFe/0?Shn06IVIP1CDe<0P82005aLG015ADD0CTi>04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>
CP24Q8@0@410079bLP1iNGT0^KVi06UYJ@2BTY80SHf=08N7Q`29RHT0QXJ60:n_[`1gMgL0EUIF04U9
B@1iNGT0IFEU08:2PP1HF5P0GemO05ADE01?Cdl0EUIF034a<@2UYJD0Cdm?06a/K01XJ6P0H61P06i^
KP16ATH0HV9R07]kN`2UYJD0De=C05YJFP2WYjL0M7Ad04Q8B01EEED0A4A407IfMP1_Kfl0@d=304];
B`2ATI40EUIF04Y:BP1BDU806ATI07emO@0l?3`0DE5A02<S8`1@D500NWYj04a<C01TI6@0?Cdm0<O7
a`1cLg<0MgMg04a<C01CDe<0B4Q803/k>`1mOGd0@T9206IVIP1hN7P0ADE505aLG00Z:RX0EEEE03Hf
=P1hN7P0EeMG07YjNP0205iNGP1B09>CT`1HF5P0@T9203Ti>@1;Bd/0?clo05EEE@13@d<0=SHf04I6
AP3Shn<0RXZ:04e=C@17AdL0CTi>05UIF@0m?Cd0C4a<05MGE`16ATH0CDe=01hN7P2?Shl0Jf][02LW
9`1TI6@0CTi>07QhN01LG5`0EUIF05MGE`1CDe<0?Cdm04i>CP1EEED0GemO069RHP1>CTh0EeMG04M7
A`1UIFD051@D03/k>`1PH600DU9B05=CD`1UIFD07AdM08Z:RP1FEUH0EeMG02d];@19BDT0GemO079b
LP1OGel0LW9b06][J`1QHF40HV9R0=?Cd`3>c/h0QhN709^KV`28R8P0I6AT0:JVYP24Q8@0DU9B03Xj
>P1MGEd0JFUY06EUI@1?Cdl0BDU904a<C01NGUh0NGUi06QXJ01VIVH0Q8B408f=SA7ooooo000?oooo
o`0409:BTP1dM7@0WinO04];B`80LG5a0:D0FEUI04A4A014A4@0EeMG06MWI`0a<C40DU9B05IFEP1H
F5P0QXJ604];B`0S8b<0AdM704A4A015ADD0MGEe08n?S`0W9bL0?Cdm07alO012@T80UiNG079bLP0a
<C40;2`/05YJFP1LG5`0N7Qh03@d=00X:2P0B4Q8092@T01OGel0QHF50<O7a`0X:2P05QHF06UYJ@14
A4@0YjNW08:2PP0G5aL0=CDe08J6QP21PH40M7Ad09JFUP0a<C40A4A404];B`1GEeL0KVi^06EUI@0G
5aL0ADE505MGE`1lO7`0b<S802l_;`0^;Rh0ADE505QHF01@D500IfMW0820P00Q8B40@D5107UiN@1B
DU80Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41003`l?00f=SH0Bd];08N7Q`19BDT0>SXj04U9B@0g
=cL0CDe=075aL@0T92@0;Bd]03hn?P1eMGD0EeMG0861P@1:BTX0<C4a06=SH`1PH600JVYZ07EeM@0c
<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/0=cLg04a<C01QHF40O7al0:b/[00/;2`0:2PX05MGE`1_
Kfl0NGUi07emO@0/;2`0@d=307moO`27QhL0N7Qh0:>SX`2TY:@0ADE505ADE02>SXh0P8200;2`/02T
Y:@0;Rh^03De=@1=CDd0Lg=c069RHP1nOWh07AdM04Y:BP2QXJ40YJFU071`L01iNGT0?Shn04=3@`1l
O7`0EeMG06UYJ@2<S8`071`L02h^;P2?Shl0OWin04Q8B02ATI40Cdm?034a<@1MGEd0RHV904U9B@2H
V9P0@d=3030`<010@400/K6a07AdM01VIVH00P0g=cL0M@2BTY80^[Zj06=SH`2KVi/0P82003Hf=P22
PX80[jn_05IFEP12@T80B4Q803Xj>P0l?3`0OWin09FEU@1:BTX0B4Q804U9B@38b<P0NWYj024Q8@0n
?Sh0D51@0451@@1YJFT0U9BD034a<@16ATH0KVi^09:BTP2[Zj/0Fe]K01hN7P1HF5P0Jf][0:b/[022
PX808R8R03Hf=P1jNWX0OWin08:2PP1TI6@07AdM07moO`1MGEd0R8R807]kN`0];Bd0D51@069RHP2k
^k/0EUIF0861P@0b<S80UiNG09JFUP1hN7P0RHV90:NWY`15ADD0BTY:09>CT`1nOWh0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0De=C07=cL`1OGel0NWYj07QhN00a<C40Fe]K06QXJ02<
S8`0ADE505]KF`0n?Sh0EEEE07YjNP1iNGT0@d=306MWI`1XJ6P0<30`06a/K02MWId0>c/k03lo?`1l
O7`0>c/k05IFEP2?Shl0BTY:03De=@1?Cdl0ATI605IFEP1eMGD0ADE502h^;P15ADD0C4a<05]KF`1W
IfL0MWIf03Lg=`1EEED0EeMG05iNGP0Looooo`1M05mOG`14A4@0DU9B04U9B@1HF5P0@D5106YZJP1<
C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EUIF05eMG@1aLG40JFUY059BDP19BDT0Cdm?038b<P0i
>CT0?Cdm03Lg=`1;Bd/0AdM704U9B@1>CTh0SXj>05mOG`1DE5@0FUYJ055AD@1?Cdl0K6a/061PH01_
Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00n?Sh0D51@04I6AP1BDU80?clo0451@@1;Bd/0EEEE059BDP0b
<S80A4A40492@P0o?cl0:RXZ04=3@`1=CDd0@D51055AD@10@400BDU90451@@18B4P0@D5104a<C00o
?cl0@41005MGE`1bLW80BDU904i>CP1<C4`0CDe=03De=@15ADD0I6AT02h^;P1<C4`0A4A404M7A`11
@D40=cLg04=3@`16ATH0:RXZ0492@P1KFe/0Cdm?02`/;00];Bd0Cdm?0080=cLg05<0?clo05ADE00m
?Cd0@T9201lO7`0b<S80>SXj04e=C@1OGel0@T9204];B`11@D409BDU04Y:BP1>CTh0F5QH07]kN`1Z
JVX0K6a/04I6AP1WIfL0@41006=SH`13@d<0?Cdm05eMG@1]KFd0Lg=c061PH01SHf<0FEUI06a/K010
@400MWIf03Xj>P1aLG40QXJ60<30`01jNWX0`l?308B4Q01lO7`0OWin05IFEP2EUID0GEeM06=SH`1>
CTh0?clo04M7A`15ADD0HF5Q05QHF01:BTX0CTi>05]KF`0N7Qh0TY:B05IFEP16ATH0@41004Y:BP1A
DE40:RXZ065QH@1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5A@1VIVH0YJFU065QH@10
@400IFEU02l_;`1cLg<0PX:203De=@0204e=C@1^05iNGP0i>CT0EUIF06YZJP1JFUX0OGem05QHF031
`L40P8200<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492@P1KFe/0LW9b06ATI021PH40CDe=04i>CP14
A4@0C4a<06i^KP25QHD0MGEe05YJFP2;Rh/0FUYJ04M7A`1GEeL0DU9B03Ti>@1VIVH0@410030`<01V
IVH0b/[:04m?C`1EEED0DE5A05=CD`1fMWH0B4Q804m?C`1EEED0C4a<04M7A`0e=CD0VIVI0820P01<
C4`0G5aL038b<P0l?3`0@D5104e=C@0c<c<0FEUI0492@P1MGEd0N7Qh069RHP20P800HF5Q04Q8B01I
FET0DE5A03dm?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP1?Cdl0D51@06MWI`1KFe/0Hf=S05ADE01R
HV80IFEU0;jn_P1RHV80Ph>308:2PP1[Jf/0MgMg09fMW@2_[jl0Ng]k07AdM02?Shl0EeMG06=SH`1j
NWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>06a/K01RHV80HF5Q071`L01TI6@Aooooo`003ooo
ool0E@22PX80IfMW0<[:bP1ADE40F5QH06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2TY:@0R8R8
0410@01ZJVX0Ph>305aLG02KVi/0:RXZ03Xj>P0k>c/0M7Ad07IfMP2OWil07AdM04A4A01/K6`0QHF5
04a<C01eMGD0A4A401HF5P0n?Sh0GUiN03lo?`1;Bd/0<30`024Q8@0g=cL0DE5A08V9R@1DE5@0IFEU
024Q8@17AdL0NWYj03/k>`1<C4`0@T9202h^;P19BDT0K6a/04m?C`19BDT0;bl_03lo?`1>CTh0K6a/
02PX:00c<c<0A4A404=3@`1gMgL0JFUY02DU9@16ATH0C4a<03`l?01oOgl0ZJVY04=3@`0a<C40@T92
04A4A028R8P0`L7102PX:00h>3P0I6AT05QHF01_Kfl0Ng]k01LG5`0j>SX00P1_Kfl0W`1YJFT0N7Qh
03Xj>P0d=3@0MWIf06m_K`23Ph<0OWin01dM7@1:BTX0ADE506i^KP1SHf<0`<3003Ph>019BDT0=cLg
05QHF01/K6`0WIfM02DU9@0Z:RX0IFEU079bLP1FEUH0?clo0492@P0h>3P0PH6107]kN`0l?3`0B4Q8
03dm?@12@T80/;2`075aL@1BDU80NGUi055AD@0_;bl0GemO07IfMP1HF5P0DE5A03`l?013@d<0EUIF
07YjNP1EEED0@410075aL@0j>SX0D51@06][J`0d=3@0AdM704e=C@18B4P0MWIf08b<S010@400=CDe
05]KF`1UIFD0Lg=c09ZJVP0i>CT09bLW05eMG@1=CDd0=CDe092@T01`L700;Bd]04i>CP14A4@0EeMG
0:RXZ01ZJVX0=3@d04e=C@1BDU80WIfM0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;R`3:b/X0>3Ph
05IFEP2EUID0MWIf06i^KP1UIFD0;Rh^05EEE@1DE5@0SXj>0820P016ATH0:2PX06e]K@2KVi/0Cdm?
08:2PP1WIfL09BDU04Y:BP1RHV80GUiN075aL@0];Bd0<30`08^;R`33`l<0GUiN07YjNP0f=SH0JFUY
09ZJVP0c<c<0H61P03/k>`0];Bd0Ogmo0;:b/P1@D500GEeM034a<@1:BTX0TY:B04m?C`0o?cl0JVYZ
051@D01HF5P0RXZ:04Q8B01:BTX0CTi>04Q8B02EUID0/K6a05aLG01>CTh0DE5A05IFEP38b<P0UYJF
02h^;P1FEUH0H61P04M7A`1YJFT0bLW905YJFP0204A4A00Z059BDP2UYJD0Vi^K04Q8B00U9BD0IfMW
07=cL`1>CTh0/;2`059BDP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`0=SHf0:>SX`1oOgl0LW9b
08f=S@0m?Cd0FUYJ06YZJP2;Rh/0H61P065QH@0S8b<0DE5A0820P02BTY80PH6108>3P`19BDT0>3Ph
04A4A02;Rh/0J6QX08b<S00c<c<0AdM77?ooool0J@1MGEd0G5aL07]kN`1:BTX0J6QX04m?C`1UIFD0
D51@04U9B@15ADD0EeMG04I6AP0g=cL0De=C05UIF@1^KVh0@D5105IFEP0n?Sh0?Cdm05QHF011@D40
=CDe02d];@0o?cl0De=C038b<P1CDe<0I6AT07MgM`1^KVh0IFEU05mOG`1[Jf/0EUIF07inOP2:RXX0
Ti>C06e]K@1OGel0ADE502LW9`1@D500E5AD05EEE@0g=cL0DU9B03dm?@1=CDd0@T9203hn?P1:BTX0
?Shn04i>CP0l?3`0ADE5038b<P1=CDd0?clo02l_;`1ADE40@T9205QHF01DE5@0GEeM0451@@1XJ6P0
>c/k02d];@1WIfL0NWYj034a<@1VIVH0I6AT069RHP0j>SX0IFEU05aLG01FEUH0IFEU02TY:@0[:b/0
A4A405MGE`18B4P0=CDe02d];@1<C4`0=SHf03Ti>@0[:b/0;bl_02TY:@0g=cL0@d=303`l?010@400
?3`l04e=C@0h>3P0@d=304Q8B01FEUH0LG5a06][J`0205QHF01c04M7A`1BDU80IfMW059BDP1oOgl0
E5AD07AdM01BDU80L71`04m?C`1oOgl0MgMg04a<C01JFUX0BTY:04m?C`1HF5P0GEeM071`L01ZJVX0
=cLg06a/K01]KFd0RHV908^;R`2RXZ80D51@08N7Q`1WIfL0O7al0:JVYP1WIfL0][Jf04M7A`1^KVh0
?3`l04i>CP1BDU80@D5106UYJ@2=SHd0DE5A071`L02FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0
EeMG05eMG@26QXH0GemO08B4Q01HF5P0P8200=OGe`1dM7@0@41004a<C016ATH0JVYZ06i^KP1@D500
C4a<07]kN`0k>c/0D51@04M7A`0P8200FEUI04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1CDe<0
e]KF06MWI`1VIVH0BDU906QXJ01ADE40@T9208R8R01EEED0V9RH0:2PX01EEED0FEUI075aL@1iNGT0
?Cdm05=CD`0d=3@0G5aL05MGE`21PH40Ph>303lo?`0j>SX0Jf][05IFEP1OGel0L71`061PH00b<S80
Bd];05]KF`1SHf<0D51@0410@002065QH@120492@P1PH600ADE5051@D01;Bd/0:BTY07AdM01@D500
:2PX07inOP0m?Cd0CTi>061PH01cLg<0?Shn04=3@`0X:2P0B4Q807QhN01bLW80GUiN04];B`1<C4`0
RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07AdM01eMGD0GemO05=CD`1OGel0>SXj05UIF@1;Bd/0
K6a/07alO03[jn/0EeMG071`L01:BTX0bl_;0:^[Z`1JFUX0KFe]06][J`1EEED0JVYZ05UIF@1EEED0
BDU9069RHP1GEeL0B4Q803<c<`10@400?Shn08f=S@1iNGT0N7Qh06UYJ@1XJ6P0Ogmo4Oooool000oo
oooo0400VIVI04m?C`1]KFd0QhN708>3P`0n?Sh0?3`l071`L01HF5P0P82005aLG00f=SH0CDe=07Ee
M@1RHV80RHV902XZ:P18B4P0KVi^06a/K01?Cdl0LG5a0492@P0i>CT0HV9R08R8R01ADE40N7Qh04I6
AP1;Bd/0LG5a07QhN01ADE40G5aL04U9B@1?Cdl0H61P07EeM@1<C4`0CTi>07]kN`1:BTX0CDe=06e]
K@0l?3`0JFUY06IVIP0n?Sh0Lg=c0:>SX`1=CDd0@D5106QXJ016ATH0Rh^;06UYJ@0[:b/0@D5105YJ
FP16ATH0G5aL08V9R@0h>3P0GemO0P1BDU805P1/K6`0MWIf02TY:@0j>SX0IfMW06e]K@1VIVH0I6AT
020P8011@D40NWYj055AD@1PH600MGEe02TY:@0];Bd0H61P03Ti>@1;Bd/0LG5a030`<011@D4205QH
F00i03dm?@1FEUH0<c<c059BDP1kNg/0EeMG05UIF@2DU9@0;2`/034a<@1/K6`0EEEE065QH@1oOgl0
8R8R03`l?01kNg/0IFEU034a<@1fMWH0=SHf051@D01KFe/0@41004Q8B023Ph<0AdM705EEE@1^KVh0
Fe]K04I6AP1;Bd/0De=C055AD@2EUID0V9RH04E5A@1DE5@0Lg=c05aLG01mOGd0YjNW03dm?@1CDe<0
Jf][05]KF`1LG5`0XJ6Q07AdM011@D40IFEU03/k>`1kNg/0S8b<04Q8B013@d<0IVIV0080DE5A08d0
TI6A03hn?P1YJFT0OGem065QH@1OGel0W9bL07emO@14A4@0Fe]K05YJFP1XJ6P0X:2P03lo?`0k>c/0
JVYZ05ADE01?Cdl0RXZ:07inOP16ATH0IVIV08V9R@1:BTX0RHV909nOW`0n?Sh0?clo05iNGP1SHf<0
X:2P07moO`0k>c/0BDU905eMG@1:BTX0O7al0:NWY`17AdL0CTi>06IVIP12@T80Ogmo07emO@10@400
NWYj09:BTP1TI6@0MGEe06e]K@1CDe<0UYJF06YZJP1BDU80MGEe04Y:BP0n?Sh0W9bL079bLP1NGUh0
O7al03hn?P1IFET0PH6104A4A020P800Hf=S04Q8B02:RXX0ADE505QHF01UIFD0ATI605EEE@2OWil0
M7Ad05EEE@27QhL0GEeM07inOP1lO7`0>CTi05]KF`2BTY80HV9R07MgM`2QXJ40@T9206i^KP1nOWh0
B4Q80861P@29RHT0>SXj04M7A`1bLW80GemO07MgM`2CTi<0=SHf04m?C`1hN7P0Hf=S05YJFP2QXJ40
Shn?02l_;`1>CTh0IfMW05QHF02HV9P0EeMG0492@P1OGel0TY:B06ATI01kNg/0DU9B03hn?P1@D500
OGem05UIF@1WIfL0JFUY02/[:`0n?Sh0SHf=055AD@1/K6`0CTi>03@d=019BDT0JVYZ0820P01=CDd0
E5AD051@D01GEeL0O7al079bLP11@D407?ooool04P1HF5P0FEUI065QH@18B4P0EeMG05eMG@1aLG40
B4Q806IVIP1CDe<0GEeM04m?C`11@D40K6a/071`L024Q8@0Fe]K07alO080CDe=00`0G5aL02/[:`0h
>3P0<30`03/k>`1HF5P0>c/k04M7A`1CDe<0RXZ:071`L01XJ6P206IVIP0@06m_K`1aLG40F5QH075a
L@1ADE40MWIf04U9B@0c<c<0CDe=04=3@`1DE5@0DU9B05iNGP12@T80CTi>04U9B@80FUYJ0=D0ATI6
04U9B@0a<C40?Shn03Lg=`1CDe<0@D5103De=@1=CDd0B4Q804i>CP1DE5@0EEEE04];B`1@D500<C4a
02d];@1jNWX0H61P03De=@1KFe/0I6AT06i^KP0d=3@0Fe]K05aLG00a<C40EeMG03Xj>P18B4P0?Shn
04A4A019BDT0@T92030`<013@d<0@41003dm?@0c<c<0=CDe0492@P0h>3P0BDU90492@P1>CTh0>CTi
04a<C00Q8B40<S8b04I6AP1:BTX0E5AD04E5A@1DE5@0@d=303dm?@1ADE40GEeM04Q8B01SHf<0H61P
06=SH`1BDU80Lg=c07EeM@2?Shl0H61P04A4A01>CTh0HV9R05iNGP1EEED0I6AT06UYJ@1DE5@0CDe=
065QH@1SHf<0QXJ609ZJVP25QHD0MGEe0<71`@1>CTh0F5QH06MWI`1OGel0YjNW04m?C`1>CTh0@D51
04I6AP10@400IFEU051@D01KFe/0G5aL05MGE`1dM7@0>SXj0:>SX`10@400M7Ad03<c<`1NGUh0BDU9
03Ti>@1_Kfl0RHV90:2PX01eMGD0S8b<0<G5a@1eMGD0Bd];07AdM01NGUh0MgMg09^KV`1PH600EUIF
071`L00c<c<0L71`05eMG@0V9RH0L71`04=3@`1NGUh0>3Ph05IFEP1EEED0HV9R07MgM`13@d<0XZ:R
08f=S@2>SXh0ATI6051@D01IFET0Jf][092@T01QHF40Cdm?05IFEP1TI6@0Jf][03dm?@1?Cdl0>SXj
06EUI@12@T80LW9b06=SH`1XJ6P0MWIf051@D00j>SX0KFe]05QHF01BDU80IVIV04Q8B00l?3`0CDe=
04m?C`19BDT0B4Q80492@P14A4@0G5aL03lo?`16ATH0EEEE04m?C`1>CTh0=SHf0:>SX`1`L700=cLg
05UIF@11@D40Kfm_05eMG@1>CTh0A4A405MGE`1ADE40E5AD04U9B@1?Cdl0JFUY059BDP16ATH0GUiN
05IFEP0/;2`0DE5A06][J`1>CTh0EEEE05QHF019BDT0Hf=S04A4A01FEUH0=SHf04i>CP1?Cdl0JFUY
05aLG02ZZZX00P1XJ6P05`1GEeL0Q8B407=cL`1XJ6P0PH6105mOG`1TI6@0Kfm_059BDP1;Bd/0EeMG
055AD@1FEUH0EeMG04E5A@1?Cdl0BTY:06e]K@1SHf<0JFUY07MgM`1/K6`0KFe]017ooooo000?oooo
o`1O08j>SP2IVIT0][Jf04U9B@1PH600Ng]k09BDU00i>CT0=CDe04a<C01iNGT0De=C09FEU@0j>SX0
De=C08b<S020P800Fe]K05MGE`17AdL0F5QH05mOG`1_Kfl0>3Ph03Lg=`0m?Cd0IFEU07QhN01TI6@0
8B4Q03Ti>@0f=SH0;2`/08V9R@0m?Cd0:BTY04A4A00l?3`09RHV06a/K026QXH0FEUI02d];@18B4P0
?clo092@T02][Jd09bLW03hn?P1cLg<0FUYJ06i^KP2a/K40;Rh^04];B`26QXH0IfMW07QhN01=CDd0
9RHV03lo?`1;Bd/0IFEU0:FUY@0I6AT0=CDe051@D01OGel0ATI60861P@2WYjL071`L05EEE@1MGEd0
ADE505QHF02BTY80820P03lo?`1]KFd0EEEE061PH01gMgL0:BTY04I6AP1fMWH0H61P055AD@1VIVH0
<c<c034a<@1_Kfl0?Cdm05]KF`1]KFd00P0l?3`0`@1DE5@0IFEU05EEE@1[Jf/0=cLg03lo?`1?Cdl0
AdM704Q8B02<S8`0?Shn03Hf=P29RHT0IfMW03`l?017AdL0<S8b04e=C@2BTY80EEEE02/[:`1EEED0
A4A406i^KP2:RXX0?Cdm03`l?01DE5@0HF5Q07AdM029RHT0R8R803Lg=`14A4@0SXj>06i^KP2HV9P0
PX:203`l?00V9RH0JVYZ08f=S@1IFET0NGUi02DU9@10@400LW9b05iNGP1aLG40`L7104E5A@0X:2P0
O7al08Z:RP2TY:@0d];B02l_;`0e=CD0GUiN0820P01ZJVX0d=3@05YJFP1@D500Rh^;06i^KP1_Kfl0
WinO05YJFP0l?3`0EeMG0:RXZ01_Kfl0][Jf05EEE@0m?Cd0IVIV0;Ng]`1gMgL0SXj>09BDU00d=3@0
FUYJ0;:b/P2BTY80KFe]05=CD`0d=3@0CTi>06UYJ@2VYZH0J6QX02/[:`0o?cl0SHf=0:JVYP1EEED0
J6QX04m?C`0`<300Ogmo0:NWY`1;Bd/0PX:203Lg=`1GEeL0W9bL05UIF@0[:b/0I6AT05IFEP2GUiL0
Zj^[03lo?`13@d<0@D5104E5A@2^[Zh0QXJ601hN7P1;Bd/0FUYJ08n?S`2b/[80;Bd]02PX:01GEeL0
OGem075aL@2PX:00E5AD04E5A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0Ng]k0:VYZ@1@D500
?3`l0410@01jNWX0HF5Q06i^KP2XZ:P0A4A404Y:BP2c/k<0IfMW09VIV@1WIfL0?Shn0492@P1VIVH0
_;bl05=CD`29RHT0>CTi03Xj>P1bLW80_;bl04U9B@1OGel0TY:B0410@01>CTh0WIfM05ADE01hN7P0
VIVI03Ph>015ADD0U9BD08Z:RP1DE5@0Cdm?03Lg=`1DE5@0LG5a03@d=00o?cl0IVIV04=3@`17AdL0
DE5A05]KF`0m?Cd0Hf=S03Xj>P1SHf<07?ooool03`1DE5@0DE5A06EUI@1<C4`0DE5A03/k>`0o?cl0
>SXj05IFEP1fMWH0KFe]04E5A@0i>CT0CTi>04U9B@02059BDP3o05QHF01=CDd0@D5103hn?P0`<300
C4a<04=3@`0h>3P0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE01>CTh0ADE505]KF`1CDe<0
Hf=S04Y:BP1DE5@0=3@d02h^;P0n?Sh0>3Ph04A4A00d=3@0?clo02`/;016ATH0=cLg04a<C015ADD0
BDU904a<C01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD04U9B@1:BTX0CDe=0451@@1IFET0
GUiN03lo?`23Ph<0HV9R04m?C`1mOGd0Hf=S08j>SP1@D500?Shn05QHF00j>SX0F5QH03dm?@1>CTh0
B4Q802l_;`10@400EEEE03<c<`11@D40E5AD0492@P0b<S80?Cdm06ATI00o?cl0CDe=0410@01VIVH0
>SXj05=CD`0_;bl0Hf=S04A4A013@d<0Fe]K0492@P1DE5@0B4Q8071`L01<C4`0IfMW065QH@1lO7`0
Hf=S06MWI`0o?cl0M7Ad05mOG`23Ph<0>3Ph03/k>`0h>3P0E5AD06YZJP1JFUX0NGUi069RHP1IFET0
>3Ph04A4A018B4P0LW9b0;Jf]P1`L700De=C08R8R014A4@0QhN708B4Q01_Kfl0[:b/07AdM02<S8`0
9bLW04m?C`0m?Cd0?Shn055AD@1?Cdl0=3@d03Ph>017AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40
@41004];B`1cLg<0LW9b09JFUP1PH600V9RH0>GUi@1dM7@0G5aL07MgM`13@d<0Ogmo09bLW018B4P0
EeMG06YZJP0M7Ad0HV9R04Q8B00P8200CTi>0451@@1PH600>CTi06IVIP1JFUX0BDU9059BDP1mOGd0
gmoO07moO`1nOWh0E5AD05IFEP1^KVh0IVIV0820P01bLW80FUYJ06QXJ013@d<0D51@05MGE`1hN7P0
ATI605ADE00h>3P0GUiN04a<C01`L700KFe]04Q8B01=CDd0KFe]05IFEP0c<c<0>SXj04=3@`0n?Sh0
?Cdm05=CD`19BDT0DE5A04=3@`1;Bd/0JVYZ04];B`1@D500GUiN055AD@1JFUX0;2`/06YZJP1KFe/0
>3Ph07moO`1ADE40CTi>04a<C01?Cdl0=SHf059BDP0d=3@0Lg=c04Y:BP13@d<0IFEU04i>CP1ADE40
L71`05QHF019BDT0>SXj05UIF@0m?Cd0JVYZ065QH@10@400Fe]K04E5A@1LG5`0@d=306QXJ00l?3`0
GemO055AD@3:b/X0OGem09:BTP17AdL0WinO07AdM01oOgl0`L71000B04U9B@1HF5P0GUiN03hn?P0m
?Cd0K6a/065QH@1EEED0CTi>02XZ:P0a<C40>3Ph09RHV01UIFD0NWYj08Z:RP1UIFD0Lg=c4Oooool0
00oooooo00@0J6QX069RHP2i^KT0FUYJ0P1DE5@0o`2BTY80KVi^02`/;019BDT0BTY:06EUI@3;bl/0
WYjN02/[:`22PX80IFEU09JFUP27QhL0:RXZ04];B`1YJFT0R8R806ATI02PX:00;Rh^04E5A@26QXH0
JFUY06ATI02ZZZX0Ogmo01HF5P1DE5@0OWin065QH@2RXZ80@D5101`L700T92@0<c<c075aL@26QXH0
Jf][02/[:`19BDT0O7al07inOP1kNg/0LW9b01`L700k>c/0MgMg05mOG`1NGUh09RHV02/[:`1PH600
UIFE05MGE`1HF5P0DU9B03Ph>01HF5P0JVYZ02/[:`17AdL0Cdm?02PX:017AdL0W9bL05ADE01:BTX0
?Shn05ADE01PH600W9bL05aLG01@D500Bd];03lo?`0k>c/0IFEU01lO7`0h>3P0D51@03hn?P23Ph<0
SXj>03@d=00O7al0@T92055AD@27QhL0T92@01hN7P12@T80DU9B03lo?`1`L700`L71038b<P16ATH0
GEeM059BDP2=SHd0[Zj^055AD@0k>c/0JFUY07alO01cLg<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0
UYJF03De=@17AdL0[:b/09JFUP2ATI40^;Rh051@D012@T80KVi^0<_;b`2FUYH0Q8B404m?C`0d=3@0
Kfm_0820P01iNGT0IfMW09VIV@1<C4`0<S8b06a/K00g=cL0HF5Q07UiN@0e=CD0@T92071`L022PX80
@d=305mOG`0b<S80GUiN079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@1OGel0ADE508Z:RP0i>CT0
>3Ph092@T021PH40:RXZ04a<C01LG5`0C4a<0:JVYP1[Jf/0>3Ph069RHP1eMGD0H61P075aL@2LW9`0
>CTi06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel0NGUi09NGU`1DE5@06a/K05IFEP27QhL0
OGem0:BTY01RHV807alO03lo?`2JVYX0G5aL0:JVYP0b<S80:RXZ06YZJP2ATI40EEEE09nOW`10@400
CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0PH61030`<014A4@0VIVI08n?S`1`L700
/k>c030`<00g=cL0G5aL061PH01kNg/0FUYJ01dM7@1UIFD0`l?308n?S`1lO7`0SHf=04];B`2DU9@0
TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ019BDT0ATI604m?C`1_Kfl0Shn?059BDP0i>CT0
BDU90410@017AdL0NGUi04=3@`18B4P0G5aL04];B`007@1JFUX0JVYZ09nOW`1:BTX0?clo06MWI`1M
GEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL06e]K@0K6a/0ADE5071`L01cLg<0KFe]0::RXP1Q
HF408b<S0410@01hN7P0Ogmo0;Fe]@0n?Sh0<C4a01cooooo05@0C4a<06ATI01`L700CDe=05mOG`16
ATH0GemO04I6AP1>CTh0@d=303Ti>@1:BTX0A4A405QHF01eMGD0I6AT05iNGP1JFUX0FEUI04I6AP1A
DE40>SXj03@d=00[:b/0;Bd]04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0FEUI05MGE`1Z
JVX0FUYJ07EeM@1>CTh0Hf=S03<c<`0e=CD0C4a<0410@01ADE40E5AD051@D00Y:BT0CDe=03lo?`1U
IFD0D51@04];B`17AdL0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1ADE40De=C05iNGP10
@400Bd];034a<@0T92@0OWin05UIF@0[:b/0HF5Q05eMG@24Q8@0ADE505mOG`1UIFD0BDU9069RHP0j
>SX0IFEU04M7A`0d=3@204i>CP2002h^;P0e=CD0Cdm?04Y:BP0a<C40?Shn04M7A`0c<c<0BDU904Q8
B01@D500;bl_04m?C`0X:2P0=3@d03Ph>019BDT0OWin04Q8B01@D500A4A404a<C01FEUH0Fe]K059B
DP1PH600F5QH07UiN@1RHV80PX:205UIF@1nOWh0JFUY07EeM@1?Cdl0De=C04a<C01YJFT0GemO06][
J`1gMgL0O7al06UYJ@1oOgl0P8200>KViP1`L700De=C08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055A
D@1/K6`0BDU904m?C`0o?cl0E5AD0410@011@D40FUYJ04i>CP1QHF40<C4a09RHV00K6a/0IVIV03<c
<`2:RXX0?3`l03/k>`1QHF40O7al08B4Q017AdL0R8R80;>c/`1[Jf/0AdM705iNGP1YJFT0LW9b08j>
SP1WIfL0Ng]k07moO`0h>3P0IfMW04Q8B00e=CD0EEEE055AD@1iNGT0:RXZ05YJFP1EEED0EUIF055A
D@1FEUH0XJ6Q08R8R01VIVH0J6QX0:JVYP1ADE40K6a/092@T01?Cdl0J6QX08>3P`1?Cdl0ADE5034a
<@16ATH0<C4a05YJFP0`<300Ng]k0451@@1SHf<0NWYj04a<C00f=SH0?Shn04U9B@13@d<204];B`0D
03/k>`12@T80HF5Q04];B`19BDT0DU9B04I6AP1SHf<0:BTY04A4A017AdL0A4A4055AD@18B4P0YZJV
06m_K`12@T80DU9B0492@P1NGUh2069RHP0d02PX:013@d<0<30`06a/K011@D40Bd];05iNGP1JFUX0
G5aL06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm04a<C00i>CT0<C4a020P801<C4`0
Bd];08V9R@1>CTh0U9BD05UIF@1GEeL0DE5A09ZJVP1GEeL0F5QH07=cL`17AdL0QXJ609>CT`1EEED0
9bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0EEEE0861P@1HF5P0GEeM07]kNa7ooooo
000?ooooo`3o09fMW@1GEeL0NWYj07]kN`1oOgl0?clo05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07If
MP34a<@0Ogmo06IVIP0V9RH0>3Ph07QhN01CDe<0A4A407MgM`0i>CT0:2PX065QH@1MGEd0Hf=S0861
P@0/;2`0@d=305ADE01[Jf/0ADE506=SH`0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@
D028R8P071`L0451@@15ADD0EEEE06e]K@2/[:`0>CTi02@T901@D500M7Ad07=cL`10@4009BDU04a<
C01IFET0CDe=08R8R02][Jd0;Rh^05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K08f=
S@18B4P0820P04M7A`2;Rh/0FUYJ09>CT`1cLg<07alO03Hf=P1EEED0DU9B0;Bd]01MGEd0=CDe03hn
?P1NGUh0LW9b06IVIP1<C4`0=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0E5AD06][
J`12@T80:RXZ04i>CP1]KFd0C4a<04e=C@1aLG40:b/[05IFEP2IVIT0Bd];03/k>`1ZJVX0:BTY03lo
?`22PX80O7al03De=@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL04m?C`1hN7P0CTi>02/[
:`13@d<0G5aL03lo?`1[Jf/0WIfM06][J`0a<C40D51@05]KF`1kNg/0UYJF03Hf=P0Z:RX0G5aL07Yj
NP1VIVH0L71`03De=@10@400GEeM07AdM02FUYH0g]kN04];B`0T92@0Jf][07emO@2:RXX0aLG503Ti
>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L010@400TI6A08b<S01ZJVX0b<S808b<S00e=CD0IFEU04m?
C`1YJFT0^KVi05YJFP11@D40ATI609NGU`1OGel0IfMW08:2PP16ATH0Bd];09nOW`1ADE40SHf=065Q
H@17AdL0IVIV0:FUY@1^KVh0JFUY06IVIP17AdL0TI6A06i^KP1;Bd/0CTi>04m?C`17AdL0`<3006IV
IP1RHV80Bd];04Y:BP2=SHd0Kfm_03<c<`1NGUh0Shn?03`l?02:RXX0=SHf02d];@1;Bd/0<C4a04U9
B@2c/k<0NGUi038b<P1FEUH0C4a<0;Fe]@2][Jd0=3@d051@D020P800I6AT08n?S`3:b/X0?Cdm05mO
G`2<S8`0MGEe0:^[Z`2@T9009bLW03Xj>P1nOWh0LG5a09FEU@1gMgL08R8R04I6AP23Ph<0HV9R071`
L02`/;00R8R8000@024Q8@29RHT0SXj>06e]K@3Cdm<0CDe=02h^;P1@D500WinO08j>SP2:RXX0?clo
03@d=01ZJVX0/;2`06EUI@80Fe]K0140:2PX04];B`2<S8`0Hf=S07alO00j>SX09RHV04Y:BP1LG5`0
L71`04M7A`1RHV80?Shn03Lg=`2:RXX0OWin03`l?00Looooo`0J04];B`1KFe/0IfMW04a<C01ZJVX0
Kfm_07]kN`12@T80JVYZ04m?C`1>CTh0BDU903Ph>01?Cdl0E5AD07=cL`1/K6`0F5QH04Y:BP1>CTh0
BDU903De=@1@D500DE5A04M7A`1WIfL20410@01f04I6AP1<C4`0G5aL06=SH`18B4P0De=C055AD@1C
De<0Bd];05iNGP1BDU80MgMg03Ti>@0b<S80CTi>03Xj>P15ADD0=3@d04a<C00m?Cd0@41003Ph>01>
CTh0ADE503De=@12@T80ATI603<c<`0[:b/0CTi>034a<@0o?cl0Cdm?0410@01<C4`0GUiN04a<C018
B4P0GUiN04U9B@0Q8B40OWin05QHF00];Bd0F5QH05mOG`1QHF40>3Ph04m?C`1IFET0>c/k06EUI@0_
;bl0>SXj03lo?`0g=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k03hn?P1TI6@0=cLg0492@P1:
BTX0Jf][03Ph>014A4@0@410055AD@1?Cdl0@D5106e]K@1;Bd/0E5AD04m?C`1QHF40G5aL05mOG`1M
GEd0PX:205QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0@D51055AD@18B4P0HF5Q04U9B@1Y
JFT0BDU903Lg=`1HF5P0R8R80:2PX02NWYh0HV9R06UYJ@1`L700Rh^;075aL@1dM7@0Kfm_0:NWY`1Y
JFT0KVi^02@T9018B4P0EeMG08N7Q`80BTY:05/0?3`l051@D01HF5P0Cdm?08R8R00h>3P0J6QX02TY
:@1EEED0?clo04U9B@1FEUH0[Jf]0<G5a@0l?3`0NWYj0:f][@1OGel0@d=305YJFP0l?3`0CDe=096A
T@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0NWYj04U9B@18B4P0?Shn06QXJ01ADE40HV9R05mO
G`14A4@0][Jf07UiN@1OGel0BDU904];B`1RHV80M7Ad08V9R@18B4P0>CTi051@D01WIfL0Ph>30492
@P17AdL0?Shn04Y:BP0c<c<0P82005UIF@1=CDd0Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn
?P0O7al0=SHf07]kN`15ADD0CTi>061PH01KFe/0J6QX04U9B@1PH600BTY:075aL@1?Cdl0<C4a06i^
KP1MGEd0;bl_06e]K@0`<300>3Ph065QH@1dM7@0>CTi0080CTi>02D0L71`04m?C`1;Bd/0Hf=S0492
@P0i>CT0Ti>C07=cL`0Y:BT0H61P05]KF`0m?Cd0CDe=051@D00i>CT0IFEU04M7A`19BDT0?clo04U9
B@0f=SH0Fe]K04E5A@2YZJT0IfMW0820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R05mO
G`19BDT0EeMG0080F5QH00X0DE5A061PH01YJFT0A4A407]kN`21PH40Ng]k08R8R02IVIT0Kfm_4Ooo
ool000oooooo0;l0Vi^K06UYJ@1oOgl0Bd];075aL@1:BTX0EEEE03Xj>P19BDT0M7Ad04m?C`0`<300
?3`l04I6AP1TI6@0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0@D51065QH@2<S8`0
b/[:03De=@0W9bL0=SHf06m_K`15ADD0WIfM02DU9@0G5aL0D51@08N7Q`1?Cdl0SXj>09:BTP0F5QH0
<30`06i^KP1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0KVi^08^;R`0i>CT0IVIV08N7Q`15ADD0
Kfm_0451@@0W9bL0@41006i^KP1WIfL0I6AT02l_;`0T92@0GUiN08j>SP18B4P0@41005ADE00Q8B40
F5QH079bLP0];Bd0A4A403/k>`0S8b<0De=C0:^[Z`1NGUh0?Cdm03`l?00Z:RX0NWYj0:FUY@0W9bL0
>3Ph05IFEP12@T80FUYJ05MGE`0W9bL0BTY:0451@@0k>c/0P8200:NWY`0Z:RX09bLW06a/K01MGEd0
TI6A075aL@0M7Ad0;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0=cLg06e]K@1hN7P0IFEU0:6QX@0/;2`0
;bl_03lo?`1aLG40IfMW04=3@`0O7al0BDU9061PH01iNGT0GEeM0;2`/02SXj<0>CTi065QH@23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@1bLW80@D5106][J`1dM7@0N7Qh05YJFP2RXZ80
;2`/04m?C`2:RXX0B4Q808B4Q01gMgL0=3@d04i>CP37alL0Xj>S06UYJ@2PX:00DE5A05]KF`2c/k<0
Hf=S04E5A@1jNWX0B4Q803dm?@1bLW80a<C404e=C@1jNWX0DU9B04I6AP2CTi<0d=3@05MGE`1UIFD0
GemO05MGE`3;bl/0H61P03De=@1lO7`0EEEE04M7A`1mOGd0^[Zj0451@@15ADD0HV9R05mOG`0208V9
R@1Q02/[:`1VIVH0IfMW06QXJ02GUiL0PH6106a/K02ATI40PH6107moO`2HV9P08b<S01/K6`1WIfL0
OGem0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1fMWH08R8R05UIF@1[Jf/0HF5Q07alO00W9bL0
>SXj055AD@2^[Zh0LW9b0;2`/017AdL0ATI609>CT`1YJFT0Zj^[07MgM`0h>3P0@d=307EeM@1VIVH0
MGEe04M7A`0d=3@0ADE508J6QP1=CDd0HF5Q0:JVYP1JFUX0C4a<08>3P`0k>c/0EUIF06ATI00g=cL0
>SXj06IVIP2WYjL0BDU904e=C@1<C4`0I6AT092@T02YZJT0@D5105aLG01QHF40Bd];06UYJ@2IVIT0
9BDU05EEE@1UIFD0Hf=S08j>SP2ATI40@D5103@d=01UIFD0LG5a09^KV`1gMgL06ATI03lo?`1gMgL0
JFUY06MWI`1oOgl0HV9R02XZ:P1MGEd0/K6a07inOP0Looooo`0c055AD@1QHF40QHF507MgM`1ZJVX0
ATI606YZJP1PH600IfMW069RHP1WIfL0HV9R05IFEP1MGEd0G5aL055AD@0e=CD0<C4a03`l?014A4@0
De=C03lo?`10@400:b/[0492@P1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG07AdM01ADE40
J6QX08V9R@20P800BTY:071`L00_;bl0<c<c05=CD`1GEeL0C4a<03`l?01=CDd0ATI605ADE00o?cl0
EEEE0080@d=308l0AdM703Ph>00e=CD0;bl_04];B`0e=CD0AdM705ADE00n?Sh0A4A405UIF@1MGEd0
@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l05aLG01QHF40Jf][04=3@`1=CDd0N7Qh04E5A@1`L700
?Cdm04Q8B01:BTX0=CDe04M7A`1@D500:RXZ03De=@1HF5P0=CDe02h^;P0e=CD0C4a<02PX:015ADD0
?Shn05ADE00h>3P0C4a<02d];@0j>SX0?3`l0492@P1iNGT0BDU904m?C`12@T80EeMG04e=C@1EEED0
De=C06ATI01BDU80B4Q804m?C`1]KFd0EEEE07emO@0T92@0TI6A051@D01NGUh0K6a/09JFUP1CDe<0
MWIf051@D016ATH0DE5A08:2PP29RHT0b/[:05iNGP1ADE40MGEe059BDP2LW9`0IFEU051@D02:RXX0
ATI606e]K@14A4@0@T92034a<@1?Cdl0AdM7069RHP1;Bd/0CDe=04a<C00m?Cd0QHF501`L701QHF40
6ATI06YZJP0_;bl0J6QX065QH@1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01WIfL0
WinO04m?C`1VIVH0H61P01dM7@21PH40EEEE02<S8`12@T80>c/k051@D00g=cL0NWYj04E5A@1>CTh0
FUYJ08J6QP3_knl0N7Qh06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0F059BDP1EEED0
Hf=S07QhN013@d<0@T9203Ph>01WIfL0Bd];05YJFP1LG5`0Cdm?038b<P1<C4`0>CTi03De=@0n?Sh0
>CTi038b<P0l?3`0EEEE0410@080>c/k03`0B4Q8069RHP0Z:RX0?3`l04=3@`10@400A4A404M7A`2<
S8`0HV9R05EEE@1UIFD0?Shn04U9B@13@d<0ATI603`l?01IFET0AdM705YJFP18B4P0F5QH05eMG@1G
EeL0HF5Q0820P01OGel0CTi>0451@@1QHF40EeMG07inOP1CDe<0<30`03/k>`18B4P0De=C05mOG`1i
NGT0=SHf069RHP1?Cdl0]KFe04m?C`14A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K017
AdL0H61P0:NWY`1IFET0I6AT04Y:BP0_;bl20492@P0608F5Q@1PH600JFUY07=cL`1OGel0Ph>34Ooo
ool000oooooo02D0Q8B409RHV03Hf=P0C4a<05IFEP1bLW80a/K604U9B@0];Bd0JFUY0:n_[`21PH40
`l?30410@00l?3`0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0OGem03hn?P1DE5@0
IFEU0:>SX`1@D500WinO03hn?P0b<S80IfMW04m?C`19BDT0JVYZ0080<30`02H0EEEE08b<S01=CDd0
;Bd]0492@P0g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP13@d<0=SHf03/k>`0d=3@0
LW9b08>3P`0S8b<09RHV03/k>`1CDe<0UiNG04U9B@0W9bL0DE5A05mOG`1_Kfl0Q8B40:FUY@0R8R80
;Rh^08B4Q01PH600^KVi06i^KP806a/K0=<0?Shn069RHP2QXJ40LG5a02@T900^;Rh0IVIV05ADE01]
KFd0WIfM02XZ:P0];Bd0FUYJ07UiN@2`/;00IFEU02h^;P0g=cL0LW9b05eMG@1WIfL0L71`03/k>`1C
De<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07alO01PH600ATI602@T901>CTh0FEUI06e]K@19
BDT0MWIf03Hf=P1SHf<0W9bL05MGE`15ADD0N7Qh02PX:00m?Cd0FEUI08f=S@16ATH0CTi>02@T901I
FET0LG5a08V9R@1ADE40B4Q806QXJ01EEED0LG5a07UiN@0S8b<0FUYJ059BDP1JFUX0GemO0;jn_P1I
FET09bLW06QXJ01<C4`0[:b/08V9R@0e=CD0<S8b05eMG@1ADE40IFEU0<S8b01ZJVX0>CTi06i^KP1c
Lg<0JVYZ0<S8b01>CTh0=SHf04i>CP2WYjL0Xj>S0;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2J
VYX0=SHf08j>SP2NWYh0GemO0=CDe01aLG40AdM703`l?01iNGT0Ogmo075aL@0Q8B40@D5107QhN02[
Zj/0E5AD09jNWP1`L700<c<c03`l?02`/;00Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075aL@0l
?3`0PX:20:RXZ01BDU80H61P030`<017AdL0ZJVY0;:b/P13@d<0G5aL0410@01IFET0Xj>S05aLG01F
EUH0MgMg03Lg=`1/K6`0[Zj^05UIF@1EEED0@d=3059BDP2k^k/0[Zj^0451@@1?Cdl0Fe]K08>3P`33
`l<0Ogmo03hn?P1<C4`0FUYJ05IFEP2EUID0]kNg06=SH`10@400MgMg04Y:BP2a/K40b<S8055AD@0h
>3P0BTY:05iNGP1:BTX0V9RH034a<@0l?3`0Lg=c07emO@1@D500QXJ60;Rh^00m?Cd0HV9R0;Fe]@1^
KVh0UiNG08j>SP0`<300JVYZ05mOG`1JFUX0BDU905QHF00n?Sh0KVi^06ATI016ATH0ADE508R8R00o
?cl0@d=306][J`1_Kfl0De=C075aL@0k>c/0Cdm?01cooooo03<0D51@05aLG01?Cdl0;Rh^04a<C01:
BTX0E5AD03hn?P13@d<0ATI604U9B@0o?cl0;2`/05EEE@25QHD0IFEU04Q8B01YJFT0GUiN05UIF@15
ADD08R8R03Hf=P0h>3P0;2`/04Y:BP0j>SX092@T0492@P1:BTX0GemO04I6AP0W9bL0@D5104a<C012
@T80=cLg05EEE@1DE5@0BDU901lO7`0e=CD0A4A4038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17
AdL00`0k>c/0[@10@400<c<c04Y:BP1LG5`0<30`04A4A01OGel0JVYZ04];B`1FEUH0GEeM04U9B@1F
EUH0FEUI03/k>`2WYjL0IfMW04Q8B01WIfL0GemO079bLP10@400CDe=06EUI@1aLG40RXZ:04A4A01A
DE40@d=3059BDP13@d<0CTi>03Lg=`0j>SX0H61P03lo?`0i>CT0A4A4051@D00^;Rh0D51@04e=C@1B
DU80@T9205IFEP0b<S80@T9203dm?@1=CDd0LG5a04E5A@1DE5@0Cdm?07EeM@1EEED0IfMW075aL@1f
MWH0D51@05UIF@1PH600O7al06=SH`1]KFd0Bd];06UYJ@1EEED0Bd];04E5A@1aLG40ADE505=CD`1I
FET0IFEU04A4A02>SXh0Shn?0=?Cd`1NGUh0DE5A04e=C@0l?3`0K6a/04=3@`1YJFT0/[:b059BDP1S
Hf<0A4A4055AD@1NGUh0Fe]K05MGE`1HF5P0IFEU05]KF`12@T80O7al0:2PX01<C4`0B4Q804=3@`1n
OWh0B4Q805EEE@1@D500M7Ad08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0EEEE06IVIP0e
=CD0GUiN05UIF@0b<S80Vi^K05aLG00O7al0EeMG03Ti>@1ADE40:b/[0451@@0h>3P0Hf=S061PH015
ADD0EEEE0;Fe]@1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@18B4P0DE5A04=3@`16
ATH0?3`l04e=C@0h>3P0KVi^059BDP1:BTX0IfMW04Q8B01EEED0MWIf03Ph>00g=cL0ATI60492@P0Y
:BT0:b/[065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ0080@d=301009BDU07emO@15
ADD0<C4a04];B`0Q8B40JVYZ04I6AP1BDU806ATI04e=C@16ATH0IFEU04m?C`1EEED0HV9R0P1SHf<0
2`1NGUh0FEUI02PX:012@T80B4Q803Lg=`10@400@T920410@01RHV80A4A400809bLW0P1FEUH0701f
MWH0IVIV0=7Ad@1ZJVX0FEUI04E5A@2SXj<0Hf=S06IVIP1gMgL0<S8b05eMG@1@D500De=C03dm?@1B
DU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH6106MWI`1kNg/0H61P07]kN`25QHDAooooo`003ooo
ool0QP1[Jf/0IVIV08:2PP1eMGD0GUiN04E5A@1VIVH0Rh^;03Ti>@1GEeL0?Cdm03Lg=`1nOWh0V9RH
0492@P13@d<0;Bd]04];B`2DU9@0CDe=02<S8`1EEED0L71`03Hf=P1[Jf/0=cLg02XZ:P12@T80KVi^
08F5Q@2>SXh0A4A401DE5@1@D500QHF508:2PP2j^[X0HF5Q01/K6`1<C4`0CTi>05YJFP1FEUH0I6AT
020P8017AdL0H61P07AdM01aLG40QHF5024Q8@0a<C40D51@06e]K@2GUiL0<C4a02d];@1HF5P0I6AT
051@D01YJFT0KFe]02XZ:P1IFET0OWin04U9B@34a<@0PX:202<S8`11@D40MGEe05eMG@1:BTX08b<S
034a<@1TI6@0WinO03`l?012@T80>3Ph02LW9`19BDT0NGUi02`/;00n?Sh0@d=302h^;P12@T80P820
06QXJ00a<C40=SHf05YJFP25QHD0HV9R01lO7`0d=3@0>CTi038b<P1@D500UiNG03De=@0a<C40GEeM
03Xj>P24Q8@0UYJF03Xj>P0W9bL0CTi>061PH01_Kfl0GUiN02/[:`0];Bd0JFUY07YjNP1]KFd0/k>c
0410@00l?3`0Hf=S05iNGP2LW9`0ZJVY030`<015ADD0Bd];0820P021PH40];Bd03dm?@16ATH0KVi^
0P2;Rh/0VP2YZJT0]kNg02l_;`1SHf<0Vi^K06EUI@2YZJT0Shn?02TY:@1>CTh0UiNG09^KV`1/K6`0
KFe]02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf=P11@D40Hf=S09JFUP21PH40QHF502DU9@18B4P0
S8b<0:^[Z`14A4@0LG5a05mOG`1<C4`0[jn_06i^KP13@d<0MGEe04a<C00e=CD0JFUY0:j^[P1>CTh0
J6QX03Ph>014A4@0T92@09BDU00f=SH0X:2P07]kN`1TI6@0PX:204E5A@0^;Rh0EEEE04i>CP1FEUH0
][Jf08b<S00_;bl0ADE506][J`2>SXh0^k^k03Ph>00l?3`0Kfm_05IFEP1jNWX0aLG503De=@1NGUh0
PX:207MgM`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2FUYH0?3`l04Y:BP1OGel0IFEU07QhN02MWId0
=3@d03Xj>P2=SHd0RHV90:f][@1ADE40A4A405ADE02VYZH0LG5a07inOP1]KFd0<30`07MgM`2CTi<0
Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:075aL@1ADE40:b/[03Hf=P29RHT0S8b<04Q8B01MGEd0
DE5A0451@@1QHF40KVi^02d];@1^KVh0IFEU04e=C@1cLg<0Zj^[06=SH`1<C4`0M7Ad05]KF`26QXH0
Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0K6a/02LW9`1<C4`0KVi^04Y:BP1PH600Zj^[06EUI@0P8200
<S8b06UYJ@1^KVh0[jn_03Ti>@0a<C4Looooo`0C05IFEP1XJ6P0Kfm_04I6AP1[Jf/0CTi>06][J`0n
?Sh0IFEU04a<C01KFe/0A4A403dm?@1EEED0IVIV06ATI01DE5@0NWYj04M7A`0204E5A@0P030`<01>
CTh0?3`l03Hf=P1ADE40D51@03lo?`15ADD0IVIV05YJFP1YJFT0B4Q804e=C@1RHV80H61P05UIF@1Z
JVX0FEUI07YjNP16ATH0BDU9069RHP1;Bd/0CTi>03lo?`1BDU80=CDe04m?C`18B4P0FEUI04E5A@0e
=CD20451@@0402XZ:P0W9bL0>CTi02d];@80>SXj07l0=3@d03/k>`1@D500BDU903dm?@1@D500H61P
04A4A01WIfL0DE5A03hn?P1HF5P0X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0=SHf
038b<P0d=3@0Bd];01lO7`0_;bl0De=C02h^;P10@400?Cdm04I6AP0f=SH0?clo04m?C`1@D500E5AD
05IFEP19BDT0B4Q805QHF01>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@22PX80OGem
07=cL`1KFe/0OWin08N7Q`1jNWX0ATI607moO`1EEED0HV9R05=CD`29RHT0CDe=079bLP0g=cL0E5AD
06=SH`2ZZZX0Z:RX0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0WIfM05YJFP1CDe<0BTY:
04a<C01FEUH0KVi^05EEE@1CDe<0BTY:05=CD`0h>3P0MWIf0;Vi^@0m?Cd0BTY:01TI6@1>CTh0;Rh^
05YJFP1MGEd0XJ6Q09ZJVP0b<S80QHF50;>c/`1@D500CDe=05UIF@11@D40Hf=S0:FUY@0n?Sh0JFUY
06EUI@12@T80IVIV055AD@12@T80Hf=S0492@P1/K6`0:BTY05iNGP0e=CD0L71`05mOG`1@D500aLG5
0080F5QH06@0=3@d04];B`0/;2`0V9RH0;Jf]P1>CTh0A4A4051@D01IFET0KFe]04I6AP14A4@0Hf=S
06IVIP0d=3@0MGEe03Ti>@16ATH0LG5a055AD@0d=3@0>SXj04I6AP17AdL0C4a<03lo?`0b<S80@d=3
05aLG00k>c/0=3@d03dm?@11@D40JVYZ01/K6`0b<S80@41003/k>`17AdL0>CTi08^;R`1VIVH0>3Ph
05EEE@0N7Qh0?Cdm03Lg=`1;Bd/06a/K04M7A`0d=3@0Cdm?04I6AP1BDU80Ng]k05YJFP17AdL0GEeM
05QHF012@T80RXZ:06i^KP0d=3@0DU9B03Ph>00f=SH0CTi>05=CD`1<C4`0B4Q805IFEP0^;Rh0F5QH
05=CD`2=SHd0KVi^059BDP19BDT0Shn?06][J`1jNWX0WYjN04];B`29RHT0K6a/04Y:BP1=CDd0LG5a
04Y:BP11@D40ADE503hn?P1HF5P0<C4a06MWI`1VIVH0F5QH071`L01aLG40MgMg4Oooool000oooooo
03h0XJ6Q05EEE@1hN7P0K6a/07inOP14A4@0Cdm?08b<S01FEUH0Zj^[04Q8B010@400>CTi08n?S`1j
NWX0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0BDU905QHF01oOgl0bl_;01LG5`0f
=SH0Bd];05QHF011@D40JVYZ02LW9`14A4@0L71`06YZJP0^;Rh0JVYZ079bLP0L71`0?Shn06MWI`0b
<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[08>3P`0^;Rh0QXJ6069RHP0P8200=SHf055AD@0c
<c<0HF5Q09^KV`80<c<c0>80>CTi03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP24Q8@0<30`028R
8P1@D500Lg=c06EUI@1fMWH0E5AD02<S8`0j>SX0NGUi04A4A029RHT0KVi^01<C4`0i>CT0Fe]K05iN
GP1SHf<0EEEE03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07AdM01^KVh0De=C01TI
6@1;Bd/0O7al06QXJ00n?Sh0GemO01dM7@18B4P0X:2P04I6AP1EEED0DU9B024Q8@0d=3@0KVi^0::R
XP1JFUX0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0J6QX06MWI`0i>CT0GUiN03Lg
=`0h>3P0EEEE0::RXP1dM7@0>3Ph0451@@1:BTX0GEeM07YjNP0e=CD0=3@d051@D01?Cdl0JFUY0861
P@0O7al0>SXj06MWI`1XJ6P0MgMg0:f][@0`<300@D5105aLG01oOgl0W9bL0=GEe@1PH600:RXZ06i^
KP27QhL0MWIf0;Bd]025QHD0?Shn08:2PP2=SHd0K6a/0<[:bP1bLW80<S8b04=3@`1^KVh0VYZJ0=cL
g00d=3@0?Cdm03hn?P1kNg/0GEeM0<?3``25QHD08B4Q06EUI@25QHD0GEeM07AdM00g=cL0?Cdm04M7
A`20P800DU9B08>3P`0o?cl0HF5Q08b<S02QXJ40O7al092@T00S8b<0<C4a0;>c/`22PX80IVIV06=S
H`10@400M7Ad0:JVYP1PH600KFe]0492@P14A4@0LG5a03Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QH
F00n?Sh0Hf=S03Ti>@1kNg/0B4Q802`/;01CDe<0EEEE06=SH`20P800U9BD03Hf=P1eMGD0Kfm_07=c
L`2GUiL0[:b/02@T900b<S80GUiN06YZJP2FUYH0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2P
X00X:2P0De=C06m_K`1/K6`0_;bl079bLP0[:b/0BTY:05MGE`2KVi/0ZJVY04];B`0m?Cd0CDe=071`
L01EEED0SHf=09JFUP0Y:BT0;Bd]07inOP1DE5@0RHV906=SH`0a<C40;2`/05YJFP2QXJ40HF5Q06][
J`17AdL0@d=308B4Q02a/K40H61P7?ooool0901LG5`0IFEU065QH@1<C4`0NGUi06i^KP1aLG40Bd];
07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09>CT`1[Jf/0DE5A06=SH`1LG5`0EUIF06EUI@0g=cL0@410
038b<P10@400FUYJ04U9B@0n?Sh0B4Q8079bLP1ADE40Hf=S04e=C@1>CTh0C4a<06=SH`80JFUY05l0
@D5106][J`0f=SH0@41005IFEP1?Cdl0@D5102PX:01ADE40<C4a04Y:BP0];Bd0CDe=0492@P0m?Cd0
@T9204m?C`13@d<0>SXj04m?C`0n?Sh0BDU906=SH`12@T80AdM705=CD`1GEeL0ATI606i^KP1aLG40
KFe]08n?S`1JFUX0@D5105YJFP17AdL0FEUI04A4A01=CDd0Hf=S03Lg=`1lO7`0Bd];03lo?`17AdL0
?clo0492@P1;Bd/0:BTY038b<P1GEeL0;2`/03Hf=P0i>CT0?Shn02`/;012@T80AdM70410@00g=cL0
?3`l038b<P14A4@0=CDe03@d=01OGel09bLW04=3@`0e=CD0FUYJ03lo?`1EEED0QXJ6075aL@1;Bd/0
EEEE06=SH`1`L700EUIF06EUI@1FEUH0MWIf04A4A01:BTX0>3Ph071`L00h>3P0JFUY03dm?@1HF5P0
EeMG0:2PX02JVYX0a/K603Lg=`0205aLG01304m?C`1XJ6P0@T9208V9R@2i^KT0Bd];05ADE01WIfL0
De=C0451@@1QHF40B4Q803Lg=`1;Bd/0J6QX06IVIP2;Rh/0V9RH05UIF@1ZJVX0?Cdm07YjNP0e=CD0
WinO06MWI`1cLg<0P82004E5A@2a/K40clo?05mOG`1PH600JFUY055AD@1KFe/0KVi^0492@P1MGEd0
HF5Q03Xj>P20P800EeMG02/[:`1KFe/0KFe]07moO`15ADD0IFEU04I6AP1QHF40Hf=S079bLP2d];@0
NGUi05mOG`17AdL0H61P03De=@1]KFd0Rh^;030`<01DE5@0D51@07YjNP1hN7P0A4A404E5A@020451
@@0_038b<P1OGel0CTi>05=CD`1;Bd/0CDe=04];B`1?Cdl0<S8b05ADE01KFe/0=SHf02LW9`0[:b/0
H61P05IFEP14A4@0@41004];B`1_Kfl0:2PX03Ti>@1EEED0@D5104U9B@0^;Rh0NGUi03Hf=P11@D40
Fe]K01/K6`1?Cdl0=SHf051@D00l?3`0BTY:02LW9`17AdL0D51@04Y:BP1NGUh0H61P05MGE`1YJFT0
CTi>030`<00j>SX00P19BDT09@1TI6@0ATI603De=@1ADE40?Shn02TY:@0_;bl0BTY:03Ph>01OGel0
B4Q809BDU01CDe<0>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0ADE503lo?`1ADE40
;Rh^04=3@`18B4P0>SXj04i>CP19BDT0Ph>306YZJP1GEeL0GUiN06][J`1cLg<04Oooool000oooooo
00L0WIfM07MgM`2;Rh/0B4Q8065QH@13@d<0H61P0080?Cdm05d0IFEU05aLG00W9bL0F5QH03<c<`15
ADD0VYZJ03`l?011@D40BDU903@d=00^;Rh0HV9R0;6a/@0k>c/0B4Q803Xj>P1DE5@0Lg=c05aLG00U
9BD0>SXj038b<P1VIVH0QHF501TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF05]KF`1G
EeL0SXj>09ZJVP0M7Ad0Cdm?06ATI01CDe<0IfMW0<C4a00b<S80Fe]K07emO@1RHV80U9BD05IFEP0O
7al0;2`/04a<C01gMgL0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL06ATI00U9BD0F5QH04M7A`1F
EUH0QhN703`l?00Z:RX0=3@d04U9B@0d=3@0EUIF04Q8B00c<c<0=3@d07IfMP1;Bd/0<C4a05EEE@0d
=3@0:BTY04i>CP0X:2P0@D5103Ti>@0X:2P0DE5A06QXJ00P8200;bl_03Xj>P16ATH00P2FUYH06P0R
8R80=SHf069RHP1XJ6P0Hf=S08R8R00X:2P09BDU07=cL`1IFET0Ti>C07moO`0S8b<09BDU055AD@1/
K6`0P82006ATI00O7al0A4A404M7A`1PH600I6AT0:ZZZP2>SXh071`L0P1TI6@0WP1eMGD0b/[:07Ad
M00b<S80ATI608:2PP2HV9P0O7al06IVIP0U9BD0SHf=096AT@1QHF40TI6A0;no_`0n?Sh0>SXj09BD
U01eMGD0XJ6Q07alO01;Bd/0Fe]K07]kN`2=SHd0OWin09nOW`1;Bd/0F5QH07EeM@2XZ:P0IfMW0;fm
_@1EEED0A4A405eMG@2QXJ40JFUY09JFUP0o?cl0@D5106m_K`2`/;00F5QH08J6QP1lO7`0B4Q808N7
Q`1eMGD0CTi>09nOW`0k>c/0ADE507emO@2MWId0<c<c051@D00`<300NGUi0;^k^`1DE5@0:RXZ061P
H018B4P0@4100;6a/@21PH40<30`061PH01CDe<0PH610;Fe]@0Y:BT0;Bd]05=CD`1`L700XZ:R05mO
G`0[:b/0GemO06EUI@1dM7@0`/;2079bLP0H61P0L71`05ADE02ATI40R8R802PX:00S8b<0H61P08N7
Q`1iNGT0`/;203Lg=`1]KFd0RHV9071`L02`/;00M7Ad030`<01WIfL0T92@08j>SP2RXZ80AdM704Y:
BP1fMWH0^[Zj07AdM02GUiL0QHF503De=@1@D500LW9b06a/K01WIfL0/K6a034a<@10@400PH610820
P01BDU80N7Qh04I6AP0^;Rh0MGEe0<C4a01ADE40Fe]K05MGE`0V9RH0KFe]08R8R00f=SH0G5aL04e=
C@11@D40HV9R0:2PX01@D500=cLg06e]K@1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861
P@0i>CT092@T03lo?`1=CDd0F5QH7?ooool0>@1ADE40J6QX07=cL`1>CTh0Lg=c06YZJP1LG5`0A4A4
04a<C01HF5P0FUYJ03Ti>@0e=CD0GemO06UYJ@1TI6@0DE5A06a/K01FEUH0EeMG04i>CP0W9bL0BDU9
04=3@`0o?cl0I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1KFe/0IfMW05EEE@1TI6@0H61P
05MGE`1KFe/0<c<c04=3@`1ADE40De=C04I6AP0j>SX0@41003/k>`17AdL0=3@d06UYJ@0m?Cd0De=C
04=3@`1:BTX09bLW02`/;00203Ph>00304];B`1IFET0BDU90080Cdm?01D0EUIF05EEE@1?Cdl0NGUi
05iNGP2RXZ80IVIV04a<C01eMGD0K6a/07YjNP19BDT0EeMG07emO@1IFET0RHV905ADE01BDU80DE5A
04i>CP10@4000P1<C4`0B@1BDU80DE5A03/k>`17AdL0B4Q804a<C00i>CT0E5AD04e=C@1<C4`0BDU9
04e=C@0n?Sh0BTY:04U9B@1HF5P0IFEU04m?C`1KFe/0EEEE05QHF01`L700OGem06a/K01dM7@0FEUI
07YjNP1DE5@0RXZ:071`L02?Shl0LG5a05IFEP1GEeL0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q
03@d=01oOgl0O7al0<S8b00i>CT0NWYj08R8R01SHf<0OGem0492@P2:RXX0TI6A05UIF@0c<c<0?Cdm
03@d=00m?Cd0H61P07AdM01LG5`0BDU90492@P0c<c<0GUiN07IfMP10@400De=C038b<P1ZJVX0>CTi
07QhN01FEUH00P2:RXX0D00_;bl0XJ6Q0<?3``1BDU80GemO061PH01@D500J6QX096AT@11@D40GUiN
05ADE00`<300GUiN04E5A@0a<C40HV9R04U9B@23Ph<0?clo05MGE`11@D40KVi^05EEE@1OGel0UiNG
07UiN@1fMWH0@41004=3@`0b<S80M7Ad07=cL`0S8b<0EeMG04Y:BP13@d<0GEeM04i>CP1?Cdl0G5aL
06YZJP15ADD0Jf][0451@@17AdL0E5AD04Y:BP1<C4`0Fe]K03De=@0i>CT0@d=3038b<P0`<300>CTi
04U9B@10@400?clo04m?C`1ADE40L71`03Xj>P0i>CT0G5aL04E5A@19BDT0@d=3096AT@1:BTX0>SXj
04e=C@13@d<0FUYJ03`l?01CDe<0;Rh^0492@P0`<300AdM70P1:BTX06P1KFe/0@d=304a<C01LG5`0
AdM70492@P1;Bd/0Cdm?0451@@1?Cdl0A4A404U9B@1CDe<0?Shn03Ph>00e=CD0A4A404=3@`22PX80
G5aL0:n_[`1oOgl0Jf][0492@P1nOWh0Fe]K0P1CDe<04P0h>3P0LG5a051@D01NGUh0Cdm?05mOG`17
AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0G5aL06QXJ01FEUH0K6a/08^;Ra7ooooo000?ooooo`1I
06UYJ@1gMgL0/k>c05IFEP1WIfL0Fe]K08N7Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0>SXj
06UYJ@1IFET0MGEe07YjNP0N7Qh0?clo03Ti>@1oOgl0K6a/09ZJVP0P8200@d=305mOG`1lO7`0I6AT
0:JVYP0Y:BT08b<S06UYJ@1:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE017AdL0<c<c
05YJFP1_Kfl0BTY:04A4A013@d<07alO06a/K038b<P0Hf=S051@D00W9bL0820P05UIF@28R8P0AdM7
034a<@0d=3@0@410069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ03Xj>P12@T80FEUI
0:2PX026QXH08b<S04A4A00i>CT0De=C07=cL`1`L700;Rh^030`<016ATH0Hf=S07IfMP2CTi<00P0U
9BD07`1@D500Jf][0::RXP1>CTh08B4Q04M7A`1>CTh0=SHf07MgM`1BDU808B4Q059BDP2VYZH0RXZ:
07alO02BTY8092@T03hn?P1oOgl0KFe]05eMG@0Q8B40;2`/05QHF02YZJT0Jf][06MWI`1FEUH0=CDe
0410@02FUYH00P10@400YP1>CTh07AdM04I6AP1aLG40S8b<055AD@1IFET0=SHf04e=C@1fMWH0[Zj^
04=3@`10@400EeMG04I6AP0h>3P0OWin03Xj>P1SHf<0HV9R03@d=013@d<0VIVI04U9B@0j>SX0BTY:
04Q8B01aLG40VIVI030`<010@400>SXj04=3@`1HF5P0/k>c06QXJ016ATH0F5QH05ADE01jNWX0cLg=
05YJFP0g=cL0HV9R051@D01YJFT0gMgM07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0f=SH0OWin
0:VYZ@1XJ6P0aLG505ADE00i>CT0DE5A0:6QX@1FEUH0U9BD02<S8`12@T80TI6A07YjNP2BTY80a<C4
06e]K@0V9RH0M7Ad0;no_`2YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003lo?`21PH40W9bL
04A4A01cLg<08b<S02l_;`2:RXX0^;Rh05EEE@1nOWh0:b/[0451@@2SXj<0IFEU05MGE`1HF5P0<30`
0451@@1kNg/0Fe]K0:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0EEEE096AT@1FEUH0?Shn
071`L019BDT0@D510:2PX02_[jl0;bl_03/k>`1ADE40=CDe07UiN@2o_kl0EeMG01lO7`1BDU80S8b<
05=CD`2JVYX0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C034a<@1DE5@0Z:RX04I6AP20P800Hf=S
02DU9@13@d<0TI6A0861P@1LG5`0Rh^;034a<@1:BTX0UYJF08:2PP1OGel0U9BD028R8P0M7Ad0DE5A
07YjNP1=CDd0H61P03dm?@0j>SXLooooo`0[05MGE`1ZJVX0GUiN04Q8B01LG5`0De=C061PH00f=SH0
J6QX059BDP1UIFD0ATI603`l?01]KFd0Rh^;07UiN@13@d<0QXJ605EEE@1IFET0Fe]K01/K6`11@D40
:RXZ034a<@18B4P0ATI6028R8P13@d<0IfMW059BDP1SHf<0ADE504];B`1?Cdl0EEEE04Y:BP1GEeL0
CDe=065QH@0g=cL0AdM7055AD@0204E5A@070451@@0m?Cd0:RXZ03Ti>@0k>c/0G5aL03Xj>P0203dm
?@2Z05EEE@0R8R80DE5A04U9B@0j>SX0BTY:0451@@10@400D51@06YZJP1>CTh0C4a<05=CD`1]KFd0
JFUY09bLW01BDU80@D5106=SH`2>SXh0VYZJ065QH@1ZJVX0EeMG03Ph>01RHV80<S8b03Lg=`0o?cl0
@D5103Hf=P1<C4`0;2`/04A4A01KFe/0@41004M7A`12@T80HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0
Bd];04I6AP17AdL0HF5Q04I6AP1IFET0Bd];05eMG@0i>CT0E5AD07YjNP1VIVH0Ogmo07alO01/K6`0
BDU905ADE01fMWH0Lg=c0;Rh^01XJ6P0Hf=S071`L01UIFD0ADE506IVIP1[Jf/0R8R808V9R@2IVIT0
TY:B0<[:bP2d];@0e]KF069RHP31`L40Zj^[06=SH`1QHF40EeMG09ZJVP2;Rh/0A4A403<c<`1UIFD0
=SHf04i>CP1@D500DE5A03@d=01IFET0Fe]K04M7A`22PX80Ogmo05iNGP1kNg/0>SXj05aLG00g=cL0
Q8B405]KF`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT06YZJP1bLW80VYZJ03hn?P27QhL0
EUIF02/[:`1NGUh0F5QH034a<@1IFET0G5aL08f=S@11@D40Hf=S04Q8B01RHV80EEEE06UYJ@2b/[80
Lg=c07moO`15ADD0C4a<04I6AP2>SXh0Shn?04m?C`1OGel0EeMG06][J`1RHV80?clo0492@P1>CTh0
E5AD04E5A@29RHT0B4Q804];B`24Q8@0I6AT04E5A@1@D500DE5A04];B`17AdL0@d=303/k>`10@400
FEUI05=CD`1:BTX0Cdm?04i>CP1gMgL202l_;`0G055AD@16ATH0=cLg03Ti>@1^KVh0<c<c03lo?`10
@40092@T04i>CP0n?Sh0EEEE02h^;P0g=cL0>CTi06a/K00i>CT0AdM706ATI019BDT0ADE506MWI`1U
IFD00P18B4P04`1NGUh0ADE505MGE`0j>SX0A4A404U9B@12@T80?clo038b<P16ATH0;Rh^04a<C01j
NWX0UIFE05]KF`17AdL0K6a/092@T01eMGD00P2HV9P01`1EEED0M7Ad04e=C@1ZJVX0Ogmo07QhN012
@T800P1KFe/02@1;Bd/0G5aL061PH02<S8`0G5aL05=CD`1_Kfl0MGEe071`L00Aooooo`003oooool0
S02GUiL0EeMG07IfMP1PH600MgMg04=3@`1HF5P0IfMW05aLG02WYjL0@D51038b<P1EEED0HV9R06IV
IP0g=cL0;2`/03hn?P1SHf<0GemO04Y:BP2GUiL0@d=303/k>`1]KFd0<c<c07MgM`2QXJ40@410059B
DP25QHD0GEeM03<c<`1VIVH09RHV05aLG02<S8`0Fe]K0492@P1aLG40OWin03Xj>P14A4@0KFe]03Hf
=P1DE5@0GemO0492@P1RHV80Kfm_030`<00a<C40H61P05UIF@1oOgl0EeMG030`<01@D500H61P04Y:
BP1TI6@0O7al04U9B@1OGel0DU9B04E5A@2HV9P0OWin02d];@11@D40Fe]K04e=C@1dM7@0>SXj02h^
;P1@D500HV9R04m?C`1hN7P0C4a<02<S8`0i>CT0Lg=c06][J`1`L700Bd];01XJ6P0e=CD0HV9R07=c
L`0j>SX0F5QH024Q8@1:BTX0N7Qh04A4A01MGEd0D51@01hN7P0n?Sh0H61P07QhN02?Shl0DE5A02@T
901EEED0PX:2055AD@1EEED0Hf=S02l_;`1OGel0K6a/03Hf=P1?Cdl0BDU903Ti>@1DE5@0PX:206i^
KP15ADD0D51@04Q8B01gMgL0NWYj03Hf=P0];Bd0HV9R05=CD`0k>c/0OWin05QHF016ATH0K6a/07=c
L`1BDU80JFUY07emO@0m?Cd0A4A40P18B4P0I`2:RXX0N7Qh03lo?`1@D500I6AT05EEE@1]KFd0Kfm_
03Ph>01gMgL0NGUi05QHF02:RXX0IfMW0451@@1<C4`0Kfm_07AdM028R8P0Shn?03Lg=`0l?3`0KVi^
09:BTP1WIfL0Ti>C05=CD`0m?Cd0LG5a0;Jf]P1dM7@0WinO065QH@0d=3@0Bd];06IVIP26QXH0]KFe
03Lg=`18B4P0JFUY07alO01=CDd0RHV907AdM00_;bl0QHF508R8R01mOGd0TY:B0451@@0o?cl0Ogmo
0:^[Z`1WIfL0Q8B406UYJ@1dM7@0UiNG05MGE`1ZJVX0PH6103@d=01DE5@0UIFE071`L01aLG40De=C
06MWI`2GUiL0LW9b0492@P1fMWH0ATI603hn?P2SXj<0C4a<051@D01RHV80Bd];075aL@2WYjL0EeMG
05IFEP1]KFd0D51@0:2PX02DU9@0ADE5075aL@1hN7P0EUIF08>3P`1nOWh0C4a<08>3P`1RHV80HF5Q
09JFUP1/K6`0;bl_03lo?`1aLG400P1kNg/0:`2@T900@d=303/k>`1OGel0JVYZ05QHF01hN7P0Ph>3
034a<@1JFUX0RXZ:04i>CP2DU9@0CDe=02HV9P11@D40P82005QHF01iNGT0@D5103Hf=P1EEED0QhN7
059BDP20P800MWIf03@d=00e=CD0JVYZ059BDP1SHf<0Ogmo02HV9P1FEUH0WinO071`L014A4@0MGEe
04];B`10@400R8R80::RXP1CDe<07?ooool0:P1YJFT0MWIf071`L01=CDd0MgMg06EUI@1jNWX0FUYJ
071`L01IFET0G5aL05]KF`1CDe<0MgMg0861P@2BTY80H61P07EeM@1FEUH0Fe]K061PH00`<300BDU9
03/k>`16ATH0GEeM05ADE01>CTh0EEEE06m_K`1mOGd0KFe]04];B`1PH600GemO06QXJ01PH600LG5a
05UIF@1]KFd0;2`/04];B`80De=C0140@T9203lo?`10@400=CDe04E5A@0a<C40Hf=S04=3@`1FEUH0
<S8b04m?C`0V9RH0@D5104Q8B012@T80De=C03hn?P0204i>CP3S061PH017AdL0IVIV04i>CP1SHf<0
K6a/09VIV@0n?Sh0BDU905eMG@1BDU80GEeM03Xj>P1BDU80CTi>03De=@1kNg/0?3`l04A4A01;Bd/0
AdM703Ph>01ADE40<c<c04A4A01NGUh0=SHf0492@P0j>SX0<C4a03<c<`0h>3P0FEUI03<c<`13@d<0
>SXj04E5A@1=CDd0?clo0410@01LG5`0<C4a04];B`0b<S80De=C05YJFP1EEED0T92@06m_K`1OGel0
?clo06=SH`1dM7@0LW9b09>CT`1WIfL0MWIf05ADE01>CTh0?clo05EEE@0j>SX0LG5a02l_;`1QHF40
;bl_0;Rh^02QXJ40]KFe051@D02JVYX0KVi^07=cL`26QXH0@T9206UYJ@1EEED0GUiN03Ti>@1GEeL0
AdM703lo?`0l?3`0Fe]K04U9B@17AdL0DE5A03`l?021PH40PX:204e=C@1>CTh0=cLg06=SH`0e=CD0
W9bL05QHF01ZJVX0LW9b04U9B@2OWil0Zj^[05EEE@1FEUH0De=C05IFEP1RHV80P820030`<021PH40
Cdm?03/k>`1VIVH0A4A404E5A@1OGel0IfMW08J6QP1ADE40HF5Q03Ti>@1SHf<0B4Q807moO`2XZ:P0
NGUi07AdM01JFUX0KVi^02XZ:P1WIfL0F5QH0410@01bLW80Fe]K04e=C@19BDT0EEEE055AD@1CDe<0
CDe=03<c<`1/K6`0?Shn0410@01NGUh0AdM704Y:BP1FEUH0@D5104m?C`1QHF40@D5102h^;P0l?3`0
EEEE04i>CP0k>c/0De=C055AD@1XJ6P0=SHf03`l?01HF5P0B4Q803`l?00e=CD0JVYZ02l_;`1GEeL0
A4A4034a<@1?Cdl0ADE5059BDP0Y:BT0>3Ph03<c<`1>CTh0?Cdm03hn?P1NGUh0A4A404M7A`1aLG40
I6AT03dm?@13@d<0@41005iNGP25QHD0G5aL05MGE`18B4P0J6QX03/k>`12@T80@D510492@P1KFe/0
E5AD08J6QP1SHf<0JFUY05YJFP21PH40=cLg05ADE018B4P0>c/k06][J`12@T80CTi>05=CD`1PH600
CTi>061PH01DE5@0ADE504Y:BP17AdL0MGEe04m?C`1dM7@0DE5A05UIF@2:RXX04Oooool000oooooo
0?l0MGEe07IfMP1YJFT0D51@06QXJ01KFe/0SHf=038b<P1?Cdl0KFe]071`L01?Cdl0HV9R03Hf=P18
B4P0ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^08B4Q01:BTX0ADE501DE5@0[:b/0OWin07alO011
@D40FUYJ02d];@0S8b<0Kfm_02TY:@0d=3@0CTi>02h^;P0k>c/0De=C096AT@0o?cl09RHV04Q8B01L
G5`0Xj>S06i^KP0H61P0;bl_04E5A@0e=CD0F5QH09^KV`12@T80BTY:03hn?P0h>3P0UIFE092@T00Z
:RX0?Cdm04A4A01ZJVX0[Jf]02LW9`0c<c<0BDU905IFEP1HF5P0UIFE0:FUY@0O7al0?Shn06][J`1]
KFd0c<c<06ATI00T92@0FUYJ0=7Ad@1]KFd0P82005]KF`16ATH0@d=305eMG@1>CTh0P82006YZJP0H
61P0ATI606UYJ@13@d<0NGUi030`<00e=CD0Cdm?05MGE`0Y:BT0C4a<05UIF@0/;2`0JVYZ06UYJ@0k
>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0?3`l03<c<`19BDT0De=C06ATI00V9RH0:RXZ03Xj>P0l
?3`0KVi^06][J`0R8R80@D5104e=C@1OGel0Cdm?09^KV`23Ph<08b<S04M7A`1?Cdl0G5aL07moO`2K
Vi/0>CTi06EUI@1[Jf/0D51@09RHV01KFe/09bLW07EeM@1GEeL0GUiN0;>c/`2GUiL0;bl_04Y:BP1M
GEd0EeMG0=oOg`2[Zj/08B4Q05YJFP2^[Zh0Ph>30:VYZ@3GemL0A4A406QXJ028R8P0QhN70820P038
b<P0H61P04=3@`2<S8`0Y:BT08:2PP20P800<S8b05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX04A4A02X
Z:P0[jn_05QHF01dM7@0;bl_04];B`1[Jf/0VIVI04M7A`1WIfL07alO04i>CP2GUiL0JFUY04Y:BP1]
KFd0>c/k02XZ:P1WIfL0Ng]k05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0D51@0:f][@1/
K6`07QhN05]KF`1VIVH0Kfm_0;>c/`1mOGd0820P05iNGP2=SHd0^KVi096AT@0Y:BT09BDU06=SH`1X
J6P0]kNg0:^[Z`0[:b/0E5AD08F5Q@1nOWh0cLg=07=cL`0a<C40Fe]K06i^KP1jNWX0/[:b05ADE00l
?3`0FUYJ08>3P`1:BTX0YZJV092@T00W9bL0=cLg07UiN@1SHf<0/[:b08B4Q00P8200:b/[04E5A@2A
TI4002<0PH6107MgM`0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c059BDP1oOgl0DE5A06a/
K00f=SH0;bl_04A4A01XJ6P0Fe]K04m?C`19BDT0?clo0451@@1kNg/0IVIV03Xj>P1oOgl0?Shn04A4
A019BDT0GUiN024Q8@1=CDd0B4Q8065QH@0Looooo`0=06QXJ01JFUX0@d=303Ti>@1>CTh0EEEE05AD
E00j>SX0EEEE05MGE`1CDe<0?3`l03Lg=`0205YJFP0706QXJ018B4P0CDe=04M7A`0o?cl0@T9202`/
;0020492@P0H03Hf=P1TI6@0De=C04M7A`1BDU80HV9R07=cL`1_Kfl0@T9205EEE@1PH600AdM704a<
C01PH600GUiN06MWI`0m?Cd0CTi>055AD@18B4P0@d=303dm?@0g=cL0:b/[0P0j>SX0501ADE40<C4a
03Ph>00h>3P0@T9201HF5P0n?Sh0<S8b03Ph>00k>c/0?Cdm079bLP1KFe/0FEUI038b<P0o?cl0IVIV
05IFEP1HF5P0NGUi0P12@T806`1OGel0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0
=CDe04=3@`10@400?clo03Lg=`11@D40GemO03Lg=`0o?cl0@T9203De=@0k>c/0=CDe05MGE`0e=CD0
>SXj02l_;`0204e=C@2:04M7A`1CDe<0Fe]K0410@01:BTX0A4A404];B`1HF5P0BTY:0:6QX@1ZJVX0
M7Ad04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01UIFD0EEEE04I6AP1JFUX0@d=305]KF`0i>CT0
MWIf04Y:BP2/[:`0SHf=0820P01:BTX0e]KF06EUI@1bLW80IVIV061PH02CTi<0DU9B05=CD`0G5aL0
GemO051@D023Ph<0I6AT06UYJ@1VIVH0Jf][06IVIP1=CDd0QHF50861P@1OGel0F5QH04Y:BP1EEED0
ATI60861P@10@400M7Ad08F5Q@0[:b/0WYjN09NGU`0m?Cd0H61P03`l?01ADE40AdM707AdM00U9BD0
QhN706][J`19BDT0H61P05eMG@1KFe/0H61P05QHF01GEeL0D51@061PH018B4P0GemO04M7A`28R8P0
[:b/06EUI@1[Jf/0HF5Q05eMG@0`<300T92@05MGE`0[:b/0D51@03dm?@1QHF40A4A404M7A`1;Bd/0
A4A403Ti>@0c<c<0EUIF0492@P14A4@0F5QH03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0
@41004I6AP1>CTh0ATI605eMG@1HF5P0GEeM04];B`13@d<0F5QH051@D00k>c/0?clo06e]K@0d=3@0
Fe]K04A4A00e=CD0?clo03`l?01:BTX0820P0P0f=SH0501SHf<0?3`l05eMG@1gMgL0?Cdm04=3@`1M
GEd0HF5Q03/k>`1@D500?3`l03Lg=`1JFUX0<c<c05IFEP0o?cl0JFUY02DU9@0e=CD0@D510P17AdL0
601OGel0O7al04M7A`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1MGEd0BTY:05iN
GP0f=SH0I6AT04Q8B013@d<0CTi>05ADE01kNg/0D51@07UiN@80FEUI00<0SHf=ooooooooool03ooo
ool000oooooo00<0OWin07AdM02h^;P00P1GEeL0BP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0m?Cd0JFUY07alO01/K6`0Hf=S01XJ6P0g=cL0Cdm?04M7A`1DE5@0XZ:R01`L700b<S80
>CTi06MWI`2IVIT0_Kfm030`<00b<S80HF5Q05ADE023Ph<0XJ6Q01dM7@0T92@0AdM705UIF@1aLG40
NGUi06a/K00Q8B40Bd];09VIV@0m?Cd0GemO05]KF`0Q8B40Cdm?05YJFP1QHF40U9BD030`<00P8200
BTY:09nOW`1`L700Jf][04Q8B00_;bl0I6AT08J6QP0i>CT0Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0
C4a<01hN7P0`<300Cdm?08N7Q`0o?cl0GEeM0P0b<S805@10@400HV9R01dM7@11@D408B4Q03lo?`2L
W9`0[Jf]03`l?00/;2`0A4A4051@D02TY:@0C4a<020P800i>CT0@410034a<@1YJFT0Xj>S02HV9P02
05QHF02j04E5A@2^[Zh0_[jn02/[:`0n?Sh0G5aL051@D02=SHd0GEeM024Q8@1KFe/0LW9b055AD@1e
MGD0^k^k04M7A`11@D40Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0MGEe02h^;P0l
?3`0F5QH08j>SP2DU9@0UIFE07UiN@0`<300H61P07inOP1FEUH0Y:BT04e=C@0l?3`0P8200<30`01T
I6@0KVi^04Y:BP0j>SX0W9bL0=KFeP1VIVH0FEUI03Ti>@17AdL0E5AD09ZJVP1lO7`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0I6AT0<?3``1DE5@0<C4a04m?C`1hN7P0IFEU07YjNP2;
Rh/0>3Ph05UIF@28R8P0SXj>0<o?c`0n?Sh07alO059BDP1bLW80EUIF07]kN`0U9BD0:2PX04E5A@1]
KFd0HV9R09jNWP1CDe<0;bl_059BDP1HF5P0_;bl08:2PP0H61P0AdM70861P@1LG5`0HF5Q07]kN`0b
<S80Hf=S0:BTY01NGUh0VYZJ01lO7`0k>c/0PH610:JVYP19BDT0MgMg02XZ:P1XJ6P0X:2P07]kN`1b
LW80PX:2030`<016ATH0RXZ:05mOG`1TI6@0:2PX04U9B@1BDU80LW9b05eMG@2:RXX0FUYJ04A4A01d
M7@0PH6105iNGP1fMWH0Fe]K03@d=01^KVh0ZJVY07MgM`18B4P0AdM704I6AP1oOgl0UiNG03hn?P0d
=3@0BTY:04I6AP1;Bd/0X:2P03lo?`0g=cL0IfMW05QHF01EEED0QHF50;Bd]00_;bl0ADE505EEE@1N
GUh0X:2P05YJFP0V9RH0De=C075aL@1jNWX0R8R808B4Q00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16
ATH0:2PX04m?C`23Ph<0EEEE0:VYZ@22PX80?3`l7?ooool0fP17AdL0Ng]k06QXJ01;Bd/0L71`05]K
F`1iNGT0BTY:07QhN01GEeL0IFEU06MWI`1RHV80Jf][07YjNP1gMgL0De=C07moO`1ADE40E5AD05=C
D`0[:b/0?3`l03hn?P16ATH0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1/K6`0I6AT05mO
G`1EEED0NGUi04m?C`1/K6`0=cLg04Y:BP1LG5`0FUYJ04A4A00l?3`0A4A40451@@0k>c/0;2`/059B
DP0i>CT0@41003Ti>@1MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b03dm?@1;Bd/0;Bd]05EE
E@1MGEd0EEEE07MgM`2OWil0?clo04e=C@16ATH08R8R04=3@`15ADD0EEEE04U9B@0/;2`0A4A40451
@@18B4P0=cLg02XZ:P0c<c<0@d=3034a<@0l?3`0Fe]K02h^;P0];Bd0;bl_02h^;P0Z:RX09bLW05QH
F00P8200<C4a02LW9`1<C4`0ATI602d];@0o?cl0DE5A02/[:`0g=cL0=3@d04A4A00g=cL0>CTi09VI
V@1GEeL0D51@038b<P1XJ6P0=CDe04=3@`1ADE40GEeM08B4Q01QHF40GUiN04];B`1NGUh0EUIF06m_
K`0V9RH0EUIF02d];@3?cll0XJ6Q08:2PP1KFe/0]kNg069RHP2EUID0OWin0451@@1GEeL09RHV05]K
F`10@400BDU902DU9@10@400=3@d04I6AP13@d<0BTY:05=CD`0h>3P0UiNG07EeM@1BDU80De=C04Q8
B01BDU80B4Q807IfMP1XJ6P0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0EEEE08:2
PP1JFUX0Rh^;05iNGP1VIVH0PH6105UIF@1<C4`0HF5Q04i>CP1^KVh0JVYZ05QHF00h>3P0GemO04I6
AP2`/;00Zj^[06a/K01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP1<C4`0=3@d05]K
F`15ADD0?Cdm034a<@0`<300De=C0451@@1>CTh0EEEE02d];@0b<S80BTY:03Hf=P17AdL0IFEU03Hf
=P0[:b/0?clo0P15ADD0AP0_;bl0@d=303/k>`1EEED09RHV034a<@1=CDd0@D51038b<P0a<C40JFUY
01/K6`1TI6@0>3Ph03De=@10@400<C4a04Y:BP0g=cL0Bd];059BDP1JFUX0CDe=03dm?@1OGel0BDU9
04Y:BP2MWId0JFUY02TY:@0h>3P0:RXZ06UYJ@22PX80BDU906=SH`0g=cL0EeMG02d];@1<C4`0?Shn
055AD@0h>3P0E5AD09jNWP1PH600L71`04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0CTi>
059BDP1eMGD0BDU906MWI`12@T80GemO05aLG01MGEd0RXZ:05mOG`1dM7@0IFEU05QHF02/[:`Aoooo
o`003oooool0Y02LW9`0FUYJ06QXJ01[Jf/0KVi^04M7A`1ADE40P8200861P@26QXH0=CDe034a<@19
BDT0GemO07emO@14A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@1FEUH0Cdm?06][J`1T
I6@0<S8b04U9B@1iNGT0O7al030`<01BDU808b<S06=SH`2/[:`0IVIV02l_;`0n?Sh0?Cdm02<S8`13
@d<0PH6102DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04i>CP27QhL0@d=301PH600i
>CT0EUIF04A4A02@T900RXZ:020P800k>c/0LW9b06YZJP2i^KT0MGEe01/K6`19BDT0De=C06=SH`2R
XZ80;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0J6QX06ATI02:RXX0B4Q801XJ6P19
BDT0Xj>S08V9R@22PX80Hf=S03@d=01BDU80OGem03`l?01MGEd0:b/[02DU9@0m?Cd0EEEE04U9B@1B
DU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@1:BTX0SXj>0410@01<C4`0CDe=02PX:00j
>SX0GEeM09NGU`16ATH0@T9202TY:@1YJFT0Jf][02/[:`0R8R80@d=303Ti>@0d=3@0Jf][04];B`0W
9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a<C40=SHf05aLG01OGel0`<3007AdM00M7Ad0C4a<07emO@20
P800_;bl05EEE@0W9bL0JFUY0:JVYP26QXH0b<S806i^KP0a<C40JVYZ08>3P`27QhL0e]KF09NGU`0Y
:BT0C4a<0P2/[:`0<026QXH0_kno06QXJ018B4P0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861
P@1gMgL0bLW902@T901ADE40_;bl08f=S@0o?cl0IfMW04a<C01[Jf/0YJFU08J6QP1DE5@0N7Qh03dm
?@18B4P0J6QX08j>SP1:BTX0KVi^0410@029RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@04m?
C`1JFUX0?Shn05ADE02JVYX0F5QH02h^;P80?clo01D0BTY:09>CT`0^;Rh0E5AD065QH@1_Kfl0Shn?
0<K6aP1^KVh0>SXj06=SH`27QhL0Zj^[03<c<`0l?3`0HV9R04];B`1/K6`0dm?C0;no_`0c<c<00P1[
Jf/0<`2ATI40]kNg07=cL`0h>3P0E5AD05IFEP1lO7`0[jn_051@D015ADD0BDU907inOP1YJFT0MgMg
0:ZZZP29RHT0;Rh^05eMG@2<S8`0R8R809>CT`0[:b/0=3@d0492@P2@T900O7al06YZJP0V9RH0BTY:
05IFEP1_Kfl0Cdm?07=cL`19BDT0=3@d05eMG@1SHf<0?Cdm06UYJ@1JFUX09BDU03hn?P1lO7`0Ogmo
03hn?P1]KFd0?3`l02HV9P1EEED0Y:BT04m?C`0Looooo`3o04A4A020P800K6a/05IFEP1VIVH0HF5Q
07QhN01KFe/0EeMG05mOG`1BDU80@D510410@01iNGT0RHV907=cL`1RHV80Ng]k05aLG01_Kfl0EEEE
03Ph>01@D500>3Ph04A4A01PH600EeMG051@D01RHV80LG5a07]kN`1XJ6P0?Cdm05EEE@1[Jf/0EEEE
065QH@1UIFD0FEUI05ADE00h>3P0B4Q8055AD@1;Bd/0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A
04E5A@1OGel0;2`/051@D00H61P0?Shn04A4A00g=cL0Cdm?0410@01BDU80EUIF04m?C`0f=SH0GUiN
075aL@1WIfL0K6a/08Z:RP0j>SX0@D5106UYJ@1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1=CDd0<30`02l_;`1ADE40>3Ph03hn?P1CDe<0@4100492@P10@400AdM703hn?P14A4@0Hf=S
03Xj>P1CDe<0ATI603dm?@19BDT0B4Q805MGE`1LG5`0?clo04m?C`0n?Sh0<S8b04m?C`1SHf<0_[jn
06m_K`1WIfL0ADE505MGE`11@D40IFEU065QH@0j>SX0HF5Q03dm?@0n?Sh0Jf][061PH00];Bd0;Rh^
03Hf=P18B4P07alO06=SH`2>SXh0P82004i>CP2>SXh0?Shn08J6QP1VIVH0HV9R07QhN00X:2P0LG5a
01LG5`0d=3@0=cLg051@D01ADE40Lg=c0492@P1DE5@0CTi>069RHP2n_[h0MWIf069RHP15ADD0DU9B
04=3@`1LG5`0LW9b04i>CP1]KFd0N7Qh0820P02m_Kd0/K6a07IfMP1NGUh0F5QH05]KF`18B4P0TI6A
04A4A029RHT0FUYJ04a<C01KFe/0?Cdm04=3@`1EEED0M7Ad06IVIP1GEeL0D51@02`/;01cLg<0:RXZ
06][J`1]KFd0LW9b04M7A`1?Cdl0BTY:0451@@28R8P0ADE50451@@18B4P0@D5104=3@`1LG5`0@d=3
04Q8B011@D40Bd];04i>CP1DE5@0A4A405MGE`1QHF40A4A405ADE01OGel0;Bd]03@d=01<C4`07AdM
02DU9@0`<300<c<c04i>CP0b<S80CDe=04];B`1OGel0>SXj03dm?@1SHf<0AdM703Ti>@1EEED0PX:2
03Xj>P1PH600A4A404M7A`1;Bd/0ATI6051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0BDU9
04A4A01JFUX0B4Q80451@@10@400=CDe04];B`1QHF40BTY:000D05UIF@0i>CT0FUYJ02@T901;Bd/0
CDe=06YZJP1VIVH0HF5Q08n?S`1mOGd0Jf][071`L02>SXh0D51@09:BTP1:BTX0De=C08f=S@1IFET2
055AD@0=07MgM`15ADD0FEUI03Xj>P14A4@0GUiN07inOP2RXZ80EeMG06=SH`1PH600GemO07alO00A
ooooo`003oooool0602GUiL0JVYZ08:2PP1MGEd0Lg=c04E5A@1QHF40>c/k04I6AP2QXJ40C4a<03hn
?P19BDT0@d=3065QH@2DU9@0<C4a03Ti>@0c<c<0@d=3071`L02=SHd0FUYJ030`<080EUIF02@0TI6A
07inOP0L71`09BDU05MGE`1/K6`0JFUY096AT@0E5AD0<c<c065QH@2@T900I6AT0:n_[`1_Kfl09bLW
03De=@19BDT0KFe]0::RXP0b<S809BDU03dm?@1?Cdl0AdM7075aL@2g]kL0=3@d07AdM01jNWX0DE5A
08b<S01;Bd/0=3@d03dm?@1kNg/207=cL`0h02`/;00m?Cd0IVIV08:2PP0d=3@0M7Ad04M7A`0N7Qh0
NWYj06i^KP1EEED0FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph0451@@0_;bl0MgMg0861P@0X:2P0
<C4a04=3@`0^;Rh0Cdm?06EUI@0V9RH0@41003De=@1FEUH0ZJVY06a/K00C4a<0;Rh^04m?C`1:BTX0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD0<S8b08R8R01CDe<0VYZJ08:2PP0O7al0
@T9204U9B@1[Jf/207]kN`2X01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0CTi>09^KV`1/
K6`0/K6a059BDP0g=cL0@T920:n_[`2?Shl0NGUi0492@P0X:2P0EUIF0:RXZ01GEeL0H61P04=3@`0P
8200BTY:06YZJP14A4@0IVIV03`l?00_;bl0AdM7092@T00c<c<0@T9205MGE`0f=SH0KFe]0:FUY@1G
EeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0IFEU07QhN01>CTh0Fe]K0:>SX`1UIFD0<C4a06EUI@26
QXH0SHf=0=?Cd`0f=SH0;bl_06MWI`29RHT0JVYZ0:FUY@0k>c/0=3@d071`L01/K6`0RXZ:0<G5a@0h
>3P0Bd];08n?S`1dM7@0RXZ:0<30`01?Cdl0<c<c0820P01lO7`0[Jf]0;^k^`0T92@0:2PX07QhN02@
T900UIFE034a<@1<C4`0Fe]K065QH@23Ph<0[Zj^03Lg=`0d=3@0Ph>307alO02NWYh0N7Qh03De=@1@
D500QHF507QhN02JVYX0QhN70492@P32`/80S8b<08>3P`25QHD0ATI603Ti>@27QhL0eMGE08^;R`24
Q8@0ATI606i^KP2GUiL0alO705MGE`29RHT0BDU9038b<P1`L700ZJVY04m?C`1GEeL0R8R803Ti>@0e
=CD0P8200:f][@19BDT0FEUI03<c<`1GEeL0XZ:R05EEE@0f=SH0Hf=S04U9B@1;Bd/0S8b<04Y:BP0c
<c<0L71`06ATI01lO7`0T92@05YJFP0V9RH0?clo05eMG@1<C4`0YJFU09BDU00g=cL0:BTY05ADE01f
MWH0GemO09RHV01hN7P09bLW05UIF@2VYZH0L71`7?ooool0?01OGel0L71`05MGE`13@d<0FUYJ04I6
AP1[Jf/0ADE5075aL@1>CTh0AdM70861P@1jNWX0K6a/06EUI@1dM7@0CTi>075aL@14A4@0Cdm?05=C
D`0M7Ad0=cLg04a<C012@T80D51@04i>CP19BDT0Hf=S06UYJ@1UIFD0KVi^04E5A@1GEeL0GemO051@
D01CDe<0HF5Q04e=C@1QHF40?clo04U9B@1;Bd/0D51@04U9B@11@D40@T9204i>CP0m?Cd0=cLg05eM
G@0h>3P0A4A40451@@1HF5P09bLW05IFEP19BDT0AdM705=CD`80<c<c02T0DU9B05=CD`0k>c/0Hf=S
071`L01MGEd0MGEe0:FUY@10@400CDe=069RHP1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:
04Q8B00n?Sh0=3@d03lo?`16ATH0A4A40410@01OGel0>3Ph04m?C`0^;Rh0?Cdm03/k>`0`<300EUIF
01dM7@1FEUH09BDU04Q8B019BDT0CTi>05=CD`0205IFEP1E04=3@`0k>c/0>CTi05MGE`15ADD0a<C4
07]kN`1fMWH0ADE505IFEP0U9BD0L71`03Xj>P0V9RH0I6AT03/k>`1@D500N7Qh07alO01?Cdl0De=C
03De=@1GEeL0ADE508n?S`1`L700J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10@400EeMG
03Hf=P1XJ6P0:b/[051@D012@T80Cdm?04];B`1UIFD0De=C05UIF@2VYZH0I6AT04];B`0];Bd0CTi>
04E5A@1OGel0RXZ:055AD@1dM7@0QXJ602PX:02_[jl0VYZJ05ADE01JFUX0<C4a06UYJ@13@d<0`<30
075aL@31`L40@41004e=C@1QHF40G5aL0451@@1CDe<0HV9R06MWI`1UIFD0EUIF038b<P1@D5007AdM
0:2PX024Q8@0I6AT04=3@`0204a<C00[03/k>`1lO7`0F5QH03dm?@1=CDd0?clo05eMG@1:BTX0@d=3
034a<@1LG5`0CTi>03dm?@1OGel0?Shn05YJFP1UIFD0DE5A04I6AP1=CDd0?3`l04];B`1CDe<08B4Q
02d];@0i>CT0E5AD04m?C`1DE5@0C4a<05mOG`1TI6@0=SHf02l_;`1UIFD0BDU903Hf=P1EEED0Jf][
030`<01kNg/0@41003Ti>@020492@P0<055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5
04e=C@1RHV80Bd];0P1OGel04015ADD0F5QH05mOG`0l?3`0LW9b04U9B@1/K6`0?Shn04m?C`18B4P0
De=C04E5A@1WIfL0R8R806UYJ@1XJ6P205aLG00E069RHP36a/H0G5aL03Ti>@1WIfL0=3@d07QhN01N
GUh0IFEU04Y:BP1hN7P0GUiN05QHF01NGUh0E5AD04e=C@1GEeL0F5QH07=cL`1NGUh0Jf][017ooooo
000?ooooo`1`08F5Q@23Ph<0X:2P04Q8B01WIfL0LW9b0;Vi^@19BDT0=3@d05MGE`1gMgL0Q8B409^K
V`0W9bL0;Rh^07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S07IfMP0L71`0DE5A09^K
V`1eMGD0Hf=S05mOG`0Q8B40?clo06IVIP15ADD0CDe=051@D00R8R80GUiN05mOG`23Ph<0@41004Q8
B013@d<0CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2OWil0Hf=S04Q8B00`<300IVIV0;:b
/P18B4P0:2PX04Y:BP1JFUX0DU9B09FEU@0U9BD06a/K03/k>`1JFUX0A4A40:ZZZP2DU9@08b<S03<c
<`1VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1XJ6P0IVIV07UiN@1=CDd08b<S0451@@1XJ6P0De=C07Ui
N@1mOGd06a/K02DU9@1EEED0F5QH0:j^[P0j>SX06ATI05IFEP1oOgl0A4A405QHF01OGel0;Bd]03Ph
>01MGEd0C4a<07YjNP1aLG40>CTi038b<P1mOGd0IFEU055AD@80;Rh^0;00>CTi08V9R@1IFET0@T92
069RHP0U9BD0A4A40:FUY@1BDU80C4a<05ADE00V9RH0>SXj05UIF@1nOWh0<C4a0410@00b<S80>3Ph
06ATI02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q01bLW80;Rh^04a<C01NGUh0Fe]K0;2`/02;Rh/09BDU
03/k>`1JFUX0MGEe0=3@d01<C4`0:RXZ03Hf=P1CDe<0FUYJ09ZJVP2b/[80=3@d0492@P1cLg<0J6QX
09jNWP2b/[80;bl_0492@P1ZJVX0IFEU096AT@2l_;`0=cLg05=CD`25QHD0O7al05ADE02][Jd0G5aL
05QHF02ZZZX0MgMg06QXJ02?Shl0>SXj03@d=028R8P0X:2P0492@P1LG5`0>CTi04E5A@1`L700/[:b
055AD@1NGUh07alO02l_;`1gMgL0QXJ604M7A`10@400=cLg055AD@2HV9P0De=C03/k>`1NGUh0Cdm?
09fMW@1dM7@0AdM706][J`0Z:RX0D51@0:NWY`2=SHd0ATI605]KF`10@400TI6A0;2`/014A4@0>c/k
05eMG@16ATH0H61P08>3P`0d=3@0D51@06e]K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP28R8P0];Bd
03Xj>P0g=cL0K6a/0::RXP1iNGT0d=3@0:FUY@0a<C40?3`l08>3P`1eMGD0U9BD0;>c/`0k>c/0?Shn
04e=C@1]KFd0I6AT09jNWP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a07QhN01dM7@0IVIV
06YZJP0O7al0:RXZ08>3P`2RXZ80EeMG08Z:RP19BDT0<30`04U9B@25QHD0Hf=S05EEE@1`L700:BTY
03lo?`13@d<0LW9b04M7A`25QHD0AdM704];Bacooooo04P0LG5a07YjNP1^KVh0EeMG06i^KP1BDU80
JVYZ05aLG01JFUX0F5QH06MWI`14A4@0@d=3061PH01nOWh0[Zj^06i^KP1`L700Cdm?05=CD`1EEED0
9RHV03dm?@0b<S80DU9B05IFEP1HF5P0M7Ad08:2PP2=SHd0JVYZ07QhN019BDT0Hf=S06i^KP1OGel0
EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ05ADE011@D40CDe=05]KF`14A4@0EEEE04Q8B01bLW80
ADE505MGE`0o?cl0Cdm?02LW9`0o?cl0>CTi02`/;01PH600=SHf04A4A01OGel0BDU905eMG@1TI6@0
GemO055AD@2EUID0XZ:R02`/;00i>CT205IFEP0R05]KF`0h>3P0IVIV03Hf=P0c<c<0Kfm_04U9B@11
@D40AdM702@T900f=SH0BDU904E5A@0n?Sh0C4a<02XZ:P0o?cl0>c/k03De=@0h>3P0?Cdm04a<C00]
;Bd0C4a<02TY:@15ADD0@T9203De=@13@d<0DU9B04M7A`0m?Cd0ADE503hn?P80FEUI0:X0TI6A05UI
F@1NGUh0CTi>05]KF`13@d<0AdM703Xj>P17AdL0MGEe05QHF01LG5`0DE5A06i^KP1PH600E5AD05aL
G01eMGD0Fe]K09^KV`2XZ:P0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0Kfm_04M7
A`0i>CT0>3Ph05]KF`0l?3`0C4a<04A4A01DE5@0Jf][04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[
:`14A4@0DE5A04Y:BP2/[:`0V9RH03hn?P2g]kL0alO7051@D01YJFT0DU9B092@T01JFUX0YZJV06EU
I@1LG5`0DU9B07AdM01_Kfl0G5aL06a/K01`L700RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0@D510:BT
Y01bLW80JFUY04];B`23Ph<0E5AD04E5A@1DE5@0AdM703Lg=`1:BTX0ADE506EUI@0m?Cd0BDU903De
=@1;Bd/0A4A405EEE@1eMGD0DE5A071`L01lO7`0GemO03lo?`1>CTh0EUIF03lo?`1EEED0A4A404E5
A@1=CDd0DU9B05]KF`0d=3@0G5aL04I6AP1NGUh0?clo03<c<`1EEED0JFUY03@d=01@D500IFEU02DU
9@2>SXh0@D5104i>CP1@D500GemO04I6AP0b<S80>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5103hn
?P2IVIT0GemO03<c<`10@40071`L05UIF@1JFUX07alO05]KF`0m?Cd0Q8B405ADE01KFe/0AdM704e=
C@0a<C40QXJ608N7Q`19BDT0AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0Bd];05eM
G@1SHf<0<C4a04Y:BP80ADE500P0K6a/071`L01nOWh0DE5A05MGE`1ADE40DU9B071`L17ooooo000?
ooooo`0O06e]K@1BDU80Kfm_05iNGP1LG5`0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`
L700De=C02l_;`0j>SX0Cdm?051@D00T92@0@D5104m?C`16ATH0I6AT07=cL`0R8R80?Cdm04Q8B01X
J6P0NGUi096AT@0202HV9P100410@01_Kfl0M7Ad08:2PP0I6AT08b<S04=3@`1FEUH0D51@075aL@1?
Cdl0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0O7al08f=S@0c<c<09bLW07QhN020
P800De=C08N7Q`1TI6@0@T9207QhN01FEUH0DU9B065QH@0^;Rh0;Bd]05EEE@1mOGd0Kfm_05UIF@0E
5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP1dM7@0;2`/06MWI`0W9bL0:b/[04U9B@2?
Shl0?Cdm03Xj>P0l?3`0?Cdm06QXJ01@D50071`L03Lg=`80;Bd]0;l0KFe]08V9R@0a<C40?Cdm03Xj
>P18B4P0UIFE09JFUP0d=3@0>SXj05IFEP15ADD0P82004E5A@0Z:RX0CTi>05YJFP1KFe/0Rh^;09ZJ
VP0V9RH0ADE507=cL`1CDe<0Ti>C0820P00L71`0;Rh^05UIF@2IVIT0HF5Q09bLW00_;bl0?Shn05AD
E01cLg<0O7al0=kNgP30`<00C4a<03hn?P1iNGT0Q8B40;Jf]P0f=SH0EUIF07IfMP2>SXh0FEUI08Z:
RP1@D500FEUI0;:b/P2`/;00Ng]k0820P01ADE40?3`l07=cL`2ATI40Hf=S06a/K01EEED0;Bd]05aL
G02g]kL0NGUi05ADE02@T900@T9204a<C02n_[h0Vi^K06EUI@2IVIT0>c/k061PH02[Zj/0QhN705iN
GP2KVi/0C4a<06ATI02QXJ40Bd];02l_;`1EEED0GEeM05YJFP1jNWX092@T02d];@1OGel0NWYj06][
J`2[Zj/0E5AD02LW9`1;Bd/0Ogmo0:j^[P1_Kfl09bLW06IVIP2JVYX0HV9R08V9R@2KVi/0<S8b08>3
P`1bLW80W9bL09ZJVP0N7Qh0=SHf05eMG@1TI6@0HV9R05mOG`0Q8B40C4a<0:VYZ@2>SXh0[Jf]08^;
R`0b<S80ATI607=cL`1WIfL0JVYZ02LW9`1;Bd/0RHV907YjNP13@d<0PX:204e=C@0e=CD0Rh^;061P
H01DE5@0FEUI0410@00n?Sh0@41009JFUP1NGUh0IfMW03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IF
EP0c<c<0;Bd]075aL@0m?Cd0CTi>04];B`0/;2`0BDU9075aL@2PX:00@d=303lo?`0k>c/0QHF50;2`
/00];Bd06a/K03Hf=P1FEUH0G5aL092@T01SHf<0:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d]
;@0k>c/0F5QH05IFEP2/[:`0HF5Q03/k>`0Looooo`80Ogmo00/0F5QH04Q8B01SHf<0IfMW07YjNP11
@D40MgMg071`L01dM7@0D51@04m?C`0207QhN01J05EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l
?3`0>SXj03Lg=`1=CDd0C4a<04E5A@1PH600De=C055AD@1IFET0EUIF05eMG@1CDe<0E5AD065QH@1G
EeL0D51@055AD@0k>c/0DE5A05YJFP1TI6@0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25
QHD0@T9206IVIP0];Bd0FEUI04A4A00d=3@0JVYZ03hn?P1kNg/0GUiN03`l?00h>3P0F5QH05EEE@1;
Bd/0FEUI06][J`0f=SH0BDU906QXJ01NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0?clo04E5A@1F
EUH0=3@d03Ti>@14A4@0GEeM03Ti>@1CDe<0>3Ph06=SH`0c<c<0<S8b04m?C`0k>c/0GUiN03dm?@1N
GUh0;Rh^04Y:BP15ADD0BTY:05eMG@1YJFT0EUIF0P1JFUX05019BDT0Kfm_079bLP2j^[X0LW9b055A
D@0l?3`0BTY:028R8P1ZJVX09bLW02d];@1IFET0>c/k05IFEP1PH600DU9B055AD@1HF5P0CTi>0P1W
IfL0X@2?Shl0W9bL07]kN`1oOgl0QhN704E5A@2<S8`0L71`09>CT`2HV9P08b<S06=SH`0n?Sh0DU9B
05IFEP1SHf<0D51@07QhN01KFe/0Jf][04a<C00h>3P0U9BD03Hf=P1KFe/0<C4a05aLG01:BTX0JVYZ
08R8R01;Bd/0FEUI05eMG@0e=CD0Shn?075aL@0n?Sh0E5AD02XZ:P1PH600?clo09FEU@1<C4`0QXJ6
04I6AP1GEeL0C4a<04M7A`0h>3P0HV9R09bLW01UIFD0?Shn03Lg=`10@400I6AT020P8023Ph<0OWin
07=cL`0k>c/0E5AD05MGE`0g=cL0GemO038b<P1=CDd0Vi^K02h^;P1>CTh0=CDe06][J`18B4P0IFEU
03lo?`0g=cL0A4A4034a<@1JFUX0KFe]04U9B@1HF5P0D51@02d];@1YJFT0WinO02PX:00c<c<0?clo
05IFEP1KFe/0@D5104=3@`1:BTX0G5aL02PX:00a<C40GUiN03lo?`0b<S80IfMW075aL@0Z:RX0F5QH
02PX:00b<S80<c<c03Hf=P14A4@0<S8b02@T900^;Rh0=CDe03Lg=`0Q8B40CDe=04=3@`0i>CT0D51@
0492@P13@d<0A4A402PX:02<S8`0QhN703Lg=`1gMgL0;Rh^04e=C@0a<C40DE5A04];B`1GEeL0=cLg
04a<C01:BTX0FUYJ03Lg=`22PX80RXZ:05]KF`1UIFD0EUIF051@D01/K6`0G5aL05=CD`1MGEd0LW9b
059BDP1FEUH0AdM704a<C01IFET0Kfm_06=SH`1?Cdl0I6AT05ADE01EEED0N7Qh017ooooo000?oooo
o`260:^[Z`1SHf<0Jf][065QH@2:RXX0?clo04a<C01EEED0J6QX0:^[Z`0d=3@0@T9205MGE`1ZJVX0
R8R803/k>`0[:b/0HV9R06YZJP1TI6@0Vi^K0:ZZZP0I6AT0BTY:079bLP1OGel0QXJ608F5Q@0V9RH0
@D5107UiN@1eMGD0EEEE07=cL`0K6a/0DU9B0820P01CDe<0=CDe08:2PP0^;Rh0:BTY04A4A01aLG40
>CTi05MGE`0[:b/09BDU05=CD`1hN7P0?clo05YJFP1NGUh0;bl_071`L014A4@0>c/k05eMG@0j>SX0
>CTi05eMG@1TI6@0?clo07QhN00`<300KFe]09FEU@0l?3`08b<S0492@P14A4@0=cLg09ZJVP0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@1BDU80GUiN08:2PP0f=SH0<S8b02LW9`1=CDd0
HV9R09jNWP0l?3`0ATI605ADE01<C4`0FEUI09FEU@1LG5`0410@020P8014A4@0GEeM07EeM@0K6a/0
92@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03dm?@1MGEd0?Cdm05mOG`1VIVH0:BTY04a<C02CTi<0
M7Ad05MGE`1=CDd0>CTi0492@P2ATI40HV9R03Lg=`1dM7@0@d=303Lg=`2BTY80UiNG061PH02BTY82
03/k>`0:08F5Q@2UYJD0GUiN055AD@19BDT0DU9B08N7Q`1UIFD09RHV06ATI080CTi>08T0JFUY08>3
P`0f=SH0DU9B04M7A`2ATI40b<S804Y:BP0Y:BT0E5AD07IfMP1lO7`0c/k>05QHF00/;2`0>c/k07mo
O`2FUYH0QHF50=3@d01;Bd/0ADE509NGU`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0UIFE0:ZZ
ZP0n?Sh0NGUi0:f][@2FUYH0NGUi0;bl_014A4@0>SXj092@T01hN7P0X:2P0:6QX@16ATH0?Shn05QH
F020P800I6AT09VIV@1>CTh0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1IFET0JVYZ02/[
:`14A4@0T92@05eMG@11@D40GEeM02@T901NGUh0T92@04=3@`1]KFd0LG5a04=3@`1dM7@0ZJVY05EE
E@1`L700EUIF065QH@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD03`l?01LG5`0IVIV07Ee
M@2b/[80I6AT03lo?`1DE5@0MWIf07inOP2EUID0GEeM02@T9017AdL0Lg=c07EeM@1HF5P0^;Rh05YJ
FP0Y:BT0MgMg04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0Q8B403<c<`10@400HV9R06EU
I@18B4P0GemO03`l?018B4P0EEEE06][J`14A4@0LW9b07AdM00_;bl0ATI607IfMP1`L700Bd];071`
L00203Hf=P0308>3P`31`L40G5aL01cooooo00/0R8R808J6QP1GEeL0B4Q806ATI01EEED0I6AT04U9
B@1XJ6P0ATI605eMG@0205ADE00X071`L01hN7P0GUiN06ATI02?Shl0Fe]K071`L01IFET0:2PX04U9
B@0i>CT0@d=3055AD@16ATH0BTY:05iNGP1GEeL0G5aL079bLP15ADD0EEEE069RHP1>CTh0F5QH05mO
G`1XJ6P0MGEe065QH@1GEeL0EEEE04e=C@11@D40AdM703<c<`0n?Sh0=SHf034a<@1PH600=cLg051@
D080@D5100l0?3`l06e]K@13@d<0@41005ADE00];Bd0ADE504e=C@1@D500C4a<05eMG@1@D500IVIV
09>CT`2GUiL00P1:BTX0IP1kNg/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400BTY:
04U9B@0m?Cd0=CDe0451@@0j>SX0BDU902LW9`12@T80?Cdm02/[:`0e=CD0ADE505MGE`0[:b/0=3@d
02XZ:P14A4@0@T9205QHF01ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@20P800LG5a
05ADE016ATH0?Shn06=SH`0g=cL0<S8b059BDP19BDT0ATI605iNGP1^KVh0Fe]K06UYJ@1EEED0JVYZ
06UYJ@1[Jf/0O7al05IFEP2BTY80RXZ:05aLG02FUYH0HV9R09NGU`2c/k<0ADE5069RHP0i>CT0QHF5
03/k>`1ADE40=cLg04a<C00[:b/0?Cdm03`l?00d=3@0Shn?04I6AP23Ph<0:2PX03dm?@0Q8B40?Cdm
04a<C01GEeL0LG5a06][J`0^;Rh0emOG0;Rh^00^;Rh0D51@02d];@2QXJ40M7Ad06EUI@1QHF40Q8B4
0451@@80De=C0180<30`05]KF`1RHV80Kfm_06QXJ01GEeL0CTi>04];B`1QHF40D51@09BDU029RHT0
FEUI0492@P0o?cl0@d=304A4A01nOWh203Ti>@0^05iNGP0e=CD0HF5Q02d];@0n?Sh0=CDe04e=C@0l
?3`0EEEE06i^KP0l?3`0K6a/08Z:RP1>CTh0ATI6059BDP0e=CD0<30`03Xj>P0Y:BT0B4Q803Xj>P0c
<c<0Cdm?0410@01ADE40ADE504e=C@0f=SH0:b/[04E5A@17AdL0:BTY04Y:BP1TI6@0;Bd]069RHP0d
=3@0@T920410@01<C4`0>CTi02/[:`0J6QX0=cLg038b<P80@41002h0IFEU0492@P10@400H61P04a<
C01HF5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0A4A4051@D00f=SH0BDU903Xj>P1=CDd09BDU06m_
K`16ATH0DU9B05QHF02RXZ80GEeM079bLP2=SHd0AdM704a<C01RHV80>3Ph05=CD`1MGEd0GUiN05YJ
FP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1CDe<0HF5Q061PH01FEUH0N7Qh4Oooool000oooooo0<<0
/k>c0:JVYP2NWYh0DU9B06=SH`1FEUH0Ph>303@d=019BDT0Ph>307EeM@1IFET0Lg=c02LW9`1NGUh0
QXJ603hn?P1eMGD0Fe]K038b<P1JFUX0Lg=c06IVIP10@400D51@04U9B@1VIVH0RXZ:03<c<`0b<S80
@D51051@D01>CTh0KVi^01@D500X:2P0IFEU059BDP1DE5@0][Jf04U9B@0M7Ad0<C4a05iNGP1LG5`0
U9BD02LW9`0k>c/0>SXj05IFEP26QXH0V9RH09^KV`0U9BD0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0
B4Q806i^KP1cLg<0UIFE03dm?@0k>c/0BDU905eMG@1NGUh0WIfM04A4A00W9bL0Hf=S07EeM@1fMWH0
Shn?038b<P0X:2P0Cdm?07]kN`1GEeL0OGem04=3@`0n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0
HV9R06MWI`16ATH0Hf=S02HV9P0U9BD0HF5Q08R8R00j>SX0FUYJ03lo?`0c<c<0PH6104m?C`0S8b<0
?Shn03Lg=`1:BTX0IfMW07emO@0l?3`0ADE503dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0
NWYj05mOG`0Y:BT0>3Ph05ADE01QHF40E5AD09BDU018B4P0;bl_071`L01oOgl0PH610<C4a00i>CT0
>3Ph05aLG01ZJVX0LG5a09BDU01PH600=CDe07]kN`2>SXh0K6a/0:NWY`16ATH09RHV0451@@1LG5`0
PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@07=cL`2PX:00Bd];06YZJP1jNWX0
@T92071`L02SXj<0/k>c08J6QP1VIVH0BDU905=CD`2QXJ40KFe]03Ti>@1aLG40@d=306EUI@2LW9`0
D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01;Bd/0?3`l0820P030`<00JFUY02l_;`1?Cdl0
0P11@D40G@2^[Zh0LW9b04A4A01?Cdl0>c/k07alO02YZJT0;Rh^03dm?@1XJ6P0JVYZ0:^[Z`0e=CD0
D51@06YZJP1CDe<0Kfm_075aL@0M7Ad06a/K07=cL`1SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0
S8b<07EeM@0f=SH0YjNW04E5A@1jNWX0TI6A04U9B@14A4@0OGem0<?3``1mOGd0V9RH04];B`1KFe/0
Ogmo0<71`@1UIFD0[Jf]065QH@0f=SH0P8200;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0
AdM706IVIP15ADD0E5AD07moO`18B4P0@D5106IVIP0h>3P0>SXj08Z:RP0c<c<0HF5Q07=cL`0g=cL0
AdM708j>SP1MGEd08b<S04U9B@1EEED0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0
Jf][01lO7`1?Cdl0O7al06a/K00Looooo`0?07UiN@1`L700FEUI059BDP1XJ6P0EeMG079bLP1>CTh0
Jf][05QHF01eMGD0DU9B055AD@1PH600JVYZ0080J6QX01X0Jf][04=3@`1KFe/0Cdm?01@D500m?Cd0
>SXj03Ph>015ADD0BTY:05=CD`1UIFD0De=C04E5A@1SHf<0Cdm?05UIF@1KFe/0Lg=c07IfMP1PH600
@41006QXJ017AdL0B4Q804M7A`80De=C05<0Kfm_04E5A@1;Bd/0@41003dm?@1jNWX0Bd];07=cL`13
@d<0GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP1@D500AdM704E5A@1CDe<0I6AT04=3@`2K
Vi/0W9bL04E5A@1KFe/0CTi>051@D01UIFD0BDU907QhN00j>SX0=CDe05YJFP15ADD0BDU904];B`0]
;Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM702`/;00S8b<0@D5104e=C@1:BTX0:2PX05ADE00M
7Ad0?3`l03De=@15ADD0@41003<c<`13@d<0:BTY05YJFP0e=CD0GemO05ADE02TY:@0Fe]K06IVIP1[
Jf/0HV9R03De=@1?Cdl0>c/k03Ph>01QHF40CTi>05=CD`1IFET0CDe=065QH@1PH600KVi^08>3P`02
06m_K`0b08V9R@22PX80`L710:^[Z`1DE5@0RHV9075aL@2IVIT0[jn_03dm?@1QHF40;bl_04];B`0Z
:RX0CDe=03dm?@1UIFD0>CTi04a<C01@D500Cdm?092@T019BDT0>SXj03<c<`1?Cdl0;Bd]07YjNP2L
W9`0DE5A07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU04A4A01ADE40>3Ph061PH00a
<C40EUIF05mOG`0d=3@0@d=304a<C01oOgl205mOG`1/0492@P1BDU80G5aL01hN7P3?cll0K6a/06UY
J@1>CTh0KVi^069RHP0n?Sh0BDU902/[:`0f=SH0HF5Q02<S8`12@T809RHV05YJFP13@d<0F5QH04i>
CP1@D500MWIf05UIF@1/K6`0LW9b03@d=018B4P0BTY:03/k>`0d=3@0FUYJ02DU9@0k>c/0>3Ph03@d
=01EEED09bLW04M7A`12@T80DE5A02l_;`0W9bL0Bd];04i>CP0X:2P0L71`06ATI00K6a/0MGEe02<S
8`14A4@0;bl_03@d=00^;Rh0=SHf02/[:`1?Cdl0B4Q8055AD@13@d<0ATI604a<C014A4@0Ph>304M7
A`0o?cl0?Shn04A4A01RHV80EEEE055AD@1iNGT0Bd];06a/K00i>CT0B4Q804=3@`1DE5@030`<06EU
I@1BDU80KFe]04e=C@2VYZH0PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ04];B`1JFUX0GUiN04m?
C`1eMGD0Cdm?05MGE`1ADE40Jf][07moO`1>CTh0LW9b05IFEP1BDU80N7Qh4Oooool000oooooo06d0
IFEU07=cL`2ZZZX0K6a/06i^KP1TI6@0SHf=069RHP1IFET0Jf][0410@01IFET0QhN705aLG01=CDd0
=cLg0492@P1cLg<0MWIf03hn?P1<C4`0HF5Q04E5A@1DE5@0Q8B402l_;`1<C4`0E5AD05YJFP22PX80
QHF503Xj>P18B4P0IFEU04Y:BP1[Jf/0K6a/02TY:@0];Bd0G5aL065QH@16ATH0LG5a05=CD`0j>SX0
FUYJ04Q8B01<C4`0MgMg038b<P0/;2`0Cdm?05iNGP1^KVh0NGUi02@T9010@400K6a/07alO01<C4`0
V9RH02d];@0g=cL0LG5a04e=C@1DE5@0Ogmo03Xj>P0f=SH0IFEU07moO`0h>3P0EUIF02LW9`14A4@0
OGem06][J`16ATH0HV9R038b<P0m?Cd0PH6107EeM@0f=SH0IFEU03lo?`1?Cdl0Ogmo07]kN`0^;Rh0
>c/k03Ti>@1WIfL0TI6A04];B`0W9bL0AdM704I6AP0g=cL0IfMW09FEU@0k>c/0GemO05IFEP1;Bd/0
P82005iNGP0V9RH0ADE50080FEUI0:40J6QX03hn?P0`<300DE5A07MgM`1;Bd/0BDU908B4Q00b<S80
>c/k07AdM01@D500LW9b07inOP0S8b<0<30`061PH02>SXh0@41007UiN@0Y:BT0@d=307AdM02?Shl0
C4a<09bLW01>CTh0<C4a06][J`1UIFD0H61P06UYJ@0[:b/0BDU908F5Q@2/[:`0De=C06UYJ@1GEeL0
De=C08F5Q@1WIfL0De=C079bLP0l?3`0>SXj06EUI@1eMGD0H61P079bLP1DE5@0DE5A08J6QP20P800
@D51061PH01`L700HF5Q07]kN`2UYJD0CDe=05YJFP2@T900NWYj05eMG@2LW9`0I6AT05iNGP1oOgl0
F5QH06QXJ02HV9P0F5QH03`l?022PX80O7al04Y:BP1oOgl0;Rh^03Lg=`1TI6@0GEeM05UIF@2RXZ80
EEEE02l_;`1EEED0Ogmo09jNWP1MGEd07alO03lo?`22PX80IFEU06i^KP2?Shl0>SXj05QHF01?Cdl0
JFUY08V9R@0^;Rh0?Shn075aL@1@D500KVi^06YZJP0[:b/0Ogmo08J6QP1IFET0YJFU05MGE`0e=CD0
Jf][09>CT`1YJFT0Hf=S03lo?`1MGEd0W9bL079bLP1UIFD0X:2P06=SH`1BDU80UYJF05]KF`1WIfL0
MgMg04Q8B016ATH0TY:B0:b/[01RHV80IFEU04a<C016ATH0YJFU0:JVYP17AdL0BDU907AdM01KFe/0
CTi>09VIV@1BDU80G5aL05mOG`0n?Sh0IVIV0::RXP1`L700>c/k075aL@1FEUH0IfMW08^;R`0l?3`0
>CTi05=CD`0205EEE@0@06ATI01MGEd0:RXZ0410@01kNg/0Rh^;05mOG`2`/;00J6QX03De=@0o?cl0
IVIV059BDP2FUYH0EeMG03dm?Acooooo09@0RHV907inOP1IFET0C4a<05eMG@1ADE40HV9R0410@01e
MGD0GemO06a/K01;Bd/0D51@07MgM`1iNGT0JVYZ07AdM01]KFd0F5QH06ATI01IFET0>c/k055AD@16
ATH0?clo05ADE018B4P0?3`l05UIF@1ZJVX0IFEU06][J`0o?cl0GUiN06=SH`1<C4`0EUIF05aLG01T
I6@0IVIV04U9B@1GEeL0Bd];04e=C@0k>c/0B4Q802TY:@17AdL092@T04U9B@1MGEd0C4a<06a/K00n
?Sh0B4Q803`l?01EEED0;Bd]05=CD`1[Jf/0BTY:04U9B@18B4P0?clo04U9B@1BDU80GemO04=3@`1i
NGT0KVi^02/[:`13@d<0M7Ad07]kN`1NGUh0=cLg061PH00c<c<0@D5106IVIP10@400BDU904=3@`0M
7Ad0@41003`l?012@T80@d=304E5A@0h>3P0CTi>04I6AP0k>c/0A4A405UIF@18B4P0=CDe055AD@0a
<C40Bd];04I6AP1EEED0DU9B04M7A`1GEeL0?Shn05QHF017AdL0JVYZ069RHP28R8P0IFEU05mOG`19
BDT0Cdm?05YJFP1bLW80C4a<05IFEP1;Bd/0B4Q80410@01MGEd0@T9207IfMP1@D500H61P05mOG`22
PX80QHF508R8R01=CDd0O7al07MgM`1BDU80Q8B406i^KP2n_[h0[Zj^03dm?@1bLW80Bd];05UIF@1>
CTh0EEEE0492@P1EEED0>c/k0P1?Cdl0500l?3`0T92@04A4A01SHf<0:BTY05IFEP0R8R80D51@06=S
H`14A4@0IVIV06MWI`0j>SX0/[:b09:BTP0^;Rh0@d=302TY:@2EUID0CTi>0P1DE5@0MP20P800ATI6
05MGE`1EEED0?clo06UYJ@1LG5`0Ogmo04Y:BP1XJ6P0DU9B05ADE01>CTh0=3@d0:ZZZP1?Cdl0LW9b
03Ti>@15ADD0>3Ph04A4A01VIVH0ADE503/k>`1=CDd092@T04a<C011@D40>3Ph0492@P1@D500=3@d
04e=C@1BDU80;Rh^055AD@1YJFT0<30`0410@015ADD09bLW034a<@18B4P05ADE03Hf=P0h>3P0<C4a
04e=C@0k>c/0B4Q804];B`1@D500=CDe03Hf=P1CDe<0AdM7034a<@1CDe<0CDe=02h^;P1NGUh08B4Q
04M7A`0j>SX0@d=302TY:@10@400;Rh^04A4A011@D40B4Q803Lg=`19BDT0@D51034a<@1HF5P0=CDe
059BDP17AdL0=3@d06i^KP1`L700IFEU07]kN`0_;bl0ATI602TY:@1ADE40GemO07UiN@14A4@0M7Ad
03dm?@1`L700B4Q809fMW@1_Kfl0M7Ad09>CT`14A4@0D51@06EUI@0X:2P0@41006MWI`1MGEd0D51@
07=cL`19BDT0B4Q8051@D027QhL0OGem05]KF`1ZJVX0EeMG059BDP1bLW8Aooooo`003oooool0o`28
R8P0IFEU06m_K`1WIfL0R8R80451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0@410079bLP0g
=cL08B4Q04a<C01QHF40Bd];08j>SP2RXZ806a/K03De=@1ADE40GUiN0;jn_P1eMGD0820P059BDP28
R8P0GEeM08V9R@1]KFd07alO05ADE02?Shl0RXZ:06e]K@28R8P0;2`/055AD@1LG5`0JVYZ065QH@1V
IVH06ATI05MGE`2NWYh0R8R804E5A@1FEUH0AdM703/k>`2KVi/0Bd];0410@01lO7`0:b/[02LW9`1Z
JVX0JFUY03lo?`1DE5@0820P04];B`1PH600LG5a03Ph>01GEeL0<30`03lo?`1EEED0=CDe061PH01a
LG40=3@d04E5A@1hN7P0ATI601`L700^;Rh0?Cdm07YjNP2:RXX0<C4a02PX:00l?3`0J6QX05UIF@2B
TY80DE5A034a<@1dM7@0EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX06EUI@2DU9@0;Rh^03/k>`1E
EED0MgMg075aL@2GUiL0?3`l01dM7@1DE5@0^;Rh06=SH`36a/H0Cdm?01/K6`0f=SH0LG5a08b<S01]
KFd0=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40HF5Q06YZJP1BDU80JVYZ04U9B@17
AdL0J6QX0:NWY`1IFET0QhN705MGE`1LG5`0ZJVY051@D01BDU80MgMg051@D00j>SX0MgMg08N7Q`1?
Cdl0Bd];02LW9`1mOGd0TY:B07=cL`0g=cL0EeMG04Q8B01^KVh0Xj>S05]KF`0a<C40CTi>06][J`1U
IFD0Shn?0<C4a01=CDd0=cLg07alO02QXJ40];Bd0<K6aP0g=cL0F5QH096AT@21PH40UiNG0<G5a@0Z
:RX0>3Ph075aL@2MWId0XZ:R0:f][@15ADD0?clo05]KF`2CTi<0WIfM08N7Q`0/;2`0CTi>05QHF02T
Y:@0Lg=c09RHV017AdL0UIFE0:f][@1ADE40VIVI03Xj>P0k>c/0EeMG07moO`1IFET0Fe]K02/[:`1E
EED0RHV906a/K01VIVH0X:2P04];B`12@T80a<C404a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01S
Hf<0Cdm?05UIF@2PX:00>SXj05EEE@1UIFD0AdM703<c<`2=SHd0Y:BT04m?C`2<S8`0C4a<05=CD`2C
Ti<0KVi^03Ph>01]KFd0U9BD05YJFP2JVYX0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`00
8`12@T80FUYJ0820P02BTY80Xj>S03Hf=P0U9BD0HV9R096AT@1YJFT0L71`0410@01JFUX0J6QX059B
DP1aLG40TY:B0410@011@D40K6a/08B4Q01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3
P`0_;bl0?Cdm05mOG`2@T900G5aL01cooooo07D0PH61079bLP1FEUH0BTY:06ATI01ADE40L71`0451
@@22PX80DU9B079bLP1<C4`0Hf=S07inOP1eMGD0Rh^;05eMG@16ATH0CDe=06EUI@20P8007alO05AD
E01EEED0?Cdm059BDP1@D500>SXj05mOG`2;Rh/0JFUY07IfMP0k>c/0KVi^08>3P`1@D500IfMW07Ad
M01hN7P0M7Ad05EEE@1TI6@0CDe=065QH@18B4P0F5QH0451@@1:BTX0>SXj03`l?01=CDd0?Cdm05IF
EP1LG5`0ADE503Hf=P15ADD08b<S04a<C01/K6`0GemO06UYJ@16ATH0C4a<05MGE`1=CDd0@d=304U9
B@2QXJ40MGEe03hn?P1NGUh0JVYZ079bLP1eMGD0G5aL07=cL`0h>3P0?Cdm05MGE`0n?Sh0ADE504=3
@`0O7al0>SXj034a<@0n?Sh0?Cdm03/k>`0V9RH0?clo03Lg=`0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8
B00Z:RX0;bl_02/[:`18B4P0EEEE02PX:014A4@0=3@d04m?C`0d=3@0EeMG05EEE@2;Rh/0EEEE055A
D@1OGel0IFEU065QH@1KFe/00P14A4@0A@1XJ6P0ADE505eMG@1YJFT0KFe]0820P01YJFT0De=C0492
@P27QhL0E5AD07AdM00g=cL0SXj>051@D01PH600QXJ604a<C01oOgl0T92@03`l?01hN7P0ADE504e=
C@10@400B4Q803hn?P1BDU80@41006EUI@1>CTh0HF5Q07inOP1UIFD0F5QH038b<P1hN7P0:RXZ05UI
F@1XJ6P0D51@071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem059BDP1KFe/0@d=306=S
H`0O7al0EUIF05EEE@0b<S80BDU904=3@`28R8P0GemO09nOW`1/K6`0JFUY04m?C`15ADD0dm?C069R
HP0205aLG0040:FUY@1HF5P0>3Ph051@D080@D5105h0EeMG02/[:`16ATH0;bl_08J6QP1IFET0DU9B
020P800_;bl0B4Q802`/;01NGUh0Y:BT04I6AP0e=CD0?Shn02`/;00o?cl0?Shn03Ph>01DE5@0C4a<
03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q806EUI@0i>CT0E5AD05eMG@0o?cl0G5aL
02TY:@1=CDd0A4A405ADE00^;Rh0=CDe03Hf=P1gMgL0?Cdm04Q8B019BDT0IFEU03lo?`1JFUX0WIfM
03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QHF01SHf<0@T9207UiN@12@T80CDe=0410@01<C4`0=SHf
0:ZZZP1VIVH0MWIf03Ti>@1nOWh0KFe]07moO`2k^k/0@d=304e=C@1LG5`0@d=3079bLP1WIfL0F5QH
06QXJ02SXj<0D51@05EEE@1CDe<0N7Qh06=SH`1VIVH0Q8B406IVIP1EEED0MGEe4Oooool000oooooo
06h0Ogmo08j>SP2OWil0C4a<07inOP2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@01>
CTh0WIfM065QH@2XZ:P0=CDe0451@@1BDU80Hf=S06MWI`1CDe<0EeMG04i>CP1_Kfl0WYjN05IFEP1Y
JFT0@41004E5A@0k>c/0JVYZ034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF04A4A01Z
JVX0QhN702d];@0K6a/0>CTi05eMG@1HF5P0N7Qh038b<P0L71`0K6a/06ATI01hN7P0V9RH02DU9@0Q
8B40?Cdm04e=C@1/K6`0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z:RX0E5AD04M7A`2N
WYh0_Kfm04M7A`0f=SH0Cdm?08n?S`1GEeL0UIFE04];B`0f=SH0LG5a07alO01XJ6P0Ogmo04];B`0V
9RH0CTi>06i^KP1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g=cL0N7Qh05MGE`0h>3P0TI6A07inOP0`
<300JFUY038b<P0`<300MWIf096AT@80?3`l0;80:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn
?P1UIFD0C4a<01`L701FEUH0G5aL03dm?@17AdL0SXj>05IFEP0Q8B40@41004U9B@1dM7@0^;Rh04Q8
B00a<C40@d=305iNGP19BDT0VYZJ06MWI`0c<c<0RXZ:06e]K@23Ph<0aLG5055AD@0c<c<0@D510820
P02j^[X0Shn?020P800i>CT0GEeM08>3P`2ATI40^;Rh05ADE018B4P0Q8B409JFUP1dM7@0^;Rh08F5
Q@13@d<0LG5a0;Jf]P2n_[h0V9RH05]KF`1;Bd/0KFe]0:RXZ02@T900NWYj0:FUY@0d=3@0HV9R0;Fe
]@1QHF40I6AT04m?C`0/;2`0BTY:092@T02KVi/0>SXj03`l?00j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`1oOgl0DU9B055AD@1FEUH0RHV908B4Q00S8b<0Bd];0820P01VIVH0YJFU034a
<@0];Bd0HV9R04];B`1UIFD0QhN703@d=00c<c<0KFe]069RHP2h^;P0Fe]K02l_;`1GEeL0K6a/05IF
EP2QXJ40PH6102l_;`1VIVH0HF5Q08F5Q@2LW9`0>SXj04=3@`1DE5@0UYJF09>CT`2UYJD0?3`l06UY
J@1hN7P0Shn?04m?C`30`<00QhN7034a<@1OGel0V9RH07]kN`2][Jd0K6a/034a<@12@T80GUiN07mo
O`1GEeL0IFEU05=CD`1JFUX0MgMg05iNGP1`L700IFEU03De=@0f=SH0K6a/02XZ:P1RHV80Jf][030`
<00e=CD0I6AT06m_K`0`<300B4Q805ADE00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07Yj
NP1<C4`0=cLg059BDP1WIfL0I6AT7?ooool0T02?Shl0Ti>C08j>SP2;Rh/0J6QX04e=C@21PH40IVIV
071`L01FEUH0GemO06YZJP1KFe/0G5aL061PH01IFET0GemO05]KF`19BDT0E5AD05iNGP0];Bd0D51@
03Ph>016ATH0FEUI05EEE@1:BTX0C4a<0820P01UIFD0O7al04Q8B01`L700Lg=c06e]K@2HV9P0K6a/
05ADE01;Bd/0Cdm?05UIF@1[Jf/0HV9R0492@P1?Cdl0@41005EEE@0U9BD0C4a<06IVIP17AdL0GEeM
03/k>`1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04e=C@1?Cdl0<30`04];B`1?Cdl0EeMG
08Z:RP1<C4`0=SHf04];B`1gMgL0O7al06IVIP0e=CD0KVi^05YJFP1TI6@0IfMW04A4A00n?Sh0Bd];
02l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd0?clo030`<01ADE40Kfm_0492@P15ADD0CTi>
02d];@10@400=3@d05=CD`1HF5P0;Rh^05]KF`0f=SH0C4a<03dm?@1SHf<0EUIF06ATI01jNWX0IFEU
04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP1:BTX0FEUI07UiN@0f=SH0M7Ad051@D01cLg<0ADE5
06MWI`1EEED0Q8B404=3@`2YZJT0DE5A051@D01/K6`0LG5a0:b/[02FUYH0>c/k08B4Q015ADD0D51@
04i>CP80C4a<08L0JVYZ03De=@1LG5`0FEUI04e=C@1oOgl0E5AD06UYJ@0c<c<0DE5A05eMG@2CTi<0
NWYj06EUI@2GUiL0KFe]051@D033`l<0YZJV03`l?01GEeL0=SHf08b<S01=CDd0R8R805IFEP1fMWH0
>SXj07alO01_Kfl0B4Q805=CD`1FEUH0QXJ602l_;`1=CDd0EUIF07UiN@19BDT0B4Q807emO@0Y:BT0
H61P02LW9`14A4@0@T9204m?C`1HF5P071`L03Ti>@24Q8@0;Bd]04i>CP0c<c<0A4A403Lg=`1TI6@0
6QXJ04A4A00_;bl0?Shn03Xj>P16ATH0=3@d03<c<`0m?Cd092@T04U9B@1ZJVX0=3@d03hn?P14A4@0
@d=305ADE00b<S80B4Q805YJFP17AdL0=cLg03Hf=P16ATH0>c/k02PX:01VIVH0DU9B06UYJ@2HV9P0
?Cdm04a<C00c<c<0@d=301lO7`0e=CD0CDe=04];B`15ADD0CTi>04A4A01:BTX0G5aL03`l?01EEED0
8b<S04=3@`10@400?clo07inOP1YJFT0@41006e]K@0l?3`0K6a/05eMG@1eMGD0DE5A061PH00N7Qh0
KVi^02d];@1aLG40@D5108>3P`22PX80J6QX08J6QP1HF5P0Jf][06a/K00i>CT0DU9B08F5Q@1hN7P0
GEeM06m_K`17AdL00P1;Bd/01`1GEeL0DU9B05=CD`1DE5@0D51@06=SH`1IFET04Oooool000oooooo
0<D0FEUI07AdM01fMWH0I6AT075aL@1@D500ZJVY05IFEP1ADE40@D5103Hf=P1PH600W9bL04Q8B00k
>c/0Kfm_03`l?021PH40LW9b02TY:@14A4@0Cdm?05UIF@1SHf<0I6AT02TY:@1NGUh0J6QX055AD@20
P800MWIf02PX:011@D40CDe=065QH@3Jf]X0D51@01`L700S8b<0De=C07YjNP1cLg<0^[Zj02d];@15
ADD0O7al05QHF01aLG40FUYJ01lO7`0m?Cd0Kfm_09:BTP1?Cdl0=SHf02l_;`1:BTX0KFe]06ATI01E
EED0Vi^K030`<010@400MWIf03Xj>P1?Cdl0M7Ad03Ti>@1BDU80Ogmo08V9R@0m?Cd0EEEE02/[:`1B
DU80HV9R07EeM@0Y:BT0N7Qh02l_;`0e=CD0D51@05ADE013@d<0?Cdm01lO7`0l?3`0NWYj065QH@0N
7Qh0@41003lo?`1cLg<0Rh^;02`/;00M7Ad0<30`03Xj>P18B4P0Shn?07inOP0];Bd0G5aL08^;R`1/
K6`0UiNG03lo?`0V9RH0?clo07AdM029RHT0QHF502l_;`0f=SH0EeMG08R8R01NGUh0QHF509BDU00S
8b<0CDe=09^KV`1NGUh0PH6108:2PP0R8R80@D510820P01iNGT0Fe]K09>CT`0/;2`0DU9B061PH02D
U9@0KFe]0:JVYP11@D40ADE5079bLP2=SHd0Ti>C07YjNP0c<c<0B4Q808B4Q02k^k/0F5QH07emO@1O
Gel0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=cL`2RXZ80CDe=06][J`19BDT0?3`l07AdM02Q
XJ40=cLg03<c<`1>CTh0?Cdm06=SH`24Q8@0?3`l04=3@`1JFUX0Jf][07alO02n_[h0FUYJ03Ph>01d
M7@0OWin08>3P`2<S8`0:BTY02/[:`1@D500Ng]k08^;R`1jNWX08b<S05aLG01[Jf/0E5AD07YjNP2c
/k<0:b/[04E5A@02096AT@0?0;6a/@1BDU80@d=305eMG@2=SHd0G5aL08N7Q`24Q8@0DE5A09:BTP1c
Lg<0SHf=08^;R`0^;Rh0D51@0080Jf][01T0MgMg04M7A`11@D40Ng]k0:b/[019BDT0FUYJ024Q8@0[
:b/0I6AT07inOP1PH600@d=303/k>`1MGEd0SXj>06e]K@1EEED0MGEe03Xj>P1IFET0_Kfm08R8R01L
G5`0JFUY0080?3`l02l0OWin0:VYZ@11@D40DU9B04Q8B01?Cdl0O7al09BDU00d=3@0A4A405aLG01>
CTh0L71`08f=S@0_;bl0BTY:055AD@1PH600LG5a0;Rh^01IFET0<30`04i>CP1OGel0Shn?0:n_[`0O
7al0B4Q8059BDP1?Cdl0CDe=08:2PP1WIfL0@410069RHP1GEeL0?Shn0861P@2h^;P07AdM04A4A01W
IfL0Bd];05QHF02^[Zh0:RXZ04i>CP0Looooo`1_08n?S`26QXH0DU9B03Xj>P1EEED0DU9B04e=C@0a
<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0O7al06=SH`24Q8@0OWin04U9B@1ZJVX0IVIV02HV9P15
ADD0C4a<0492@P1=CDd0Cdm?09^KV`24Q8@0JVYZ05QHF01LG5`0Hf=S06YZJP1=CDd0<30`065QH@1P
H600Cdm?071`L01UIFD0FEUI04i>CP1CDe<0@41004i>CP0c<c<0?Shn02h^;P16ATH0EUIF055AD@1I
FET0=cLg04];B`1`L700IfMW04];B`1PH600M7Ad04I6AP1XJ6P0BDU906=SH`1>CTh0EEEE04i>CP1E
EED0UiNG06YZJP0n?Sh0BDU909RHV02PX:00Hf=S04];B`1EEED0;Bd]03<c<`1VIVH0ATI604i>CP1:
BTX0=SHf0492@P18B4P0>3Ph04i>CP0j>SX0=cLg0451@@13@d<0>3Ph05ADE01lO7`0@D5103Hf=P11
@D40>c/k04U9B@12@T80>SXj05eMG@1@D500=SHf03lo?`1ADE40BTY:06e]K@1TI6@0QXJ60080EEEE
00H0De=C06ATI02TY:@0K6a/03`l?01UIFD204E5A@2Y04i>CP1_Kfl0@T9206i^KP1ZJVX0EeMG05AD
E02NWYh0MGEe06UYJ@1SHf<0a/K605mOG`1LG5`0Hf=S051@D02JVYX0Rh^;05]KF`29RHT0CDe=06AT
I01XJ6P0?Shn02XZ:P0g=cL0>3Ph0410@00l?3`0IfMW0:>SX`1?Cdl0E5AD05QHF01>CTh0=cLg051@
D01WIfL0Lg=c05EEE@0o?cl0Hf=S0<W9b@20P800>3Ph05QHF00n?Sh0Shn?05=CD`1FEUH0IFEU08F5
Q@0[:b/0B4Q803lo?`0Z:RX0MgMg06EUI@28R8P0:b/[05mOG`1BDU80Q8B404a<C00i>CT0XJ6Q03Ph
>01VIVH0@41005eMG@0a<C40Fe]K07IfMP0R8R809bLW05ADE00m?Cd0HV9R02h^;P1EEED0>c/k04M7
A`0[:b/0F5QH034a<@0c<c<0A4A406QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];03@d
=00`<300?Cdm03<c<`16ATH0AdM704a<C00m?Cd0<c<c0410@01@D500;bl_069RHP1:BTX0;bl_04e=
C@0`<300IFEU0410@00n?Sh061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0@D51069R
HP0S8b<0D51@04I6AP0i>CT0@41006IVIP1<C4`0MWIf03dm?@1<C4`0:b/[04E5A@0n?Sh0G5aL04M7
A`2CTi<0=CDe05YJFP16ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01RHV80Fe]K05IF
EP1_Kfl0V9RH06ATI011@D40D51@06][J`1OGel0EEEE079bLP1>CTh0Bd];05aLG00Aooooo`003ooo
ool0G@23Ph<0HV9R07inOP1[Jf/0S8b<03lo?`1YJFT0IVIV096AT@1^KVh0=SHf069RHP1dM7@0IFEU
08B4Q00a<C40:b/[05EEE@1lO7`0DE5A08>3P`1]KFd08B4Q05eMG@1>CTh0@T920:NWY`1LG5`0<C4a
075aL@1_Kfl0HF5Q06EUI@1`L7007QhN06UYJ@2`/;00De=C06a/K01LG5`0<c<c03Ti>@26QXH0De=C
03Ti>@19BDT0:2PX059BDP1iNGT0?Shn02l_;`1=CDd0Cdm?04i>CP1LG5`07QhN03@d=01;Bd/0AdM7
04E5A@2LW9`0?Shn03De=@1<C4`0@T92065QH@2YZJT0=CDe024Q8@1<C4`0Jf][055AD@1ZJVX0:2PX
03`l?01LG5`0OGem059BDP2f][H0<c<c01hN7P16ATH0GUiN08b<S02][Jd0:BTY02@T901@D500NWYj
05MGE`1/K6`0<30`03dm?@0207UiN@0N06=SH`1kNg/08B4Q02l_;`0m?Cd0G5aL079bLP1QHF408R8R
02PX:01LG5`0Ph>3051@D027QhL0>CTi01dM7@12@T80HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S
055AD@17AdL0<C4a03De=@1RHV80L71`0P0g=cL0X`28R8P0?Cdm04A4A02NWYh0BTY:0410@01JFUX0
=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0KVi^06MWI`2FUYH0;bl_02d];@1GEeL0MGEe05QHF02HV9P0
J6QX03Ti>@1EEED0EeMG06m_K`2MWId0<30`04E5A@1QHF40KFe]08n?S`2b/[80?3`l05EEE@1SHf<0
X:2P08F5Q@29RHT0W9bL01dM7@1IFET0UiNG08F5Q@2?Shl0RXZ:02PX:01CDe<0KVi^08B4Q01_Kfl0
GUiN0410@024Q8@0LW9b069RHP0`<300XZ:R059BDP0[:b/0VIVI055AD@2FUYH0E5AD0451@@1TI6@0
UiNG07inOP1:BTX0^[Zj03hn?P2ATI40ZJVY04A4A01_Kfl0>3Ph02d];@1FEUH0]KFe05ADE01GEeL0
>SXj051@D025QHD0Bd];03dm?@1QHF40BDU909fMW@1_Kfl0<C4a05EEE@1QHF40MGEe092@T00f=SH0
7alO04U9B@1RHV80Lg=c069RHP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500A4A406YZJP1nOWh0
Ph>30;Fe]@0f=SH0Cdm?06IVIP2WYjL0R8R808N7Q`0e=CD0GEeM0861P@2OWil0IVIV06i^KP2ATI40
@T9203Lg=`2RXZ80F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`1QHF40;2`/08B4Q02ZZZX0
FEUI03Ph>01XJ6P0B4Q802/[:`19BDT0KVi^03@d=01TI6@0ADE502h^;P1^KVh0[:b/05mOG`0W9bL0
?clo04E5A@1IFET0^k^k07moO`0l?3`07?ooool0@@1_Kfl0O7al05UIF@1<C4`0EeMG04Q8B01?Cdl0
@D5106i^KP1`L700IVIV04E5A@1HF5P0QXJ608j>SP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZJP0g=cL0
G5aL04m?C`11@D40GemO0451@@13@d<0GUiN05eMG@1_Kfl0IFEU04I6AP1CDe<0LG5a05mOG`1fMWH0
GEeM05]KF`1VIVH0EeMG061PH01EEED0GUiN03Lg=`1ADE40?3`l05IFEP15ADD0B4Q805EEE@0i>CT0
Cdm?0451@@13@d<0=SHf05MGE`15ADD0GemO06m_K`12@T80MGEe05=CD`1VIVH0DE5A0080G5aL04<0
EEEE09fMW@1dM7@0A4A404Y:BP1GEeL0I6AT05QHF01<C4`0J6QX04=3@`18B4P0M7Ad05QHF01QHF40
CTi>03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c02@T900h>3P0>SXj03@d=01JFUX0JVYZ055AD@15ADD0
EUIF04M7A`1@D500ADE505=CD`1ZJVX0@41005aLG00o?cl0CDe=03`l?018B4P0I6AT08f=S@1GEeL0
Jf][05QHF01^KVh0B4Q807AdM013@d<0SXj>075aL@1@D500CDe=09NGU`1dM7@0OWin059BDP1`L700
HV9R08F5Q@1IFET0Vi^K06=SH`1cLg<0GemO0080EeMG02/0:RXZ05]KF`1DE5@0<c<c0861P@1RHV80
JVYZ051@D01QHF40L71`04m?C`0i>CT0ATI606a/K01oOgl0IVIV05ADE01SHf<0=SHf06][J`0O7al0
N7Qh07IfMP1BDU80H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<0@d=304U9B@1;Bd/0
J6QX03Ti>@1HF5P0B4Q804Y:BP1HF5P0BDU90080MGEe06d0IFEU079bLP1>CTh0?Cdm06IVIP2JVYX0
:RXZ04e=C@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`0];Bd0:2PX04U9B@0a<C40
BDU901<C4`1<C4`092@T03Ti>@16ATH0QHF502l_;`1BDU80BDU902PX:010@400?clo01XJ6P0e=CD0
<S8b04Y:BP19BDT0?Shn05UIF@1OGel0@41004Y:BP0a<C40?3`l04Y:BP0h>3P0G5aL03Hf=P18B4P0
J6QX02d];@0c<c<0<C4a0492@P0<30`0<S8b03De=@1BDU80?Cdm04I6AP0o?cl0>CTi04a<C01BDU80
MGEe05ADE015ADD0?Shn04E5A@1FEUH0IFEU07AdM02:RXX0FUYJ06m_K`0`<300?Shn0492@P1GEeL0
D51@0;:b/P13@d<0L71`03hn?P1_Kfl0?clo05YJFP24Q8@0<c<c05=CD`0o?cl092@T04A4A01PH600
CDe=05EEE@1XJ6P0@41004U9B@1GEeL0LW9b05=CD`1KFe/0IFEU05aLG01?Cdl0P820017ooooo000?
ooooo`1S09:BTP2?Shl0M7Ad04m?C`1WIfL0K6a/06YZJP0j>SX0=3@d07EeM@1PH600DE5A06UYJ@0h
>3P0BDU9034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04i>CP1KFe/0WIfM0<G5a@0W
9bL0<30`05=CD`1MGEd0Q8B4055AD@0I6AT0?clo059BDP1>CTh0SHf=0;Fe]@0a<C4092@T05aLG01N
GUh0UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0?clo055AD@0d=3@0JVYZ06MWI`0T
92@0<C4a069RHP1kNg/0I6AT03Lg=`0G5aL0?clo08>3P`1UIFD0G5aL069RHP0E5AD0@410069RHP0g
=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`0b<S80I6AT069RHP1TI6@0@T92061PH00f
=SH0@T9205YJFP13@d<0?clo05=CD`0P8200D51@09VIV@1:BTX07AdM0080:BTY04@0G5aL096AT@0j
>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY0410@00m?Cd0O7al0<W9b@1RHV808b<S04a<C01G
EeL0HV9R09FEU@0a<C406ATI03Hf=P1aLG40NWYj06m_K`35aLD0>SXj03<c<`1jNWX0Rh^;08N7Q`2Y
ZJT0?3`l051@D01HF5P0Lg=c059BDP2/[:`0A4A407UiN@28R8P0Ng]k0820P02EUID0=3@d0451@@2J
VYX0XZ:R0861P@1kNg/08b<S05QHF02=SHd0RXZ:05UIF@2>SXh0C4a<04Y:BP1aLG40I6AT04A4A02P
X:00I6AT04=3@`1TI6@0QhN706i^KP80DE5A0640FUYJ071`L02^[Zh0@D5103`l?01OGel0C4a<08Z:
RP2SXj<0<c<c0492@P1ZJVX0HF5Q04i>CP33`l<0S8b<02<S8`1DE5@0Cdm?0:>SX`1dM7@07QhN04e=
C@27QhL0M7Ad06e]K@3De=@0;2`/05UIF@2?Shl0NGUi0;Vi^@1?Cdl0:b/[04U9B@1nOWh0QXJ608f=
S@0T92@0@41004a<C01aLG40Q8B409JFUP0S8b<0A4A4071`L01/K6`0[jn_03Lg=`0j>SX0UYJF07al
O00m?Cd0MGEe05ADE012@T80Vi^K04A4A01aLG40De=C02l_;`1=CDd0O7al08Z:RP1[Jf/0GemO04M7
A`1MGEd0O7al05EEE@11@D40H61P03Xj>P12@T80N7Qh05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FU
Y@1QHF40;Bd]04m?C`1oOgl0R8R807YjNP0W9bL0=CDe07]kN`1lO7`0FEUI06m_K`0R8R80=CDe0080
FUYJ01@0Fe]K09:BTP0m?Cd0;Bd]03dm?@1cLg<0K6a/0;^k^`1PH600;Rh^04E5A@1dM7@0R8R8059B
DP2SXj<0?Cdm04M7A`1DE5@0Vi^K061PH1cooooo0240QXJ607UiN@1ZJVX0IVIV05aLG01ADE40HF5Q
0451@@1CDe<0BDU905MGE`1;Bd/0ADE505ADE01GEeL0PX:207alO01YJFT0?Shn06ATI01JFUX05aLG
03Lg=`0f=SH0BTY:03hn?P0i>CT0CDe=04Y:BP13@d<0Cdm?04A4A00k>c/00P1>CTh0o`12@T80FEUI
04a<C01=CDd0?Shn04=3@`17AdL0E5AD059BDP0i>CT0ATI602h^;P1=CDd07QhN05QHF01ADE40?Shn
04m?C`0l?3`0Cdm?038b<P1CDe<0ATI606ATI01fMWH0Bd];05MGE`1EEED0G5aL05EEE@1TI6@0LG5a
06EUI@2MWId0Bd];0410@01;Bd/0MWIf08^;R`1XJ6P0GemO06=SH`0o?cl0AdM707IfMP13@d<0E5AD
05UIF@1BDU80B4Q803Ti>@0j>SX0Bd];03Lg=`0b<S80Bd];03Xj>P0[:b/0G5aL08R8R00m?Cd0ATI6
03lo?`0Z:RX0>CTi02h^;P19BDT0HV9R03Ph>01TI6@0?clo03`l?00`<300CDe=06=SH`2c/k<0GEeM
06m_K`2BTY80OGem06IVIP1:BTX0?3`l08J6QP13@d<0HF5Q051@D01fMWH0ADE508n?S`1JFUX0M7Ad
051@D01cLg<0SHf=09fMW@1dM7@0Ti>C04E5A@1RHV80GUiN05eMG@1nOWh0O7al04a<C01GEeL0B4Q8
04Y:BP13@d<0>CTi03/k>`1TI6@0ADE505MGE`1;Bd/0MWIf0:VYZ@1@D500RHV902l_;`17AdL0@d=3
051@D01[Jf/0IfMW07YjNP1CDe<0A4A407inOP1mOGd0ATI605aLG00m?Cd0Lg=c065QH@2;Rh/0Lg=c
07inOP1JFUX0PH6105aLG01=CDd0H61P04M7A`20P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo
0410@01[Jf/0@T9204M7A`0i>CT0Bd];051@D00S8b<0@T9205IFEP0l?3`0FUYJ030`<00o?cl0DE5A
05iNGP0S8b<0DU9B02`/;01ADE40@41005mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]
02PX:00e=CD0C4a<02`/;016ATH0GEeM04Y:BP11@D40A4A404e=C@1CDe<0>CTi08b<S01?Cdl0BTY:
04a<C00i>CT0JVYZ030`<012@T804a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De=@1PH600?Shn
04a<C00K6a/0>c/k04U9B@18B4P0JFUY06a/K00e=CD0I6AT0410@027QhL0B4Q806=SH`1FEUH0FUYJ
05aLG01oOgl0@D5104I6AP0l?3`0QXJ604I6AP1KFe/0HV9R034a<@1OGel0GUiN038b<P1:BTX0Ng]k
065QH@1>CTh0E5AD03@d=01CDe<0>CTi06ATI01ADE40CTi>04I6AP1MGEd0O7al071`L00Aooooo`00
3oooool0o`1ZJVX0PH610:2PX01=CDd0HF5Q08R8R02RXZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0
<C4a04e=C@1:BTX0N7Qh0;:b/P0g=cL0?3`l05]KF`1hN7P0F5QH06m_K`1KFe/0:RXZ08N7Q`2SXj<0
KVi^08B4Q015ADD05ADE0451@@1bLW80E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0
;Rh^04I6AP2KVi/0Fe]K051@D01JFUX09RHV02l_;`1XJ6P0Ti>C04a<C00n?Sh0<30`05]KF`1LG5`0
;Bd]04=3@`1PH600=SHf07=cL`1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`1=CDd0
LG5a08>3P`21PH409bLW024Q8@12@T80F5QH051@D02WYjL0B4Q802TY:@1DE5@0Hf=S06m_K`2JVYX0
<c<c02LW9`1IFET0Hf=S07inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI028R8P1cLg<0
JFUY06ATI01SHf<08B4Q02d];@1<C4`0P820061PH01OGel0<C4a03@d=01RHV80];Bd06=SH`1/K6`0
IfMW02DU9@19BDT0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d=3@0HV9R05]KF`1dM7@0
Y:BT04m?C`0d=3@0F5QH03/k>`1;Bd/0Ogmo06EUI@1GEeL0MGEe0410@02ATI40^k^k04M7A`0k>c/0
De=C069RHP2ZZZX0/K6a02d];@15ADD0D51@06YZJP1^KVh0]kNg08N7Q`13@d<0E5AD0861P@1YJFT0
alO709BDU00];Bd0EUIF06IVIP2>SXh0UIFE09>CT`0T92@0IVIV09VIV@2MWId0S8b<08^;R`11@D40
JFUY0;Bd]01RHV80UIFE08J6QP0^;Rh0@d=307emO@2YZJT0Bd];04U9B@0a<C40LW9b0:f][@1IFET0
GUiN07]kN`0M7Ad0@D510:n_[`1lO7`0NWYj0492@P0c<c<0Cdm?08V9R@0d=3@0KFe]05YJFP16ATH0
UIFE05YJFP13@d<0H61P03Ti>@1ADE40X:2P07alO01GEeL0GUiN05QHF02KVi/0PX:20410@01DE5@0
HV9R03lo?`2=SHd0LW9b03Ti>@1bLW80Bd];08n?S`2LW9`0;2`/034a<@14A4@0IFEU08f=S@2;Rh/0
<c<c05YJFP2>SXh0Ng]k07=cL`2[Zj/0CTi>03@d=01PH600OGem07EeM@2k^k/0L71`02<S8`1IFET0
TY:B0;^k^`008`1mOGd0JFUY03Ph>02KVi/0]KFe07AdM01HF5P0Z:RX03<c<`0n?Sh0Ph>30410@01T
I6@0IFEU030`<019BDT0IVIV07]kN`0_;bl0HV9R04m?C`1;Bd/0E5AD06UYJ@0j>SX0G5aL0820P00e
=CD0ATI604Q8B01?Cdl0:RXZ05EEE@0i>CT0=3@d01cooooo02`0QhN709ZJVP1MGEd0B4Q806MWI`1Z
JVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`24Q8@0Cdm?05ADE01ADE40BTY:05EEE@1;
Bd/09bLW0451@@0a<C40=3@d04I6AP1<C4`0@41005=CD`1cLg<0EEEE069RHP0h>3P0HV9R07=cL`1:
BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03@d=080=SHf0340;2`/04];B`0^;Rh0BDU904Y:
BP1CDe<0ATI60451@@1@D500DE5A04];B`15ADD0Ng]k03Ti>@1;Bd/0FUYJ05=CD`1MGEd0De=C04U9
B@17AdL0I6AT09FEU@0o?cl0B4Q806UYJ@2IVIT0OWin05=CD`16ATH0JVYZ05MGE`1[Jf/0QHF506EU
I@1aLG40G5aL03Hf=P1@D500@T9204Q8B01CDe<0@T92055AD@1BDU80BDU90492@P1TI6@0LW9b0080
B4Q802L0EEEE038b<P1<C4`0?Cdm05MGE`1[Jf/0ATI605mOG`15ADD0A4A403Ti>@1?Cdl0C4a<079b
LP1IFET0GUiN05=CD`26QXH0U9BD07IfMP16ATH0R8R804U9B@0d=3@0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0UiNG07YjNP2ATI40J6QX08:2PP2BTY800P1MGEd07P1[Jf/0Hf=S08:2
PP1=CDd0EUIF04e=C@19BDT0MWIf061PH010@400<30`05aLG02DU9@0UIFE04A4A01CDe<0BDU9059B
DP0Y:BT0Cdm?04M7A`0o?cl0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055AD@80IfMW0680A4A4
05aLG01OGel0<c<c05]KF`1=CDd09RHV065QH@16ATH0QHF50492@P1;Bd/0F5QH07IfMP1UIFD0NGUi
06e]K@1LG5`0O7al02d];@1:BTX0:RXZ06ATI01kNg/08b<S03hn?P1;Bd/09BDU055AD@0/;2`0De=C
02LW9`1:BTX0:b/[05=CD`0l?3`0B4Q804A4A01RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]
04Q8B010@400?Shn04Q8B00n?Sh0@T9205eMG@1DE5@0BDU903<c<`0h>3P0GemO01lO7`1HF5P0;Bd]
03dm?@1GEeL0=SHf03Ph>00T92@0?Cdm030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE5
04A4A01BDU80=3@d05]KF`1:BTX0@d=304i>CP1bLW80KVi^0:2PX00o?cl0FEUI03Ti>@17AdL0IVIV
08B4Q01=CDd0O7al03De=@1RHV80AdM705iNGP80EeMG01@0H61P04Q8B01MGEd0EEEE04a<C01EEED0
GUiN04M7A`1;Bd/0EEEE04E5A@14A4@0Bd];071`L01=CDd0De=C05MGE`1QHF40NWYj05YJFQ7ooooo
000?ooooo`1N05mOG`1eMGD0L71`08J6QP1oOgl0CTi>07AdM01gMgL0G5aL065QH@0g=cL0>SXj075a
L@1/K6`0IfMW02/[:`1?Cdl0JFUY04m?C`0i>CT0NWYj03`l?013@d<0F5QH05=CD`0d=3@0H61P03`l
?01?Cdl0PX:209^KV`0X:2P0=cLg059BDP0k>c/0QXJ6071`L00Y:BT0B4Q80410@013@d<0CTi>0;2`
/00n?Sh092@T04E5A@0m?Cd0UYJF092@T00U9BD0;2`/0410@01MGEd0NGUi08V9R@0J6QX0=cLg06m_
K`1QHF40P8200;Ng]`0`<300Bd];08Z:RP1CDe<0Lg=c07YjNP0g=cL0JFUY07QhN028R8P0L71`05]K
F`0g=cL0EeMG08B4Q029RHT0H61P07QhN00N7Qh0<C4a0451@@1ZJVX0NGUi05YJFP0a<C40=cLg06=S
H`1QHF40<30`04E5A@0a<C40Hf=S08n?S`80=SHf0<80BTY:03@d=018B4P0IVIV03lo?`0b<S80?Shn
05YJFP1eMGD0OGem02`/;00N7Qh09RHV05MGE`1=CDd0RHV902@T900];Bd0<C4a05ADE01>CTh0PX:2
07emO@0T92@0EUIF06QXJ016ATH0QhN7096AT@0c<c<0DU9B08b<S02YZJT0GUiN09ZJVP0g=cL0EUIF
0:>SX`1^KVh0NWYj09JFUP0`<3009bLW06IVIP1jNWX0ZZZZ0:RXZ013@d<0?Shn079bLP2NWYh0LG5a
0:^[Z`17AdL0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0LW9b0:>SX`0d=3@0@d=3
06EUI@2CTi<0DE5A05UIF@1YJFT09RHV05iNGP2PX:00Cdm?069RHP1eMGD0=3@d0861P@25QHD0BTY:
05ADE00n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM01ZJVX08R8R03lo?`1OGel0IVIV
07=cL`2_[jl0;Bd]02XZ:P1>CTh0R8R80=kNgP1lO7`0@4100492@P1PH600Hf=S0;jn_P2EUID0?3`l
05UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^07=cL`17AdL0Ogmo07=cL`23Ph<0_[jn
04m?C`0/;2`0IFEU0;Jf]P1kNg/0I6AT04E5A@1?Cdl0Xj>S079bLP1KFe/0L71`02l_;`1@D500X:2P
05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:0:6QX@1;Bd/0GUiN03/k>`1LG5`0Jf][07moO`0h>3P0;Rh^
0451@@0g=cL0QHF5096AT@0b<S80?Cdm04E5A@16ATH0I6AT0;:b/P1FEUH0<S8b055AD@1OGel0Ph>3
08F5Q@0K6a/0<C4a04I6AP1IFET0DE5A069RHP19BDT0@D5105ADE01PH600C4a<06][J`2ZZZX0:b/[
0451@@1XJ6P0KFe]05YJFP2e]KD0<C4a03hn?Qcooooo03@0Jf][0:>SX`1GEeL0C4a<04e=C@1@D500
F5QH04I6AP1TI6@0CTi>061PH00j>SX0Hf=S06a/K01IFET0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0
=CDe065QH@19BDT0@41005QHF019BDT0=cLg04U9B@1CDe<0M7Ad065QH@0i>CT0CDe=061PH014A4@0
F5QH04i>CP15ADD0C4a<04E5A@0i>CT0?clo04Y:BP1IFET0G5aL02d];@14A4@061PH05UIF@0d=3@0
<c<c0P13@d<0F00];Bd07alO02<S8`19BDT0PH6103hn?P0];Bd0ADE506YZJP1<C4`0AdM705mOG`1T
I6@0IfMW07IfMP1CDe<0LW9b08:2PP1>CTh0I6AT07YjNP1oOgl0GUiN02LW9`0`<300CDe=03lo?`1N
GUh0A4A403dm?@1IFET0=3@d02/[:`1;Bd/0;bl_02XZ:P0/;2`0Hf=S03Ti>@1BDU80Y:BT04=3@`0c
<c<0>3Ph05IFEP1^KVh0B4Q803lo?`21PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1`
L700LG5a08:2PP1cLg<0RXZ:079bLP11@D40TY:B06a/K01TI6@0C4a<061PH01<C4`0Ng]k05=CD`2>
SXh0BDU90;2`/01RHV80[:b/09RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`04M7A`1i
NGT205=CD`110451@@0l?3`0ATI606YZJP1FEUH0BDU908n?S`2NWYh0I6AT07=cL`16ATH0DU9B03hn
?P1_Kfl0Jf][05]KF`1<C4`0?Shn08Z:RP2g]kL0PH6104Q8B01>CTh0@41005UIF@1GEeL0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1WIfL0MWIf079bLP1ADE40DU9B04m?C`1EEED0Ph>3092@
T01KFe/0D51@03/k>`1<C4`0>3Ph06EUI@1RHV80;Bd]05UIF@1;Bd/05QHF04a<C01:BTX0JFUY0410
@01CDe<09BDU06m_K`0c<c<0DE5A06][J`22PX800P0o?cl0:@0g=cL06a/K03lo?`11@D409BDU04];
B`1ADE40@d=3051@D011@D40E5AD06a/K01ADE40EEEE0410@00m?Cd0C4a<02@T901VIVH0:RXZ075a
L@1UIFD0=CDe04M7A`0c<c<0<30`01dM7@14A4@0ATI606a/K017AdL0@T92069RHP14A4@0Bd];059B
DP1NGUh0@d=303Xj>P1CDe<0C4a<0080DE5A00l0G5aL06IVIP1QHF40KFe]04Y:BP0b<S80=SHf05EE
E@1;Bd/0OWin05IFEP1]KFd0=3@d06ATI01;Bd/00P1[Jf/04`1UIFD0JVYZ06ATI01WIfL0EEEE05]K
F`0h>3P0C4a<05YJFP0^;Rh0ATI604M7A`0m?Cd0C4a<05UIF@1SHf<0CDe=05EEE@1PH6004Oooool0
00oooooo0?l0Ph>305eMG@1HF5P0MWIf09JFUP15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj
03<c<`2:RXX061PH02d];@1;Bd/0AdM705MGE`2c/k<0MWIf020P801DE5@0J6QX07MgM`31`L40Cdm?
02@T901LG5`0V9RH06][J`1mOGd0L71`0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo
06m_K`1aLG40?clo02l_;`0Y:BT0IFEU05ADE01BDU80L71`02`/;00j>SX0DE5A03@d=01CDe<0?clo
01dM7@18B4P0GUiN0492@P1TI6@0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj>P0l?3`0Jf][
024Q8@1NGUh0De=C02l_;`1VIVH0/[:b03De=@0R8R80@d=303dm?@28R8P0Y:BT024Q8@0e=CD0=SHf
0451@@1MGEd0^k^k03Hf=P0o?cl0E5AD05mOG`2>SXh0Vi^K01/K6`0b<S80Kfm_07YjNP1cLg<0>3Ph
01lO7`15ADD0Ogmo07AdM01mOGd0Y:BT028R8P0o?cl0NWYj09BDU01KFe/0PH6103Xj>P0W9bL0GemO
075aL@1JFUX0GUiN024Q8@0S8b<0Bd];0820P01KFe/0E5AD07moO`0U9BD0@d=306QXJ015ADD0I6AT
06IVIP0_;bl0CDe=0:RXZ01MGEd0:RXZ03`l?00m?Cd0HV9R06i^KP10@400@d=304i>CP0c<c<0JFUY
096AT@1`L700A4A405QHF015ADD0Zj^[0:RXZ00U9BD0>SXj055AD@1LG5`0O7al0;Bd]00/;2`0B4Q8
06e]K@1kNg/0FEUI0;Vi^@2k^k/0;Rh^05EEE@2KVi/0O7al0;Bd]02VYZH0:RXZ0451@@22PX80Kfm_
0:^[Z`1VIVH0?clo07YjNP27QhL0LG5a06IVIP2JVYX0=3@d05aLG01lO7`0CDe=0:BTY00c<c<0=cLg
075aL@2JVYX0IVIV069RHP1QHF40<c<c0:JVYP2c/k<0EEEE05YJFP0S8b<0C4a<05aLG02YZJT0FUYJ
059BDP0X:2P0Ng]k0;Jf]P1SHf<0L71`07MgM`0V9RH0F5QH0;Jf]P1TI6@0FEUI03lo?`10@400Ng]k
071`L00g=cL0CTi>03dm?@1nOWh0Ph>302TY:@1;Bd/0FEUI05IFEP1ZJVX0YjNW059BDP0k>c/0H61P
055AD@2YZJT0TY:B03Hf=P0l?3`0G5aL0820P01eMGD0XJ6Q02`/;01GEeL0P82009JFUP1XJ6P0RHV9
07moO`0R8R8002<0E5AD09NGU`21PH40Lg=c05IFEP13@d<0HV9R09^KV`2][Jd0O7al06a/K00];Bd0
A4A407YjNP1>CTh0ATI606m_K`0/;2`0:2PX06QXJ01_Kfl0E5AD08b<S01=CDd0:2PX04a<C01LG5`0
Lg=c03Ti>@1gMgL0?3`l03/k>`1XJ6P0Ogmo0451@@0Looooo`2;06UYJ@1OGel0HV9R065QH@1DE5@0
EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@061PH01ZJVX0IVIV0861P@1bLW80FUYJ03`l?01JFUX0
Bd];02d];@0n?Sh0>SXj04=3@`12@T80CTi>04U9B@1UIFD0HF5Q05]KF`1@D500A4A4069RHP1SHf<0
D51@06EUI@1MGEd0C4a<051@D01=CDd0Bd];05=CD`1DE5@0=3@d03lo?`0e=CD0@D5102PX:01>CTh0
CDe=04Q8B011@D40AdM703hn?P0e=CD0<S8b02`/;00o?cl0C4a<05]KF`1JFUX0EeMG05iNGP19BDT0
@41004m?C`21PH40WinO04e=C@0f=SH0?Cdm05aLG01EEED0<S8b02l_;`1<C4`0;bl_03lo?`1^KVh0
@d=305MGE`1JFUX0@41005mOG`11@D40EEEE05ADE01=CDd0@d=304a<C011@D40>c/k061PH01OGel0
@D5104I6AP1GEeL0>SXj04I6AP0h>3P0BDU905=CD`11@D40Cdm?0451@@0k>c/0?3`l04A4A010@400
Bd];055AD@1JFUX0De=C06EUI@29RHT0R8R806QXJ02XZ:P0@D5106=SH`13@d<0IVIV03lo?`1dM7@0
E5AD079bLP1CDe<0WIfM06ATI02:RXX0NWYj0:6QX@1VIVH0QhN707moO`1EEED0NGUi06UYJ@0206a/
K00@04i>CP0m?Cd0A4A404M7A`1OGel0BTY:03Ti>@0j>SX0G5aL07=cL`2FUYH0H61P06EUI@1]KFd0
MWIf03dm?@80KFe]0P1EEED02@1CDe<0L71`05mOG`14A4@0FEUI05mOG`1[Jf/0MWIf07YjNP02065Q
H@1f07=cL`1?Cdl0PH6105UIF@1:BTX0DU9B04Y:BP1YJFT0J6QX0820P01YJFT0IVIV05eMG@1EEED0
VYZJ06m_K`1XJ6P0L71`0861P@1ADE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80C4a<03<c<`12@T80
>CTi04i>CP0f=SH0JVYZ03dm?@1IFET0DE5A075aL@0R8R80FEUI03@d=0061PH0?3`l02h^;P0V9RH0
Bd];04m?C`13@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1?Cdl07QhN05QHF00c<c<0
ATI603De=@0c<c<0A4A402/[:`15ADD07AdM03Lg=`0o?cl0FUYJ059BDP1ADE40JFUY04A4A015ADD0
NWYj06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:04m?C`1lO7`0@T920451@@1:BTX0
Ng]k06IVIP22PX80?Shn05=CD`1FEUH0Fe]K04];B`1GEeL0LG5a04m?C`29RHT0?3`l0451@@1<C4`0
NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0JVYZ05]KF`1HF5P0K6a/06ATI17ooooo
000?ooooo`1W0:NWY`2EUID0IFEU04E5A@2FUYH0SXj>09JFUP0a<C40CTi>071`L019BDT0TI6A07Yj
NP0T92@0EUIF05]KF`16ATH0C4a<02@T900X:2P0JFUY0:BTY01LG5`0MGEe03hn?P1?Cdl0Q8B409NG
U`0f=SH0D51@03dm?@0W9bL0Bd];07=cL`13@d<0I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=S
H`0o?cl0VIVI07]kN`0U9BD0;Bd]0492@P0f=SH0ATI609>CT`10@400C4a<04m?C`0g=cL0N7Qh07em
O@0C4a<0=cLg06a/K00o?cl0Q8B407MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906][
J`1SHf<0ZJVY0;Bd]00M7Ad0@d=309RHV02<S8`0EUIF08J6QP0f=SH0C4a<08N7Q`1cLg<0M7Ad08:2
PP0Y:BT09bLW06UYJ@1MGEd0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0@d=305EE
E@0203Hf=P1d04E5A@0[:b/0JFUY08R8R01EEED09bLW034a<@13@d<0C4a<08n?S`15ADD06a/K03`l
?01FEUH0?Cdm09JFUP0l?3`0820P04U9B@1@D500?3`l06][J`31`L40?3`l038b<P1nOWh0EUIF0:^[
Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0;bl_0492@P20P800Lg=c07YjNP1oOgl0;Rh^03dm
?@1LG5`0T92@0:>SX`22PX80:b/[05MGE`2HV9P0L71`075aL@2RXZ80De=C04E5A@1XJ6P0NWYj059B
DP2i^KT0BDU904=3@`1>CTh0LW9b05ADE01]KFd0:BTY0451@@1LG5`0SHf=04Y:BP1BDU80Lg=c03dm
?@1VIVH0U9BD03Ph>01OGel0A4A403lo?`1MGEd0QhN7075aL@0e=CD0EUIF03<c<`1^KVh0LW9b02TY
:@1=CDd0JVYZ06ATI02?Shl0MgMg02LW9`1MGEd0Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q08>3
P`20P8005aLG05IFEP1eMGD0De=C09ZJVP2/[:`0<C4a02<S8`25QHD0QXJ608V9R@0Y:BT204M7A`13
07]kN`1aLG40V9RH04I6AP1;Bd/0ZZZZ06QXJ02UYJD0MGEe02d];@1<C4`0KFe]0:6QX@29RHT0Fe]K
02d];@1CDe<0[:b/07YjNP1SHf<0UYJF059BDP0e=CD0Rh^;079bLP1BDU80MWIf02`/;01;Bd/0G5aL
09JFUP2?Shl0?clo04U9B@1PH600Rh^;0820P00_;bl0GEeM061PH00n?Sh0ATI607EeM@0_;bl0De=C
05QHF01GEeL0FEUI0:2PX01DE5@0;Rh^04A4A01;Bd/0GEeM09jNWP2;Rh/0820P03lo?`1FEUH0DU9B
04e=C@2RXZ80GEeM03Ph>01=CDd0S8b<06EUI@0Looooo`0=06m_K`1hN7P0?Cdm038b<P1KFe/0L71`
05ADE00l?3`0DE5A04A4A011@D40<S8b04i>CP0207UiN@0R04a<C01MGEd0F5QH04A4A01;Bd/0;Rh^
03Lg=`1ADE40;bl_02XZ:P16ATH0>3Ph02l_;`12@T80CDe=08>3P`1BDU80;Rh^05ADE01IFET0?Shn
04M7A`1DE5@0FUYJ03Hf=P18B4P0C4a<02`/;00f=SH0De=C0492@P0K6a/0:2PX01<C4`<0>c/k0P0d
=3@0aP0c<c<0G5aL059BDP1OGel0Vi^K03<c<`0i>CT0@D5105eMG@15ADD0BTY:05=CD`1@D500JVYZ
06m_K`0c<c<0@D5104];B`1jNWX0I6AT04U9B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0JFUY
03hn?P1TI6@0CDe=0492@P1@D500BDU904];B`0m?Cd0De=C04I6AP1QHF40OWin04m?C`19BDT0CTi>
03dm?@1LG5`0AdM705IFEP1]KFd0BDU905UIF@1:BTX0BDU904A4A01FEUH0Kfm_08^;R`1OGel0GEeM
075aL@1eMGD0TI6A0;Bd]01ADE40KFe]05YJFP1<C4`0EEEE05aLG00/;2`0GUiN06ATI02ATI40E5AD
08j>SP1DE5@0/k>c09:BTP2YZJT0ADE5079bLP1QHF40?Shn08:2PP1?Cdl0>3Ph03lo?`17AdL0@d=3
07=cL`13@d<0>CTi04U9B@1eMGD0?Shn04A4A02<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1ADE40Ph>3055AD@23Ph<0_;bl04a<C01SHf<0FUYJ03hn?P1ADE40NWYj03Xj>P17AdL0ATI6
03Lg=`1_Kfl0F5QH03dm?@1jNWX0C4a<08R8R00o?cl0>c/k04];B`1VIVH0>CTi07EeM@2GUiL0I6AT
05YJFP0_;bl0Fe]K059BDP1_Kfl0HF5Q030`<016ATH0@41004e=C@20P800=SHf04Y:BP1VIVH0Lg=c
03/k>`1IFET0?Cdm05=CD`16ATH0DU9B01PH601ADE40>3Ph00X:2P18B4P0>c/k02LW9`0b<S80=CDe
04M7A`10@400>c/k04Q8B01JFUX0BTY:04M7A`14A4@0>3Ph04i>CP0V9RH0J6QX01dM7@1DE5@0B4Q8
03Ti>@17AdL0<30`05=CD`0e=CD0GUiN05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@1<C4`0=SHf
02d];@0n?Sh0ATI606ATI080IVIV02@0D51@06e]K@0l?3`0MGEe055AD@1]KFd0LG5a07inOP1NGUh0
Ogmo0451@@1@D500GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0AdM705]KF`1MGEd0
Lg=c06QXJ01<C4`0@41004Q8B01DE5@0BTY:05=CD`1;Bd/0Fe]K06][J`1iNGTAooooo`003oooool0
6`1OGel0N7Qh07EeM@1hN7P0HV9R05eMG@1dM7@0G5aL08f=S@10@400ATI605ADE01eMGD0Cdm?05eM
G@0`<300AdM707UiN@1LG5`0>SXj06e]K@16ATH0AdM705UIF@1>CTh0@410065QH@0205iNGP3O06QX
J01GEeL0<30`03Lg=`1BDU80E5AD08:2PP1DE5@0:RXZ03hn?P10@400Bd];05=CD`2CTi<0AdM704a<
C01PH600>SXj06m_K`1dM7@0;bl_02XZ:P1<C4`0N7Qh071`L01ADE409BDU03hn?P1HF5P0CDe=06QX
J021PH40820P03`l?01[Jf/0?Cdm09BDU01RHV80820P030`<01PH600I6AT04m?C`1ZJVX0:b/[05AD
E01hN7P0EUIF04U9B@1OGel0:b/[034a<@1MGEd0D51@06UYJ@1BDU80;bl_05QHF022PX80G5aL03<c
<`1^KVh0A4A407IfMP1HF5P0:2PX03Ti>@1LG5`0BDU904E5A@1RHV80>SXj04E5A@0l?3`0BDU906QX
J01fMWH0>CTi04M7A`1^KVh0BTY:05IFEP1]KFd0<S8b03/k>`1/K6`0JFUY05]KF`1/K6`0KFe]02h^
;P1ADE40OGem04A4A02HV9P0J6QX02d];@0j>SX0F5QH069RHP1EEED0O7al03Hf=P1PH600UIFE07Ui
N@1bLW80]kNg03Ti>@18B4P0LG5a06UYJ@1gMgL0LG5a03hn?P1@D500QXJ606YZJP1/K6`0WIfM03`l
?01SHf<0P82005ADE01OGel0Shn?030`<017AdL0NGUi06i^KP1QHF40SHf=03De=@1GEeL0Vi^K07al
O01@D500QhN708j>SP11@D40Rh^;07IfMP0k>c/0N7Qh07YjNP1<C4`0KVi^07YjNP15ADD0GEeM04E5
A@1=CDd0Rh^;096AT@0f=SH0ATI6069RHP1:BTX0F5QH08Z:RP11@D40C4a<04];B`18B4P0RXZ:09:B
TP0h>3P0E5AD071`L01@D500Xj>S05mOG`0h>3P0IVIV06QXJ01;Bd/0R8R806e]K@16ATH0LG5a051@
D026QXH0IfMW02XZ:P17AdL0Ogmo06e]K@1LG5`0HF5Q05EEE@2DU9@0OWin06][J`2NWYh0;Rh^03Hf
=P21PH40M7Ad05aLG011@D409RHV04Y:BP28R8P0F5QH04a<C01eMGD0;Rh^06EUI@2][Jd0HF5Q05iN
GP23Ph<0?clo069RHP26QXH0P82004];B`1YJFT0EeMG08B4Q025QHD0De=C03Ti>@0206=SH`0T04i>
CP1TI6@0V9RH03Ti>@1JFUX0LG5a04A4A021PH40ZZZZ0492@P13@d<0I6AT04i>CP1]KFd0MGEe03`l
?011@D40FUYJ06QXJ010@400Kfm_04e=C@0o?cl0GEeM07MgM`1JFUX0IFEU09NGU`0j>SX0=3@d059B
DP1YJFT0A4A409VIV@0Z:RX0?clo7?ooool0@`1NGUh0K6a/05IFEP1>CTh0HV9R06YZJP1/K6`0Fe]K
07AdM01JFUX0MGEe04m?C`1_Kfl0Lg=c06a/K01jNWX0R8R806m_K`1=CDd0KFe]05UIF@12@T80ATI6
04i>CP1<C4`0Bd];05mOG`1=CDd0H61P05EEE@1:BTX0CTi>04a<C01PH600IfMW04e=C@1bLW80FUYJ
05EEE@13@d<0Cdm?0492@P19BDT0C4a<03lo?`1DE5@0<c<c04I6AP0H61P0Cdm?02d];@0l?3`0=SHf
04U9B@0d=3@0@41004e=C@0m?Cd0GEeM03De=@0o?cl0EUIF05aLG01IFET0Bd];05QHF01KFe/00P1d
M7@0S@0U9BD0@T9204a<C01=CDd0GEeM05IFEP1CDe<0Fe]K02d];@0j>SX0FUYJ04a<C01DE5@0A4A4
03Ti>@1@D500=cLg03<c<`1IFET0:b/[03`l?00b<S80ADE503Xj>P1DE5@0N7Qh03/k>`13@d<0<S8b
04=3@`1GEeL0<30`0492@P1PH600A4A404M7A`19BDT0?Shn03dm?@14A4@0J6QX07emO@1CDe<0EEEE
05mOG`1FEUH0OGem08F5Q@1LG5`0UiNG04U9B@1RHV80C4a<07AdM010@400IfMW04];B`1kNg/0EeMG
069RHP1gMgL0UIFE07moO`2^[Zh0HV9R08V9R@1lO7`0HF5Q09JFUP1aLG40?3`l03hn?P1XJ6P0<S8b
04E5A@0b<S80ATI60410@011@D40EeMG06=SH`26QXH0JFUY059BDP14A4@0Fe]K05IFEP0Z:RX0GUiN
06IVIP1DE5@0LW9b02LW9`2ATI40[:b/03lo?`1FEUH0E5AD04Y:BP1;Bd/0Lg=c038b<P1PH600FUYJ
059BDP23Ph<0JVYZ04e=C@1_Kfl0DU9B06i^KP1JFUX0FEUI061PH01eMGD0EeMG06m_K`2GUiL0NWYj
071`L01IFET0EUIF01lO7`1ZJVX0HV9R028R8P23Ph<0>3Ph02l_;`1ADE40CDe=05QHF015ADD0E5AD
03hn?P1iNGT0B4Q8061PH01TI6@0K6a/03<c<`0205UIF@0M02XZ:P1CDe<0?clo03Hf=P1ADE40AdM7
04U9B@14A4@0B4Q804e=C@1XJ6P0C4a<04e=C@13@d<0?Shn05=CD`14A4@0IFEU05]KF`1`L700ADE5
04I6AP1HF5P0@41005EEE@0`<300ATI60492@P1HF5P00P19BDT04`1KFe/0@T92061PH01WIfL0KFe]
04E5A@1@D500Cdm?04];B`0l?3`0@41005YJFP2ATI40Fe]K06a/K01BDU80GEeM04A4A01NGUh00P2J
VYX06P1KFe/0HV9R059BDP1TI6@0?Shn071`L01BDU80D51@07QhN00k>c/0?clo03hn?P1YJFT0BDU9
04Y:BP0i>CT0>3Ph05IFEP19BDT0Hf=S04];B`1EEED0EeMG065QH@1XJ6P0E5AD4Oooool000oooooo
0?l0Ti>C07MgM`1:BTX0FEUI079bLP13@d<0AdM703hn?P1`L700O7al03dm?@14A4@0Bd];02HV9P20
P800@41004=3@`0U9BD0=3@d055AD@1@D500BDU902TY:@13@d<0=cLg07=cL`2XZ:P0D51@02<S8`10
@400DE5A04A4A022PX80D51@03dm?@18B4P0P820069RHP2:RXX0NWYj01TI6@19BDT0ADE5065QH@2[
Zj/0A4A402`/;012@T80A4A406QXJ01MGEd0UIFE02h^;P16ATH0DE5A03Ti>@1dM7@0HF5Q01<C4`0a
<C40O7al05ADE01YJFT09bLW02@T9016ATH0SHf=05ADE01=CDd0Bd];02<S8`10@400TY:B065QH@21
PH40@d=302@T901IFET0/k>c05YJFP0m?Cd0EUIF03`l?01nOWh0YjNW03Ph>00d=3@0Jf][03De=@1H
F5P0Shn?04M7A`1UIFD0E5AD03/k>`2>SXh0LW9b02<S8`0_;bl0@d=303Lg=`27QhL0<c<c01PH600^
;Rh0EeMG05YJFP1YJFT0_Kfm02PX:00S8b<0BTY:06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0LW9b02/[:`0_;bl0Jf][08J6QP1DE5@0TY:B0:ZZZP0M7Ad0=CDe08f=S@1]KFd0W9bL07MgM`0j
>SX0BDU90<W9b@2=SHd0DU9B0;>c/`19BDT0EeMG06][J`1JFUX0HF5Q05MGE`0l?3`0GemO06UYJ@1N
GUh0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0BDU90;Jf]P1CDe<0<S8b05mOG`1C
De<0DE5A07YjNP2ZZZX0ADE504m?C`15ADD0>CTi09ZJVP2j^[X0?3`l03lo?`1NGUh0AdM707emO@14
A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1kNg/0Cdm?08b<S00Q8B409BDU04m?C`1^
KVh0@T9209FEU@26QXH0:b/[075aL@2QXJ40LG5a079bLP0S8b<0Bd];05aLG02a/K40PH6105MGE`0c
<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^;Rh0Fe]K07MgM`1EEED0CTi>03Xj>P14A4@0K6a/07=cL`0c
<c<0IfMW02h^;P1CDe<0Q8B403@d=01?Cdl0EUIF03Xj>P1IFET0OWin07=cL`1KFe/0BTY:05iNGP2>
SXh0XJ6Q05EEE@0k>c/0KVi^04Y:BP1;Bd/0[Zj^03@d=017AdL0J6QX05YJFP17AdL0ZJVY0;Jf]P0g
=cL002<0;Rh^06a/K01^KVh0^KVi07MgM`0a<C40@T9207EeM@2GUiL0PH6108B4Q012@T80E5AD06e]
K@1[Jf/0QXJ609NGU`0[:b/0?3`l055AD@1VIVH0HF5Q0;6a/@1BDU807AdM05ADE022PX80KVi^051@
D01]KFd0ATI60451@@1<C4`0MWIf03/k>`0Looooo`0W05mOG`1dM7@0C4a<04Y:BP1MGEd0G5aL05YJ
FP1?Cdl0GEeM04i>CP1?Cdl0?Cdm061PH01gMgL0Kfm_04];B`1gMgL0S8b<079bLP1cLg<0@D5103Ti
>@1KFe/0@T9204Y:BP1RHV80DU9B03Xj>P1EEED0Kfm_079bLP1[Jf/0BDU906YZJP1YJFT0DE5A06YZ
JP1`L700KFe]0080EEEE00h0:BTY03dm?@1ADE40Cdm?05ADE00j>SX0@D5101dM7@1?Cdl0ADE505aL
G00e=CD0?Shn03De=@80DE5A03h0H61P0820P00g=cL0Kfm_05MGE`1bLW80J6QX06e]K@1DE5@0IVIV
0:b/[02<S8`08b<S0451@@1EEED0MGEe06a/K017AdL0ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE
05MGE`0h>3P0@T9204M7A`0[:b/0>c/k03<c<`19BDT0=SHf04E5A@19BDT0C4a<04];B`0o?cl0HV9R
034a<@0o?cl0C4a<03/k>`1;Bd/0EEEE06EUI@1HF5P0>SXj03Ph>014A4@0AdM706EUI@1gMgL0FUYJ
04M7A`1<C4`0BDU9065QH@1[Jf/0AdM706ATI080?Shn01T0FEUI05IFEP0[:b/0D51@04Y:BP1TI6@0
FEUI09FEU@1FEUH0O7al06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU90492@P1ADE40
@41006][J`0m?Cd0MWIf00<0BDU908d0JFUY0:2PX01YJFT0L71`05mOG`1QHF40EEEE03Lg=`2HV9P0
Y:BT04a<C01FEUH05QHF0:BTY02`/;00:BTY05ADE011@D40>3Ph04Q8B01IFET0HF5Q05iNGP1/K6`0
AdM705]KF`1>CTh0ADE506YZJP12@T80BTY:04A4A010@400H61P07moO`1;Bd/0FUYJ07=cL`2BTY80
Vi^K03Hf=P10@400=CDe0:f][@23Ph<0>c/k06YZJP15ADD0GUiN07UiN@0l?3`0ATI606YZJP1fMWH0
Cdm?05YJFP1IFET0Vi^K05iNGP19BDT0IVIV0<30`01/K6`0?3`l04m?C`14A4@0<S8b04];B`0n?Sh0
GEeM0492@P0l?3`0?Cdm06IVIP15ADD0?Shn05ADE00l?3`0BTY:059BDP2;Rh/0>3Ph055AD@1:BTX0
@d=306m_K`0j>SX0B4Q803Ti>@0e=CD0>c/k04i>CP0f=SH0@T92069RHP1:BTX0De=C04Q8B019BDT0
@41007MgM`0h>3P0Lg=c07moO`0l?3`0@D5107AdM00`<300E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0
MgMg05MGE`1MGEd0IFEU07QhN01BDU80Z:RX06e]K@1DE5@0TI6A0492@P1DE5@0<c<c05ADE00i>CT0
ATI603Hf=P0h>3P0ATI604];B`1^KVh0Bd];05=CD`17AdL0Hf=S07IfMP1YJFT04Oooool000oooooo
0:d0LW9b0<?3``1EEED0FEUI07IfMP2OWil0GUiN03hn?P0i>CT0KFe]05mOG`2f][H0Hf=S02d];@11
@D40AdM706UYJ@1_Kfl07QhN03<c<`1BDU80FUYJ0410@024Q8@0>c/k02<S8`1TI6@0QHF505QHF02;
Rh/0:BTY03Ti>@1=CDd0P82005YJFP1VIVH0:BTY04I6AP1/K6`0NWYj059BDP1NGUh0IVIV02XZ:P1C
De<0IFEU030`<00o?cl0AdM702`/;016ATH0Jf][07alO015ADD0>3Ph030`<01iNGT0PX:201HF5P0W
9bL0B4Q803<c<`24Q8@0:b/[02LW9`0_;bl0>CTi06][J`1fMWH0M7Ad01dM7@0Z:RX0EeMG06i^KP2Z
ZZX0FEUI02TY:@0e=CD0EEEE07EeM@1gMgL0SXj>03/k>`1?Cdl0O7al07]kN`1jNWX0QhN703Ph>00c
<c<0M7Ad07UiN@2PX:00DE5A020P8013@d<0U9BD05UIF@27QhL0RXZ:01lO7`18B4P0H61P04A4A01g
MgL0CTi>03`l?01IFET0KVi^096AT@0m?Cd0C4a<02<S8`1;Bd/0IfMW05aLG00`<300LG5a03Ph>00f
=SH0Hf=S03dm?@1?Cdl0T92@04Q8B011@D40FEUI09ZJVP2CTi<0?3`l05QHF010@400TY:B0:BTY00`
<300;bl_06YZJP1<C4`0ADE509VIV@1<C4`0>CTi07IfMP1OGel0OWin08^;R`0Y:BT0E5AD07moO`1h
N7P0Xj>S08Z:RP0^;Rh0Fe]K05mOG`2HV9P0HF5Q0<g=c@14A4@0ATI6071`L02@T900IfMW08f=S@1F
EUH0;Bd]07EeM@2BTY80?clo09^KV`0`<300>CTi04m?C`0209^KV`1c075aL@1?Cdl07QhN06UYJ@1j
NWX0Bd];08f=S@1<C4`0=3@d06UYJ@1NGUh0Cdm?06QXJ01QHF40?3`l065QH@1dM7@0?Cdm07moO`1D
E5@0;Bd]04M7A`1iNGT0@T9205YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0GEeM096AT@0Z
:RX0I6AT06EUI@1CDe<0Shn?07alO00W9bL0ADE505mOG`1lO7`0Ti>C02l_;`0g=cL0BTY:061PH01G
EeL0^;Rh03dm?@0l?3`0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096AT@25QHD0JVYZ02HV9P1I
FET0PH6107EeM@1SHf<0U9BD03hn?P0c<c<0S8b<06][J`1iNGT0QXJ603Hf=P0c<c<0Hf=S0;Jf]P2[
Zj/0RXZ:06YZJP0b<S80De=C0:>SX`1ADE40J6QX07]kN`0M7Ad0B4Q808B4Q00h>3P0DE5A05aLG00Q
8B40Cdm?08n?S`1XJ6P0:b/[065QH@0i>CT0C4a<06ATI01IFET0=CDe03lo?`1ADE40?Shn05IFEP1[
Jf/0EeMG030`<01RHV80EUIF05=CD`0Looooo`2N05UIF@1mOGd0DE5A051@D01[Jf/0OGem06i^KP1C
De<0PX:205QHF01PH600ADE508:2PP23Ph<0NGUi0861P@2MWId0KFe]04=3@`1SHf<0AdM703lo?`11
@D40Cdm?04M7A`19BDT0I6AT03lo?`1ADE40Cdm?04Y:BP1EEED0@T9205YJFP1PH600BTY:07alO01D
E5@0GEeM03dm?@1;Bd/0DU9B03dm?@1=CDd0A4A404e=C@0f=SH0ADE502d];@1IFET0;2`/04I6AP0l
?3`0EEEE03<c<`0l?3`0ADE5051@D01JFUX0820P04I6AP1VIVH0EUIF05QHF01ADE40F5QH05UIF@1U
IFD0GemO04U9B@1KFe/0GUiN05=CD`1]KFd0BDU904E5A@1FEUH0:RXZ0410@02;Rh/0Kfm_06ATI017
AdL0?Shn051@D00o?cl0;bl_05ADE00g=cL0ADE502d];@18B4P0ADE505ADE01_Kfl0=CDe051@D00`
<300EUIF05aLG00k>c/0@41005UIF@19BDT0BTY:051@D016ATH0Fe]K04m?C`2HV9P0QHF505QHF01F
EUH0Hf=S04I6AP1OGel0FEUI04M7A`1lO7`0B4Q805]KF`0m?Cd0HV9R02`/;01FEUH0GemO06MWI`16
ATH0G5aL04=3@`1cLg<0GUiN05eMG@0Y:BT0JFUY0410@01DE5@0Zj^[055AD@0g=cL0?3`l069RHP0S
8b<0ATI602d];@19BDT0CTi>05iNGP18B4P0Fe]K0:6QX@0g=cL0B4Q803Lg=`1TI6@0EUIF03dm?@18
B4P204m?C`1k055AD@0Y:BT0a<C40<;2`P0Z:RX0OWin07UiN@1RHV80V9RH06a/K00o?cl0L71`061P
H00i>CT0H61P0492@P1:BTX0MgMg03Lg=`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=c
L`1[Jf/0AdM70451@@0_;bl0BDU905iNGP1;Bd/0Ng]k04A4A01>CTh0E5AD04i>CP0m?Cd0>SXj0451
@@1<C4`0PX:204i>CP1:BTX0Rh^;09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD04M7
A`1JFUX0C4a<04I6AP12@T80L71`0451@@13@d<0E5AD0492@P1HF5P0?clo04i>CP0k>c/0L71`03dm
?@0h>3P0Hf=S03dm?@1MGEd0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?Cdl0G5aL05QH
F00/;2`0;Bd]01lO7`1<C4`0Cdm?03<c<`1[Jf/0SXj>04e=C@1ADE40Fe]K06YZJP1=CDd0D51@0;^k
^`2FUYH0BTY:055AD@1`L700IfMW08n?S`39bLT0N7Qh071`L029RHT0;Bd]04i>CP18B4P0Jf][03<c
<`1ZJVX0BTY:04m?C`1BDU80@D510080F5QH00D0EeMG05iNGP1BDU80GEeM06QXJ00Aooooo`003ooo
ool0o`1HF5P0MgMg08^;R`1VIVH0GemO05=CD`25QHD0B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c
04a<C00^;Rh0Cdm?06e]K@13@d<0?3`l04m?C`0b<S80CTi>06QXJ01SHf<0:BTY04a<C01ADE40De=C
08V9R@1PH6006a/K04E5A@13@d<0J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0?3`l
04A4A01eMGD0HV9R07=cL`1nOWh06QXJ02XZ:P10@400IfMW08V9R@0b<S80:RXZ03Ph>01LG5`0DE5A
09BDU01@D5008B4Q05MGE`1eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A015ADD0CTi>
075aL@2;Rh/0@41004=3@`18B4P05aLG03Xj>P1:BTX0?Cdm05YJFP14A4@08B4Q04i>CP1QHF40DU9B
03De=@1jNWX0<C4a06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A03<c<`11@D40Cdm?
061PH015ADD0;Bd]03lo?`1ADE40Cdm?075aL@2>SXh06a/K03<c<`1<C4`0?clo04m?C`2l_;`0GEeM
01hN7P1ADE40@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0SHf=04=3@`1?Cdl0S8b<
07emO@2SXj<0UIFE03Lg=`1HF5P0IfMW08b<S01mOGd0IFEU03Ti>@1ADE40HV9R05YJFP1=CDd0SXj>
02l_;`1ADE40MGEe051@D01jNWX0SXj>01hN7P17AdL0LW9b07inOP1OGel0FUYJ03dm?@1NGUh0M7Ad
07QhN00n?Sh0LW9b08B4Q01@D500PH6106][J`0c<c<0NWYj07AdM00l?3`0Xj>S0;no_`15ADD0F5QH
06MWI`1BDU80Xj>S08n?S`0b<S80?Cdm05YJFP0l?3`0QXJ6092@T00X:2P0?Shn05iNGP1EEED0bLW9
07emO@0a<C40>CTi06a/K028R8P0emOG05]KF`0/;2`0BDU905ADE01]KFd0alO707UiN@0e=CD0IVIV
05mOG`2c/k<0QhN702HV9P1_Kfl0_[jn08R8R022PX80F5QH07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX
04M7A`2;Rh/0Ogmo07MgM`1CDe<0=CDe04a<C021PH40EEEE05]KF`1oOgl0;Rh^07MgM`2<S8`0>CTi
03lo?`1[Jf/0?clo069RHP1iNGT0F5QH03Xj>P1PH600Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0HV9R
03hn?P008`1PH600QhN703@d=011@D40Hf=S06QXJ01mOGd0SHf=024Q8@0a<C40G5aL07IfMP1kNg/0
Rh^;02<S8`0d=3@0FUYJ07emO@15ADD0QXJ604Q8B01;Bd/0LW9b06YZJP1<C4`0Ti>C0:BTY00b<S80
9bLW069RHP26QXH0IFEU0;Ng]`0c<c<0=3@d01cooooo03h0EeMG0820P01[Jf/0HV9R06e]K@1nOWh0
KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1cLg<0E5AD06i^KP1UIFD0I6AT07=cL`18B4P0
AdM704i>CP1ADE40Fe]K05eMG@1eMGD0C4a<05mOG`1WIfL0GemO06i^KP1BDU80MWIf06a/K01VIVH0
Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE5059BDP17AdL0GemO03Lg=`15ADD0;Rh^065QH@10@400
EEEE03lo?`1;Bd/0<c<c0492@P1QHF40G5aL06m_K`0n?Sh0EEEE069RHP80HF5Q02l0D51@055AD@1a
LG40RXZ:08f=S@11@D40>3Ph05YJFP1SHf<0FUYJ051@D01WIfL0Fe]K03<c<`0o?cl0IFEU03dm?@1W
IfL0EUIF04E5A@1@D500>CTi03Lg=`1UIFD0;bl_04Q8B00];Bd0@41004=3@`1BDU80FEUI02XZ:P1@
D500820P03De=@16ATH0;2`/03hn?P18B4P0DU9B03lo?`19BDT0<c<c04Y:BP0m?Cd0FUYJ05aLG002
04e=C@1j05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP1<C4`0CDe=07MgM`0j>SX0GemO0492@P1H
F5P0Lg=c09JFUP1:BTX0H61P07MgM`1oOgl0ADE50;>c/`1BDU80>SXj09JFUP1ADE40GUiN0410@01;
Bd/0<30`04U9B@0n?Sh0IfMW034a<@0j>SX0@41005UIF@2WYjL0AdM707EeM@1HF5P0HV9R04a<C00k
>c/0LW9b07AdM01IFET0IVIV04e=C@28R8P0RXZ:04m?C`1aLG40B4Q804M7A`12@T80HV9R01dM7@1C
De<0D51@04Y:BP1WIfL0AdM703lo?`1EEED0G5aL06MWI`1;Bd/0EEEE05aLG021PH40GUiN0861P@2C
Ti<0RHV9071`L017AdL0EeMG03hn?P1ZJVX0H61P05]KF`2SXj<0I6AT06a/K01]KFd0Hf=S04U9B@1I
FET0E5AD03/k>`1OGel0AdM707YjNP1JFUX0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1F
EUH0F5QH06UYJ@0l?3`0B4Q804M7A`1aLG40@D510492@P1?Cdl0:b/[04A4A015ADD0HV9R04=3@`20
P800@d=303lo?`1?Cdl204Y:BP0e02DU9@0b<S80:b/[0451@@0_;bl0<c<c05IFEP11@D40IVIV04U9
B@1>CTh0@T9204i>CP0k>c/0KFe]08F5Q@1;Bd/0AdM7065QH@0l?3`0GUiN06][J`1YJFT0FEUI061P
H01`L700PX:206YZJP1VIVH0LW9b08f=S@1`L700PX:203Ph>00o?cl0De=C01dM7@16ATH0>3Ph04Y:
BP0k>c/0DE5A03@d=00m?Cd0Bd];061PH01lO7`0FUYJ05=CD`15ADD0EUIF06IVIP1LG5`04Oooool0
00oooooo04<0FUYJ05IFEP1cLg<0SHf=065QH@0o?cl0LW9b06YZJP2GUiL0B4Q802PX:010@400Cdm?
03/k>`2LW9`07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0KFe]07EeM@1<C4`09RHV
03hn?P1VIVH0QhN705iNGP2;Rh/0?3`l0492@P1iNGT0WIfM05eMG@1fMWH0AdM701hN7P18B4P0L71`
065QH@1ZJVX0ADE501dM7@16ATH0De=C03`l?00c<c<0ATI601dM7@1;Bd/0IfMW03@d=01GEeL0=CDe
01dM7@19BDT0OWin02XZ:P0n?Sh0;Rh^04M7A`2DU9@0N7Qh00806a/K0=d0CDe=05iNGP1UIFD0Hf=S
02HV9P0a<C40H61P05ADE01iNGT0P82001DE5@0i>CT0Bd];04A4A02=SHd0K6a/01hN7P0m?Cd0BDU9
05iNGP1<C4`0`L7102d];@1@D500H61P059BDP1_Kfl0?clo01hN7P0a<C40G5aL08F5Q@1WIfL07QhN
02`/;019BDT0H61P04M7A`1nOWh0^k^k02HV9P0[:b/0J6QX04M7A`1QHF40Ph>301lO7`0Z:RX0Fe]K
07IfMP0`<300DE5A028R8P0Q8B40GUiN07=cL`13@d<0EeMG05IFEP0a<C40<c<c06=SH`0j>SX0G5aL
04I6AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B013@d<0LG5a06e]K@0[:b/0BDU905eMG@13@d<0P820
0:n_[`0d=3@0GemO05ADE01GEeL0WinO0;6a/@0V9RH0CTi>06][J`1_Kfl0Q8B408R8R00[:b/0FUYJ
06m_K`1^KVh0EUIF0=CDe02YZJT0;Bd]04m?C`1^KVh0DU9B0;:b/P2MWId0DU9B04E5A@2<S8`0I6AT
08n?S`0f=SH0>c/k06YZJP2;Rh/0F5QH05mOG`1GEeL0:b/[0492@P2DU9@0E5AD071`L00T92@0;2`/
08n?S`2NWYh0DU9B06MWI`12@T80@4100;Zj^P2h^;P0LG5a04m?C`0U9BD0@D5107MgM`2^[Zh0L71`
03Lg=`10@400MWIf0;Rh^01>CTh0HF5Q03`l?019BDT0O7al04];B`1DE5@0NGUi03`l?01nOWh0[Jf]
03dm?@0a<C40EUIF05ADE01aLG40@D5102/[:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P17AdL0R8R8
05]KF`1jNWX0U9BD03Ti>@0g=cL0Ph>3069RHP1^KVh0];Bd0492@P1KFe/0FEUI075aL@1WIfL0e]KF
08j>SP1;Bd/0CDe=07=cL`20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG05mOG`0a<C40@T92
05YJFP15ADD0BDU908F5Q@0e=CD0>CTi04];B`1OGel0BDU9065QH@0d=3@0<S8b04i>CP1NGUh0H61P
038b<P1:BTX0?Shn04E5A@1mOGd0Cdm?02/[:`0Looooo`1[05ADE01dM7@0DU9B051@D01TI6@0MgMg
05]KF`1CDe<0J6QX06ATI016ATH0>SXj06ATI01]KFd0Hf=S04i>CP1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05mOG`1ADE40J6QX06MWI`1ZJVX0H61P07IfMP1?Cdl0?3`l051@D01LG5`0AdM7
05QHF019BDT0E5AD03dm?@1JFUX0BDU90451@@1CDe<0Jf][055AD@10@400@d=302HV9P1HF5P0<30`
059BDP0_;bl0BDU903`l?01?Cdl0FUYJ06e]K@1iNGT09RHV04E5A@1^KVh0IfMW05YJFP1SHf<0GEeM
07MgM`2[Zj/0RHV903@d=014A4@0HV9R07MgM`1CDe<0B4Q8059BDP1[Jf/0B4Q805YJFP1lO7`0Cdm?
06=SH`1CDe<0=CDe055AD@1?Cdl0>SXj069RHP17AdL0CTi>03Ti>@1@D500FEUI05ADE01gMgL0@D51
05IFEP0k>c/0CTi>05EEE@14A4@0EeMG05]KF`1CDe<0GemO04e=C@1:BTX00P1FEUH0D`2IVIT0QHF5
05]KF`16ATH0Fe]K0410@01SHf<0=cLg03hn?P1oOgl0CTi>04E5A@1@D500GEeM03Hf=P1GEeL0FUYJ
06UYJ@1?Cdl0J6QX059BDP1kNg/0HF5Q04E5A@0_;bl0N7Qh04I6AP13@d<0UiNG05iNGP1?Cdl0B4Q8
04e=C@0b<S80I6AT02PX:01CDe<0C4a<04m?C`0/;2`0Hf=S0;>c/`0R8R80GUiN03@d=01=CDd0>SXj
05iNGP2QXJ40W9bL075aL@1cLg<0B4Q80<k>cP2g]kL0?Shn0:>SX`15ADD0B4Q804Y:BP1]KFd0D51@
08Z:RP1UIFD0?Cdm0492@P0h>3P0GUiN08^;R`1<C4`0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0Ph>3
09nOW`2_[jl0NGUi065QH@1DE5@0Bd];0080JFUY03H0DU9B09JFUP1nOWh0YjNW08B4Q015ADD0:2PX
04Y:BP14A4@0?clo05=CD`18B4P0LW9b06MWI`1kNg/0I6AT0<g=c@1eMGD0?Shn04=3@`0n?Sh0@D51
04a<C011@D40ADE5030`<00j>SX0<30`05QHF00e=CD0>CTi04a<C00d=3@0CTi>05UIF@1eMGD0;bl_
05ADE00_;bl0@d=306EUI@0];Bd0B4Q8020P800X:2P0<30`04U9B@10@400ATI607UiN@16ATH0ADE5
06YZJP1aLG4206=SH`0X02`/;01SHf<0G5aL02HV9P1UIFD0[Jf]03dm?@1JFUX0R8R807QhN01NGUh0
DU9B0;no_`29RHT0Lg=c06EUI@1YJFT0EEEE08R8R02XZ:P0=3@d05EEE@1PH600=3@d04e=C@0h>3P0
FUYJ065QH@2:RXX0GemO04I6AP14A4@0C4a<05aLG00n?Sh0CTi>04M7A`1[Jf/0MgMg05IFEQ7ooooo
000?ooooo`3o0::RXP2KVi/0D51@06=SH`2;Rh/0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QH
F00/;2`0Ph>303Ti>@18B4P0BTY:01lO7`0n?Sh0PX:20492@P0M7Ad0HF5Q03lo?`29RHT0QHF503<c
<`0S8b<0@d=302`/;01PH600/;2`04E5A@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410
@012@T80LW9b065QH@0H61P07alO04U9B@0e=CD0Hf=S08N7Q`0O7al08b<S051@D01=CDd0QhN704i>
CP0Z:RX0=cLg05aLG013@d<0TY:B01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J6QX0>CTi05AD
E016ATH0N7Qh04=3@`0h>3P0AdM705eMG@1:BTX0AdM709NGU`1>CTh0L71`0:6QX@1CDe<0IFEU08V9
R@0P8200BTY:0820P01]KFd0FUYJ02@T900g=cL0C4a<07AdM013@d<0>3Ph04m?C`0d=3@0HV9R03dm
?@0K6a/0?Shn03dm?@12@T80IfMW09RHV018B4P08B4Q04e=C@1]KFd0LW9b0<K6aP0l?3`0820P05QH
F01lO7`0J6QX08>3P`0U9BD071`L04U9B@1PH600CTi>07EeM@2JVYX06a/K0410@01GEeL0F5QH09FE
U@1kNg/0:b/[04E5A@1UIFD0Jf][06ATI02HV9P0?Cdm051@D01mOGd0EeMG05IFEP1jNWX06a/K02d]
;@1dM7@0J6QX0:b/[01OGel07AdM05eMG@2MWId0Bd];04U9B@2?Shl0=3@d04E5A@2NWYh0D51@055A
D@1OGel0>3Ph03Ti>@1MGEd0];Bd05IFEP1?Cdl0:BTY02PX:01hN7P0ZZZZ05EEE@1=CDd0>CTi03hn
?P1RHV80;Rh^02l_;`1SHf<0@D5105mOG`27QhL0C4a<020P800[:b/0FUYJ09FEU@2ATI40820P02PX
:01JFUX0J6QX04e=C@2HV9P0C4a<02TY:@1_Kfl0RXZ:0<;2`P2MWId09bLW03Hf=P1>CTh0QXJ60:2P
X01JFUX0;2`/05YJFP1jNWX0LG5a09NGU`1[Jf/06QXJ05IFEP2<S8`0P82008V9R@0`<300<S8b07in
OP1OGel0FUYJ07emO@0Z:RX0BDU908n?S`1UIFD0MGEe04I6AP12@T80IVIV06YZJP1NGUh0RXZ:034a
<@0`<300CTi>0:n_[`1cLg<0EeMG08B4Q00i>CT0=SHf08^;R`1JFUX0IfMW05]KF`0a<C40:BTY059B
DP2=SHd0CTi>000S06ATI00d=3@0De=C0820P025QHD0>SXj05]KF`1?Cdl0?3`l08Z:RP2IVIT0<S8b
05QHF01:BTX0@d=307UiN@2WYjL0DE5A034a<@18B4P0EEEE0820P03<c<`0GemO02LW9`12@T80BDU9
06EUI@1_Kfl0TY:B04m?C`15ADD0L71`08:2PP1[Jf/07?ooool0[P1@D500RXZ:05eMG@1BDU80Lg=c
07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De=@1gMgL0N7Qh0820P01cLg<0W9bL079bLP1;Bd/0E5AD
03/k>`12@T80DE5A0451@@1;Bd/0IfMW055AD@0n?Sh0AdM703lo?`1=CDd0HV9R04I6AP1YJFT0JVYZ
05]KF`28R8P0FEUI06i^KP18B4P0H61P05IFEP0n?Sh0DE5A03Lg=`0o?cl0=CDe03dm?@0];Bd0F5QH
02l_;`1ADE40;Rh^04U9B@0_;bl0>c/k04A4A01HF5P0H61P02@T9012@T80B4Q805aLG018B4P0CDe=
07AdM01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1NGUh0J6QX05IFEP1SHf<0F5QH02/[:`10@400M7Ad
06YZJP1SHf<0DE5A04A4A01EEED0?clo04M7A`1RHV80?3`l03Lg=`0Z:RX0BTY:04E5A@1:BTX0IVIV
03Hf=P10@400820P059BDP1FEUH0;bl_04A4A01IFET0BDU903Lg=`1LG5`0?Shn06=SH`1>CTh0T92@
08:2PP1FEUH0B4Q805UIF@10@400BDU903/k>`1;Bd/0M7Ad04A4A01BDU80@d=307AdM011@D40M7Ad
05QHF01PH600LW9b08j>SP1BDU80Q8B40861P@0l?3`0?Shn08Z:RP1=CDd0Hf=S0<30`01JFUX0Jf][
04a<C01NGUh0BDU905ADE016ATH0F5QH02d];@0j>SX0CDe=06i^KP2HV9P0>CTi06ATI010@400NWYj
03Ph>016ATH0G5aL05eMG@1oOgl0Fe]K03Lg=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0F5QH
034a<@1JFUX0De=C0451@@80DU9B0240FUYJ07moO`1;Bd/0GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0
OGem07UiN@27QhL0LW9b04A4A01<C4`0;bl_0:JVYP1FEUH0A4A408N7Q`16ATH0D51@055AD@1dM7@0
FEUI055AD@1BDU80GemO07YjNP0h>3P0DE5A051@D01lO7`00P0j>SX0;@0m?Cd09bLW05MGE`0n?Sh0
9BDU03Ph>013@d<0CDe=02LW9`1=CDd0>3Ph069RHP0[:b/0<c<c04m?C`0l?3`0D51@03Lg=`1<C4`0
=CDe06=SH`0T92@0;bl_04M7A`0^;Rh0HF5Q02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`<300
D51@065QH@1CDe<0>CTi03lo?`11@D40K6a/061PH00k>c/0Bd];06=SH`0206YZJP0P06UYJ@16ATH0
C4a<03<c<`2i^KT0PH6106EUI@1DE5@0Hf=S061PH01[Jf/0OGem04=3@`1_Kfl0MGEe0492@P1gMgL0
HV9R065QH@12@T80J6QX03Xj>P11@D40=cLg05UIF@1oOgl0@d=305iNGP1>CTh0E5AD079bLP1ADE4A
ooooo`003oooool0>`1HF5P0^[Zj071`L01KFe/0GEeM0:6QX@1<C4`0<S8b04Y:BP1?Cdl0J6QX0<G5
a@1TI6@08b<S04M7A`10@400L71`06IVIP0V9RH0:BTY0410@01SHf<0DE5A0;2`/00c<c<092@T08B4
Q02SXj<0Hf=S0;Rh^00c<c<0:2PX06m_K`2RXZ80NWYj07]kN`0a<C407QhN051@D02EUID0IFEU07em
O@2KVi/0:BTY03Lg=`1SHf<0ATI605aLG01BDU809BDU034a<@2;Rh/0UIFE061PH00e=CD09RHV04Y:
BP1=CDd0=SHf0080AdM70340:RXZ04i>CP17AdL0<C4a04Q8B00W9bL0?Shn05=CD`2:RXX0G5aL02l_
;`1:BTX0FUYJ0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0@T9203Xj>P0e=CD0>3Ph06e]
K@2@T9008b<S030`<013@d<0NGUi0;Bd]00j>SX09BDU03Lg=`1JFUX0Kfm_08B4Q02SXj<07AdM0410
@01mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD0080FEUI04/0=CDe07AdM02b/[80Vi^K04a<
C01LG5`0:BTY04=3@`2@T900Cdm?04I6AP1JFUX0:BTY02LW9`1ADE40H61P0492@P0];Bd0CTi>03Ti
>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R03De=@1CDe<0:b/[0492@P1FEUH0NWYj034a
<@0o?cl0IfMW059BDP2IVIT0F5QH03Ph>013@d<0F5QH04a<C01[Jf/0`<3006][J`0f=SH0KVi^04=3
@`1dM7@0c/k>05]KF`0];Bd0Cdm?075aL@2GUiL0Z:RX03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079b
LP0R8R80FEUI06=SH`1QHF40]KFe0451@@0M7Ad0ADE506MWI`1:BTX00P1EEED0=`0f=SH0Fe]K07Ad
M010@400[Jf]06ATI00Y:BT0?clo075aL@1>CTh0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5
A@0h>3P0FEUI0410@01VIVH0B4Q803Ti>@2GUiL0S8b<0410@01WIfL0BDU907QhN02d];@0@T9203/k
>`1CDe<0A4A405iNGP2KVi/0=CDe03Lg=`1MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm0:ZZ
ZP17AdL0;Bd]04Q8B01gMgL0LG5a08B4Q031`L400P0n?Sh0:P1QHF40MGEe09NGU`2KVi/09RHV04I6
AP1EEED0HV9R04];B`35aLD0Fe]K04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0XZ:R06MW
I`2[Zj/0?Shn0410@011@D40Kfm_07UiN@1DE5@0O7al0451@@0o?cl0GEeM07QhN017AdL0FEUI069R
HP0O7al0@41006QXJ01EEED0CDe=08>3P`80:RXZ7?ooool0B01>CTh0IVIV07inOP1UIFD0De=C06=S
H`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH6107moO`2IVIT0LG5a05YJFP19BDT0Fe]K05UI
F@0k>c/0?clo04m?C`1GEeL0FUYJ05mOG`1FEUH0Jf][04i>CP1ADE40H61P06ATI01LG5`0EUIF06EU
I@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0HV9R04U9B@1GEeL0De=C0492@P0c<c<0EeMG051@
D01SHf<0:RXZ04E5A@0i>CT0ADE504Y:BP1TI6@0L71`030`<016ATH0>SXj065QH@1HF5P0EeMG05aL
G01HF5P0[Zj^0861P@14A4@0DU9B06IVIP80F5QH02h0@D5104a<C01KFe/0Bd];059BDP1eMGD0D51@
06MWI`1?Cdl0:RXZ04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`14A4@0BTY:055AD@1[Jf/0;Bd]
04=3@`0N7Qh0@T9204I6AP0[:b/0AdM705ADE018B4P0@41005ADE00l?3`0DE5A04U9B@22PX80HV9R
051@D018B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@4100P12@T80G01^KVh0C4a<06EUI@1KFe/0
MgMg08N7Q`2/[:`0MgMg09:BTP2TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l07EeM@1ADE40
>c/k02TY:@1cLg<0=3@d05UIF@1:BTX0KFe]04e=C@1aLG40/[:b05ADE01/K6`0P820079bLP1EEED0
D51@06YZJP1]KFd0FEUI06][J`0k>c/0bLW909BDU00g=cL0OWin03Hf=P1CDe<0?clo05YJFP11@D40
FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`04M7A`1JFUX0EEEE06IVIP1GEeL0LW9b08b<S02h^;P0
MWIf06e]K@1CDe<0ATI604=3@`0c<c<0EeMG05=CD`1YJFT0ZZZZ0492@P1nOWh0F5QH04=3@`0Z:RX0
Cdm?02h^;P14A4@0GemO059BDP1XJ6P0@d=307AdM010@400K6a/038b<P0?3`l0?Cdm0P0/;2`08`1?
Cdl0Bd];051@D00e=CD0Bd];0410@01NGUh0=SHf03/k>`1=CDd0?Shn04e=C@1;Bd/0GEeM0410@024
Q8@0:b/[03Hf=P15ADD0=3@d05]KF`1;Bd/0>SXj04Y:BP1CDe<0AdM7051@D01ZJVX0AdM705ADE01e
MGD0Kfm_04Y:BP17AdL0E5AD0080GUiN02D0@D5105ADE025QHD0>c/k02PX:01`L700ATI606][J`1B
DU80GEeM05iNGP1]KFd0CTi>05IFEP1UIFD0Q8B408j>SP0N7Qh0A4A404Q8B00W9bL0BTY:02/[:`1@
D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A01OGel0FUYJ04M7A`1oOgl0Fe]K017ooooo
000?ooooo`0E05UIF@1YJFT0OGem0:j^[P1YJFT0EUIF06YZJP1UIFD0TY:B03Hf=P0d=3@0?Cdm065Q
H@13@d<0EEEE02h^;P0i>CT0Bd];04Y:BP1BDU80FUYJ00809RHV0;<0=3@d05ADE01GEeL0Cdm?02h^
;P10@400J6QX03hn?P0a<C40E5AD02/[:`1bLW80NGUi0492@P0k>c/0G5aL038b<P0K6a/0C4a<08F5
Q@0f=SH0AdM70410@01IFET0JVYZ079bLP0G5aL0=CDe04E5A@1eMGD0Y:BT0451@@0P8200BTY:0451
@@1IFET0Vi^K08j>SP0B4Q80ATI60451@@1iNGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A08:2
PP0];Bd0De=C08B4Q01SHf<0^KVi08n?S`0_;bl0=SHf06ATI01]KFd0SHf=03Hf=P0_;bl0C4a<05iN
GP1?Cdl0FUYJ0861P@0a<C40MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0@41002<S
8`15ADD0JVYZ07AdM00^;Rh0;Bd]059BDP0i>CT0FUYJ05aLG00I6AT0<C4a04M7A`1bLW80MWIf07al
O00W9bL0:RXZ04Q8B01WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN01EEED06a/K03hn
?P1lO7`0E5AD0:VYZ@20P800:2PX020P801PH600L71`0:JVYP0b<S8071`L055AD@1WIfL0De=C07If
MP2ATI40>SXj06QXJ02BTY80De=C0:NWY`1kNg/0;bl_04M7A`1SHf<0YjNW06YZJP1[Jf/0>c/k0492
@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1aLG40HV9R05UIF@1gMgL0C4a<04M7A`1OGel0UIFE05EE
E@1ZJVX0?Cdm061PH022PX80WIfM03Ti>@1BDU80IFEU03@d=01QHF40JVYZ03/k>`1HF5P0>CTi03Xj
>P2h^;P0Lg=c02l_;`1GEeL0Bd];069RHP2UYJD0DU9B038b<P0204M7A`0H07MgM`2a/K40MWIf04M7
A`1:BTX0Ng]k08n?S`1VIVH05QHF04e=C@1fMWH0CTi>0;no_`1<C4`0>c/k0:f][@2@T900UIFE08>3
P`0U9BD0@d=307emO@1TI6@0EeMG0P0k>c/0:@1XJ6P0WIfM05aLG02IVIT0QhN704=3@`1SHf<0PX:2
05MGE`1UIFD0OWin03lo?`18B4P0Z:RX059BDP0o?cl0H61P059BDP2OWil0XZ:R03dm?@1;Bd/0Vi^K
0492@P1@D500XJ6Q06][J`0c<c<0DE5A04i>CP1OGel0O7al065QH@0S8b<0=cLg05IFEP1VIVH0QhN7
06UYJ@0N7Qh0?clo0080HF5Q0140I6AT0:2PX01@D500B4Q806][J`1KFe/0BDU907YjNP1`L700:RXZ
01lO7`19BDT0MgMg06=SH`2h^;P0<C4a03dm?@0Looooo`0T05IFEP1JFUX0=cLg03dm?@1ZJVX0GUiN
04E5A@19BDT0GUiN079bLP0i>CT0?Cdm06YZJP1GEeL0FUYJ07inOP1^KVh0J6QX06=SH`19BDT0<c<c
04m?C`1<C4`0@T9204Q8B01@D500BTY:055AD@1BDU80D51@06=SH`14A4@0?3`l05mOG`1LG5`0DU9B
0P1PH600201NGUh0BTY:05=CD`1@D500=SHf04i>CP1=CDd0B4Q80P0b<S80900m?Cd0EeMG03Xj>P16
ATH0>c/k03lo?`0i>CT0Bd];04A4A01XJ6P0EeMG03dm?@0i>CT0@d=305mOG`1;Bd/0CDe=05eMG@1N
GUh0UIFE071`L00b<S80?Cdm05QHF027QhL0D51@04Q8B01;Bd/0C4a<0492@P1?Cdl0F5QH04Y:BP1Q
HF40IVIV0451@@80DU9B06/0>3Ph05QHF019BDT0CTi>01`L701:BTX0I6AT04a<C01eMGD0ADE5061P
H00M7Ad0De=C05IFEP0l?3`0EEEE05ADE01LG5`0?Cdm05]KF`19BDT0NGUi05EEE@2[Zj/0KFe]06=S
H`10@400EUIF05UIF@1hN7P0>3Ph04];B`1/K6`0<c<c04I6AP1?Cdl0DE5A038b<P1=CDd0I6AT069R
HP1=CDd0JVYZ05UIF@2IVIT0GemO03Xj>P1FEUH0/;2`07emO@1`L700VIVI07]kN`1[Jf/0I6AT051@
D013@d<0EUIF04e=C@1PH600;bl_03hn?P1;Bd/0Q8B40;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07Ad
M02PX:00`<30079bLP1LG5`0<C4a0;Zj^P2][Jd0>SXj08:2PP0i>CT0Cdm?03hn?P1PH600<c<c05AD
E01EEED0DU9B06EUI@0o?cl0P8200;Bd]01TI6@0Hf=S05]KF`1EEED0=cLg05IFEP13@d<0S8b<0820
P028R8P0MGEe08J6QP1QHF40<S8b08R8R00204Y:BP0;08R8R018B4P0IFEU06YZJP1?Cdl0@410079b
LP0o?cl0EeMG06IVIP11@D400P1LG5`0DP20P800CDe=06ATI017AdL0>3Ph04U9B@1:BTX0=SHf03hn
?P15ADD0JFUY02PX:01@D500BTY:06ATI00m?Cd0ADE506=SH`10@400Bd];03dm?@1UIFD0>3Ph07Yj
NP0n?Sh0?Cdm04e=C@19BDT0LG5a04M7A`0l?3`0B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG05UI
F@1<C4`0?Cdm04U9B@0Q8B40Hf=S06IVIP0o?cl0C4a<08>3P`1?Cdl0:BTY06][J`1;Bd/0EEEE05=C
D`1^KVh0Hf=S05YJFP1CDe<0IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0=SHf04];
B`0S8b<0EEEE01dM7@14A4@0?clo05mOG`1eMGD0EEEE055AD@1@D500DE5A06UYJ@1NGUhAooooo`00
3oooool2092@T02a05ADE01YJFT0K6a/05YJFP14A4@0AdM707moO`1bLW80<S8b04A4A00h>3P0EUIF
08>3P`0S8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP18B4P0P820071`L00U9BD0=CDe
06EUI@1OGel0De=C09bLW01=CDd0ATI606UYJ@1MGEd0EeMG09^KV`1>CTh07alO03hn?P0i>CT0CTi>
07QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE06QXJ01_Kfl0?Shn06IVIP0f=SH0;2`/
0451@@2OWil0G5aL05EEE@0R8R80<S8b05ADE01MGEd08R8R03Ph>016ATH092@T04U9B@1PH600>SXj
04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0EUIF07inOP17AdL0:BTY05QHF00l?3`0>3Ph
08F5Q@2`/;009RHV04I6AP1NGUh0Bd];08V9R@1mOGd07AdM02PX:01LG5`0QXJ6075aL@0N7Qh06ATI
030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01UIFD0H61P09^KV`2k^k/09bLW04m?C`1ZJVX0I6AT
04Q8B01kNg/0;Bd]04M7A`1]KFd0FUYJ03Ti>@1eMGD0>SXj02<S8`19BDT0Shn?038b<P1:BTX0>CTi
03`l?01SHf<0T92@05ADE010@400BTY:03@d=02>SXh0Shn?02/[:`0e=CD0CTi>030`<00n?Sh0NWYj
03dm?@1;Bd/0BDU904=3@`1eMGD0Rh^;02XZ:P0g=cL0AdM7059BDP1fMWH0LW9b02<S8`0o?cl0Fe]K
065QH@1OGel0WYjN0:NWY`0M7Ad0BDU9069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0T92@
0080@d=306d0PX:20:^[Z`1OGel0Q8B404i>CP0P8200C4a<0820P02@T900X:2P04A4A00[:b/0L71`
08:2PP1?Cdl0W9bL04=3@`0Y:BT0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@2=SHd0?clo
02h^;P2RXZ80]kNg04Y:BP1cLg<0?clo02PX:01JFUX0DE5A069RHP18B4P0=SHf04e=C@1hN7P0?clo
05=CD`1eMGD0@T92092@T01@D500>CTi059BDP1HF5P0DU9B09RHV02DU9@0:b/[05ADE01GEeL0G5aL
0:ZZZP28R8P0>3Ph04Q8B01RHV80K6a/08V9R@1lO7`0<C4a051@D02CTi<0GUiN096AT@3Hf=P0PX:2
03lo?`1FEUH0OWin07EeM@2`/;00>SXj038b<P1`L700UIFE05eMG@2>SXh0EUIF04I6AP1LG5`0U9BD
04Q8B01DE5@0UIFE03Hf=P0];Bd0M7Ad06UYJ@0i>CT0P82004a<C00T92@0IfMW07QhN01HF5P0B4Q8
06QXJ00Y:BT0GUiN08>3P`1^KVh0?Shn01cooooo0680CDe=08B4Q017AdL0CDe=05EEE@1OGel0D51@
04m?C`1ADE40Bd];04=3@`11@D40RXZ:07MgM`1XJ6P0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn
04e=C@1ADE40GUiN07EeM@1;Bd/0?3`l04a<C019BDT0Jf][04Q8B01@D500EUIF061PH01JFUX0IFEU
04M7A`1PH600BTY:04U9B@0m?Cd0ATI604U9B@0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@
0492@P13@d<0;bl_0451@@1MGEd0LG5a06IVIP0e=CD0AdM703Ph>01MGEd0HV9R06ATI01iNGT0Jf][
0:FUY@2DU9@0GemO07UiN@1aLG40EeMG06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1MGEd0LW9b
04Y:BP1;Bd/0CTi>04=3@`1?Cdl0JVYZ0451@@0h>3P0:b/[05eMG@1EEED0IVIV08>3P`15ADD0?Shn
03/k>`80E5AD0200?Shn04e=C@1ADE40AdM704I6AP1ADE40Bd];055AD@1=CDd0[jn_06IVIP1DE5@0
?3`l069RHP1=CDd0EUIF04Q8B01<C4`0GEeM04];B`1UIFD0De=C05ADE00n?Sh0@T9207AdM01YJFT0
GEeM08:2PP0[:b/0OWin061PH080@D5109`0Ti>C03Lg=`1dM7@0]KFe06m_K`1SHf<0FEUI06QXJ00b
<S80FUYJ03Ti>@1CDe<0=SHf04M7A`0g=cL0F5QH09:BTP0j>SX0UYJF03hn?P1hN7P0=CDe08b<S036
a/H0P82008Z:RP1NGUh0;bl_0;6a/@1jNWX0B4Q80:BTY00h>3P0O7al03Xj>P1[Jf/0AdM706a/K015
ADD0DU9B069RHP10@400KFe]08^;R`1>CTh0DU9B05UIF@1ADE40EUIF06MWI`1;Bd/0RXZ:04E5A@28
R8P0M7Ad04];B`0o?cl08B4Q06ATI00m?Cd0E5AD0:^[Z`1?Cdl0I6AT05mOG`1PH6007AdM04=3@`0Z
:RX0JFUY069RHP1YJFT0M7Ad05IFEP1/K6`0DU9B07IfMP0[:b/092@T04m?C`0i>CT0<30`04e=C@1>
CTh0ATI60451@@1CDe<0BDU9059BDP0g=cL0?Cdm04i>CP1?Cdl0G5aL04i>CP1MGEd0@T9208J6QP0`
<300FUYJ06UYJ@1=CDd0GemO03hn?P0O7al0D51@05]KF`17AdL0@D5106IVIP17AdL0EEEE06QXJ018
B4P0JFUY05EEE@1;Bd/0FUYJ06EUI@0O7al0@D5109NGU`0k>c/0=3@d051@D00e=CD0E5AD02`/;01o
Ogl0GUiN04a<C00j>SX0Kfm_06UYJ@1[Jf/0Ng]k03@d=01CDe<0?3`l030`<01^KVh0<c<c04E5A@0a
<C40Hf=S03`l?01HF5P0FUYJ06a/K01dM7@0?clo059BDP1IFET0C4a<0820P023Ph<Aooooo`003ooo
ool0>P2NWYh0[Jf]051@D01GEeL0Ng]k09JFUP1=CDd0@41006e]K@2OWil0Kfm_08>3P`17AdL0:BTY
0::RXP1XJ6P0NWYj04A4A00];Bd0ADE508f=S@1iNGT0Cdm?05mOG`0Z:RX0F5QH09BDU01]KFd0Bd];
07YjNP0T92@0<c<c05YJFP1XJ6P0GEeM05MGE`0^;Rh0@D5105QHF01eMGD0:b/[03Ph>01:BTX0ATI6
08j>SP1QHF407alO04Y:BP16ATH0A4A406IVIP2][Jd0ADE503De=@1BDU80KVi^09FEU@0^;Rh2034a
<@1=075aL@16ATH0PH6101DE5@0o?cl0FEUI06MWI`0k>c/0Jf][05EEE@0K6a/0<C4a04i>CP1YJFT0
[Jf]04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P0h>3P0EUIF08B4Q00k>c/0TI6A06EUI@0S8b<0
ADE506UYJ@1KFe/0I6AT01/K6`0X:2P0FEUI079bLP1FEUH0FEUI04I6AP0O7al0De=C06a/K00`<300
IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX0410@00R8R80<30`08:2PP0l?3`0:b/[04M7A`0f=SH0
ADE505QHF00R8R80?clo08B4Q017AdL0BTY:0:RXZ01^KVh09BDU02TY:@1YJFT0J6QX07UiN@0/;2`0
92@T04E5A@23Ph<00P21PH40U`2PX:00;Bd]06IVIP2ATI40BDU906i^KP28R8P0<30`03/k>`1/K6`0
PX:20;jn_P0g=cL0>c/k05eMG@1hN7P0IVIV07alO02c/k<0?clo0492@P2=SHd0BTY:05QHF02TY:@0
@D51034a<@1>CTh0L71`04Y:BP1LG5`09BDU051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1`L700
F5QH03Ti>@1lO7`0>c/k04I6AP1cLg<0Rh^;03hn?P1>CTh0>CTi05eMG@1oOgl0AdM703dm?@1GEeL0
@d=305MGE`1bLW80Kfm_02/[:`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c09BDU01QHF40
9BDU04E5A@2=SHd0KVi^0:2PX01=CDd0;Bd]059BDP1FEUH0WinO08^;R`0I6AT0Cdm?09jNWP1=CDd0
GUiN09FEU@0N7Qh0>SXj0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500OWin03Ph>00];Bd0
CDe=07emO@1LG5`0V9RH0:6QX@0Q8B40BTY:07AdM010@400GemO04E5A@0f=SH0B4Q806m_K`2=SHd0
Bd];071`L017AdL0?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@1WIfL0;Rh^05eMG@1ADE40
@d=3069RHP2RXZ80NWYj02XZ:P1>CTh0J6QX05eMG@2@T900B4Q802TY:@0h>3P0Cdm?07]kN`1gMgL0
_;bl03Lg=`0^;Rh0JFUY05eMG@1/K6`07?ooool0f01@D500R8R804a<C01<C4`0H61P07MgM`1^KVh0
Jf][06ATI01BDU80@d=304M7A`27QhL0LG5a06i^KP1jNWX0Z:RX07=cL`1<C4`0F5QH03Lg=`1:BTX0
CTi>05=CD`1>CTh0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0BTY:05QHF01bLW80I6AT04i>CP1MGEd0
DU9B061PH01;Bd/0Cdm?05aLG016ATH0E5AD05=CD`1XJ6P0BTY:05MGE`1:BTX0HV9R03hn?P1VIVH0
=SHf04=3@`0`<300?clo0451@@1CDe<0Bd];01`L700o?cl09BDU05YJFP1?Cdl0GEeM05]KF`1QHF40
`/;2071`L00c<c<0?Cdm05YJFP1LG5`0GemO05iNGP1kNg/0De=C04Q8B01ADE40FUYJ04M7A`1MGEd0
IfMW04I6AP1>CTh0B4Q80492@P1DE5@0@41004I6AP0Y:BT0@41004];B`13@d<0E5AD038b<P13@d<0
=CDe069RHP1SHf<0=cLg051@D017AdL0F5QH0410@01UIFD0@D51061PH01QHF40Q8B405iNGP1QHF40
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0l?3`0ATI605UIF@1JFUX0IVIV05UIF@1XJ6P0
MWIf09:BTP15ADD0RXZ:09jNWP15ADD0EEEE0:>SX`0j>SX0Cdm?07UiN@14A4@0L71`04M7A`10@400
<C4a06IVIP12@T80F5QH0410@01DE5@0?3`l05UIF@2BTY808b<S04M7A`0Z:RX0J6QX03Ph>01YJFT0
IfMW05YJFP1HF5P0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`<300O7al03hn?P1=CDd0
@T9204U9B@1=CDd0;2`/07AdM020P800GemO03/k>`1=CDd0C4a<03`l?01KFe/0B4Q806YZJP1KFe/0
Q8B406][J`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026QXH0EEEE07moO`1UIFD0E5AD04I6AP1bLW80
;Bd]06YZJP1`L700ADE505IFEP1UIFD0NWYj03Xj>P0n?Sh08R8R01hN7P1>CTh0@T9204E5A@80@D51
00T0KVi^020P8017AdL0?3`l06ATI00a<C40=cLg05]KF`0m?Cd00P11@D40401/K6`0?clo08b<S00i
>CT0BTY:051@D00_;bl0AdM703Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@206QXJ00W04A4
A015ADD0BDU902d];@1<C4`0EEEE02HV9P0i>CT0I6AT03De=@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FU
Y@1XJ6P0EeMG04I6AP1nOWh0GEeM05IFEP1WIfL0>c/k065QH@13@d<0:2PX055AD@12@T80FUYJ03lo
?`1@D5006ATI03`l?00f=SH0QhN70861P@0j>SX0IVIV0080Cdm?00<0Kfm_04m?Coooool04?ooool0
00oooooo06H0E5AD09RHV01lO7`0QhN7051@D01VIVH0V9RH04m?C`2;Rh/0=SHf03lo?`1_Kfl0MGEe
03Hf=P1/K6`0@T9205EEE@1TI6@0>CTi04a<C01PH600=CDe03/k>`1VIVH0De=C04I6AP1:BTX0AdM7
061PH021PH40@T9202l_;`1NGUh0ADE507inOP2@T900ATI6030`<01:BTX0Cdm?030`<01eMGD0L71`
02h^;P1@D500ATI604E5A@2?Shl0IVIV02@T900b<S80EEEE05IFEP1eMGD0?Shn02TY:@1KFe/0IfMW
04e=C@1PH600AdM702LW9`1ADE40H61P04a<C01eMGD07QhN01XJ6P19BDT0LG5a051@D01MGEd0@d=3
03@d=01eMGD0NWYj03/k>`1bLW80B4Q802HV9P17AdL0RHV905eMG@2<S8`0>CTi038b<P1@D500L71`
0451@@1DE5@0K6a/03Ti>@1KFe/0?clo02PX:01hN7P0>SXj03De=@1<C4`0Kfm_03Ph>01>CTh203Ph
>01:07]kN`1bLW80<C4a03hn?P1=CDd0Cdm?051@D01VIVH0<30`05iNGP1@D500A4A4075aL@2KVi/0
>SXj02XZ:P1FEUH0?clo04m?C`1nOWh0@41003@d=019BDT0LG5a051@D01QHF40EEEE04U9B@1_Kfl0
JFUY05YJFP1bLW80ATI6030`<019BDT0IfMW05iNGP2?Shl0>3Ph020P800o?cl0Jf][06ATI01QHF40
WinO03Lg=`1[Jf/0MWIf04a<C01bLW80IfMW02h^;P1EEED0WIfM079bLP1MGEd0H61P038b<P1;Bd/0
FUYJ06m_K`15ADD0Lg=c06=SH`0c<c<0QhN703lo?`1;Bd/0LW9b065QH@1:BTX0PH6108Z:RP0k>c/3
05IFEP1S09fMW@1^KVh0;bl_04];B`1HF5P0B4Q807MgM`1>CTh0B4Q8055AD@16ATH0M7Ad0:>SX`16
ATH0<S8b04i>CP1UIFD0FUYJ0820P00d=3@0EEEE06e]K@1PH600Hf=S09>CT`0o?cl0BTY:05]KF`1Q
HF40V9RH06UYJ@0a<C40JFUY06i^KP1HF5P0Vi^K03lo?`1WIfL0U9BD04Y:BP1]KFd0OWin03/k>`1=
CDd0RHV905iNGP1`L700?Shn04=3@`1WIfL0N7Qh05=CD`2<S8`0MGEe03Hf=P26QXH0E5AD04];B`20
P800LW9b03`l?01XJ6P0Rh^;04];B`1@D500Kfm_055AD@1jNWX0M7Ad03<c<`1;Bd/0GUiN055AD@1D
E5@0PH6106YZJP1:BTX0EeMG04e=C@1FEUH0SXj>06UYJ@0R8R80ATI6061PH01DE5@0Ng]k05iNGP0X
:2P0?3`l05ADE01KFe/0@d=309RHV01TI6@0=cLg06QXJ01NGUh0>3Ph0080R8R800P0;bl_03`l?01H
F5P0F5QH08:2PP2ATI40A4A403De=Acooooo0240IVIV07AdM01:BTX0B4Q804e=C@1MGEd0BDU904=3
@`1=CDd0C4a<04A4A015ADD0IFEU06ATI01ZJVX0TI6A08Z:RP1PH600CDe=059BDP13@d<0?Cdm04=3
@`12@T80AdM7055AD@1CDe<0DE5A04a<C01@D500IfMW05EEE@1LG5`00P1MGEd01P1VIVH0G5aL04m?
C`1;Bd/0B4Q8055AD@80CDe=02D0CTi>04Q8B018B4P0?clo038b<P18B4P0AdM7038b<P1BDU80=3@d
03dm?@0/;2`0?Cdm03`l?01FEUH0ATI603<c<`1KFe/0<c<c05eMG@19BDT0Jf][05aLG025QHD0T92@
071`L015ADD0Cdm?07IfMP1RHV80LW9b05aLG01]KFd0?clo03dm?@1=CDd0EEEE0080E5AD07@0B4Q8
04a<C018B4P0Bd];04M7A`1QHF40ADE504M7A`0[:b/0B4Q804U9B@12@T80K6a/0410@019BDT0=CDe
069RHP1/K6`0@410055AD@1CDe<0FUYJ04I6AP1ZJVX0BTY:06YZJP1OGel0Xj>S06i^KP1OGel0BDU9
06MWI`1EEED0G5aL05MGE`1ADE40J6QX03lo?`1>CTh0EUIF05iNGP0o?cl0FUYJ06UYJ@1HF5P0HF5Q
07moO`1bLW80QhN706QXJ018B4P0C4a<08V9R@0e=CD0Jf][09VIV@1XJ6P0IfMW06QXJ01ADE40>c/k
061PH017AdL0BDU904i>CP1FEUH0IFEU07EeM@2NWYh0@T9206m_K`15ADD0Ng]k034a<@1TI6@0K6a/
075aL@1bLW80Cdm?0410@034a<@0LW9b0451@@2;Rh/0>SXj06EUI@0Z:RX0EEEE03Xj>P1]KFd0B4Q8
05]KF`1RHV80:BTY06][J`1YJFT0ADE504=3@`1?Cdl0B4Q80410@01KFe/0>3Ph05eMG@10@400Shn?
06ATI01HF5P0BDU9038b<P2DU9@0CDe=065QH@21PH40Bd];08Z:RP80GemO05X0:RXZ04];B`0T92@0
JVYZ05ADE01MGEd0JFUY05]KF`1YJFT0Bd];05UIF@0h>3P0>SXj05=CD`12@T80@d=3055AD@19BDT0
EEEE03<c<`1GEeL0@410055AD@0c<c<0<S8b05EEE@1NGUh0FUYJ05MGE`1XJ6P0?3`l06UYJ@0a<C40
CDe=05IFEP0l?3`0EEEE04Q8B00X:2P0ADE503Hf=P16ATH0;Bd]04U9B@0`<300Bd];05=CD`0`<300
DE5A0492@P0P8200EeMG059BDP0V9RH0BTY:09:BTP12@T80<S8b04m?C`13@d<0EUIF0451@@1NGUh0
HF5Q069RHP1?Cdl0HV9R04Y:BP1`L700MgMg03@d=01<C4`0DU9B0410@01TI6@0=CDe04Q8B010@400
IVIV03Ti>@1BDU80CTi>06UYJ@1_Kfl0EUIF06MWI`1@D500Bd];06i^KP1RHV8Aooooo`003oooool0
2P1fMWH0Lg=c04m?C`1WIfL0G5aL05iNGP11@D40ATI606IVIP1aLG420492@P0j03De=@0`<300PH61
03Hf=P1FEUH0=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM703hn?P1aLG40IFEU02d];@0j>SX0@d=3
03De=@1QHF40XZ:R02TY:@0a<C40GEeM06e]K@1YJFT0/K6a020P800B4Q80@d=307UiN@1cLg<0PH61
02TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0ATI606IVIP1SHf<0S8b<024Q8@0^;Rh0A4A4
065QH@0b<S80GemO01/K6`1>CTh0IVIV07alO017AdL0MWIf04M7A`80>3Ph09L0JFUY05ADE024Q8@0
>c/k04E5A@18B4P0N7Qh03De=@1=CDd0N7Qh02`/;01fMWH0MgMg02d];@1BDU80;Rh^03De=@1CDe<0
MGEe03De=@19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0B4Q8034a<@2FUYH0?3`l01/K6`0c<c<0
FUYJ03Hf=P21PH40JFUY02DU9@12@T80DE5A04Q8B02c/k<0J6QX02<S8`0V9RH0EeMG07MgM`1OGel0
L71`02DU9@1NGUh0KVi^05MGE`1RHV80Xj>S05aLG00E5AD0@T9208>3P`1@D500R8R8034a<@0`<300
EeMG08^;R`1OGel0GEeM06i^KP0g=cL0UIFE0:>SX`1>CTh0GUiN04m?C`0i>CT0G5aL0820P01DE5@0
OGem03Hf=P0Y:BT0QhN708>3P`15ADD0?3`l06][J`0a<C40HF5Q0:2PX019BDT0=3@d06YZJP0a<C40
B4Q808B4Q02?Shl0<c<c04a<C00i>CT0KFe]09^KV`1[Jf/0;Bd]065QH@1;Bd/0HV9R07alO00O7al0
FEUI09RHV01hN7P0K6a/08V9R@1=CDd08B4Q075aL@1TI6@0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D40?Cdm08b<S01UIFD0VYZJ09:BTP0[:b/0Fe]K08J6QP20P800EUIF01hN7P0Z:RX0
Q8B40;6a/@1=CDd0QXJ603Xj>P0W9bL0OGem07IfMP1JFUX0=SHf03@d=019BDT0Shn?0080De=C0440
IVIV02h^;P1UIFD0MWIf04Y:BP2BTY80@D5103@d=01XJ6P0_[jn07MgM`1=CDd0>3Ph03Ti>@1eMGD0
UYJF05=CD`1GEeL0Fe]K05aLG01UIFD0LG5a02h^;P1?Cdl0G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0
@T9206IVIP1lO7`0IFEU02/[:`0/;2`0JVYZ09:BTP1FEUH0LW9b04E5A@0^;Rh0NWYj08>3P`1SHf<0
MGEe08B4Q00a<C40:b/[055AD@28R8P0EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700
:b/[0410@01OGel0Hf=S061PH00Looooo`3o05aLG01QHF40O7al07EeM@1GEeL0JFUY06EUI@1OGel0
FUYJ04i>CP1`L700LW9b07emO@1[Jf/0P8200::RXP27QhL0H61P04e=C@1ADE40@D510410@017AdL0
De=C05mOG`1QHF40Q8B408F5Q@1]KFd0EEEE04i>CP0i>CT0DU9B07EeM@1mOGd0HV9R07EeM@1ADE40
IfMW04i>CP1:BTX0FUYJ04m?C`19BDT0DE5A05eMG@13@d<0=cLg03Ti>@1>CTh0<c<c04i>CP0^;Rh0
>CTi055AD@1QHF40BTY:05IFEP1;Bd/0;bl_051@D00c<c<0EEEE04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL0De=C05mOG`1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@17AdL0
=cLg03Ti>@12@T80<c<c04=3@`10@400>CTi01PH600Y:BT0@D5101lO7`0f=SH0;Rh^0451@@0Q8B40
<30`02l_;`0j>SX0>CTi0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01hN7P0C4a<05UIF@1=CDd0
Cdm?05=CD`1`L700CDe=065QH@1]KFd0@410051@D01BDU80HF5Q04i>CP15ADD0HV9R079bLP2OWil0
_Kfm0:RXZ02FUYH0QhN706][J`1FEUH0Ti>C05]KF`20P800U9BD03lo?`1IFET0G5aL06m_K`1=CDd0
E5AD059BDP1nOWh0ADE504e=C@21PH40Ogmo09^KV`1^KVh0MGEe05IFEP1^KVh0ATI60861P@2JVYX0
UYJF07IfMP1SHf<0H61P0;Bd]01/K6`0?3`l061PH00k>c/0FUYJ03@d=01SHf<0?3`l05iNGP1EEED0
D51@04Y:BP0j>SX0PH6107AdM01CDe<0CTi>04I6AP1<C4`0A4A405YJFP1OGel0P82005mOG`1fMWH0
E5AD05IFEP1?Cdl0@d=30820P01?Cdl0Lg=c09bLW01EEED0`<3006=SH`16ATH0>CTi07MgM`0H61P0
De=C03Xj>P1ADE40EUIF06a/K01LG5`0>CTi0492@P0h>3P0<c<c06UYJ@15ADD0>c/k0492@P1;Bd/0
Fe]K02TY:@16ATH0@d=304U9B@0Z:RX0:2PX059BDP0n?Sh0?clo04i>CP1VIVH0E5AD0:NWY`11@D40
C4a<04U9B@0b<S80=cLg04A4A00R8R80E5AD02h^;P0o?cl0<C4a04e=C@13@d<0FEUI04Y:BP0o?cl0
?Cdm04A4A01;Bd/0RXZ:07inOP0d=3@0DU9B000S065QH@1<C4`0A4A405MGE`0Y:BT0GUiN05YJFP22
PX80OGem05=CD`1OGel0JVYZ02`/;01GEeL0Rh^;04M7A`1HF5P0Bd];03dm?@1ADE40@T9205ADE01M
GEd0IVIV03/k>`18B4P0A4A407AdM01EEED0ADE505ADE015ADD0D51@08J6QP1KFe/04Oooool000oo
oooo0;<0NWYj09RHV01GEeL0FUYJ06EUI@2c/k<0HF5Q0410@01/K6`0F5QH0820P02n_[h0H61P030`
<01JFUX0Ng]k09^KV`2FUYH07alO04E5A@1^KVh0P8200451@@1gMgL09bLW05eMG@2`/;00B4Q807If
MP1/K6`08b<S04i>CP19BDT0A4A405iNGP1:BTX09bLW05eMG@1iNGT0KFe]03Lg=`1OGel0DE5A0492
@P2MWId0FEUI030`<01JFUX0?3`l02`/;01jNWX0][Jf03Hf=P0k>c/06QXJ03De=@2CTi<0KFe]02LW
9`1PH600B4Q803hn?P2@T900<C4a0410@00n?Sh0<C4a04U9B@2i^KT0OGem02DU9@1=CDd0MgMg06m_
K`2a/K40CTi>01lO7`1GEeL0D51@059BDP2VYZH0hN7Q038b<P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ
6P0j>SX0Rh^;06][J`21PH40>CTi028R8P1KFe/0^KVi08j>SP2:RXX0R8R802l_;`1ADE40P82005eM
G@2;Rh/0?Cdm02d];@0i>CT0J6QX0492@P1EEED0De=C0410@01BDU80QHF503@d=013@d<0F5QH02/[
:`0n?Sh0NWYj01dM7@0e=CD0EUIF03`l?00/;2`0PH610:FUY@0/;2`0<C4a055AD@11@D40MgMg05aL
G00H61P0AdM705EEE@0f=SH0NGUi0;Fe]@0g=cL0>c/k05MGE`13@d<0Xj>S07emO@0M7Ad0De=C065Q
H@1OGel0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0?Cdm08b<S01NGUh0O7al0;^k
^`16ATH08b<S059BDP28R8P0JFUY0;2`/00g=cL0>c/k05aLG02DU9@0Hf=S0;Rh^01LG5`0@D5106AT
I00205=CD`1C0:n_[`0`<300?3`l07inOP1jNWX08B4Q05MGE`0V9RH0EUIF0:ZZZP1ZJVX0EEEE05eM
G@0^;Rh0GemO07inOP21PH40=cLg05QHF01@D500WYjN09>CT`0g=cL0@D5105=CD`1BDU80O7al04i>
CP0U9BD0EUIF06=SH`1WIfL0YJFU05ADE00d=3@0C4a<05]KF`2;Rh/0LG5a01hN7P1>CTh0IVIV05IF
EP1lO7`0YJFU03/k>`1@D500NWYj079bLP2/[:`0?Cdm030`<00i>CT0SXj>09JFUP29RHT09bLW04I6
AP1KFe/0OGem06ATI01kNg/0LG5a02TY:@1DE5@0Kfm_05QHF02?Shl0CDe=03@d=01GEeL0Ng]k06m_
K`1EEED0KFe]0410@01WIfL0QHF505UIF@13@d<0Jf][055AD@11@D400P1jNWX0600k>c/0Lg=c06UY
J@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@13@d<0B4Q8075aL@1BDU80:2PX03hn?P1@D500DE5A05=C
D`1iNGT0>3Ph04I6AP1@D500ATI607UiNAcooooo00H0KFe]06][J`17AdL0Bd];05=CD`1TI6@204A4
A00?065QH@0l?3`0@4100451@@1ZJVX0QhN707=cL`28R8P0VYZJ07YjNP1XJ6P0H61P03De=@19BDT0
Cdm?0080DE5A00@0G5aL04A4A015ADD0CDe=0P1_Kfl0G019BDT0EEEE075aL@1aLG40I6AT0820P01Z
JVX0Kfm_06=SH`1IFET0G5aL04a<C01QHF40E5AD05=CD`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c
<c<0?Cdm02/[:`15ADD0E5AD06UYJ@1NGUh0>3Ph05MGE`0^;Rh0F5QH06MWI`1OGel0DE5A092@T02E
UID0Ogmo04=3@`1:BTX0NGUi06ATI01CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@1F
EUH0ATI605=CD`1RHV80CDe=05EEE@1?Cdl0FEUI02/[:`13@d<0FEUI03Hf=P1LG5`0?Shn05mOG`0_
;bl0DE5A05=CD`1;Bd/0ADE5059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06i^KP1;
Bd/0De=C07AdM02FUYH0@T920451@@13@d<0;bl_0492@P1>CTh0=SHf0P0o?cl0Y@20P800F5QH06QX
J01gMgL0YJFU0:RXZ01ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0m?Cd0;Bd]01PH
6017AdL0I6AT07=cL`28R8P0PH6108J6QP29RHT0XZ:R06QXJ01eMGD0FUYJ07MgM`0g=cL0Kfm_08N7
Q`2SXj<0Vi^K0410@01bLW80SXj>059BDP1;Bd/0JFUY03Ti>@1SHf<06a/K04Q8B00c<c<0KVi^06=S
H`1VIVH0DU9B05iNGP1MGEd0IFEU059BDP0^;Rh0Cdm?04U9B@1?Cdl0FUYJ04I6AP2>SXh0De=C0:JV
YP1VIVH0QhN706QXJ01:BTX0OWin05mOG`1kNg/0QXJ604i>CP24Q8@0JVYZ05EEE@0o?cl0CTi>024Q
8@1NGUh0<c<c069RHP1HF5P0C4a<03Hf=P13@d<0FEUI01/K6`0X:2P0@41002l_;`16ATH0@d=303dm
?@1<C4`06a/K059BDP0g=cL0>3Ph02h^;P0O7al0De=C04=3@`16ATH0IVIV07MgM`0b<S80FEUI02@T
901KFe/0H61P04I6AP17AdL0=cLg020P801ADE40A4A404];B`1YJFT0MgMg05UIF@1BDU80KFe]051@
D01NGUh0D51@03dm?@1;Bd/0BDU903hn?P1;Bd/0EeMG03`l?00b<S80I6AT04m?C`1LG5`092@T071`
L00g=cL0Bd];059BDP26QXH0CTi>05]KF`1fMWH0<c<c06IVIP16ATH0;Bd]04U9B@0b<S80=3@d03lo
?`1TI6@0:2PX04a<C00k>c/0UYJF065QH@18B4P0Lg=c05EEE@1KFe/0PH6106IVIP0Aooooo`003ooo
ool0o`1OGel0LG5a079bLP2OWil0E5AD06EUI@2RXZ80Kfm_0:2PX00^;Rh0@41005ADE01aLG40?Cdm
04i>CP18B4P0H61P09:BTP1RHV80=CDe0492@P0c<c<0B4Q806IVIP0Z:RX0?3`l038b<P10@400KFe]
07emO@0_;bl0;Bd]051@D01UIFD0/;2`09fMW@0K6a/09RHV05IFEP1]KFd0E5AD075aL@1_Kfl07alO
05IFEP1YJFT0Fe]K08>3P`1@D5006a/K034a<@27QhL0Ti>C07inOP0U9BD0A4A4055AD@1_Kfl0Fe]K
09fMW@14A4@0;Rh^06IVIP1:BTX0^;Rh09ZJVP0M7Ad08B4Q04A4A01lO7`0B4Q807inOP1dM7@0<C4a
04M7A`1oOgl0>CTi08J6QP0i>CT08B4Q04M7A`1nOWh0FEUI04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c
04=3@`0k>c/0:2PX05QHF00l?3`092@T03hn?P0/;2`0=cLg059BDP1^KVh0:b/[02PX:00g=cL0<30`
07moO`1ZJVX06ATI030`<00e=CD0BDU905iNGP1VIVH092@T0451@@1GEeL0L71`08B4Q023Ph<092@T
034a<@1aLG40G5aL06EUI@2ATI40<S8b02d];@11@D40Shn?075aL@20P800DE5A05ADE01FEUH0Rh^;
04I6AP23Ph<0Kfm_030`<01>CTh0Hf=S07YjNP2;Rh/0?Shn02d];@0h>3P0JFUY04a<C01_Kfl0OWin
0410@01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L018B4P0E5AD0410@00n?Sh0Ng]k
08V9R@0c<c<0H61P03/k>`0M7Ad0KFe]05UIF@0j>SX0E5AD04A4A00e=CD0GemO07YjNP0^;Rh0D51@
04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN03dm?@0Y:BT0H61P05IFEP1gMgL0YjNW
02XZ:P0j>SX0JVYZ06MWI`1aLG40VYZJ02TY:@0f=SH0OGem05aLG027QhL0Shn?038b<P1GEeL0QhN7
05YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40Bd];05EEE@2?Shl0?3`l075aL@1HF5P0>SXj
03Lg=`2DU9@0T92@05eMG@0c<c<0CTi>05EEE@1CDe<0;Rh^059BDP1IFET0<c<c06a/K012@T80>3Ph
05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`04A4A01iNGT0FEUI0:b/[01oOgl0<C4a051@D01GEeL0Cdm?
05iNGP00101aLG40@d=303@d=01RHV8206IVIP0M09^KV`1`L7007alO03Ph>01eMGD0Bd];08R8R01k
Ng/0<c<c03`l?01HF5P0NGUi05YJFP2DU9@0?Shn03Ph>01EEED0KVi^05=CD`1iNGT0KFe]01hN7P15
ADD0Cdm?05ADE01/K6`0Kfm_01`L701BDU807?ooool0701ZJVX0Ng]k04m?C`1>CTh0I6AT07QhN019
BDT0A4A4069RHP16ATH0>SXj0410@01nOWh0OGem07YjNP2>SXh0XZ:R079bLP1HF5P0DE5A02h^;P0_
;bl0@D5104M7A`18B4P0DU9B04i>CP11@D4204A4A00?059BDP12@T80G5aL06m_K`1TI6@0FEUI061P
H00d=3@0Cdm?04A4A01=CDd0DE5A04Y:BP1DE5@0B4Q80080?Cdm0280<c<c055AD@0m?Cd0;2`/05IF
EP1=CDd0BDU9030`<014A4@0IFEU0:JVYP1mOGd0@d=304];B`1MGEd0KVi^04=3@`1HF5P0BTY:07em
O@3Ogml0Vi^K04];B`12@T80HF5Q08^;R`1KFe/0I6AT075aL@16ATH0=3@d055AD@1HF5P0De=C0P16
ATH0601EEED0D51@04M7A`1:BTX0I6AT03Xj>P0i>CT09BDU04M7A`15ADD0<30`06IVIP0^;Rh0>SXj
02XZ:P1HF5P0De=C04m?C`16ATH0F5QH05UIF@1<C4`0F5QH04a<C080EEEE02<0YZJV06EUI@1OGel0
DE5A06QXJ01>CTh0EEEE0492@P1IFET0De=C05UIF@1PH600CDe=03dm?@1;Bd/0@D51059BDP0_;bl0
KVi^07moO`1<C4`0IVIV06QXJ01hN7P0BDU9079bLP0I6AT0E5AD09NGU`0c<c<0G5aL04];B`17AdL0
<C4a04e=C@02038b<P1N03lo?`0h>3P0MGEe07MgM`1QHF40F5QH08f=S@12@T80K6a/02PX:02o_kl0
ZJVY07YjNP1WIfL0C4a<07QhN02CTi<0JFUY04a<C01YJFT0=3@d05MGE`0_;bl0JFUY04M7A`1OGel0
=3@d05=CD`1<C4`05QHF05UIF@1HF5P0Cdm?04i>CP1LG5`0IfMW04a<C01WIfL0A4A407alO00k>c/0
Hf=S04i>CP15ADD0AdM704];B`1YJFT0G5aL05MGE`28R8P0Lg=c0:2PX01MGEd0FUYJ04U9B@1IFET0
Cdm?06MWI`1:BTX0FEUI04U9B@1IFET0;2`/04A4A01CDe<071`L02d];@1<C4`0<30`0410@017AdL0
BDU905EEE@0j>SX0Bd];04e=C@1BDU80?Shn03Ph>01BDU80GemO05IFEP1LG5`0FUYJ03De=@1bLW80
9BDU04E5A@1BDU80@T92055AD@12@T80@d=306ATI080ATI60300=cLg05iNGP14A4@0Fe]K05UIF@1;
Bd/0@D5103hn?P0Y:BT0C4a<04e=C@0J6QX0EEEE061PH014A4@0=CDe055AD@0k>c/0Cdm?0492@P1i
NGT0B4Q8069RHP15ADD0D51@055AD@1aLG40P8200492@P1DE5@0=CDe02`/;01=CDd0>CTi0451@@1X
J6P0QXJ604m?C`1<C4`0DE5A071`L01PH600Cdm?05mOG`1SHf<0Cdm?06QXJ01UIFDAooooo`003ooo
ool0d01WIfL0JFUY06MWI`2GUiL0IFEU04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG
06a/K00Q8B40;Rh^06IVIP1_Kfl0WIfM08V9R@0S8b<09RHV04i>CP1LG5`0`l?304U9B@0K6a/0BTY:
075aL@0m?Cd0HF5Q07emO@0U9BD0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0JVYZ
08N7Q`0D51@0=3@d04=3@`1HF5P0=CDe05eMG@1WIfL05QHF06i^KP0k>c/0BDU905eMG@0O7al0;Rh^
07EeM@2a/K40@41003De=@0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`1]KFd09bLW
04I6AP1:BTX0JFUY09nOW`1[Jf/061PH02d];@13@d<0JVYZ0:b/[01JFUX092@T04i>CP11@D40>CTi
08>3P`2MWId06ATI0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901EEED0ADE507AdM00G5aL08R8R
03hn?P1gMgL0BTY:07EeM@1XJ6P061PH02h^;P1aLG40=cLg079bLP0f=SH09BDU05ADE01QHF40IVIV
0492@P17AdL0>CTi04Y:BP1OGel0JFUY03De=@1IFET0;Rh^030`<00c<c<0J6QX02l_;`1GEeL0>3Ph
02l_;`1JFUX0Vi^K055AD@1?Cdl0G5aL03hn?P27QhL0MGEe03De=@18B4P0@d=3034a<@1RHV80RHV9
02l_;`1<C4`0Bd];05eMG@2EUID0WIfM03`l?00h>3P0DU9B06EUI@23Ph<0MgMg02TY:@12@T80@d=3
07IfMP1NGUh0`/;20:>SX`0_;bl0C4a<06a/K020P800YZJV0451@@0d=3@0I6AT0820P01QHF40I6AT
02PX:01CDe<0J6QX07alO01QHF40RHV908^;R`0b<S80>SXj07EeM@1ZJVX0LW9b02TY:@0j>SX0DE5A
04e=C@0n?Sh0Ng]k02XZ:P13@d<0OGem05EEE@1@D500DE5A01lO7`1<C4`0Shn?06a/K01SHf<2038b
<P0?09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b013@d<0FEUI065QH@10@400R8R80:6QX@0Q8B40
:RXZ0080Cdm?03l0PH6102h^;P13@d<0KVi^06][J`1?Cdl0UYJF08^;R`0^;Rh0FUYJ05=CD`1VIVH0
QhN7061PH00^;Rh0FEUI09:BTP1>CTh0O7al05eMG@1OGel0HV9R0:6QX@1<C4`0MgMg0820P00k>c/0
BDU9065QH@1/K6`0M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD06ATI01DE5@0?clo05UIF@1iNGT0
<30`0451@@1dM7@0@T9202<S8`1_Kfl0JVYZ03Ti>@1>CTh0>c/k028R8P1=CDd0VIVI03<c<`0`<300
Lg=c03Hf=P1OGel0XZ:R03`l?00c<c<07?ooool09`1/K6`0O7al05UIF@1QHF40F5QH06EUI@1aLG40
FEUI071`L00a<C40Hf=S079bLP2<S8`0O7al092@T03Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0
D51@05]KF`1@D500FUYJ07]kN`1LG5`0FEUI05=CD`1SHf<0HV9R08B4Q01gMgL0Q8B408>3P`29RHT0
GUiN075aL@0205=CD`0605mOG`1LG5`0Hf=S05=CD`1/K6`0EEEE0P1:BTX0>@1BDU80?Shn05mOG`0g
=cL0>SXj03Ti>@12@T80Bd];05MGE`1<C4`09RHV051@D013@d<0De=C03Xj>P1XJ6P0IfMW06][J`1V
IVH0H61P05YJFP1KFe/0EeMG055AD@1FEUH0A4A406][J`0[:b/0?Shn06IVIP1JFUX0>c/k03hn?P14
A4@0B4Q803Ph>00o?cl0AdM7055AD@11@D40De=C03dm?@1;Bd/0B4Q803hn?P1PH600AdM7055AD@0l
?3`0BDU904a<C01:BTX0Cdm?05IFEP1NGUh0DU9B075aL@02069RHP2f06ATI02:RXX0MGEe06QXJ01W
IfL0GemO05aLG01nOWh0?clo07=cL`1dM7@0?3`l03Ph>01ADE40HV9R0492@P13@d<0EeMG03Xj>P2>
SXh0SHf=07=cL`28R8P0PX:205mOG`1DE5@0TY:B01<C4`20P800Y:BT02LW9`2<S8`0A4A403<c<`0U
9BD0Fe]K03`l?011@D40Bd];04a<C01nOWh0QhN707inOP0i>CT0DE5A03`l?01WIfL0:2PX05mOG`2?
Shl0QXJ605ADE016ATH0PX:20;2`/01LG5`0@41005aLG016ATH0E5AD03De=@18B4P0?Shn0861P@10
@400GEeM055AD@0^;Rh0I6AT05mOG`1WIfL0C4a<051@D011@D40GUiN08j>SP1eMGD0RHV906MWI`2@
T900HV9R05ADE00g=cL0=SHf0861P@1LG5`0EeMG0820P01GEeL0/k>c06e]K@1SHf<0?clo04i>CP0H
61P0M7Ad04Q8B01KFe/0De=C06EUI@1:BTX0DU9B04a<C018B4P0=SHf05=CD`19BDT0CTi>05QHF017
AdL0GEeM03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0ATI605iNGP1/K6`0BTY:0820P016
ATH0D51@05=CD`1KFe/0EeMG04M7A`0L71`0F5QH0410@01BDU80Bd];04A4A017AdL0DE5A04I6AP0_
;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?01NGUh0AdM7059BDP11@D40DE5A04E5A@2Q
XJ40@D51075aL@1DE5@0KVi^01lO7`1ADE40Lg=c03De=@1DE5@0Fe]K04A4A01;Bd/0B4Q805MGE`1T
I6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l05iNGP17AdL0DU9B08B4Q01CDe<Aooooo`003ooo
ool04020P800VIVI051@D01[Jf/0LG5a0:2PX016ATH0AdM7061PH01JFUX0GemO06i^KP0j>SX0?Shn
05ADE011@D42055AD@1901hN7P0j>SX0Ph>3075aL@16ATH0De=C01`L701?Cdl0Rh^;04A4A00/;2`0
@d=302d];@12@T80VYZJ02PX:00f=SH0CTi>034a<@1IFET0^KVi04m?C`0K6a/0>CTi03Ph>01SHf<0
]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0QHF50;2`/00M7Ad0AdM704I6AP1UIFD0Kfm_020P800m?Cd0
FUYJ08R8R01cLg<0ATI602DU9@0/;2`0BDU906EUI@1cLg<0Y:BT02d];@0W9bL0:BTY05IFEP16ATH0
Ph>3020P800[:b/0N7Qh08B4Q00c<c<0H61P07IfMP0o?cl0IVIV069RHP1EEED0NWYj0492@P0];Bd0
@d=308Z:RP0205]KF`1M038b<P0d=3@0FUYJ08n?S`11@D40@T9205UIF@0H61P0GemO04a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04E5A@1IFET0Ogmo07inOP0I6AT0;Rh^059BDP0d=3@0
OWin09NGU`0J6QX0@d=30451@@1:BTX0HF5Q0;Zj^P1eMGD08B4Q0451@@1KFe/0PH610:b/[00d=3@0
<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:008B4Q061PH01dM7@0IfMW08j>SP19BDT0;2`/04A4A027QhL0
NGUi08N7Q`0O7al0=SHf061PH02@T900Cdm?06i^KP25QHD0:BTY05MGE`1iNGT0<C4a04a<C029RHT0
9BDU02PX:01;Bd/0N7Qh04e=C@1ZJVX06a/K04Y:BP1IFET0IfMW03Hf=P1NGUh0De=C03Ti>@1iNGT0
;Rh^03Xj>P1cLg<0>3Ph04Y:BP1SHf<0TY:B0080@d=301@0<c<c06e]K@1iNGT0>3Ph02l_;`1MGEd0
A4A407UiN@2][Jd0Fe]K03<c<`1OGel0C4a<09>CT`28R8P08R8R02h^;P18B4P0EUIF08n?S`80=cLg
0500CTi>06IVIP21PH40W9bL024Q8@0^;Rh0MgMg079bLP1_Kfl0=cLg02DU9@1JFUX0W9bL07moO`1:
BTX0NGUi03dm?@1aLG40KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01WIfL06a/K055AD@24
Q8@0M7Ad03Xj>P1OGel0IVIV02d];@1ADE40M7Ad03lo?`1iNGT0CDe=03<c<`1QHF40][Jf06YZJP0o
?cl0JVYZ04E5A@1LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K06m_K`0O7al0>CTi05mOG`1@
D500H61P09ZJVP14A4@092@T03Lg=`1RHV80J6QX09bLW00o?cl0:b/[03Ph>01YJFT0GEeM06=SH`2X
Z:P0=SHf04e=C@1;Bd/0EEEE06ATI1cooooo00<0PX:206i^KP1GEeL00P1FEUH0H01BDU80AdM704a<
C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1UIFD0BDU905ADE01MGEd0EeMG04a<C00k>c/0CDe=03/k
>`0Z:RX0?clo04I6AP0X:2P0<c<c04=3@`1NGUh0D51@03`l?01=CDd0FEUI051@D01]KFd0Hf=S06QX
J01?Cdl0A4A40492@P15ADD0A4A4051@D01<C4`0E5AD06IVIP13@d<0D51@05EEE@1IFET0Hf=S03Ph
>01;Bd/0TY:B0;Jf]P1;Bd/0O7al06i^KP0m?Cd0FEUI02TY:@1NGUh0ATI606EUI@1/K6`0RXZ:08j>
SP2UYJD0B4Q804U9B@1oOgl0T92@04M7A`19BDT0IfMW05QHF01bLW80Shn?06IVIP15ADD0Fe]K05mO
G`1;Bd/0De=C04i>CP1DE5@0IfMW04U9B@1EEED0>c/k04Y:BP1JFUX0ADE506a/K00d=3@0JFUY0410
@01FEUH0Cdm?04I6AP80EeMG01P0GEeM05ADE01MGEd0D51@07EeM@1cLg<0TY:B04a<C01gMgL0GUiN
06IVIP1IFET0IfMW07IfMP1cLg<0I6AT03Ph>01:BTX0N7Qh05aLG013@d<0C4a<07EeM@1CDe<204];
B`0?0;6a/@2=SHd0ADE504=3@`1KFe/0[:b/02`/;025QHD0WinO02`/;01VIVH0>c/k02HV9P0G5aL0
>CTi0080<C4a04H0Ng]k04a<C01GEeL0MgMg0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IFEP1<C4`0
Bd];065QH@1:BTX0N7Qh0::RXP1QHF40DE5A05YJFP15ADD0N7Qh03Ti>@1GEeL0FUYJ06a/K013@d<0
F5QH04a<C010@400LG5a0492@P13@d<07alO059BDP1DE5@0EEEE06EUI@1OGel0T92@04=3@`2EUID0
EeMG04i>CP0m?Cd0?clo07inOP1QHF40S8b<08Z:RP10@400IFEU05YJFP1;Bd/0DE5A05ADE00W9bL0
EeMG03<c<`1PH600F5QH06][J`13@d<0Fe]K05mOG`0Y:BT0A4A404e=C@0`<300B4Q80P1:BTX0B00o
?cl0?Cdm04Q8B00o?cl0@D5104A4A00f=SH0D51@05=CD`1;Bd/0G5aL06IVIP0k>c/0HV9R024Q8@1B
DU80BTY:0492@P1:BTX0@T9203Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80C4a<04Y:BP1N
GUh0B4Q8020P801<C4`0BTY:02LW9`1FEUH0GemO05aLG01>CTh0MGEe04=3@`17AdL0:b/[05EEE@1<
C4`0KFe]051@D01dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0a<C40BDU906MWI`1M
GEd0<30`0410@00k>c/0VIVI0492@P0m?Cd0GemO04m?C`1LG5`0Lg=c05UIFA7ooooo000?ooooo`1I
05UIF@1hN7P0DU9B05MGE`1>CTh0Ng]k06EUI@12@T80E5AD04a<C021PH40UYJF04=3@`0/;2`0Bd];
06=SH`2SXj<0WIfM02/[:`0B4Q80>CTi059BDP1WIfL0[Jf]02h^;P0e=CD0D51@06EUI@2@T900R8R8
01hN7P0^;Rh0De=C06IVIP2_[jl0JFUY03Xj>P0/;2`0FUYJ07AdM01XJ6P0L71`038b<P12@T80FUYJ
06e]K@1=CDd0`l?303Hf=P0N7Qh0=SHf09BDU01fMWH0De=C02@T900b<S80ADE501/K6`0h>3P0JFUY
02d];@0k>c/0T92@02TY:@18B4P0=SHf01hN7P19BDT0WinO05IFEP0J6QX0Bd];04A4A01^KVh0^;Rh
05=CD`0K6a/0<c<c05QHF01FEUH0MGEe0:VYZ@0[:b/0DE5A0492@P1KFe/0[Jf]04e=C@0K6a/00P18
B4P06`1HF5P0P82002/[:`0T92@0ADE504=3@`11@D40Kfm_0:NWY`0V9RH0A4A405]KF`1LG5`0VYZJ
055AD@0X:2P0?clo065QH@1OGel0N7Qh04Q8B00`<300CTi>05QHF016ATH0EEEE07moO`0202/[:`2Z
08>3P`0e=CD0DU9B03Hf=P0/;2`0:BTY06=SH`2FUYH0?clo05EEE@0o?cl0De=C08F5Q@27QhL0=CDe
0820P00o?cl0<30`07=cL`34a<@0IVIV08F5Q@0d=3@0;Bd]07MgM`27QhL0;2`/04=3@`1DE5@0GUiN
0=;BdP1KFe/0:2PX04A4A01KFe/0IfMW07moO`2d];@0@41004=3@`1OGel0GEeM08V9R@2IVIT0A4A4
034a<@1<C4`0DU9B05aLG02NWYh08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<02>SXh0HV9R
06UYJ@2>SXh0=SHf01dM7@1?Cdl0Y:BT075aL@1dM7@0<30`05=CD`1nOWh0N7Qh05YJFP2LW9`0=SHf
02/[:`2DU9@0ZZZZ04];B`1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600<S8b06YZJP1oOgl0D51@
05QHF00e=CD0Bd];09ZJVP1bLW80=CDe05EEE@1;Bd/0Rh^;06ATI00Q8B40CDe=0451@@17AdL0KVi^
08:2PP0h>3P0Cdm?04e=C@1mOGd0ZZZZ04E5A@0f=SH0EUIF06e]K@1EEED0WIfM030`<00[:b/0F5QH
06MWI`1NGUh0[Zj^09JFUP0c<c<0@41005UIF@1bLW80alO706QXJ00e=CD0>3Ph05UIF@1aLG40I6AT
0:RXZ01EEED0HF5Q06UYJ@1aLG40KVi^09ZJVP1WIfL0=SHf06ATI02BTY80DE5A09bLW01]KFd0:b/[
04];B`1jNWX0L71`038b<P1SHf<0=SHf03Lg=`1`L700LW9b03hn?P1iNGT0M7Ad03Ph>00c<c<0I6AT
06=SH`1]KFd0?3`l02@T901ADE4Looooo`1<0861P@1VIVH0BTY:059BDP20P800Lg=c04i>CP1MGEd0
UYJF04];B`1EEED0CTi>06EUI@1]KFd0Kfm_0861P@1aLG40I6AT06e]K@1IFET0@d=305=CD`1KFe/0
ATI605MGE`1FEUH0JFUY03<c<`1?Cdl0Xj>S08J6QP17AdL0DE5A07moO`1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01dM7@0MGEe05MGE`1MGEd0?Cdm09:BTP1>CTh0=3@d05=CD`0m?Cd0
=cLg02l_;`15ADD0De=C0:FUY@1LG5`0@D5105MGE`0c<c<0DU9B04a<C01GEeL0OGem07AdM02MWId0
MGEe04];B`1=CDd0K6a/061PH01;Bd/0BDU906a/K080<30`0P1PH6004P1RHV80>c/k0410@00m?Cd0
>c/k04Y:BP1<C4`0G5aL03/k>`13@d<0=3@d04Q8B01@D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<
06d0DE5A04I6AP1HF5P0FEUI055AD@1EEED0E5AD075aL@1KFe/0VIVI06QXJ01[Jf/0GUiN06ATI01n
OWh0Xj>S03`l?01lO7`0SHf=04];B`1=CDd0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:
RXX0NGUi04U9B@1iNGT0KVi^09bLW01iNGT0SHf=0<W9b@1FEUH0O7al04=3@`0Y:BT06ATI03Hf=P0d
=3@0<30`03/k>`0`<300L71`07alO01XJ6P0@D5106QXJ00l?3`0KFe]01DE5@1FEUH0<C4a024Q8@23
Ph<0=CDe05mOG`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0EUIF03<c<`1^KVh0<c<c06IVIP19
BDT04Q8B04];B`0a<C40BTY:038b<P1VIVH0CTi>04m?C`1PH600DE5A09FEU@0k>c/0MGEe05aLG022
PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1LG5`0EUIF04m?C`15ADD0>SXj05mOG`0T
92@0@T9204];B`1>CTh05aLG0080<C4a04l05ADE03De=@1>CTh0820P03hn?P1=CDd0B4Q804i>CP0i
>CT0F5QH055AD@15ADD0DU9B03Hf=P1@D500PH6106MWI`1NGUh0CDe=0451@@1UIFD071`L03Hf=P0`
<300>c/k05iNGP12@T80CTi>04A4A00k>c/0ATI605mOG`1LG5`0@D5104];B`25QHD0?clo020P800M
7Ad0:b/[04e=C@0l?3`0:b/[079bLP1aLG40BDU903Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f
][H0DE5A06YZJP17AdL0Ogmo07]kN`0f=SH0@41003De=@0k>c/0Bd];03Xj>P13@d<0IFEU065QH@0f
=SH0BTY:05YJFP3@d=00GUiN05=CD`1oOgl0De=C04U9B@1iNGT0H61P017ooooo000?ooooo`0R05QH
F024Q8@0PX:20;Rh^01:BTX0CTi>08V9R@2GUiL0V9RH024Q8@12@T80I6AT05iNGP1XJ6P0KVi^030`
<01CDe<0Ti>C06i^KP1QHF40Hf=S02TY:@0g=cL0Bd];06MWI`1`L700>c/k03@d=01MGEd0IfMW03Ti
>@0[:b/0GEeM03@d=080Cdm?06L08b<S03<c<`1NGUh0;bl_05YJFP1oOgl0>SXj02d];@1?Cdl0=cLg
06i^KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02ATI40;2`/0492@P1OGel0>SXj06QXJ02l_;`0?3`l
030`<01<C4`0=SHf08>3P`1hN7P06QXJ02`/;01OGel0LG5a04m?C`3EeMD0EeMG04m?C`1gMgL0V9RH
065QH@2<S8`07QhN03Ph>01GEeL0Kfm_04i>CP1CDe<092@T03De=@1[Jf/0T92@03Lg=`1RHV80=cLg
02PX:022PX80KFe]0451@@1eMGD0<c<c01HF5P1@D500YJFU08N7Q`0i>CT0:2PX02l_;`1fMWH0Ng]k
03@d=00l?3`0;2`/02DU9@1DE5@0MGEe01dM7@15ADD0FEUI04m?C`1]KFd0NGUi01hN7P0K6a/0FUYJ
03/k>`1jNWX0H61P01`L700W9bL0@D5108B4Q01BDU80GemO04e=C@0Q8B40FEUI07moO`1?Cdl0[Jf]
06=SH`0I6AT0@T920080NWYj0700dM7A03Xj>P0o?cl0D51@065QH@19BDT0Lg=c08:2PP0R8R80I6AT
05QHF01?Cdl0IFEU03<c<`0Q8B40DE5A07moO`1]KFd0RXZ:04i>CP0S8b<0De=C07MgM`1YJFT0>c/k
0861P@0j>SX0;bl_07inOP1_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm06UYJ@0O7al0EUIF
0:JVYP1VIVH0;bl_055AD@1BDU80:b/[08F5Q@1EEED0?3`l0492@P14A4@0@d=309bLW01WIfL07QhN
0451@@1BDU80GUiN05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0ATI605aLG028R8P0][Jf
02l_;`15ADD0GEeM07QhN023Ph<0T92@0492@P1cLg<0PX:2055AD@2YZJT0LG5a01lO7`1HF5P0YjNW
06QXJ02<S8`0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1mOGd0RXZ:05MGE`1oOgl0=SHf
03Ph>01[Jf/0X:2P04Y:BP1ADE40@D5104Q8B01VIVH0UIFE04Y:BP1@D500HF5Q0P0d=3@08`2RXZ80
N7Qh03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40J6QX04=3@`2<S8`0VYZJ030`<00Y:BT0
DE5A05iNGP1<C4`0TY:B055AD@0e=CD0@T9205IFEP0m?Cd0V9RH0:RXZ00V9RH0?clo059BDP1YJFT0
/k>c08B4Q00J6QX0=cLg01cooooo0540LG5a09BDU01JFUX0HF5Q05=CD`1gMgL0NGUi06=SH`1/K6`0
>c/k069RHP1ZJVX0MGEe07MgM`2@T900^KVi09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0
CTi>05mOG`1eMGD0C4a<05YJFP1<C4`0DE5A05MGE`1RHV80De=C065QH@1]KFd0De=C03hn?P1@D500
ATI603Lg=`1;Bd/0De=C059BDP0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>00j>SX0
ATI60410@00n?Sh0@d=3034a<@0Y:BT0>SXj03@d=00i>CT0=cLg05ADE01jNWX0IFEU08^;R`2<S8`0
T92@09nOW`1VIVH0IfMW07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl00P10@400D@1ADE40
=cLg04=3@`1OGel0I6AT03`l?00i>CT0<30`0451@@1@D5006a/K05YJFP0g=cL0DE5A03Ph>01KFe/0
>CTi03`l?01:BTX0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0JVYZ07AdM01BDU80
D51@06EUI@14A4@0P82008B4Q01MGEd0HF5Q071`L01IFET0GemO03/k>`1[Jf/0E5AD09BDU020P800
V9RH08R8R01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO06ATI01ZJVX0@D5102PX:00f=SH0
ADE504I6AP1DE5@0C4a<07QhN01WIfL0GEeM04A4A01RHV80Cdm?06QXJ00M7Ad0Kfm_05ADE00l?3`0
FEUI03<c<`1WIfL0Y:BT0410@00204U9B@0`030`<01HF5P08b<S04=3@`0f=SH0JVYZ04A4A01JFUX0
ATI6038b<P25QHD0EEEE07=cL`1:BTX0A4A404U9B@1DE5@0GEeM07AdM02c/k<0@D5108J6QP19BDT0
ATI6034a<@10@400MgMg03Hf=P1TI6@0Shn?079bLP2ZZZX0N7Qh05EEE@1HF5P0FEUI03@d=01ZJVX0
E5AD05aLG01VIVH0HF5Q018B4P1=CDd0D51@01dM7@15ADD0DU9B0P1LG5`0301`L700F5QH051@D00o
?cl0>c/k055AD@0g=cL0=SHf02d];@1>CTh0CDe=03hn?P80I6AT03`0CDe=06i^KP1:BTX0EEEE05QH
F01QHF40I6AT0410@01DE5@0Jf][05=CD`19BDT0@41003Ph>00n?Sh0AdM703lo?`0i>CT0BDU90410
@00S8b<0CTi>04=3@`0h>3P0@T9205ADE01=CDd0>CTi05MGE`1]KFd0Ng]k04];B`1CDe<0?3`l059B
DP1KFe/0Lg=c0410@02e]KD0LW9b03hn?P1MGEd0FUYJ03Ti>@11@D40@41005ADE02CTi<0T92@05EE
E@1DE5@0FEUI07EeM@1TI6@0FEUI05]KF`1fMWH0Ng]k096AT@2EUIDAooooo`003oooool0:P1VIVH0
MgMg04E5A@2FUYH0I6AT065QH@0k>c/0DU9B096AT@0j>SX0;bl_04Q8B014A4@0>c/k08B4Q00S8b<0
F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P12@T80]kNg065QH@0F5QH09bLW04e=C@1:BTX0
M7Ad0<30`00V9RH0B4Q807alO01:BTX0MgMg0:VYZ@0M7Ad0:RXZ069RHP80O7al0?H0MGEe02`/;00/
;2`0IVIV05QHF00k>c/0Rh^;05QHF00C4a<0GemO04I6AP1_Kfl0@D5102DU9@1<C4`0SHf=05eMG@18
B4P0KVi^028R8P1BDU80QHF503/k>`0l?3`0HF5Q02d];@0[:b/0EEEE05ADE00Y:BT0C4a<03@d=01[
Jf/0PH6104U9B@0S8b<0<S8b03Ti>@1HF5P0T92@02XZ:P0K6a/0=SHf04U9B@1FEUH0Ph>3079bLP0Q
8B40?clo05iNGP13@d<0Xj>S03Hf=P0L71`0;Bd]075aL@25QHD0H61P01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41006YZJP15ADD0QHF503Ti>@0R8R80De=C0:2PX01gMgL0BTY:0492@P0j
>SX0BTY:0:f][@1FEUH0@41007YjNP14A4@09BDU0492@P1RHV80EeMG079bLP0`<300?Cdm05mOG`1^
KVh0?clo06a/K016ATH0>3Ph0:^[Z`1OGel0:b/[04a<C01ADE40<30`0:FUY@3:b/X0ATI605mOG`10
@400GUiN0;fm_@1[Jf/08b<S03/k>`1NGUh0B4Q8096AT@1`L700;Bd]03dm?@1bLW80E5AD05UIF@2d
];@0MgMg03<c<`1KFe/0JFUY065QH@2>SXh0>CTi02XZ:P28R8P0RHV907YjNP2VYZH0<S8b02`/;01b
LW80OWin05IFEP21PH40De=C01lO7`0h>3P0GemO07emO@1gMgL06a/K020P801VIVH0TY:B04Y:BP2J
VYX0:b/[03Ti>@1ZJVX0A4A405eMG@15ADD0:RXZ059BDP1fMWH0CTi>05iNGP0m?Cd0AdM707AdM01n
OWh0IFEU08:2PP0U9BD0DE5A0:NWY`1LG5`0K6a/04a<C00l?3`0LG5a0:BTY018B4P0HF5Q05=CD`1:
BTX0IVIV04I6AP0h>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0ATI6059BDP1VIVH0/k>c06i^KP0O
7al0>CTi07EeM@1RHV80PH6106e]K@0^;Rh0A4A406i^KP1ZJVX0U9BD09fMW@0a<C409RHV04E5A@1/
K6`0FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1FEUH0;Rh^03/k>`1EEED0?Cdm05=CD`2R
XZ80>SXj038b<P1=CDd0E5AD04m?C`1PH6008b<S020P800m?Cd0LG5a04Y:BP0[:b/0De=C02@T9024
Q8@0MWIf03De=@1:BTXLooooo`0?06e]K@1QHF40DU9B055AD@1EEED0G5aL04=3@`1MGEd0Ph>303@d
=01GEeL0DE5A07AdM02GUiL0IfMW0080EUIF00@0NWYj07EeM@15ADD0>c/k0P1LG5`05P16ATH0IFEU
07=cL`1CDe<0?clo05=CD`2TY:@0NGUi03hn?P1GEeL0P82007IfMP1LG5`0MWIf05aLG01PH600A4A4
03dm?@17AdL0BDU9059BDP1EEED206IVIP3c0451@@1EEED0Bd];05QHF01YJFT0=SHf03`l?01YJFT0
FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R04];B`0k>c/0FUYJ0410@01PH600UYJF071`L00/;2`0
;bl_04Q8B01NGUh0<30`02PX:01[Jf/0>3Ph03lo?`1/K6`0E5AD04];B`1?Cdl0ADE5034a<@10@400
AdM703@d=013@d<0B4Q803Ti>@0W9bL0=cLg0492@P0V9RH0@D5103dm?@14A4@0820P02TY:@0^;Rh0
Bd];03De=@1CDe<0EeMG03De=@0b<S80CTi>05IFEP0h>3P0>CTi04a<C01TI6@0BTY:05EEE@1PH600
L71`0492@P1[Jf/0HV9R04Q8B01MGEd0Q8B404I6AP1:BTX0AdM708n?S`1CDe<0H61P069RHP2][Jd0
TY:B08F5Q@1;Bd/0Rh^;0<g=c@1IFET0KVi^09jNWP1EEED0Shn?069RHP1DE5@0HF5Q079bLP1_Kfl0
AdM7055AD@1kNg/0Ogmo08n?S`1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c06m_K`1LG5`0
EeMG07=cL`2CTi<0FUYJ05iNGP1PH600?Shn05IFEP0`<300D51@0410@01SHf<0@41005]KF`1BDU80
820P096AT@0^;Rh0>SXj02DU9@18B4P0Bd];06][J`1RHV80?3`l06MWI`1TI6@0TI6A051@D01<C4`0
?clo05eMG@1kNg/0>CTi08b<S02[Zj/0VIVI09JFUP1QHF40Hf=S05EEE@10@400@D5109fMW@1:BTX0
FEUI05IFEP2GUiL0B4Q804m?C`1FEUH0De=C075aL@2ATI40F5QH05mOG`12@T80CDe=05QHF015ADD0
AdM7069RHP1=CDd0ADE504I6AP1JFUX0DU9B04i>CP1ZJVX0I6AT05aLG02@T900?Shn059BDP19BDT0
>SXj04m?C`16ATH0<c<c04a<C00/;2`0@T9203De=@16ATH0EeMG05IFEP1=CDd0AdM704];B`1EEED0
GEeM09BDU01DE5@03@d=03Xj>P1oOgl0FUYJ04a<C017AdL0<S8b05MGE`1`L700QHF505UIF@1dM7@0
MGEe0820P01GEeL0Kfm_08J6QP1>CTh0HV9R04I6AP1_Kfl0QHF504U9B@0];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1]KFd0EeMG05EEE@1^KVh0GEeM017ooooo000?ooooo`3o06QXJ02Y
ZJT0FUYJ05mOG`1LG5`0RXZ:06][J`1<C4`0FEUI04I6AP1RHV80SHf=059BDP0b<S80GEeM03lo?`2O
Wil0N7Qh02l_;`0d=3@0FEUI06EUI@1?Cdl0NGUi02/[:`12@T80I6AT04Y:BP1UIFD0IVIV02DU9@0i
>CT0EeMG06=SH`1hN7P0Fe]K01/K6`0g=cL0FUYJ04];B`0n?Sh0RXZ:02XZ:P0/;2`0L71`03Ti>@1>
CTh0Lg=c02/[:`0k>c/0QXJ608B4Q00e=CD0D51@03/k>`1XJ6P0GUiN02HV9P0n?Sh0D51@03@d=013
@d<0O7al02/[:`0i>CT0E5AD03@d=01MGEd0TI6A04E5A@0X:2P0D51@05]KF`1VIVH0Shn?0410@00c
<c<0A4A403dm?@1ADE40OWin096AT@0[:b/0DU9B0451@@1ADE40Ph>303Lg=`0K6a/0?Shn05YJFP1R
HV80WinO04a<C00U9BD0>3Ph05aLG00l?3`0M7Ad07IfMP0U9BD0HF5Q04Y:BP0f=SH0Rh^;03lo?`0[
:b/0FEUI08^;R`0j>SX0E5AD04Q8B012@T80OWin06i^KP0_;bl0JVYZ071`L013@d<0Bd];079bLP0g
=cL0F5QH05aLG013@d<0DE5A08J6QP1_Kfl0>SXj05EEE@19BDT0DE5A07UiN@1kNg/0>3Ph05aLG01F
EUH0=3@d079bLP28R8P0>CTi06a/K016ATH0CDe=07UiN@1YJFT0;bl_05MGE`2;Rh/0IVIV08>3P`0e
=CD0>SXj07IfMP1oOgl0ATI607YjNP1kNg/0>SXj0410@02IVIT0F5QH065QH@2KVi/0?3`l02d];@1@
D500MgMg04A4A01]KFd0:BTY03hn?P1HF5P0GEeM05aLG02DU9@0@41002DU9@1GEeL0H61P07EeM@1d
M7@0:RXZ02@T901FEUH0Ph>3055AD@1SHf<0>SXj05QHF027QhL0EUIF03De=@1OGel0=CDe03lo?`2>
SXh0QhN705mOG`1<C4`0@T9207IfMP23Ph<0=CDe03Xj>P1ZJVX0>SXj06a/K013@d<0EUIF059BDP0j
>SX0J6QX08R8R01<C4`0Bd];07AdM01DE5@0Zj^[05mOG`0a<C40EUIF065QH@0];Bd0Lg=c09jNWP19
BDT0H61P059BDP29RHT0YZJV055AD@0^;Rh0H61P08>3P`1JFUX0Ogmo03`l?01;Bd/0FUYJ08^;R`1/
K6`0Lg=c079bLP0h>3P0Bd];06i^KP1EEED0UYJF0492@P0`<300@T9206EUI@1OGel0BDU9000S06][
J`14A4@0F5QH096AT@1VIVH0>3Ph05IFEP1CDe<0<c<c055AD@1PH600@T9206YZJP0l?3`0>c/k05AD
E02<S8`0Fe]K05=CD`1OGel0A4A406QXJ027QhL0FUYJ02d];@1fMWH0CTi>03Ph>01?Cdl0P82003Ph
>01OGel0FUYJ02/[:`1CDe<07?ooool0@@1`L700K6a/04i>CP1=CDd0JFUY07=cL`1=CDd0FEUI07Mg
M`1HF5P0De=C051@D020P800N7Qh08Z:RP2b/[80WYjN06a/K01BDU80Hf=S03Ph>012@T80>SXj04e=
C@1BDU80EEEE06][J`14A4@0IVIV05YJFP1YJFT0Cdm?061PH01_Kfl0IfMW05mOG`1VIVH0D51@05mO
G`1;Bd/0Cdm?055AD@1;Bd/0FUYJ05UIF@1@D500Bd];04m?C`1cLg<0ADE504=3@`19BDT0?Cdm03Ti
>@0k>c/0@D5104A4A01`L700:b/[030`<01DE5@0=CDe05aLG00l?3`0EEEE0080HV9R01d0PX:2069R
HP1PH600L71`06QXJ01`L700ADE505IFEP1RHV80?Shn03Ph>01@D500E5AD05QHF015ADD0>3Ph04M7
A`0/;2`0>c/k04A4A01:BTX0=CDe02XZ:P0/;2`0?clo03De=@0[:b/0B4Q803<c<`0203@d=01M04m?
C`0e=CD0@T9203Lg=`13@d<0@D5104Q8B014A4@0?Shn05ADE01FEUH0RHV905ADE01FEUH0GemO0451
@@1QHF40JFUY038b<P1VIVH0H61P05ADE01KFe/0DE5A03lo?`1DE5@0<S8b051@D00d=3@0MGEe06][
J`27QhL0Hf=S05eMG@11@D40>c/k08Z:RP0^;Rh0Ogmo0;>c/`1EEED0E5AD04a<C00];Bd0>3Ph04I6
AP1RHV80L71`07emO@1bLW80QXJ60;6a/@2f][H0QHF507YjNP1iNGT0Ng]k05aLG027QhL0SXj>0820
P01XJ6P0F5QH07QhN02OWil0De=C06i^KP1_Kfl0B4Q806UYJ@14A4@0IfMW04e=C@1bLW80C4a<05QH
F01;Bd/0C4a<092@T013@d<0G5aL0451@@1@D500H61P051@D01MGEd0Hf=S09:BTP1@D500QXJ605aL
G01<C4`0B4Q80080D51@00l0ATI608^;R`2PX:00VIVI07inOP1NGUh0F5QH05iNGP1<C4`0>SXj05UI
F@13@d<0G5aL05eMG@1fMWH00P18B4P04P1@D500;Rh^04e=C@1RHV80<30`05MGE`18B4P0BTY:04Q8
B014A4@0CTi>061PH012@T80Bd];03Lg=`16ATH0IFEU04i>CP80IFEU00/0Cdm?06m_K`14A4@0Hf=S
04I6AP12@T80ADE503`l?00c<c<0D51@03De=@0204Y:BP0_05]KF`15ADD0CDe=059BDP16ATH0B4Q8
03hn?P0l?3`0CTi>04Q8B00e=CD0EeMG09BDU01NGUh0Cdm?05EEE@1:BTX0GUiN04a<C01]KFd0AdM7
07EeM@1]KFd0YJFU05eMG@24Q8@0CTi>05UIF@23Ph<0EeMG04a<C01EEED0E5AD03hn?P1ADE40IFEU
03`l?01cLg<0IVIV0:>SX`1TI6@0G5aL06][J`1SHf<0EEEE06EUI@1bLW804Oooool000oooooo00T0
Cdm?08B4Q01YJFT0YjNW03hn?P1IFET0Ph>3079bLP1nOWh00P0g=cL0c`1=CDd0S8b<06IVIP1eMGD0
9RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0GEeM08>3P`0X:2P0;2`/04m?C`1LG5`0
ATI6055AD@1cLg<0;Bd]05mOG`25QHD0D51@06EUI@1VIVH0820P03/k>`1kNg/0QXJ603/k>`1:BTX0
:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_03De=@21PH40:BTY03Ti>@12@T80BDU907EeM@2WYjL0
>3Ph020P801SHf<0HV9R09NGU`1kNg/07QhN02PX:01GEeL0FUYJ05QHF02][Jd0EeMG034a<@1ZJVX0
PX:208B4Q02_[jl071`L03Hf=P1WIfL0PH6106IVIP1EEED03`l?04U9B@2>SXh0QXJ604=3@`22PX80
@T92034a<@1GEeL0P82005]KF`2RXZ808B4Q02TY:@18B4P0GEeM04U9B@12@T806ATI02l_;`1jNWX0
IVIV02XZ:P1;Bd/0<c<c02h^;P0l?3`0GemO01`L7017AdL0?Cdm03<c<`1KFe/0Ng]k02HV9P0U9BD0
@T92030`<01]KFd0SHf=02l_;`0^;Rh0C4a<05IFEP0h>3P0MgMg05iNGP0a<C40EEEE07QhN01MGEd0
VYZJ07EeM@0O7al0>3Ph04a<C01SHf<0ZZZZ02@T900h>3P0JFUY06a/K01CDe<0YjNW06IVIP0k>c/0
P82007=cL`1ZJVX0Q8B405QHF00Q8B40HV9R0;6a/@1SHf<0PX:2055AD@0j>SX0IFEU07AdM01[Jf/0
IFEU09>CT`0i>CT0BTY:0861P@1DE5@0D51@08Z:RP0O7al0?Cdm06EUI@2d];@0MgMg07IfMP0S8b<0
Cdm?0;Rh^02^[Zh0>3Ph06IVIP1PH600820P05iNGP1>CTh0A4A405EEE@0l?3`0Jf][09jNWP18B4P0
:BTY04Q8B014A4@0JVYZ09ZJVP0Z:RX0ADE504m?C`1MGEd0KFe]0::RXP0m?Cd0AdM704Q8B02IVIT0
YJFU034a<@0h>3P0F5QH05YJFP1lO7`0W9bL02TY:@0207YjNP16079bLP2TY:@0GemO01XJ6P10@400
L71`051@D01jNWX0<30`038b<P1VIVH0WYjN06EUI@1nOWh0FUYJ03dm?@1eMGD0FEUI07=cL`1mOGd0
A4A4055AD@1VIVH0QXJ604M7A`1TI6@0?3`l051@D01dM7@0RHV904Y:BP1lO7`0QHF502XZ:P0i>CT0
C4a<05EEE@1SHf<0I6AT02HV9P0b<S80KVi^05]KF`0R8R80ATI603/k>`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@18B4P0?Cdm04M7A`0e=CD0:RXZ0:n_[`1gMgL05aLG03Xj>P16ATH0
@d=30:>SX`1WIfL07alO04A4A1cooooo00T0L71`06m_K`1`L700FEUI06ATI01aLG40IVIV06UYJ@2G
UiL00P1?Cdl07P1>CTh0IFEU08f=S@1[Jf/0KVi^07QhN01RHV80F5QH051@D013@d<0Bd];03dm?@19
BDT0HV9R06QXJ01NGUh0C4a<06ATI02<S8`0F5QH03<c<`19BDT0I6AT04i>CP1ADE40FEUI06EUI@1C
De<0?3`l04a<C080AdM702T0BTY:05IFEP1BDU80Cdm?051@D01HF5P0CDe=059BDP1CDe<0=CDe04e=
C@19BDT0C4a<04M7A`1YJFT0A4A4055AD@1/K6`0@d=304m?C`1=CDd0GEeM05UIF@1WIfL0]KFe07=c
L`0b<S80>SXj065QH@1fMWH0B4Q803lo?`1]KFd0@T9204Y:BP1/K6`0B4Q806=SH`1HF5P0@d=304a<
C00204I6AP1604m?C`19BDT0=cLg04I6AP11@D40@T9204Q8B00W9bL0CTi>030`<00h>3P0<c<c04U9
B@0a<C40BDU903Hf=P18B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1IFET0BTY:051@
D01cLg<0OGem05=CD`23Ph<0HF5Q04];B`1GEeL0Kfm_030`<01;Bd/0>c/k08N7Q`0_;bl0Kfm_05iN
GP2^[Zh0M7Ad05ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>05]KF`0l?3`0@41005UI
F@1>CTh0EEEE0861P@1BDU80U9BD07EeM@1DE5@0PH61069RHP1@D500I6AT03`l?080Kfm_08@0IVIV
05EEE@1ZJVX0Cdm?04U9B@15ADD0ATI60492@P17AdL0EeMG0410@01DE5@0@d=305QHF01PH600Q8B4
05iNGP1@D500NWYj059BDP1HF5P0C4a<06EUI@1QHF40De=C06QXJ01]KFd0Ti>C059BDP28R8P0CDe=
05mOG`16ATH0CTi>05UIF@2CTi<0`l?30;>c/`1fMWH0N7Qh051@D019BDT0Hf=S04U9B@0h>3P0Ng]k
02`/;01=CDd0B4Q808F5Q@16ATH0EEEE04i>CP0b<S80ADE505]KF`0c<c<0Hf=S03Xj>P1EEED0CTi>
03dm?@0l?3`0Ng]k04E5A@1;Bd/0AdM704];B`1GEeL0Cdm?07QhN01OGel0@D51061PH00l?3`0KVi^
03Xj>P1>CTh0Cdm?05MGE`0l?3`0EUIF04I6AP1JFUX0@41003dm?@1MGEd0DU9B051@D019BDT0?clo
059BDP11@D40PX:204m?C`0G5aL0GEeM08V9R@1TI6@0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ
05IFEP1=CDd0MGEe05aLG02?Shl0L71`04A4A01[Jf/0?Shn061PH01[Jf/0MWIf0492@P1OGel0EUIF
038b<P1JFUX0LG5a0;^k^`1UIFD0G5aL06i^KP1?Cdl0?clo04m?C`1KFe/Aooooo`003oooool0l`1^
KVh0LG5a05EEE@1hN7P0JFUY05mOG`14A4@0FUYJ08:2PP15ADD0@41004m?C`0j>SX0ATI608>3P`0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@17AdL0QHF506][J`0P8200>c/k05ADE01X
J6P0K6a/0:^[Z`0Z:RX0ADE507=cL`0l?3`0Shn?09nOW`0E5AD05QHF04A4A01eMGD0GUiN0820P00Z
:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q04m?C`0o?cl0EEEE02l_;`0N7Qh0BTY:06e]K@1T
I6@0@d=306e]K@0^;Rh0ATI608Z:RP10@400A4A406=SH`0S8b<0<30`04Q8B01GEeL0Fe]K05IFEP0/
;2`0BTY:05QHF012@T8061PH051@D00h>3P0IfMW0:NWY`0o?cl08b<S0451@@0O7al0:b/[07=cL`1E
EED092@T02l_;`1ADE40Cdm?08j>SP1OGel07AdM04=3@`1FEUH0CDe=09:BTP0E5AD08B4Q0492@P16
ATH0Fe]K0:BTY01DE5@09BDU02l_;`1IFET0GUiN09ZJVP0O7al092@T03Ti>@24Q8@0LW9b06YZJP1L
G5`0A4A403`l?01MGEd0JVYZ07MgM`1nOWh07alO04E5A@1ADE40De=C0410@01dM7@0;bl_03Hf=P1K
Fe/0QXJ604e=C@1EEED0B4Q802XZ:P1?Cdl0KVi^038b<P21PH40ATI602h^;P1]KFd0LG5a03hn?P0l
?3`0>c/k04I6AP27QhL0EeMG034a<@13@d<0?3`l0492@P1NGUh0JVYZ01`L701:BTX0DU9B0451@@1D
E5@0YjNW06a/K00S8b<0I6AT06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0Ti>C02HV9P0P
8200Bd];07alO01^KVh0TY:B06i^KP0E5AD0@d=305aLG02NWYh0Xj>S03Ti>@0_;bl0Ti>C08J6QP1;
Bd/0RHV903<c<`0d=3@0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1WIfL0<C4a03<c<`26
QXH0GEeM06e]K@13@d<07AdM04E5A@1[Jf/0Fe]K08>3P`11@D40=cLg07alO02UYJD0@T9205eMG@1F
EUH0>c/k07AdM01<C4`0EUIF05eMG@18B4P0EUIF09JFUP2GUiL0@D5105=CD`1LG5`0N7Qh0::RXP1X
J6P0:b/[065QH@0205EEE@0]07inOP1]KFd0<30`06UYJ@1GEeL0D51@07MgM`2g]kL0<S8b02l_;`14
A4@0GUiN07IfMP28R8P0:BTY02XZ:P14A4@0IFEU02l_;`1RHV80<C4a03Xj>P1NGUh0FEUI02TY:@15
ADD0De=C03lo?`0W9bL0Fe]K06ATI01BDU80HV9R02DU9@0P8200BTY:06e]K@0a<C40GEeM059BDP0Z
:RX0MWIf0::RXP19BDT0IFEU01cooooo00X0H61P07MgM`13@d<0A4A4051@D01jNWX0Cdm?06YZJP2J
VYX0IfMW0P18B4P0HP2HV9P0UIFE08j>SP2OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3
@`1@D500H61P05eMG@19BDT0Kfm_06EUI@1]KFd0@D5106=SH`1mOGd0H61P05QHF01]KFd0EEEE051@
D00i>CT0Bd];04U9B@0j>SX0CTi>04e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@41003hn
?P0P8200?Shn04i>CP1YJFT0<C4a02XZ:P15ADD0<S8b05YJFP0c<c<0Cdm?05ADE01NGUh0HV9R05UI
F@16ATH0BTY:06IVIP1HF5P0?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm06e]K@0o?cl0>c/k04];
B`0b<S80?clo05mOG`11@D40<c<c038b<P1:BTX0BDU90492@P13@d<0CDe=03hn?P0k>c/0D51@05]K
F`0j>SX0@D5104Y:BP1DE5@0EeMG04m?C`1IFET0DE5A06ATI01fMWH0UiNG0P1TI6@0901MGEd0IVIV
079bLP1UIFD0AdM707=cL`1hN7P0FUYJ05UIF@1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW
07emO@1WIfL0EEEE030`<00T92@0LG5a01DE5@1bLW80_Kfm04=3@`1KFe/0HF5Q04i>CP19BDT0GemO
061PH01FEUH0IFEU05=CD`80MWIf0P1EEED0BP1?Cdl0GUiN06MWI`0^;Rh0PX:209:BTP1LG5`0IVIV
06EUI@2NWYh0`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A06YZJP1DE5@0M7Ad04m?C`17AdL0>c/k
05aLG01YJFT0?3`l06e]K@1CDe<0C4a<06][J`1cLg<0FEUI06i^KP2IVIT0G5aL092@T01UIFD0KVi^
05]KF`1=CDd0EeMG07QhN01CDe<0JVYZ03hn?P1mOGd0CTi>03De=@1NGUh0G5aL03dm?@1DE5@0;Bd]
07QhN01;Bd/0MGEe04U9B@1MGEd0BTY:02<S8`1;Bd/0EUIF02HV9P1=CDd0A4A40492@P0e=CD0?Cdm
03De=@14A4@0<C4a03`l?00h>3P0?Cdm0P1ADE4206IVIP0l05aLG01YJFT0>c/k05IFEP1=CDd0A4A4
04I6AP0m?Cd0;Bd]05iNGP0b<S80CTi>05EEE@1FEUH0ATI6038b<P1RHV80GUiN05eMG@0l?3`0@d=3
051@D01HF5P0>SXj04E5A@1YJFT0EUIF07AdM01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0IVIV
0;Vi^@1LG5`0Lg=c030`<01cLg<0ZJVY05iNGP1CDe<0>SXj03Ph>00a<C40HV9R05aLG00a<C40De=C
04Q8B025QHD0ATI605YJFP1ADE40NWYj055AD@1CDe<0Ph>34Oooool000oooooo0840N7Qh07inOP1A
DE40Cdm?069RHP25QHD0@D5103Ph>01RHV80G5aL06EUI@1aLG40<30`02XZ:P1bLW80MGEe0:FUY@2T
Y:@08B4Q04E5A@1nOWh0I6AT06YZJP2GUiL0<S8b05eMG@2ATI40CDe=08N7Q`1RHV808B4Q03Ti>@1h
N7P0MgMg09BDU01NGUh0;Rh^03Hf=P1fMWH0?3`l02/[:`1OGel092@T01lO7`1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0f=SH0EEEE09NGU`1?Cdl05aLG028R8P11@D40<C4a061PH01g
MgL0:BTY03@d=015ADD0>SXj06a/K02^[Zh08B4Q038b<P14A4@0EeMG09NGU`2d];@06a/K030`<017
AdL0EeMG051@D02KVi/0Ogmo02/[:`2:RXX0J6QX05QHF01eMGD092@T04];B`1DE5@0OWin05YJFP1o
Ogl06a/K03Ph>01QHF40H61P03Lg=`1XJ6P0D51@01TI6@1RHV80D51@05EEE@1ZJVX09BDU03dm?@1:
BTX0MGEe03Ph>017AdL0=cLg0492@P2a/K40Ph>3034a<@1BDU80B4Q802<S8`17AdL0QXJ6024Q8@0o
?cl0BDU902HV9P1CDe<0YZJV06a/K00K6a/00P1=CDd0A01CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01a
LG40R8R805YJFP0X:2P0@d=304I6AP1;Bd/0WYjN0451@@0d=3@0MGEe06ATI01QHF40UIFE01lO7`1=
CDd0J6QX07YjNP2ZZZX0Zj^[05aLG00L71`0FEUI06i^KP1;Bd/0WinO07IfMP0U9BD0C4a<055AD@1m
OGd0Fe]K065QH@0^;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b07YjNP1aLG40@41005iNGP0M
7Ad0;2`/05mOG`2<S8`0@4100492@P0Z:RX0BTY:06EUI@0d=3@0<30`05]KF`0];Bd0DU9B0:BTY01P
H600?Cdm0P0h>3P0F@1<C4`0L71`02l_;`0[:b/0@d=304E5A@2>SXh0=3@d03`l?01CDe<0CDe=0;Fe
]@2XZ:P0:RXZ02`/;014A4@0D51@0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2KVi/0<S8b05AD
E01]KFd0WYjN0;6a/@0c<c<0>3Ph04M7A`2GUiL0N7Qh09^KV`0g=cL0A4A406][J`2][Jd0JVYZ0<30
`01iNGT0;Bd]05QHF01YJFT0DU9B08^;R`12@T80=CDe04e=C@1NGUh0E5AD05eMG@2:RXX0A4A405MG
E`24Q8@0CDe=030`<028R8P0ADE503dm?@1VIVH0HV9R03Xj>P1mOGd0IfMW04e=C@1PH600Lg=c03Lg
=`0T92@0?Shn04I6AP1XJ6P0Ph>302LW9`0P8200>3Ph04];B`0j>SX0TI6A07MgM`0P8200ADE506m_
K`1=CDd0IFEU01cooooo0240I6AT07AdM01GEeL0AdM704a<C025QHD0Cdm?06QXJ02=SHd0IVIV04U9
B@1;Bd/0NWYj09JFUP2MWId0hN7Q09RHV01UIFD0C4a<06EUI@1JFUX0?clo03Hf=P1ADE40Hf=S07Ad
M01aLG40EEEE0861P@1fMWH0IFEU06e]K@2:RXX00P1lO7`08P23Ph<0K6a/05mOG`1EEED0Bd];04e=
C@1IFET0AdM7059BDP1IFET0FUYJ051@D01=CDd0BTY:0451@@0g=cL0AdM702d];@0o?cl0:2PX04Y:
BP19BDT0JVYZ04];B`0[:b/0G5aL02PX:01<C4`0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP05
07YjNP1XJ6P0F5QH059BDP1QHF400P0o?cl0501BDU80?Shn065QH@1?Cdl0>3Ph04];B`0];Bd0BDU9
04m?C`0f=SH0:BTY03@d=00_;bl0>CTi04I6AP0f=SH0D51@04Y:BP15ADD0>CTi0P14A4@0O01@D500
@d=304M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04U9B@1UIFD0A4A404I6AP1;Bd/0
A4A40:f][@1IFET0@d=305]KF`1XJ6P0@41005EEE@1?Cdl0EeMG059BDP24Q8@0O7al0;:b/P27QhL0
PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0ATI602h^;P0d=3@0LW9b08:2PP1VIVH0
BDU905ADE01eMGD0Shn?07moO`1FEUH0=CDe02h^;P1:BTX07alO05=CD`1:BTX0ATI6071`L01:BTX0
GUiN05aLG014A4@0WYjN0861P@0m?Cd0KFe]059BDP1OGel0BTY:05EEE@0k>c/0FEUI04U9B@1aLG40
TY:B03Ph>017AdL0>SXj04U9B@17AdL0B4Q8059BDP1WIfL0O7al07IfMP2EUID0CDe=04E5A@1kNg/0
PH6106ATI01gMgL0Cdm?05aLG015ADD0DE5A05=CD`1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0
<c<c05QHF00m?Cd0D51@03/k>`0V9RH0C4a<05UIF@0c<c<0DE5A03lo?`1DE5@0AdM704=3@`0l?3`0
FUYJ03lo?`19BDT204Y:BP10075aL@1QHF40J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1<
C4`0Bd];03Xj>P1BDU80=CDe03`l?00b<S80>c/k0492@P1BDU80BTY:03dm?@0c<c<09RHV02l_;`1I
FET0D51@03hn?P1fMWH0PX:204a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1EEED0TY:B059BDP1c
Lg<0EeMG06QXJ017AdL0ADE5069RHP12@T80IfMW05]KF`15ADD06ATI038b<P0j>SX09RHV08b<S01E
EED0U9BD0492@P17AdL0O7al04i>CP1?Cdl0KVi^05MGEa7ooooo000?ooooo`3o05EEE@1ZJVX0GemO
08N7Q`17AdL0Hf=S06a/K01IFET0OWin038b<P10@400EEEE05eMG@1=CDd0E5AD03lo?`1cLg<0NGUi
05IFEP1CDe<0Jf][02h^;P0h>3P0VIVI04A4A01LG5`0=3@d02l_;`1KFe/0Rh^;02/[:`0b<S80K6a/
03@d=024Q8@0E5AD02TY:@0j>SX0DE5A03/k>`1?Cdl0TY:B04Y:BP0`<300De=C04A4A01OGel0WIfM
024Q8@0f=SH0CDe=04m?C`19BDT0EeMG01HF5P12@T80AdM703De=@1/K6`0LW9b01/K6`0c<c<0CDe=
051@D025QHD0MWIf01XJ6P0l?3`0K6a/06ATI014A4@0PX:203dm?@1<C4`0QhN704U9B@1DE5@0J6QX
01hN7P12@T80EeMG07UiN@14A4@0DU9B02d];@1IFET0SXj>06EUI@0_;bl0CTi>03/k>`11@D40Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0?clo0410@01UIFD0Y:BT04Y:BP0E5AD0@D51
05eMG@13@d<0HV9R04i>CP0O7al0E5AD07EeM@1UIFD0SXj>06][J`0H61P0:2PX08B4Q01=CDd0KFe]
05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0f=SH0>c/k07inOP3:b/X0G5aL08Z:RP0c<c<0820P
05]KF`1bLW80B4Q805iNGP0U9BD0>CTi05iNGP1dM7@0=SHf07EeM@0e=CD0ADE507QhN01@D500?Cdm
079bLP0Y:BT0ATI60;>c/`2e]KD0E5AD03lo?`1BDU80;2`/07=cL`2f][H0G5aL0492@P1XJ6P0?Shn
05QHF02:RXX09bLW04Y:BP1CDe<0I6AT06a/K02<S8`0>3Ph03Ti>@1ADE40@d=306a/K02;Rh/09RHV
02LW9`1OGel0J6QX04m?C`2KVi/0<30`04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW
08J6QP0j>SX0:BTY04=3@`1oOgl0OWin06][J`1`L7005aLG079bLP1eMGD0IFEU05iNGP0j>SX0=cLg
09NGU`1hN7P0G5aL069RHP0j>SX0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80EUIF
034a<@0i>CT0OGem07=cL`0h>3P0Cdm?04E5A@0i>CT0TY:B04Q8B00j>SX0ATI60410@014A4@0/;2`
09bLW00W9bL0A4A404Y:BP19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE000S0:VYZ@12@T80
CDe=06QXJ01EEED0F5QH0<G5a@1PH6008b<S04A4A01JFUX0JVYZ0<_;b`1IFET0=3@d03Xj>P1HF5P0
Hf=S08b<S02:RXX0ADE505QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi04Y:BP1hN7P0
<30`02d];@1IFET07?ooool02`1TI6@0Ph>306UYJ@0o?cl0EUIF09NGU`1kNg/0GUiN06UYJ@17AdL0
M7Ad0080LG5a0;T0Ti>C055AD@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0<30`05ADE01RHV80
EEEE05]KF`1CDe<0GUiN079bLP1FEUH0<C4a05UIF@1aLG40C4a<04I6AP1LG5`0FUYJ04M7A`0^;Rh0
ATI604];B`1GEeL0De=C04m?C`1]KFd0L71`059BDP1IFET0C4a<03dm?@1IFET0<S8b03`l?00o?cl0
F5QH05EEE@1^KVh0=3@d030`<01OGel0>c/k05UIF@0h>3P0GemO06IVIP1oOgl0T92@07IfMP15ADD0
CTi>06QXJ01VIVH0>3Ph04Y:BP1=CDd0<C4a04M7A`1>CTh0?Shn05iNGP1PH600DE5A04Q8B00_;bl0
@T9204i>CP0i>CT0;2`/03<c<`0f=SH0@D51059BDP0k>c/0FUYJ04I6AP13@d<0@T9204a<C015ADD0
FUYJ051@D01:BTX0Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1JFUX0J6QX05iNGP1VIVH0
KVi^04=3@`1`L700F5QH04U9B@1MGEd0NWYj03@d=01=CDd0>c/k06m_K`0h>3P0IfMW04a<C02h^;P0
LG5a05MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05mOG`13@d<09BDU05EEE@1>CTh0
FEUI055AD@1LG5`0TI6A09>CT`1OGel0KVi^03hn?P0m?Cd0DU9B02/[:`1OGel0EUIF04];B`17AdL0
?clo0861P@2][Jd0=cLg04a<C01;Bd/0?Cdm069RHP0n?Sh0GEeM03Ph>01JFUX0B4Q808j>SP13@d<0
ADE504e=C@0T92@0D51@03Xj>P1UIFD0>c/k04m?C`12@T80L71`06YZJP10@400NGUi03dm?@10@400
<S8b03Ph>01;Bd/0C4a<06QXJ01;Bd/0Kfm_09VIV@0203Ti>@1J04U9B@13@d<0?Cdm059BDP0m?Cd0
EUIF04=3@`1aLG40JVYZ05UIF@1<C4`07AdM06MWI`1LG5`0?Shn04M7A`13@d<0De=C04U9B@1?Cdl0
BDU905eMG@0k>c/0Bd];059BDP0f=SH0@d=303/k>`2>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0
ATI605EEE@1JFUX0CTi>07emO@1KFe/0FEUI061PH01GEeL0IFEU04I6AP1GEeL0BTY:04];B`0V9RH0
@d=308J6QP15ADD08R8R05aLG01ADE40IfMW065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0
Lg=c0:FUY@1SHf<0Ti>C05QHF017AdL0N7Qh03Ti>@1TI6@0ADE506=SH`0f=SH0FUYJ051@D00/;2`0
?clo04e=C@2_[jl0@d=304U9B@1UIFD0EUIF071`L01dM7@0Fe]K4Oooool000oooooo0:<0LW9b06EU
I@1/K6`0W9bL05MGE`1FEUH0FEUI08:2PP2LW9`0;bl_02PX:019BDT0B4Q807emO@1^KVh08B4Q038b
<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0JVYZ0;>c/`0m?Cd0:BTY034a<@26QXH0JFUY08R8
R02f][H0=CDe03Ti>@12@T80Fe]K08B4Q01iNGT06ATI038b<P0W9bL0DE5A06UYJ@1FEUH09RHV02XZ
:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1[Jf/0=cLg055AD@0o?cl08R8R05mOG`2RXZ80CDe=0492
@P15ADD0<S8b07MgM`1aLG409RHV02XZ:P1:BTX0;2`/03/k>`2PX:00CTi>03<c<`1?Cdl0EEEE075a
L@2BTY809RHV028R8P0h>3P0GEeM06QXJ01gMgL07QhN034a<@1FEUH0LG5a065QH@2HV9P0>3Ph03@d
=01]KFd0GemO06EUI@2;Rh/061PH01LG5`0_;bl0L71`04U9B@1QHF405QHF02/[:`1LG5`0F5QH038b
<P1>CTh0;Rh^024Q8@1?Cdl0FEUI0492@P1TI6@09BDU03De=@14A4@0RHV904U9B@0d=3@0BTY:03Ph
>01=CDd0Kfm_02h^;P0];Bd0DE5A04Q8B01PH600EeMG03hn?P0b<S80EEEE04E5A@1JFUX0];Bd06MW
I`0N7Qh0=cLg055AD@1OGel0W9bL01XJ6P10@400GUiN06m_K`1CDe<0YZJV05mOG`0];Bd0Ti>C06=S
H`1RHV80d];B04Y:BP0R8R80FUYJ08Z:RP1WIfL0Ogmo04a<C014A4@0CDe=0080MGEe07d0GEeM09>C
T`0i>CT0>CTi07EeM@1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0820P011@D40@T9207Ee
M@1KFe/0D51@06i^KP0Z:RX0=cLg05EEE@19BDT0G5aL03Xj>P0a<C40DE5A08:2PP1^KVh0?clo05AD
E00e=CD0JFUY08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40>CTi04e=C@1PH600Jf][02d]
;@0e=CD0@D5105ADE01QHF40Rh^;02`/;01SHf<0F5QH06UYJ@35aLD0L71`03Xj>P13@d<0LG5a06EU
I@24Q8@0>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0Jf][0451@@1?Cdl0GEeM071`L02/[:`0>SXj04I6
AP1>CTh0SHf=04e=C@1/K6`0ADE503Ti>@1<C4`0YJFU05iNGP1QHF40L71`03Ph>00m?Cd0CTi>05YJ
FP1kNg/0NGUi030`<00^;Rh0MGEe09JFUP0d=3@0EUIF02XZ:P0i>CT0NGUi08Z:RP0h>3P0@T9205MG
E`0P8200=cLg09RHV00h>3P0>SXj04i>CP0_;bl0D51@08N7Q`18B4P0820P03Ti>@0h>3P0@d=30820
P012@T809BDU03`l?00Looooo`0Q07]kN`1OGel0JVYZ04Q8B01FEUH0B4Q802/[:`1ADE40RXZ:04];
B`0l?3`0?clo07emO@2>SXh0Shn?0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=305IF
EP1XJ6P0DE5A05ADE01lO7`0UiNG06m_K`1;Bd/0GEeM0080Jf][01P0HF5Q05MGE`1>CTh0C4a<038b
<P10@400ATI603`l?017AdL0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0>3Ph03De
=@0m?Cd0Cdm?05QHF00g=cL2069RHP0H02LW9`1ADE40EEEE05MGE`1PH600GEeM08:2PP1UIFD0A4A4
03lo?`1LG5`0IfMW04E5A@19BDT0DE5A01/K6`0V9RH0Bd];034a<@1KFe/0?Cdm030`<00j>SX0@410
0P14A4@01`0m?Cd0CDe=02/[:`0o?cl0ATI603Xj>P0e=CD00P17AdL02`0Y:BT0>SXj04];B`0b<S80
M7Ad0492@P1MGEd0C4a<04U9B@17AdL0JFUY0080G5aL0:T0Ti>C075aL@1WIfL0H61P05MGE`2BTY80
Cdm?0451@@2:RXX0IFEU08:2PP1[Jf/0MgMg03Xj>P1BDU80@T9205MGE`17AdL0NWYj06YZJP2QXJ40
I6AT07EeM@1CDe<0:b/[06a/K00R8R80Q8B40:RXZ01?Cdl0IFEU06ATI00n?Sh0FUYJ08R8R02h^;P0
SXj>079bLP1JFUX0PH6108R8R01eMGD0@T9204U9B@1QHF40GEeM03<c<`0i>CT0ATI603De=@1MGEd0
<c<c04i>CP21PH40<30`06IVIP1;Bd/0=cLg04E5A@0e=CD0DU9B04Q8B01TI6@09RHV03dm?@0V9RH0
J6QX07emO@0e=CD0I6AT02`/;00g=cL0?Cdm07YjNP1<C4`0M7Ad06m_K`1SHf<0VIVI04e=C@1dM7@0
FEUI061PH00j>SX0M7Ad07YjNP0a<C40BTY:05iNGP0k>c/0ATI6079bLP1<C4`0<c<c04i>CP0[:b/0
LG5a04M7A`1OGel0DU9B08B4Q01FEUH0C4a<055AD@1IFET0>c/k04];B`0k>c/0F5QH03hn?P1CDe<0
EeMG07IfMP1>CTh0?clo04M7A`1ADE40Cdm?04U9B@1VIVH0HV9R05iNGP1TI6@0AdM704e=C@18B4P0
FEUI05QHF00d=3@0>3Ph05iNGP0c<c<0<30`03lo?`0a<C40?Cdm02h^;P1IFET0ADE504e=C@0Q8B40
;2`/0451@@0S8b<04A4A04A4A012@T80@d=304M7A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0
LW9b06UYJ@1OGel0De=C059BDP1_Kfl0Ti>C04e=C@1JFUX0F5QH03dm?@0Y:BT0BDU90080>SXj00X0
FEUI03hn?P1GEeL0C4a<05]KF`1EEED0FUYJ05=CD`1kNg/0HF5Q4Oooool000oooooo08D0TY:B07mo
O`1;Bd/0HF5Q071`L01hN7P0=3@d05MGE`1XJ6P0EEEE05YJFP1OGel0;2`/03Xj>P1gMgL0?Cdm0861
P@0l?3`0:2PX03/k>`25QHD0H61P04I6AP0d=3@0<c<c05eMG@20P8008b<S059BDP0f=SH0;Rh^03hn
?P2CTi<0ADE508N7Q`0Y:BT09BDU08>3P`2a/K40:2PX028R8P19BDT0<30`06IVIP2QXJ409BDU02XZ
:P17AdL0?clo05ADE02e]KD0CDe=02XZ:P18B4P0Bd];092@T01?Cdl09BDU04m?C`1DE5@0Cdm?08>3
P`1dM7@092@T04I6AP1`L700EUIF07alO02RXZ809BDU02h^;P17AdL0F5QH08Z:RP1OGel08B4Q04Q8
B01MGEd0H61P05MGE`29RHT0@T9203@d=01lO7`0=SHf03`l?01=CDd06ATI02l_;`1EEED0OWin04=3
@`1/K6`061PH0410@01oOgl0EUIF02d];@1;Bd/0@41003Hf=P1jNWX0;bl_02`/;013@d<0CDe=03dm
?@29RHT0B4Q801LG5`0N7Qh0?Shn06][J`2UYJD0=SHf01`L700R8R80DU9B04a<C01CDe<0M7Ad02LW
9`15ADD0HV9R06=SH`1YJFT0Xj>S03/k>`0e=CD0BDU907MgM`1JFUX0T92@0080<c<c07l0@410092@
T01GEeL0UYJF05YJFP0h>3P0MWIf051@D01MGEd0TI6A02h^;P0`<300IfMW08R8R01=CDd0ADE501lO
7`0f=SH0VYZJ0:NWY`17AdL0IVIV061PH00e=CD0Fe]K05eMG@0Z:RX0@d=303dm?@16ATH0KFe]08>3
P`1=CDd0=cLg0451@@0m?Cd0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh08F5Q@0N7Qh0?clo05eM
G@1SHf<0C4a<09>CT`0`<3006ATI04U9B@14A4@0S8b<069RHP0M7Ad0;2`/05mOG`1SHf<0GUiN0:2P
X00d=3@0DE5A08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD0IFEU02HV9P1FEUH0NGUi051@
D01TI6@0IfMW02d];@1PH600LG5a05=CD`1mOGd0?Shn03Hf=P23Ph<0];Bd0451@@1KFe/0ATI603/k
>`1fMWH0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1SHf<0@41007EeM@2HV9P0Lg=c03hn
?P1fMWH0DU9B061PH01UIFD0GemO03<c<`1RHV80F5QH051@D01[Jf/0Shn?03Hf=P0g=cL0P82004];
B`1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>01X0WIfM03hn?P0k>c/0ADE505UIF@1iNGT0PH6108j>
SP0h>3P08b<S07=cL`1^KVh0IFEU0:f][@0U9BD0:2PX05QHF01CDe<0@T9208N7Q`1[Jf/0<c<c05EE
E@1[Jf/0?3`l08B4Q1cooooo02`0S8b<06EUI@1?Cdl0CDe=06=SH`1aLG40B4Q805aLG01eMGD0J6QX
03hn?P14A4@0KFe]08j>SP27QhL0UYJF08F5Q@1jNWX0IFEU06ATI019BDT0DE5A04E5A@19BDT0CTi>
061PH01BDU80F5QH05]KF`1WIfL0EeMG06EUI@1[Jf/0IfMW04i>CP1UIFD0EEEE05=CD`1ADE40@D51
04A4A01DE5@0ADE504m?C`80CTi>02<0@d=304m?C`10@400?Cdm03Ti>@15ADD0;Bd]03@d=018B4P0
ATI605ADE01VIVH07QhN024Q8@12@T80;bl_04e=C@0U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400
?Shn04=3@`1BDU80B4Q805MGE`1:BTX0=cLg06EUI@1MGEd0>SXj069RHP020410@00l04e=C@0W9bL0
>CTi04Q8B00Z:RX07AdM02l_;`0j>SX0@d=303<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069RHP0o?cl0
?Shn0451@@0g=cL0;bl_04];B`0c<c<08R8R02h^;P1PH600SXj>03@d=016ATH0FUYJ04Q8B00k>c/0
De=C04Q8B01iNGT0?3`l03<c<`1ADE40IVIV04m?C`1HF5P0:2PX04I6AP0];Bd0WIfM0492@P2NWYh0
Ph>308J6QP1@D500?3`l06i^KP0];Bd0=3@d05QHF01@D500FUYJ03Lg=`0^;Rh0>SXj0P1HF5P0H01G
EeL0C4a<04a<C02GUiL0Ogmo05=CD`1<C4`0<30`03Lg=`1EEED0;Bd]07MgM`1[Jf/0E5AD06ATI010
@400LW9b096AT@0_;bl0J6QX04I6AP0n?Sh0Cdm?03De=@1HF5P0;bl_04Y:BP0b<S80HF5Q02`/;00m
?Cd0C4a<01dM7@14A4@0>c/k05UIF@0k>c/0EUIF04M7A`2LW9`0KVi^069RHP2?Shl0DE5A075aL@13
@d<0BDU902LW9`1;Bd/0J6QX02`/;01VIVH0NGUi03Xj>P0_;bl0>SXj03`l?019BDT0EeMG03@d=01M
GEd0>SXj07MgM`0g=cL0BDU903`l?00_;bl0R8R806MWI`0a<C40CTi>04E5A@1ADE40>SXj05YJFP0o
?cl0Fe]K030`<00j>SX0A4A403Ti>@1_Kfl0CDe=06m_K`1ADE40GUiN06IVIP0b<S80Fe]K03<c<`19
BDT0De=C04a<C00W9bL0?Cdm03lo?`80ATI601l0>CTi05MGE`0n?Sh0Hf=S04e=C@13@d<0?3`l061P
H01]KFd0>c/k014A4@1[Jf/0ADE504A4A01CDe<0CDe=04I6AP0g=cL0BDU907emO@1YJFT0R8R805YJ
FP1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b0080EeMG00h0=SHf04a<C017AdL0<c<c04M7
A`12@T80NWYj03Hf=P19BDT0Bd];05aLG01mOGd0OWin05MGEa7ooooo000?ooooo`1;06e]K@2EUID0
CDe=05IFEP1<C4`0MgMg05IFEP0h>3P0Cdm?04a<C01EEED0IVIV038b<P0Y:BT0EeMG051@D02RXZ80
Cdm?02<S8`0`<300C4a<05QHF01TI6@0HV9R02XZ:P16ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0
OWin04];B`3>c/h0<30`02TY:@0_;bl0IfMW04m?C`1FEUH0MWIf02DU9@0m?Cd0M7Ad04i>CP1JFUX0
C4a<01lO7`0j>SX0C4a<07inOP1;Bd/0?3`l02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0
NWYj01hN7P14A4@0>c/k03dm?@0b<S80Jf][04e=C@0Q8B40EUIF04m?C`22PX80Xj>S0080?clo0;`0
BTY:03Lg=`1PH600bLW906][J`0U9BD0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`1VIVH0
VYZJ02h^;P0U9BD0Cdm?05QHF016ATH0QXJ603/k>`0M7Ad0De=C06ATI01iNGT0R8R802HV9P0a<C40
FUYJ0:6QX@19BDT0MgMg03De=@0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05mOG`0a<C40
De=C05QHF00V9RH0B4Q8051@D01HF5P0;Rh^04U9B@0f=SH0N7Qh06e]K@16ATH09RHV0410@00Z:RX0
>3Ph07alO028R8P0?Cdm04Q8B00i>CT0CTi>09RHV01WIfL0;Rh^04E5A@0o?cl0OGem09nOW`0U9BD0
;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_04a<C02=SHd0EEEE09NGU`21PH4071`L034a<@28R8P0
XJ6Q06a/K01hN7P09BDU02l_;`2ATI40WinO04E5A@1EEED07alO028R8P25QHD0M7Ad05MGE`1JFUX0
6QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0:b/[04=3@`1lO7`0@d=304m?C`1KFe/0<S8b02TY:@1/K6`0
QHF504=3@`0c<c<09RHV04E5A@1oOgl0?Cdm0410@01HF5P0?Shn06i^KP0n?Sh0@D51051@D011@D40
Ph>309bLW017AdL0=SHf05UIF@1EEED0YjNW03Ph>00U9BD0A4A406EUI@1BDU80Ti>C05MGE`0X:2P0
Cdm?079bLP2CTi<0VYZJ01/K6`11@D40IVIV06e]K@1LG5`0UIFE02DU9@0h>3P0Hf=S06IVIP1eMGD0
b/[:07]kN`0Z:RX0E5AD05iNGP1`L700/k>c05aLG019BDT0EeMG06MWI`1oOgl0FUYJ0;Bd]013@d<0
;2`/075aL@1BDU80@d=309>CT`0l?3`0:RXZ04];B`80BTY:01L0J6QX02PX:00f=SH0EUIF08>3P`1J
FUX0B4Q806QXJ00d=3@0CTi>06a/K01LG5`0>3Ph05IFEP0`<300>CTi051@D02:RXX0=cLg05ADE00g
=cL0CDe=06IVIP0Looooo`0L096AT@29RHT0O7al04A4A01CDe<0SHf=06e]K@1_Kfl0MgMg05ADE01<
C4`0BDU907UiN@1bLW80UIFE0<;2`P2>SXh0EEEE04Y:BP1=CDd0?Shn04i>CP19BDT0MGEe06MWI`1d
M7@0H61P06i^KP80JFUY03<0FEUI04E5A@1cLg<0MWIf061PH01/K6`0JFUY055AD@16ATH07alO034a
<@0h>3P0>c/k04A4A01>CTh0FUYJ055AD@1>CTh0DU9B04M7A`1:BTX0@d=302`/;00W9bL07alO03lo
?`13@d<0E5AD02<S8`0i>CT0GEeM02d];@14A4@0?Shn059BDP1FEUH0IFEU08F5Q@1/K6`0DE5A05AD
E01NGUh0J6QX0410@01@D500GEeM034a<@0U9BD0BDU902h^;P1DE5@00P0l?3`0700n?Sh0AdM704=3
@`0m?Cd0=SHf02h^;P0d=3@08B4Q03Xj>P1:BTX0<C4a03Xj>P18B4P0<C4a038b<P0o?cl09RHV05YJ
FP12@T80DE5A04a<C017AdL0=cLg03<c<`1<C4`0AdM705mOG`12@T83051@D00a079bLP1;Bd/0<S8b
06a/K00d=3@0ADE505IFEP1mOGd08b<S03Ti>@17AdL0DE5A02l_;`12@T80@4100::RXP1UIFD0FUYJ
03Lg=`0Z:RX0OGem02<S8`1PH600O7al04=3@`1UIFD0EeMG03Lg=`1=CDd0Ph>306m_K`1=CDd0Cdm?
04i>CP1KFe/0Ng]k079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU905YJFP1LG5`0H61P
09BDU00206e]K@0@05UIF@1EEED0NGUi061PH01UIFD0@T9205EEE@16ATH0FEUI06QXJ016ATH0GEeM
04e=C@1`L700De=C03dm?@80H61P02h0Lg=c07AdM021PH40JFUY07moO`1?Cdl0BTY:05IFEP1SHf<0
FUYJ055AD@1CDe<0?clo06EUI@1fMWH0B4Q803dm?@18B4P0>CTi03Lg=`1>CTh092@T06][J`0S8b<0
Bd];03Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18B4P0:BTY04];B`10@400>c/k04A4A01SHf<0
?Shn03/k>`1GEeL0?clo0410@00l?3`0S8b<0P1;Bd/0>`1FEUH0<c<c05aLG00i>CT0ADE504A4A00j
>SX0:b/[03Ph>01:BTX0BDU904Y:BP0S8b<0?clo02`/;019BDT0AdM705ADE00b<S80<30`04=3@`0f
=SH0=cLg055AD@17AdL0D51@05QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0GEeM065QH@0f
=SH0D51@05ADE01CDe<0MgMg034a<@1FEUH0GEeM055AD@17AdL0F5QH05]KF`13@d<0Cdm?05iNGP1n
OWh0BTY:061PH01EEED0F5QH06m_K`1VIVH0GEeM017ooooo000?ooooo`0b05IFEP1_Kfl0IfMW08f=
S@1<C4`0FUYJ07EeM@1TI6@0RHV902<S8`1EEED0RHV905iNGP17AdL0O7al0492@P1dM7@0Zj^[04I6
AP1iNGT0KFe]020P8017AdL0H61P03lo?`1JFUX07AdM03Xj>P1:BTX0IFEU02d];@1aLG40G5aL03hn
?P25QHD0Lg=c02l_;`11@D40Cdm?02TY:@1TI6@0W9bL03/k>`0h>3P0<c<c069RHP1CDe<0Lg=c01hN
7P0Z:RX205IFEP0@05eMG@28R8P0820P051@D01FEUH0DE5A06i^KP1fMWH08b<S02LW9`1UIFD0Cdm?
07IfMP0b<S809bLW04i>CP80ATI607h0@4100:RXZ00d=3@0H61P06EUI@18B4P0OGem069RHP0K6a/0
8B4Q06MWI`2QXJ40EeMG03Ph>00W9bL0>c/k08f=S@2LW9`0ATI60820P00P8200@T9206MWI`17AdL0
?clo06EUI@0V9RH0AdM705ADE019BDT07QhN03De=@0];Bd0GEeM08f=S@1;Bd/06ATI04E5A@0k>c/0
G5aL08F5Q@11@D40=CDe05aLG00a<C40=SHf08F5Q@2FUYH09bLW02d];@1SHf<0=CDe0861P@2JVYX0
9BDU03De=@1SHf<0DE5A05IFEP1ZJVX0@T9204Q8B01hN7P0G5aL06IVIP25QHD08b<S02d];@1BDU80
Hf=S065QH@1UIFD08b<S04i>CP1NGUh0Kfm_065QH@2b/[80FUYJ03<c<`2MWId0Ogmo04=3@`2XZ:P0
AdM7024Q8@1BDU80Xj>S06i^KP1[Jf/0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
PX:203`l?011@D40GemO03`l?026QXH0VYZJ055AD@0/;2`0DE5A05=CD`1fMWH0QXJ602DU9@0o?cl0
A4A403hn?P1;Bd/0Ogmo04M7A`0f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C4204];B`1L08n?S`1=
CDd0:b/[069RHP1QHF40?3`l09RHV02PX:00:RXZ069RHP1<C4`0LW9b0820P00Q8B40>CTi07emO@1@
D500OGem08f=S@0[:b/0O7al07=cL`1aLG40MGEe04e=C@13@d<0DE5A09JFUP1OGel0IFEU04=3@`1O
Gel0MGEe05MGE`1QHF40/[:b061PH01?Cdl0SHf=05MGE`1KFe/0VYZJ04Q8B00`<300S8b<0<K6aP18
B4P0DE5A0410@00o?cl0OWin0;2`/01=CDd0AdM7071`L00c<c<0;bl_07moO`1HF5P0?3`l03Ti>@0f
=SH0KVi^08F5Q@1?Cdl08b<S04];B`13@d<0Lg=c08J6QP0n?Sh07QhN03lo?`13@d<0EEEE06QXJ02O
Wil0?3`l03Ti>@1;Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06MWI`23Ph<0<c<c02LW9`16
ATHLooooo`0a08R8R01eMGD0ADE504=3@`1@D500EUIF03Ph>01:BTX0Lg=c059BDP26QXH0SHf=09ZJ
VP2@T900GUiN05MGE`24Q8@0OGem05QHF01GEeL0<c<c06=SH`18B4P0@D5104U9B@1:BTX0?Cdm069R
HP1PH600RXZ:06a/K01:BTX0CTi>075aL@1EEED0FEUI04i>CP1VIVH0GemO02HV9P0l?3`0@D5104I6
AP1IFET0HF5Q05UIF@14A4@0C4a<04m?C`0203/k>`0X04m?C`0Y:BT0@T92030`<01=CDd0E5AD05aL
G00i>CT0Cdm?06EUI@0U9BD0E5AD05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410@012@T80Cdm?04a<
C016ATH0@4100492@P0S8b<0<C4a04M7A`0m?Cd0JFUY02d];@15ADD0@T9203Lg=`0o?cl0Bd];0492
@P1>CTh0;Bd]02l_;`80=CDe0:H0<30`04=3@`0m?Cd0<S8b03De=@11@D40;Rh^04m?C`0m?Cd0@d=3
03`l?014A4@0BDU906UYJ@1BDU80EUIF07IfMP1HF5P0EeMG04e=C@14A4@0EEEE05=CD`14A4@0H61P
03dm?@1LG5`0D51@06EUI@15ADD0F5QH03hn?P17AdL0IfMW0:j^[P18B4P0Kfm_079bLP1lO7`0>c/k
02HV9P29RHT06ATI09ZJVP2][Jd0BDU906][J`14A4@061PH02`/;018B4P0Ti>C065QH@0m?Cd0DU9B
07]kN`2RXZ80O7al05YJFP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0FUYJ05EEE@1gMgL0b/[:
03/k>`1QHF40EeMG06a/K01eMGD0AdM706i^KP0[:b/0Cdm?03Lg=`1WIfL0Bd];05ADE01OGel08B4Q
055AD@0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00k>c/0AdM70492@P1;Bd/0Jf][
0492@P1GEeL0EEEE08^;R`28R8P0;bl_02LW9`15ADD0?3`l03Xj>P19BDT0B4Q805EEE@0g=cL0GEeM
03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU905]KF`17AdL0H61P04M7A`1[Jf/0@T92
02h^;P1GEeL0<30`05]KF`11@D40LG5a059BDP1TI6@0G5aL03dm?@1HF5P0=SHf06IVIP1KFe/0EUIF
02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0Fe]K05IFEP17AdL0?clo04I6AP1<C4`0;Bd]
02DU9@1OGel0Cdm?04M7A`1FEUH0>c/k0P1HF5P07@12@T80OGem04U9B@1bLW80Fe]K061PH01>CTh0
Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B05=CD`0Y:BT0IfMW061PH00f=SH0B4Q806=SH`2EUID0
Bd];061PH01LG5`0DU9B06QXJ01RHV80GEeM017ooooo000?ooooo`0906EUI@1PH600EeMG05mOG`1K
Fe/0FUYJ0410@01EEED0J6QX0080CTi>03l0KFe]03dm?@1@D500MWIf02d];@0j>SX0C4a<03@d=01K
Fe/0R8R8020P800X:2P0>c/k055AD@2VYZH0>SXj01hN7P1PH600GUiN04U9B@2VYZH0/[:b02/[:`1`
L700Kfm_06ATI01mOGd0@D5101`L700S8b<0BTY:06a/K01`L700=3@d02/[:`0k>c/0PX:207UiN@1S
Hf<0PH6103hn?P0X:2P0QhN705]KF`1OGel0>SXj01/K6`1EEED0R8R803@d=014A4@0ADE502LW9`1l
O7`0PH6102LW9`0n?Sh0EEEE030`<01ADE40NWYj03Ti>@0g=cL00P12@T80=@1MGEd0SHf=02`/;00R
8R80?3`l055AD@1[Jf/0IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0];Bd0D51@04A4A01S
Hf<0UiNG01lO7`0U9BD0Kfm_079bLP0n?Sh0Hf=S01DE5@0U9BD0F5QH07]kN`0k>c/0JFUY02@T900H
61P0AdM704];B`18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0@d=304M7A`0Z:RX0<C4a08V9R@1M
GEd0Cdm?06i^KP0R8R80<c<c0080FUYJ09l0ADE505IFEP0m?Cd0@D5106ATI01JFUX09BDU04U9B@1=
CDd0DU9B08>3P`0U9BD0<c<c05UIF@0l?3`0ATI608b<S024Q8@0:RXZ055AD@1LG5`0J6QX09NGU`1a
LG40:2PX04m?C`1KFe/0JFUY07moO`1YJFT09RHV051@D01?Cdl0>3Ph0820P02_[jl0;bl_02d];@1f
MWH0GemO07QhN037alL0A4A403/k>`1hN7P0Y:BT07AdM02MWId08B4Q05=CD`2;Rh/0@D5105YJFP1Y
JFT06a/K02HV9P1PH600IVIV08F5Q@1ZJVX0<C4a04a<C02k^k/0R8R8055AD@2>SXh0DE5A06MWI`2P
X:00AdM707YjNP0k>c/07alO05YJFP2FUYH0Hf=S05aLG00_;bl0CTi>08b<S01:BTX0ATI6051@D00o
?cl0JFUY09VIV@0o?cl0FEUI03/k>`1mOGd0a<C405eMG@0j>SX0DE5A04U9B@1;Bd/0VYZJ0410@019
BDT0LW9b04M7A`1PH600^k^k09FEU@0g=cL0NGUi05EEE@1SHf<0YJFU06i^KP0Y:BT0GEeM08>3P`1I
FET0QHF505QHF00i>CT0Bd];09fMW@1/K6`0OWin09ZJVP0[:b/0@T9205MGE`1]KFd0YjNW0820P00S
8b<0BDU908n?S`1]KFd0?3`l07QhN00b<S80>3Ph08n?S`21PH40A4A405]KF`1VIVH0:BTY03@d=01P
H600Hf=S05eMG@13@d<06ATI04E5A@1WIfL0HV9R03Hf=P1TI6@0<C4a03Lg=`2ATI40Kfm_01LG5`0f
=SH07?ooool0602EUID0NGUi05IFEP1UIFD0SHf=07=cL`1=CDd0CTi>05YJFP0n?Sh0>CTi04M7A`1O
Gel0FEUI07=cL`2/[:`0F5QH04Y:BP14A4@0D51@02XZ:P16ATH0=SHf055AD@80GemO00H0>CTi03hn
?P0[:b/0BDU905=CD`15ADD205mOG`0l04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6
04a<C017AdL0ADE504i>CP1XJ6P0IfMW0410@014A4@0DE5A051@D010@400<C4a03`l?01JFUX0IFEU
02HV9P0h>3P0D51@04=3@`1EEED0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0Bd];
034a<@0i>CT0EEEE01lO7`0c<c<0F5QH02`/;00`<3008B4Q04E5A@1ADE40>CTi04e=C@1LG5`0=CDe
02LW9`0a<C40?Shn04];B`12@T80?Shn0P1;Bd/0>015ADD0EEEE06=SH`0h>3P0Hf=S051@D01>CTh0
Bd];04M7A`16ATH0?clo04E5A@1QHF40MWIf04=3@`19BDT0B4Q804A4A01MGEd0BDU904A4A01CDe<0
DU9B04Y:BP1HF5P0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02EUID0HF5Q07inOP1PH600
@41008:2PP0n?Sh0GemO06m_K`1<C4`0IVIV04i>CP0@4100BDU903dm?@1GEeL0A4A405=CD`1BDU80
RHV908Z:RP1QHF40Hf=S0P1>CTh07`1JFUX0<C4a07EeM@1hN7P0B4Q8065QH@17AdL0A4A405UIF@12
@T80I6AT04a<C00j>SX0C4a<05EEE@1TI6@0B4Q804e=C@12@T80FEUI051@D02=SHd0P820055AD@1J
FUX0?Cdm04Q8B00i>CT0BTY:0451@@1cLg<00P1PH6006`24Q8@0=cLg04i>CP0d=3@0EUIF04U9B@2O
Wil0Z:RX08:2PP2>SXh0QhN705UIF@0f=SH0BDU902l_;`1JFUX0DU9B034a<@1NGUh0:b/[07QhN01K
Fe/0HV9R034a<@15ADD0I6AT061PH00204=3@`1:04E5A@1BDU80<C4a06e]K@15ADD0Hf=S03hn?P0d
=3@0EUIF03<c<`20P800CTi>07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400A4A4059BDP0l
?3`0BDU904];B`1:BTX0HV9R059BDP19BDT0?Cdm069RHP0f=SH0B4Q803Ti>@0l?3`0D51@04i>CP0d
=3@0Jf][02PX:014A4@0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1iNGT0D51@04I6AP1<
C4`0<C4a05eMG@1eMGD0BDU906UYJ@1UIFD0DU9B02LW9`1QHF40FUYJ03lo?`18B4P0NGUi0:>SX`19
BDT0?clo04M7A`1>CTh0HF5Q06][J`1hN7PAooooo`003oooool0d@26QXH0TY:B05eMG@1mOGd0JVYZ
09nOW`1PH600De=C06UYJ@1<C4`0KVi^06m_K`18B4P0<c<c065QH@1>CTh0Lg=c05MGE`0d=3@0>c/k
05aLG01IFET0@D51069RHP0[:b/0CDe=06MWI`0k>c/0M7Ad03De=@0Q8B40B4Q8069RHP1;Bd/0Q8B4
03De=@0`<300F5QH06ATI018B4P0HF5Q07AdM00];Bd0De=C075aL@10@400Jf][06UYJ@0a<C40@410
07MgM`1JFUX0C4a<04e=C@0n?Sh0JFUY061PH00g=cL0NGUi05UIF@10@400FEUI06e]K@0e=CD0LW9b
065QH@0n?Sh0GEeM079bLP0h>3P0>c/k065QH@1@D500P82004e=C@0`<300C4a<06EUI@1=CDd0F5QH
0861P@0Y:BT0@T9206UYJ@0g=cL0DU9B07inOP0O7al08b<S04i>CP1MGEd0FUYJ06IVIP0S8b<0?Cdm
04i>CP10@400@D5106MWI`0`<3009BDU05MGE`0`<300Bd];05YJFP0M7Ad0>CTi055AD@1eMGD0820P
03hn?P0/;2`0A4A405iNGP1^KVh0<C4a04Q8B017AdL0>3Ph03hn?P1`L700<c<c075aL@17AdL0>CTi
05eMG@2?Shl0E5AD02PX:01;Bd/0CTi>08^;R`2KVi/0DU9B03hn?P1]KFd0F5QH04M7A`1eMGD0GUiN
0451@@1eMGD0;Rh^06=SH`2PX:00@d=302/[:`1RHV80J6QX05]KF`1kNg/0;bl_038b<P1XJ6P0K6a/
055AD@28R8P0PH61038b<P1PH600Ng]k04M7A`1nOWh0J6QX02PX:00j>SX0NGUi07MgM`1FEUH0PH61
02/[:`0o?cl0MgMg08>3P`1NGUh0MgMg02HV9P0a<C40JFUY04];B`1lO7`0IVIV01lO7`1ADE40QhN7
05aLG00j>SX0J6QX03@d=01[Jf/0OWin02`/;00h>3P0Bd];03Hf=P16ATH0RXZ:07emO@1EEED0FEUI
04Y:BP2IVIT0P82002`/;01HF5P0Cdm?03Ph>01iNGT0@T920080DE5A0300Bd];06][J`21PH40@T92
04Y:BP1hN7P0BTY:07YjNP0a<C40>3Ph079bLP1GEeL0GEeM08f=S@15ADD09bLW05UIF@1@D500MWIf
06][J`0^;Rh0=SHf05QHF026QXH0MWIf08f=S@0a<C40CTi>05YJFP1PH600IfMW0;Jf]P1cLg<0;Bd]
04Q8B01ZJVX0HV9R08R8R00b<S80>3Ph04m?C`2<S8`0HF5Q05aLG02NWYh0=CDe051@D029RHT204e=
C@0M069RHP0h>3P0@41006e]K@1BDU80>CTi05iNGP10@400=3@d06a/K024Q8@0CDe=051@D01TI6@0
@T9208B4Q02HV9P0?Shn04E5A@1=CDd0<C4a04A4A01bLW80J6QX02l_;`1TI6@0@T920451@@1jNWX0
7?ooool0Z02=SHd0K6a/05EEE@1;Bd/0HF5Q06a/K01=CDd0HV9R08B4Q012@T80B4Q804a<C01KFe/0
NGUi061PH01VIVH0Fe]K065QH@1EEED0CTi>02TY:@1NGUh0?Cdm04i>CP1FEUH0C4a<03hn?P1FEUH0
AdM7069RHP1ADE40Cdm?05ADE01RHV80DU9B069RHP1HF5P0JVYZ05=CD`0T92@0>c/k0492@P1;Bd/0
De=C05]KF`1NGUh0CDe=03De=@0l?3`0?Cdm04Q8B012@T80:RXZ04=3@`0n?Sh0CTi>051@D01YJFT0
9bLW03Lg=`1QHF40<C4a0492@P18B4P0CTi>04=3@`1MGEd0N7Qh06m_K`11@D40BTY:04e=C@1ZJVX0
@d=304A4A01JFUX0=SHf0410@01?Cdl0<C4a05IFEP0e=CD0>3Ph04U9B@13@d<0@41003hn?P0c<c<0
?Cdm02l_;`0Z:RX0?Cdm03Hf=P0e=CD0>CTi0492@P0a<C40<c<c03/k>`0Q8B40DU9B03Xj>P1EEED0
?Shn04Y:BP0a<C40BTY:0492@P1FEUH0IVIV05ADE01<C4`0ATI60410@01CDe<0Bd];03Hf=P15ADD0
92@T03/k>`1ADE40JFUY03`l?01DE5@0A4A404m?C`1>CTh0OWin04m?C`2@T900IfMW06=SH`1iNGT0
FEUI09FEU@1;Bd/0QhN709:BTP1>CTh0KVi^05MGE`10@400Hf=S04Y:BP1BDU80AdM703hn?P1MGEd0
NGUi06m_K`0l?3`0@D5104I6AP0n?Sh0A4A404=3@`27QhL0M7Ad02/[:`15ADD0?clo05ADE02?Shl0
B4Q8061PH01BDU80H61P05eMG@80EEEE07P0@D51051@D00e=CD0FUYJ03Ph>01lO7`0KVi^030`<01H
F5P0@D5104Q8B00a<C40ATI603lo?`1nOWh0FEUI06a/K029RHT0@41005mOG`1CDe<0OWin04E5A@1=
CDd0MGEe04Y:BP24Q8@0JVYZ03Hf=P0l?3`0Cdm?0492@P19BDT0DU9B04I6AP1CDe<0A4A406EUI@1E
EED0Jf][03hn?P0b<S80L71`04M7A`0c<c<0>SXj04A4A01IFET0B4Q805eMG@1EEED0J6QX04];B`15
ADD0GEeM04i>CP1TI6@0D51@06i^KP1TI6@0JFUY06MWI`17AdL0J6QX030`<01SHf<0EEEE0492@P19
BDT0Fe]K051@D01<C4`0R8R803Hf=P1;Bd/0>c/k061PH019BDT0DE5A03<c<`1IFET0GemO034a<@0c
<c<0EUIF03Lg=`1QHF40JVYZ04Q8B01MGEd0?clo04a<C01LG5`0GUiN08B4Q01GEeL0EEEE07YjNP1d
M7@0GEeM05aLG01OGel0?Cdm07QhN01:BTX0EUIF03Ph>01YJFT0EEEE03/k>`1FEUH0QhN70;jn_P1<
C4`0DE5A06QXJ01LG5`0LG5a06MWI`1jNWXAooooo`003oooool0o`1EEED0IFEU08V9R@2GUiL0?Shn
06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2JVYX0IVIV06e]K@0e=CD0F5QH06i^KP1RHV80KFe]
07emO@0Y:BT0BDU904I6AP1OGel0]KFe01/K6`0W9bL0CTi>03Xj>P0e=CD0KVi^06IVIP0L71`0Ng]k
07UiN@1@D500JFUY028R8P0B4Q80:BTY075aL@1GEeL0I6AT02h^;P0I6AT0=3@d08J6QP1<C4`0GemO
06ATI00Y:BT0@T9205EEE@0d=3@0Cdm?02d];@0W9bL0T92@0:VYZ@0_;bl0<C4a03De=@0];Bd0P820
08:2PP0Y:BT0@41004m?C`0f=SH0MgMg0=oOg`0m?Cd0ADE506YZJP1HF5P0Ti>C09RHV00c<c<0@410
05mOG`1?Cdl0MWIf05mOG`0@4100D51@06YZJP1QHF40IFEU0:FUY@16ATH0?clo0:^[Z`1XJ6P0I6AT
05EEE@0X:2P0CTi>06QXJ01OGel09RHV04i>CP0g=cL0DE5A07emO@1EEED0;Bd]05mOG`0i>CT0B4Q8
05EEE@1IFET07alO04a<C00Y:BT09BDU03@d=01gMgL0:2PX02h^;P19BDT0C4a<07IfMP17AdL0820P
02@T9012@T80ADE505IFEP1VIVH0;2`/02TY:@1VIVH0UYJF05]KF`2CTi<08R8R02<S8`0a<C40IVIV
05aLG01[Jf/08b<S03hn?P1ADE40H61P0451@@2<S8`0>SXj034a<@1nOWh0L71`04I6AP2j^[X0A4A4
03lo?`1ZJVX0EUIF05ADE02;Rh/0>CTi03Ph>01`L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0QhN7
05MGE`1HF5P0Hf=S03Lg=`17AdL0IVIV06i^KP0X:2P0AdM703/k>`1eMGD0KFe]04Q8B00l?3`0AdM7
02l_;`11@D40K6a/05iNGP19BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@29RHT0Ph>3
02/[:`0k>c/0G5aL04A4A02EUID0N7Qh02h^;P11@D40GEeM0:>SX`15ADD06a/K04i>CP1JFUX0EeMG
07EeM@29RHT0ADE506IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/08R8R00n?Sh0BDU9
07AdM01:BTX0Lg=c09BDU01@D500?Shn0820P01=CDd0GUiN08j>SP0k>c/0A4A405mOG`2?Shl0JVYZ
07moO`17AdL0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@008`1BDU80Bd];06YZJP1JFUX0
;Bd]04i>CP2XZ:P0K6a/03<c<`1EEED0C4a<05]KF`2SXj<0EeMG01DE5@0f=SH0C4a<03Lg=`1gMgL0
YJFU03Ph>00f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`18B4P0Zj^[03De=@0N7Qh0
?clo01cooooo04H0TY:B08V9R@18B4P0DU9B05UIF@1OGel0?Cdm05]KF`1GEeL0@D51030`<00k>c/0
HV9R05QHF01VIVH0LG5a092@T01LG5`0DE5A05eMG@0S8b<0AdM703Hf=P0i>CT0?Cdm05IFEP0k>c/0
GemO04I6AP0l?3`0@D5103<c<`1LG5`0Kfm_04a<C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40
@D5104=3@`0e=CD0ATI603lo?`1EEED0GemO03Ph>00o?cl0DU9B04e=C@0h>3P0:RXZ04];B`1VIVH0
J6QX01lO7`0b<S80CDe=03<c<`1KFe/0C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0CP1C
De<0GemO06m_K`1EEED0;Rh^03Xj>P1VIVH0>c/k04U9B@0S8b<0=cLg05UIF@1EEED0Cdm?05mOG`12
@T80<c<c030`<011@D40DE5A03Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04m?C`1>
CTh0ATI6059BDP18B4P0?Cdm04a<C01lO7`0QhN704E5A@1>CTh0FEUI05=CD`1;Bd/0CDe=03dm?@18
B4P0<c<c05]KF`1?Cdl0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0Fe]K075aL@1R
HV80C4a<06e]K@0[:b/0SHf=09nOW`0o?cl0GEeM04U9B@0c<c<0>c/k05eMG@1jNWX0IfMW04M7A`1C
De<0TI6A07IfMP<0DE5A08T0Hf=S05eMG@1@D500Ng]k06m_K`1hN7P0E5AD059BDP1jNWX0Kfm_03/k
>`1eMGD0De=C04I6AP1:BTX0CTi>05EEE@18B4P0G5aL038b<P1QHF40;bl_061PH01NGUh0>c/k04Q8
B00k>c/0@d=304m?C`1JFUX0Cdm?079bLP0c<c<0JFUY08N7Q`0n?Sh0C4a<04];B`1EEED0@D510:^[
Z`2`/;00@41004i>CP0c<c<0H61P038b<P1UIFD0EeMG06MWI`1bLW80FUYJ07UiN@1WIfL0LW9b05aL
G01dM7@0CDe=03Hf=P1TI6@0Lg=c05=CD`1FEUH0FEUI05=CD`1GEeL0RXZ:04m?C`1>CTh0GUiN04e=
C@1BDU80FUYJ0:6QX@1MGEd0OWin06MWI`1dM7@0J6QX03Lg=`1BDU80:b/[06][J`1>CTh0@d=303Hf
=P15ADD0@T9203Lg=`1BDU809BDU04];B`0i>CT0ATI603`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=
C@1YJFT0=CDe03dm?@1;Bd/0@410059BDP11@D40Fe]K05aLG01FEUH0EEEE07=cL`1_Kfl0MgMg08J6
QP1<C4`0=CDe0492@P17AdL0Ti>C05=CD`1;Bd/0?Cdm051@D01ADE40?clo04Y:BP1KFe/0Jf][03hn
?P1BDU80FUYJ04Y:BP1ADE40Cdm?07moO`0Aooooo`003oooool04@2DU9@0G5aL059BDP1hN7P0Hf=S
05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08>3P`0^;Rh0JVYZ0080Bd];02X0Fe]K
06UYJ@0h>3P08B4Q04A4A00^;Rh0NWYj04];B`0G5aL0C4a<0451@@0Y:BT0LG5a08F5Q@0N7Qh0?Shn
03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0SHf=03Hf=P0Q8B4092@T04I6AP1@D500UIFE
0:f][@0K6a/09bLW0410@014A4@0Bd];03<c<`0^;Rh0=cLg06IVIP10@40205=CD`0]030`<01BDU80
EeMG06UYJ@1oOgl0XJ6Q02XZ:P0m?Cd0MgMg06ATI01EEED05ADE02/[:`14A4@0KFe]03Lg=`0o?cl0
KVi^02TY:@1:BTX0N7Qh02h^;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00[:b/0CDe=03Ph>01YJFT0
S8b<01LG5`0`<300BDU905QHF012@T80PX:202TY:@17AdL0DE5A059BDP12@T80ZZZZ0080<S8b09P0
?clo05UIF@1cLg<0PX:2028R8P0Y:BT0=SHf06QXJ01EEED0NGUi05IFEP0h>3P0Fe]K08B4Q01<C4`0
QXJ608>3P`0X:2P0@d=305QHF01aLG40K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
A4A407inOP0l?3`0FEUI08f=S@0d=3@0CDe=06=SH`1TI6@0>c/k05QHF00a<C40<30`08>3P`2VYZH0
<c<c05MGE`1/K6`0:BTY06YZJP28R8P0>CTi04Y:BP1BDU80?Cdm05]KF`2KVi/0=3@d024Q8@19BDT0
FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP1TI6@061PH03Ti>@21PH40@41005mOG`1IFET0
:BTY04M7A`1DE5@0GemO07QhN01BDU80<S8b05IFEP1jNWX0IfMW03Hf=P1mOGd0?Shn04Y:BP1nOWh0
DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];06ATI00Y:BT0GemO08:2PP16ATH0K6a/06e]K@0];Bd0
ADE50;:b/P1@D500IVIV02l_;`0n?Sh0P82006EUI@11@D40EeMG02h^;P0m?Cd0Kfm_038b<P1=CDd0
BDU904A4A017AdL0SXj>05MGE`0e=CD0D51@05UIF@1RHV80ZZZZ04=3@`15ADD0EeMG065QH@1[Jf/0
QXJ6061PH015ADD0CTi>05UIF@1PH600Z:RX07UiN@0e=CD0@41005eMG@1KFe/0WYjN059BDP0e=CD0
>CTi075aL@80H61P01X0Kfm_05IFEP0[:b/0K6a/08V9R@0l?3`0HF5Q0492@P0d=3@0=cLg06EUI@1Z
JVX0NWYj03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400>3Ph061PH01EEED0<30`05IFEQco
oooo01T0Vi^K07inOP19BDT0D51@06e]K@1dM7@0BTY:07inOP1dM7@0CTi>02l_;`15ADD0PH61079b
LP2ATI40ZJVY092@T01RHV80E5AD05iNGP10@400D51@03`l?00n?Sh0C4a<0080IFEU04/0P82005UI
F@1RHV80DE5A04E5A@1eMGD0R8R8069RHP1gMgL0KFe]05ADE01GEeL0;Bd]038b<P1GEeL0I6AT04e=
C@1>CTh0EEEE0451@@1;Bd/0K6a/04A4A00n?Sh0Bd];02LW9`0k>c/0;2`/04=3@`1>CTh0GEeM014A
4@0X:2P0CDe=03`l?018B4P0?clo04E5A@1?Cdl0EEEE06a/K01LG5`0?clo04I6AP1>CTh0DU9B034a
<@0n?Sh0IfMW02HV9P10@400HV9R038b<P1RHV80>3Ph03Lg=`1EEED0AdM704A4A01ADE40>CTi03De
=@0^;Rh0:b/[03Lg=`0c<c<0=CDe03/k>`0h>3P0<c<c02LW9`0c<c<07AdM05EEE@1:BTX00P1<C4`0
^P1EEED0ADE504e=C@14A4@0LG5a079bLP18B4P0De=C05EEE@17AdL0DU9B04Y:BP1DE5@0LG5a0492
@P13@d<0B4Q806UYJ@0i>CT0DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]055AD@1UIFD0JVYZ05YJ
FP1kNg/0:RXZ05]KF`1eMGD0;Rh^075aL@0n?Sh061PH06a/K01=CDd0H61P03`l?00`<300C4a<09^K
V`1_Kfl0FEUI05aLG011@D40<S8b03<c<`0i>CT0Zj^[08R8R011@D40P820069RHP2CTi<0XJ6Q04U9
B@1BDU80AdM704i>CP1?Cdl0GEeM05=CD`19BDT0De=C05iNGP2BTY80Cdm?06YZJP21PH40B4Q8069R
HP1BDU80I6AT051@D01<C4`0D51@08b<S013@d<0KFe]08V9R@18B4P0@D5103<c<`1[Jf/0>SXj04m?
C`1nOWh0?clo061PH01EEED0<S8b04=3@`14A4@0;Bd]069RHP1`L700BTY:06][J`1eMGD0Shn?06m_
K`28R8P0=CDe05IFEP1`L700HV9R04=3@`1>CTh0G5aL06IVIP0a<C40C4a<04=3@`1MGEd0<c<c02LW
9`1OGel0;Rh^059BDP1:BTX0Ogmo051@D01YJFT0K6a/04U9B@1GEeL0=3@d04Y:BP17AdL0>CTi03Lg
=`19BDT0ATI60451@@1cLg<0BDU904E5A@0e=CD0E5AD059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8
B01LG5`0;Bd]065QH@1mOGd0BTY:04a<C015ADD0H61P05IFEP1CDe<0Ti>C06UYJ@1JFUX0Vi^K09BD
U00i>CT0GUiN04i>CP10@400FEUI04E5A@1JFUX0<C4a04I6AP0n?Sh0FEUI05mOG`1kNg/0XJ6Q02h^
;P0e=CD0Hf=S04a<C01HF5P0CTi>0:JVYQ7ooooo000?ooooo`2U07IfMP2:RXX0CDe=06][J`1^KVh0
TY:B03Xj>P17AdL0FEUI0451@@1iNGT0QhN703<c<`14A4@0GemO04E5A@2BTY80=SHf02`/;018B4P0
JFUY05QHF01LG5`0KVi^03Hf=P1VIVH0UiNG05YJFP2SXj<0ATI602LW9`0o?cl0Kfm_05QHF02;Rh/0
9BDU03@d=01kNg/0PH6104E5A@1PH600FUYJ01hN7P1@D500GemO03Ph>018B4P0?Shn01TI6@0f=SH0
Q8B404e=C@0f=SH0?clo03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0IFEU01/K6`1EEED0
>SXj02d];@1`L700a<C403Hf=P0U9BD0JFUY06QXJ02;Rh/09bLW01LG5`0W9bL0Hf=S04U9B@1SHf<0
Lg=c01/K6`0a<C40U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX029RHT0?Cdm03Hf=P11@D40
G5aL069RHP1:BTX0Ng]k02@T900[:b/0FEUI03dm?@17AdL0Fe]K01hN7P0X:2P0=SHf05=CD`0b<S80
F5QH02`/;00T92@0EeMG06QXJ00K6a/0AdM704a<C00J6QX0=CDe07UiN@0a<C40FUYJ038b<P0_;bl0
AdM708R8R01CDe<0:2PX06QXJ015ADD0HF5Q08b<S00b<S80@T9205]KF`0d=3@0ADE5096AT@1^KVh0
8R8R04M7A`0k>c/0T92@09fMW@16ATH08R8R05ADE01KFe/0H61P09nOW`0g=cL0A4A4051@D02>SXh0
FEUI0:6QX@2HV9P0=cLg04I6AP1ZJVX0IVIV0:b/[01[Jf/0?3`l0080E5AD07/0L71`04I6AP1aLG40
9bLW05UIF@1fMWH0CTi>03lo?`1ADE40=CDe051@D02?Shl0<30`061PH00`<300<C4a05]KF`1hN7P0
8B4Q01`L7011@D40>3Ph08b<S01/K6`09RHV038b<P1EEED0=cLg051@D01oOgl0Jf][03hn?P11@D40
Hf=S08V9R@1PH600<C4a0410@012@T80EEEE06m_K`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f=SH0
>CTi05eMG@1LG5`0WIfM02TY:@0U9BD0H61P06IVIP1EEED0MWIf02d];@0l?3`0JFUY04=3@`1YJFT0
EeMG02HV9P1DE5@0De=C065QH@1=CDd0J6QX02XZ:P1GEeL0LW9b06YZJP1[Jf/0TI6A04Y:BP14A4@0
DE5A07=cL`1kNg/0R8R803<c<`0U9BD0IVIV07emO@19BDT0EUIF07moO`0a<C40Xj>S09^KV`0f=SH0
>CTi05iNGP0f=SH0=CDe05aLG01KFe/0D51@06a/K00a<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0
ATI608n?S`1TI6@09bLW03Hf=P1BDU80>CTi05ADE01UIFD0G5aL02`/;01RHV80Bd];061PH02ZZZX0
7?ooool05@2LW9`0R8R8069RHP1ADE40JVYZ06][J`11@D40E5AD08B4Q01?Cdl0BTY:05MGE`1VIVH0
RXZ:075aL@1RHV80Ogmo05YJFP1<C4`0EeMG02LW9`020451@@1V05]KF`1<C4`0@D5103Lg=`1XJ6P0
I6AT0861P@1=CDd0>CTi05ADE01_Kfl0@d=305QHF01FEUH0RXZ:051@D017AdL0D51@04M7A`0i>CT0
Cdm?05ADE01@D500@d=304i>CP1GEeL0ADE505=CD`1JFUX0=SHf04a<C00f=SH0Cdm?04];B`1OGel0
9bLW03Lg=`1QHF40>SXj05]KF`1=CDd0GEeM061PH01ZJVX0Jf][06ATI016ATH0F5QH069RHP1MGEd0
BTY:04m?C`1]KFd0?3`l03@d=01@D500?clo055AD@0^;Rh0BDU905aLG00l?3`0Bd];069RHP14A4@0
?3`l03<c<`0h>3P0BDU904I6AP19BDT0FEUI04A4A00n?Sh0ATI604i>CP0`<300IfMW05YJFP19BDT0
Bd];05UIF@16ATH0BDU905aLG01[Jf/0BTY:03hn?P1MGEd0EUIF0410@01DE5@0O7al04U9B@1LG5`0
?clo04Y:BP1IFET0FUYJ03Ph>01@D500G5aL0P1dM7@06@2IVIT0IVIV0=CDe025QHD0Hf=S06QXJ01Z
JVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0E5AD02DU9@13@d<0:BTY04i>CP0c<c<0C4a<0451@@1`
L700P82003/k>`1?Cdl00P13@d<0EP12@T80<30`03Ti>@14A4@0:b/[03lo?`17AdL0MGEe09fMW@1V
IVH0LG5a06a/K01GEeL0BTY:059BDP1=CDd0ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1g
MgL0?Cdm0451@@0i>CT0CDe=06=SH`2RXZ80?clo07YjNP2ATI40EUIF06MWI`1NGUh0Ogmo03/k>`1]
KFd0QXJ6071`L01UIFD0E5AD051@D01<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05=CD`1h
N7P0LW9b055AD@12@T80PH6104m?C`1;Bd/0>CTi03lo?`17AdL0@T9205iNGP19BDT0D51@055AD@0g
=cL0CTi>04I6AP1`L700F5QH08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0CTi>04e=C@18
B4P0@D510P13@d<0<02UYJD0?clo04M7A`0V9RH0EEEE02l_;`0`<300>CTi05=CD`1EEED0:2PX0451
@@1DE5@0:BTY0451@@15ADD0@d=306i^KP1CDe<0GemO03hn?P1mOGd0_kno08^;R`1UIFD0Hf=S04m?
C`0d=3@0SXj>06a/K016ATH0JFUY04E5A@12@T80B4Q805UIF@17AdL0ATI603dm?@1MGEd0PH6104U9
B@18B4P0G5aL051@D01DE5@0Fe]K07IfMQ7ooooo000?ooooo`0:06QXJ024Q8@0SXj>08:2PP18B4P0
LG5a05mOG`27QhL0Rh^;030`<080CTi>09h0D51@04U9B@1=CDd0<30`04Y:BP1gMgL0>3Ph06QXJ011
@D40>3Ph03hn?P1OGel0CDe=09JFUP0f=SH07alO051@D01;Bd/08b<S04M7A`0h>3P0=SHf061PH00d
=3@08R8R059BDP13@d<0FEUI096AT@1PH600;Rh^03Ph>01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;
Bd/0DU9B08R8R01LG5`07AdM0410@01XJ6P0K6a/07YjNP1eMGD0820P03De=@1MGEd0Cdm?0;2`/00i
>CT071`L03Xj>P1hN7P0MGEe04e=C@2RXZ80:b/[04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1R
HV80GEeM05QHF00W9bL0:2PX03dm?@1HF5P0;bl_02XZ:P11@D407QhN05MGE`1XJ6P07AdM03De=@0d
=3@0?Cdm05=CD`2ATI40=CDe01DE5@0k>c/0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD04M7A`21
PH40EUIF01dM7@10@400GemO04I6AP2BTY80D51@020P8017AdL0E5AD065QH@2JVYX0=cLg02TY:@11
@D40FUYJ075aL@1EEED0Xj>S03@d=01TI6@0QXJ6069RHP1jNWX0MgMg02HV9P0`<300DE5A08^;R`1A
DE40EUIF02@T900h>3P0P82008N7Q`1ADE40Ogmo04U9B@0g=cL0P82004I6AP0Z:RX0GemO02`/;015
ADD0E5AD09NGU`1IFET0KVi^02LW9`0g=cL0TY:B0:n_[`11@D40?clo06EUI@0o?cl0?Shn0;Fe]@80
@D5104T0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40GEeM05IFEP2`/;00Cdm?01PH600c<c<0K6a/04A4
A01LG5`0Shn?02PX:01ADE40WIfM04];B`1YJFT0MWIf02<S8`0`<300O7al07YjNP25QHD0@410030`
<01[Jf/0W9bL051@D01ZJVX0=SHf03Xj>P1ZJVX0CTi>07=cL`0m?Cd092@T07moO`2XZ:P0EEEE05mO
G`1`L700AdM70;Ng]`1nOWh0C4a<05aLG010@400Fe]K08R8R01eMGD0;bl_05MGE`14A4@0UIFE09nO
W`15ADD0BTY:08j>SP19BDT0FEUI0:j^[P0m?Cd0?clo06=SH`0h>3P0HF5Q0;^k^`1?Cdl0@4100080
Bd];02/0O7al0:f][@1ADE40:BTY04Q8B01GEeL0BTY:06ATI023Ph<0;2`/05ADE029RHT0Jf][06AT
I01NGUh0;Rh^03hn?P17AdL0GemO04];B`1`L7008R8R03Lg=`1^KVh0HV9R03hn?P1OGel0D51@02DU
9@1NGUh0Vi^K03dm?@0l?3`0A4A402XZ:P19BDT0Bd];065QH@11@D40N7Qh02HV9P0[:b/0O7al01co
oooo0180UYJF06YZJP15ADD0DE5A065QH@1KFe/0A4A405aLG01?Cdl0@41005QHF01OGel0GUiN075a
L@2:RXX0^KVi0820P01^KVh205MGE`0T02DU9@1VIVH0@d=304e=C@1DE5@0De=C03hn?P1@D500BDU9
05MGE`1:BTX0=cLg03Xj>P1FEUH0Cdm?05UIF@1@D500>SXj04];B`0];Bd0:BTY0451@@14A4@0BTY:
03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>CTh0A4A403Lg=`0j>SX0@d=30P1GEeL0600K6a/0
D51@05EEE@0e=CD0EUIF05iNGP1GEeL0D51@05iNGP2BTY80K6a/0451@@1FEUH0HV9R06QXJ013@d<0
B4Q80451@@0N7Qh08b<S05YJFP0e=CD0HV9R02XZ:P80@T9203@0@D5104=3@`1DE5@0?Shn04A4A00]
;Bd0?Shn04E5A@0h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`1<C4`0GUiN03dm?@1A
DE40F5QH065QH@16ATH0LG5a05UIF@1=CDd0EUIF065QH@1@D500FUYJ0410@01:BTX0Kfm_04I6AP1B
DU80C4a<065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ604Q8B01DE5@0QHF506MWI`23
Ph<0KVi^0P2?Shl0>`1JFUX0IFEU065QH@1>CTh0IVIV04a<C01CDe<0;bl_03`l?014A4@0M7Ad04];
B`0g=cL0DU9B055AD@24Q8@0HV9R04E5A@1[Jf/0Fe]K010@401UIFD08B4Q0451@@1VIVH0@D5109^K
V`1LG5`0BTY:04M7A`14A4@0EEEE04A4A01>CTh0;2`/08:2PP0h>3P0K6a/06i^KP0P8200=cLg038b
<P1=CDd0?Cdm05]KF`1ADE40M7Ad03De=@1:BTX0Kfm_03hn?P1GEeL0AdM704U9B@1FEUH0MWIf09>C
T`1RHV80Lg=c0080AdM705/08b<S04E5A@0`<300EeMG05YJFP1LG5`0I6AT04];B`1SHf<0?clo06IV
IP0`<300F5QH06EUI@16ATH0?clo059BDP1<C4`0DE5A04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=C
D`1EEED0TY:B05ADE01`L700CTi>08R8R01fMWH0>CTi059BDP0Y:BT0G5aL04i>CP18B4P0AdM704e=
C@15ADD0>CTi05eMG@0];Bd0DU9B02LW9`1FEUH0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZ
JP11@D40?clo05QHF00f=SH0@d=304e=C@1EEED0@D5104Q8B01HF5P0EeMG05UIF@2EUID0T92@051@
D019BDT0=CDe04e=C@1hN7P0BDU904Q8B00E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH069R
HP1mOGd0Fe]K061PH01=CDd0M7Ad017ooooo000?ooooo`3o07]kN`1GEeL0D51@09BDU01HF5P0Fe]K
03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0JFUY03Hf=P1>CTh0B4Q805QHF02k^k/0T92@
01`L700n?Sh0=3@d04E5A@2e]KD0@T9203Hf=P0c<c<0ATI606MWI`2i^KT0UiNG02<S8`1ADE40Jf][
07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@23Ph<07alO038b<P1OGel0LW9b04M7A`1ADE40=SHf
01HF5P0T92@0BDU9030`<01<C4`071`L02d];@1PH600I6AT02LW9`0Y:BT0>3Ph04i>CP2_[jl0L71`
01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI0451@@0i>CT0=cLg04E5A@2HV9P0Lg=c020P800m?Cd0Cdm?
04i>CP1lO7`0FUYJ01dM7@17AdL0IfMW04Y:BP1CDe<0QHF502<S8`0o?cl0M7Ad04M7A`1^KVh0JFUY
020P800a<C40P82007]kN`0j>SX0DU9B01dM7@15ADD0Shn?07EeM@17AdL0Hf=S024Q8@0/;2`0EeMG
07AdM00h>3P0HV9R02PX:00c<c<0E5AD09bLW017AdL0GemO03dm?@0X:2P0GemO079bLP0_;bl0CDe=
05]KF`0c<c<09bLW06i^KP1@D500?Shn04U9B@0n?Sh0UiNG07MgM`0M7Ad08B4Q03Xj>P14A4@0IfMW
05mOG`0I6AT0<c<c04M7A`1GEeL0I6AT09nOW`1QHF40<30`06a/K00l?3`0DU9B0;no_`1=CDd06ATI
04Y:BP1mOGd0FUYJ0:VYZ@14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`1NGUh0Ng]k
09:BTP2LW9`092@T05QHF01lO7`0IVIV06e]K@26QXH08b<S071`L02EUID0?Cdm05MGE`1KFe/0=SHf
03Lg=`1HF5P0BDU9059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01aLG40>SXj05ADE01PH600<C4a
03`l?00b<S80AdM706=SH`1ZJVX08b<S04Y:BP19BDT0RXZ:06MWI`0[:b/0B4Q807alO01RHV80P820
09ZJVP0k>c/0F5QH05iNGP1YJFT0[Zj^03Ti>@0m?Cd0QhN706=SH`1DE5@0QXJ602HV9P1SHf<0R8R8
04a<C01nOWh0VIVI051@D00[:b/0S8b<06YZJP1iNGT0TI6A04e=C@0o?cl0LG5a08V9R@13@d<0LW9b
05MGE`10@400DE5A06=SH`1=CDd0T92@0410@00_;bl0?3`l000S05=CD`1;Bd/0G5aL03De=@0m?Cd0
De=C069RHP19BDT0@D5105iNGP0n?Sh0>c/k06e]K@0c<c<06ATI04U9B@0d=3@0>c/k06YZJP25QHD0
9bLW03Ph>01KFe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`04m?C`2XZ:P0;Bd]01TI6@0j>SX0
7?ooool0]@2CTi<0U9BD04Y:BP1ADE40HV9R07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0
]KFe06UYJ@1=CDd0JVYZ065QH@1DE5@0FEUI02DU9@0m?Cd0;Rh^04Q8B010@400DU9B04=3@`29RHT0
KFe]051@D01?Cdl0CTi>05]KF`1kNg/0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1CDe<0
EeMG05ADE01PH600?3`l04U9B@1GEeL0?Shn03`l?015ADD09bLW03<c<`0Y:BT0A4A406=SH`1HF5P0
4Q8B02TY:@1BDU80AdM7061PH00];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m?Cd0BDU904e=C@1;Bd/0
C4a<06IVIP1NGUh09BDU02h^;P10@400@D5105eMG@0_;bl0D51@05YJFP0n?Sh0Cdm?06a/K00f=SH0
>c/k028R8P1EEED0@41003De=@1;Bd/0?clo03Ti>@0b<S80Cdm?05YJFP0P8200D51@04a<C00f=SH0
>CTi07=cL`0h>3P0?Cdm03/k>`2>SXh0E5AD03Hf=P1ADE40FEUI03hn?P0m?Cd0CTi>059BDP1TI6@0
@T9205QHF01?Cdl0De=C03dm?@1OGel0BTY:04i>CP1mOGd0XZ:R05ADE02KVi/0K6a/05EEE@21PH40
HV9R07AdM00];Bd0CDe=0820P01<C4`0Q8B404A4A00`<300Xj>S09JFUP1hN7P0I6AT04M7A`1RHV80
QXJ609FEU@1QHF40De=C04I6AP14A4@0CDe=04M7A`1fMWH0E5AD02l_;`10@400;Bd]065QH@2WYjL0
Cdm?065QH@0a<C40=cLg03dm?@0k>c/0Fe]K0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0
EeMG03hn?P1WIfL00P10@400AP1VIVH0][Jf03Ti>@1GEeL0M7Ad059BDP1SHf<0=SHf05QHF011@D40
[:b/0;Rh^01SHf<0RHV904Q8B01RHV80=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059BDP1VIVH0
H61P06EUI@0m?Cd0?3`l08>3P`18B4P0?clo05eMG@1HF5P0EEEE03Ti>@14A4@0CDe=05QHF00j>SX0
820P05YJFP0V9RH0DE5A0451@@1hN7P0ATI6059BDP1>CTh0@T9206ATI00K6a/0CDe=04=3@`0j>SX0
CDe=03dm?@12@T80?Cdm079bLP0a<C40EeMG02LW9`1OGel0IVIV059BDP1OGel0Bd];03lo?`10@402
051@D00S03lo?`1GEeL0EUIF02h^;P1@D500@T9207inOP1GEeL0EUIF08:2PP1[Jf/0JFUY04m?C`1D
E5@0:b/[04m?C`0o?cl0?3`l05aLG01:BTX0DE5A01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`
<300=cLg04m?C`16ATH0G5aL06IVIP1RHV804Oooool000oooooo05@0Xj>S061PH01EEED0GUiN06][
J`20P800=CDe05aLG028R8P0Cdm?08n?S`2ATI40=SHf04U9B@2GUiL0E5AD0820P00d=3@07AdM06QX
J02JVYX0E5AD05QHF00m?Cd071`L06EUI@2CTi<0ADE507YjNP0^;Rh0:2PX075aL@2=SHd0=cLg05YJ
FP0K6a/0=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]08:2PP1GEeL05ADE03Lg=`13@d<0E5AD09VI
V@26QXH08b<S038b<P18B4P0HF5Q0:f][@0e=CD06ATI034a<@1VIVH0BDU906EUI@1DE5@0;Bd]06UY
J@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80S8b<06QXJ00E5AD0;bl_05=CD`1bLW80Bd];06YZ
JP1WIfL04Q8B03hn?P1PH60205EEE@1j06ATI00J6QX0=3@d069RHP1ADE40D51@0451@@0l?3`0IFEU
07IfMP0[:b/0<c<c055AD@0j>SX0<30`071`L00^;Rh0>CTi03/k>`12@T80C4a<079bLP0g=cL0;2`/
04I6AP1MGEd0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0DE5A07MgM`1<C4`0>CTi03Xj>P1KFe/0E5AD
08f=S@1lO7`0:RXZ03hn?P1GEeL0Fe]K08^;R`22PX806ATI04M7A`2FUYH0EUIF04e=C@2MWId0?Shn
0451@@2=SHd0>3Ph04Y:BP2BTY80@D5102l_;`2:RXX0UIFE05EEE@1RHV807QhN02TY:@1cLg<0WinO
03@d=01TI6@0B4Q801dM7@1FEUH0GemO02PX:00m?Cd0>CTi03Ph>01;Bd/0U9BD04m?C`0W9bL0@D51
034a<@20P800/k>c05QHF00/;2`0C4a<04m?C`1ZJVX0T92@02d];@0j>SX0?clo03Hf=P1fMWH0X:2P
02XZ:P0e=CD0DU9B04e=C@2CTi<0MWIf02l_;`1HF5P0JFUY05YJFP20P800][Jf03lo?`1bLW80I6AT
055AD@2>SXh0D51@02/[:`1FEUH0MgMg04A4A01VIVH204A4A01@0820P01BDU80SXj>04];B`0l?3`0
ATI609JFUP1mOGd0Ng]k04=3@`17AdL0Ogmo07EeM@1?Cdl0HV9R03hn?P0_;bl0LG5a05ADE01XJ6P0
A4A404=3@`1HF5P0UiNG069RHP0l?3`0CTi>05aLG01ZJVX0SXj>05=CD`1=CDd0IFEU065QH@14A4@0
N7Qh05YJFP11@D40De=C04];B`1XJ6P0YJFU08f=S@0Y:BT0@41004U9B@1eMGD0XJ6Q04e=C@0R8R80
De=C05]KF`16ATH0LW9b0;6a/@1;Bd/0;Rh^06ATI01WIfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80
LG5a079bLP0h>3P0;2`/03lo?`1dM7@0LW9b03/k>`1?Cdl0:BTY03Ti>@2<S8`0O7al02XZ:P1PH60L
ooooo`0b09ZJVP2=SHd0DE5A05MGE`20P800GemO03Ti>@1NGUh0MgMg04M7A`1:BTX0EUIF071`L01V
IVH0MWIf06EUI@1lO7`0EeMG05IFEP1@D5007QhN04Q8B00j>SX0CDe=04A4A00o?cl0ADE5065QH@1O
Gel0U9BD05IFEP0i>CT0CDe=07]kN`1;Bd/0De=C05]KF`1[Jf/0EeMG02l_;`17AdL0ADE503Ph>01>
CTh0GEeM05EEE@11@D40ADE505YJFP1BDU8205]KF`1d03@d=01=CDd0<S8b05=CD`1JFUX0HF5Q01hN
7P0[:b/0DE5A03<c<`0l?3`0B4Q804M7A`10@400B4Q807EeM@1LG5`0E5AD055AD@1CDe<0BTY:02d]
;@0Z:RX0Cdm?0410@013@d<0C4a<03lo?`1DE5@0<30`03Ti>@0j>SX0Bd];03`l?015ADD0?3`l03dm
?@0G5aL09RHV03De=@0];Bd0:b/[02d];@0n?Sh09bLW02PX:00h>3P05aLG05=CD`0c<c<0A4A402d]
;@0h>3P0:RXZ04E5A@13@d<0DU9B03dm?@13@d<0BDU904I6AP0j>SX0E5AD04I6AP1XJ6P0Ogmo04Y:
BP1EEED0EeMG05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80^[Zj05ADE01YJFT0I6AT07mo
O`2WYjL0<c<c06EUI@1aLG40=CDe04e=C@1BDU809RHV03dm?@1HF5P0OGem07]kN`1FEUH0MgMg0;fm
_@2FUYH0FEUI06e]K@0k>c/0EUIF03Lg=`1ADE40NGUi06EUI@1GEeL0NGUi07alO01dM7@0/K6a06][
J`2ATI40FEUI03lo?`18B4P2061PH00P05MGE`1[Jf/0@T92065QH@1NGUh0IVIV08^;R`1[Jf/0IFEU
030`<01EEED0EUIF06QXJ01;Bd/0Kfm_0451@@2;Rh/0SXj>03dm?@1;Bd/0E5AD09>CT`0k>c/0D51@
05mOG`0d=3@0DU9B03<c<`0_;bl0=3@d04];B`0i>CT205IFEP0P05eMG@1/K6`0B4Q804];B`1WIfL0
MGEe03<c<`0[:b/0CTi>03Hf=P1=CDd0;Rh^04Q8B01>CTh0;Bd]04a<C00c<c<0?clo04E5A@0[:b/0
CTi>02d];@1]KFd0ATI609^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd2038b<P0X04E5A@1<
C4`0BTY:055AD@1PH600F5QH05=CD`12@T80EUIF05aLG01eMGD0;Rh^05MGE`1IFET0@41005ADE00m
?Cd09bLW0492@P1XJ6P0G5aL05ADE00l?3`0ADE504=3@`1;Bd/0CDe=05UIF@1/K6`0Ti>C06][J`14
A4@0T92@04i>CP10@400IFEU02HV9P1KFe/0?3`l05mOG`<0@d=300T0LW9b0:2PX00o?cl0?Shn055A
D@1FEUH0EEEE059BDP1jNWX04Oooool000oooooo00d0I6AT0;Fe]@1^KVh0KVi^05MGE`2OWil0FUYJ
09bLW01GEeL0?3`l05ADE01aLG40>c/k0080?Shn03@0RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=3
09FEU@1_Kfl09BDU04Y:BP1CDe<0M7Ad0<71`@0Z:RX07alO04e=C@1cLg<0GUiN09nOW`0Q8B40:2PX
04M7A`1VIVH0CDe=0861P@1OGel07QhN04i>CP2GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM
04a<C018B4P09RHV059BDP1JFUX0@41005MGE`0i>CT0820P03Xj>P23Ph<0A4A407alO00_;bl0A4A4
0P1VIVH0c@0S8b<0?clo04e=C@1?Cdl0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0
@d=304U9B@1MGEd0Rh^;0:FUY@0^;Rh09RHV05MGE`1hN7P0Rh^;03lo?`0A4A40@T9208V9R@16ATH0
LW9b08b<S00W9bL08B4Q06QXJ00g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0V9RH0
BTY:06IVIP1OGel0>SXj07emO@0S8b<07alO04a<C01ADE40ATI606IVIP0k>c/09BDU04M7A`2EUID0
HF5Q05=CD`2BTY80;2`/055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1MGEd0ATI603Xj>P11@D40
:2PX03<c<`25QHD0CTi>024Q8@15ADD0B4Q804a<C024Q8@07QhN020P801@D500GUiN04a<C02WYjL0
Lg=c02<S8`1;Bd/0Jf][05YJFP2IVIT0@410028R8P0`<300O7al09JFUP1:BTX0IVIV01lO7`0h>3P0
PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0FEUI04m?C`2SXj<0De=C02d];@0g=cL0G5aL06IVIP19BDT0
EEEE02TY:@19BDT0Shn?03/k>`18B4P0BTY:02h^;P10@400O7al079bLP19BDT0=CDe03dm?@1MGEd0
Lg=c03hn?P1?Cdl0?Shn04a<C01gMgL0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0
JVYZ0<30`00i>CT0Cdm?06QXJ01JFUX0I6AT09jNWP1:BTX0;bl_05ADE01FEUH0/K6a04M7A`0i>CT0
E5AD0:2PX01[Jf/0Lg=c08n?S`0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1UIFD0
WinO08^;R`0Q8B40>SXj05UIF@2CTi<0MgMg0:BTY020P800;Bd]07YjNP1lO7`0CDe=04Q8B01>CTh0
>c/k03Lg=`1]KFd0NGUi04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL00P0j>SX03P1`L700
KVi^03<c<`0m?Cd0@d=303Ph>01eMGD0Shn?0410@00Y:BT0HV9R05ADE01WIfL0_[jn7?ooool0CP25
QHD0JFUY04I6AP1<C4`0IVIV061PH01=CDd0KFe]061PH013@d<0EEEE079bLP2ATI40Rh^;09JFUP2D
U9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1BDU80@41003Lg=`1LG5`0CTi>04e=C@1<
C4`0=cLg04=3@`1UIFD0DE5A05MGE`1[Jf/0DU9B05]KF`0T92@0>SXj04Q8B00h>3P0AdM704A4A01J
FUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn0492@P0i>CT0Bd];05aLG01IFET07alO04=3@`1G
EeL0?3`l051@D01HF5P0E5AD05=CD`1UIFD0WYjN06][J`0a<C40>CTi04U9B@1RHV80<c<c03`l?017
AdL07QhN028R8P80C4a<0=80J6QX03dm?@16ATH0Bd];03Ti>@10@400C4a<03@d=00i>CT071`L059B
DP0j>SX0<30`04I6AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@d=304I6AP0f=SH0ADE502<S
8`18B4P0>c/k06a/K00n?Sh0CDe=04i>CP1?Cdl0DE5A05]KF`13@d<0@41006QXJ00];Bd0KVi^04E5
A@17AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`0e=CD0CTi>03Lg=`0_;bl0DU9B02@T
902=SHd0KFe]02DU9@1JFUX0?Cdm02TY:@1OGel0De=C06QXJ01<C4`0QHF505UIF@1LG5`0KVi^03lo
?`1ADE40@D51051@D00X:2P0>3Ph05ADE01ADE40:2PX08b<S00l?3`0Fe]K07QhN01XJ6P0P82007Ad
M01IFET0ADE506ATI01OGel0FEUI05ADE00/;2`0HV9R02h^;P2FUYH0Y:BT0451@@1SHf<0DE5A065Q
H@1:BTX0B4Q8055AD@25QHD0Cdm?06MWI`2;Rh/0B4Q804];B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj
>P1;Bd/0A4A40492@P0f=SH0F5QH04I6AP1IFET0C4a<051@D01CDe<0F5QH05aLG02<S8`0ZJVY03hn
?P17AdL0IFEU03<c<`0n?Sh0;bl_03dm?@1YJFT0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IF
EP1aLG40FUYJ07alO01JFUX0Hf=S05IFEP1?Cdl0GUiN034a<@1WIfL0D51@05iNGP1=CDd0CTi>05QH
F01:BTX0F5QH03Hf=P1TI6@0;2`/06=SH`13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^
;P1>CTh0MgMg03Xj>P1LG5`0AdM707YjNP1=CDd0Cdm?05eMG@1[Jf/0IVIV06i^KP1_Kfl0>3Ph0492
@P0k>c/0BTY:06MWI`0k>c/0C4a<01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL05]K
F`1`L700EUIF06IVIP2SXj<Aooooo`003oooool09P1NGUh0Ogmo09^KV`29RHT0A4A406YZJP1`L700
f][J08:2PP0b<S80>CTi075aL@1[Jf/0Xj>S05=CD`0d=3@0HF5Q07MgM`1GEeL0Ph>304i>CP0S8b<0
=SHf04e=C@0k>c/0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00h>3P0[Jf]07YjNP0`<300
=3@d0P0/;2`0A`0g=cL0N7Qh03Ph>00g=cL0=3@d04a<C01NGUh0QHF504a<C00k>c/0B4Q803@d=026
QXH0JVYZ01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I6AT0@D5105EEE@39bLT0Hf=S028R8P1:
BTX0Fe]K04=3@`2FUYH0b/[:03<c<`1dM7@0NGUi05EEE@2e]KD0C4a<01PH6018B4P0OGem04=3@`21
PH40BTY:02d];@1[Jf/0TI6A0451@@1>CTh0I6AT02LW9`1KFe/0QHF503Xj>P1ADE40=SHf02l_;`12
@T80GEeM04=3@`0i>CT0A4A403Lg=`1HF5P0Ng]k02/[:`0];Bd0=CDe03dm?@1GEeL0U9BD0080=CDe
01l0@D5105ADE01LG5`0WIfM03Lg=`0K6a/0A4A404=3@`1aLG40S8b<02l_;`0U9BD0=CDe04=3@`1R
HV80GEeM0=oOg`0m?Cd0OGem07inOP13@d<0PX:209NGU`0M7Ad0<C4a07=cL`1JFUX0Kfm_04Q8B00E
5AD0A4A40080EeMG02/0?Shn0:b/[015ADD0?Shn07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj05MGE`0g=cL0<c<c06IVIP2EUID0D51@030`<01KFe/092@T0451@@1UIFD0;Rh^03@d=014
A4@0?3`l05QHF01NGUh0:b/[03<c<`0b<S80=CDe08Z:RP2EUID0>SXj03dm?@1NGUh0B4Q807emO@2F
UYH0<30`0080AdM701d0?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM09FEU@0/;2`0=SHf06IVIP1k
Ng/0Fe]K09JFUP16ATH0:b/[07emO@1WIfL0Lg=c03Hf=P0U9BD0KVi^0;Fe]@1_Kfl0JVYZ06QXJ00j
>SX0MWIf05mOG`0206a/K00S02HV9P0n?Sh0D51@06QXJ01<C4`0D51@034a<@2IVIT0QHF5034a<@1@
D500JVYZ03/k>`12@T80Y:BT0492@P0o?cl0IfMW03Ph>01ADE40_Kfm07inOP0e=CD0C4a<04A4A01^
KVh0`/;2065QH@0o?cl0B4Q803dm?@0e=CD0MgMg0<[:bP0o?cl00P1?Cdl07`1^KVh0Zj^[05IFEP0K
6a/0>3Ph051@D01RHV80IFEU09fMW@0U9BD0<C4a07AdM01YJFT0BDU906IVIP1:BTX09BDU05]KF`22
PX80FEUI07]kN`1gMgL07alO02LW9`1WIfL0YZJV061PH02GUiL0?clo02LW9`1IFET07?ooool0G@27
QhL0Ogmo03De=@1?Cdl0HF5Q06IVIP1CDe<0P82007AdM00a<C40I6AT05aLG01YJFT0SHf=06ATI01C
De<0HV9R055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1>CTh0EEEE06MWI`22PX80M7Ad05]KF`1H
F5P0?clo04Q8B01[Jf/0C4a<061PH01dM7@0HF5Q059BDP10@400D51@05=CD`1;Bd/0B4Q804i>CP1Y
JFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf0492@P0Y:BT0C4a<05UIF@1XJ6P07QhN024Q8@0o
?cl0CDe=051@D015ADD0CDe=04E5A@1;Bd/0CTi>055AD@19BDT0A4A404Y:BP1DE5@0Cdm?051@D01Q
HF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0Bd];04A4A00j>SX0Bd];04Y:BP0j>SX0>3Ph02`/;00W
9bL0>SXj04A4A00203Ph>00D03/k>`17AdL0>3Ph04I6AP0Q8B40Fe]K0451@@14A4@0=CDe055AD@0M
7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1<C4`0G5aL03<c<`1=CDd204Y:BP1X08f=S@0_;bl0?Shn04e=
C@1NGUh0CTi>05QHF017AdL0Bd];06UYJ@1eMGD0@41007=cL`1FEUH0K6a/06UYJ@1PH600LW9b04A4
A01CDe<0D51@02h^;P1ZJVX0@D5101DE5@1mOGd0?Cdm07AdM018B4P0=3@d04=3@`2GUiL0JVYZ0492
@P1]KFd0=cLg05IFEP0L71`0DE5A08:2PP1FEUH0820P0451@@0V9RH0EUIF06a/K00j>SX0TI6A04=3
@`0i>CT0<c<c05eMG@18B4P0D51@05ADE014A4@0T92@0410@01RHV80H61P03Xj>P1QHF40?Shn06IV
IP0c<c<0>3Ph03`l?021PH40=SHf06m_K`1/K6`0Bd];07AdM01>CTh0FEUI03/k>`1BDU80H61P0410
@01@D500<c<c04];B`0Y:BT0GUiN02l_;`1UIFD0G5aL05MGE`1;Bd/0Fe]K05YJFP1GEeL0KFe]05aL
G010@400IVIV05=CD`1ADE40GUiN05QHF01ZJVX0EeMG06e]K@1<C4`204m?C`0702d];@1TI6@0>3Ph
0861P@1]KFd0U9BD079bLP0207QhN00R05]KF`1eMGD0C4a<06UYJ@1RHV80GUiN04Q8B00l?3`0IFEU
04e=C@1?Cdl0Fe]K08B4Q012@T80Cdm?06a/K01ZJVX0@410075aL@1HF5P0@D510:b/[01aLG40?3`l
05IFEP1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o?cl0Bd];071`L080JVYZ01H0Fe]K04i>CP2TY:@0
HV9R03hn?P1:BTX0@T9207=cL`1>CTh0E5AD0410@01;Bd/0IFEU08:2PP2>SXh0Bd];04M7A`1JFUX0
EUIF07UiN@1lO7`0JFUY4Oooool000oooooo0:@0YjNW04M7A`1VIVH0R8R806=SH`1KFe/0=cLg06YZ
JP2UYJD0@410055AD@0h>3P0A4A404U9B@1/K6`0BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492
@P0j>SX0@d=30:ZZZP1;Bd/06QXJ04i>CP1JFUX0JVYZ08n?S`1HF5P071`L05]KF`2=SHd0IVIV08b<
S00^;Rh08R8R02d];@1XJ6P0F5QH092@T00[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^
KP1WIfL0BDU904a<C00K6a/0<c<c05eMG@1aLG40<C4a069RHP0m?Cd0>SXj075aL@2<S8`0?Cdm06][
J`1;Bd/0:RXZ05mOG`2GUiL0Jf][065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1DE5@08R8R08N7
Q`1>CTh05ADE03Ti>@1XJ6P0;Bd]05IFEP29RHT05aLG02`/;01JFUX0BTY:0:VYZ@1dM7@05ADE03Lg
=`1UIFD0Cdm?06ATI026QXH05QHF03hn?P1aLG40E5AD07IfMP1_Kfl08b<S02l_;`1NGUh0KVi^08n?
S`2=SHd0:RXZ03dm?@1MGEd0Ph>303`l?01/K6`0>c/k06=SH`1nOWh0Ogmo02DU9@0b<S80DU9B02DU
9@0d=3@0BDU905EEE@1<C4`0ADE503`l?01EEED0Kfm_05=CD`0`<300K6a/030`<01^KVh0Q8B403Lg
=`10@400Hf=S03Hf=P0`<300Zj^[0;6a/@0g=cL0GEeM05EEE@1@D500`<3007inOP0T92@0ATI604a<
C018B4P0MgMg034a<@0h>3P0FEUI05]KF`80MWIf00D0];Bd02l_;`0o?cl0GemO06][J`0207IfMP0E
02PX:00o?cl0EEEE04];B`1RHV80H61P02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg
05YJFP29RHT0G5aL0410@014A4@0LW9b0080A4A405h0H61P020P801CDe<0CDe=02`/;01IFET0?3`l
04=3@`1LG5`0MWIf02/[:`1>CTh0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0Bd];
05=CD`13@d<0JFUY08Z:RP0/;2`0>CTi05MGE`1RHV80Kfm_07UiN@0X:2P0J6QX07IfMP1XJ6P0RXZ:
09jNWP0f=SH0C4a<071`L024Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ09:BTP1;Bd/0CTi>
06ATI02DU9@0PX:20:NWY`0j>SX0=SHf0410@01XJ6P0Kfm_06YZJP0j>SX0:b/[04];B`26QXH0Cdm?
05UIF@1jNWX0@T9205MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm030`<01UIFD0MgMg03De=@1:BTX0=3@d
038b<P15ADD0N7Qh02/[:`0V9RH0=cLg02XZ:P0o?cl0Y:BT03De=@0/;2`0?clo7?ooool04@2EUID0
PX:20492@P1FEUH0DE5A05ADE01;Bd/0Fe]K07AdM00`<300BTY:05mOG`2=SHd0/K6a08>3P`1gMgL0
Ti>C0080EUIF01D0EEEE02HV9P13@d<0<c<c0492@P15ADD0?Shn0410@01UIFD0Fe]K06UYJ@1LG5`0
HV9R05UIF@1XJ6P0G5aL07moO`1HF5P0EUIF05=CD`0f=SH00P12@T80600a<C40?Shn04=3@`1FEUH0
<c<c04E5A@1CDe<0CDe=04];B`1:BTX0;2`/04m?C`0Y:BT0BTY:04U9B@1LG5`0=3@d02PX:017AdL0
E5AD05aLG01OGel0IfMW04e=C@80KFe]00l0L71`03/k>`11@D40Bd];04m?C`0b<S80>c/k05EEE@0V
9RH0:RXZ04];B`0h>3P0HV9R04Y:BP14A4@00P15ADD0?`16ATH0C4a<04Q8B011@D40:2PX03Lg=`17
AdL0?Cdm03/k>`10@400ADE503@d=00f=SH0@41003Ti>@1KFe/0CTi>051@D00e=CD0A4A402LW9`1=
CDd0?clo06UYJ@1@D500ATI604U9B@1IFET0=SHf05YJFP1YJFT0:2PX07IfMP1ADE40Ogmo05ADE01O
Gel0<C4a04A4A01JFUX0?Cdm05=CD`1<C4`09bLW09fMW@1=CDd0EUIF05MGE`1[Jf/0X:2P03`l?01Q
HF40ATI602<S8`1dM7@0Bd];03De=@1GEeL0;2`/04i>CP0/;2`0Bd];03Hf=P020861P@0]03Ph>014
A4@0@d=30820P00W9bL0Bd];06=SH`1GEeL05aLG06MWI`0M7Ad0J6QX092@T018B4P0>3Ph038b<P1<
C4`0ATI604A4A00d=3@0DE5A04a<C00N7Qh0B4Q801hN7P29RHT0OGem05MGE`1[Jf/0@T9206e]K@1>
CTh0BTY:06a/K02FUYH0Fe]K09jNWP26QXH0@D5105]KF`1WIfL0RHV906a/K024Q8@0Ph>30080GUiN
02/0EUIF03Ti>@0b<S80N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l04M7A`2TY:@0d=3@05QHF01@
D500MgMg04];B`1RHV80=cLg04M7A`1JFUX0=cLg04Q8B012@T80EeMG04E5A@0W9bL0Hf=S038b<P1L
G5`0CDe=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0@d=303Lg=`1@D500>3Ph0080ATI6
00P0Fe]K04Q8B014A4@0Cdm?07=cL`1@D500A4A403hn?P80AdM702H0<c<c07QhN018B4P0=CDe0451
@@23Ph<0@D5104Q8B00m?Cd0?3`l04=3@`0o?cl0DE5A04Y:BP1RHV80O7al04Y:BP0a<C40C4a<05IF
EP1IFET0Hf=S03Ph>014A4@0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0[Jf]05MGE`1OGel0J6QX05QH
F01TI6@0DU9B07UiNA7ooooo000?ooooo`0M09bLW02QXJ40K6a/07YjNP1[Jf/0QhN703dm?@1ZJVX0
KVi^05EEE@27QhL0GEeM04=3@`1=CDd0BTY:07MgM`1oOgl0B4Q8030`<01LG5`0IFEU02d];@26QXH0
AdM702l_;`1dM7@0I6AT05IFEP1jNWX00P0R8R808P0o?cl0KFe]05MGE`1JFUX09BDU02TY:@19BDT0
HV9R04A4A01MGEd0@d=302PX:01=CDd0Hf=S04Q8B023Ph<0=cLg03hn?P1CDe<0FEUI02h^;P1XJ6P0
C4a<05=CD`1`L700=SHf028R8P1[Jf/0De=C02l_;`1XJ6P0Bd];02`/;01QHF4204Q8B00:08V9R@1L
G5`0:b/[0410@01OGel0Fe]K08J6QP0a<C40;2`/05ADE080@d=30=<0IVIV079bLP0];Bd0?Cdm06YZ
JP1HF5P0PH6106i^KP0U9BD0<c<c05iNGP1FEUH0L71`03Lg=`0P8200ADE508J6QP11@D40F5QH071`
L00S8b<09BDU07QhN00h>3P0IFEU065QH@0R8R80=SHf05=CD`1:BTX0Bd];06MWI`0S8b<0>CTi05QH
F01@D500EUIF079bLP0];Bd0>SXj05MGE`16ATH0@41006e]K@1=CDd0>3Ph07AdM01oOgl0<C4a04M7
A`1HF5P0A4A408f=S@1_Kfl0:BTY0492@P1=CDd0?Cdm051@D02;Rh/0BTY:03/k>`0o?cl0=3@d06=S
H`2BTY80AdM703Xj>P1FEUH0IFEU059BDP1]KFd0;Rh^03hn?P1mOGd0Q8B404a<C025QHD0M7Ad02d]
;@1CDe<0Hf=S0492@P27QhL0EEEE02PX:01EEED0LW9b05ADE01=CDd0IfMW03De=@1=CDd0MgMg055A
D@1?Cdl0IVIV030`<014A4@0K6a/055AD@1eMGD0AdM703@d=01EEED0OWin05mOG`1@D500KFe]03Hf
=P1dM7@0J6QX03Ph>01/K6`0IFEU03hn?P1[Jf/0YZJV04Q8B01dM7@0CTi>04m?C`1dM7@0Kfm_0410
@01eMGD0NGUi03lo?`27QhL0B4Q805MGE`1=CDd0>c/k0820P01TI6@0>3Ph05eMG@1^KVh0IFEU08f=
S@17AdL0Bd];05]KF`1@D500J6QX096AT@0n?Sh0@T9205aLG01<C4`0VIVI05aLG00b<S80HV9R08f=
S@1LG5`0LG5a07IfMP1:BTX0KVi^08f=S@1VIVH0GUiN08>3P`0o?cl0FUYJ07MgM`1WIfL0Ng]k03lo
?`0h>3P0G5aL09>CT`2LW9`0Cdm?065QH@1RHV80?Shn07UiN@1]KFd0?3`l061PH013@d<0>c/k04i>
CP1_Kfl0EEEE06MWI`1DE5@0ADE506IVIP1eMGD0BTY:03Xj>P18B4P0GUiN05MGE`20P800FEUI030`
<01=CDd0EeMG03dm?@1<C4`0NWYj03hn?P0c<c<0IfMW069RHP1EEED0MWIf01cooooo00@0Lg=c07mo
O`1=CDd0EUIF0P1UIFD0=P19BDT0F5QH06i^KP13@d<0EEEE061PH01^KVh0I6AT06][J`1iNGT0J6QX
04];B`19BDT0CDe=038b<P13@d<0@D51055AD@1>CTh0DE5A05eMG@1]KFd0FUYJ07QhN01JFUX0C4a<
04I6AP1EEED0F5QH06QXJ01EEED0FUYJ04Y:BP0k>c/0ADE504I6AP14A4@0AdM704A4A01HF5P0>c/k
04I6AP1@D500@d=303Xj>P17AdL0<30`03dm?@0a<C40@d=305YJFP1WIfL0:BTY03@d=080ATI601h0
EUIF055AD@1BDU80EUIF05YJFP1^KVh0I6AT03/k>`11@D40D51@05]KF`1:BTX0DU9B06UYJ@0a<C40
=CDe05IFEP12@T80D51@04e=C@18B4P0De=C03Ti>@1:BTX0CTi>0492@P0o?cl09RHV03hn?P11@D43
0492@P0?04U9B@18B4P0>SXj04I6AP0e=CD0G5aL051@D014A4@0>CTi05ADE00h>3P0@T9204I6AP1Z
JVX0DE5A0080DU9B00`0H61P04E5A@1IFET0L71`03Ph>01]KFd0FEUI04i>CP1FEUH0IFEU04M7A`1J
FUX204Q8B01J07QhN01lO7`0>SXj09^KV`1KFe/0R8R808J6QP1ZJVX0MGEe03dm?@2FUYH0O7al03De
=@1kNg/0De=C030`<01/K6`0EeMG05ADE012@T80Fe]K05YJFP2>SXh0QHF505iNGP1/K6`0>SXj05mO
G`0G5aL0FUYJ08B4Q01VIVH0820P075aL@0/;2`0Fe]K08F5Q@17AdL0MGEe03lo?`19BDT0@T9206EU
I@1CDe<0G5aL04M7A`0P8200LW9b02XZ:P1dM7@0N7Qh034a<@1;Bd/0>SXj06YZJP15ADD0@41006AT
I01lO7`0AdM706IVIP1]KFd0?Cdm04e=C@13@d<0FEUI05ADE02OWil0TI6A05ADE01JFUX0<30`03Xj
>P0U9BD0HF5Q034a<@1IFET0ADE504Y:BP1DE5@0ATI6069RHP1QHF40I6AT02<S8`0_;bl0FEUI02l_
;`1<C4`0@4100P1ADE403@12@T80F5QH04A4A017AdL0D51@02l_;`1MGEd0?Shn07moO`1NGUh0RXZ:
04M7A`1YJFT00P19BDT0>@1HF5P08R8R069RHP0i>CT0@41004e=C@0i>CT0E5AD04e=C@1_Kfl0D51@
05EEE@0h>3P0Hf=S04A4A01=CDd0>CTi05iNGP1IFET0Bd];0861P@16ATH0=3@d04i>CP1;Bd/0D51@
05eMG@1?Cdl0LG5a03hn?P1<C4`0EUIF05EEE@0o?cl0NGUi02d];@0o?cl0NGUi04Y:BP0n?Sh0EUIF
03`l?01:BTX09RHV05iNGP0U9BD0AdM704];B`1^KVh0NWYj0451@@15ADD0Cdm?05ADE01MGEd0EEEE
071`L00Aooooo`003oooool0[`1`L700O7al08N7Q`29RHT0ATI605iNGP1]KFd0Z:RX04m?C`0g=cL0
Fe]K07]kN`1ZJVX0QHF505EEE@0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@1ZJVX0
UYJF02h^;P11@D40Kfm_06YZJP1WIfL0RHV9024Q8@0j>SX0][Jf06][J`1eMGD0Kfm_01XJ6P0g=cL0
@T9206a/K00n?Sh0DE5A028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S06YZJP0h>3P0
D51@03<c<`11@D40PX:208V9R@0X:2P0ADE504];B`1@D500WIfM05eMG@0X:2P0DU9B04I6AP1=CDd0
/[:b09RHV00^;Rh0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80S8b<028R8P1;Bd/0
Cdm?09VIV@15ADD0QhN707inOP0N7Qh0E5AD079bLP10@400M7Ad06ATI00M7Ad0>CTi09:BTP1^KVh0
@d=305mOG`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0AdM707QhN01?Cdl0?Cdm04m?C`0K6a/0
EeMG08N7Q`1DE5@0:BTY0492@P0l?3`0De=C0:JVYP17AdL09BDU03hn?P1YJFT0ADE506YZJP2][Jd0
;Rh^04a<C01fMWH0EEEE06m_K`1>CTh0;Bd]03Ph>01XJ6P0FUYJ07moO`1;Bd/08B4Q04Q8B01PH600
KVi^05UIF@2h^;P0E5AD04I6AP20P800QhN7075aL@2e]KD0?Shn03Lg=`1<C4`0Ng]k08^;R`1LG5`0
?3`l04M7A`1MGEd0M7Ad04A4A01jNWX0Jf][02LW9`0o?cl0FEUI04I6AP2<S8`0?clo02TY:@1>CTh0
0P1BDU80L@0n?Sh0ADE503<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/04e=C@1ZJVX0
FUYJ030`<01VIVH0/;2`05EEE@0h>3P0Cdm?04i>CP2:RXX0F5QH03De=@11@D40>SXj04U9B@2j^[X0
P82002PX:01EEED0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0>CTi07AdM01aLG40
ZZZZ09BDU00[:b/0?3`l07inOP1]KFd0F5QH059BDP1@D500L71`0:n_[`1/K6`0LW9b075aL@11@D40
Hf=S07moO`10@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00k>c/0OGem08n?S`1PH600
IfMW08J6QP0f=SH0C4a<05eMG@2GUiL0Bd];06e]K@1?Cdl0E5AD07MgM`2EUID0?Cdm03De=@1>CTh0
BDU908>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1iNGT0QhN702`/;01=CDd0MGEe05ADE02KVi/0
PX:201/K6`0/;2`0Fe]K09>CT`1^KVh0OGem01dM7@16ATH0G5aL01cooooo0580J6QX07EeM@1;Bd/0
@D5104I6AP0n?Sh0;2`/05iNGP1gMgL0>3Ph04Y:BP1JFUX0NWYj09BDU01^KVh0FUYJ06IVIP26QXH0
LG5a04e=C@0Q8B40@T9202d];@0a<C40@D5103Xj>P11@D40J6QX071`L02KVi/0M7Ad04U9B@1HF5P0
M7Ad05IFEP1eMGD0I6AT09:BTP1dM7@0;bl_02d];@15ADD0=SHf04Y:BP17AdL0Jf][03Ti>@0h>3P0
?Shn03`l?00Z:RX0<c<c02LW9`1<C4`0=SHf03lo?`0e=CD0BDU903Hf=P0`<300=SHf03Ph>01;Bd/0
D51@04a<C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0EUIF03`l?018B4P0E5AD02/[:`0U9BD0
BTY:075aL@1VIVH0@T920P0j>SX01`15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P00P0e=CD04@0]
;Bd0:b/[04I6AP0f=SH092@T02l_;`0g=cL0E5AD04M7A`14A4@0:RXZ04E5A@0/;2`0@T9203Hf=P1b
LW80?Cdm0080Bd];05`0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<C01EEED0D51@03Xj>P1J
FUX0DE5A059BDP1LG5`0Hf=S05=CD`2c/k<0GemO06][J`1`L700GemO07]kN`16ATH0^[Zj0820P00/
;2`0FEUI055AD@0U9BD0Lg=c04M7A`2:RXX0<S8b051@D019BDT0[Zj^08J6QP1=CDd0Bd];05YJFP1W
IfL07AdM061PH01KFe/0BTY:02LW9`1SHf<03`l?07emO@2EUID0=CDe06][J`11@D40ATI6034a<@1B
DU80>SXj075aL@1BDU8061PH06e]K@0c<c<0DE5A071`L00Y:BT0Bd];02XZ:P1MGEd0GUiN03<c<`1Y
JFT0U9BD0451@@32`/80YjNW04A4A018B4P0D51@07=cL`0j>SX0_;bl0:FUY@0f=SH0CTi>02HV9P0X
:2P061PH051@D011@D40DE5A0451@@80DU9B05@0>SXj06MWI`29RHT0UiNG061PH01JFUX0R8R803`l
?01RHV80>CTi05QHF01NGUh0>3Ph04Q8B01DE5@0BDU903/k>`0b<S80Hf=S0451@@1?Cdl0Fe]K09^K
V`1;Bd/0BTY:03dm?@0a<C40Bd];01`L701OGel0?3`l04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ03<c
<`16ATH0;2`/05QHF00_;bl0?Cdm02LW9`1<C4`0@D5102<S8`1^KVh0>SXj04e=C@1LG5`0KFe]05eM
G@1;Bd/0C4a<07moO`1:BTX0DE5A06a/K01`L700AdM70:VYZ@1DE5@0@T9205EEE@0o?cl0CDe=065Q
H@1<C4`0GUiN03hn?P2:RXX0<30`04m?C`14A4@0OGem09:BTP1>CTh0@d=30451@@17AdL0IfMW04Q8
B01OGelAooooo`003oooool08P31`L40Bd];06e]K@24Q8@0TI6A06MWI`0k>c/0ZZZZ0;Ng]`18B4P0
TY:B04U9B@13@d<0FUYJ0:ZZZP1>CTh0Lg=c02d];@0g=cL0CTi>08j>SP0i>CT0De=C03/k>`0_;bl0
QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@D00e=CD203hn?P0A05ADE02UYJD0@D5102DU9@15
ADD0DU9B05aLG028R8P0;Bd]03/k>`1mOGd0TY:B07EeM@2=SHd0?clo02<S8`0j>SX00P1PH600902F
UYH09bLW02/[:`16ATH0P8200451@@2DU9@0@T9203<c<`1bLW80RXZ:05iNGP2@T900C4a<01lO7`1@
D500/K6a06YZJP1kNg/08b<S03dm?@1SHf<0Jf][04A4A01IFET0BDU902l_;`1MGEd0D51@034a<@1b
LW80ADE50451@@1IFET0U9BD02l_;`80ADE50;`0>CTi079bLP2[Zj/0AdM701dM7@1=CDd0A4A402d]
;@25QHD09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0KVi^07alO01ZJVX09bLW02PX
:01SHf<0NGUi04e=C@1mOGd0@d=303dm?@1SHf<0NWYj051@D01dM7@0EEEE01XJ6P0_;bl0BTY:05MG
E`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`17AdL0CDe=038b<P1bLW80KFe]01hN
7P13@d<0FUYJ07AdM00l?3`0<S8b02HV9P1EEED0LW9b07emO@0Y:BT0M7Ad0410@00[:b/0SXj>034a
<@0`<300CDe=0451@@0^;Rh0L71`0;Zj^P1HF5P0<S8b04Y:BP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069R
HP1OGel0EeMG08:2PP0Y:BT0B4Q806EUI@20P800WYjN0;2`/00f=SH0<S8b05QHF01ZJVX0XJ6Q04a<
C00Y:BT0CDe=08n?S`1^KVh0IfMW04a<C00V9RH0HV9R0:FUY@27QhL0OGem0410@00P8200Fe]K08:2
PP1VIVH0IfMW03Hf=P24Q8@0OWin04=3@`1aLG40@41003Hf=P1SHf<0b/[:06MWI`1_Kfl0BDU908>3
P`1lO7`0C4a<03Xj>P1VIVH0D51@05EEE@1[Jf/0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l
?01ZJVX0De=C09nOW`28R8P0<C4a0492@P1aLG40LW9b06IVIP2VYZH0>CTi0410@01ADE40Fe]K07]k
N`2b/[80>CTi03<c<`0g=cL0JFUY06YZJP2HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin03Xj
>P1ADE40PH6107=cL`1[Jf/0IVIV01/K6`0l?3`0DE5A05IFEP1TI6@0QhN702h^;P0Z:RX0EUIF09>C
T`80E5AD00L0HV9R034a<@19BDT0J6QX0410@00l?3`0JFUY01cooooo03<0HF5Q04a<C00U9BD0E5AD
07QhN01CDe<0=3@d04E5A@1CDe<0;Rh^03Hf=P18B4P0Fe]K05mOG`1SHf<0A4A407EeM@1;Bd/0DU9B
0451@@0M7Ad0ATI602/[:`0b<S80EeMG03Lg=`15ADD0FUYJ04U9B@1;Bd/0CTi>03lo?`10@400DU9B
04Y:BP1FEUH0L71`08J6QP1CDe<0:b/[04e=C@0n?Sh0?3`l059BDP1VIVH0H61P03Xj>P1=CDd0GUiN
03lo?`0c<c<00P1>CTh0B@0m?Cd09BDU03Lg=`14A4@0CTi>02@T900b<S80?Cdm03Ti>@18B4P0=SHf
04E5A@1TI6@0EeMG079bLP1LG5`0ADE504];B`1EEED0Bd];079bLP1oOgl0Fe]K02PX:00Y:BT0D51@
03Ti>@0k>c/0A4A404Q8B01?Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03De=@0j>SX0=CDe
03hn?P0d=3@0?clo02<S8`0_;bl0=cLg0451@@14A4@0B4Q804=3@`0k>c/0ATI604U9B@0f=SH0Hf=S
055AD@18B4P0De=C059BDP0/;2`0FUYJ05MGE`0R8R80FEUI03Ti>@1<C4`0ADE504=3@`0e=CD0=cLg
03dm?@0f=SH00P1eMGD0K@0i>CT0QhN704e=C@20P800LW9b051@D01BDU80?Cdm06EUI@1QHF408b<S
069RHP0m?Cd0>c/k0492@P0i>CT0FEUI03lo?`0i>CT0CTi>0;:b/P2@T900LW9b06m_K`1FEUH0NWYj
02HV9P1XJ6P0Kfm_06e]K@0l?3`0EEEE02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MGE`0d=3@0@d=3
03Hf=P10@400?Shn01/K6`24Q8@09BDU079bLP1ZJVX0>CTi04e=C@0_;bl0I6AT0451@@0`<300@T92
06i^KP0i>CT0IfMW075aL@0];Bd0>3Ph038b<P1NGUh0@D51075aL@1[Jf/0>CTi04m?C`0/;2`0>SXj
018B4P1HF5P0<30`06a/K00f=SH0?Shn05MGE`0H61P0K6a/0820P02QXJ40@41003Lg=`1NGUh0?Cdm
059BDP1=CDd0Cdm?05]KF`1EEED0F5QH05YJFP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1CDe<0LW9b
04=3@`2@T900EUIF04e=C@1HF5P0CTi>09jNWP1GEeL00P1;Bd/0<`0b<S80ATI603<c<`1BDU80?Cdm
04I6AP0W9bL0B4Q802/[:`0i>CT0BDU908^;R`1SHf<0AdM709jNWP0h>3P0;Rh^04i>CP1WIfL0J6QX
04a<C01VIVH0MgMg04=3@`15ADD0GUiN07MgM`1HF5P0I6AT05iNGP12@T80HF5Q03Xj>P1MGEd0MGEe
034a<@0h>3P0;Bd]05ADE01:BTX0A4A404M7A`1WIfL0N7Qh05EEE@1KFe/0IfMW065QH@1IFET0Cdm?
05iNGP0Aooooo`003oooool0``29RHT0MWIf04];B`1]KFd0JVYZ08N7Q`0j>SX0D51@05QHF01`L700
Ogmo061PH00e=CD0@T9205YJFP2?Shl0Lg=c02d];@0d=3@0?Cdm06EUI@1GEeL0QXJ60410@00b<S80
EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM01`L700?Shn03<c<`12@T80B4Q807MgM`0e=CD0
HV9R03Lg=`0K6a/0Bd];0451@@13@d<0KVi^01HF5P0Z:RX0JVYZ08^;R`0c<c<0CTi>038b<P19BDT0
DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<04m?C`0];Bd0=SHf03De=@1=CDd0R8R805EEE@0E5AD0
<30`03dm?@1WIfL0XJ6Q03Xj>P0i>CT0EUIF04i>CP1EEED0SHf=07moO`0N7Qh0De=C06e]K@1ADE40
];Bd05]KF`0O7al0=SHf06a/K01UIFD0WinO03Ti>@0];Bd0D51@08b<S02JVYX0HF5Q0;Rh^00n?Sh0
@T9205mOG`1?Cdl0EEEE05QHF00Y:BT0>SXj06YZJP1RHV80>SXj051@D00^;Rh0Jf][0820P00o?cl0
=cLg05=CD`0c<c<0<C4a08N7Q`1TI6@0>SXj06IVIP0i>CT0=CDe09JFUP2h^;P0>SXj03Lg=`1BDU80
>3Ph0:NWY`2LW9`08b<S03dm?@1EEED0;Bd]065QH@2k^k/0EUIF0451@@1^KVh0?Shn09BDU02FUYH0
:BTY02XZ:P1dM7@0YJFU06YZJP10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P1HF5P0
H61P05eMG@1_Kfl0;bl_02PX:01LG5`0UYJF05mOG`1GEeL0@41002TY:@1VIVH0YZJV07inOP1>CTh0
H61P02l_;`13@d<0I6AT065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q030`<01]KFd0
PX:203lo?`1YJFT0=3@d04M7A`0207]kN`1M03Xj>P16ATH0?Cdm05UIF@2RXZ80HV9R01/K6`0k>c/0
=cLg05UIF@2WYjL0>CTi055AD@1NGUh0GemO0<[:bP1TI6@09bLW03lo?`1XJ6P0WIfM08f=S@0d=3@0
FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5106m_K`1RHV80Z:RX04m?C`13@d<0H61P0861P@1lO7`0
QHF506][J`1LG5`0NGUi08R8R01RHV80RXZ:061PH00h>3P0BTY:08F5Q@1LG5`0PH6105UIF@0i>CT0
?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0<C4a06UYJ@1fMWH0?3`l04i>CP1MGEd0=CDe05MGE`2GUiL0
CTi>055AD@0[:b/0BTY:09FEU@22PX80BTY:02XZ:P1;Bd/0BDU903De=@2a/K40Kfm_020P800n?Sh0
CTi>03@d=01[Jf/0X:2P030`<00e=CD0OWin06i^KP1SHf<0X:2P01cooooo00d0KVi^061PH00_;bl0
>3Ph051@D01/K6`0FEUI06YZJP1]KFd0FEUI0820P021PH40T92@0080O7al04<0JFUY06a/K01TI6@0
MGEe06IVIP12@T80@410034a<@0c<c<0D51@04Y:BP11@D40SHf=0861P@1jNWX0Hf=S03hn?P1QHF40
Lg=c05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04=3@`0k>c/0D51@034a<@0i>CT0
@d=303dm?@0];Bd0@d=3030`<00e=CD06a/K04E5A@1lO7`0OWin02/[:`0/;2`0>SXj03Hf=P17AdL0
<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0C4a<02TY:@0c<c<0N7Qh02HV9P0Y:BT0
GEeM04i>CP1HF5P0DU9B00<0?clo09/0BTY:06e]K@16ATH0@T9202@T901@D500<C4a03Hf=P1;Bd/0
<c<c04Q8B00b<S80@41004];B`0l?3`0D51@04Q8B00a<C40?Shn05MGE`0U9BD0=SHf02HV9P1QHF40
@D5103`l?012@T80>CTi04Q8B015ADD0B4Q8051@D02ATI40ADE503dm?@16ATH0EEEE03dm?@14A4@0
AdM703hn?P1bLW80MGEe03`l?026QXH0EeMG08j>SP1kNg/0GUiN06=SH`1DE5@0UIFE071`L00d=3@0
Q8B403Xj>P0T92@0Lg=c055AD@2BTY80>3Ph038b<P0h>3P0U9BD0861P@1JFUX0MGEe05IFEP1MGEd0
;bl_0820P01oOgl0EEEE02/[:`1HF5P071`L06a/K01nOWh0C4a<05UIF@0Y:BT0A4A403De=@16ATH0
?clo05MGE`1=CDd0<S8b09jNWP0m?Cd0NGUi07MgM`0d=3@0De=C04a<C01LG5`0ATI604A4A01^KVh0
TY:B03lo?`1dM7@0Lg=c04a<C01EEED0AdM705mOG`1<C4`0R8R809VIV@1EEED0DU9B03Ti>@0U9BD0
5ADE05iNGP0`<300JFUY04Y:BP0k>c/0CDe=01DE5@1EEED0MWIf08N7Q`0W9bL0?Cdm06=SH`0G5aL0
ATI603De=@1MGEd0@T92034a<@1JFUX0A4A403/k>`1DE5@0;bl_04m?C`0_;bl0CDe=04A4A01YJFT0
9bLW04a<C00o?cl0?Cdm04i>CP0W9bL0BTY:03<c<`0g=cL0CDe=03Hf=P0203lo?`0`06][J`0a<C40
B4Q803De=@1WIfL0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0GEeM034a<@0c<c<0=cLg05MGE`20P800
LW9b05]KF`1aLG40GEeM05UIF@1FEUH0GUiN03hn?P2TY:@0KVi^05eMG@1oOgl0BTY:05IFEP1TI6@0
?Cdm04A4A00J6QX0FUYJ01hN7P0k>c/0CDe=0820P02>SXh0BDU905QHF01ZJVX0ADE5051@D013@d<0
DE5A4Oooool000oooooo0100V9RH08B4Q01gMgL0Kfm_05]KF`2EUID0GemO0:2PX014A4@0=CDe06EU
I@2QXJ40GUiN08>3P`1;Bd/0C4a<0P1_Kfl0<@1HF5P0Vi^K02DU9@0f=SH0H61P05QHF01ADE40MGEe
02h^;P14A4@0EeMG034a<@0o?cl0DU9B020P801JFUX0DU9B01lO7`0h>3P0Bd];04=3@`1DE5@0Lg=c
08^;R`0S8b<0@T9203hn?P1WIfL0/K6a04M7A`0V9RH0CTi>05]KF`1<C4`0Q8B405=CD`0o?cl0HV9R
05EEE@1KFe/0_[jn061PH00F5QH0AdM705iNGP1lO7`0VYZJ01dM7@0^;Rh00P1MGEd0g@1CDe<0MGEe
03dm?@0c<c<0RHV907AdM025QHD0YZJV01PH600V9RH0C4a<07AdM01WIfL0Ti>C03@d=00l?3`0EEEE
07EeM@0l?3`0GemO06m_K`0P8200DE5A0451@@0N7Qh0CDe=03Hf=P0`<300A4A407IfMP1SHf<08b<S
04I6AP0m?Cd0Ti>C09BDU00U9BD0?clo04Y:BP0e=CD0DE5A09RHV00[:b/0FEUI08f=S@1BDU80H61P
09fMW@0Y:BT07AdM04a<C020P800IFEU0:ZZZP0Z:RX07alO05UIF@2a/K40KFe]075aL@2WYjL0;Rh^
055AD@2JVYX0EeMG061PH01;Bd/09bLW05QHF01ZJVX0IVIV05iNGP0i>CT0=cLg06i^KP1cLg<0ADE5
05EEE@27QhL09RHV05ADE01YJFT0=CDe05UIF@1iNGT0>3Ph03dm?@1gMgL0Xj>S04a<C01RHV80;bl_
07=cL`2m_Kd0Lg=c02HV9P10@400GemO0410@01XJ6P0Kfm_03Lg=`0j>SX0CTi>06ATI01cLg<0Ti>C
03@d=00h>3P0EUIF05QHF02n_[h0UIFE02DU9@1GEeL0UiNG06EUI@1[Jf/0O7al034a<@1<C4`0Bd];
04U9B@2a/K40F5QH02HV9P1EEED0Ogmo04A4A01SHf<07AdM02l_;`1TI6@0Rh^;05YJFP1YJFT0>3Ph
02l_;`1FEUH0Bd];07=cL`0h>3P06ATI04Q8B01YJFT0ADE508J6QP1ADE40?3`l08f=S@1:BTX0CDe=
04Y:BP0[:b/0=SHf075aL@1fMWH0?3`l03dm?@1CDe<0Q8B407emO@0e=CD0Lg=c05=CD`16ATH0H61P
09VIV@0`<300DU9B05mOG`0i>CT0Ogmo0:RXZ00l?3`0;2`/05mOG`1NGUh0VIVI05EEE@0];Bd0ATI6
04m?C`2>SXh0N7Qh096AT@21PH40>c/k06m_K`1SHf<0KFe]08N7Q`1]KFd09bLW06ATI02;Rh/0Jf][
09bLW00e=CD0;Bd]04e=C@2<S8`0I6AT03`l?01GEeL0>CTi02XZ:P1IFET0/[:b05YJFP1IFET0I6AT
024Q8@0V9RH0HF5Q06e]K@16ATH0B4Q801`L700^;Rh0>SXj01cooooo03X0J6QX09NGU`0k>c/0>SXj
04e=C@1BDU80@41005iNGP1VIVH0>c/k0410@01=CDd0Ogmo08N7Q`1SHf<0GemO07=cL`1IFET0EUIF
059BDP0i>CT0@D5103lo?`1MGEd0BTY:04];B`1PH600MWIf06MWI`1dM7@0EeMG05mOG`1RHV80Lg=c
04i>CP1RHV80KVi^07MgM`1ADE40=SHf02PX:00k>c/0B4Q803dm?@1=CDd0EUIF0451@@16ATH0EUIF
04a<C01;Bd/0DU9B02`/;014A4@05aLG04Q8B017AdL0C4a<0P0[:b/07P0a<C40<S8b04E5A@0`<300
FEUI04i>CP1XJ6P0G5aL06EUI@0h>3P0BTY:06][J`1>CTh0?Shn04i>CP1XJ6P0ATI604e=C@1SHf<0
EeMG05UIF@1@D500DE5A05ADE00^;Rh0?Shn0410@00j>SX0?Shn024Q8@80:RXZ03l0;Bd]03Xj>P0e
=CD0<c<c02PX:00^;Rh0?Cdm03<c<`1;Bd/0BDU903Xj>P15ADD0C4a<034a<@0l?3`0<S8b07EeM@0o
?cl0B4Q805YJFP1_Kfl0;Rh^04];B`0j>SX09bLW0410@00T92@0?clo05eMG@1EEED0<C4a051@D01Z
JVX0IVIV07AdM021PH40G5aL0:f][@1cLg<0EUIF07MgM`2BTY80UYJF06m_K`2BTY80GemO03dm?@1F
EUH0B4Q801/K6`1:BTX09RHV04I6AP0_;bl0?3`l04Q8B036a/H0K6a/05eMG@1?Cdl0@T9206a/K00L
71`00P0o?cl0C`19BDT0>3Ph03`l?00C4a<0VIVI08f=S@12@T80JFUY030`<017AdL0BDU904Q8B011
@D40HF5Q03lo?`0P8200NGUi061PH02EUID0WYjN02<S8`1CDe<0;Bd]061PH012@T80Fe]K05iNGP1a
LG40GemO06ATI01`L700>SXj05EEE@15ADD0FEUI06EUI@2IVIT0YZJV05MGE`1@D500?Cdm04Y:BP0i
>CT0EUIF03lo?`1KFe/0C4a<03`l?01<C4`09bLW06i^KP27QhL0ZZZZ01dM7@0];Bd0E5AD01<C4`13
@d<0:RXZ04E5A@17AdL0=cLg04I6AP1BDU80?clo04E5A@0n?Sh0E5AD03/k>`1aLG40ADE506EUI@0E
5AD0IFEU02h^;P0j>SX0D51@02DU9@1^KVh00P0l?3`01@1IFET0=CDe04I6AP13@d<0LG5a0080ATI6
01X0AdM705iNGP14A4@0@D51028R8P16ATH0AdM704A4A01`L700<S8b03dm?@1JFUX0A4A404E5A@1;
Bd/0E5AD06a/K01QHF40NGUi07MgM`1KFe/0D51@07AdM02BTY80C4a<04Y:BP80ADE50140FEUI04I6
AP1BDU80F5QH05eMG@12@T80DU9B04];B`1hN7P0K6a/03<c<`0o?cl0Cdm?03hn?P1?Cdl0Bd];05AD
E00Aooooo`003oooool02`1/K6`0EUIF05IFEP2CTi<0CDe=04M7A`1IFET0QXJ605UIF@0d=3@0C4a<
0080Cdm?00l0IFEU05mOG`11@D40A4A405IFEP1/K6`0[:b/06MWI`0N7Qh0DE5A05]KF`1OGel0[jn_
02TY:@0O7al00P19BDT0I@1aLG40QhN703Xj>P0i>CT0Ng]k05QHF02FUYH0WIfM01TI6@0`<300EUIF
05UIF@1SHf<0Q8B401hN7P1CDe<0D51@08b<S01`L700Ph>303hn?P0/;2`0Kfm_07QhN01GEeL0HV9R
01/K6`0g=cL0EUIF06m_K`15ADD0Cdm?02TY:@1RHV80JFUY061PH00n?Sh0GUiN02PX:00l?3`0UYJF
096AT@0[:b/0@410028R8P1KFe/0_;bl055AD@0V9RH0>SXj038b<P0c<c<0TI6A03/k>`0[:b/0Bd];
065QH@0n?Sh0TY:B0>3Ph00g=cL0BDU907moO`0k>c/0Zj^[07=cL`0O7al09BDU06MWI`1_Kfl0Cdm?
06e]K@0O7al09RHV05]KF`1BDU80GUiN05YJFP0F5QH0;Bd]06=SH`1<C4`0?Shn051@D00l?3`0=CDe
05iNGP1TI6@0;Bd]03Xj>P0d=3@0De=C08>3P`1fMWH0<S8b05]KF`1;Bd/0BDU905iNGP2NWYh0AdM7
0080EeMG01/0?Cdm0820P02XZ:P0:b/[02`/;01]KFd0BDU907IfMP0o?cl06a/K04A4A01QHF40GEeM
07IfMP32`/80;bl_03Ph>01LG5`0>c/k08^;R`3;bl/0?clo024Q8@0l?3`0LG5a05QHF02a/K400P0m
?Cd0IP1=CDd0J6QX04a<C02MWId0N7Qh020P801?Cdl0MWIf07MgM`2BTY80@T9202@T901JFUX0RHV9
06ATI021PH40GUiN0492@P1BDU80XZ:R07=cL`2SXj<0KFe]0410@01cLg<0Ph>304U9B@1hN7P0>c/k
03Lg=`2IVIT0a<C405IFEP1CDe<0Bd];03De=@20P800D51@03@d=01ADE40Cdm?06m_K`2PX:00OGem
03Hf=P1@D500FEUI0:b/[01VIVH0=3@d04a<C01KFe/0B4Q80:RXZ021PH40=CDe0820P01WIfL0S8b<
06MWI`0U9BD0:2PX07IfMP1iNGT0LW9b06QXJ00`<300HF5Q07]kN`1UIFD0^KVi06MWI`11@D40Cdm?
0820P01BDU80Kfm_03Xj>P12@T80De=C092@T01VIVH0@T92069RHP0d=3@0BDU907YjNP1:BTX0=cLg
05]KF`0];Bd0?Shn04a<C01aLG40JFUY06][J`0Z:RX0:2PX04Q8B02CTi<0?Shn03/k>`80BTY:01P0
J6QX04m?C`0N7Qh0ATI604i>CP0i>CT0EEEE06YZJP19BDT09bLW03Xj>P1FEUH0Bd];05UIF@1kNg/0
7AdM02l_;`11@D40G5aL06e]K@1ZJVX09RHV03Ti>@1DE5@Looooo`0O05iNGP1JFUX0C4a<04A4A01W
IfL0E5AD03Hf=P1ADE40E5AD03Xj>P1WIfL0GEeM05UIF@1>CTh0HV9R06i^KP1NGUh0EUIF05iNGP19
BDT08b<S04i>CP0h>3P0?3`l05ADE00l?3`0>c/k055AD@1;Bd/0FEUI059BDP020410@00704Q8B01<
C4`0D51@04Q8B01VIVH0EEEE02LW9`0202h^;P3D03De=@0m?Cd0@d=304Q8B00e=CD0?Cdm04Y:BP0^
;Rh09BDU03Xj>P0i>CT0@41003De=@1<C4`0HF5Q0861P@0l?3`0BDU904i>CP0c<c<0@D5103Xj>P12
@T80ADE505MGE`1cLg<0Hf=S03dm?@1=CDd0Fe]K06MWI`1CDe<0Hf=S04E5A@0L71`07alO03dm?@1<
C4`0Cdm?03Ph>01<C4`0HV9R059BDP19BDT0DU9B05=CD`1EEED09bLW04a<C00h>3P0<c<c04m?C`14
A4@0@d=303<c<`1=CDd0@d=30492@P1DE5@0BTY:04E5A@10@400ATI602DU9@1<C4`092@T05IFEP1G
EeL0J6QX04Q8B01<C4`0;Bd]04];B`1DE5@0<C4a05EEE@14A4@0?Cdm05ADE01CDe<0;bl_03/k>`12
@T80?Shn06m_K`1SHf<0B4Q80:VYZ@1CDe<0GemO03De=@1TI6@0GemO03`l?02@T900GemO034a<@25
QHD0ATI604];B`1HF5P07AdM04a<C00T92@0;2`/04];B`1VIVH0MgMg06i^KP1SHf<0CDe=09NGU`0]
;Bd0DU9B05eMG@1;Bd/08B4Q0492@P0P8200BDU906UYJ@0h>3P0ATI601/K6`1;Bd/0<30`03<c<`0`
<300AdM703Hf=P0_;bl0J6QX04E5A@2CTi<0Vi^K05UIF@1WIfL0>SXj05eMG@0d=3@0IfMW069RHP2?
Shl0=cLg055AD@1CDe<0=SHf04];B`1:BTX0GEeM04I6AP2LW9`0UiNG04e=C@1DE5@0De=C0410@00D
51@0BDU904];B`1NGUh0HV9R04=3@`1@D500GUiN07UiN@1NGUh0IfMW01DE5@0R8R80GemO014A4@1F
EUH09bLW05QHF011@D40=cLg05UIF@1EEED0GemO05]KF`1;Bd/0IVIV04E5A@21PH40Fe]K06ATI00T
92@0Lg=c05=CD`16ATH0IfMW03De=@1gMgL0ADE504I6AP1:BTX0D51@04U9B@1GEeL0HF5Q03lo?`17
AdL05aLG04a<C00Y:BT0=cLg01lO7`1KFe/0GEeM03lo?`1XJ6P205UIF@0304I6AP1DE5@0IFEU0080
IFEU01d0GEeM03Lg=`1ADE40De=C03@d=00A4A40RXZ:0<;2`P1hN7P0KFe]04=3@`0o?cl0EUIF02`/
;00o?cl0ADE506EUI@0`<300@T92061PH01nOWh0RXZ:07alO01UIFD0FEUI04];B`1VIVH0EeMG06a/
K00Aooooo`003oooool03@2c/k<0DE5A04m?C`1_Kfl0QHF504Q8B016ATH0OWin08>3P`26QXH0_Kfm
0451@@0j>SX00P1SHf<0M@1kNg/0LG5a020P801OGel0EeMG06i^KP1JFUX0M7Ad02/[:`0b<S80O7al
03Ph>00g=cL0=3@d020P800n?Sh0HV9R04Q8B01dM7@08b<S02TY:@0o?cl0OWin07QhN00^;Rh0KVi^
02<S8`0[:b/0V9RH05UIF@0U9BD0De=C03@d=01FEUH0/k>c07YjNP0T92@0C4a<05]KF`24Q8@0Shn?
02DU9@0R8R80ADE505iNGP1KFe/0NWYj03@d=00g=cL0Fe]K04U9B@21PH40WinO024Q8@0e=CD0EeMG
09>CT`1[Jf/0M7Ad01TI6@0Z:RX0LW9b08J6QP1ADE40VIVI0451@@0O7al0CDe=09BDU01RHV80M7Ad
038b<P0O7al0@D5107QhN022PX80J6QX028R8P11@D40M7Ad06MWI`13@d<0CDe=08J6QP0h>3P0A4A4
07emO@0[:b/0@41004m?C`12@T80MgMg08f=S@13@d<0:2PX04M7A`1LG5`0NGUi07IfMP0U9BD0;2`/
04Y:BP1[Jf/0EUIF0:6QX@0m?Cd0BDU906ATI01hN7P0HV9R0:6QX@24Q8@0<c<c05UIF@1UIFD0MGEe
0;fm_@0204E5A@2L04U9B@2EUID0KVi^061PH01UIFD08B4Q05EEE@22PX80A4A4071`L01<C4`0;Rh^
04M7A`2LW9`0VYZJ05iNGP0];Bd0<c<c03hn?P21PH40FEUI03Ti>@1/K6`0<30`02`/;01/K6`0BDU9
03dm?@1=CDd0;Rh^03Hf=P1MGEd0PX:20410@00j>SX0CDe=04M7A`2PX:00OWin030`<01HF5P0A4A4
02d];@1hN7P0Ogmo030`<01EEED0D51@04I6AP2g]kL0_kno03Lg=`1:BTX0SXj>05UIF@2LW9`0BDU9
024Q8@1<C4`0TY:B05iNGP20P800Ng]k034a<@1RHV80VYZJ06m_K`30`<00>CTi0410@02LW9`0TY:B
05]KF`1IFET0:b/[07=cL`2GUiL0De=C07=cL`0m?Cd0BDU904e=C@1cLg<0MGEe092@T00i>CT0UIFE
08f=S@1mOGd0Bd];09FEU@1;Bd/0E5AD08j>SP1>CTh0H61P04I6AP0e=CD0NGUi0:JVYP1>CTh0De=C
06i^KP17AdL0Q8B405QHF00c<c<0Kfm_06MWI`1DE5@0TI6A0;2`/00j>SX0G5aL08B4Q01/K6`0PX:2
09^KV`0i>CT0?3`l04=3@`1CDe<0Kfm_0;:b/P0`<300<C4a03`l?01lO7`0HF5Q07emO@28R8P0=3@d
065QH@1GEeL0>3Ph07YjNP2>SXh09bLW028R8P1LG5`0LG5a04U9B@27QhL0<c<c02d];@12@T80EeMG
038b<P1>CTh0Jf][03<c<`0o?cl0Bd];05ADE019BDT0Q8B47?ooool0AP18B4P0HV9R02/[:`0d=3@0
B4Q806][J`1RHV80G5aL05EEE@0m?Cd0>SXj04m?C`1OGel0FEUI07EeM@27QhL0MGEe04U9B@1LG5`0
Bd];01HF5P0/;2`06a/K03<c<`1>CTh0GEeM055AD@1jNWX0IfMW069RHP1HF5P0De=C069RHP1XJ6P0
IVIV07alO01aLG40Hf=S061PH00f=SH0;bl_04Q8B00j>SX0BDU90410@01NGUh0=CDe03`l?01>CTh0
>SXj038b<P0k>c/06ATI02d];@0O7al0<c<c03Lg=`0m?Cd0;2`/01`L700R8R80;Bd]030`<00c<c<0
?Shn04a<C01:BTX0Fe]K04i>CP0k>c/203Ph>01d04A4A00N7Qh0;2`/059BDP0T92@0:RXZ06=SH`18
B4P0F5QH04m?C`14A4@0=CDe03`l?00_;bl0@41002LW9`0Z:RX08b<S03@d=00];Bd0<30`03Hf=P0T
92@0;Bd]028R8P0_;bl0=cLg02h^;P12@T80ADE503<c<`13@d<0C4a<01lO7`0`<3007AdM06IVIP1C
De<0>SXj04m?C`1[Jf/0AdM705MGE`10@400IfMW09:BTP1IFET0L71`05mOG`1iNGT0;bl_05MGE`1D
E5@0GemO06i^KP1gMgL0EeMG0:>SX`1[Jf/0J6QX05QHF02ATI40PH6104e=C@1dM7@0CTi>04e=C@24
Q8@0ATI604Y:BP20P800EUIF04Y:BP17AdL0SXj>05YJFP2ATI40F5QH05IFEP1CDe<0?Shn04e=C@1:
BTX0D51@05aLG01=CDd0=CDe051@D00@4100JVYZ075aL@0i>CT0Fe]K034a<@12@T80;2`/03Lg=`10
@400EEEE04];B`0`<300P82005EEE@1jNWX0S8b<02`/;00l?3`0@d=306i^KP13@d<0EeMG065QH@2H
V9P0H61P04];B`18B4P204Y:BP0P03Lg=`1>CTh0<S8b07AdM01iNGT0BTY:05QHF00a<C40CTi>04I6
AP1GEeL0>CTi079bLP1>CTh0=cLg05ADE01EEED0R8R80861P@29RHT0:RXZ030`<01^KVh07alO04a<
C01?Cdl0E5AD04m?C`1:BTX0FEUI06EUI@1PH60205EEE@1207moO`1UIFD0U9BD06=SH`2LW9`0CTi>
08J6QP0m?Cd0>3Ph04a<C00/;2`0N7Qh0410@01@D500Cdm?059BDP1GEeL0@d=3051@D01:BTX0H61P
038b<P14A4@0GUiN06i^KP0c<c<0R8R806ATI012@T80Lg=c01DE5@0U9BD0?clo04A4A01ADE40D51@
04a<C01gMgL0BTY:06e]K@1?Cdl0=CDe01@D501KFe/0^k^k09jNWP2;Rh/0ADE504=3@`1CDe<0<c<c
071`L00i>CT0@d=303<c<`1PH600EeMG06=SH`1JFUX0@T9205EEE@1RHV80E5AD05EEE@20P800JFUY
4Oooool000oooooo02T0N7Qh07AdM01JFUX0JFUY06][J`1fMWH0ATI6075aL@0m?Cd0=SHf06YZJP20
P800@T92071`L016ATH0GUiN09FEU@0e=CD0;2`/04e=C@0g=cL0?Shn08n?S`1:BTX0=SHf05]KF`1S
Hf<0Ph>304e=C@0P8200;2`/059BDP14A4@0RHV9028R8P0f=SH0ATI606i^KP1dM7@0FEUI09RHV002
04M7A`3g0410@01LG5`0RHV90:b/[00L71`0=CDe04e=C@1aLG40Bd];07emO@12@T80De=C059BDP0l
?3`0@T9209NGU`0U9BD0?Cdm04Y:BP1@D500BTY:05ADE00S8b<0>CTi08f=S@1cLg<08b<S0410@00`
<300BTY:05QHF00^;Rh0:2PX07UiN@0c<c<0?Cdm09JFUP1ADE406ATI02h^;P14A4@0DU9B0;Bd]01?
Cdl071`L03Xj>P19BDT0F5QH0:>SX`1CDe<051@D061PH02LW9`0J6QX08f=S@3Bd]80=CDe03Xj>P1h
N7P0LG5a06a/K01iNGT07alO06MWI`2@T900Bd];05mOG`1nOWh0;Bd]05QHF026QXH0A4A406ATI027
QhL05ADE030`<013@d<0F5QH055AD@25QHD07QhN02LW9`1EEED0[Jf]04a<C01CDe<0Jf][02XZ:P1f
MWH0TY:B02l_;`1IFET0ADE502DU9@11@D40RXZ:03/k>`11@D40>c/k0451@@1lO7`0RXZ:02`/;00d
=3@0Hf=S05ADE01`L700HV9R02l_;`1?Cdl0EeMG04];B`1NGUh0/k>c055AD@0[:b/0L71`05eMG@25
QHD0UiNG02XZ:P0f=SH0JVYZ069RHP14A4@0VYZJ05IFEP0m?Cd0I6AT096AT@1KFe/0^;Rh07IfMP0U
9BD0AdM708^;R`1HF5P0XZ:R03De=@0/;2`0=SHf07EeM@1JFUX0EeMG06MWI`0j>SX0GemO06IVIP19
BDT0LW9b03dm?@0g=cL0GUiN06MWI`0e=CD0EEEE03Ti>@13@d<0IVIV06ATI00U9BD0NGUi04A4A02;
Rh/0Ogmo03Ph>013@d<0>3Ph0451@@2c/k<0QHF503Xj>P1EEED0Bd];05iNGP2m_Kd0?clo03Ph>01W
IfL0IFEU06ATI03=cLd0C4a<02/[:`1/K6`0FEUI08n?S`1HF5P0;bl_04E5A@2:RXX0Rh^;08B4Q023
Ph<0DE5A04i>CP1]KFd0Fe]K0;^k^`2DU9@0<S8b04Y:BP1bLW80Kfm_0:VYZ@15ADD0<S8b04E5A@25
QHD0Lg=c05]KF`1gMgL0A4A404i>CP2CTi<0N7Qh04M7A`1[Jf/0?Shn02d];@1DE5@0YZJV06YZJP1c
Lg<0ADE502<S8`1mOGd0^[Zj071`L014A4@0EUIF034a<@1=CDd0UiNG04U9B@0^;Rh0G5aL04M7A`0o
?cl0F5QH08Z:RP0`<300@41004I6AP0m?Cd0F5QH0:2PX00Looooo`0^05MGE`2:RXX0?Shn04I6AP1?
Cdl0C4a<03Xj>P1UIFD0I6AT03Ti>@19BDT0HV9R09NGU`2@T900JVYZ059BDP1WIfL0HF5Q05QHF01F
EUH0;Rh^03<c<`0a<C40=SHf03hn?P11@D40EUIF05ADE01JFUX0Lg=c05EEE@0f=SH0GEeM06e]K@0m
?Cd0CTi>065QH@1`L700D51@02TY:@0a<C40?Cdm05EEE@18B4P0ATI6069RHP80AdM704H0De=C04I6
AP0j>SX0CTi>02TY:@0m?Cd071`L04];B`12@T80E5AD0492@P0Q8B40;Rh^03Ti>@10@400<30`04A4
A00n?Sh0EEEE05YJFP1OGel0<30`04=3@`1VIVH0G5aL03hn?P15ADD0Kfm_04Y:BP1@D500Fe]K059B
DP1=CDd0IFEU061PH01@D500Bd];04A4A016ATH0>c/k04I6AP0a<C40<S8b030`<00j>SX0@41003`l
?01ADE40<30`02`/;00g=cL0?Shn05eMG@10@400Cdm?04M7A`0i>CT0;2`/0492@P0a<C40?clo04M7
A`0j>SX0@41003<c<`0X:2P0ADE504I6AP0^;Rh0>c/k0P0c<c<0GP1IFET0I6AT04A4A01>CTh0H61P
065QH@1gMgL0NWYj06UYJ@2i^KT0Lg=c05iNGP0i>CT0NWYj07AdM015ADD0J6QX05MGE`10@400DU9B
03hn?P0_;bl0R8R805ADE01fMWH0I6AT04];B`1RHV80S8b<08:2PP1aLG40DE5A03lo?`1MGEd0;Bd]
065QH@24Q8@0H61P0451@@1@D5005ADE06ATI01aLG40Bd];07alO00I6AT0?Shn0451@@0n?Sh0>3Ph
04m?C`0l?3`0<S8b092@T01SHf<0KFe]08F5Q@1CDe<0F5QH0410@01=CDd0<S8b03De=@1MGEd0Xj>S
03Ph>01YJFT0EUIF03Xj>P13@d<0E5AD08>3P`0];Bd0De=C061PH00b<S80@41002LW9`0b<S805ADE
055AD@0Y:BT0Cdm?03/k>`1;Bd/0IfMW03/k>`1UIFD0WYjN09NGU`1:BTX0<C4a08^;R`0[:b/205UI
F@1:06][J`1ADE40=3@d05EEE@1NGUh0D51@04=3@`0c<c<0J6QX02l_;`1KFe/0@D5106MWI`0^;Rh0
BDU904Q8B01:BTX0Kfm_04M7A`1XJ6P0BTY:04I6AP13@d<0>SXj03De=@0Z:RX0?clo02XZ:P16ATH0
=cLg05EEE@18B4P0=CDe04A4A01;Bd/0BTY:05QHF01NGUh0?3`l05YJFP1?Cdl0?Cdm069RHP1OGel0
GEeM0:b/[01MGEd0NGUi04=3@`1<C4`0<30`05mOG`29RHT0LG5a05mOG`1NGUh0A4A405IFEP0V9RH0
?Cdm02d];@1;Bd/0;2`/05eMG@1?Cdl0IVIV05mOG`0k>c/0?clo04m?C`13@d<0G5aL04Q8B01@D50A
ooooo`003oooool0@@1/K6`0Ph>30;Fe]@1cLg<0CTi>06MWI`1MGEd0QhN703@d=015ADD0D51@06][
J`21PH40^;Rh04E5A@14A4@0FUYJ04Q8B01WIfL0WIfM04=3@`0Z:RX0Bd];061PH01jNWX0SHf=01DE
5@14A4@0Lg=c04M7A`1WIfL0EUIF028R8P18B4P0QhN703@d=01MGEd0I6AT02d];@0c<c<0TI6A06YZ
JP0i>CT0DU9B02HV9P1SHf<0Xj>S07YjNP0i>CT0LW9b05=CD`14A4@0VYZJ06=SH`16ATH0HV9R0492
@P1CDe<0YZJV03Ti>@0R8R80@T9205MGE`1gMgL0KVi^0080;2`/0540GemO0861P@1ADE40SXj>03<c
<`0k>c/0TY:B05MGE`1DE5@0UIFE0451@@0i>CT0>c/k08Z:RP1;Bd/0NGUi024Q8@0a<C40IFEU09>C
T`0l?3`0JFUY04];B`0];Bd0EeMG071`L00l?3`0AdM703/k>`17AdL0@d=30861P@1PH600;2`/03`l
?00d=3@0C4a<07=cL`10@400820P03Ti>@0a<C40DU9B07emO@0c<c<0<C4a05MGE`1<C4`0Fe]K0;Jf
]P0^;Rh08b<S04E5A@11@D40QHF50:FUY@0V9RH09BDU04=3@`1OGel0?Cdm09jNWP36a/H0;2`/03Xj
>P1]KFd0JVYZ0:BTY02VYZH0820P0451@@1EEED0IfMW08^;R`0h>3P0:2PX05mOG`2CTi<0L71`08^;
R`2BTY800P0l?3`0S01fMWH0@D5108V9R@2FUYH0;2`/04=3@`1SHf<0W9bL04M7A`1^KVh08B4Q04U9
B@1JFUX0H61P03Hf=P1ADE40=SHf024Q8@1ADE40V9RH03@d=01<C4`0D51@03Hf=P1UIFD0Ogmo0492
@P13@d<0ADE506ATI02?Shl0I6AT0451@@1PH600ATI603lo?`2LW9`0cLg=04=3@`1/K6`0IFEU05AD
E02`/;00OGem038b<P18B4P0FUYJ05ADE029RHT08R8R04m?C`22PX80I6AT04m?C`3;bl/0K6a/02/[
:`1fMWH0BTY:08R8R00/;2`0<c<c04i>CP1/K6`0EUIF08n?S`0o?cl0?Shn08J6QP1]KFd0HV9R05iN
GP0U9BD0CDe=075aL@1kNg/0OGem069RHP0e=CD0Hf=S0:NWY`14A4@0Kfm_0410@00a<C40CDe=09NG
U`0l?3`0C4a<02/[:`11@D40O7al09VIV@17AdL0@D5105QHF016ATH0QhN7061PH00g=cL0>CTi051@
D00i>CT0JFUY0:j^[P0g=cL0>3Ph061PH01BDU80Kfm_0:VYZ@2DU9@09bLW04m?C`23Ph<0UYJF0:j^
[P0i>CT08R8R04=3@`1oOgl0JVYZ07EeM@2WYjL0>CTi02h^;P1ADE40NWYj06UYJ@35aLD0Cdm?02`/
;00c<c<0CTi>04m?C`1bLW80L71`01lO7`0g=cL0CDe=7?ooool0:`1PH600DU9B02DU9@0f=SH0GUiN
06][J`14A4@0B4Q806=SH`0n?Sh0EeMG06EUI@1OGel0AdM704m?C`0`<300DU9B04U9B@1EEED0B4Q8
038b<P19BDT0;2`/03De=@1>CTh0A4A404Q8B016ATH0@41004A4A01DE5@0?clo04I6AP1?Cdl0ATI6
04m?C`0m?Cd0BDU9051@D00d=3@0?clo03hn?P0g=cL00P0o?cl0O00m?Cd0>CTi04];B`1ADE40ATI6
04i>CP1ADE40?3`l04E5A@0n?Sh0Bd];0410@01@D500=cLg03hn?P19BDT0;Bd]04E5A@18B4P0AdM7
04=3@`19BDT0MGEe05iNGP0e=CD0?clo06IVIP1OGel0>CTi0451@@1JFUX07alO02@T901IFET0EeMG
059BDP0k>c/0@41004M7A`1CDe<0ATI604m?C`0m?Cd0B4Q8028R8P0T92@0:RXZ038b<P0g=cL0<c<c
03Hf=P0R8R80;Rh^034a<@0[:b/0@T9203Ph>00^;Rh0?Cdm03Ph>00b<S80C4a<02d];@0l?3`0F5QH
05MGE`1JFUX0EUIF03Ti>@1WIfL0D51@03Lg=`1EEED0>c/k03Xj>P1;Bd/0E5AD02/[:`0o?cl0;2`/
03<c<`1LG5`0GemO04M7A`14A4@0@41005aLG00U9BD0JVYZ07IfMP15ADD0MWIf05]KF`0o?cl0G5aL
0492@P0e=CD0?Cdm01/K6`1?Cdl0<30`04];B`0e=CD0^k^k07alO01UIFD0BDU904a<C02EUID0?Shn
02l_;`16ATH0BTY:03<c<`18B4P0<c<c0:NWY`24Q8@0@41005QHF00d=3@0>CTi03`l?01MGEd204Y:
BP1303dm?@0a<C40ADE506ATI01RHV80Ph>303Ti>@1ADE40?Shn059BDP0m?Cd0F5QH05MGE`1/K6`0
G5aL0:JVYP28R8P0>3Ph0451@@0j>SX0AdM705iNGP1UIFD0Kfm_05EEE@1<C4`0E5AD04I6AP0b<S80
HV9R04U9B@1VIVH0BTY:04M7A`1CDe<0A4A406QXJ01[Jf/0WinO061PH017AdL0VYZJ079bLP1`L700
CDe=04Y:BP14A4@0>c/k04i>CP15ADD0A4A404i>CP15ADD0IfMW03`l?01^KVh0@d=306i^KP0P8200
Hf=S02l_;`0g=cL0EEEE01lO7`1OGel0:b/[03@d=00203Hf=P0b05ADE01<C4`0BDU905IFEP1IFET0
J6QX04i>CP13@d<0Bd];04A4A01RHV80HF5Q07]kN`1hN7P0ATI604=3@`1:BTX0HF5Q06MWI`1ADE40
ATI605mOG`1@D500Ph>306][J`2>SXh0BTY:05aLG02ZZZX0QHF506i^KP1SHf<0M7Ad07]kN`0i>CT0
EUIF04=3@`1ADE40:BTY0492@P1:BTX0M7Ad07IfMP19BDT0Bd];059BDP1?Cdl0G5aL06EUI@1cLg<A
ooooo`003oooool01@2HV9P0De=C05ADE02GUiL0Lg=c0080A4A40:P0L71`06e]K@1>CTh0PX:20451
@@0h>3P0GUiN05UIF@24Q8@0NGUi02`/;016ATH0IFEU05YJFP1HF5P0Ph>302DU9@1FEUH0R8R80451
@@1SHf<0CTi>034a<@1EEED0SHf=06YZJP1MGEd0>3Ph03Hf=P1iNGT0Shn?03lo?`1=CDd0J6QX03Lg
=`1<C4`0R8R804Q8B012@T80N7Qh04i>CP1BDU80TY:B069RHP0^;Rh0CTi>059BDP1ZJVX0Kfm_02TY
:@0h>3P0IVIV04Y:BP1]KFd0TI6A034a<@0m?Cd0J6QX04M7A`1SHf<0TI6A03@d=00b<S80F5QH06e]
K@1LG5`0I6AT02HV9P0o?cl0Lg=c05eMG@1KFe/0SXj>02d];@0^;Rh0Kfm_04m?C`19BDT0O7al0410
@00d=3@0N7Qh096AT@0d=3@0FUYJ03/k>`17AdL0KVi^06EUI@0_;bl0ATI6075aL@0n?Sh0B4Q807If
MP0];Bd0GUiN04m?C`14A4@0H61P06QXJ00f=SH0=CDe06ATI01@D500Ng]k06m_K`12@T80?3`l05eM
G@1EEED0EeMG07]kN`13@d<0D51@07AdM01LG5`0A4A409RHV02=SHd0=CDe04I6AP1`L700J6QX092@
T016ATH0=3@d05mOG`26QXH0EeMG069RHP1_Kfl0:RXZ05QHF01VIVH0BTY:07MgM`1EEED0:b/[051@
D024Q8@0O7al05YJFP0i>CT0?Shn069RHP28R8P0J6QX04m?C`1RHV80FUYJ04i>CP27QhL0ATI604=3
@`1@D500CTi>04I6AP28R8P0JFUY030`<01:BTX0Fe]K05QHF02<S8`0IfMW0451@@1JFUX2051@D00I
079bLP1QHF40>c/k04];B`1MGEd0CTi>09JFUP1eMGD0;Bd]03@d=01XJ6P0GemO07emO@0V9RH0=CDe
04i>CP1HF5P0Bd];07inOP1oOgl09BDU059BDP1DE5@0OGem09RHV002038b<P0b05eMG@24Q8@0HV9R
06IVIP11@D40M7Ad05UIF@15ADD0PH6103Ph>00l?3`0JVYZ06a/K01QHF40Jf][04=3@`22PX80QXJ6
03lo?`1`L700O7al03Ph>01ADE40RHV90451@@1lO7`0PH6105EEE@2BTY80S8b<03hn?P1`L700LG5a
06ATI02@T900J6QX04A4A01UIFD0G5aL04a<C01_Kfl0PX:203/k>`1_Kfl0IVIV06ATI01nOWh0SHf=
055AD@0j>SX206e]K@0R05QHF02PX:00Cdm?03De=@1iNGT0R8R806UYJ@2=SHd0EUIF038b<P1eMGD0
JFUY04=3@`1bLW80H61P02/[:`0Z:RX0DE5A079bLP1LG5`0IVIV02<S8`0[:b/0JFUY07EeM@0d=3@0
De=C05ADE00S8b<0@D5106QXJ00m?Cd0>SXj07]kNacooooo05T0EUIF06IVIP0o?cl0@410059BDP1J
FUX0ATI6059BDP1OGel0>c/k03Lg=`1EEED0P82007EeM@1kNg/0FUYJ06IVIP1=CDd0FUYJ059BDP0X
:2P0<S8b02l_;`0];Bd0=SHf03Ti>@1?Cdl0IfMW065QH@1JFUX0Fe]K04M7A`1^KVh0IFEU04m?C`1K
Fe/0H61P055AD@1DE5@0:RXZ034a<@0o?cl0>CTi0492@P0l?3`0D51@03/k>`0i>CT0ATI603hn?P0l
?3`0AdM702XZ:P0h>3P0:BTY03@d=00f=SH0AdM702l_;`0W9bL0;bl_03Lg=`17AdL0>3Ph04m?C`1:
BTX0B4Q8061PH01GEeL0@41003hn?P1IFET0DU9B03Lg=`14A4@0IFEU03@d=010@400EeMG04Q8B01<
C4`0F5QH059BDP1?Cdl0B4Q804=3@`1BDU80;Rh^0451@@0202l_;`0C02/[:`0c<c<0?3`l03@d=014
A4@0;2`/03<c<`0m?Cd0;bl_059BDP0n?Sh0@T9204Y:BP19BDT0>c/k04];B`0k>c/0@41005eMG@02
04E5A@2?04e=C@0k>c/0EUIF03Ph>011@D40B4Q8038b<P12@T80C4a<05ADE00o?cl0Cdm?0451@@1?
Cdl0LW9b08j>SP1>CTh0R8R806EUI@1QHF407QhN07YjNP1YJFT0@d=307emO@0m?Cd0?clo059BDP0f
=SH0?3`l05]KF`13@d<0EUIF051@D01NGUh0EEEE07inOP1VIVH0J6QX05=CD`1BDU80CTi>03hn?P1D
E5@0K6a/061PH00m?Cd0B4Q8014A4@1BDU80IVIV03hn?P1RHV80;2`/05IFEP15ADD0J6QX05IFEP1N
GUh0>SXj04i>CP24Q8@0HV9R06e]K@2DU9@0?Shn05ADE00g=cL0EeMG0492@P13@d<0?clo06ATI00m
?Cd0I6AT061PH00d=3@0BDU903dm?@1IFET0;Rh^06a/K01lO7`0E5AD07YjNP1/K6`0CDe=030`<01K
Fe/0=cLg06i^KP1ADE40E5AD06UYJ@11@D40MWIf08J6QP23Ph<0ADE50:ZZZP2[Zj/0RXZ:06YZJP1B
DU80E5AD06IVIP1KFe/0HV9R06=SH`1VIVH0De=C04Q8B01`L700CDe=08B4Q01DE5@0MWIf0451@@1b
LW80FUYJ04I6AP1[Jf/0C4a<07AdM01EEED0HV9R04A4A017AdL0Fe]K04Q8B016ATH0DU9B06MWI`0n
?Sh0B4Q8055AD@1GEeL0=CDe05eMG@1IFET0F5QH07alO00U9BD00P0k>c/08@19BDT0Fe]K05eMG@1k
Ng/0TI6A065QH@1dM7@0GUiN06EUI@1>CTh0LW9b07emO@1fMWH0LG5a05QHF00o?cl0CTi>03Xj>P1L
G5`0?Shn04Y:BP0c<c<0EEEE055AD@1PH600FUYJ0451@@1:BTX0EEEE05UIF@1KFe/0M7Ad06EUI@0A
ooooo`003oooool0o`26QXH0/K6a07=cL`26QXH0HF5Q06][J`1KFe/0MWIf03hn?P0k>c/0MGEe08:2
PP1GEeL0O7al03@d=01OGel0U9BD04M7A`1>CTh0Ogmo028R8P16ATH0F5QH065QH@1BDU80@d=303Xj
>P1?Cdl0DE5A02`/;00j>SX0?Cdm04=3@`1QHF409RHV02DU9@0g=cL0B4Q804E5A@1cLg<0][Jf04a<
C00N7Qh0GemO06UYJ@1]KFd0bl_;02d];@0W9bL0H61P06YZJP1HF5P0YJFU04U9B@12@T80M7Ad03lo
?`1JFUX0ZZZZ04E5A@0Y:BT0Jf][05aLG02ZZZX0Cdm?02<S8`0];Bd0JFUY06QXJ01VIVH0J6QX02<S
8`0k>c/0M7Ad02`/;01OGel0Lg=c01/K6`0m?Cd0Zj^[08:2PP0U9BD0@d=303Ti>@0o?cl0Ph>307If
MP0i>CT0GUiN0451@@0j>SX0JVYZ059BDP0V9RH0CTi>04I6AP1PH600PH610=?Cd`1CDe<09bLW04I6
AP1GEeL0S8b<07moO`0[:b/0Bd];06ATI01YJFT0HF5Q0:VYZ@0W9bL0ADE509>CT`1SHf<0RXZ:09:B
TP0O7al0;Bd]08J6QP1eMGD0MWIf08V9R@0R8R80<C4a07EeM@2_[jl0CDe=07YjNP1kNg/0:BTY06EU
I@1mOGd0B4Q8079bLP0n?Sh0:2PX04A4A01FEUH0A4A406UYJ@0Y:BT092@T06EUI@21PH40B4Q804m?
C`1^KVh0>CTi06e]K@2;Rh/0@d=3061PH01TI6@0;Bd]075aL@26QXH0KVi^055AD@1DE5@0Cdm?06QX
J02NWYh0@D5102`/;01:BTX0FEUI04=3@`1mOGd0J6QX030`<019BDT0Lg=c04Y:BP2@T900Bd];02d]
;@1:BTX0Ng]k06IVIP2UYJD0?Shn05eMG@1LG5`0S8b<05QHF023Ph<0EUIF04e=C@2;Rh/0QXJ6065Q
H@2^[Zh0GEeM04I6AP1eMGD0c<c<07=cL`1EEED0=cLg04I6AP2;Rh/0R8R805UIF@2:RXX0<c<c04U9
B@1jNWX0BDU905eMG@0/;2`0<c<c06MWI`2=SHd0B4Q8071`L00l?3`0Fe]K0:^[Z`1>CTh0@D5104m?
C`0a<C40M7Ad09nOW`18B4P0=SHf059BDP16ATH0K6a/08>3P`0h>3P0AdM705IFEP1HF5P0PH6107em
O@1CDe<0F5QH05YJFP1^KVh0/K6a06][J`0Y:BT0AdM707YjNP1`L700cLg=055AD@0e=CD0@410092@
T02LW9`0N7Qh08f=S@00701YJFT0=cLg06a/K02@T900GemO0:n_[`1HF5P0A4A405=CD`23Ph<0IVIV
09FEU@0i>CT0<S8b07AdM02DU9@0ADE50410@01;Bd/08B4Q03Lg=`1PH600ADE503Xj>P1>CTh07AdM
034a<@0o?cl207]kN`0504Y:BP0`<300>c/k03dm?@1mOGd07?ooool04@1aLG40J6QX02d];@13@d<0
DU9B05EEE@12@T80Fe]K065QH@13@d<0CTi>05MGE`1BDU80B4Q807YjNP22PX80SHf=0080GEeM05X0
CDe=02LW9`16ATH0=SHf03@d=01<C4`0>CTi04A4A017AdL0FEUI06a/K01;Bd/0?Shn05=CD`1RHV80
De=C05IFEP1IFET0EeMG059BDP0j>SX0?3`l04Q8B00n?Sh0ADE504i>CP1@D500>c/k04Q8B01;Bd/0
@41003Ti>@1>CTh09BDU04];B`0^;Rh0@d=302l_;`1;Bd/0>CTi034a<@0h>3P0>CTi04a<C01DE5@0
C4a<04I6AP1<C4`0W9bL06IVIP0l?3`0A4A406UYJ@1IFET0;bl_04A4A01NGUh0:2PX02HV9P1OGel0
E5AD05EEE@1ADE40Bd];04E5A@13@d<0>3Ph051@D00d=3@0E5AD03Lg=`0T92@0A4A403/k>`0j>SX0
?Shn04Y:BP0];Bd0<30`03Xj>P0e=CD0AdM703lo?`11@D40<c<c02`/;00a<C40Bd];03De=@0o?cl2
04m?C`0L04M7A`1<C4`0@41006e]K@0i>CT0>c/k051@D00g=cL0BDU90492@P0j>SX0<30`04Y:BP1B
DU80?clo065QH@1OGel0DU9B08b<S01:BTX0@410018B4P1EEED0FUYJ04a<C02<S8`0Fe]K03dm?@80
@D5106@06a/K038b<P0Z:RX0Fe]K030`<00n?Sh0E5AD09JFUP2?Shl0OGem051@D00n?Sh0J6QX02<S
8`0g=cL0@D5103dm?@0c<c<0ADE503Lg=`1lO7`0JVYZ034a<@16ATH0:BTY0451@@0a<C40>c/k04A4
A01;Bd/0ADE503<c<`14A4@0@41006UYJ@2GUiL0Cdm?05YJFP0`<300ADE504a<C011@D40De=C09ZJ
VP19BDT0Xj>S09fMW@0k>c/0Cdm?05iNGP1oOgl0ATI6069RHP1cLg<0?Cdm03hn?P15ADD0=3@d02XZ
:P1`L700=CDe04a<C013@d<0LW9b06m_K`17AdL0E5AD04M7A`1OGel0:b/[03/k>`0W9bL0PH6105aL
G00e=CD0>SXj04i>CP0_;bl0@41005UIF@1HF5P0?3`l03<c<`1eMGD0=cLg04E5A@0o?cl0Ogmo030`
<01ADE40?clo03Xj>P1EEED0;bl_05aLG00V9RH0;2`/04e=C@11@D40<C4a0P12@T809P0n?Sh0<c<c
03lo?`1;Bd/0@41003hn?P10@400CDe=04U9B@1=CDd0R8R802l_;`0l?3`0DU9B06e]K@1=CDd0EUIF
04Y:BP17AdL0H61P069RHP19BDT0MGEe0861P@1^KVh0TY:B092@T01VIVH0NWYj04e=C@1eMGD0?clo
04m?C`13@d<0E5AD02TY:@10@400@d=30P23Ph<01`1<C4`0CDe=05QHF01CDe<0C4a<059BDP1KFe/0
4Oooool000oooooo03l0Kfm_05ADE02TY:@0][Jf04m?C`19BDT0EeMG08B4Q00h>3P0;Bd]04A4A01/
K6`0R8R80;Zj^P0d=3@0:b/[061PH01MGEd0T92@0;6a/@0V9RH0>SXj04];B`1IFET0O7al05YJFP0F
5QH0A4A407=cL`1ADE40M7Ad05iNGP0I6AT0D51@05iNGP1SHf<0_[jn069RHP0U9BD0?3`l07QhN02<
S8`0BTY:07EeM@0Z:RX09bLW079bLP2<S8`0I6AT09VIV@0R8R80;Bd]04e=C@1QHF40JVYZ04m?C`0G
5aL0?3`l06MWI`0k>c/0?Cdm04e=C@0c<c<00P1HF5P0T@0U9BD0=CDe04m?C`0[:b/0Fe]K0:>SX`17
AdL0;2`/06MWI`0o?cl0Ng]k0:FUY@0J6QX04Q8B03/k>`1cLg<0I6AT07]kN`0Q8B40?Shn06MWI`1K
Fe/0H61P09fMW@27QhL06a/K06a/K01TI6@0GEeM0:NWY`15ADD09bLW04I6AP23Ph<0KVi^051@D01=
CDd0@41005YJFP1nOWh0CTi>07UiN@1BDU80820P03hn?P24Q8@0GEeM04];B`10@400>CTi05UIF@1`
L700Cdm?02l_;`10@400AdM706IVIP2JVYX0>SXj02XZ:P18B4P0FUYJ04Y:BP1dM7@0WIfM02d];@0l
?3`0EUIF04Q8B02][Jd0WYjN02HV9P0d=3@0FUYJ04Y:BP2DU9@0EUIF01`L700l?3`0IfMW04m?C`23
Ph<0/;2`03<c<`1>CTh0EeMG06IVIP2][Jd0XJ6Q02HV9P13@d<0MWIf0861P@2ATI40Zj^[02l_;`14
A4@0PX:2092@T01fMWH0Y:BT04=3@`0[:b/0ATI605mOG`1TI6@0Rh^;059BDP18B4P0Jf][06UYJ@0i
>CT0Kfm_05IFEP0m?Cd0LG5a05QHF012@T80NGUi05EEE@1?Cdl0F5QH07inOP11@D40DU9B05QHF01L
G5`0NWYj05MGE`0S8b<0>3Ph05QHF01>CTh0M7Ad02HV9P0o?cl0@41005=CD`2=SHd0`L710410@00^
;Rh0IVIV06MWI`2KVi/00P0/;2`0CP1@D500I6AT05IFEP2HV9P0ATI602/[:`1dM7@0FEUI08F5Q@1]
KFd0=CDe04e=C@1IFET0HV9R06IVIP1MGEd0=CDe05IFEP1_Kfl0Bd];09:BTP12@T80;bl_06MWI`1I
FET0BDU907moO`0l?3`0<S8b06a/K02i^KT0JVYZ05eMG@1`L700<C4a06a/K01cLg<0CTi>09FEU@1_
Kfl0<S8b04m?C`1aLG40TI6A04E5A@1DE5@0<30`04e=C@2c/k<0L71`02/[:`10@400@D5104m?C`2N
WYh0NGUi02<S8`0l?3`0H61P05EEE@1YJFT0Jf][02PX:00R8R80HF5Q0492@P1IFET0O7al01lO7`0W
9bL0=3@d04i>CP0g=cL0F5QH02d];@0U9BD0>SXj051@D1cooooo0100M7Ad06ATI00_;bl0?3`l06MW
I`1KFe/0C4a<05]KF`1/K6`0?clo04E5A@1JFUX0IVIV07moO`1iNGT0OGem0P1MGEd02@1HF5P0CDe=
02DU9@16ATH0:2PX02`/;00j>SX0ATI605]KF`0304I6AP3Q03lo?`0i>CT0CDe=0451@@10@400D51@
04M7A`11@D40AdM7028R8P0O7al0<C4a04I6AP0g=cL09RHV038b<P11@D40;2`/02/[:`0e=CD0?clo
04A4A00h>3P0ATI602XZ:P14A4@0<c<c06=SH`0b<S80;bl_03`l?00h>3P0E5AD04E5A@1@D500AdM7
04Q8B01DE5@0Cdm?0492@P16ATH0A4A404E5A@0o?cl0>SXj05=CD`0];Bd0?3`l05IFEP1KFe/0DU9B
05YJFP1>CTh0Bd];04M7A`0f=SH0JVYZ02DU9@0o?cl0<c<c04I6AP0g=cL0?clo04a<C00d=3@0ADE5
02XZ:P0i>CT0Bd];02PX:019BDT0?clo03Ph>013@d<0=SHf03Xj>P12@T80>c/k0451@@1OGel0@T92
04=3@`1BDU80A4A4069RHP1EEED0A4A4055AD@0c<c<0<C4a0492@P1DE5@0@D5105=CD`1>CTh0B4Q8
07UiN@2FUYH0I6AT07alO01HF5P0GEeM018B4P1PH600GUiN03Lg=`1^KVh0>3Ph05YJFP1CDe<0<S8b
03@d=01:BTX09BDU069RHP0b<S80L71`0492@P23Ph<0DU9B055AD@1ZJVX0FUYJ03dm?@0/;2`0F5QH
07emO@1/K6`0>3Ph05=CD`0P8200IfMW07moO`19BDT0De=C038b<P1FEUH0?3`l05ADE01IFET0KVi^
04=3@`14A4@0KVi^05iNGP1^KVh0Rh^;04I6AP1<C4`0?clo05MGE`1JFUX0DU9B04M7A`1KFe/0@D51
04Q8B01MGEd0<c<c04E5A@0f=SH0DE5A04];B`1bLW80SXj>051@D01KFe/0F5QH0451@@0Y:BT0CDe=
03Hf=P1HF5P0EEEE04A4A01DE5@0A4A406EUI@1dM7@0QHF501/K6`10@400LG5a07YjNP1/K6`0?3`l
04I6AP14A4@0?clo04Y:BP1@D500EUIF04E5A@0d=3@0Fe]K04=3@`1VIVH0?Shn05eMG@0O7al0IVIV
04e=C@0e=CD0FUYJ03Lg=`1cLg<0DE5A05YJFP1QHF40E5AD04i>CP1JFUX0GUiN04=3@`1BDU80:b/[
04i>CP0a<C40AdM704=3@`1bLW80@T9206EUI@1^KVh0?3`l0080?Cdm0240:b/[04a<C01=CDd0GEeM
06][J`1KFe/0HV9R07moO`1kNg/0Fe]K075aL@1hN7P0SHf=06i^KP1kNg/0IVIV061PH00m?Cd0EEEE
03De=@15ADD06ATI0451@@0f=SH0EEEE06ATI01CDe<0B4Q804m?C`1ADE40GEeM07alO01OGel04Ooo
ool000oooooo0?`0]KFe059BDP1BDU80LG5a07EeM@0f=SH0De=C055AD@19BDT0Fe]K07emO@0R8R80
<C4a06=SH`1IFET0Kfm_05=CD`0Y:BT0AdM708n?S`1FEUH0B4Q804m?C`0J6QX0C4a<09jNWP11@D40
J6QX03Ti>@0O7al0F5QH08^;R`0n?Sh0BTY:02TY:@0W9bL0Jf][096AT@0X:2P0>SXj05MGE`16ATH0
=SHf08>3P`0V9RH0:2PX03Lg=`11@D40WIfM0:FUY@1;Bd/05ADE04E5A@1EEED0][Jf07]kN`0W9bL0
ATI60820P01SHf<0RHV90:VYZ@0`<300Cdm?07inOP1cLg<0LW9b08f=S@0h>3P08b<S04A4A01RHV80
FEUI02l_;`0Q8B40@T9208Z:RP1aLG40EeMG07EeM@0V9RH0;2`/08f=S@13@d<0ADE5069RHP0d=3@0
A4A407QhN02ATI40E5AD04i>CP0`<300BDU908B4Q02HV9P09bLW03Lg=`1=CDd0>SXj05EEE@1iNGT0
8b<S04a<C01WIfL0IVIV08^;R`1`L7008b<S02TY:@1=CDd0IFEU08>3P`1TI6@0:b/[04U9B@1XJ6P0
Cdm?06EUI@23Ph<0>CTi04Y:BP1_Kfl0Lg=c05]KF`2YZJT0FEUI03`l?01GEeL0P820071`L026QXH0
<S8b03Lg=`1SHf<0RXZ:05=CD`1mOGd0PX:202TY:@1HF5P0Rh^;07YjNP1gMgL0?Cdm02d];@0f=SH0
X:2P0;Rh^01fMWH0BDU902/[:`1/K6`0g]kN08f=S@1EEED0MWIf038b<P0d=3@0T92@05QHF00o?cl0
BTY:02LW9`1IFET0[jn_06e]K@0];Bd0Bd];04Y:BP1NGUh0];Bd0:VYZ@0e=CD0CDe=07=cL`1=CDd0
UiNG06i^KP19BDT0DU9B05iNGP1_Kfl0/;2`07emO@0h>3P0GEeM07=cL`2?Shl0R8R8028R8P0e=CD0
ADE50820P01ADE40Ph>305eMG@0W9bL0Lg=c04a<C01SHf<0Ph>3024Q8@0h>3P0]kNg09:BTP17AdL0
BTY:03<c<`1^KVh0PX:203Lg=`1`L700>c/k03dm?@1oOgl0WinO04a<C01EEED0<S8b0451@@1_Kfl0
>c/k04M7A`1BDU80;2`/0492@P1bLW809bLW06ATI019BDT0E5AD07IfMP1_Kfl0;Bd]04M7A`1ADE40
QHF50;6a/@1IFET092@T03lo?`1^KVh0H61P08j>SP2BTY80=cLg04];B`1LG5`0@D5109RHV02QXJ42
03Xj>P0T04U9B@23Ph<0RHV90:b/[017AdL0;Rh^069RHP2VYZH0Shn?09FEU@1@D500;Bd]06i^KP2I
VIT0H61P07moO`1fMWH08R8R04I6AP1/K6`0H61P04e=C@1NGUh08b<S04M7A`1fMWH0De=C03@d=01E
EED0>CTi01dM7@1MGEd0EUIF01dM7@1;Bd/0@D517?ooool0;01JFUX0HV9R04I6AP0n?Sh0BTY:04A4
A01<C4`0BTY:059BDP1?Cdl0?clo05EEE@1nOWh0MWIf071`L01IFET0EeMG06=SH`1=CDd0BTY:03<c
<`17AdL0?Cdm04=3@`0k>c/0<c<c03`l?01?Cdl0J6QX08F5Q@1GEeL0?3`l04M7A`1FEUH0@T9204e=
C@1OGel0FEUI04];B`0b<S808B4Q02h^;P0Y:BT0?clo0P0l?3`0;@0X:2P0>3Ph03dm?@13@d<0;2`/
04M7A`0V9RH0>SXj02d];@0c<c<09BDU04=3@`0^;Rh0>CTi03lo?`0`<300<S8b04e=C@14A4@0G5aL
04i>CP1aLG40IfMW03Ph>010@400EeMG05eMG@0V9RH0<C4a04a<C00Y:BT08B4Q04m?C`18B4P0A4A4
0492@P11@D40?Shn03Ti>@0[:b/0C4a<03<c<`16ATH0;Bd]02HV9P0203lo?`0I03De=@0b<S80?Shn
02`/;00P8200;Bd]03Lg=`0h>3P0;Rh^04a<C010@400BDU9034a<@15ADD0<30`05YJFP1RHV80BTY:
04m?C`1HF5P0GEeM09JFUP1DE5@0DE5A05EEE@0304E5A@0h05EEE@0X:2P0?clo04a<C00e=CD0Cdm?
06e]K@12@T80QXJ6059BDP1IFET07QhN07MgM`20P800DE5A06a/K00m?Cd0AdM7061PH011@D40>3Ph
05MGE`0a<C40@d=3028R8P0i>CT0A4A40;>c/`20P800JVYZ04E5A@1;Bd/0EEEE03`l?00_;bl0A4A4
04m?C`0a<C40=SHf01hN7P1oOgl0Hf=S03@d=01OGel09BDU03dm?@0[:b/0De=C05mOG`1<C4`0ADE5
03/k>`1eMGD0FUYJ065QH@20P80204=3@`0R03hn?P1JFUX0DU9B04a<C01OGel0PH61061PH01EEED0
D51@03<c<`1;Bd/0A4A405ADE01:BTX0W9bL0::RXP1ADE40FUYJ04Y:BP1LG5`0@T9205ADE00`<300
N7Qh06ATI018B4P0EeMG04Y:BP1kNg/0Ogmo08Z:RP0];Bd0:b/[09VIV@80C4a<04/0MWIf061PH01I
FET0C4a<065QH@1NGUh0GEeM051@D01<C4`0J6QX051@D01RHV80Hf=S07moO`1DE5@0HV9R06QXJ01C
De<0JVYZ04=3@`2?Shl0ADE504i>CP0k>c/0;bl_04Q8B00a<C40<S8b03lo?`1LG5`0:b/[05=CD`1B
DU80CDe=05IFEP1>CTh0G5aL05=CD`1UIFD0>3Ph04Q8B012@T80=SHf04a<C01GEeL0I6AT07=cL`1V
IVH0JFUY08>3P`22PX80P820051@D01bLW80MWIf061PH01]KFd0ATI606ATI01NGUh0KVi^04e=C@1@
D500:b/[05]KF`16ATH0MWIf06][J`19BDT0D51@05=CD`1=CDd0Fe]K04m?C`1@D5004Oooool000oo
oooo0?l0W9bL079bLP20P800EEEE06e]K@1>CTh0@410071`L01@D500EeMG0;bl_025QHD0>3Ph04a<
C011@D40Z:RX06e]K@0U9BD0:BTY051@D00e=CD0IFEU09NGU`0U9BD0<c<c04E5A@1UIFD0b<S803lo
?`0Y:BT0=cLg069RHP1KFe/0WYjN02PX:015ADD0?Cdm07IfMP10@400ZJVY0=cLg00Q8B408R8R07Ui
N@2<S8`0Ti>C09ZJVP0C4a<0BDU908V9R@2JVYX0BDU90820P00_;bl0AdM707AdM010@400FEUI03Hf
=P0F5QH0>CTi04E5A@0h>3P0CTi>02`/;00M7Ad0LG5a08Z:RP1JFUX0=3@d05]KF`0V9RH0EUIF06YZ
JP0L71`0<C4a0451@@1EEED0Lg=c08f=S@1>CTh06ATI04=3@`1/K6`0GemO09RHV00c<c<06ATI03Ph
>01/K6`0G5aL09bLW00L71`09RHV04a<C029RHT0Hf=S0:2PX02BTY80;Bd]04A4A020P800LG5a0;Rh
^01dM7@0;2`/06a/K01bLW80IVIV06e]K@2g]kL0<S8b06=SH`1TI6@0>3Ph069RHP1PH600?Cdm03Ph
>01iNGT0DE5A05]KF`1WIfL0:2PX0492@P1QHF40Hf=S02XZ:P1CDe<0EEEE04];B`2GUiL0G5aL03Lg
=`1SHf<0E5AD03<c<`2GUiL0fm_K04];B`17AdL0<S8b04A4A02/[:`0UIFE02TY:@0g=cL0G5aL04Q8
B02>SXh0@d=302l_;`10@400VIVI08>3P`1dM7@0[Zj^03<c<`0j>SX0H61P08F5Q@2<S8`0L71`01lO
7`0Z:RX0Bd];0861P@1;Bd/0JFUY05=CD`0[:b/0E5AD0:b/[01TI6@0Ng]k02l_;`0];Bd0?Cdm05UI
F@1FEUH0H61P020P800c<c<0BDU907MgM`0c<c<0C4a<04I6AP0m?Cd0XJ6Q05mOG`1=CDd0IFEU03hn
?P0e=CD0P82009nOW`15ADD0>3Ph04=3@`1eMGD0Shn?05QHF00a<C40GUiN03Ph>01kNg/0P82002d]
;@14A4@0Bd];05EEE@2l_;`0Fe]K024Q8@1:BTX0KVi^07emO@2QXJ40>c/k03Lg=`1BDU80ATI60::R
XP2@T900820P04I6AP1FEUH0CDe=0;no_`1DE5@0:2PX08R8R02TY:@0Bd];09BDU01QHF40>SXj07al
O028R8P0GUiN07moO`13@d<0>c/k03hn?P24Q8@0IFEU06QXJ00V9RH0;2`/05ADE01RHV80GUiN04];
B`1PH60002<0CTi>03/k>`1TI6@0GEeM05ADE025QHD0=CDe03<c<`2BTY80PX:203/k>`1OGel0@T92
0410@02;Rh/0L71`02LW9`0^;Rh0AdM705=CD`1MGEd0LG5a02XZ:P0O7al0BTY:05=CD`1MGEd0WIfM
06IVIP0E5AD0=3@d071`L00k>c/0UIFE08B4Q00Looooo`1H05mOG`1WIfL0<30`03@d=01EEED0Bd];
03/k>`1eMGD0RXZ:03Lg=`1?Cdl0GEeM05aLG01JFUX0NWYj05IFEP1`L700B4Q803hn?P14A4@0>3Ph
04I6AP0e=CD0<C4a0492@P0l?3`0A4A402@T900N7Qh0;bl_03`l?00f=SH0<c<c03lo?`0m?Cd0@T92
03@d=00_;bl0Bd];03/k>`0n?Sh0;2`/03De=@0n?Sh0A4A403@d=00b<S80BTY:04e=C@0i>CT0>3Ph
04i>CP0m?Cd0Bd];02DU9@0n?Sh08B4Q04Y:BP0R8R807QhN02TY:@0h>3P0@41002HV9P0^;Rh0BTY:
03@d=01BDU80EeMG05]KF`1SHf<0E5AD04E5A@0n?Sh0?Cdm069RHP0U9BD0;2`/06EUI@19BDT0C4a<
05MGE`1@D500DE5A0451@@0a<C40GemO02DU9@80=cLg00/0>c/k0492@P0m?Cd0ATI603hn?P10@400
;2`/03<c<`14A4@08b<S04Y:BP02038b<P0[0492@P0Z:RX0?Cdm0492@P0W9bL0>3Ph0492@P1>CTh0
BDU903dm?@16ATH0De=C03`l?016ATH0B4Q803De=@0`<300>3Ph04Y:BP0l?3`0Bd];05EEE@12@T80
L71`06i^KP0g=cL0NWYj05MGE`25QHD0@41004Q8B01EEED0?clo0820P01:BTX0BDU904m?C`1>CTh0
<C4a07moO`0k>c/0DE5A034a<@02055AD@0807inOP1QHF40DE5A061PH01EEED0JVYZ03Xj>P12@T82
05iNGP1B02XZ:P1TI6@0:RXZ06a/K01^KVh0>c/k03Xj>P0J6QX0CTi>03Ph>014A4@0DE5A069RHP0i
>CT0<c<c06QXJ01BDU80Jf][08Z:RP13@d<0<S8b030`<01EEED0D51@04I6AP1GEeL0TY:B04Y:BP1P
H600D51@03Ti>@1;Bd/0GEeM07=cL`14A4@0H61P06i^KP17AdL0N7Qh05ADE00d=3@0:2PX06UYJ@0n
?Sh0A4A403/k>`1BDU80Bd];04Q8B01eMGD0Lg=c092@T01XJ6P0>c/k08V9R@1MGEd0CDe=04U9B@1Q
HF40AdM7034a<@1QHF40BTY:05EEE@13@d<0>c/k065QH@14A4@0S8b<05YJFP1fMWH07AdM075aL@1[
Jf/0BTY:07MgM`0^;Rh0JVYZ02l_;`0Y:BT0:2PX02HV9P80@T9201D0Bd];0492@P10@400A4A405MG
E`1LG5`0De=C04=3@`1;Bd/0CDe=061PH01RHV80?Cdm06EUI@14A4@0=3@d059BDP1GEeL0I6AT08b<
S01XJ6P00P1dM7@06@2;Rh/0L71`03Ph>01dM7@0NGUi06e]K@1aLG40@d=305MGE`0X:2P0C4a<04Y:
BP1NGUh0;2`/0451@@10@400WinO0:>SX`1ADE40DU9B06=SH`1ADE40F5QH05EEE@1QHF404Oooool0
00oooooo0:P0Hf=S06EUI@2XZ:P0O7al05MGE`1kNg/0IFEU09FEU@0h>3P0CTi>06][J`2?Shl0W9bL
0=7Ad@0h>3P0>c/k07moO`26QXH0Ti>C08B4Q00^;Rh0@T9204e=C@1:BTX0L71`0492@P0`<300QHF5
08V9R@0d=3@0CTi>03lo?`0W9bL0IFEU0451@@0];Bd0EEEE03dm?@0O7al0<C4a08^;R`1/K6`0;Rh^
04M7A`0];Bd0EEEE07emO@0X:2P0=cLg04U9B@1DE5@0PX:20::RXP0Y:BT0?Shn04A4A00l?3`0Ph>3
09BDU00R8R80:2PX05iNGP1IFET0[jn_06e]K@0M7Ad0=SHf07moO`2=SHd0GEeM09FEU@0];Bd0<C4a
08^;R`1?Cdl0Ph>3071`L00G5aL0=SHf04e=C@1FEUH0ATI606UYJ@0I6AT0<30`05IFEP1SHf<0:2PX
06a/K01HF5P06ATI065QH@1ADE40<S8b06UYJ@0l?3`0=SHf05eMG@28R8P0BTY:03dm?@0l?3`0<C4a
05YJFP29RHT0A4A406ATI01[Jf/0;Bd]04U9B@2][Jd0GemO04E5A@1RHV80ATI607MgM`2DU9@0;Bd]
030`<016ATH0GEeM0:JVYP30`<00<30`02d];@1ADE40S8b<04];B`2HV9P0SXj>02d];@1cLg<0SHf=
0410@02ATI40BTY:03@d=013@d<0LW9b07UiN@1hN7P09BDU03Hf=P0l?3`0QhN706][J`18B4P0JVYZ
02l_;`1IFET0Kfm_03`l?01=CDd0@T9203<c<`1IFET0K6a/065QH@1@D500J6QX02TY:@20P800_;bl
06UYJ@0g=cL0DE5A04I6AP0h>3P206][J`0o02/[:`1@D500CTi>04i>CP2WYjL0JFUY01XJ6P0o?cl0
G5aL07=cL`2g]kL0<C4a02LW9`1MGEd0IfMW059BDP1oOgl0R8R802d];@1IFET0JVYZ06QXJ02YZJT0
<30`02d];@11@D40HF5Q05eMG@2>SXh06QXJ05MGE`2UYJD0Zj^[06ATI02XZ:P0;Bd]04Y:BP1cLg<0
DU9B06i^KP0V9RH08b<S06e]K@1iNGT0I6AT07IfMP0a<C40<c<c07YjNP1EEED0H61P04E5A@0/;2`0
K6a/0;^k^`1MGEd0CDe=04=3@`16ATH0TI6A06QXJ014A4@0IFEU0080@T9203L0GUiN06][J`10@400
CTi>04a<C01PH600PH6107=cL`0f=SH0ATI605YJFP1OGel0R8R804I6AP0U9BD0CTi>05]KF`1LG5`0
JVYZ07IfMP2[Zj/0>SXj05]KF`1>CTh0RHV90=3@d00l?3`08b<S05UIF@1]KFd0QhN70:BTY00Z:RX0
C4a<06UYJ@1cLg<0DE5A065QH@1hN7P07alO02l_;`1XJ6P0@T9204i>CP1<C4`07QhN02d];@17AdL0
IFEU0410@01>CTh0<C4a02`/;01<C4`0GEeM01cooooo0?l0L71`04Q8B00R8R80?Shn079bLP1ADE40
>CTi0410@00k>c/0<S8b03<c<`1=CDd0IVIV061PH01`L700DU9B07=cL`1DE5@0FUYJ04=3@`0G5aL0
@410020P800`<300AdM705=CD`17AdL0De=C065QH@1NGUh0De=C03`l?01RHV80LW9b051@D01:BTX0
HF5Q04a<C01MGEd0=CDe03Ph>014A4@0=SHf0451@@0n?Sh0DE5A03<c<`0i>CT0=cLg04a<C00h>3P0
?Cdm02`/;00g=cL08B4Q03`l?00d=3@0EEEE02LW9`0T92@0;2`/02/[:`0d=3@0<30`04a<C01=CDd0
BTY:06=SH`1KFe/09RHV02XZ:P1BDU80ADE503/k>`1EEED0A4A401hN7P0U9BD0CDe=069RHP1@D500
@T9203@d=012@T80=SHf02d];@0i>CT0820P03De=@0];Bd0?Cdm03@d=00c<c<0?clo03Ti>@0o?cl0
820P03De=@0h>3P0<C4a0492@P0g=cL0?Cdm04=3@`1>CTh0?clo055AD@0`<300@d=304e=C@13@d<0
ATI6051@D016ATH0NWYj03lo?`1EEED0De=C02l_;`0k>c/0=3@d04U9B@0R8R80=cLg04U9B@0l?3`0
Fe]K07AdM00];Bd0GemO05aLG01dM7@09BDU05]KF`1@D500=CDe05eMG@0h>3P0RHV905mOG`0o?cl0
=SHf04A4A00i>CT0NWYj02d];@0Z:RX0?Shn0:>SX`1cLg<0Cdm?06e]K@1DE5@0BTY:02`/;00n?Sh0
Hf=S061PH00W9bL0AdM700D51@22PX80IfMW030`<01CDe<0;Rh^04];B`0n?Sh0ADE505IFEP1:BTX0
=SHf02h^;P1TI6@0B4Q80451@@1OGel0=cLg055AD@0f=SH0F5QH06YZJP1?Cdl0@D5106][J`0f=SH0
MGEe06IVIP0Q8B408R8R02@T9014A4@0<c<c09fMW@2VYZH0A4A404E5A@17AdL0Fe]K03Lg=`0n?Sh0
>3Ph079bLP1QHF40@T9204M7A`1?Cdl0NGUi07IfMP2GUiL0GUiN04E5A@1MGEd0?Cdm05=CD`1HF5P0
HF5Q04M7A`10@400EeMG059BDP1OGel0Cdm?0451@@1nOWh0DU9B04i>CP1@D500Ph>30492@P16ATH0
CTi>03Ph>01NGUh0?3`l06][J`1=CDd0ATI603De=@0n?Sh0D51@061PH025QHD0F5QH05aLG00j>SX0
EEEE03lo?`1>CTh0BTY:05=CD`1<C4`0GemO08N7Q`1ZJVX001X0?clo04Y:BP1JFUX0GemO07=cL`1F
EUH0J6QX05YJFP2ATI40O7al06m_K`1RHV80A4A408N7Q`1KFe/0O7al065QH@1SHf<0OGem04A4A01Y
JFT0DU9B06QXJ00f=SH0EUIF03Ti>@80LG5a00D0FEUI03dm?@1>CTh0ADE504M7A`0205UIFA7ooooo
000?ooooo`2L09FEU@1>CTh0DE5A09FEU@1TI6@0?clo04Y:BP1XJ6P0G5aL0410@01]KFd0=CDe03/k
>`1hN7P0BTY:04U9B@0b<S80:2PX05]KF`2IVIT0;Bd]03Ti>@1:BTX0?Shn06e]K@14A4@07QhN04=3
@`1OGel0Cdm?08j>SP1QHF409bLW038b<P12@T80Cdm?0:n_[`1cLg<09bLW02<S8`13@d<0HV9R05QH
F02CTi<0<30`05mOG`1SHf<0?clo06m_K`39bLT0<C4a02l_;`2EUID0LG5a08V9R@0n?Sh0:BTY051@
D02LW9`0G5aL06=SH`1XJ6P092@T04];B`1IFET0;bl_05MGE`1DE5@0;2`/05IFEP1jNWX0Fe]K04e=
C@0f=SH0<S8b0451@@23Ph<0>CTi03/k>`1]KFd0:BTY04E5A@1]KFd06ATI02TY:@1LG5`0EeMG06QX
J02DU9@0VIVI02LW9`0k>c/0@41006=SH`2^[Zh0BDU9034a<@19BDT0DE5A04Y:BP1^KVh0Lg=c02LW
9`1IFET0SHf=06UYJ@2FUYH0S8b<0451@@0a<C40?Shn06IVIP2CTi<0M7Ad020P8012@T80De=C06QX
J015ADD0JFUY03De=@1>CTh0LG5a05iNGP1?Cdl0QhN704=3@`0g=cL0HF5Q07AdM01;Bd/0FUYJ034a
<@15ADD0EEEE07alO00e=CD0HF5Q06=SH`0_;bl0PH61051@D00^;Rh0De=C05iNGP1MGEd0MgMg0:VY
Z@0h>3P0Cdm?05mOG`1DE5@0O7al0861P@0W9bL0ATI60P27QhL0Q01CDe<0QXJ60410@00_;bl0M7Ad
07alO01OGel0SXj>02`/;00j>SX0>c/k07IfMP1jNWX0T92@02XZ:P0j>SX0AdM706UYJ@14A4@0MgMg
05QHF01<C4`0Ng]k07EeM@15ADD0LG5a05QHF01:BTX0DE5A0::RXP1EEED0ADE503dm?@1:BTX0PH61
0:6QX@0n?Sh0HV9R04i>CP0e=CD0MGEe03<c<`0^;Rh0<C4a03Ph>01NGUh0Shn?06ATI00/;2`0B4Q8
065QH@33`l<0B4Q802HV9P1@D500<c<c061PH02i^KT0IVIV034a<@1NGUh0KVi^0;Zj^P24Q8@0<30`
0410@01IFET0D51@08R8R01IFET0>c/k06EUI@1`L700GemO0:j^[P1dM7@09bLW05QHF01QHF40L71`
05UIF@11@D40BDU906YZJP2NWYh0NGUi08n?S`2HV9P0DE5A09BDU01oOgl0D51@0:^[Z`2=SHd0?Shn
03Lg=`1EEED0NWYj05MGE`1XJ6P0<c<c03Ti>@2WYjL0];Bd04e=C@1dM7@0@D5104Y:BP2MWId0Jf][
03Hf=P21PH40?Cdm03/k>`1JFUX0/K6a06QXJ00d=3@0Bd];03@d=01EEED0Shn?02`/;00O7al0<c<c
061PH011@D40PH6103Ti>@0V9RH0BTY:04m?Cacooooo0>l0Q8B406][J`11@D40>SXj04U9B@1CDe<0
@41005QHF01CDe<061PH03Hf=P1=CDd0OWin06YZJP1EEED0BTY:06QXJ01JFUX0CTi>05=CD`0k>c/0
A4A403Lg=`12@T80ADE503De=@11@D40CTi>06UYJ@21PH40Bd];03@d=01CDe<0JVYZ04m?C`1EEED0
GUiN06IVIP1DE5@0>SXj03Ph>00f=SH0@D5105=CD`1bLW80De=C04M7A`1:BTX0G5aL04e=C@0a<C40
EEEE03<c<`10@4007alO02d];@0M7Ad0@41004m?C`0/;2`0=SHf04Y:BP1<C4`0;Rh^05IFEP1=CDd0
HV9R06ATI01ZJVX0?Shn04E5A@1`L700DE5A02`/;00Y:BT0;2`/02d];@0k>c/0Bd];0451@@14A4@0
DU9B04a<C01ADE40EUIF04M7A`1=CDd0<C4a03Xj>P0i>CT0=3@d04U9B@12@T80ADE50410@00n?Sh0
<c<c02l_;`1<C4`0;Rh^04m?C`0l?3`0<S8b03Ph>00];Bd0<C4a0492@P0/;2`0Fe]K05EEE@12@T80
C4a<05IFEP16ATH0JFUY03De=@0b<S80<c<c03De=@17AdL0;Rh^038b<P0/;2`0=cLg04I6AP0_;bl0
B4Q804m?C`0o?cl0ZZZZ061PH023Ph<08B4Q06][J`1gMgL0BTY:05eMG@0k>c/0Fe]K06][J`0l?3`0
=CDe05=CD`17AdL0DE5A03<c<`0n?Sh0A4A4075aL@1mOGd0IFEU06a/K01@D500EEEE024Q8@0h>3P0
C4a<05mOG`0V9RH0EUIF020P801@D500Jf][034a<@1kNg/071`L05mOG`0/;2`0;bl_03`l?01iNGT0
B4Q802d];@1FEUH0>SXj061PH01`L7006ATI0410@00W9bL0B4Q8059BDP16ATH0E5AD0:NWY`0l?3`0
@d=304U9B@0_;bl0>SXj04I6AP1NGUh0=SHf04e=C@1NGUh0CTi>051@D01=CDd0?3`l03/k>`1?Cdl0
=3@d04U9B@0i>CT0CTi>0492@P10@400GUiN04m?C`1;Bd/0=cLg03hn?P1BDU80BDU904i>CP1CDe<0
H61P05EEE@0j>SX0Fe]K04Y:BP1BDU80CDe=04Y:BP1SHf<0ADE506QXJ01LG5`0GemO04E5A@1EEED0
HF5Q04e=C@1VIVH0ADE509:BTP1WIfL0BTY:04E5A@0305IFEP0Y065QH@0g=cL0ADE504A4A01>CTh0
BTY:04i>CP1<C4`0Ph>307UiN@1?Cdl0C4a<01hN7P13@d<0CDe=03lo?`1:BTX0H61P051@D01[Jf/0
DU9B055AD@1NGUh0SXj>05aLG01WIfL0/[:b05aLG01cLg<0CDe=03Lg=`1KFe/0;2`/03lo?`14A4@0
HV9R03dm?@0o?cl0=3@d096AT@1nOWh00P17AdL01@1OGel0BDU906ATI01QHF40Fe]K017ooooo000?
ooooo`210:>SX`1QHF40EUIF05aLG02ATI40EUIF0492@P1ADE40EeMG079bLP2^[Zh0AdM7038b<P1<
C4`0F5QH0;no_`1XJ6P092@T04];B`1DE5@0CDe=09BDU01aLG405ADE04i>CP1RHV80EEEE0;>c/`0Q
8B40;bl_065QH@1IFET0GemO05QHF00J6QX0:2PX02l_;`1NGUh0?Shn07moO`1YJFT08R8R03/k>`23
Ph<0:BTY04a<C01FEUH06QXJ05UIF@2`/;00HV9R03Ph>01MGEd0=cLg08b<S00k>c/07AdM03De=@1P
H600<c<c05YJFP2ATI408R8R03<c<`13@d<0:b/[09>CT`2KVi/0B4Q802PX:01DE5@0GUiN08>3P`1O
Gel0820P0410@015ADD0EUIF06UYJ@3Hf=P0ADE502<S8`1`L700>3Ph05UIF@25QHD0?3`l01/K6`1V
IVH0Lg=c0451@@1MGEd0=3@d03Hf=P2>SXh0];Bd04Q8B01KFe/0AdM702LW9`15ADD0Ng]k04E5A@1M
GEd0?Shn03<c<`1RHV80QhN70451@@13@d<0EEEE04A4A01iNGT0UIFE03De=@0^;Rh0>c/k04I6AP1o
Ogl0Xj>S03Ti>@0m?Cd0O7al05EEE@1lO7`0g]kN08f=S@0O7al0?3`l0080IfMW0340b/[:04A4A00n
?Sh0E5AD05MGE`1JFUX0VYZJ0;Bd]00o?cl0JFUY08>3P`1;Bd/0Ogmo04m?C`0n?Sh0EEEE09:BTP21
PH40PX:202d];@1ADE40MgMg0;Bd]01]KFd0D51@04e=C@0d=3@0BDU908f=S@1GEeL0LG5a05aLG016
ATH0BDU909jNWP23Ph<0>3Ph05QHF00n?Sh0D51@0;fm_@1eMGD0?3`l05mOG`0j>SX0>CTi05aLG01N
GUh0?Cdm0080AdM703D0EeMG096AT@1VIVH09bLW04];B`1UIFD0Hf=S08:2PP0Q8B40?Cdm06MWI`1_
Kfl0PH610:FUY@1_Kfl06QXJ069RHP0m?Cd0IFEU05QHF00M7Ad0;Bd]079bLP21PH40D51@06=SH`0c
<c<0HV9R07EeM@1ADE40QhN7028R8P0f=SH0CTi>07alO01;Bd/0BDU902l_;`1JFUX0Ng]k04Q8B01f
MWH0L71`02HV9P1=CDd0GEeM05EEE@1`L700:RXZ03Ti>@1NGUh0QXJ605EEE@02065QH@0e07emO@2X
Z:P0Hf=S0451@@1<C4`0ADE504=3@`1:BTX0LW9b04];B`1EEED0?Cdm03Lg=`1fMWH0WinO051@D00/
;2`0ATI6061PH029RHT0/k>c04];B`0c<c<0DE5A08V9R@1oOgl0Xj>S06ATI00n?Sh0NWYj08Z:RP1K
Fe/0h^;R05MGE`0N7Qh0@T9204U9B@2h^;P0MWIf06=SH`0];Bd0ATI604U9B@1QHF40@41004m?C`0]
;Bd0;bl_03Ti>@25QHD0=CDe05mOG`1KFe/07?ooool0C021PH40LW9b02HV9P0a<C40F5QH0492@P0b
<S80HF5Q06m_K`0^;Rh0DU9B05ADE01CDe<0DE5A06UYJ@1=CDd0JFUY05iNGP15ADD0?Cdm020P801C
De<0>3Ph034a<@10@400BDU904=3@`1FEUH0GUiN05EEE@10@4009bLW055AD@1NGUh0C4a<05=CD`1O
Gel0AdM7055AD@0g=cL0ATI604e=C@0a<C40ATI60492@P1@D500=SHf04i>CP1QHF40@D5104=3@`1D
E5@0=cLg04m?C`0d=3@0BTY:02PX:01PH600<C4a05=CD`1<C4`0BDU904i>CP0l?3`0E5AD06EUI@19
BDT0KVi^079bLP11@D40ADE5075aL@1OGel0Bd];04e=C@0/;2`201/K6`3D04Y:BP1KFe/0HF5Q03lo
?`17AdL0CDe=03Lg=`0l?3`0BDU903`l?016ATH0?3`l05YJFP1?Cdl0?Cdm04a<C019BDT0>3Ph02DU
9@1BDU80DE5A02`/;00k>c/0DE5A03Ph>01?Cdl0@T9204A4A01=CDd0=CDe04A4A015ADD0@d=304U9
B@1:BTX0Bd];07MgM`1@D500M7Ad061PH00h>3P0?clo038b<P0`<300=SHf0451@@14A4@0<30`04=3
@`19BDT0>c/k05IFEP13@d<0UYJF04M7A`1mOGd0G5aL051@D021PH40A4A405IFEP1CDe<0>CTi069R
HP2CTi<092@T05MGE`0`<300Bd];05MGE`2<S8`0IfMW05IFEP1NGUh0F5QH071`L00o?cl0BTY:055A
D@1QHF4071`L0820P00;2`/0I6AT05]KF`0[:b/0Cdm?01PH6015ADD092@T02d];@0g=cL0CTi>03Ti
>@0K6a/0@T9204i>CP18B4P0Cdm?02d];@1?Cdl0>3Ph055AD@1;Bd/0@41003De=@1XJ6P0;Bd]06AT
I01/K6`0:RXZ03`l?00a<C40>SXj030`<01MGEd0Hf=S03lo?`1VIVH0?Cdm0492@P0b<S80BDU902`/
;01WIfL0@d=303Lg=`0X:2P0=3@d06=SH`1BDU80L71`03@d=00];Bd0M7Ad04M7A`1:BTX0G5aL06MW
I`1OGel0>c/k05EEE@1>CTh0GEeM04=3@`0o?cl0KFe]04M7A`2>SXh0HV9R08V9R@1<C4`0LG5a07Ee
M@1HF5P0KFe]02@T901jNWX0IfMW04A4A01KFe/0DE5A03`l?00m?Cd0BTY:03@d=01=CDd07alO02h^
;P0Z:RX0=3@d04A4A01>CTh0@D5105]KF`1^KVh06a/K04I6AP1IFET0CDe=03hn?P17AdL0Fe]K08Z:
RP1[Jf/0Cdm?04Y:BP1=CDd0Bd];04i>CP2GUiL0>c/k05IFEP15ADD0@41005mOG`0g=cL0ATI603@d
=01ZJVX0<C4a03hn?P11@D40RXZ:07YjNP1:BTX0DU9B05]KF`1EEED0E5AD055AD@1SHf<Aooooo`00
3oooool05`2IVIT0OWin09jNWP1ADE40HF5Q09nOW`1gMgL0W9bL03`l?01?Cdl0SXj>08B4Q01IFET0
IfMW02`/;01NGUh0OGem03/k>`1@D500DE5A03`l?019BDT0T92@0080?Shn0600?clo05IFEP2OWil0
CTi>02@T900l?3`0?Shn0492@P1bLW80ATI601/K6`0g=cL0<30`0451@@2JVYX0aLG502h^;P0/;2`0
HF5Q055AD@2`/;00JVYZ02d];@0^;Rh0Fe]K06a/K01@D500[Zj^02TY:@1KFe/0WinO05aLG02>SXh0
:RXZ02d];@0U9BD0GUiN05MGE`1]KFd0820P02XZ:P0m?Cd0L71`05iNGP1GEeL0J6QX01TI6@0l?3`0
I6AT02XZ:P1BDU80BTY:01lO7`0f=SH0MGEe08R8R00];Bd0@D5104M7A`0n?Sh0Kfm_03/k>`0O7al0
ATI605UIF@1CDe<0J6QX02@T900a<C40F5QH06e]K@1ZJVX0Zj^[06QXJ00Q8B40?Cdm05eMG@1NGUh0
WinO03@d=00P8200?3`l08F5Q@1nOWh0QHF50;Zj^P0/;2`0@T9208V9R@1ADE40TI6A07moO`0a<C40
<30`08>3P`1gMgL206a/K01B0451@@13@d<0O7al0=7Ad@20P800J6QX05]KF`0e=CD0Ogmo08F5Q@0n
?Sh0KFe]02h^;P0W9bL0DU9B09VIV@1WIfL0CTi>034a<@12@T80GUiN071`L00c<c<0IfMW05QHF012
@T80OWin03Xj>P0i>CT0G5aL04=3@`0f=SH0WYjN08N7Q`0Z:RX0:b/[06i^KP1?Cdl0Y:BT0;2`/00l
?3`0@T9204];B`1/K6`0E5AD0820P01DE5@0=3@d061PH02a/K40U9BD0;Fe]@0e=CD0?3`l04e=C@1]
KFd0PH6107YjNP0M7Ad0<S8b04a<C01jNWX0AdM705iNGP0n?Sh0B4Q807=cL`1FEUH0<c<c05eMG@0P
8200=3@d07MgM`1eMGD0>SXj04i>CP0R8R80HF5Q0:FUY@0g=cL08B4Q04];B`80A4A405<0LG5a03Ph
>01RHV80=SHf05IFEP2@T900BTY:02PX:01=CDd0Bd];071`L01aLG40=SHf0451@@1MGEd0BDU908R8
R02BTY807AdM0410@01JFUX0Ogmo0<S8b01?Cdl0:BTY06MWI`25QHD0E5AD0;>c/`1XJ6P0?Shn06m_
K`1oOgl0MWIf0<71`@1]KFd0>c/k03Xj>P1TI6@0PX:208>3P`19BDT0@410051@D023Ph<0R8R8059B
DP1kNg/0CTi>04I6AP2_[jl0YjNW06m_K`2UYJD0=3@d05eMG@1cLg<0R8R806UYJ@20P800>CTi059B
DP2PX:00XZ:R02h^;P0`<300GemO03@d=018B4P0IVIV02d];@0f=SH0C4a<03Hf=P0n?Sh0Ph>307Ad
M00P8200>3Ph05mOG`0n?Sh0RHV9096AT@0Looooo`0R06YZJP1CDe<0;bl_0492@P1UIFD0Bd];03Xj
>P1KFe/0A4A401TI6@0];Bd0CTi>07AdM01YJFT0IFEU05EEE@1UIFD0BDU90492@P0n?Sh06ATI03Hf
=P0V9RH0<30`03`l?00g=cL0DU9B06YZJP1VIVH0JFUY05ADE00i>CT0I6AT06MWI`80K6a/01T0KFe]
04m?C`1QHF409BDU03<c<`0g=cL0>CTi04Q8B01<C4`0HF5Q03`l?01:BTX0D51@04Y:BP0^;Rh0@D51
03Xj>P0g=cL07alO03@d=00I6AT0?Shn01XJ6P0Y:BT0<c<c0080=CDe04d09bLW0410@00h>3P0?clo
061PH01FEUH0CDe=065QH@1KFe/0A4A402@T900f=SH0;Rh^01lO7`0U9BD0GUiN04E5A@1<C4`0D51@
0451@@1;Bd/0?3`l04=3@`1=CDd092@T03<c<`0Y:BT0:2PX03dm?@0c<c<0>3Ph02/[:`0k>c/09RHV
02LW9`13@d<0:2PX04Q8B00j>SX09bLW03lo?`1FEUH0C4a<04Y:BP11@D40KFe]05iNGP0f=SH0?clo
04U9B@13@d<0GemO0492@P1BDU80?3`l02TY:@0m?Cd0CDe=05QHF00a<C40?Cdm061PH01MGEd0FUYJ
05iNGP1<C4`0J6QX06][J`29RHT05ADE05IFEP1RHV80@41005eMG@0k>c/0T92@07YjNP0203Ph>00[
059BDP0b<S80DU9B03<c<`0l?3`0:2PX09nOW`1iNGT0MWIf06QXJ01<C4`0Cdm?03<c<`0k>c/0B4Q8
05ADE00T92@0De=C00L71`1dM7@0Lg=c03dm?@1RHV80:BTY05IFEP0N7Qh09bLW03Hf=P1GEeL0EEEE
030`<00o?cl0@d=304U9B@1RHV808R8R06i^KP0m?Cd0?Shn05=CD`16ATH0I6AT09jNWP0204i>CP1W
04M7A`0V9RH0=3@d02h^;P14A4@09bLW079bLP1gMgL0<C4a038b<P0e=CD0AdM7038b<P0n?Sh06QXJ
03Ph>00i>CT0>c/k03dm?@0k>c/0AdM7055AD@1FEUH0<30`05MGE`2VYZH0GUiN05=CD`1@D500KVi^
059BDP1;Bd/0HV9R03Lg=`0l?3`0@D5104E5A@1CDe<0BDU908>3P`1WIfL0OGem04Q8B01IFET0H61P
038b<P1<C4`0<S8b04M7A`1?Cdl0@D5103`l?01;Bd/0EUIF038b<P1@D500:BTY0451@@0L71`0EEEE
03Ti>@10@400<30`03Ti>@0^;Rh0@d=304e=C@0U9BD0ADE504Q8B00`<300AdM7051@D01<C4`0DU9B
05ADE01^KVh0IVIV08B4Q01dM7@0A4A407YjNP10@400L71`05QHF018B4P0IFEU04a<C01KFe/0CDe=
06ATI00f=SH0O7al04m?C`2BTY80Ng]k05UIF@1;Bd/0I6AT04U9B@1RHV80GUiN05eMG@0Aooooo`00
3oooool0A`1OGel0LW9b08^;R`26QXH0BTY:05iNGP1<C4`0RHV903De=@0m?Cd0ATI606m_K`2;Rh/0
/[:b02`/;01>CTh0GemO06UYJ@2TY:@0WIfM024Q8@1;Bd/0JVYZ05=CD`2>SXh0?Cdm02l_;`1JFUX0
SHf=069RHP2=SHd0DE5A038b<P1ADE40EUIF059BDP2=SHd0B4Q801PH601=CDd0E5AD071`L01JFUX0
H61P02h^;P12@T80Ng]k03dm?@0n?Sh0JVYZ02l_;`16ATH0Hf=S03`l?01<C4`0;Rh^03Ti>@1MGEd0
FEUI01hN7P0i>CT0@D5104i>CP2IVIT0CDe=01LG5`0e=CD0?Shn03Hf=P1]KFd0/k>c0080;Rh^0;<0
IFEU04a<C020P800RXZ:01DE5@0T92@0@D5107IfMP1?Cdl0N7Qh020P800_;bl0=3@d04];B`15ADD0
[Jf]04i>CP0h>3P0CDe=04a<C00o?cl0R8R803Ph>00i>CT0BTY:08:2PP16ATH0>c/k04I6AP0U9BD0
Cdm?0861P@0_;bl0A4A403Hf=P0U9BD0>SXj07inOP0j>SX0?3`l04I6AP0e=CD0IfMW0:RXZ00e=CD0
8B4Q04M7A`1;Bd/0TY:B0;2`/00V9RH0<30`0410@01fMWH0Jf][0:6QX@2^[Zh0<C4a069RHP1NGUh0
O7al0;Jf]P0e=CD0;Bd]05iNGP1VIVH0Hf=S09bLW00V9RH0<c<c06MWI`1PH600>c/k0;Jf]P26QXH0
>c/k05aLG01bLW80DE5A09BDU01aLG40<c<c04e=C@2XZ:P0QXJ606IVIP1MGEd0;Bd]04Q8B02GUiL0
JFUY05MGE`1mOGd07QhN02h^;P1kNg/0Ogmo04a<C01hN7P0<S8b04i>CP1/K6`0EUIF02l_;`1<C4`0
@41006EUI@2MWId0CDe=02DU9@1_Kfl0IfMW04U9B@1hN7P0TY:B03Xj>P1gMgL0EEEE07AdM02:RXX0
;Rh^02HV9P10@400J6QX0410@026QXH0=SHf0410@01@D500H61P06a/K027QhL071`L04=3@`1EEED0
Fe]K0;Ng]`0e=CD0=SHf07IfMP1TI6@0F5QH07QhN013@d<0BDU909nOW`1PH600PX:204e=C@19BDT0
KVi^096AT@12@T80GemO02h^;P1;Bd/0WIfM09^KV`19BDT0D51@03Lg=`11@D40DU9B06m_K`18B4P0
BDU903<c<`15ADD0E5AD08f=S@16ATH0Bd];05ADE00m?Cd0YJFU04i>CP0X:2P0ADE504m?C`020492
@P0T09jNWP2UYJD0=SHf05iNGP1VIVH0MgMg0:FUY@18B4P0:b/[08R8R01bLW80IFEU0;Bd]00k>c/0
=CDe069RHP2:RXX0MGEe08J6QP1hN7P0;2`/03De=@1dM7@0BDU908>3P`2CTi<07QhN01XJ6P1MGEd0
MGEe05YJFP1jNWX0@d=301hN7P12@T80NWYj7?ooool0:`1bLW80LG5a04Q8B00h>3P0FUYJ05IFEP1:
BTX0EeMG06MWI`0j>SX0=cLg069RHP2@T900RHV907IfMP1@D500GUiN04I6AP1<C4`0DU9B02h^;P15
ADD0<30`059BDP0j>SX0;Rh^04=3@`19BDT0BTY:06UYJ@1BDU80De=C069RHP1HF5P0AdM7059BDP1D
E5@0D51@059BDP0`<300:b/[02l_;`1>CTh00P1;Bd/05@17AdL0=CDe04a<C01@D500BTY:0492@P1I
FET0:RXZ04Y:BP14A4@0BTY:02LW9`1<C4`09bLW04];B`17AdL0ADE504i>CP0f=SH0EUIF04Y:BP03
06a/K00C03dm?@11@D40NWYj061PH00c<c<0?Cdm04Y:BP0j>SX0>CTi0451@@1<C4`0CTi>05UIF@1C
De<0GUiN03lo?`1GEeL0FEUI03`l?00203hn?P0Q03Lg=`1:BTX0CTi>04I6AP11@D40@41003<c<`0e
=CD0EUIF02PX:01;Bd/0@d=302l_;`16ATH0Bd];03Ti>@1<C4`0;Bd]04Q8B014A4@0;Rh^04I6AP1A
DE40>CTi06m_K`1:BTX0R8R8069RHP0S8b<0A4A4038b<P0O7al0:b/[0080?clo05P0?Shn04M7A`1C
De<0Kfm_09>CT`1nOWh0Ti>C05YJFP2;Rh/0QhN7065QH@1PH600?Shn05IFEP1BDU80>SXj04I6AP1T
I6@0>c/k065QH@0S8b<0LW9b0492@P1cLg<0KFe]07UiN@1ADE40BDU9069RHP0`<300ADE505UIF@1S
Hf<0;2`/05]KF`0@4100GUiN06UYJ@1EEED0Rh^;03<c<`1HF5P0;bl_03Lg=`17AdL0DE5A05iNGP0T
92@0>SXj04a<C019BDT0IfMW01`L701VIVH0?Shn04Y:BP1>CTh0>3Ph03De=@1UIFD0;2`/05=CD`16
ATH0;Bd]061PH012@T80A4A402TY:@1=CDd0M7Ad04m?C`0e=CD0:BTY03dm?@0g=cL0EEEE01hN7P1?
Cdl0BDU903hn?P10@400DE5A075aL@1BDU80EeMG04Y:BP0e=CD0C4a<0P0h>3P01`10@400C4a<04Q8
B00V9RH0BTY:03lo?`14A4@00P0b<S807P1ADE409bLW04=3@`19BDT0LG5a03Ti>@1?Cdl0DU9B03<c
<`1ADE40:2PX06EUI@1`L700@41005EEE@0j>SX0<C4a020P801?Cdl0=SHf051@D00o?cl0FEUI034a
<@0c<c<0:2PX055AD@1@D500KVi^09:BTP80=cLg00<0D51@05EEE@1?Cdl00P1GEeL07@1bLW80GEeM
071`L01?Cdl0IVIV06EUI@23Ph<0f][J07MgM`1DE5@0ADE503lo?`1CDe<0<S8b030`<01>CTh0GEeM
02LW9`13@d<0?Shn07moO`1OGel0@T9204m?C`1>CTh0@d=305IFEP1LG5`0HF5Q017ooooo000?oooo
o`2n0:n_[`1GEeL0IVIV08b<S027QhL0C4a<04e=C@1CDe<0DU9B07QhN02FUYH0<C4a03/k>`1QHF40
E5AD07moO`0i>CT0?clo059BDP21PH40E5AD0861P@1/K6`09bLW04Y:BP1[Jf/0JVYZ08N7Q`0Z:RX0
=cLg05QHF01ZJVX0A4A406e]K@0[:b/0AdM707AdM02:RXX0Bd];0410@01/K6`0;Bd]04Y:BP24Q8@0
=CDe06IVIP1HF5P0<30`04];B`2;Rh/0ADE503dm?@1FEUH0?Cdm0861P@1?Cdl0;bl_05ADE01EEED0
?Cdm06EUI@1]KFd0<C4a05aLG01GEeL0@D5105]KF`1/K6`08B4Q02PX:01BDU80Cdm?069RHP0T92@0
:RXZ03Hf=P1]KFd0@D5104A4A01fMWH09RHV03Lg=`1OGel0?Shn04m?C`1JFUX0;bl_03Ti>@1^KVh0
S8b<04A4A01EEED0:2PX04M7A`1oOgl0G5aL030`<01:BTX0D51@0451@@1<C4`0G5aL03`l?01GEeL0
EUIF03Xj>P1gMgL0KVi^030`<01EEED0G5aL04A4A01kNg/0IFEU030`<00l?3`0C4a<05aLG014A4@0
UIFE04=3@`12@T80F5QH05iNGP1DE5@0S8b<05iNGP0k>c/0BDU905aLG01IFET0Y:BT03dm?@0W9bL0
QXJ608^;R`1:BTX0R8R807inOP0b<S80I6AT09bLW01MGEd0Ti>C06YZJP0f=SH0DU9B09^KV`1XJ6P0
JVYZ03hn?P0j>SX0HV9R07UiN@1=CDd0H61P06m_K`0f=SH0Fe]K09>CT`19BDT0CDe=079bLP1=CDd0
IfMW0;Jf]P1eMGD0>3Ph059BDP1GEeL0CDe=0:NWY`1]KFd0@T92051@D017AdL0B4Q807alO01UIFD0
>c/k0451@@1ADE40?clo079bLP1RHV80?3`l05UIF@1DE5@0GUiN07QhN080:2PX03P0JFUY06=SH`1B
DU80Ti>C055AD@0/;2`0HV9R0410@01XJ6P0Jf][02@T901;Bd/0Shn?06MWI`1@D500DE5A04U9B@23
Ph<0G5aL06EUI@29RHT0<S8b03`l?029RHT0RXZ:05QHF01UIFD0ADE507YjNP1oOgl0?3`l05eMG@1_
Kfl0?Cdm08n?S`1UIFD0DU9B07QhN01PH600E5AD09fMW@1nOWh0BDU906][J`1MGEd0K6a/096AT@1G
EeL0E5AD07YjNP1OGel0D51@06i^KP25QHD0?clo055AD@80C4a<02P0Rh^;0:ZZZP1eMGD0>CTi04i>
CP1BDU80FEUI0;Bd]01cLg<0?clo05IFEP1EEED0@D510:FUY@1NGUh0?3`l069RHP1DE5@0B4Q80:2P
X01LG5`092@T03hn?P1`L700Fe]K06MWI`1NGUh08R8R03`l?01fMWH0GEeM04];B`1KFe/0?3`l01/K
6`19BDT0GemO04E5A@19BDT0?Shn7?ooool09`1XJ6P0De=C02/[:`0g=cL0EEEE05QHF015ADD0De=C
051@D00/;2`0@T9204e=C@1>CTh0DU9B061PH018B4P0E5AD04A4A00n?Sh0B4Q8030`<00l?3`09RHV
034a<@0m?Cd0?clo055AD@1DE5@0CTi>06IVIP1@D500C4a<05IFEP1HF5P0GEeM071`L01OGel0HV9R
05EEE@0202TY:@0D02XZ:P0i>CT0>c/k03Ti>@16ATH0<30`0451@@14A4@0@D5103dm?@0o?cl0<C4a
03<c<`0O7al0>SXj028R8P0j>SX0:b/[02LW9`0/;2`203Xj>P0M03`l?00g=cL0@D510492@P1dM7@0
F5QH0410@016ATH0GEeM05EEE@11@D40@d=3028R8P0M7Ad08B4Q04U9B@0n?Sh0GemO04M7A`14A4@0
C4a<0492@P1=CDd0AdM702d];@0k>c/0:RXZ03Ti>@10@4000P11@D40B`0j>SX0ATI602/[:`0d=3@0
@41002l_;`15ADD0?Shn0410@00m?Cd0@41004Q8B01=CDd0>CTi059BDP1:BTX0@D51051@D01HF5P0
A4A406UYJ@0n?Sh0QXJ605aLG00k>c/0FUYJ03`l?01FEUH0<c<c04i>CP1;Bd/0CTi>05eMG@1HF5P0
CDe=08:2PP1mOGd0Rh^;02HV9P1YJFT0J6QX05=CD`1kNg/0@T9206][J`1NGUh0AdM704E5A@1OGel0
<30`04M7A`0Z:RX0Bd];0492@P28R8P0H61P06QXJ01jNWX0HF5Q06i^KP10@400<C4a04=3@`1IFET0
7AdM06=SH`0A4A40C4a<07]kN`0a<C40DE5A024Q8@18B4P0?clo04m?C`0204e=C@0J04E5A@0X:2P0
BDU905=CD`1>CTh0MGEe02@T901/K6`0ATI604];B`1ADE40ADE503Ph>01oOgl0:RXZ069RHP1XJ6P0
7alO03<c<`0m?Cd0IVIV02HV9P1TI6@0Lg=c04E5A@1CDe<204A4A01K03Lg=`13@d<08b<S055AD@1B
DU80C4a<04Q8B010@400JFUY06IVIP1ZJVX0CTi>04A4A01ADE40=3@d04A4A01>CTh0FUYJ05MGE`0n
?Sh0D51@0451@@15ADD0=CDe038b<P1EEED0:b/[05UIF@18B4P0O7al04e=C@1IFET0DU9B02PX:01H
F5P0=SHf04i>CP1MGEd0@T9204M7A`11@D40CTi>03Hf=P19BDT0>3Ph05]KF`0R8R80BTY:04=3@`1<
C4`0@D5105eMG@1LG5`0ADE506e]K@13@d<0?Cdm04m?C`11@D40>SXj04i>CP1EEED0OGem06ATI01B
DU80ADE506m_K`1HF5P0FUYJ06YZJP0/;2`0Fe]K04e=C@0o?cl0EEEE0410@01?Cdl0:b/[06=SH`16
ATH0GemO061PH01QHF40GemO05]KF`15ADD0CDe=04];B`1CDe<0K6a/07alO00Aooooo`003oooool0
202UYJD0OWin0:RXZ01cLg<0IfMW08>3P`26QXH0XZ:R0P0m?Cd0DP1oOgl0U9BD06a/K01nOWh08R8R
07UiN@1VIVH0=3@d05UIF@1OGel092@T03Hf=P1VIVH0@T9205EEE@0W9bL0<S8b07EeM@1SHf<0>CTi
07QhN010@4006QXJ06e]K@0];Bd0:RXZ04];B`0m?Cd0@T9204e=C@1lO7`09RHV03<c<`1FEUH0DE5A
09BDU02XZ:P0:b/[03dm?@19BDT0@D5109RHV02][Jd0<C4a061PH01=CDd0IfMW0;2`/00h>3P07alO
03hn?P1QHF40DE5A0:VYZ@18B4P0<C4a03lo?`1MGEd0ADE5065QH@26QXH0=CDe04];B`1dM7@0;Rh^
05MGE`0n?Sh09BDU03`l?01YJFT0Fe]K02TY:@1?Cdl0=SHf0410@01oOgl0>CTi03De=@1BDU809RHV
05=CD`1cLg<202DU9@3404U9B@13@d<0=cLg07emO@1SHf<0820P03lo?`1<C4`0@D5108^;R`1IFET0
7QhN04=3@`1PH600@41006a/K030`<00:BTY05eMG@2;Rh/0IFEU06YZJP2b/[80:b/[02HV9P1CDe<0
Kfm_08Z:RP1eMGD07QhN03<c<`1RHV80OWin065QH@2?Shl0EUIF03Lg=`1OGel0Ogmo04Q8B01hN7P0
:BTY02/[:`16ATH0M7Ad06EUI@1CDe<06a/K03dm?@1FEUH0Xj>S05aLG025QHD0H61P030`<01aLG40
SHf=03hn?P13@d<0>CTi03lo?`1FEUH0KVi^04I6AP0k>c/0EeMG05EEE@1TI6@0TY:B03Ph>00k>c/0
F5QH06MWI`1`L700NWYj05ADE013@d<0FUYJ08^;R`1NGUh0/;2`03hn?P0^;Rh0Cdm?05=CD`1mOGd0
YjNW02DU9@0k>c/0L71`05]KF`18B4P0[:b/05MGE`0d=3@0S8b<06YZJP1CDe<0KVi^02PX:00_;bl0
MWIf092@T00i>CT0DE5A02<S8`0n?Sh0O7al04m?C`0d=3@0Fe]K02/[:`0n?Sh0H61P04I6AP1IFET0
8b<S03dm?@2DU9@0KFe]03dm?@1>CTh0:BTY055AD@2DU9@0?Cdm05YJFP1DE5@0DU9B0::RXP2VYZH0
<c<c03Xj>P1@D500NGUi09bLW01<C4`0<30`0410@01PH600PH610:FUY@1YJFT0GUiN06=SH`1LG5`0
N7Qh0=;BdP25QHD0;bl_06MWI`2KVi/0PX:20::RXP0o?cl09RHV04I6AP1ZJVX0SXj>07emO@2k^k/0
J6QX02h^;P2=SHd0YZJV09fMW@2o_kl0>c/k02/[:`1`L700_;bl06i^KP1jNWX0?Shn05iNGP1eMGD0
VIVI05UIF@1QHF40V9RH02l_;`16ATH0WYjN05ADE013@d<0O7al03De=@0`<300IfMW05eMG@0h>3P0
FEUI02@T900`<300SHf=08>3Pacooooo0?l0J6QX06YZJP0a<C40<c<c05=CD`11@D40:b/[061PH01Z
JVX0;2`/03Ph>01<C4`0TI6A09NGU`1lO7`0EUIF079bLP12@T80De=C0492@P0j>SX0?Cdm03<c<`16
ATH0>SXj02`/;011@D40CTi>05QHF02BTY80EEEE03Ph>01HF5P0M7Ad03lo?`1>CTh0J6QX08b<S01:
BTX0=CDe03hn?P0W9bL0=3@d04A4A01;Bd/0BTY:02`/;01CDe<0GemO04e=C@1@D500F5QH03Ti>@1<
C4`0?Cdm05UIF@0T92@0@d=3055AD@0g=cL0<c<c04=3@`1;Bd/0;Bd]04e=C@10@400BDU906m_K`1`
L700<c<c03Ti>@1dM7@0KVi^03@d=01CDe<0?Cdm02LW9`0c<c<0Cdm?02TY:@1@D500BDU904M7A`1;
Bd/0>c/k0492@P0c<c<0<C4a03Xj>P0U9BD08R8R0410@00k>c/0>SXj03dm?@19BDT04Q8B024Q8@0h
>3P09BDU03lo?`0Z:RX0=SHf03Lg=`0b<S80;2`/03`l?00g=cL0A4A403Xj>P0m?Cd0Bd];04A4A011
@D40GEeM03`l?00o?cl0?Cdm038b<P11@D40>CTi03De=@0o?cl0>CTi06YZJP17AdL0Jf][05]KF`1/
K6`0YjNW06EUI@1mOGd0GUiN09RHV01fMWH0Rh^;0:>SX`1GEeL0QHF505aLG00b<S80ATI606ATI014
A4@0FUYJ04I6AP1>CTh0=3@d08f=S@1OGel0O7al059BDP14A4@0JVYZ03Hf=P19BDT0KVi^07QhN00b
<S80Cdm?01LG5`0[:b/0LW9b03hn?P1XJ6P08b<S05=CD`0U9BD0EUIF03Ti>@0k>c/0A4A404];B`1^
KVh0Fe]K03De=@1<C4`06QXJ05=CD`0g=cL0DE5A04m?C`1CDe<0@T9207]kN`0`<300FUYJ05]KF`0U
9BD0@T9202l_;`1?Cdl0@D5105iNGP20P800LG5a06QXJ01LG5`0Cdm?038b<P0i>CT061PH04A4A017
AdL0IFEU04E5A@0^;Rh0Cdm?04=3@`0o?cl0=3@d03Ph>01DE5@08R8R03Hf=P0_;bl0De=C055AD@0_
;bl0@T9204=3@`17AdL0;2`/02d];@1EEED0;bl_06YZJP12@T80PX:204e=C@1SHf<0De=C02PX:01b
LW80>3Ph03<c<`13@d<0?3`l030`<00a<C40=cLg02TY:@0k>c/0=SHf059BDP0T92@0@T9203<c<`14
A4@0CTi>03`l?011@D40CDe=08^;R`1IFET002<0ATI605ADE01;Bd/0BTY:06YZJP1CDe<0Ng]k04U9
B@27QhL0BTY:05iNGP1HF5P0=cLg030`<00P8200Q8B405QHF011@D40F5QH04E5A@1?Cdl0<S8b07If
MP1=CDd0ADE502d];@23Ph<0GemO04];B`1EEED0E5AD04m?C`1ZJVX0G5aL05iNGP0Aooooo`003ooo
ool0D`2=SHd0CDe=07AdM02KVi/0Cdm?04A4A01HF5P0XJ6Q05EEE@0l?3`0B4Q803Ph>02EUID0/K6a
02`/;00m?Cd0BTY:0410@02CTi<0T92@024Q8@0R8R80>3Ph03Lg=`2BTY80ATI602PX:00c<c<0?Shn
059BDP2NWYh0Ph>301DE5@1EEED0IVIV04m?C`2NWYh0Hf=S01LG5`17AdL0CTi>0410@01YJFT0IfMW
02/[:`1lO7`0VIVI065QH@2@T900O7al01lO7`0o?cl0Y:BT07UiN@1jNWX08b<S02d];@1kNg/0RHV9
03<c<`1?Cdl0BTY:02<S8`1nOWh0E5AD01LG5`1?Cdl0A4A402<S8`1NGUh0[Zj^02TY:@0f=SH0?clo
03Ti>@1[Jf/0LW9b01LG5`0L71`0Bd];05MGE`1:BTX0N7Qh0080;Bd]02H0Hf=S06EUI@1PH600_Kfm
038b<P0[:b/0Fe]K05IFEP1iNGT0XJ6Q02h^;P0M7Ad0?clo071`L017AdL0LG5a04];B`0V9RH0EeMG
08F5Q@0o?cl0GEeM075aL@0Y:BT0>SXj05YJFP0o?cl0FUYJ04m?C`0c<c<0<S8b05ADE01=CDd0?Cdm
04Y:BP0o?cl0Bd];05YJFP80:BTY0:D0ATI603Ti>@14A4@0RHV907emO@0_;bl0CTi>04I6AP1BDU80
UiNG04Q8B00R8R80=CDe05=CD`1BDU80R8R802d];@0U9BD0BDU90820P01HF5P0Y:BT0;^k^`0g=cL0
?Shn07]kN`1fMWH0N7Qh03Xj>P0_;bl0Jf][07EeM@1UIFD0Lg=c06m_K`0g=cL0Cdm?05]KF`1OGel0
IVIV0:f][@0Y:BT0BTY:05ADE01nOWh0Z:RX09fMW@0n?Sh0ATI605mOG`1bLW80@D51061PH017AdL0
<30`06][J`1EEED0;bl_05]KF`14A4@0:b/[06QXJ02SXj<0@T92051@D00d=3@0IFEU09fMW@0j>SX0
9bLW03lo?`1TI6@0@D5108:2PP0U9BD0=CDe059BDP1;Bd/0GemO0:6QX@0c<c<0>c/k04m?C`1jNWX0
YZJV02d];@0V9RH0F5QH05aLG01mOGd0YJFU02/[:`0a<C40Ph>306ATI02ATI40G5aL02h^;P18B4P0
UYJF05MGE`1eMGD0?Shn04i>CP1ZJVX0Shn?06MWI`24Q8@0:RXZ04A4A01hN7P0KFe]06=SH`17AdL0
=CDe03Hf=P1DE5@0Zj^[061PH01NGUh0LW9b04E5A@21PH40IfMW02l_;`1EEED0JFUY02HV9P13@d<0
U9BD0:JVYP16ATH0G5aL04M7A`1GEeL0ZJVY03hn?P0R8R80ADE504Q8B01GEeL0VIVI030`<00N7Qh0
IfMW07=cL`1VIVH0GEeM09>CT`0^;Rh09RHV06EUI@1MGEd0D51@09JFUP0g=cL0:RXZ04Q8B01EEED0
?Cdm08R8R00S8b<08B4Q06=SH`21PH407?ooool0?@1CDe<0BDU9038b<P0^;Rh0ADE504m?C`0l?3`0
A4A403dm?@14A4@0AdM704I6AP0o?cl0>CTi05YJFP1FEUH0JFUY05iNGP14A4@0?Shn02/[:`1>CTh0
ATI603Ti>@1DE5@0AdM704Y:BP0_;bl0<C4a03Ph>012@T80?Cdm04Q8B01;Bd/0C4a<051@D01<C4`0
@d=304Y:BP0Y:BT0=cLg03Xj>P0`<300?clo03Hf=P15ADD0<S8b03Ti>@0m?Cd0?clo03Hf=P14A4@0
D51@04I6AP0/;2`0@d=303<c<`1OGel0D51@04A4A018B4P00P14A4@03`12@T80@41004E5A@0^;Rh0
PH6106e]K@0d=3@0>CTi05YJFP1>CTh0?Shn05MGE`1BDU80CDe=04i>CP0204Y:BP3B05aLG013@d<0
@d=303`l?015ADD0?Cdm03Ti>@0^;Rh0BTY:02l_;`0j>SX0AdM703<c<`0j>SX0?3`l05UIF@0Q8B40
<c<c0492@P0f=SH0>3Ph03`l?01?Cdl0@d=304i>CP15ADD0EUIF03@d=01<C4`0;bl_03dm?@0l?3`0
@d=303lo?`25QHD0<30`059BDP0R8R80=CDe04i>CP0X:2P0<C4a03Hf=P0_;bl0:RXZ03dm?@1?Cdl0
@41002d];@19BDT0H61P075aL@0[:b/0ATI60492@P17AdL0Fe]K04U9B@1HF5P0@d=303hn?P1YJFT0
VIVI02h^;P12@T809RHV04m?C`1HF5P0QHF508N7Q`2@T900J6QX04Q8B024Q8@0De=C028R8P0m?Cd0
E5AD02DU9@1<C4`06QXJ03Ph>02=SHd0@D5108:2PP0b<S80BTY:024Q8@0n?Sh0<c<c04];B`1>CTh0
;bl_03/k>`0g=cL0Cdm?059BDP0[:b/0MGEe04a<C01@D500DE5A05QHF01@D500Ng]k04a<C01RHV80
H61P038b<P1HF5P0ADE505IFEP1:BTX0M7Ad07alO01SHf<0NGUi06MWI`0l?3`0=SHf04Y:BP0/;2`0
BDU904e=C@0k>c/0De=C0451@@1BDU80MWIf07EeM@0h>3P0>SXj04i>CP0M7Ad0?Cdm03<c<`13@d<0
E5AD03Ti>@15ADD0=cLg04A4A00e=CD0:RXZ05aLG00d=3@0CDe=03/k>`1lO7`0Fe]K059BDP17AdL0
5ADE04E5A@0d=3@0<C4a04I6AP15ADD0;2`/03Hf=P12@T809bLW04I6AP0Y:BT0EUIF02l_;`1FEUH0
AdM704a<C01MGEd0HF5Q06=SH`2:RXX0S8b<04=3@`0a<C40B4Q803Xj>P0R8R80?clo04];B`2ATI40
GEeM05MGE`1QHF40MGEe075aL@19BDT0ATI602PX:01FEUH0?Cdm04I6AP1XJ6P0<S8b04e=C@0f=SH0
LG5a04Y:BP19BDT0@D5105aLG01OGel0Bd];05=CD`1=CDd0ATI607UiN@1QHF40Lg=c4Oooool000oo
oooo07<0alO705]KF`1JFUX0OWin0:2PX00l?3`0@41006ATI01hN7P0O7al09>CT`0f=SH0>CTi04a<
C01ZJVX0Ogmo034a<@10@400Hf=S0:2PX01?Cdl0IfMW05QHF00P8200F5QH07moO`1FEUH0LG5a01XJ
6P0n?Sh0IFEU08R8R016ATH0LG5a02XZ:P10@400BDU905ADE00`<300?Cdm04e=C@0I6AT0BDU906IV
IP0O7al0>c/k03`l?00i>CT0[jn_0;Bd]00`<300;Bd]0492@P1UIFD0`<3004i>CP0K6a/0AdM707Yj
NP1HF5P0RXZ:071`L00[:b/0B4Q8079bLP16ATH0QHF505eMG@0P8200<30`0861P@1<C4`0IfMW02@T
900g=cL0ATI607emO@1GEeL0OGem07inOP0K6a/07AdM05mOG`16ATH0HF5Q07UiN@0S8b<09RHV05eM
G@1mOGd0<S8b055AD@0R8R80=cLg079bLP1KFe/07alO04M7A`1GEeL0:b/[061PH01TI6@0;2`/03`l
?01=CDd0=3@d07]kN`2BTY80;Rh^01dM7@1>CTh0E5AD09^KV`1kNg/0:2PX0080@T9203X0BTY:06UY
J@2k^k/0?3`l04U9B@1LG5`0@D5105EEE@2KVi/0EeMG01XJ6P1DE5@0PH6106][J`2?Shl0<S8b03@d
=01mOGd0S8b<04M7A`1^KVh0D51@024Q8@1[Jf/0Kfm_04a<C01SHf<0<C4a03`l?017AdL0Shn?07Qh
N01KFe/0;Rh^02/[:`2<S8`0PX:203Hf=P1@D500IVIV03Hf=P10@400Vi^K030`<00m?Cd0De=C0492
@P1CDe<0];Bd079bLP0T92@0Cdm?04A4A02?Shl0f][J04Y:BP0c<c<0DE5A0P0n?Sh0CP2?Shl0LG5a
03Ti>@10@400AdM704m?C`2][Jd0E5AD03<c<`0e=CD0BDU905MGE`1iNGT092@T03De=@1BDU80GUiN
04i>CP1kNg/0?clo03Ph>01MGEd0?clo06EUI@12@T808B4Q04=3@`1HF5P0E5AD06EUI@13@d<0Bd];
05UIF@1;Bd/0DE5A061PH00/;2`0@4100:RXZ026QXH0JFUY03`l?00Y:BT0GUiN08R8R00j>SX0De=C
05QHF00l?3`0QhN7065QH@14A4@0J6QX06EUI@1KFe/0/K6a08j>SP0/;2`0D51@075aL@2f][H0TI6A
03Hf=P0o?cl0EUIF07YjNP1gMgL0]kNg0;Fe]@12@T80G5aL096AT@1>CTh0/k>c0:^[Z`0o?cl0@T92
04U9B@80P8200240/;2`04a<C01kNg/0VYZJ06m_K`1`L700X:2P065QH@10@400JVYZ06e]K@1BDU80
Q8B404Q8B00b<S80ADE506MWI`2ATI40EeMG05aLG00Y:BT0;2`/0492@P1PH600<c<c04M7A`0_;bl0
6a/K059BDP1GEeL0:b/[04I6AP0l?3`07?ooool0E@1HF5P0EeMG034a<@0`<300BDU904a<C01?Cdl0
K6a/05UIF@0Q8B40<c<c05=CD`1UIFD0GUiN05UIF@1ADE40Fe]K03hn?P1FEUH0ADE502LW9`0g=cL0
<S8b03Ti>@0j>SX0?clo05MGE`1IFET0GUiN061PH01FEUH0?3`l05UIF@1ZJVX0DE5A05MGE`1ZJVX0
F5QH05ADE00K6a/0;2`/03Ph>00/;2`0AdM704A4A01SHf<0?3`l04A4A019BDT0Hf=S04A4A01HF5P0
=3@d03Xj>P0P8200>3Ph02@T900j>SX0BTY:030`<00Q8B40>c/k02DU9@0X:2P0=cLg03Xj>P0g=cL0
DU9B05EEE@1CDe<0GEeM04E5A@17AdL0<S8b03Lg=`0/;2`08B4Q02LW9`0j>SX0=3@d04];B`0f=SH0
>SXj03Hf=P0m?Cd00P16ATH02P0M7Ad0:BTY01dM7@0n?Sh0=SHf03De=@10@400:b/[03Ti>@0E5AD2
03Xj>P17028R8P0^;Rh0;Rh^02@T900/;2`0=3@d03Lg=`11@D40<30`04I6AP0j>SX0EUIF04I6AP18
B4P0?Shn055AD@0l?3`0I6AT03Lg=`0X:2P0B4Q803Hf=P0c<c<0EUIF04E5A@19BDT0EUIF08f=S@1c
Lg<0?clo07IfMP1dM7@0MWIf02l_;`1JFUX0GUiN05aLG01_Kfl0BDU908N7Q`1BDU80EUIF04A4A01I
FET0?Cdm04Q8B01ADE40JVYZ065QH@29RHT0D51@04];B`2TY:@0GemO04E5A@0k>c/0@d=305IFEP1W
IfL07AdM06MWI`0O7al0De=C08N7Q`19BDT0GemO03dm?@1dM7@0;2`/069RHP1<C4`00P1bLW80600n
?Sh0BTY:04=3@`0o?cl0H61P01PH601:BTX0?3`l04];B`1ADE40BTY:04m?C`20P800Cdm?06UYJ@1U
IFD0BDU905mOG`19BDT0IfMW05MGE`1>CTh0JFUY05=CD`80FEUI05`0>c/k059BDP1;Bd/0IVIV05IF
EP1JFUX0BTY:07IfMP17AdL0IFEU04e=C@11@D40BDU903<c<`1>CTh0<C4a03<c<`13@d<0GemO069R
HP1IFET0BDU90451@@1FEUH0@d=303Lg=`1IFET0GemO04i>CP1ADE40Lg=c06YZJP18B4P0Cdm?034a
<@1DE5@0GEeM03hn?P1GEeL0@d=303/k>`1:BTX0ATI60410@014A4@0ATI605ADE00o?cl0CTi>0410
@01:BTX0>3Ph059BDP1[Jf/0ADE507=cL`21PH40@D5106QXJ017AdL0:RXZ04U9B@18B4P0IFEU04];
B`1IFET0G5aL07AdM01EEED0EeMG05ADE00^;Rh0OGem05ADE01EEED0JFUY03lo?`1PH600;Bd]065Q
H@1<C4`0GemO03De=@1gMgL0KFe]04];B`1HF5P0EeMG04E5A@1:BTX0EUIF05aLG17ooooo000?oooo
o`0509ZJVP1NGUh0LW9b05=CD`1GEeL00P1CDe<0I@1MGEd0>SXj06=SH`1ZJVX0D51@03/k>`1JFUX0
AdM70:VYZ@1ZJVX0DU9B03Ti>@14A4@0ATI6079bLP20P8008B4Q03De=@1;Bd/0]KFe09>CT`0H61P0
9BDU03@d=01TI6@0ATI60820P00>3Ph0>c/k04Q8B01CDe<0ADE507inOP1cLg<061PH04e=C@1fMWH0
A4A408b<S00n?Sh061PH05MGE`2UYJD0EUIF05mOG`1?Cdl0;2`/06][J`1cLg<0FEUI07UiN@0H61P0
<S8b05=CD`1XJ6P0ATI606MWI`0Z:RX0AdM707moO`1iNGT0;Bd]034a<@1>CTh0<30`079bLP14A4@0
5aLG03lo?`0l?3`08R8R0492@P2CTi<0>3Ph02@T900j>SX0=cLg07MgM`2HV9P09bLW01dM7@1:BTX0
IfMW061PH02i^KT09RHV02d];@0m?Cd0HV9R04m?C`2<S8`0O7al03Lg=`1>CTh0DU9B06QXJ02BTY80
<C4a02TY:@0n?Sh0D51@0080HF5Q00L0OGem028R8P0m?Cd0QHF504m?C`0j>SX0TI6A0080:b/[06l0
DE5A05aLG01NGUh0FEUI02LW9`10@400Cdm?05]KF`0S8b<0CTi>03dm?@12@T80PX:203<c<`0^;Rh0
DU9B055AD@0n?Sh0P82007emO@0Q8B40@410065QH@1WIfL0ZZZZ04M7A`0a<C40@d=3061PH01LG5`0
WinO04I6AP0[:b/0@d=307=cL`1:BTX0NGUi0861P@0i>CT0ADE506m_K`1YJFT0MgMg05]KF`0W9bL0
<C4a05QHF02>SXh0IFEU08V9R@0o?cl0?Shn06QXJ028R8P0GEeM07inOP0_;bl0:b/[04e=C@2<S8`0
KFe]05YJFP0U9BD0A4A4061PH01dM7@0:b/[055AD@0n?Sh0?3`l08F5Q@1=CDd0=CDe04m?C`0Y:BT0
@41008:2PP18B4P07alO03Lg=`1CDe<0RHV908f=S@0Z:RX0;Rh^04U9B@0^;Rh0KFe]06MWI`0m?Cd0
Lg=c04i>CP29RHT0Rh^;03@d=00Y:BT0L71`05iNGP2>SXh0GUiN03/k>`1IFET0Xj>S05aLG02DU9@0
SHf=02PX:01IFET0IFEU061PH01]KFd00P0b<S806@1SHf<0TI6A04m?C`1`L700Bd];05]KF`1mOGd0
GemO06IVIP2BTY80EUIF03lo?`11@D40S8b<061PH026QXH0?3`l034a<@0j>SX0MWIf08V9R@1:BTX0
Jf][01hN7P15ADD00P2CTi<07`1QHF40PX:203De=@0f=SH0MWIf09BDU01<C4`0CDe=05=CD`1<C4`0
SXj>06=SH`0S8b<0=CDe03`l?01NGUh0NGUi09JFUP0U9BD0>CTi04I6AP1PH600DE5A09JFUP1ZJVX0
51@D059BDP1TI6@0Cdm?09JFUP1GEeL07?ooool0EP1NGUh0Kfm_04I6AP0b<S80F5QH04a<C00k>c/0
K6a/06QXJ017AdL0@41004];B`1UIFD0IfMW05]KF`1<C4`0HV9R06IVIP1NGUh0Bd];030`<019BDT0
<S8b03Lg=`0k>c/0<30`03dm?@1<C4`0J6QX0861P@1IFET0ADE505UIF@1^KVh0EeMG05eMG@1RHV80
LG5a059BDP0`<300=3@d02d];@0m?Cd0BDU904m?C`1LG5`0;bl_04];B`1@D500G5aL04];B`1VIVH0
?3`l03dm?@0M7Ad0CDe=03Ph>00n?Sh0MGEe024Q8@0P8200AdM704Y:BP16ATH0BDU903Xj>P1:BTX0
KFe]06IVIP0^;Rh0<C4a065QH@1:BTX0820P04Q8B01TI6@0=cLg04=3@`1<C4`08R8R05ADE01;Bd/0
@d=30451@@0e=CD0?Shn0P0_;bl05`0d=3@0:BTY01dM7@16ATH0=3@d034a<@0m?Cd0@d=301`L700K
6a/0=cLg02h^;P0c<c<07alO030`<00c<c<0ATI602@T9015ADD0=CDe05EEE@0Z:RX0@D510080D51@
0200>CTi05QHF00/;2`0>3Ph02`/;00^;Rh0@D5103<c<`0P8200<C4a03Ti>@1ZJVX0ATI604i>CP1B
DU80GUiN0861P@1<C4`0QXJ60492@P2:RXX0MWIf06UYJ@1UIFD0Cdm?05YJFP1<C4`0;Bd]0451@@1M
GEd0DU9B05iNGP80BDU903d0@D5109BDU023Ph<0KFe]05MGE`13@d<0E5AD03@d=00a<C40Jf][07=c
L`12@T80?clo01@D500d=3@0JVYZ03Ti>@1fMWH0>3Ph04M7A`0^;Rh0HV9R0492@P0`<300<c<c03Hf
=P1]KFd0C4a<03Ti>@1KFe/05ADE05eMG@1=CDd0CTi>05YJFP1MGEd0BDU9061PH017AdL0N7Qh0861
P@0_;bl0BDU903Lg=`1ADE40?clo06][J`2;Rh/0BTY:0492@P0n?Sh0Cdm?05MGE`16ATH0?clo04i>
CP1QHF40C4a<05QHF01CDe<0Ph>300<0FUYJ00l0B4Q805=CD`1ZJVX0?Shn04Q8B01OGel0Kfm_04m?
C`1MGEd0BDU904a<C01:BTX0Fe]K05eMG@11@D400P1ADE4207EeM@0l06YZJP1YJFT0;2`/055AD@0m
?Cd0BTY:05]KF`1EEED0CTi>04U9B@15ADD0B4Q804e=C@0c<c<0D51@03hn?P1IFET0@d=30492@P0h
>3P0BTY:04=3@`0n?Sh0W9bL07moO`1SHf<0D51@03dm?@0o?cl0DU9B04A4A01aLG40De=C04e=C@1i
NGT0?clo05QHF01ADE40@d=302XZ:P0j>SX0=cLg0492@P1ADE40;Bd]03`l?01:BTX0MgMg03dm?@0o
?cl0I6AT0;Bd]028R8P0CTi>07inOP1ZJVX0ADE5061PH01TI6@0IfMW4Oooool000oooooo01`0Lg=c
06][J`2ATI40MWIf05=CD`1/K6`0TY:B0;Rh^00m?Cd0CTi>06MWI`1dM7@0NWYj0:j^[P0b<S80=cLg
06IVIP1iNGT0RHV907YjNP0Y:BT0C4a<04I6AP1=CDd0OGem02@T900Z:RX0IfMW0P1BDU80<@1lO7`0
AdM702XZ:P1aLG40;bl_02h^;P1BDU80820P01lO7`0k>c/0N7Qh03Ti>@0Y:BT0AdM704Y:BP1UIFD0
QHF503Ti>@0n?Sh0FEUI03Lg=`2DU9@0QHF502@T900n?Sh0<30`059BDP37alL0H61P01@D501;Bd/0
Q8B405MGE`2=SHd0:2PX01DE5@1<C4`0V9RH06QXJ01gMgL0Ph>302@T900f=SH0FEUI059BDP2BTY80
=SHf02l_;`1:BTX00P1<C4`04`0o?cl0KVi^01HF5P15ADD0RHV905iNGP1=CDd0D51@03@d=00O7al0
IVIV07MgM`1GEeL0KFe]02DU9@0R8R80BDU909VIV@0k>c/00P0j>SX0_011@D40Ogmo06YZJP0Z:RX0
@T9204M7A`1=CDd0Ogmo08N7Q`0^;Rh0BTY:05=CD`1SHf<0Q8B40<C4a00a<C40>3Ph04a<C01?Cdl0
VIVI0:BTY00K6a/0;Rh^05iNGP1/K6`0BTY:09fMW@2:RXX0;bl_09NGU`1^KVh0OWin0:RXZ00c<c<0
?3`l05aLG02=SHd0EUIF05eMG@0V9RH0D51@06][J`2=SHd0D51@06][J`1JFUX09bLW06e]K@28R8P0
BDU905aLG00l?3`0:b/[0451@@1oOgl0C4a<034a<@1HF5P0<c<c07alO02ATI409BDU02h^;P15ADD0
;Bd]02l_;`2;Rh/0Bd];03Xj>P18B4P0E5AD04];B`2QXJ40BTY:02HV9P10@400C4a<07IfMP1kNg/0
:b/[03Ph>01BDU80M7Ad05MGE`2b/[80IFEU030`<01hN7P0GEeM07alO02MWId092@T02d];@1UIFD0
Shn?059BDP1DE5@0820P05iNGP2TY:@0D51@03Ph>01ADE40:RXZ02d];@1/K6`0@41006ATI00O7al0
?3`l08^;R`1VIVH0Cdm?05iNGP0W9bL0AdM706=SH`0[:b/0AdM703De=@0m?Cd0EUIF0:2PX015ADD0
@D5104Y:BP1dM7@0Ph>304Q8B00];Bd0@41004M7A`1eMGD0/[:b05YJFP14A4@0BTY:03/k>`1kNg/0
alO7079bLP0e=CD0?Cdm055AD@1LG5`0YJFU06YZJP0e=CD0<c<c03Ti>@1bLW80SXj>0;no_`0e=CD0
>SXj0861P@2=SHd0J6QX0:n_[`0^;Rh0CDe=06YZJP28R8P0GemO05iNGP0k>c/0DU9B07moO`2EUID0
CDe=06MWI`1oOgl071`L04M7A`2SXj<0K6a/03dm?@1]KFd06a/K034a<@2<S8`0PH6103/k>`17AdL0
6ATI030`<01BDU80K6a/7?ooool0<`17AdL0Bd];02TY:@0];Bd0A4A404U9B@0f=SH0G5aL06=SH`0T
92@0@d=304I6AP14A4@0C4a<06ATI01<C4`0Lg=c03/k>`14A4@0?Shn01PH600i>CT0:b/[03Lg=`11
@D40A4A403hn?P1GEeL0Fe]K04U9B@12@T80>SXj04a<C01BDU80BDU904];B`18B4P0BTY:051@D00g
=cL0<S8b03Xj>P0^;Rh0@T920410@00o?cl0;2`/03`l?012@T80?Shn03<c<`0204e=C@1U04=3@`0d
=3@0D51@03Ph>01=CDd0HV9R02/[:`0n?Sh0A4A404U9B@16ATH0De=C05YJFP16ATH0Jf][06YZJP1K
Fe/0HF5Q075aL@1KFe/0:2PX059BDP1PH600:2PX02@T901>CTh07QhN05YJFP1CDe<0?Shn04I6AP0o
?cl0>c/k03Ti>@0S8b<0@T9202XZ:P0V9RH0>SXj034a<@0l?3`0<S8b04Y:BP0T92@0>CTi04A4A00]
;Bd0ATI603Ph>00i>CT0@D5103Ti>@0j>SX0@d=3038b<P0_;bl0<C4a0451@@0d=3@0BTY:05UIF@1m
OGd0:RXZ05eMG@17AdL0>c/k05EEE@0Z:RX0=CDe03Xj>P0e=CD0;Rh^04=3@`1WIfL0FEUI065QH@2<
S8`0DU9B05]KF`0M7Ad0?3`l04Q8B01CDe<0P82003Lg=`10@400>CTi03hn?P1:BTX0De=C02l_;`0m
?Cd0?clo06EUI@17AdL0IfMW05MGE`15ADD0GEeM061PH026QXH00P0h>3P0;`1CDe<0K6a/02l_;`1E
EED08B4Q05eMG@1mOGd0?Cdm061PH00^;Rh0L71`02/[:`1<C4`0<c<c06UYJ@1:BTX0820P038b<P0a
<C40KVi^07alO00_;bl0E5AD04Y:BP19BDT0H61P05aLG01ADE40Ng]k038b<P1GEeL0G5aL04m?C`1W
IfL0AdM706][J`10@400FEUI07=cL`1CDe<0H61P05eMG@0d=3@0>CTi06IVIP1RHV80IfMW0080GEeM
0340Q8B404M7A`1@D500NGUi07AdM01QHF40De=C07QhN016ATH0@d=305MGE`1mOGd0IVIV0492@P1=
CDd0A4A404e=C@0/;2`0:RXZ065QH@14A4@0LW9b05iNGP2EUID0MGEe06IVIP1^KVh0>CTi06QXJ01B
DU80ATI604i>CP0i>CT0?clo03hn?P0/;2`09RHV05QHF00V9RH0CDe=03`l?01DE5@0?Cdm02l_;`1T
I6@0WinO06m_K`1OGel0DE5A0080<C4a01H0De=C04=3@`1<C4`0R8R804i>CP1aLG40FUYJ06m_K`2?
Shl0DU9B04U9B@1_Kfl0G5aL01dM7@1OGel0De=C06MWI`1eMGD0AdM70451@@0^;Rh0F5QH0P0i>CT0
2P0S8b<0Cdm?05IFEP19BDT0ATI604M7A`15ADD0C4a<059BDP1IFETAooooo`003oooool0e@2QXJ40
Cdm?05IFEP2@T900QXJ603dm?@1@D500O7al06][J`13@d<0G5aL03@d=018B4P0IVIV03Ph>01<C4`0
9BDU03dm?@18B4P0Ph>30410@014A4@0?Shn02XZ:P2NWYh0?3`l028R8P0j>SX0:BTY0451@@2ATI40
De=C02<S8`1NGUh0@T9206QXJ02OWil0<c<c01HF5P0j>SX0?Shn06=SH`1OGel0Ng]k01`L701UIFD0
Shn?06ATI021PH40MgMg02DU9@0a<C40KFe]07]kN`1IFET09bLW03Ti>@18B4P0Kfm_05iNGP21PH40
L71`030`<01<C4`0IFEU03De=@2KVi/0C4a<02/[:`1=CDd0OGem04a<C01^KVh0:b/[02TY:@1LG5`0
QhN701lO7`0S8b<0DU9B02<S8`0U9BD0O7al01dM7@0/;2`0@d=303lo?`1LG5`0GemO038b<P0F5QH0
>CTi038b<P2DU9@0a<C4059BDP0Q8B40Bd];05aLG01GEeL0VYZJ059BDP0S8b<0I6AT06e]K@1LG5`0
Ti>C079bLP0^;Rh0?Shn079bLP1FEUH0YjNW06a/K00I6AT0<c<c04m?C`1kNg/0ATI607=cL`0^;Rh0
ATI607=cL`1DE5@0>CTi06][J`0n?Sh092@T05IFEP1iNGT0>CTi03hn?P0N7Qh0>CTi09fMW@1_Kfl0
:BTY04U9B@0f=SH0DE5A075aL@0l?3`08b<S061PH01:BTX0@D5108f=S@1oOgl09RHV03Ph>01OGel0
Hf=S09RHV01@D5008b<S03dm?@1KFe/0MgMg079bLP1iNGT0<30`03/k>`2FUYH0KVi^06a/K02DU9@0
:BTY02l_;`1XJ6P0O7al0:RXZ02CTi<0ADE504];B`1UIFD0T92@06UYJ@2UYJD0G5aL04=3@`2;Rh/0
OGem05MGE`2[Zj/0Bd];02PX:011@D40UiNG04m?C`1MGEd0:RXZ03Lg=`1XJ6P0ADE503Xj>P1EEED0
?Shn05=CD`1OGel0:b/[03`l?011@D40CTi>08F5Q@28R8P0?clo03Hf=P0j>SX0FUYJ09VIV@0];Bd0
8R8R03hn?P0206ATI0190:FUY@0g=cL0Bd];06MWI`1iNGT0Xj>S04];B`0Z:RX0DE5A065QH@1cLg<0
Vi^K04=3@`18B4P0PX:208f=S@1[Jf/0W9bL03Hf=P0];Bd0Cdm?07]kN`1^KVh0Hf=S03Hf=P0m?Cd0
EUIF0:f][@1MGEd0Fe]K04m?C`0_;bl0E5AD05QHF018B4P0LW9b065QH@0O7al0@D5108J6QP2ATI40
?Cdm059BDP0l?3`0E5AD08J6QP1GEeL0<c<c04E5A@1OGel0H61P08F5Q@0W9bL092@T04M7A`0o?cl0
<C4a06e]K@2OWil0<c<c02HV9P1>CTh0GUiN05mOG`2GUiL09bLW01TI6@0j>SX0R8R8059BDP1dM7@0
5aLG03@d=00204U9BAcooooo0400KFe]06=SH`0l?3`0<c<c04m?C`1<C4`0?Shn05IFEP1ADE40<30`
04E5A@1=CDd0DE5A05QHF01dM7@0LG5a07IfMP1>CTh0H61P0492@P0M7Ad0=CDe02<S8`0b<S80?clo
04Q8B01CDe<0B4Q805iNGP1LG5`0D51@04a<C01MGEd0HF5Q05iNGP1TI6@0HV9R05IFEP1IFET0<S8b
03<c<`0j>SX0>3Ph04=3@`0o?cl0H61P04Q8B01ADE40B4Q805aLG00e=CD0F5QH03lo?`0a<C40:b/[
03/k>`0`<300>CTi04];B`0Q8B40;Bd]0451@@14A4@0?clo0P0k>c/0CP0h>3P0IFEU06IVIP0b<S80
:BTY04A4A017AdL0EEEE06m_K`20P800:2PX02/[:`1@D500;Rh^05MGE`15ADD0?Shn04I6AP0c<c<0
@d=304E5A@0J6QX0;bl_020P800i>CT0=cLg034a<@0n?Sh0<C4a04M7A`0L71`0?3`l03Ph>00P8200
92@T03@d=00^;Rh0<c<c04a<C00_;bl0E5AD0410@01CDe<0;Bd]05QHF01?Cdl0AdM703dm?@1KFe/0
;bl_07moO`0V9RH08B4Q04m?C`0j>SX0<C4a0410@018B4P0>SXj05YJFP1UIFD0FUYJ03@d=01CDe<0
GEeM07YjNP0a<C40J6QX07alO01JFUX0IVIV02d];@1IFET0AdM704];B`0T92@0<30`03Lg=`80@T92
08P0=cLg04M7A`2IVIT0Q8B4065QH@1kNg/0Bd];0492@P0d=3@0B4Q805YJFP1LG5`0>SXj05eMG@0Q
8B40CDe=05ADE00k>c/0GUiN03dm?@1RHV80:RXZ05EEE@17AdL0<c<c0451@@0X:2P0Bd];04e=C@0h
>3P0E5AD01/K6`1;Bd/0Fe]K05=CD`0[:b/0>SXj04E5A@1OGel0>c/k06ATI01dM7@0>CTi04=3@`19
BDT0E5AD06IVIP1_Kfl0SHf=05UIF@0d=3@0Bd];05aLG014A4@0<C4a03@d=01[Jf/0Lg=c03<c<`1@
D500HV9R07=cL`0];Bd0>c/k04e=C@12@T80C4a<03hn?P1=CDd0FUYJ05IFEP11@D40De=C05QHF00j
>SX0ADE504Q8B00g=cL0F5QH04=3@`19BDT0?3`l03Ti>@1:BTX0F5QH04e=C@0B4Q80@41003De=@0V
9RH0J6QX0410@00^;Rh0<c<c0492@P13@d<0DU9B04e=C@1RHV80@d=3055AD@0c<c<0?Shn03Lg=`0m
?Cd0@d=302XZ:P1VIVH0Cdm?03@d=01;Bd/0H61P03lo?`13@d<0FUYJ0:RXZ01UIFD0IfMW07]kN`1L
G5`0NGUi08f=S@1nOWh0CDe=079bLP13@d<0<S8b04e=C@1MGEd0GUiN04a<C01MGEd0CDe=05IFEP0c
<c<0IfMW0P1TI6@01P1_Kfl0EUIF04i>CP1>CTh0LW9b06QXJ17ooooo000?ooooo`0j0;2`/01@D500
CTi>051@D026QXH0BTY:03<c<`16ATH0IVIV06YZJP2FUYH0<30`02<S8`1EEED0GemO0:^[Z`0g=cL0
8B4Q03/k>`1YJFT0@d=306QXJ01FEUH0<C4a0492@P23Ph<0CDe=06a/K00K6a/0:RXZ03`l?028R8P0
KFe]061PH00m?Cd0A4A404i>CP1UIFD0Bd];05]KF`1CDe<05QHF04e=C@1WIfL0>CTi08J6QP16ATH0
>CTi06MWI`2BTY80CDe=04M7A`11@D40A4A40::RXP1?Cdl0<c<c05QHF080:BTY0>H0RXZ:08b<S00e
=CD0E5AD03/k>`0j>SX0]kNg08R8R00I6AT0:b/[05mOG`1>CTh0QhN7034a<@0W9bL0;Rh^04m?C`1[
Jf/0A4A40:6QX@0M7Ad09BDU04I6AP19BDT0E5AD06=SH`0N7Qh0:BTY05IFEP1ZJVX0AdM707QhN00H
61P0>c/k065QH@1[Jf/0=cLg09^KV`0Z:RX0;2`/04i>CP1PH600AdM707=cL`0/;2`08R8R04m?C`1f
MWH0:BTY03Lg=`1<C4`0A4A408>3P`2CTi<0;2`/04E5A@1JFUX0ADE505]KF`2QXJ40ADE504Q8B01K
Fe/0D51@05=CD`2`/;00FEUI024Q8@1HF5P0G5aL07=cL`1@D5008b<S02d];@1IFET0MgMg05eMG@2F
UYH0?Shn02HV9P1:BTX0BDU906IVIP26QXH0ADE502`/;01<C4`0ZZZZ05mOG`1bLW807AdM03Lg=`17
AdL0FEUI03@d=01CDe<0Hf=S028R8P19BDT0MGEe03<c<`1>CTh0B4Q804E5A@13@d<0Ph>305ADE00T
92@0Fe]K0451@@1KFe/0X:2P04A4A00_;bl0CTi>038b<P0Z:RX0KVi^06MWI`0g=cL0DE5A03lo?`1D
E5@0XZ:R07MgM`0X:2P0B4Q805UIF@1fMWH0SXj>02`/;00];Bd0?Cdm04U9B@1^KVh0ZJVY03Ti>@0d
=3@0IVIV03Ph>01gMgL0ADE501lO7`0_;bl0L71`06ATI028R8P0CTi>02LW9`1NGUh0EUIF04U9B@1H
F5P08R8R04I6AP1HF5P0J6QX05=CD`0m?Cd0;bl_075aL@1hN7P0=3@d06ATI01GEeL0>CTi05ADE01:
BTX0@41006EUI@0c<c<0Bd];06m_K`1TI6@0<S8b05YJFP1ADE40WinO09FEU@0d=3@0@d=305YJFP1G
EeL0DE5A0;>c/`2ATI40;Rh^065QH@1aLG40FUYJ0::RXP2VYZH0<30`038b<P18B4P0EEEE06EUI@2;
Rh/0=cLg051@D01LG5`0K6a/07MgM`2MWId0@41004a<C01XJ6P0H61P05eMG@2LW9`0?clo030`<00i
>CT0JVYZ08N7Q`1[Jf/0Hf=S02@T9017AdL0Cdm?05QHF019BDT0FUYJ03Hf=P0N7Qh0IVIV02d];@0W
9bL0EUIF02`/;1cooooo07h0EUIF04i>CP0h>3P0@T9206YZJP1EEED0B4Q806MWI`1`L700:2PX04E5
A@1>CTh0OGem06i^KP1]KFd0ADE505]KF`1@D500HV9R05EEE@0h>3P0@d=303Ph>01BDU80>CTi02h^
;P0n?Sh0Hf=S06UYJ@1SHf<0BTY:02l_;`1LG5`0I6AT04I6AP1@D500MWIf08^;R`1PH600=cLg03Xj
>P0f=SH0=3@d03`l?019BDT0EeMG04E5A@1;Bd/0AdM705QHF00l?3`0EEEE04I6AP0m?Cd0;2`/04A4
A00d=3@0>SXj061PH00l?3`0?Cdm04e=C@1;Bd/0B4Q804];B`11@D40Cdm?08F5Q@20P800@41003`l
?01bLW80CTi>02@T900c<c<0AdM7024Q8@0[:b/0>c/k020P801<C4`0Cdm?0492@P1:BTX0>3Ph04I6
AP0^;Rh08R8R030`<00P82007AdM03/k>`0a<C40@d=303/k>`1>CTh06ATI03@d=01CDe<0;2`/0492
@P0Z:RX0;bl_03`l?00_;bl0:RXZ04M7A`0i>CT0CDe=01hN7P0m?Cd0?clo03`l?012@T80I6AT02@T
901QHF40=cLg020P801FEUH0@D51028R8P11@D40<30`04M7A`16ATH207moO`0B05EEE@1TI6@0F5QH
06a/K01>CTh0Ph>3069RHP1bLW80L71`04I6AP1oOgl0F5QH03Xj>P0^;Rh0?Cdm03`l?01EEED08b<S
0P14A4@03@1OGel0BTY:0451@@1^KVh0Bd];08f=S@0`<3009BDU061PH01LG5`0:RXZ04E5A@0Y:BT0
0P1SHf<08@1=CDd0VIVI03Xj>P1SHf<0>SXj04a<C01;Bd/0C4a<03`l?00d=3@0MGEe05YJFP1>CTh0
JVYZ02PX:016ATH0=CDe03Hf=P11@D40ATI605YJFP2JVYX0>3Ph04U9B@1EEED0=3@d05EEE@12@T80
DE5A03dm?@1lO7`0YJFU05QHF00205UIF@1L03@d=00^;Rh0Fe]K03dm?@10@400ATI603lo?`1FEUH0
;Bd]04Q8B01KFe/0IVIV0451@@0h>3P0Cdm?03Xj>P0c<c<0DU9B079bLP1=CDd0A4A405UIF@12@T80
B4Q803Ph>00a<C40De=C04M7A`1dM7@0EeMG05aLG01SHf<0KVi^06a/K00a<C40E5AD04I6AP1?Cdl0
JFUY059BDP1<C4`0IVIV06ATI01KFe/0D51@03Ti>@15ADD0=SHf05]KF`17AdL0@T9202l_;`1;Bd/0
Cdm?02DU9@1eMGD0EUIF03Ti>@0j>SX0@d=304Q8B01LG5`0>SXj051@D00k>c/0BTY:07YjNP1QHF40
DE5A05]KF`17AdL0@41007MgM`1BDU80ATI6051@D00Z:RX0?3`l04=3@`1BDU80>c/k04I6AP1ADE40
MWIf05QHF017AdL0DE5A04];B`14A4@0De=C051@D01IFETAooooo`003oooool0ZP25QHD0JFUY09VI
V@1:BTX0F5QH05UIF@1[Jf/0M7Ad02PX:01DE5@0IFEU05ADE01@D500GUiN038b<P18B4P0BDU902LW
9`1ZJVX0@T9203De=@1BDU80Jf][030`<014A4@0<c<c08B4Q01nOWh0=SHf02DU9@1=CDd0;Bd]03Ti
>@2KVi/071`L03Ti>@1EEED0ATI60451@@2LW9`0VYZJ01TI6@0c<c<0IFEU04Y:BP2/[:`0E5AD02TY
:@0j>SX0MgMg05aLG01hN7P0Lg=c028R8P1?Cdl0Kfm_05IFEP2KVi/0@T9202PX:00j>SX0QhN706YZ
JP1^KVh0<30`02PX:01EEED0V9RH07moO`1OGel0SXj>01lO7`16ATH0Fe]K020P801>CTh0@D5102TY
:@0j>SX0GemO03De=@17AdL0DU9B030`<01PH600TI6A02XZ:P0O7al0>SXj03/k>`19BDT0Q8B401lO
7`0R8R80D51@0410@01>CTh0V9RH04I6AP0O7al0=3@d06QXJ01OGel0_Kfm03Ph>00O7al0@D510820
P01CDe<0MgMg07UiN@0N7Qh0JFUY09:BTP1QHF40];Bd0:NWY`0Q8B40=cLg06m_K`1bLW80Jf][04U9
B@0W9bL0@T9205iNGP24Q8@0?clo0820P00m?Cd0BTY:07alO014A4@0;Rh^05]KF`0Y:BT0>CTi08N7
Q`1oOgl0@T9204Y:BP0_;bl0B4Q80861P@1MGEd0=cLg06=SH`1?Cdl0=cLg08j>SP1lO7`0:2PX05=C
D`1:BTX0>c/k079bLP2RXZ80=3@d03De=@1PH600C4a<079bLP1nOWh08B4Q03dm?@1@D500MGEe05AD
E02FUYH0AdM70P1:BTX0=P1GEeL0LW9b07IfMP0V9RH0=cLg0451@@1BDU80IfMW06ATI00L71`0C4a<
061PH01FEUH0@T9208f=S@1ZJVX0:2PX06QXJ01BDU80Fe]K06=SH`0N7Qh0:RXZ05mOG`1bLW80>CTi
0492@P0o?cl0CTi>06IVIP0a<C40<S8b04m?C`0M7Ad0Hf=S06QXJ00];Bd0?3`l0410@01FEUH0Ng]k
03<c<`0/;2`0De=C03Lg=`2GUiL0ADE502<S8`17AdL0E5AD04M7A`2KVi/0Rh^;034a<@80H61P03h0
T92@08^;R`0h>3P0;bl_05]KF`26QXH0R8R80:JVYP1PH600Bd];06ATI01IFET0PH610:ZZZP17AdL0
?3`l04Y:BP2BTY80MgMg08N7Q`0d=3@0;Rh^04a<C02@T900GUiN0451@@1XJ6P0<30`03Ph>01gMgL0
Hf=S04a<C01aLG40:BTY04U9B@1hN7P0PH610410@01<C4`09BDU04Q8B01TI6@0G5aL01lO7`0m?Cd0
L71`02PX:01>CTh0NGUi02PX:00g=cL0@d=303Xj>P1eMGD0O7al08B4Q00Q8B40@T9203`l?01UIFD0
SHf=038b<Qcooooo05D0DU9B04e=C@0[:b/0;Rh^0451@@15ADD0<30`04a<C00l?3`06a/K04I6AP0l
?3`0BDU904i>CP1TI6@0BTY:059BDP0o?cl0ATI603Xj>P0Q8B40?clo02`/;00o?cl0B4Q803Ti>@14
A4@0=cLg04E5A@14A4@0?clo03@d=015ADD0@D5104A4A01<C4`0Bd];051@D01BDU80<C4a03<c<`0m
?Cd0;2`/03Ph>00a<C40;Bd]02TY:@0b<S80<c<c03Xj>P0W9bL0?Shn03`l?00d=3@071`L02`/;00o
?cl0Fe]K04];B`0Y:BT0<C4a04Q8B01HF5P0<c<c05ADE01XJ6P0ADE504i>CP1FEUH0DU9B05ADE01U
IFD0EUIF03`l?01QHF40J6QX02TY:@0[:b/0BDU902XZ:P1PH600AdM70492@P11@D40?3`l0080AdM7
01<0<c<c03dm?@0e=CD0AdM704E5A@0h>3P0C4a<03Lg=`1:BTX0;2`/04A4A01<C4`0;bl_03De=@0c
<c<0A4A40492@P17AdL0>SXj0080DE5A07P0De=C03lo?`1GEeL0A4A404E5A@1?Cdl0NWYj01lO7`1c
Lg<0JVYZ03lo?`1cLg<0@d=3034a<@0h>3P0;bl_05ADE00i>CT0CTi>04];B`11@D40RXZ:05MGE`1/
K6`0>SXj07YjNP1^KVh0D51@06IVIP1=CDd0EeMG04E5A@12@T80ADE505=CD`0b<S80ATI604=3@`1=
CDd0F5QH08b<S01aLG40Fe]K08V9R@1WIfL0F5QH02HV9P0/;2`0EeMG04i>CP0];Bd0@T9201lO7`1[
Jf/0HV9R04Y:BP1DE5@0<S8b05eMG@0d=3@0Hf=S05EEE@17AdL0@D510410@015ADD0@D51061PH01^
KVh0:RXZ04I6AP0g=cL0@41005EEE@1OGel0?clo05YJFP0i>CT0D51@04e=C@1<C4`0Lg=c059BDP1l
O7`0DU9B05IFEP20P800AdM7034a<@1IFET0?Cdm03lo?`0e=CD0<30`04=3@`17AdL0DE5A069RHP0_
;bl0ATI605IFEP1dM7@0EEEE03Hf=P1>CTh0>c/k04Q8B01RHV80Cdm?05iNGP1<C4`0CTi>04e=C@1J
FUX0>3Ph02/[:`1?Cdl0CDe=03dm?@13@d<206ATI00l05MGE`1NGUh08b<S051@D00l?3`0<S8b06QX
J01eMGD0Cdm?04=3@`0k>c/0@41004Y:BP0V9RH0BTY:034a<@1@D500;Bd]02XZ:P0h>3P0FUYJ059B
DP16ATH0HF5Q03`l?00_;bl0AdM704i>CP13@d<0B4Q803hn?P24Q8@0GUiN069RHP1eMGD0KVi^04m?
C`1WIfL0=cLg01PH601GEeL0CDe=04M7A`1QHF40;Bd]04m?C`0d=3@0H61P03Hf=P13@d<0=cLg07mo
O`1jNWX0D51@055AD@1>CTh0Cdm?04];B`1BDU80GemO4Oooool000oooooo07h0RXZ:05ADE02IVIT0
KVi^04i>CP1`L700T92@0:NWY`0g=cL0ADE504i>CP10@400MgMg075aL@0V9RH0CTi>051@D017AdL0
X:2P08^;R`0D51@0A4A408f=S@17AdL0OGem01`L701;Bd/0EeMG04I6AP1HF5P0U9BD04a<C00I6AT0
O7al04Y:BP1JFUX0Hf=S03Ph>00Q8B40EEEE08J6QP19BDT0Jf][04I6AP0a<C40@D5106MWI`0k>c/0
K6a/03`l?00^;Rh0FEUI09>CT`1CDe<0CDe=02LW9`0b<S80CDe=04a<C00Y:BT0MWIf05]KF`1NGUh0
I6AT01`L700S8b<0?Shn04=3@`1MGEd0IFEU08^;R`0S8b<0>CTi059BDP1GEeL0O7al069RHP0/;2`0
>CTi06EUI@1;Bd/0C4a<07MgM`0`<300;Rh^05YJFP1LG5`0EUIF071`L00N7Qh0:BTY05EEE@1SHf<0
BTY:061PH00Q8B40=CDe05aLG01aLG40?3`l075aL@0m?Cd0<C4a051@D01RHV80<30`04m?C`0o?cl0
:BTY0492@P1WIfL0?Cdm06i^KP0f=SH0:RXZ0861P@2][Jd0>3Ph02XZ:P1:BTX0?3`l09bLW02GUiL0
9bLW02d];@0h>3P203dm?@2R0:>SX`2ATI40:RXZ051@D01LG5`0FUYJ09jNWP0k>c/0;2`/05ADE01m
OGd0Jf][079bLP0X:2P0=SHf07UiN@2MWId0GemO0;jn_P1YJFT0=CDe05=CD`2d];@0FEUI08Z:RP0k
>c/0=CDe06UYJ@1]KFd0E5AD04i>CP1IFET092@T05QHF02HV9P0Lg=c04a<C01aLG407QhN03Xj>P1P
H600CDe=05MGE`1HF5P09BDU069RHP2b/[80JVYZ03/k>`1fMWH0ATI60820P02VYZH0DU9B03/k>`1b
LW80A4A403/k>`2FUYH0WYjN03`l?011@D40?3`l075aL@2[Zj/0<30`02DU9@0a<C40@D5106][J`1J
FUX07alO03Lg=`1JFUX0EUIF07inOP1mOGd0;Bd]01TI6@1>CTh0L71`08:2PP0J6QX09bLW06EUI@1D
E5@0@D5106a/K00U9BD0DU9B04i>CP0o?cl0JVYZ03De=@12@T80I6AT07AdM00f=SH0JFUY038b<P1?
Cdl0P82005EEE@1BDU80EeMG02`/;00l?3`0PH6107=cL`1<C4`0EEEE03`l?01KFe/0UIFE08j>SP0h
>3P0KFe]04M7A`1ADE40X:2P06a/K00];Bd0>3Ph05EEE@19BDT0KFe]0;>c/`1?Cdl0<30`05MGE`1C
De<0LG5a0;Jf]P0o?cl09RHV05]KF`1dM7@0MgMg092@T00^;Rh092@T06ATI01ZJVX0BTY:075aL@2W
YjL071`L03dm?@1SHf<0@d=307=cL`1HF5P05QHF02<S8`11@D40Lg=c05=CD`1TI6@0:RXZ02<S8`1k
Ng/0Ogmo7?ooool0701HF5P0FUYJ03`l?011@D40De=C06=SH`1:BTX0M7Ad065QH@0P8200CDe=04m?
C`1_Kfl0KVi^07QhN01HF5P0MGEe04M7A`1EEED0DU9B01hN7P0d=3@09bLW03@d=00h>3P0=3@d04I6
AP1WIfL206ATI00=05mOG`0k>c/0JVYZ06UYJ@1CDe<0CTi>065QH@1GEeL0FUYJ01lO7`0^;Rh0?Cdm
02HV9P0204=3@`0:05QHF00Z:RX0D51@03dm?@1LG5`0:b/[04A4A01HF5P0A4A401`L7080?Cdm08@0
;Bd]05QHF00`<300=CDe04M7A`16ATH0=cLg03`l?00^;Rh0@T9205UIF@1CDe<0?3`l0451@@1=CDd0
>c/k03lo?`0c<c<0<C4a01XJ6P0O7al0Bd];01TI6@0d=3@0>CTi02h^;P0c<c<0;2`/02/[:`0Z:RX0
7alO02DU9@0Y:BT0:2PX03Ti>@0h>3P0?3`l02/[:`10@400<c<c02d];@0f=SH0;bl_03/k>`0g=cL0
;bl_04E5A@1EEED0=cLg04m?C`1HF5P0K6a/0492@P0l?3`0@410055AD@1@D500GemO03/k>`1FEUH0
?clo04M7A`1[Jf/0BDU904=3@`0m?Cd0;Bd]03Ti>@1:BTX0GUiN04M7A`0b<S80NGUi06YZJP1kNg/0
=cLg092@T01^KVh0EUIF07YjNP16ATH0MGEe05ADE018B4P0C4a<05MGE`0o?cl0@d=302l_;`11@D40
@41007]kN`1jNWX0De=C05YJFP17AdL0Lg=c02LW9`0Y:BT0IVIV05]KF`0g=cL0ADE501hN7P1mOGd0
De=C02PX:01?Cdl0>3Ph075aL@0k>c/0<c<c03Ph>01OGel0@D5102d];@1/K6`0EEEE03Hf=P10@400
7QhN02`/;00n?Sh0@d=3028R8P0/;2`0?Shn061PH00b<S80EeMG05aLG00^;Rh203Lg=`0N04E5A@1@
D500MGEe0:j^[P1:BTX0BDU905UIF@1:BTX0<30`038b<P0`<300?Cdm04A4A00T92@0@d=302XZ:P1<
C4`0:2PX03dm?@15ADD0@D5105QHF00j>SX0?clo05EEE@1GEeL0ATI60492@P1PH600=CDe0P0k>c/0
@`0`<300@T920451@@17AdL0CDe=06IVIP1hN7P0D51@05mOG`0I6AT0;Rh^03Lg=`0f=SH0JVYZ07Ad
M00i>CT0?clo055AD@10@400C4a<02DU9@1RHV80<C4a04Y:BP0_;bl0A4A403lo?`1nOWh0M7Ad03Xj
>P1CDe<0FUYJ03Xj>P1RHV80Jf][04=3@`1FEUH0ATI606YZJP0c<c<0BDU9065QH@1>CTh0DU9B0:FU
Y@1KFe/06a/K069RHP19BDT0D51@06EUI@0b<S80GemO03<c<`1BDU80?clo05]KF`0Z:RX0HV9R06QX
J01VIVH0F5QH05=CD`16ATH0Bd];04e=C@1<C4`04Oooool000oooooo0680/K6a05IFEP1gMgL0OWin
07UiN@1?Cdl0EUIF075aL@1>CTh0MgMg07AdM00m?Cd0B4Q806QXJ017AdL0M7Ad02d];@0Y:BT0I6AT
08F5Q@1ADE40PH6106ATI00Y:BT0CTi>04A4A01PH600Ogmo02@T900k>c/0HF5Q05QHF01@D500H61P
02LW9`1@D500J6QX03Lg=`0V9RH0HV9R04Y:BP0V9RH0I6AT06i^KP0l?3`0G5aL0451@@19BDT0QXJ6
07inOP0g=cL0CTi>06=SH`1>CTh0Ng]k0492@P0f=SH0CDe=051@D00i>CT0MGEe06YZJP0c<c<0Jf][
04E5A@1HF5P0SHf=06UYJ@0b<S80I6AT06UYJ@1<C4`0SXj>03<c<`0Z:RX0AdM704a<C00f=SH0KVi^
09JFUP0X:2P07AdM05]KF`14A4@0Jf][075aL@0g=cL0=3@d05MGE`1OGel0BTY:05aLG00d=3@0BTY:
06a/K010@400BTY:09BDU080=3@d00@0P82005eMG@13@d<0GUiN0P0o?cl0^02@T900Rh^;03Xj>P1:
BTX0CTi>05MGE`2SXj<0De=C02l_;`1OGel0KFe]05=CD`1LG5`0U9BD03/k>`1CDe<0I6AT04=3@`1X
J6P0T92@03Ph>00c<c<0Bd];05UIF@1OGel0Lg=c02HV9P18B4P0MgMg06][J`1OGel0JVYZ03Xj>P0^
;Rh0Fe]K04M7A`1/K6`0TI6A03`l?013@d<0G5aL08N7Q`1KFe/0OGem04I6AP0g=cL0Lg=c06a/K00e
=CD0DE5A06i^KP0m?Cd0GemO06a/K00_;bl0ATI605=CD`14A4@0Fe]K08B4Q01:BTX0;bl_071`L00n
?Sh0Lg=c09fMW@0b<S80@d=306IVIP1@D500?clo08n?S`1MGEd0>c/k069RHP0m?Cd0Bd];09BDU01V
IVH09bLW04=3@`1VIVH0Kfm_07]kN`0[:b/0?3`l05MGE`1XJ6P0FUYJ07alO00d=3@08R8R075aL@1>
CTh0OGem04a<C00O7al0>SXj08^;R`25QHD0Lg=c0410@012@T80KFe]04e=C@1RHV80RXZ:03Hf=P1<
C4`0Q8B404Y:BP1SHf<0;2`/04a<C022PX80GemO03Hf=P1fMWH0Jf][03lo?`29RHT0GUiN05EEE@1d
M7@0G5aL07=cL`2DU9@0Ogmo0492@P1ADE40KVi^07]kN`2=SHd0ADE504Y:BP1VIVH0N7Qh055AD@26
QXH0Q8B403Xj>P1[Jf/0JFUY04i>CP20P800TY:B03Lg=`0d=3@0IVIV06a/K01cLg<0M7Ad02h^;P0n
?Sh0MWIf0820P01hN7P0LW9b04e=C@17AdL0Kfm_0410@016ATH0O7al02l_;`0/;2`0A4A406EUI@1I
FET0LW9b05aLG00m?Cd0I6AT07emO@0m?Cd0CTi>06YZJP11@D40<30`07EeM@14A4@0>CTi04m?C`0g
=cLLooooo`2X05]KF`1WIfL0?3`l03<c<`1>CTh0CDe=0492@P1^KVh0MgMg03Xj>P1GEeL0EUIF06a/
K01dM7@0DU9B04Q8B01EEED0C4a<04I6AP15ADD0=CDe0410@00c<c<0B4Q804e=C@0i>CT0DE5A04Y:
BP1FEUH0Lg=c04a<C00n?Sh0CTi>051@D01GEeL0EUIF04m?C`1KFe/0De=C03Hf=P0c<c<0=SHf0451
@@15ADD0Bd];04=3@`0`<300@d=304e=C@1?Cdl09RHV04I6AP1EEED0BDU902XZ:P18B4P0?Shn03Hf
=P1SHf<0@d=303/k>`1ADE40EEEE02d];@19BDT0Cdm?05ADE01cLg<0M7Ad03dm?@16ATH0K6a/05EE
E@13@d<0DU9B06IVIP0c<c<0=CDe05eMG@0R8R80AdM704i>CP15ADD0BTY:03Hf=P11@D40ATI602/[
:`0j>SX0=CDe03<c<`1<C4`0?Cdm04i>CP0o?cl0EUIF02HV9P0_;bl0E5AD038b<P10@400=CDe03Ph
>016ATH0?Cdm03`l?01@D500@D5104U9B@0e=CD0>SXj03<c<`0a<C40?clo065QH@0U9BD0A4A404m?
C`0g=cL0FEUI0410@00T92@0<S8b030`<011@D40@d=3069RHP1>CTh0De=C0:2PX01IFET0Kfm_03Ph
>01WIfL0FUYJ06m_K`1^KVh0AdM7075aL@1JFUX0BDU9069RHP1YJFT0?3`l04Y:BP0g=cL0E5AD04m?
C`1gMgL0JVYZ061PH01UIFD0GUiN07]kN`0c<c<0;2`/04Q8B01CDe<08B4Q05ADE00X:2P0Ogmo05MG
E`15ADD0I6AT03@d=01MGEd0:b/[0P1:BTX02015ADD0>SXj038b<P1CDe<0DE5A04i>CP1ADE40;2`/
0P0k>c/08@14A4@0@D5105EEE@14A4@0IfMW03De=@0f=SH0>c/k02XZ:P15ADD0<S8b05mOG`1IFET0
H61P09>CT`1<C4`0>c/k05iNGP13@d<0=SHf04=3@`16ATH0E5AD04m?C`0k>c/0DU9B01/K6`1>CTh0
?Shn05mOG`1LG5`0=3@d059BDP0203dm?@0H05UIF@1MGEd0CDe=03hn?P1?Cdl0@d=3059BDP0l?3`0
:2PX0410@00l?3`0A4A404=3@`1LG5`0H61P055AD@1TI6@04Q8B03Hf=P0a<C40:RXZ04m?C`1[Jf/0
?clo0P15ADD0<@0j>SX0D51@02TY:@1>CTh0=3@d04i>CP0a<C40Cdm?04M7A`1SHf<0FUYJ0410@01[
Jf/0EUIF024Q8@1:BTX0Kfm_04e=C@1KFe/0AdM707]kN`1MGEd0Jf][06MWI`1>CTh0@d=306][J`11
@D40;bl_06=SH`1@D500EEEE069RHP0g=cL0C4a<04Q8B01LG5`0=cLg04e=C@10@400Ogmo04m?C`1:
BTX0Fe]K04e=C@19BDT0FEUI05IFEP1@D5004Oooool000oooooo0?l0QXJ607moO`3<c<`0CDe=06AT
I01kNg/0ZZZZ05YJFP19BDT0AdM708j>SP1BDU80YjNW071`L00e=CD0H61P04e=C@19BDT0PH610492
@P0a<C40E5AD08b<S01FEUH0NGUi01dM7@1JFUX0LW9b065QH@13@d<0NWYj02LW9`0n?Sh0CDe=030`
<00Y:BT0DU9B038b<P0k>c/0GEeM07IfMP0l?3`0?Shn05ADE01]KFd0L71`02PX:00W9bL0Cdm?05eM
G@1BDU80TI6A08R8R00U9BD0DU9B07UiN@1QHF40^;Rh02HV9P0[:b/0B4Q806][J`1RHV80Shn?01@D
500W9bL0Cdm?06YZJP16ATH0^[Zj09:BTP0J6QX0?Cdm04Q8B01QHF40I6AT02d];@0^;Rh0=SHf05QH
F01CDe<0>SXj03`l?00N7Qh0;2`/05aLG01WIfL0>SXj0861P@12@T8092@T07YjNP0a<C40B4Q806EU
I@0K6a/0ADE5096AT@1ZJVX0;Bd]03/k>`0o?cl0E5AD09VIV@0V9RH07QhN030`<01@D500?3`l096A
T@21PH40;bl_04=3@`19BDT0FUYJ0;Jf]P22PX806ATI03`l?01YJFT0B4Q807MgM`1`L7006a/K04M7
A`2FUYH0J6QX04e=C@1PH600=cLg03lo?`1jNWX0?Shn07YjNP1iNGT05ADE03De=@1oOgl0GemO03Ph
>019BDT07alO0410@02BTY80LW9b02/[:`1FEUH0;Rh^02@T901dM7@0Q8B404I6AP1/K6`0@41002TY
:@1HF5P0_;bl06ATI00h>3P0EUIF055AD@28R8P0Xj>S02/[:`0o?cl0BDU904Y:BP1oOgl0Ph>303Hf
=P0j>SX0ADE503Ph>021PH40ZJVY03<c<`0T92@0=3@d05UIF@2EUID0Ti>C02/[:`16ATH0ADE506QX
J01WIfL0MWIf04e=C@0c<c<0J6QX04Y:BP1UIFD0QhN701dM7@18B4P0KFe]06MWI`1ADE40E5AD03Ti
>@11@D40Q8B4055AD@17AdL0BTY:020P801HF5P0FUYJ03Lg=`1HF5P06QXJ03De=@2TY:@0NGUi03dm
?@1MGEd08B4Q09jNWP1HF5P0<C4a05UIF@12@T80<c<c09^KV`1nOWh08B4Q038b<P1ADE40P82008V9
R@0V9RH0?3`l065QH@21PH40W9bL0:n_[`1SHf<0>3Ph07QhN01MGEd0KFe]0:j^[P0i>CT0@410061P
H01UIFD0FEUI08b<S00g=cL0:RXZ05ADE029RHT0HF5Q06YZJP2LW9`002<0;bl_03hn?P25QHD0CTi>
07MgM`1HF5P09BDU03Lg=`1RHV80JVYZ04m?C`1kNg/0;Rh^03/k>`2BTY80R8R804I6AP1]KFd0Cdm?
01TI6@1BDU80O7al03Ph>01:BTX0ADE5034a<@13@d<0PX:206ATI00V9RH0@T9205MGE`1KFe/0QHF5
03hn?P0Looooo`80De=C00`0Bd];05iNGP1_Kfl0F5QH04];B`16ATH0BDU902LW9`1<C4`0AdM706IV
IP1bLW8209FEU@0/07moO`1;Bd/0G5aL05MGE`10@400@T9204I6AP1LG5`0@T9203dm?@1NGUh0Kfm_
061PH01LG5`0GEeM051@D01QHF40EeMG05EEE@1BDU80FUYJ051@D01IFET0:BTY02HV9P11@D40D51@
059BDP12@T80DE5A03Hf=P0o?cl0:BTY03Ph>00X:2P0<S8b04I6AP12@T808b<S03Ti>@0g=cL0CTi>
055AD@0f=SH203Ti>@0W0492@P0];Bd0@41004e=C@0a<C40B4Q804i>CP13@d<0EeMG0451@@15ADD0
=cLg03Ti>@1:BTX09bLW02PX:01VIVH0:BTY05MGE`1FEUH0BTY:04];B`10@400ATI60492@P0^;Rh0
;bl_03Ph>00g=cL0B4Q803@d=019BDT0@T9204m?C`0e=CD0>3Ph04U9B@0X:2P0?clo0080=CDe02P0
@d=304M7A`0o?cl0EeMG04e=C@1BDU80;bl_05YJFP0e=CD0=SHf05QHF01LG5`09BDU05EEE@1UIFD0
K6a/07]kN`11@D40=CDe03dm?@0a<C40=cLg05EEE@1>CTh0AdM702`/;017AdL0I6AT079bLP0m?Cd0
G5aL03dm?@1JFUX0NWYj03hn?P1kNg/0EUIF03`l?00[:b/0>SXj0P17AdL0;`0`<300@d=305ADE01h
N7P0P82007=cL`1fMWH0GUiN05EEE@0g=cL0?clo06EUI@1IFET0<30`05]KF`0P8200Jf][04Y:BP0T
92@0EeMG030`<01NGUh0=CDe03Ti>@1@D500G5aL0451@@0S8b<0B4Q804U9B@0d=3@0?Shn02d];@1E
EED0>SXj051@D00l?3`0Bd];03De=@1UIFD0?Shn02HV9P0m?Cd0=3@d04e=C@1;Bd/0De=C0080MGEe
0600[:b/06MWI`1<C4`0IVIV05mOG`1ADE40>SXj03Lg=`1PH600N7Qh04I6AP1MGEd09RHV05IFEP0f
=SH0DU9B05YJFP1LG5`0NWYj05aLG018B4P0DU9B069RHP1PH600B4Q806ATI01<C4`0Cdm?0451@@15
ADD0?Cdm04A4A013@d<0BDU9061PH01bLW80D51@06=SH`0i>CT0ADE504A4A018B4P0IVIV04e=C@0l
?3`0CDe=06a/K01FEUH0GUiN02TY:@1LG5`0820P04U9B@1:BTX0IFEU04Y:BP1/K6`0M7Ad02d];@1F
EUH0De=C010@401]KFd0EEEE03Xj>P1oOgl0Hf=S071`L01?Cdl0/K6a07EeM@27QhL0L71`0:RXZ01Q
HF40>3Ph08F5Q@1OGel0Ogmo06YZJP0f=SH0ADE503`l?01@D500B4Q8079bLP0f=SH0Hf=S04U9B@1X
J6P0Lg=c059BDP1<C4`0DE5A06MWI`1DE5@Aooooo`003oooool0B@1hN7P0EUIF06QXJ01/K6`0H61P
03@d=01@D500VYZJ04I6AP1]KFd0IFEU03<c<`1CDe<0P82003Hf=P0l?3`0=CDe05MGE`1kNg/0CTi>
02LW9`11@D40>3Ph059BDP2BTY808b<S030`<01NGUh0>CTi07=cL`3?cll0De=C01@D501:BTX0@D51
07=cL`2RXZ80>3Ph020P801KFe/0DE5A04Y:BP1lO7`0Jf][03Xj>P1nOWh0LG5a04a<C01[Jf/0?3`l
02LW9`0d=3@0PX:205YJFP1IFET051@D0451@@1dM7@0JFUY038b<P27QhL0Bd];0492@P29RHT0BDU9
04e=C@1SHf<0=3@d04=3@`1WIfL0YJFU03Ph>017AdL00P18B4P0TP2NWYh0PH6101LG5`0c<c<0FUYJ
04U9B@1HF5P0KVi^01XJ6P0T92@0:b/[04];B`1TI6@0UiNG03Hf=P0Z:RX0A4A4051@D01hN7P0Xj>S
02HV9P0l?3`0=3@d06=SH`1<C4`0IFEU04Q8B016ATH0Fe]K05ADE012@T80J6QX03dm?@0F5QH0:2PX
069RHP16ATH0M7Ad03Lg=`0c<c<0Lg=c09:BTP1JFUX0FEUI07YjNP0c<c<0WinO0:>SX`0W9bL0@410
05aLG00h>3P0JVYZ07alO00i>CT0=CDe04m?C`0m?Cd0Ogmo09VIV@10@4007QhN05YJFP1UIFD0GUiN
04];B`0J6QX0=3@d06EUI@2PX:00LW9b0:JVYP0i>CT07alO04];B`1PH600ADE50:VYZ@0R8R80;2`/
038b<P1CDe<0LW9b06MWI`1HF5P0;Rh^06YZJP20P800DE5A08n?S`2IVIT07QhN02<S8`25QHD0DU9B
06a/K01:BTX0>CTi03/k>`1oOgl0MGEe03`l?01PH6006a/K03/k>`2KVi/0D51@03De=@1BDU806ATI
03<c<`1jNWX0Z:RX04i>CP11@D40;Bd]079bLP2EUID0;2`/034a<@1=CDd0=3@d04m?C`1jNWX092@T
03/k>`19BDT0LW9b07QhN01fMWH09BDU03`l?01>CTh0GemO08V9R@0P82008b<S07UiN@2>SXh0HV9R
0820P00V9RH0DU9B069RHP1`L700W9bL0P0k>c/0@`1fMWH0TY:B05aLG02=SHd0=SHf04m?C`2g]kL0
Ph>304=3@`1HF5P08R8R03hn?P1[Jf/0SXj>06YZJP1CDe<0:2PX05mOG`1oOgl0LW9b03Lg=`18B4P0
D51@04];B`2SXj<0Fe]K03Ti>@18B4P0>CTi04I6AP19BDT0PH61069RHP12@T80CTi>05]KF`23Ph<0
VIVI02h^;P0_;bl0E5AD05iNGP1YJFT0T92@02/[:`0O7al0@d=304a<C01GEeL0QXJ609JFUP0O7al0
<S8b069RHP19BDT0O7al06MWI`0P8200AdM7059BDP1dM7@0ADE506ATI00G5aL0@D5107]kN`1`L700
7?ooool0E@1TI6@0OWin04Y:BP0e=CD0A4A406a/K013@d<0FUYJ06YZJP0Y:BT0N7Qh06ATI01FEUH0
GEeM05=CD`1>CTh0Kfm_06EUI@19BDT0A4A4024Q8@0g=cL0<C4a03dm?@0l?3`0>c/k0451@@1DE5@0
FUYJ05]KF`1;Bd/0;2`/04Y:BP18B4P0ATI605EEE@1FEUH0FUYJ04M7A`19BDT0<c<c04A4A00W9bL0
@41004e=C@10@400<S8b03Xj>P0i>CT0BDU904I6AP1?Cdl0EUIF04M7A`0h>3P0B4Q803De=@0Q8B40
B4Q804A4A00m?Cd0=3@d04m?C`11@D40D51@04M7A`18B4P0GUiN05aLG00];Bd0=CDe05aLG01ADE40
<c<c03Ph>01/K6`092@T02/[:`10@4008b<S03`l?016ATH0=SHf03@d=00f=SH00P0`<300b`0W9bL0
;bl_01lO7`0a<C40?clo02XZ:P0o?cl0>CTi04e=C@0W9bL0;Bd]03Xj>P11@D40?Cdm030`<016ATH0
BTY:05UIF@0_;bl0BDU905MGE`1HF5P07QhN04I6AP0g=cL0:RXZ04=3@`1@D500?3`l03lo?`0b<S80
:BTY0451@@0n?Sh07QhN04A4A00j>SX0>CTi051@D01hN7P0Fe]K04i>CP1hN7P0>SXj065QH@0h>3P0
MWIf04];B`1YJFT0Hf=S04=3@`2IVIT0FEUI06MWI`1IFET0KFe]04A4A01WIfL0:2PX04M7A`1JFUX0
MgMg04m?C`1HF5P0TI6A04m?C`1YJFT0@T9207moO`1bLW80CDe=02/[:`1<C4`092@T07QhN01NGUh0
>SXj07alO00c<c<0>c/k03Ph>016ATH0F5QH059BDP0g=cL0=CDe075aL@1JFUX0AdM704=3@`12@T80
IVIV04];B`1ADE40<C4a05YJFP14A4@0Kfm_04e=C@11@D40I6AT02d];@1;Bd/0@D5105UIF@1<C4`0
CTi>08b<S01HF5P0O7al07moO`10@400A4A405]KF`1FEUH0BDU904e=C@0l?3`0D51@03Ph>02CTi<0
>3Ph05=CD`1EEED0:RXZ04Q8B00l?3`0=SHf04Q8B01JFUX0G5aL03De=@1CDe<0ATI604a<C00e=CD0
>3Ph03`l?00d=3@0B4Q804M7A`1QHF40EEEE04=3@`1ZJVX051@D05UIF@13@d<0>CTi03dm?@1EEED0
ADE504U9B@0];Bd0@41005QHF00V9RH0?Shn01dM7@0n?Sh06ATI02XZ:P0P8200De=C059BDP0];Bd0
T92@071`L00m?Cd0@D51061PH01EEED0Hf=S069RHP1oOgl0Fe]K04a<C01>CTh0De=C06a/K02BTY80
EeMG0451@@1GEeL0FEUI04A4A01FEUH0BTY:04I6AP1DE5@0I6AT03hn?P14A4@0ADE507moO`1LG5`0
BTY:05IFEP0o?cl0@T9206EUI@1ADE40EEEE017ooooo000?ooooo`1a0;no_`1CDe<0OWin05iNGP2V
YZH0ATI603lo?`1@D500M7Ad09nOW`27QhL0<c<c03De=@1NGUh0K6a/079bLP0P8200<S8b04I6AP1T
I6@0R8R80:ZZZP0c<c<0>CTi06ATI00n?Sh0IfMW05=CD`0Q8B40?3`l06IVIP1dM7@0@T92051@D00X
:2P0?clo071`L01[Jf/0<S8b06QXJ00l?3`0:BTY05QHF01bLW809bLW05MGE`0[:b/0LG5a09FEU@0j
>SX08R8R030`<01=CDd0GEeM09bLW00Y:BT092@T055AD@0^;Rh0B4Q80:RXZ01eMGD0:b/[06YZJP1^
KVh0IVIV0;Zj^P1@D500=SHf04];B`1JFUX0EUIF08Z:RP0O7al0>3Ph05YJFP2FUYH0Bd];06m_K`27
QhL0;Bd]01hN7P1kNg/0=SHf06IVIP11@D406a/K02XZ:P1gMgL0XJ6Q02PX:01BDU80:BTY0410@025
QHD0GEeM05QHF01TI6@09BDU04A4A01VIVH0J6QX03Ti>@1FEUH0>c/k02l_;`2=SHd0S8b<02<S8`0g
=cL0?clo05aLG02IVIT00P0c<c<0@@0i>CT0GemO06UYJ@2GUiL0[Zj^03`l?01FEUH0S8b<05eMG@1a
LG40W9bL03`l?00T92@0LG5a09ZJVP24Q8@0OWin01lO7`0k>c/0XZ:R059BDP1NGUh0MGEe02l_;`0^
;Rh0LG5a03Lg=`2NWYh0IFEU01hN7P0i>CT0K6a/08R8R00c<c<0CTi>02LW9`0k>c/0JVYZ07UiN@0X
:2P0=SHf04i>CP0n?Sh0AdM707moO`0^;Rh0C4a<04Y:BP0Z:RX0SXj>0:6QX@0l?3`09BDU04Y:BP1<
C4`0WIfM05IFEP0N7Qh0:2PX03Ti>@1<C4`0FUYJ09nOW`0[:b/092@T0080GemO00h0N7Qh08R8R00T
92@09RHV03hn?P21PH40NGUi04i>CP0`<300G5aL071`L01BDU80Jf][08F5Q@809BDU0580IVIV0410
@01iNGT0ATI6024Q8@1IFET0WYjN07QhN00m?Cd0?Shn030`<01hN7P0FEUI065QH@13@d<09BDU055A
D@1dM7@0BTY:04a<C00P8200@T9208B4Q01`L7007alO06][J`13@d<0I6AT08J6QP13@d<0<30`05]K
F`1cLg<0V9RH09jNWP19BDT0:2PX06QXJ01bLW80XJ6Q09VIV@0[:b/0;Rh^06i^KP23Ph<0N7Qh08B4
Q025QHD0>c/k06m_K`2DU9@0LW9b0;Fe]@2WYjL092@T03@d=01OGel0OGem079bLP1KFe/06QXJ05QH
F02WYjL0Kfm_06i^KP2MWId0?clo04Y:BP2;Rh/0KVi^0410@01[Jf/09RHV02l_;`16ATH0L71`03Xj
>P14A4@09BDU03@d=01IFET0MgMg0P0l?3`0201IFET0?Cdm02XZ:P22PX80@T92028R8P0i>CT0=CDe
7?ooool04P1@D500BTY:03Ti>@1BDU80HV9R04e=C@14A4@0De=C075aL@1:BTX0@D5104I6AP1nOWh0
NGUi06=SH`1BDU80GEeM04E5A@80@d=303P08b<S0492@P0d=3@0?clo05UIF@10@400ADE505aLG01W
IfL0R8R805YJFP0h>3P0De=C05IFEP15ADD0A4A4051@D01]KFd0FEUI03De=@0j>SX0C4a<03Ph>01?
Cdl0G5aL04e=C@0^;Rh0@d=3051@D01?Cdl0;bl_034a<@1@D500FEUI01DE5@0k>c/0@T9204i>CP1I
FET09bLW02/[:`1?Cdl0DU9B02TY:@17AdL0HF5Q03/k>`1eMGD0JFUY04e=C@1>CTh0D51@03/k>`0j
>SX0>3Ph06=SH`80Bd];05l0EUIF024Q8@11@D40BTY:04M7A`0c<c<0;Bd]02LW9`0X:2P0;Bd]03hn
?P0V9RH0:2PX04i>CP0K6a/0A4A404=3@`1DE5@06QXJ024Q8@14A4@0:b/[03@d=00^;Rh0@D5103/k
>`0i>CT0?Cdm05MGE`0o?cl0=cLg03Ti>@1SHf<0;2`/034a<@1iNGT0GUiN020P800o?cl0?Shn03De
=@14A4@0<S8b01/K6`0i>CT0=cLg04I6AP0j>SX0@T920451@@13@d<0VYZJ04Y:BP1ADE40;Rh^04Y:
BP0j>SX0G5aL05mOG`0c<c<0>c/k03dm?@11@D40Kfm_06i^KP1]KFd0JVYZ03Hf=P19BDT0I6AT08R8
R01_Kfl0GEeM06=SH`1PH600Q8B403/k>`12@T80K6a/06UYJ@0k>c/0FUYJ02HV9P1jNWX0EeMG01PH
6015ADD09RHV04U9B@0T92@0<30`04a<C01YJFT0>CTi02PX:00203De=@1G06IVIP1LG5`0<c<c0410
@00b<S80=cLg04a<C01aLG40D51@0820P00e=CD0UIFE0:>SX`16ATH0H61P05ADE01iNGT0KVi^06MW
I`2BTY80EUIF04=3@`1=CDd0CTi>04a<C017AdL0@T92051@D019BDT0CDe=06YZJP0O7al0GUiN05YJ
FP1iNGT0K6a/03Ti>@1<C4`0ATI6059BDP1LG5`0HV9R05mOG`1FEUH0F5QH05=CD`1DE5@0@41003Xj
>P19BDT0Fe]K0492@P13@d<0KFe]06ATI00g=cL0CDe=01PH600m?Cd0<C4a04M7A`16ATH0@41003lo
?`1<C4`0?3`l03Hf=P1BDU80<30`04m?C`0m?Cd0AdM702l_;`18B4P0=3@d07alO02@T900@d=3055A
D@17AdL0:RXZ05aLG01ZJVX0LG5a071`L01UIFD0X:2P0080NGUi00X0MGEe079bLP1EEED0L71`06MW
I`1@D500IFEU06][J`1:BTX0GemO0P1DE5@03P18B4P0F5QH04a<C01=CDd0?Shn05=CD`1DE5@0EUIF
05eMG@19BDT0E5AD07alO01MGEd0H61P4Oooool000oooooo00`0Ng]k09bLW02j^[X0DE5A0861P@2;
Rh/0LW9b04U9B@12@T80KFe]08V9R@13@d<205iNGP3503hn?P2YZJT0E5AD04i>CP1TI6@071`L03<c
<`1oOgl0Ph>302l_;`1LG5`0D51@09:BTP1dM7@09RHV02TY:@1;Bd/0D51@06UYJ@1bLW8061PH02<S
8`1MGEd0Kfm_08F5Q@2<S8`0<c<c028R8P0d=3@0LW9b08n?S`2DU9@0<30`038b<P1`L700P82004e=
C@1nOWh0NGUi02d];@1kNg/0IVIV04M7A`1dM7@07AdM01hN7P0l?3`0I6AT05QHF01JFUX06QXJ03Ti
>@12@T80GemO02TY:@1cLg<0G5aL02LW9`20P800=CDe020P800n?Sh0=cLg02XZ:P15ADD0TI6A038b
<P0G5aL0?3`l03/k>`1]KFd0EEEE01dM7@0W9bL0?3`l07UiN@1_Kfl0Lg=c01/K6`0[:b/0BTY:04=3
@`22PX80WinO01LG5`0Z:RX0>c/k08n?S`2:RXX0[jn_01/K6`0e=CD0CDe=0861P@1/K6`0R8R806UY
J@0d=3@0Q8B4079bLP1BDU80PX:205UIF@0X:2P0D51@06IVIP12@T80H61P03Ph>00`<300E5AD06m_
K`18B4P0=CDe04a<C00S8b<0Fe]K08n?S`1DE5@0HF5Q04U9B@0i>CT0E5AD08F5Q@1DE5@08R8R03hn
?P1;Bd/0U9BD09FEU@0/;2`0<c<c04];B`1gMgL0DU9B08f=S@0Z:RX0@d=304];B`1bLW80Cdm?07mo
O`23Ph<07QhN04m?C`1UIFD0F5QH0;6a/@1XJ6P05aLG04Q8B01nOWh0J6QX05ADE02<S8`0:b/[0492
@P28R8P0Jf][06e]K@1ZJVX07QhN03Xj>P1OGel0KFe]04U9B@0n?Sh0?Cdm06i^KP2;Rh/0Kfm_03Lg
=`1IFET0?3`l04m?C`22PX80?Cdm03Xj>P1OGel0>CTi03hn?P1lO7`0HV9R03Lg=`1<C4`0D51@0861
P@1WIfL0;2`/03@d=01QHF40DU9B071`L01>CTh08R8R03lo?`10@4000P1[Jf/01`0M7Ad0@41006UY
J@15ADD0N7Qh01dM7@0a<C400P1ZJVX0A011@D40UiNG03De=@0g=cL0MGEe075aL@1hN7P0OGem01lO
7`1GEeL0XJ6Q0;Vi^@1CDe<0ZZZZ03dm?@22PX80TI6A07IfMP1`L700V9RH03@d=00b<S80Rh^;0:NW
Y`1IFET0P82002l_;`1JFUX0GUiN071`L01IFET0@T9205aLG00^;Rh0IVIV0:6QX@16ATH0Cdm?051@
D00f=SH0CTi>06MWI`1EEED0<c<c04m?C`1TI6@0GemO075aL@0k>c/08R8R04I6AP1HF5P0HF5Q096A
T@11@D40:2PX03/k>`1YJFT0Bd];05MGE`2][Jd0@T920410@01RHV80IFEU065QH@2LW9`0<30`7?oo
ool0301JFUX0HV9R0492@P0j>SX0Cdm?05=CD`1;Bd/0I6AT069RHP0d=3@0EEEE05IFEP80ATI601d0
M7Ad05MGE`1hN7P0C4a<04Q8B010@4007AdM03Lg=`0W9bL0>c/k02`/;00b<S80B4Q805IFEP1?Cdl0
C4a<055AD@0e=CD0H61P051@D014A4@0CDe=06UYJ@1TI6@0M7Ad04E5A@0[:b/0C4a<030`<00204U9
B@1105UIF@0g=cL0EEEE051@D01LG5`0BDU90492@P1=CDd0>3Ph024Q8@0c<c<0AdM702d];@13@d<0
=CDe030`<00_;bl0;Rh^0492@P0m?Cd0=SHf034a<@0m?Cd0A4A40451@@1>CTh0BDU904Y:BP1mOGd0
MgMg065QH@0H61P07AdM05]KF`0];Bd0C4a<04Y:BP1<C4`0Bd];034a<@16ATH0@T9203<c<`0];Bd0
>c/k06ATI016ATH0=CDe065QH@11@D40CTi>034a<@0n?Sh0F5QH02l_;`11@D40?Cdm034a<@11@D40
AdM703lo?`0i>CT0@T9204E5A@0L71`00P19BDT0K00O7al0A4A403De=@0H61P0>c/k04A4A01JFUX0
GemO02/[:`0F5QH0>c/k02XZ:P0^;Rh0?3`l059BDP0a<C408R8R03hn?P1@D500Fe]K04A4A01lO7`0
;Bd]03lo?`1LG5`0>3Ph07MgM`18B4P0EeMG038b<P1@D500>CTi04U9B@0K6a/0>c/k061PH021PH40
SXj>06i^KP21PH40E5AD071`L00c<c<0D51@04m?C`1:BTX0>3Ph05IFEP1EEED0T92@06e]K@0[:b/0
F5QH03Lg=`1`L7009BDU03Xj>P1>CTh0?clo04m?C`0[:b/0CTi>03Xj>P0^;Rh0ATI602l_;`1>CTh0
B4Q805=CD`0e=CD0@T9205ADE01ZJVX0=cLg04Q8B01?Cdl0@41004M7A`0n?Sh0?Cdm06i^KP1ZJVX0
];Bd08Z:RP1EEED0I6AT05EEE@14A4@0>SXj03Lg=`1>CTh0Cdm?034a<@1>CTh0?3`l08V9R@0V9RH0
A4A4061PH010@400JFUY05=CD`0j>SX0?Shn05UIF@1OGel0?3`l061PH080C4a<00<0;bl_04=3@`0c
<c<00P10@400?`14A4@0GEeM05iNGP0m?Cd0KFe]00/;2`0m?Cd0<S8b03<c<`14A4@0?Cdm03Hf=P1:
BTX0De=C04=3@`1JFUX0:b/[07UiN@0I6AT0A4A402@T901:BTX07AdM04=3@`16ATH0@d=306i^KP1b
LW80ADE506i^KP24Q8@0BDU907EeM@0^;Rh0K6a/04=3@`1kNg/0S8b<08F5Q@1>CTh0MWIf06e]K@0`
<300G5aL05eMG@1;Bd/0Hf=S04M7A`19BDT0DU9B04I6AP11@D40ATI605IFEP1dM7@0EUIF059BDP2I
VIT0FEUI06QXJ01kNg/0FEUI0820P00Aooooo`003oooool09`1iNGT0NWYj0;2`/01EEED0EUIF0:6Q
X@3;bl/0Hf=S03Lg=`13@d<0MgMg06ATI02IVIT0Ph>3030`<01YJFT0Jf][0:2PX02b/[809bLW04E5
A@18B4P0V9RH061PH02WYjL06a/K05ADE01]KFd0Bd];06e]K@27QhL0ADE501dM7@20P800B4Q8051@
D01gMgL092@T03@d=00208^;R`1j02l_;`1HF5P0B4Q803hn?P1nOWh0CDe=03De=@1JFUX0=CDe02d]
;@1BDU80Rh^;03Xj>P0h>3P0?3`l071`L01nOWh0@41001dM7@15ADD0?clo06IVIP2LW9`092@T02TY
:@0i>CT0CTi>03/k>`2IVIT0Xj>S01/K6`0k>c/0A4A405iNGP2k^k/0FEUI01PH600a<C40IfMW05mO
G`1YJFT0I6AT01TI6@13@d<0HF5Q0492@P1UIFD0QHF501HF5P0g=cL0LG5a03`l?01fMWH0Cdm?01XJ
6P1=CDd0QHF505iNGP0`<300Hf=S03@d=01;Bd/0OGem0410@00X:2P0FUYJ030`<00V9RH0GEeM08:2
PP0P8200@T9203`l?01=CDd0VYZJ07YjNP0L71`08b<S059BDP1PH600SHf=04=3@`0W9bL0BTY:06YZ
JP1SHf<0JFUY06YZJP0O7al0ADE505EEE@1LG5`0MWIf08B4Q00Q8B40<C4a06EUI@1cLg<0GEeM069R
HP0Z:RX0Hf=S09NGU`20P800A4A409JFUP0g=cL0;Bd]05IFEP1:BTX0DE5A07alO00N7Qh0>CTi04Y:
BP1HF5P0=cLg0492@P1>CTh0<c<c05eMG@2BTY8204Q8B00L05=CD`0U9BD0G5aL0;jn_P14A4@0?Cdm
02XZ:P0a<C40De=C0:^[Z`17AdL0:b/[05aLG010@400Xj>S0:6QX@0[:b/0=SHf05IFEP1@D500FUYJ
09fMW@0g=cL0<S8b06ATI01GEeL0Ph>3092@T080=CDe05l0Cdm?05=CD`1KFe/0IfMW0410@019BDT0
F5QH051@D01eMGD0JFUY02@T9013@d<0CDe=0492@P10@4008R8R04M7A`1XJ6P0ATI604M7A`1^KVh0
>c/k05iNGP18B4P09bLW04M7A`0a<C40@41008f=S@1fMWH0820P03Ti>@17AdL0Lg=c0:j^[P1ADE40
;Bd]04=3@`0n?Sh0DU9B0:j^[P0o?cl0Hf=S06MWI`0b<S80KFe]0=?Cd`21PH408b<S0451@@1NGUh0
GemO0<g=c@1:BTX0<30`06EUI@1XJ6P0BTY:06a/K02c/k<0ADE502l_;`1YJFT0CTi>09nOW`2d];@0
=SHf03De=@1>CTh0JVYZ07YjNP26QXH07alO059BDP1nOWh0Hf=S02/[:`1SHf<0KVi^02LW9`1ZJVX0
ZZZZ03hn?P1CDe<0BDU903De=@0o?cl0KFe]07]kN`0Y:BT0?Shn02d];@19BDT0DU9B04m?C`0Loooo
o`1904a<C01BDU80@T920451@@1DE5@0Bd];03Hf=P1EEED0JFUY02DU9@1LG5`0EUIF055AD@1XJ6P0
I6AT055AD@1LG5`0FEUI04I6AP11@D40?Cdm05eMG@0m?Cd0E5AD04i>CP0h>3P0D51@05]KF`1IFET0
IFEU05=CD`17AdL0GUiN051@D01ADE40GEeM07=cL`2JVYX0Hf=S02h^;P0f=SH0?clo04E5A@19BDT0
Bd];05]KF`13@d<0Cdm?061PH01ZJVX0Cdm?04e=C@1KFe/0AdM702XZ:P0j>SX0IVIV03@d=01BDU80
>c/k03Xj>P19BDT0DU9B04E5A@1DE5@0A4A405EEE@1MGEd0HF5Q03Hf=P0`<300EeMG04e=C@0202XZ
:P1e03/k>`0/;2`0=3@d04e=C@0`<300AdM703`l?00];Bd0?Shn02XZ:P0c<c<0=3@d03Ph>00/;2`0
:2PX02/[:`1FEUH0<c<c0451@@0m?Cd0AdM7028R8P0P8200ADE504U9B@10@400@D5103Xj>P19BDT0
Hf=S0492@P1BDU80EeMG05mOG`0U9BD0Bd];03Hf=P0L71`0Hf=S05ADE00c<c<0BDU905EEE@0d=3@0
BDU902l_;`0[:b/0CDe=01dM7@0d=3@0?Cdm06i^KP13@d<0<c<c0820P00j>SX0BDU904A4A00l?3`0
>CTi05EEE@1`L700ADE50;>c/`1@D500@T9205ADE01QHF40>CTi05IFEP0m?Cd0IFEU065QH@25QHD0
K6a/055AD@1MGEd0ATI6061PH00`<300H61P05QHF01EEED0@d=3069RHP0c<c<0Ogmo08F5Q@1;Bd/0
CTi>0451@@15ADD0;2`/03Lg=`13@d<0AdM704Q8B00a<C40FUYJ04a<C00f=SH0DE5A03@d=016ATH0
<30`04Q8B013@d<0FEUI06a/K01mOGd0G5aL07EeM@1^KVh0DE5A07=cL`1XJ6P0Hf=S0080GEeM05<0
OWin065QH@1VIVH0LW9b03/k>`0c<c<0DU9B04I6AP13@d<0Cdm?03dm?@1BDU80:2PX069RHP17AdL0
GemO05]KF`0[:b/0CDe=03<c<`0^;Rh0>3Ph03Xj>P1DE5@0=CDe05=CD`14A4@0E5AD02h^;P0f=SH0
>CTi03Xj>P18B4P0CTi>05EEE@19BDT0>c/k04];B`0/;2`0?Cdm03Ti>@1GEeL0>CTi04e=C@0g=cL0
>SXj02h^;P0V9RH0BTY:01DE5@0i>CT07AdM04i>CP1@D500LW9b04M7A`1BDU80GEeM04U9B@1ZJVX0
JFUY03De=@15ADD0B4Q803dm?@1QHF40ATI60820P015ADD0MGEe06e]K@1jNWX0O7al0:6QX@2:RXX0
BTY:0861P@1UIFD0D51@06EUI@0a<C40ATI604U9B@0204E5A@0;06EUI@1CDe<0UIFE059BDP1PH600
PH6104m?C`14A4@0H61P071`L01HF5P04Oooool000oooooo02P0NWYj05UIF@26QXH0MgMg07emO@14
A4@0Hf=S0<W9b@1^KVh0Q8B4065QH@0f=SH0@41007QhN00j>SX0@41003Xj>P11@D40FUYJ03lo?`0T
92@0A4A402TY:@0c<c<0IVIV02h^;P0m?Cd0=CDe03/k>`2HV9P0YjNW03Ph>00M7Ad0?Shn04M7A`19
BDT0R8R80410@00G5aL0@D510P1BDU80F@1mOGd0Hf=S02LW9`1hN7P0Q8B405EEE@2][Jd0C4a<01`L
700d=3@0R8R806UYJ@1UIFD06QXJ0451@@1<C4`0EEEE04E5A@26QXH0=cLg0492@P1cLg<0Hf=S051@
D01aLG40<30`03lo?`16ATH0QhN705UIF@1?Cdl07QhN02XZ:P1EEED0Rh^;02<S8`0`<300EeMG02<S
8`0e=CD0L71`02`/;00g=cL0@D510492@P1SHf<0KVi^034a<@0Q8B40@41005eMG@29RHT0M7Ad01XJ
6P0[:b/0=cLg05IFEP1LG5`0`/;2051@D01KFe/0Hf=S0492@P1ADE40cLg=05ADE00G5aL0Cdm?07Ui
N@1ZJVX0UiNG02`/;00d=3@0ADE5092@T014A4@0H61P07=cL`0];Bd0MGEe08>3P`0[:b/0ADE5061P
H00U9BD0EeMG08^;R`15ADD0?Cdm0080=CDe02<0EeMG07alO00`<3008B4Q05IFEP0h>3P0@D51051@
D00L71`0>c/k04Y:BP19BDT0ADE50:^[Z`1?Cdl07AdM03Lg=`0i>CT0QHF50<K6aP0[:b/0:2PX071`
L01^KVh0ADE5061PH01MGEd0?clo05=CD`1ZJVX0AdM708:2PP1jNWX08b<S03/k>`0204m?C`1h07Ee
M@0V9RH0:b/[04Y:BP1;Bd/0AdM704Y:BP20P800>3Ph05]KF`1kNg/0B4Q806MWI`1IFET0;2`/03@d
=01iNGT0Lg=c059BDP0Z:RX0;Bd]06UYJ@1aLG40DE5A04m?C`21PH40<30`03<c<`21PH40>CTi04Q8
B00d=3@0@410061PH02^[Zh0IFEU03Lg=`14A4@0QhN708j>SP0O7al0>c/k05=CD`1DE5@0H61P09VI
V@0Q8B40HF5Q05EEE@1KFe/0O7al02h^;P0M7Ad0Fe]K06e]K@1QHF40S8b<02HV9P1=CDd0XZ:R06a/
K02@T900K6a/02<S8`1<C4`0G5aL07moO`2SXj<0GEeM02`/;00m?Cd0IFEU0<;2`P1CDe<0PH6105aL
G00n?Sh0HV9R06ATI012@T80EUIF03Ph>00K6a/0<c<c04E5A@1lO7`0Fe]K04A4A00X:2P0DU9B07Yj
NP1]KFd0:2PX06UYJ@0X:2P0ATI606=SH`0h>3P08B4Q04e=C@0k>c/0>3Ph07AdM01_Kfl07QhN02h^
;P1XJ6P0Jf][0861P@1gMgL07alO034a<@15ADD0JFUY071`L01nOWh05aLG03@d=01aLG40OGem7?oo
ool09`1;Bd/0DU9B02l_;`0n?Sh0C4a<04M7A`0_;bl0De=C05iNGP0C4a<0BDU904M7A`21PH40OGem
065QH@1>CTh0GemO05IFEP0a<C40:RXZ01LG5`0f=SH0:2PX03@d=00g=cL0=3@d0410@01DE5@0GUiN
07QhN01>CTh0<S8b03lo?`1<C4`0@41004I6AP19BDT0JFUY05eMG@02034a<@0m03Lg=`0S8b<0?clo
05aLG00i>CT0820P03De=@1FEUH0DE5A02HV9P0k>c/0AdM704i>CP0g=cL0@41004];B`0`<300@410
04Y:BP14A4@0ATI6055AD@1<C4`0CTi>04e=C@18B4P0JFUY05mOG`13@d<0?clo05aLG01GEeL0BTY:
06MWI`1@D500<30`02TY:@14A4@0<S8b03lo?`0h>3P0@d=30410@00i>CT0?Cdm02XZ:P0b<S80@410
03Xj>P15ADD0EEEE04A4A01NGUh0ADE504M7A`0_;bl0CTi>05mOG`1<C4`0D51@04m?C`0204e=C@0>
04Y:BP14A4@0De=C04=3@`1IFET0?clo05eMG@1BDU80@T9208N7Q`1EEED0<S8b04Y:BP15ADD204A4
A00S03Xj>P0Q8B40>c/k02PX:01<C4`0;bl_03hn?P0T92@09BDU05QHF011@D40Bd];03Xj>P1HF5P0
CDe=05UIF@24Q8@0?clo04a<C014A4@0?Shn05QHF01[Jf/0=3@d03lo?`0T92@0?3`l05EEE@2HV9P0
NGUi04A4A01`L700I6AT08>3P`11@D400P1LG5`0Q@16ATH0;Bd]04Y:BP0d=3@0SHf=0861P@17AdL0
Hf=S04e=C@1BDU80Bd];051@D01>CTh0Cdm?04Q8B00_;bl0>3Ph0451@@1EEED0IFEU03Xj>P0c<c<0
>c/k04Q8B011@D40EeMG04U9B@1cLg<0IfMW07=cL`1UIFD0?Shn04E5A@1NGUh0JFUY06m_K`1TI6@0
TY:B05mOG`0a<C40DU9B051@D01<C4`0@T9204U9B@1EEED0I6AT04a<C01aLG40>3Ph075aL@1=CDd0
N7Qh07emO@0U9BD0Cdm?03De=@11@D40C4a<04E5A@1DE5@0?Shn04=3@`0l?3`0B4Q802d];@0^;Rh0
>CTi03/k>`0e=CD0>CTi08Z:RP1LG5`0=cLg04m?C`0:2PX0GUiN03<c<`1?Cdl0?Cdm03Xj>P0d=3@0
@T920410@00h>3P0Bd];03Hf=P1SHf<0;2`/04a<C010@400CDe=06IVIP1XJ6P0I6AT04A4A027QhL0
ZJVY05MGE`1`L700GemO055AD@1eMGD0Rh^;0:n_[`1EEED0NWYj07inOP1kNg/0K6a/05YJFP1LG5`0
AdM707alO00m?Cd0D51@05QHF00Y:BT0>CTi04=3@`0`<3009bLW03hn?P0d=3@0VYZJ05aLG01OGel0
KFe]05eMG@1TI6@0GUiN05MGE`1KFe/04Oooool000oooooo0<`0XJ6Q05ADE01LG5`0Fe]K07moO`0l
?3`0E5AD06UYJ@1[Jf/0TI6A07]kN`0/;2`0AdM704U9B@1[Jf/0K6a/02LW9`0g=cL0?Shn061PH01d
M7@0/k>c024Q8@0`<300LG5a05mOG`2k^k/0Jf][01LG5`1<C4`0Xj>S0861P@1NGUh0WYjN01dM7@0b
<S80G5aL05]KF`1?Cdl0EUIF01XJ6P0[:b/0F5QH05IFEP1TI6@0NGUi02/[:`0i>CT0OGem08b<S013
@d<0HV9R0492@P0k>c/0F5QH0410@00e=CD0De=C01@D5019BDT0I6AT06=SH`0c<c<0ATI605IFEP1P
H600Ogmo04m?C`0R8R80@d=304U9B@1CDe<0SXj>01TI6@0P8200>SXj07=cL`27QhL0Jf][08^;R`0M
7Ad0:BTY04i>CP1KFe/0Jf][02h^;P0K6a/0CTi>07=cL`1WIfL0WYjN06a/K00[:b/0G5aL07EeM@0k
>c/0JFUY07]kN`0I6AT0=cLg061PH01UIFD0IfMW0820P00Z:RX0Cdm?08R8R020P800BTY:061PH00^
;Rh0B4Q809FEU@1MGEd0?clo05]KF`17AdL0BDU907moO`1kNg/0;Bd]055AD@18B4P0BTY:06YZJP1k
Ng/09bLW03Lg=`1QHF40EeMG075aL@1UIFD06a/K04];B`2?Shl0IfMW04a<C01oOgl071`L03Ph>01@
D500;bl_08N7Q`2DU9@0;2`/02DU9@18B4P0L71`04U9B@1JFUX0:b/[02PX:01CDe<0Hf=S02h^;P1N
GUh0BDU901/K6`0`<300E5AD03dm?@26QXH0;Rh^038b<P1LG5`0J6QX02h^;P0h>3P0L71`04I6AP2Y
ZJT0Lg=c02TY:@10@400LW9b03Xj>P0h>3P0QhN703`l?01/K6`0CDe=04];B`2:RXX0P82002XZ:P0]
;Bd0L71`06MWI`21PH40LW9b01@D500m?Cd0NWYj061PH01MGEd0SXj>034a<@0N7Qh0IFEU04Q8B01^
KVh08b<S028R8P1KFe/208V9R@1D05ADE00i>CT0B4Q806m_K`0a<C40Cdm?03Ti>@0Z:RX0BDU9096A
T@1iNGT0DE5A02XZ:P1>CTh0Cdm?04Q8B00S8b<0HF5Q04I6AP0X:2P0QhN7051@D011@D40CTi>02l_
;`1ZJVX0/[:b06EUI@0k>c/0Hf=S0492@P28R8P0Ti>C03@d=00j>SX0AdM706=SH`1bLW80SHf=08J6
QP0/;2`0Cdm?03Ph>01OGel0`l?309RHV00W9bL0<c<c05eMG@0o?cl0OWin09>CT`0M7Ad0=SHf08Z:
RP28R8P0ATI60;Zj^P12@T80>SXj07EeM@1?Cdl0A4A4069RHP0_;bl0<30`04m?C`1kNg/0E5AD05mO
G`0d=3@0B4Q8069RHP2JVYX0EEEE03Xj>P1fMWH08B4Q03hn?P1bLW80>SXj04e=C@16ATH05ADE7?oo
ool0]P1NGUh0JVYZ04e=C@1>CTh0IVIV0492@P15ADD0IfMW0861P@18B4P0?Shn04E5A@1BDU80DE5A
05EEE@1>CTh0JFUY05UIF@16ATH0;Rh^02`/;017AdL0:2PX03De=@0g=cL09BDU0492@P1;Bd/0HV9R
05MGE`1BDU80=cLg065QH@1aLG40CTi>05UIF@1iNGT0E5AD06ATI00T92@0<S8b04=3@`0];Bd0C4a<
04I6AP1IFET0<30`04i>CP1HF5P0J6QX03@d=014A4@0HV9R03/k>`0S8b<0<30`05eMG@1XJ6P0GUiN
034a<@0T92@0ATI605=CD`12@T80DE5A05MGE`16ATH0C4a<051@D016ATH0F5QH06UYJ@1:BTX0E5AD
04=3@`1RHV806QXJ01TI6@1MGEd09BDU038b<P0n?Sh0=CDe03lo?`0Q8B40A4A403`l?00g=cL0=CDe
03dm?@19BDT0Cdm?02l_;`1FEUH0?Cdm04Y:BP0Q8B40=3@d04M7A`0a<C40@T9204m?C`0/;2`0DE5A
05IFEP0n?Sh0Fe]K065QH@1MGEd0?Shn05]KF`1RHV80BDU905EEE@12@T80@d=3051@D014A4@0GUiN
05UIF@11@D40<S8b03hn?P0O7al0?Cdm04U9B@1VIVH0?Cdm04A4A01KFe/0HV9R055AD@1bLW80QhN7
059BDP1KFe/0P82006e]K@2YZJT0GEeM069RHP16ATH0G5aL03De=@1IFET07QhN03hn?P1LG5`0PH61
07QhN01SHf<0KFe]0451@@1@D500>SXj06ATI01?Cdl0DU9B03lo?`1WIfL0<30`096AT@25QHD0?3`l
04I6AP0e=CD0GUiN03Xj>P0];Bd0ATI606m_K`1NGUh0=SHf059BDP1FEUH0@T9206i^KP1:BTX0CDe=
04E5A@1=CDd0?3`l0P1<C4`03`1_Kfl0?clo05MGE`1JFUX0;bl_04A4A00k>c/0E5AD05aLG01<C4`0
YjNW06IVIP1CDe<0KVi^04a<C00203`l?01I03dm?@1HF5P0NGUi03Lg=`1KFe/0DU9B07emO@1:BTX0
Bd];05IFEP0e=CD0AdM703<c<`0n?Sh0CTi>04U9B@1LG5`0C4a<04E5A@12@T80De=C038b<P0c<c<0
<S8b03Ti>@0e=CD0?clo055AD@12@T80=cLg05MGE`0J6QX0<c<c03De=@1DE5@0@41003dm?@0];Bd0
EUIF03`l?00g=cL0Bd];0451@@1bLW80>3Ph04Q8B00];Bd0ATI602`/;01bLW80L71`038b<P1LG5`0
N7Qh04Q8B01LG5`0TI6A06i^KP1eMGD0>CTi05mOG`1:BTX0FUYJ08j>SP2BTY80KVi^08R8R02[Zj/0
FEUI05iNGP1FEUH0GemO06QXJ00j>SX0@D5104i>CP1KFe/0BTY:04Q8B00N7Qh0EEEE03`l?01YJFT0
E5AD05QHF01CDe<0D51@07QhN01XJ6P04Oooool000oooooo0140^;Rh09RHV027QhL0BTY:07inOP1g
MgL0ZJVY0410@00o?cl0B4Q806UYJ@1MGEd0WYjN06YZJP0e=CD0I6AT04e=C@0205=CD`3o02PX:00^
;Rh0H61P06IVIP0c<c<0BDU902HV9P1gMgL0RHV902HV9P0[:b/0ADE503Lg=`0`<300JVYZ02`/;00Q
8B40BDU903@d=01jNWX0VIVI05IFEP0D51@0A4A405iNGP2FUYH0/k>c02`/;00e=CD0EeMG09:BTP1;
Bd/0YZJV06=SH`0f=SH0H61P04Y:BP1TI6@0WinO01lO7`0L71`0QHF50:^[Z`1/K6`0NWYj02DU9@10
@400J6QX06UYJ@1>CTh0UIFE04M7A`0h>3P0J6QX05MGE`13@d<0Ogmo02<S8`0/;2`0GEeM05YJFP0n
?Sh0ATI60451@@0j>SX0R8R808F5Q@0h>3P0A4A403<c<`0D51@0Bd];079bLP0e=CD0?Cdm04];B`0n
?Sh0PX:20:6QX@0O7al05aLG04M7A`19BDT0WYjN0;fm_@0K6a/09BDU05ADE01ADE40?clo09ZJVP11
@D408b<S05eMG@1ZJVX0K6a/075aL@14A4@0:2PX069RHP1TI6@0@T9209^KV`1CDe<08b<S065QH@1b
LW80Bd];03<c<`1XJ6P0;Rh^04U9B@2ATI40CDe=0492@P0e=CD09bLW04=3@`1]KFd0IVIV02`/;016
ATH0;Bd]04m?C`1fMWH0>SXj03`l?01GEeL0>c/k04E5A@2CTi<09bLW03De=@1?Cdl0;Bd]04];B`2b
/[80HF5Q01TI6@0^;Rh0BTY:06MWI`3Bd]80Bd];01LG5`14A4@0Q8B403Xj>P1/K6`0[:b/02`/;01E
EED0Q8B403lo?`1fMWH0Q8B404I6AP1=CDd0Fe]K05aLG02PX:00EUIF038b<P1VIVH0Ph>304a<C01L
G5`0J6QX04I6AP1ADE40Lg=c03<c<`1:BTX0D51@02h^;P15ADD0Lg=c04Y:BP0U9BD0@d=303De=@1`
L700EEEE01TI6@0c<c<0>c/k03@d=01BDU80EeMG03De=@1BDU80EEEE075aL@1@D5006ATI02d];@1I
FET0NWYj08V9R@0S8b<0<S8b06YZJP1@D500AdM708F5Q@15ADD0:b/[03/k>`1JFUX0L71`06QXJ00m
?Cd0<S8b05YJFP21PH40EUIF09bLW016ATH0LG5a06QXJ00j>SX0EeMG08f=S@0J6QX0@T9208V9R@1b
LW80DU9B06YZJP1;Bd/09bLW06ATI02ZZZX0K6a/04i>CP1UIFD0<30`04I6AP2BTY80DE5A04m?C`1d
M7@0;Rh^03/k>`1KFe/0JVYZ04A4A01;Bd/071`L05IFEP23Ph<0?clo01HF5P14A4@0GemO000@03hn
?P1dM7@0?clo02@T901ADE40Hf=S04U9B@1TI6@0/;2`03Ti>@0O7al0F5QH03@d=01/K6`0/;2`02`/
;1cooooo08d0CTi>07EeM@1=CDd0E5AD07moO`1aLG40?Shn05iNGP2=SHd09bLW0861P@1bLW80N7Qh
06i^KP1oOgl0F5QH06IVIP1CDe<0?clo05mOG`0[:b/0DU9B04Q8B01JFUX0C4a<03Xj>P1PH600?Cdm
06MWI`1bLW80F5QH05aLG01BDU80I6AT075aL@1hN7P0H61P05EEE@13@d<0<S8b02/[:`0_;bl0EUIF
05ADE016ATH0C4a<03Xj>P16ATH0DU9B05UIF@0Y:BT0EeMG06UYJ@1>CTh0;bl_038b<P1NGUh0;bl_
0492@P0U9BD0820P04e=C@1@D500:2PX05=CD`1BDU80GUiN07IfMP1EEED0=SHf0451@@1JFUX0DE5A
04e=C@1CDe<0MWIf03dm?@0b<S80MGEe03Lg=`12@T80C4a<04E5A@1BDU808b<S04e=C@11@D40BDU9
03Xj>P0m?Cd0>c/k05=CD`1JFUX0Jf][051@D01GEeL0:BTY04m?C`1]KFd0?clo05YJFP1QHF40<c<c
06QXJ01WIfL0?clo05IFEP1LG5`0JFUY03Ti>@1BDU80H61P059BDP1^KVh0DE5A02DU9@1@D500G5aL
03Hf=P0m?Cd0Cdm?02XZ:P18B4P0;bl_03/k>`10@400Fe]K04E5A@1DE5@0JVYZ03hn?P16ATH0?Shn
05UIF@1KFe/0F5QH09nOW`1<C4`0JFUY051@D013@d<00P1IFET0GP0o?cl0EEEE02DU9@1;Bd/0IVIV
08f=S@2JVYX0>3Ph06a/K01IFET0G5aL030`<01ADE40Ogmo06UYJ@0g=cL0IFEU024Q8@1QHF40GEeM
05IFEP1aLG40@41004=3@`11@D40CTi>05IFEP0i>CT0CTi>04A4A01jNWX0K6a/04=3@`1NGUh0<c<c
051@D00a<C40C4a<05MGE`1DE5@0EEEE07inOP0n?Sh0EEEE05UIF@0o?cl0DU9B04i>CP1gMgL0LW9b
04U9B@1`L700B4Q803hn?P1OGel0AdM703Ti>@1;Bd/0=3@d04Y:BP1KFe/0Bd];061PH00h>3P0Q8B4
03hn?P1QHF40EEEE024Q8@1[Jf/0CTi>04I6AP1?Cdl0GUiN07EeM@1>CTh0J6QX05IFEP1<C4`0?3`l
059BDP0n?Sh0B4Q805mOG`1FEUH0IVIV06m_K`1BDU80H61P03Hf=P19BDT0ADE505EEE@16ATH203hn
?P0c05QHF01CDe<0Cdm?04a<C00k>c/0OGem02/[:`1MGEd0Hf=S07MgM`17AdL0De=C0451@@1HF5P0
[Jf]08b<S00l?3`0IVIV05iNGP1:BTX0F5QH07emO@2BTY80@d=309>CT`20P800PH6105YJFP1MGEd0
UiNG06e]K@2_[jl0JFUY04E5A@1JFUX0ATI606IVIP1;Bd/0@d=305=CD`1VIVH0De=C065QH@0c<c<0
D51@05mOG`0o?cl0@D51055AD@1FEUH0FEUI017ooooo000?ooooo`1A07EeM@1^KVh0UiNG05aLG01U
IFD0@d=306a/K01cLg<0Bd];09ZJVP1BDU80<C4a06][J`21PH40FUYJ04e=C@1:BTX0I6AT08R8R01?
Cdl0@D5106][J`10@400ATI608F5Q@0f=SH0GUiN05mOG`14A4@0Ogmo0:b/[01MGEd0:2PX059BDP1M
GEd0EUIF08F5Q@0f=SH08R8R04Q8B019BDT0CDe=08>3P`0i>CT0@T9206IVIP14A4@0I6AT0:b/[00a
<C40=CDe065QH@1[Jf/0D51@06=SH`0Z:RX0BDU907IfMP1EEED0?Shn069RHP17AdL0De=C079bLP13
@d<0H61P06YZJP0k>c/0?Shn07MgM`1mOGd0>CTi05MGE`0[:b/0CDe=0:RXZ01dM7@0>3Ph04Y:BP1>
CTh0<C4a0080DU9B0<l07QhN03dm?@1;Bd/0>3Ph07alO022PX80:RXZ02l_;`0o?cl0?Shn08^;R`2@
T9007alO0410@01NGUh0DU9B04E5A@2=SHd0>3Ph030`<01CDe<0D51@04];B`1bLW80:b/[03Hf=P1C
De<0E5AD04Y:BP1DE5@0:2PX04];B`21PH40Q8B402d];@1IFET0I6AT04I6AP20P800Kfm_02`/;01?
Cdl0EeMG03Ph>01LG5`0MGEe04M7A`19BDT0BTY:04=3@`1gMgL0L71`02/[:`0i>CT0Fe]K04];B`13
@d<0Hf=S02LW9`1<C4`0IfMW051@D01ADE40UYJF03Xj>P0a<C40G5aL04e=C@1XJ6P0NWYj02`/;00`
<300De=C07emO@1EEED0Fe]K05=CD`0e=CD0Fe]K06UYJ@18B4P0KFe]079bLP0P8200?Cdm06m_K`1G
EeL0MGEe02`/;00L71`0ATI608Z:RP1NGUh0CDe=06MWI`0n?Sh0Kfm_08^;R`13@d<0F5QH069RHP0]
;Bd0@D5109>CT`1NGUh0EUIF04Q8B00l?3`0Hf=S096AT@19BDT0B4Q807=cL`11@D40Cdm?07inOP0c
<c<0EEEE05QHF010@400Ogmo08:2PP19BDT0De=C04e=C@1]KFd0PX:203Ti>@1:BTX0IFEU04=3@`1e
MGD0S8b<02l_;`1@D500JVYZ05IFEP2>SXh0?Cdm03Ti>@1QHF40Hf=S05iNGP27QhL0=cLg059BDP23
Ph<0AdM707emO@1fMWH0<c<c04i>CP1LG5`0DE5A08R8R01bLW80=cLg069RHP2@T900JFUY03lo?`1a
LG40EUIF055AD@28R8P0ADE503Xj>P1ADE40EeMG038b<P1SHf<0UIFE04Y:BP1=CDd0E5AD03lo?`1K
Fe/0WYjN05QHF00f=SH0Hf=S05ADE01NGUh0LW9b02/[:`0_;bl0HF5Q05iNGP15ADD0HV9R05MGE`0c
<c<0Bd];04m?C`10@400MgMg08b<S00e=CD0?clo069RHP1DE5@0@D5106QXJ00[:b/0=CDe065QH@12
@T807?ooool07`1GEeL0Jf][05EEE@1;Bd/0IFEU06ATI01=CDd0EEEE07MgM`1:BTX0Fe]K05eMG@1V
IVH0L71`06a/K01XJ6P0GUiN05YJFP0n?Sh0C4a<03Lg=`1:BTX0=cLg04];B`12@T80<30`065QH@11
@D40GEeM075aL@1BDU800P1?Cdl0C@1JFUX0EUIF06=SH`1MGEd0HF5Q04i>CP0];Bd0:RXZ03De=@0j
>SX0@41003lo?`0i>CT0;bl_03/k>`1:BTX0@410038b<P1BDU80ADE50492@P17AdL0B4Q805=CD`14
A4@0B4Q803lo?`0k>c/0Bd];04i>CP0i>CT0BDU9055AD@17AdL0PH6105ADE00o?cl0Cdm?061PH01L
G5`0D51@04A4A01PH600;Rh^02`/;01OGel0?3`l0451@@1KFe/0CTi>04Q8B00n?Sh0ADE503De=@13
@d<0=SHf03<c<`0h>3P0ATI603Ti>@1GEeL0A4A4055AD@0c<c<0?Cdm05=CD`0m?Cd0HF5Q04m?C`1;
Bd/0F5QH05eMG@15ADD0J6QX05eMG@1UIFD0@D510080MGEe06h0J6QX07]kN`1XJ6P0>CTi065QH@1]
KFd0?clo05EEE@1<C4`08B4Q04M7A`0Z:RX0F5QH0492@P1MGEd0=cLg05EEE@22PX80Cdm?04Y:BP1F
EUH0M7Ad04Q8B01HF5P0/[:b07=cL`2<S8`0OWin04U9B@1IFET0MWIf0451@@1@D500>CTi04a<C01T
I6@0Vi^K07QhN011@D40HV9R05YJFP1ZJVX0EEEE05iNGP1JFUX0EUIF0492@P1DE5@09BDU07UiN@1k
Ng/0?3`l069RHP0/;2`0EEEE02h^;P16ATH0BDU905UIF@1DE5@09RHV055AD@1EEED0AdM706IVIP0k
>c/0F5QH03`l?01;Bd/0;bl_038b<P0o?cl0OGem03`l?00n?Sh0ATI603Hf=P19BDT0<c<c0451@@1D
E5@0@41008B4Q01QHF40@D5105=CD`11@D40<C4a03Hf=P0n?Sh0EeMG06][J`0o?cl0JFUY038b<P1/
K6`0?Shn06MWI`1QHF40:RXZ04U9B@1CDe<0ATI6059BDP16ATH0FEUI05ADE01JFUX0EUIF05aLG080
AdM700d0D51@05IFEP16ATH0ADE506MWI`1SHf<0A4A405]KF`0S8b<0EeMG0410@018B4P0A4A40080
D51@03<0IfMW04i>CP1HF5P0Fe]K04U9B@1PH600>3Ph05EEE@0f=SH0@d=303Ti>@1SHf<0HF5Q04U9
B@1SHf<0SXj>04e=C@1DE5@0HF5Q04Q8B01iNGT0E5AD07UiN@19BDT0FUYJ06ATI01QHF40A4A407=c
L`2BTY80DU9B07IfMP1ADE40B4Q8051@D010@400B4Q804a<C01:BTX0ADE504Q8B00i>CT0J6QX04m?
C`1UIFD0NWYj05YJFP1IFET0I6AT07alO01^KVh04Oooool000oooooo0?l0KVi^075aL@1lO7`0CDe=
075aL@1PH600TI6A04A4A00n?Sh0Shn?0:BTY01<C4`0B4Q80451@@1EEED0Q8B403Ph>00d=3@0B4Q8
055AD@20P800XZ:R02XZ:P0R8R80BDU9051@D039bLT0Ogmo01LG5`0L71`0?3`l06ATI01>CTh0[Jf]
024Q8@1TI6@0H61P0492@P1JFUX0U9BD03Lg=`0J6QX0H61P04Y:BP1UIFD0IfMW01/K6`0g=cL0SHf=
07emO@1;Bd/0OWin038b<P0[:b/0Rh^;05MGE`1?Cdl0KFe]01DE5@0a<C40E5AD06UYJ@14A4@0>SXj
02@T901=CDd0[:b/05QHF00h>3P0KVi^03Xj>P0O7al0KVi^01lO7`0/;2`0EEEE0410@016ATH0Hf=S
075aL@0D51@0=cLg05EEE@1GEeL0UYJF04U9B@0W9bL0CDe=069RHP1JFUX0JVYZ071`L00O7al0A4A4
0861P@1LG5`0NGUi07=cL`0C4a<0:BTY04m?C`1DE5@0KFe]07alO00W9bL0;bl_05mOG`1=CDd0<S8b
05ADE00e=CD0>c/k079bLP0/;2`0<30`04U9B@1HF5P0=cLg08B4Q027QhL092@T05ADE00c<c<0DE5A
061PH01lO7`0;2`/02TY:@1TI6@0K6a/06UYJ@15ADD07alO02`/;01_Kfl0C4a<061PH02@T9006a/K
03<c<`1LG5`0EeMG07emO@1jNWX0:b/[05YJFP1GEeL0R8R8065QH@1^KVh0:b/[05YJFP1IFET0CTi>
04e=C@1gMgL0;2`/02l_;`1eMGD0XJ6Q03Ph>01YJFT08b<S03/k>`1YJFT0[jn_055AD@1RHV80EUIF
03Ti>@1cLg<0S8b<02d];@1=CDd0DE5A02/[:`1EEED0J6QX0492@P1?Cdl0@D5103`l?01YJFT0Q8B4
03Ph>00V9RH0>3Ph03lo?`1cLg<0GemO028R8P15ADD0CDe=04A4A01cLg<0_kno04Y:BP0J6QX0K6a/
04i>CP1]KFd0>3Ph020P801EEED0QHF506IVIP1fMWH0@41003Lg=`1^KVh0EeMG05mOG`17AdL0:RXZ
034a<@1/K6`0[Zj^08^;R`0W9bL0>3Ph069RHP1NGUh0CTi>06YZJP0];Bd0<C4a04U9B@1BDU80EeMG
04E5A@0W9bL0C4a<07alO01IFET0A4A407AdM00[:b/0MGEe07]kN`0k>c/0Bd];05MGE`0e=CD0Hf=S
09RHV02ZZZX0C4a<06IVIP16ATH0EUIF07QhN02:RXX0=cLg02DU9@1GEeL002<0JFUY07MgM`1YJFT0
92@T03`l?01YJFT0Ogmo08f=S@2f][H0<30`03hn?P1=CDd0BDU90861P@2g]kL0>CTi03Xj>P1:BTX0
JFUY04];B`29RHT07QhN02XZ:P12@T80M7Ad03hn?P1^KVh0RXZ:02TY:@0];Bd0FEUI03Hf=P0_;bl0
=SHf01lO7`0Looooo`0G04E5A@1^KVh0GUiN04Q8B01?Cdl0De=C02d];@0l?3`0NGUi01`L7011@D40
DU9B04m?C`1LG5`0EeMG0451@@1ADE40@d=303/k>`15ADD0?clo059BDP1FEUH00P13@d<0LP15ADD0
Bd];03Ph>01PH600G5aL05UIF@11@D40HF5Q06QXJ018B4P0FEUI06=SH`1HF5P0KFe]04a<C00Z:RX0
BDU90492@P1;Bd/0ATI606IVIP0d=3@0D51@04A4A01IFET071`L03Ti>@1QHF40BTY:02TY:@0S8b<0
ATI603Lg=`0j>SX0@41003Ph>00n?Sh0ADE504e=C@13@d<0ADE504];B`31`L40MWIf02`/;00a<C40
IFEU06a/K017AdL0ADE505iNGP16ATH0CTi>06MWI`0l?3`0@41005IFEP1=CDd0ATI603dm?@1;Bd/0
>3Ph0451@@0h>3P0<c<c02`/;010@400>SXj055AD@1<C4`0EUIF02DU9@0l?3`0ADE503Hf=P14A4@0
?Shn04A4A012@T80De=C03@d=00i>CT0De=C05QHF00^;Rh0BTY:06a/K01SHf<0HF5Q0451@@1@D500
GemO05QHF01YJFT0EEEE04Q8B00S8b<0G5aL02HV9P1GEeL0B4Q809^KV`1=CDd0GEeM07moO`1PH600
F5QH05eMG@2CTi<0@D5105ADE01^KVh0QhN70;^k^`80HF5Q02P0GEeM0820P00`<300AdM702TY:@18
B4P0>SXj05]KF`2:RXX0IVIV0820P017AdL0LW9b03Ti>@1KFe/0IFEU05ADE01<C4`0Lg=c0492@P23
Ph<0PH6104E5A@17AdL0@T9205IFEP0k>c/0=CDe04A4A01BDU80JFUY04Q8B00h>3P0C4a<04m?C`1U
IFD0ADE504m?C`0j>SX0AdM70P1TI6@0@`13@d<0GUiN03Hf=P1JFUX0Cdm?02XZ:P15ADD0?Cdm055A
D@19BDT0;Rh^075aL@1NGUh0Cdm?075aL@11@D40<30`04E5A@0f=SH0;2`/03Ph>00S8b<0Bd];034a
<@1gMgL0>SXj06UYJ@1JFUX08R8R05UIF@1?Cdl0=3@d05UIF@0h>3P0HV9R04M7A`1=CDd0@d=3069R
HP0f=SH0>3Ph0410@00Y:BT0HF5Q04i>CP1:BTX0De=C05EEE@1dM7@0=CDe04m?C`0o?cl0F5QH0410
@01OGel0=CDe04A4A00c<c<0>SXj055AD@11@D40BDU902`/;01JFUX0Lg=c06IVIP1QHF400P11@D40
9P0U9BD0Kfm_096AT@1WIfL0F5QH0:RXZ01nOWh0VIVI0492@P1ZJVX0;Rh^06e]K@1NGUh0U9BD04Y:
BP1eMGD0QHF50451@@24Q8@0F5QH04e=C@1?Cdl0;Rh^04Q8B01?Cdl07AdM02`/;00c<c<0?3`l06MW
I`0i>CT0IVIV07EeM@1QHF40EeMG061PH01LG5`0Lg=c4Oooool000oooooo04P0SXj>0:VYZ@2k^k/0
ATI606ATI026QXH0f=SH05mOG`0k>c/0G5aL07alO01fMWH0[Jf]04M7A`0X:2P0De=C05EEE@1WIfL0
L71`02PX:00l?3`0MgMg061PH01NGUh0FEUI03Lg=`1:BTX0IfMW03De=@1KFe/0@d=302@T900i>CT0
NWYj03De=@1GEeL0FEUI020P800V9RH0NGUi06e]K@0X:2P0>SXj03lo?`2DU9@0NGUi03<c<`0a<C40
@T9203Lg=`1GEeL0[jn_05YJFP0R8R80Cdm?05MGE`1^KVh0Z:RX024Q8@0N7Qh0=3@d04U9B@2=SHd0
MWIf010@400P8200G5aL06i^KP1BDU80alO705QHF00J6QX204Y:BP0805YJFP2QXJ40:2PX02h^;P1A
DE40W9bL05ADE01YJFT203Ti>@1A069RHP23Ph<0?Shn03Hf=P14A4@08R8R03Lg=`1MGEd0:RXZ03`l
?00];Bd0:BTY04a<C01oOgl09BDU02LW9`0i>CT0?clo07UiN@1fMWH061PH03Hf=P1?Cdl0CDe=04];
B`2IVIT0?Shn03Ti>@1=CDd0D51@06a/K02HV9P0=3@d02`/;011@D40LG5a05QHF02RXZ80EeMG02DU
9@0m?Cd0GEeM05EEE@1YJFT0ZJVY03@d=00j>SX0Fe]K06=SH`2LW9`0ADE501dM7@0g=cL0JFUY065Q
H@0[:b/0<c<c02`/;01SHf<0O7al03Hf=P0e=CD0EUIF02<S8`13@d<0H61P02<S8`0m?Cd0CTi>03lo
?`1HF5P0QXJ607AdM00P8200;2`/06m_K`1oOgl0Vi^K03De=@0L71`0AdM70080?clo07/0QhN70:b/
[00];Bd0ATI604e=C@11@D40Xj>S08N7Q`0T92@0<c<c04a<C01/K6`0[Jf]07emO@0O7al0D51@05eM
G@1aLG40EeMG092@T00O7al0EUIF06EUI@1EEED0Bd];05UIF@0Q8B40EeMG06a/K01VIVH0ATI606][
J`1;Bd/0TY:B09BDU01>CTh0IfMW038b<P0S8b<0JFUY07EeM@1DE5@0EUIF02TY:@1EEED0NWYj02DU
9@0i>CT0@D51051@D02NWYh0ADE5038b<P1>CTh0@41005UIF@2=SHd0@d=302DU9@1?Cdl0DU9B08R8
R022PX808B4Q04Q8B01cLg<0GEeM06=SH`2b/[80=3@d069RHP2i^KT0E5AD09VIV@2NWYh092@T03hn
?P1MGEd0LW9b065QH@1lO7`07QhN04a<C02@T900X:2P06m_K`1/K6`0^k^k04e=C@1HF5P0Ti>C06e]
K@1VIVH0UIFE04U9B@1OGel0]KFe08j>SP1NGUh0?Cdm03hn?P0j>SX0IFEU05mOG`0Z:RX0EeMG02`/
;00T92@0L71`05]KF`0M7Ad0?clo05ADE00b<S80@d=3079bLP1IFET0:RXZ051@D01=CDd0Kfm_069R
HP0U9BD07?ooool0NP18B4P0MGEe03Ph>00k>c/0DE5A07emO@0j>SX0Bd];08>3P`0Q8B40GUiN04m?
C`1<C4`0CDe=05mOG`1EEED0Kfm_06QXJ00a<C40>c/k01dM7@1?Cdl0<S8b059BDP1IFET0?Shn05EE
E@15ADD0LW9b08b<S01TI6@0AdM705QHF01YJFT0CDe=05ADE01JFUX0Ogmo061PH01;Bd/0ADE5055A
D@17AdL0EeMG06=SH`1VIVH0BDU904a<C01=CDd0E5AD02h^;P16ATH0Fe]K05QHF017AdL0BTY:07=c
L`0g=cL0B4Q805IFEP1?Cdl0FEUI04i>CP1ADE40D51@04];B`1@D500FEUI05MGE`13@d<0?3`l05AD
E00l?3`0:BTY02h^;P1?Cdl0;bl_030`<01=CDd0=3@d03lo?`1FEUH0BTY:03Ti>@12@T80?Cdm02XZ
:P0l?3`0=cLg03@d=00a<C40>c/k02@T900];Bd0>3Ph04E5A@0R8R80;Rh^0451@@0_;bl0@41003@d
=01>CTh0?clo04=3@`1IFET0L71`03lo?`0h>3P0B4Q806ATI017AdL0C4a<09>CT`1FEUH0CDe=04a<
C01XJ6P0EeMG04=3@`15ADD07QhN0P10@400YP1:BTX0<S8b04a<C00m?Cd0Ph>307]kN`0o?cl0?Cdm
05QHF01<C4`0=CDe096AT@2ZZZX0G5aL04i>CP1@D500?3`l06m_K`1mOGd0BDU905=CD`0`<300GEeM
05QHF02IVIT0Ng]k07YjNP18B4P0GUiN07UiN@11@D40NWYj06e]K@1@D5007AdM05=CD`0Z:RX0L71`
08V9R@1_Kfl0Fe]K04Y:BP1GEeL0FEUI065QH@1MGEd0C4a<07IfMP1>CTh0G5aL06i^KP1UIFD0O7al
05=CD`1JFUX0?3`l05ADE013@d<0>3Ph04A4A01/K6`09RHV069RHP1DE5@0=cLg04Y:BP18B4P0De=C
06a/K01<C4`0QHF506QXJ01=CDd0IFEU051@D00e=CD0>CTi03lo?`18B4P0DE5A03<c<`1HF5P0AdM7
06UYJ@1@D500K6a/06UYJ@0G5aL0=3@d03Hf=P0c<c<0CTi>03Ti>@1GEeL0E5AD04a<C00o?cl0B4Q8
03De=@0f=SH0Fe]K03<c<`0j>SX0?Shn07IfMP1HF5P0:BTY04U9B@0J6QX0J6QX03Lg=`14A4@0>c/k
055AD@0d=3@0AdM705MGE`1PH600GEeM04I6AP1VIVH0>CTi07EeM@0m?Cd0=cLg03De=@1oOgl0R8R8
04a<C02=SHd0Ti>C059BDP17AdL0E5AD059BDP16ATH0GUiN08Z:RP14A4@0Lg=c04E5A@1SHf<0GEeM
08:2PP21PH40CTi>05MGE`1:BTX0CDe=05QHF016ATH0Cdm?04];B`16ATH0?clo03hn?P1GEeL0Q8B4
03hn?P1@D500Shn?059BDP0n?Sh0@d=306EUI@1CDe<Aooooo`003oooool0;`1RHV80IfMW09nOW`1U
IFD0HV9R04I6AP1bLW80SXj>05=CD`25QHD0ADE502/[:`1MGEd0SXj>04m?C`0l?3`0<30`059BDP1^
KVh09BDU04=3@`18B4P0ADE505EEE@1XJ6P07QhN061PH01QHF40BTY:08Z:RP1OGel06ATI01/K6`1i
NGT0Cdm?0:b/[02?Shl07QhN02XZ:P1RHV80M7Ad04a<C02KVi/0;Rh^05EEE@1_Kfl0<c<c0080LG5a
03D0>CTi030`<01=CDd0Ti>C06EUI@0k>c/07QhN0410@018B4P0BDU904=3@`1`L700<c<c06=SH`2a
/K40BDU9059BDP1ADE40;Bd]02/[:`22PX80Ph>3034a<@1QHF409BDU04Q8B02OWil0F5QH02HV9P0c
<c<0C4a<02XZ:P1IFET0Hf=S01LG5`0c<c<0>CTi04=3@`2:RXX0TY:B018B4P0c<c<0BDU905IFEP2R
XZ80GEeM01PH601FEUH0GUiN04U9B@1XJ6P0Xj>S02TY:@0204a<C00;03lo?`18B4P0MWIf02DU9@0j
>SX0Fe]K05iNGP17AdL0JFUY020P800e=CD00P1LG5`0=P0`<300NWYj07UiN@0S8b<0Kfm_061PH00Y
:BT0?3`l02<S8`0b<S80?clo06YZJP1=CDd0@D5103Ti>@11@D40MGEe061PH00K6a/0=SHf04i>CP1Z
JVX0Fe]K05IFEP0K6a/0;2`/05MGE`1VIVH0OWin096AT@0J6QX0=CDe07IfMP1:BTX0EEEE069RHP0K
6a/0>3Ph05=CD`1lO7`0ADE506e]K@1HF5P09BDU07IfMP1XJ6P0;2`/06UYJ@1DE5@08B4Q02PX:01`
L700E5AD05iNGP80820P07D0=cLg08j>SP1ZJVX0@41005iNGP0X:2P0=SHf065QH@0f=SH0DE5A05EE
E@0];Bd0Ogmo0:^[Z`1ADE40A4A405aLG00l?3`0W9bL0:RXZ00U9BD0>3Ph04A4A00m?Cd0AdM707em
O@0N7Qh0CTi>069RHP1CDe<0];Bd05]KF`0E5AD0B4Q8065QH@1dM7@0L71`02TY:@1;Bd/0FUYJ04E5
A@1PH600JFUY01HF5P1;Bd/0MgMg06EUI@2QXJ40;Bd]03dm?@2UYJD0MWIf05=CD`1WIfL0;Bd]06QX
J02JVYX0D51@05MGE`1>CTh0:RXZ04Y:BP1gMgL0ATI6055AD@0i>CT0ATI606ATI02=SHd0AdM702XZ
:P1_Kfl0DU9B05IFEP24Q8@0Fe]K02TY:@1GEeL0EEEE04a<C00n?Sh0Q8B404Y:BP0g=cL0@d=3030`
<01YJFT0Xj>S05ADE00`<300A4A404I6AP1^KVh0J6QX02DU9@14A4@0AdM70492@P14A4@0MWIf04];
B`0D51@0GemO08V9R@13@d<0Cdm?03dm?@0o?cl0GemO075aL@1XJ6P0H61P08J6QP0U9BD0GUiN08N7
Q`1@D5007?ooool0?@11@D40FUYJ04Q8B01CDe<0HV9R07IfMP1IFET0H61P09^KV`0n?Sh0EeMG055A
D@1bLW80UIFE06EUI@11@D40D51@04e=C@15ADD0@D5103<c<`1IFET0;Rh^04Y:BP1<C4`07QhN04a<
C00M7Ad0De=C04];B`1GEeL0>c/k07=cL`27QhL0C4a<05YJFP1jNWX0MWIf06][J`0V9RH0<S8b04I6
AP0l?3`0CDe=04A4A01NGUh0?Cdm05IFEP1>CTh0Jf][0492@P13@d<0L71`04E5A@0h>3P0<C4a06UY
J@1KFe/0EEEE051@D01=CDd00P1MGEd0:@1GEeL0FUYJ06QXJ01KFe/0PH6107]kN`1IFET0G5aL06a/
K01JFUX0?Cdm03Xj>P2ATI40>c/k02h^;P25QHD0EEEE05QHF01GEeL0CTi>059BDP13@d<0BTY:04];
B`1?Cdl0<c<c0492@P1JFUX0BDU904E5A@1ADE40EeMG055AD@0d=3@0?3`l065QH@12@T80FEUI03`l
?017AdL0CTi>0080@T920;P0Bd];04=3@`1<C4`0=CDe03/k>`1KFe/0FEUI05eMG@1ADE40CTi>065Q
H@1BDU80<S8b03`l?00`<300;2`/055AD@0M7Ad0@d=304a<C02QXJ40=cLg05QHF01[Jf/0EUIF04Y:
BP1?Cdl0FEUI03De=@0k>c/0GemO06e]K@1VIVH0CDe=06=SH`1ADE40FEUI051@D01ADE40;bl_030`
<00e=CD0HF5Q07YjNP1NGUh0NGUi055AD@1FEUH0@T9206ATI02ATI40GEeM030`<01WIfL04Q8B0:JV
YP2QXJ40BDU906ATI01@D500L71`04i>CP1[Jf/0EeMG07EeM@1YJFT09RHV05aLG01?Cdl0?3`l05EE
E@0_;bl0EeMG05UIF@1UIFD0C4a<04i>CP1ADE40Lg=c04a<C01hN7P0LW9b03Ph>018B4P0?clo06i^
KP2<S8`0DU9B09:BTP1cLg<0C4a<06IVIP19BDT0?Cdm04Q8B01?Cdl0B4Q805IFEP11@D40GUiN02h^
;P1aLG40>c/k069RHP2BTY80>CTi0410@00m?Cd0@41005ADE01FEUH0JVYZ04a<C01?Cdl0B4Q804i>
CP0c<c<0=SHf04Q8B00`<300AdM70410@01=CDd0Jf][04];B`1RHV80=CDe04m?C`1FEUH0NGUi06=S
H`1JFUX0GEeM06ATI01ZJVX0GemO05EEE@0o?cl0IFEU03Xj>P0_;bl0GEeM07IfMP0l?3`0M7Ad06][
J`1?Cdl0K6a/0<71`@1CDe<0CTi>075aL@2>SXh0HV9R06EUI@2NWYh0P8200;2`/01PH600PX:204i>
CP1lO7`0TI6A0492@P1XJ6P0Cdm?07AdM01RHV80@D5104I6AP1oOgl0?Cdm055AD@0c<c<0;bl_06IV
IP11@D40BDU905MGE`1EEED0DU9B05EEE@1YJFT0HV9R4Oooool000oooooo0<T0JFUY05IFEP26QXH0
P82008R8R00l?3`0A4A406MWI`1QHF40`/;204Y:BP0g=cL0Bd];09BDU01]KFd0BTY:02<S8`1<C4`0
K6a/04Q8B01YJFT0T92@01`L700i>CT0GUiN05ADE02@T900QhN701/K6`1@D500^[Zj05iNGP0f=SH0
HV9R02PX:01?Cdl0T92@05ADE00k>c/0CDe=01dM7@0V9RH0HV9R04Q8B012@T80D51@030`<01GEeL0
QXJ603Xj>P0^;Rh0FUYJ03Ph>026QXH0IFEU01dM7@0/;2`0CDe=03`l?01cLg<0WIfM03<c<`0j>SX0
Lg=c03lo?`1mOGd0WIfM02`/;00Y:BT0F5QH05iNGP11@D40VYZJ01`L700g=cL0JFUY07YjNP1EEED0
N7Qh04I6AP0o?cl0Cdm?07]kN`13@d<0Shn?05IFEP0W9bL0:2PX07MgM`1>CTh0DU9B03`l?00W9bL0
?Shn07]kN`0g=cL0?Shn03Ph>00W9bL0;bl_08Z:RP1LG5`0@4100492@P0b<S80Cdm?09ZJVP1[Jf/0
8B4Q04m?C`14A4@0EeMG0;>c/`1:BTX09BDU04i>CP13@d<0F5QH08n?S`3>c/h0>c/k0451@@1IFET0
GEeM08f=S@0g=cL06ATI02h^;P1DE5@0FUYJ07QhN00N7Qh0:2PX05UIF@29RHT0@D5104Q8B01fMWH0
8b<S03Ph>01YJFT0:b/[04Y:BP0d=3@0:BTY05=CD`23Ph<0Bd];024Q8@1=CDd0@d=3055AD@22PX80
=cLg04];B`1_Kfl0ADE503Ti>@16ATH0GEeM02HV9P12@T80>CTi0492@P2OWil0KVi^01lO7`0^;Rh0
@d=304Q8B02ZZZX0Cdm?02<S8`0m?Cd0Cdm?05]KF`20P800bLW903`l?01ADE40FUYJ04A4A027QhL0
OWin024Q8@0V9RH0De=C05iNGP1aLG40DU9B02DU9@0o?cl0JVYZ03dm?@1/K6`0EEEE01lO7`15ADD0
Fe]K04i>CP1ZJVX00P0[:b/0E`1WIfL0QHF503De=@1OGel0:RXZ05]KF`2BTY80>c/k04E5A@17AdL0
?3`l09^KV`2l_;`0GUiN05mOG`11@D40G5aL0:>SX`0k>c/08b<S06][J`1EEED0E5AD08f=S@0c<c<0
H61P075aL@1XJ6P0XJ6Q08Z:RP0^;Rh0<S8b06a/K02ATI40a<C406=SH`0c<c<0EeMG06m_K`1MGEd0
JVYZ0;Ng]`1;Bd/0FEUI06MWI`20P800GemO0<G5a@1aLG40?clo059BDP1;Bd/0PH610820P01>CTh0
B4Q804E5A@1@D500JFUY0:RXZ025QHD0>c/k03Xj>P2<S8`0A4A404m?C`12@T80>SXj03Ti>@1SHf<0
MgMg03<c<`1=CDd0:2PX0451@@29RHT0MGEe01PH600Y:BT0CTi>03Ti>@0^;Rh0QHF503`l?00/;2`0
BDU902l_;`0Looooo`2Z05MGE`1XJ6P0>c/k03dm?@1hN7P0EeMG03Lg=`12@T80KFe]03@d=01jNWX0
FUYJ07inOP1/K6`0HV9R04];B`1FEUH0KFe]03/k>`1:BTX0=3@d06QXJ00j>SX0H61P05mOG`0e=CD0
DE5A01XJ6P1OGel0N7Qh06QXJ01>CTh0IVIV08b<S01PH600Hf=S06m_K`2OWil0I6AT04U9B@1=CDd0
C4a<04i>CP1OGel0N7Qh069RHP1:BTX0HF5Q05YJFP1VIVH0;Rh^05mOG`1`L700GUiN03Ph>00Z:RX0
GemO0451@@19BDT0>CTi03Ph>01KFe/0DU9B03/k>`18B4P0CTi>06=SH`1nOWh0Xj>S051@D013@d<0
GUiN051@D01[Jf/0JFUY08V9R@0_;bl0;2`/06=SH`0e=CD0?Cdm06YZJP1BDU80G5aL03`l?01FEUH0
?Shn055AD@0_;bl0A4A40451@@1:BTX0?clo04M7A`1:BTX0DE5A03@d=00/;2`0Cdm?03lo?`1:BTX0
Cdm?04A4A01@D500IVIV04e=C@1RHV80H61P06a/K019BDT0IfMW065QH@1EEED0O7al07YjNP1<C4`0
AdM7061PH017AdL0EEEE03Ti>@0K6a/0@D5101LG5`15ADD09RHV04A4A00k>c/0F5QH07IfMP1FEUH0
FEUI065QH@1]KFd0A4A406MWI`26QXH0Ph>308J6QP1`L700AdM705IFEP1KFe/0<C4a04I6AP0W9bL0
@d=303dm?@27QhL0Kfm_08:2PP1cLg<0HF5Q05ADE01JFUX0BTY:06=SH`1TI6@0@d=306m_K`0T92@0
E5AD05QHF016ATH0OWin03`l?01TI6@0<S8b06QXJ019BDT203`l?00P02XZ:P1QHF40Fe]K04Y:BP1c
Lg<0CTi>05]KF`0_;bl0?clo02LW9`1BDU80DE5A08V9R@0F5QH0De=C04i>CP0e=CD0BTY:03`l?017
AdL0LW9b05QHF02l_;`0VYZJ05YJFP1RHV80Hf=S05=CD`0m?Cd0ADE507UiN@2@T90204Y:BP1105MG
E`2`/;00BTY:04A4A01^KVh0>CTi071`L01_Kfl0A4A405=CD`1;Bd/0MGEe05YJFP1dM7@0Cdm?05QH
F01ADE40EeMG05EEE@0n?Sh0Lg=c069RHP1OGel0HV9R05iNGP2BTY80Hf=S07EeM@1NGUh0NGUi05QH
F01LG5`0LW9b07inOP12@T80CDe=06QXJ00k>c/0De=C02<S8`1FEUH0=CDe03lo?`0_;bl0IVIV05iN
GP3?cll0d];B0=kNgP2^[Zh0T92@06m_K`2XZ:P0T92@065QH@1aLG40@41004M7A`1>CTh0N7Qh04M7
A`2<S8`0JVYZ059BDP2<S8`00P0h>3P04@10@400>SXj04I6AP11@D40=CDe05ADE017AdL0Bd];07em
O@0a<C40C4a<0:2PX01@D500E5AD065QH@1eMGD0HV9R017ooooo000?ooooo`3o0:j^[P1kNg/0ZJVY
05=CD`1ZJVX0F5QH08:2PP0n?Sh0E5AD08V9R@2NWYh0@d=305mOG`0i>CT0DE5A08F5Q@0`<300@T92
04M7A`0e=CD0Lg=c092@T00a<C40:RXZ04];B`0`<300Ti>C05]KF`0U9BD0;Rh^051@D00l?3`0G5aL
08R8R00T92@0>3Ph05MGE`1:BTX0MGEe0;^k^`15ADD0<S8b03Lg=`1BDU80TY:B08J6QP0S8b<0C4a<
051@D01QHF40IfMW09fMW@13@d<0?Shn096AT@1LG5`0IFEU061PH00/;2`0@D5108V9R@1dM7@0HF5Q
03lo?`0J6QX0@T9209RHV01/K6`0:2PX05MGE`0a<C407alO06m_K`1CDe<0:2PX03Ph>00T92@0:b/[
04A4A01VIVH09BDU02HV9P0a<C40>SXj08:2PP1`L7009RHV03dm?@0o?cl0:b/[07=cL`1KFe/0=SHf
04A4A019BDT0=CDe08j>SP1oOgl06a/K0410@015ADD0E5AD096AT@1:BTX092@T03Ti>@1FEUH0JFUY
05mOG`2@T900=CDe030`<00b<S80AdM704A4A01oOgl0=SHf02HV9P13@d<0De=C05EEE@1eMGD0A4A4
02/[:`1/K6`0KFe]03Hf=P1EEED0GEeM01TI6@1YJFT0EEEE02d];@1DE5@0BDU903/k>`1iNGT0X:2P
03<c<`0Q8B40B4Q8061PH02FUYH0BTY:01lO7`0^;Rh0De=C0410@01EEED0PH6102LW9`12@T80B4Q8
0410@01_Kfl0[Jf]05IFEP0[:b/0AdM706QXJ01aLG40`L7104M7A`0/;2`0CDe=06YZJP0h>3P0GUiN
071`L00d=3@0KFe]07QhN00e=CD0Lg=c04A4A00X:2P0;2`/08j>SP1`L700Kfm_02`/;00U9BD0@d=3
09jNWP1CDe<0DE5A06][J`0P8200@D5108j>SP0^;Rh0GUiN05IFEP0l?3`0P8200:^[Z`0g=cL09RHV
05IFEP12@T80NGUi0410@00R8R80?Cdm06MWI`1PH600Vi^K04E5A@0m?Cd0Kfm_04Y:BP1gMgL0D51@
02PX:01:BTX0OGem07MgM`2BTY80=cLg05UIF@1gMgL0JVYZ04m?C`2?Shl0>c/k059BDP1RHV80Cdm?
08j>SP13@d<0=SHf04U9B@1aLG40EeMG04Q8B01MGEd0>CTi075aL@1_Kfl0>SXj05aLG01eMGD07QhN
02@T902FUYH0TI6A03/k>`1<C4`0>CTi03Ph>01MGEd0QXJ603De=@1@D500Hf=S000S02HV9P1jNWX0
JFUY02@T9014A4@0Bd];03dm?@1MGEd0ZZZZ04];B`0k>c/0CDe=07emO@2TY:@0Ti>C02LW9`13@d<0
FUYJ05iNGP16ATH0V9RH03Hf=P0n?Sh0HV9R0820P01:BTX0KVi^08b<S00^;Rh08B4Q04];B`14A4@0
P82008F5Q@0P82007?ooool0:`13@d<0BTY:03De=@0n?Sh0BDU905EEE@0a<C40@41007IfMP0I6AT0
AdM703/k>`1cLg<0Ti>C05QHF00m?Cd0E5AD055AD@0m?Cd0AdM703Lg=`1:BTX0=3@d0410@019BDT0
:BTY0492@P0K6a/0GemO05ADE01NGUh0?3`l06ATI01UIFD0ATI6055AD@1ZJVX0I6AT05aLG00i>CT0
?clo05IFEP0d=3@00P1>CTh09@1<C4`0=CDe04E5A@1KFe/0G5aL03Ph>00m?Cd0Cdm?04=3@`0k>c/0
>CTi05UIF@1JFUX0F5QH04M7A`15ADD0Hf=S06EUI@14A4@0EeMG07YjNP1BDU80EeMG08:2PP1OGel0
D51@05QHF01OGel0?Cdm038b<P1aLG40?Shn04I6AP1oOgl0EEEE04a<C01QHF400P1BDU805`17AdL0
Cdm?04A4A015ADD0=SHf04=3@`1:BTX0@d=305YJFP1NGUh0CDe=04Q8B00/;2`0@D51069RHP0n?Sh0
GemO05IFEP1;Bd/0I6AT06][J`1PH600I6AT0080DU9B0;D0Fe]K05UIF@1ZJVX0MGEe06EUI@2GUiL0
IfMW05IFEP1dM7@0ATI6059BDP13@d<0:BTY05YJFP0b<S80JFUY04i>CP1VIVH0DE5A08F5Q@24Q8@0
HF5Q055AD@1MGEd0JVYZ05MGE`1jNWX0RXZ:07YjNP1HF5P0GUiN05EEE@1/K6`0RXZ:04A4A01LG5`0
<S8b05EEE@19BDT0Rh^;08>3P`2JVYX0OGem079bLP1BDU80KFe]065QH@1^KVh0FUYJ02LW9`1>CTh0
;Bd]08>3P`2;Rh/0A4A404];B`16ATH0QXJ60410@018B4P0?Cdm069RHP1JFUX0<30`04=3@`10@400
GUiN07IfMP18B4P0>c/k04U9B@1GEeL0=cLg06ATI019BDT0EeMG01LG5`1[Jf/0EEEE02h^;P1NGUh0
<C4a05eMG@1RHV80:2PX06=SH`1=CDd0EEEE07AdM00o?cl0;2`/03hn?P0c<c<0=CDe05eMG@0b<S80
FUYJ020P801GEeL0<C4a07QhN01eMGD06ATI03dm?@18B4P0=3@d05QHF00j>SX0Fe]K03lo?`1@D500
?Cdm04e=C@0[:b/0;2`/04E5A@0N7Qh0=CDe030`<01ZJVX0J6QX03Ti>@1^KVh0:b/[04];B`0j>SX0
EeMG03`l?012@T80;bl_03/k>`13@d<0;bl_05=CD`0_;bl0CDe=02PX:00o?cl0>CTi04a<C00f=SH0
De=C0:j^[P3oool0a/K6092@T017AdL0MGEe09:BTP15ADD0ATI605MGE`1/K6`0Kfm_0:2PX00c<c<0
Ogmo04=3@`1YJFT0GemO03`l?01UIFD0A4A4061PH01ZJVX0=SHf051@D021PH40De=C04U9B@0];Bd0
E5AD092@T01:BTX0>SXj059BDP1>CTh0BTY:051@D01MGEd0K6a/017ooooo000?ooooo`80IVIV0?l0
];Bd04e=C@1NGUh0Ng]k09BDU016ATH0?Shn05EEE@15ADD0IFEU0;6a/@16ATH0?clo07IfMP1YJFT0
T92@065QH@0^;Rh0?3`l06YZJP1IFET0OWin05YJFP0Z:RX0@d=306e]K@1cLg<0UYJF04m?C`0[:b/0
;Bd]065QH@0k>c/0OGem065QH@0E5AD0;Bd]05IFEP1WIfL0=SHf05QHF00b<S80Jf][07]kN`1FEUH0
LW9b05EEE@0L71`0A4A406EUI@1iNGT0E5AD02l_;`0U9BD0I6AT08B4Q00Z:RX08B4Q05=CD`1;Bd/0
LW9b05ADE00C4a<08b<S04E5A@1RHV80I6AT0:j^[P1BDU804a<C04e=C@1^KVh0Hf=S07]kN`0J6QX0
7AdM02LW9`1FEUH0BDU905=CD`16ATH0<S8b05aLG01aLG40C4a<06=SH`1HF5P06ATI01lO7`1TI6@0
?3`l07]kN`0/;2`09bLW04Y:BP1jNWX0?Shn03Xj>P1LG5`09BDU06EUI@26QXH0;Rh^03<c<`14A4@0
?3`l03Ti>@25QHD0Cdm?03/k>`1QHF40;2`/04Q8B02BTY80BTY:01DE5@0g=cL0Cdm?04a<C022PX80
A4A402HV9P1:BTX0?3`l0492@P1^KVh0Jf][02DU9@0n?Sh0MWIf03`l?01TI6@0<C4a02PX:01CDe<0
[:b/08B4Q01<C4`0ADE501lO7`28R8P0^[Zj03hn?P1HF5P0LW9b03Xj>P0N7Qh0R8R804E5A@1CDe<0
?clo020P800`<300@d=306QXJ00m?Cd0Fe]K04M7A`0`<300QHF5079bLP0S8b<0EUIF0492@P14A4@0
F5QH0:^[Z`0o?cl0CTi>03lo?`0f=SH0MGEe07IfMP0/;2`0:BTY05EEE@1RHV80U9BD0410@00T92@0
=CDe051@D01HF5P0Vi^K0:2PX00[:b/0?Cdm06i^KP1EEED0Vi^K09bLW00N7Qh0EeMG09BDU01TI6@0
Bd];05]KF`1;Bd/0IVIV05UIF@0h>3P0DE5A02PX:00Y:BT0EUIF06EUI@1IFET0M7Ad03lo?`1BDU80
GemO02PX:01SHf<0C4a<0451@@2@T900B4Q80410@01^KVh0>CTi0410@02ATI40Xj>S09NGU`20P800
A4A407AdM01EEED09bLW04];B`1KFe/0HF5Q06m_K`2VYZH0<S8b05IFEP1OGel0GEeM08>3P`2/[:`0
=cLg034a<@1>CTh0I6AT07IfMP1nOWh092@T01dM7@1EEED0Kfm_071`L02HV9P0/;2`03Lg=`0o?cl0
0240Ogmo05]KF`1jNWX0IfMW03/k>`1UIFD0LG5a07EeM@1SHf<0=CDe01`L7012@T80JVYZ04Q8B010
@400FUYJ03De=@0L71`0De=C04i>CP0N7Qh0A4A404];B`0/;2`0=CDe07=cL`1FEUH0:BTY05ADE00Y
:BT0=CDe05eMG@13@d<07?ooool0FP1>CTh0Hf=S0492@P18B4P0GEeM05MGE`0o?cl0CTi>07YjNP0K
6a/0ATI60451@@1CDe<0IVIV075aL@1JFUX0N7Qh05ADE016ATH0DU9B03Lg=`1DE5@08B4Q03De=@19
BDT06ATI04a<C00O7al0Kfm_04m?C`1TI6@0ATI606m_K`1lO7`0C4a<05iNGP25QHD0Kfm_06EUI@0[
:b/0=CDe05=CD`0o?cl0DU9B05IFEP1^KVh0@T92061PH01?Cdl0IVIV03dm?@13@d<0Kfm_04i>CP12
@T80:2PX06QXJ00j>SX0AdM703/k>`0c<c<0Fe]K04i>CP0f=SH0BDU904i>CP1cLg<0CTi>08J6QP0o
?cl0@D5106e]K@13@d<0De=C051@D01XJ6P09bLW02@T901SHf<0=3@d03/k>`1DE5@0CDe=05YJFP0n
?Sh0D51@04i>CP14A4@0;Bd]03lo?`80ADE50:L0CTi>04e=C@15ADD0AdM7038b<P0c<c<0De=C03@d
=018B4P0De=C03/k>`1@D500KFe]05=CD`1HF5P0JVYZ0820P01DE5@0EUIF07inOP1EEED0@D5107em
O@1<C4`0HF5Q06i^KP1JFUX0GUiN04Q8B00Y:BT0D51@03<c<`1?Cdl0DE5A06EUI@14A4@0AdM707Yj
NP1WIfL0F5QH079bLP1oOgl0ADE505YJFP1bLW80Ph>309RHV01oOgl0EUIF04i>CP1WIfL0B4Q805AD
E00m?Cd0ATI605=CD`2PX:00Lg=c0861P@1kNg/0HV9R06QXJ01hN7P0JVYZ07UiN@2:RXX0?clo05YJ
FP0G5aL0Rh^;07QhN00k>c/0EeMG03Ph>01DE5@0?3`l055AD@12@T80@D5105QHF00O7al0A4A405UI
F@10@400L71`06=SH`1:BTX0=cLg04M7A`0];Bd0ADE507AdM02SXj<0;2`/055AD@1NGUh0>SXj06UY
J@0a<C40BDU905]KF`11@D40Shn?06YZJP0i>CT0CDe=04Y:BP0h>3P0=SHf03Ti>@1ADE40GUiN034a
<@0o?cl09BDU08R8R00Z:RX0AdM70492@P0B4Q80E5AD05iNGP0U9BD0C4a<02d];@1GEeL0B4Q8055A
D@15ADD0@d=303<c<`0e=CD0CDe=02HV9P1SHf<0@d=304a<C015ADD0<c<c061PH00Q8B40De=C024Q
8@1=CDd0?3`l04=3@`1@D500GEeM05YJFP1;Bd/0LW9b03Xj>P1IFET092@T059BDP0i>CT0@4100492
@P1FEUH0XJ6Q0=[JfP1FEUH0G5aL0410@01lO7`0RHV90410@00205MGE`0M05IFEP11@D40D51@04e=
C@1dM7@0IfMW0<O7a`2KVi/0F5QH05iNGP15ADD0I6AT05EEE@0c<c<0>3Ph051@D00k>c/0B4Q803Xj
>P1<C4`0NWYj03dm?@13@d<0S8b<05IFEP17AdL0EEEE05iNGP1GEeL04Oooool000oooooo0=T0Hf=S
059BDP2>SXh0JVYZ07UiN@18B4P0K6a/08b<S01QHF40^[Zj03lo?`0d=3@0EeMG09:BTP1ZJVX08b<S
02LW9`1^KVh0S8b<04Y:BP1=CDd0FEUI01TI6@0`<300E5AD028R8P1FEUH09bLW03hn?P1HF5P0HF5Q
028R8P0c<c<0>3Ph04A4A01KFe/0Ogmo01/K6`0Q8B40EUIF03/k>`1RHV80N7Qh01lO7`0c<c<0Lg=c
04M7A`2DU9@0T92@020P800O7al0ADE508b<S020P800>SXj03`l?01=CDd0DU9B04a<C01;Bd/0KFe]
01XJ6P0e=CD0Lg=c03lo?`1JFUX0Cdm?01hN7P0/;2`0G5aL07YjNP0_;bl0=3@d02d];@1=CDd0HV9R
04U9B@0i>CT0GemO02l_;`0f=SH0LG5a061PH00U9BD0@T9202h^;P0/;2`0LW9b0820P00P82006a/K
03`l?01ADE40YJFU04];B`0Q8B40;Rh^03Ti>@0o?cl0Fe]K09:BTP0P8200;2`/05ADE013@d<0Lg=c
0820P00W9bL0:2PX0451@@1UIFD0H61P09>CT`1;Bd/0;Bd]05ADE01XJ6P0>CTi069RHP1kNg/09RHV
06a/K01_Kfl0ADE5071`L00n?Sh08R8R04Q8B01lO7`0FUYJ05IFEP0Q8B40ATI607moO`18B4P09RHV
04];B`1HF5P0ATI604a<C01OGel07AdM03hn?P1XJ6P0@D5107=cL`23Ph<08B4Q020P801HF5P0EeMG
06a/K01YJFT05ADE02h^;P0P8200BDU903dm?@1dM7@0JFUY01lO7`0o?cl0GEeM051@D02<S8`0=3@d
02LW9`18B4P0MgMg07IfMP2c/k<0@T9202`/;01;Bd/0NGUi06MWI`1VIVH0Y:BT03Ph>01[Jf/0H61P
04i>CP28R8P0K6a/01/K6`15ADD0K6a/03dm?@1NGUh0?clo01dM7@1FEUH0Xj>S04Q8B00i>CT0>c/k
034a<@1ADE40N7Qh01dM7@1>CTh0@T9205ADE01iNGT0@D5101lO7`0f=SH0G5aL06YZJP1eMGD06QXJ
03De=@1FEUH0BDU909NGU`1SHf<06ATI0080EeMG04L0RXZ:09JFUP0_;bl0:b/[08N7Q`2IVIT0f=SH
08R8R00h>3P0S8b<07=cL`12@T80Lg=c05YJFP0[:b/0CDe=092@T01DE5@0MWIf04I6AP10@400Bd];
06YZJP1OGel0?3`l07]kN`0e=CD0BDU905iNGP1TI6@0>c/k07alO01:BTX08b<S05MGE`2TY:@0FEUI
03Ph>00o?cl0?Shn07EeM@2HV9P09BDU02h^;P1FEUH0?Shn07=cL`1eMGD05ADE03Ph>01TI6@0BTY:
06a/K02>SXh0B4Q801dM7@13@d<0IfMW04U9B@1gMgL0H61P02XZ:P0];Bd0Fe]K08N7Q`14A4@0Lg=c
03@d=01;Bd/0GUiN03`l?00Looooo`2305ADE01^KVh0@d=303/k>`25QHD0Kfm_04a<C013@d<0M7Ad
04A4A01]KFd0Cdm?04];B`1/K6`0JFUY06a/K01MGEd0CTi>04A4A01?Cdl0Bd];07EeM@0l?3`0ADE5
06MWI`0a<C40ADE501DE5@1CDe<0IFEU051@D01;Bd/0EUIF05MGE`1@D500Fe]K06i^KP2HV9P0GemO
0492@P0^;Rh0Cdm?05iNGP1CDe<0HV9R04a<C011@D40BTY:04a<C01DE5@092@T069RHP1VIVH0Cdm?
05IFEP0n?Sh0Lg=c03lo?`1;Bd/0D51@04Q8B01MGEd0F5QH03lo?`1EEED0E5AD07=cL`17AdL0QhN7
04Y:BP19BDT0OWin05aLG01<C4`0?clo0:b/[00f=SH0:b/[08Z:RP15ADD0@D51061PH01?Cdl0DU9B
04M7A`1VIVH0A4A404e=C@18B4P0@T9204I6AP1NGUh0G5aL05IFEP1BDU80EeMG03`l?00k>c/0I6AT
03lo?`1NGUh0Fe]K04A4A01UIFD0GUiN051@D01QHF40Cdm?051@D017AdL0DU9B05QHF00m?Cd0;bl_
051@D010@400IVIV04m?C`0c<c<0>c/k04Q8B00M7Ad0@D5102DU9@1>CTh0>c/k05aLG00];Bd0K6a/
069RHP1<C4`00P1RHV80C020P800BTY:069RHP1YJFT0KVi^05EEE@1?Cdl0EEEE06][J`24Q8@0D51@
06YZJP0g=cL0EEEE04=3@`2RXZ80OGem079bLP1^KVh0EUIF07QhN01PH600FUYJ07EeM@1PH600?clo
0861P@0L71`0Rh^;0861P@12@T80P82004I6AP1IFET0>SXj07alO01DE5@0Bd];06QXJ00^;Rh0KFe]
06MWI`14A4@0P82006ATI01bLW80?Cdm05]KF`0];Bd0BTY:0451@@1DE5@092@T04a<C016ATH0820P
038b<P0`<300ADE5055AD@0V9RH0M7Ad069RHP0R8R80@d=3030`<011@D40=3@d03Hf=P0b<S80Fe]K
02l_;`1<C4`07AdM05ADE00V9RH2059BDP1?00T92@0h>3P0BDU9024Q8@1?Cdl0@D5106][J`18B4P0
F5QH0410@013@d<0<C4a03lo?`1ADE40=cLg04A4A00`<300C4a<0492@P0c<c<0HV9R02HV9P1?Cdl0
?Cdm07AdM01CDe<0GEeM04m?C`1DE5@0=3@d03Xj>P1DE5@0:2PX04=3@`0M7Ad0F5QH05ADE01MGEd0
>3Ph05UIF@25QHD0UiNG051@D00e=CD0B4Q809fMW@1hN7P0?Shn04];B`1<C4`0H61P05EEE@1/K6`0
820P06EUI@0l?3`0G5aL05ADE00g=cL0OGem02/[:`1CDe<0AdM703Ph>019BDT0HF5Q03dm?@1SHf<0
=cLg05MGE`1hN7P0<30`04m?C`29RHT0CTi>05QHF01ADE40Ph>305QHF00Aooooo`003oooool04P2P
X:00J6QX06UYJ@1<C4`0Ti>C04Q8B01YJFT0DU9B06m_K`2][Jd0EeMG03Hf=P18B4P0AdM707MgM`0_
;bl0820P02/[:`80BDU904D0TY:B08B4Q00N7Qh09bLW05ADE01RHV80alO7069RHP0L71`0>3Ph06=S
H`1FEUH0Ti>C06i^KP0Y:BT0>SXj05EEE@14A4@0EUIF06IVIP0P8200:RXZ04U9B@0m?Cd0I6AT04I6
AP0U9BD0E5AD08F5Q@0n?Sh0=cLg05aLG00T92@0B4Q806][J`0I6AT0;bl_05QHF011@D40DE5A0:n_
[`1?Cdl0A4A403hn?P14A4@0QhN708R8R00Q8B406a/K02l_;`1ADE40Cdm?07EeM@0G5aL0C4a<079b
LP1FEUH0DE5A08V9R@0l?3`0820P03<c<`1TI6@0MgMg0::RXP0S8b<0ADE504U9B@29RHT00P1`L700
C01ADE40>c/k05=CD`1^KVh0>3Ph0861P@1>CTh0;Rh^04I6AP1gMgL0GUiN075aL@16ATH09bLW03/k
>`2EUID0EUIF03Hf=P1@D5008B4Q03Hf=P22PX80@T9202/[:`20P800?Cdm028R8P1NGUh0Shn?02h^
;P1LG5`0DU9B03hn?P2CTi<0K6a/020P8011@D40FEUI055AD@1nOWh0:RXZ038b<P1MGEd0O7al04];
B`2WYjL0]kNg01hN7P0m?Cd0Kfm_05UIF@2CTi<0>SXj03@d=01EEED0PX:206MWI`1CDe<0IfMW04i>
CP1NGUh0KFe]03Hf=P1BDU80@T9202<S8`0W9bL0FEUI07IfMP0];Bd0E5AD02l_;`12@T80LG5a0820
P00a<C420451@@0l03lo?`2b/[80GemO02TY:@0g=cL0>3Ph028R8P1OGel0[Zj^05MGE`1HF5P0?Cdm
055AD@2NWYh0YjNW038b<P0d=3@0N7Qh04m?C`1iNGT0NWYj024Q8@1DE5@0A4A4055AD@1lO7`0JVYZ
01LG5`1=CDd0D51@06YZJP2MWId0?Cdm02PX:01^KVh0Jf][05IFEP2?Shl0;Bd]06EUI@2JVYX0BTY:
05eMG@1JFUX0:b/[04M7A`2CTi<0De=C06e]K@0_;bl0Bd];08n?S`19BDT0>3Ph07AdM00b<S80@410
09>CT`13@d<0K6a/0P18B4P02@21PH40Ogmo02XZ:P0n?Sh0CTi>07IfMP2GUiL0GEeM02TY:@0205QH
F00`03`l?01WIfL0bLW904Q8B00k>c/0De=C04a<C01XJ6P0f=SH071`L00[:b/0>CTi04A4A01FEUH0
PH6104a<C00e=CD0BDU905ADE019BDT0DE5A07AdM00Z:RX0Cdm?0861P@12@T80DU9B05]KF`0O7al0
?3`l04Q8B01VIVH0CTi>06ATI00M7Ad07alO0410@01hN7P0;Rh^03Hf=P0o?cl06a/K03Lg=`1PH600
:RXZ03De=@0_;bl09BDU7?ooool0G011@D40EeMG0492@P0o?cl0@T9205]KF`18B4P0CTi>08>3P`0g
=cL0>c/k04A4A01ADE40EEEE061PH01JFUX0PH6108V9R@1=CDd0Bd];020P801?Cdl0:RXZ03De=@16
ATH0;Rh^051@D00[:b/0CDe=06i^KP1KFe/0Bd];055AD@1BDU80Bd];04m?C`1BDU80EeMG05ADE00n
?Sh0=cLg03hn?P0l?3`0Cdm?06EUI@1CDe<0?clo051@D01aLG40GEeM03@d=00c<c<0CTi>065QH@10
@400;2`/05MGE`0i>CT0ATI6055AD@15ADD0AdM704];B`17AdL0CDe=059BDP1@D500F5QH06m_K`1=
CDd0CTi>05iNGP1WIfL0De=C05aLG02?Shl0EEEE0451@@1]KFd0ADE50410@01IFET0C4a<04=3@`1A
DE40CDe=03/k>`0j>SX0@41002h^;P0m?Cd0@T920P16ATH08P0m?Cd0D51@02@T9015ADD0CDe=03/k
>`1PH600Cdm?05MGE`1MGEd0Fe]K06=SH`1^KVh0H61P07YjNP1UIFD0Hf=S06YZJP1TI6@0?clo06MW
I`1:BTX0EeMG07EeM@11@D40D51@04A4A00U9BD0F5QH02PX:016ATH0=SHf069RHP1<C4`206m_K`0G
04a<C01`L700M7Ad08j>SP28R8P0MgMg06UYJ@2FUYH0J6QX07=cL`16ATH0J6QX07inOP1:BTX0CTi>
02l_;`0n?Sh0>SXj0;>c/`1oOgl0K6a/079bLP1YJFT00P1^KVh0H01eMGD0TI6A05mOG`0P8200E5AD
02@T9020P800RHV904e=C@1ADE40>SXj05aLG00g=cL0EUIF0410@01NGUh0GEeM01dM7@0k>c/0C4a<
03@d=01GEeL0AdM705UIF@0j>SX0DU9B03@d=01QHF40Fe]K07QhN00N7Qh0BTY:059BDP0`<300@T92
03Ti>@11@D40GEeM04=3@`2<S8`0M7Ad03dm?@1OGel0@d=303Xj>P0^;Rh0>c/k03Hf=P1_Kfl0>CTi
04];B`0h>3P0PH6103dm?@1IFET0Fe]K02@T9015ADD0DE5A01lO7`1IFET0@D5106YZJP1EEED0EUIF
04A4A01CDe<0>CTi03lo?`0n?Sh08B4Q04U9B@0e=CD0CTi>02l_;`0o?cl0KFe]02/[:`1TI6@0<30`
06IVIP16ATH0BTY:04A4A017AdL0CTi>03Ph>012@T80>SXj05iNGP0f=SH0EeMG04E5A@0l?3`0@d=3
06ATI080Bd];02D0TI6A05eMG@1cLg<0`<3009:BTP16ATH0DU9B08F5Q@2=SHd0De=C07QhN00/;2`0
M7Ad05iNGP26QXH0EeMG0451@@1QHF40ATI605ADE01FEUH0<c<c04=3@`1aLG40?clo03Ph>016ATH0
EeMG06EUI@0e=CD0>3Ph07MgM`1@D500Cdm?04i>CP1GEeL0GEeM017ooooo000?ooooo`0>08^;R`2B
TY80X:2P04i>CP1fMWH0NGUi09^KV`0o?cl0EUIF0861P@1]KFd0NGUi0;^k^`18B4P206a/K0180492
@P1MGEd0IfMW01dM7@0h>3P0KVi^0410@00n?Sh0>CTi038b<P1FEUH0RXZ:02l_;`1CDe<0ATI603Hf
=P1?Cdl0KVi^02/[:`13@d<0@D5105=CD`1gMgL0Z:RX04a<C00X:2P0AdM7055AD@2BTY80CDe=01PH
600i>CT0IFEU05UIF@1SHf<0/k>c02h^;P0g=cL0GUiN04i>CP1UIFD0Lg=c034a<@0h>3P0I6AT05eM
G@1gMgL0@41002DU9@1KFe/0LW9b06][J`1LG5`0U9BD03dm?@0i>CT0Lg=c04=3@`14A4@0Cdm?01hN
7P0M7Ad0>c/k061PH00R8R80<S8b034a<@0o?cl0J6QX04I6AP0N7Qh0ATI60P0g=cL0G@1MGEd0BTY:
01lO7`13@d<0;Rh^0492@P2=SHd0M7Ad01LG5`0a<C40AdM705UIF@2l_;`0@d=301`L700/;2`0CDe=
05MGE`1YJFT0Xj>S02d];@0Z:RX0De=C06i^KP1FEUH0YJFU03`l?00^;Rh0>CTi04M7A`1OGel0R8R8
02/[:`0o?cl0IVIV07AdM00j>SX0DE5A051@D00Q8B40CDe=06a/K00_;bl0CDe=02XZ:P0L71`0BTY:
06][J`10@400?Shn04U9B@0[:b/0IFEU08J6QP0Q8B40=SHf05mOG`0T92@0;Bd]071`L00X:2P0EeMG
04=3@`11@D40Ti>C06IVIP0[:b/05ADE051@D01GEeL0GEeM0;Ng]`0b<S809RHV06EUI@20P800D51@
09FEU@1^KVh09BDU07EeM@2e]KD0ATI608b<S01TI6@0;Rh^02d];@1bLW80Lg=c07EeM@0O7al09bLW
03lo?`02061PH00C04Q8B021PH40=3@d03/k>`1ZJVX0@d=308b<S01:BTX08B4Q071`L01oOgl0CTi>
055AD@1<C4`0?3`l09NGU`1mOGd0>CTi0410@00203Ph>00_07]kN`11@D40?Cdm04m?C`1ADE40JFUY
06i^KP0W9bL0CTi>03lo?`16ATH0YJFU02<S8`17AdL0EeMG0492@P1cLg<0cLg=06][J`0_;bl0Cdm?
08>3P`3=cLd0<30`04I6AP1EEED0IVIV065QH@2KVi/0XJ6Q04A4A01bLW80PX:204];B`1jNWX0P820
03De=@0Y:BT0V9RH071`L01?Cdl0IfMW02/[:`0j>SX0BDU907moO`13@d<00P1ADE40700`<300@d=3
06UYJ@0_;bl0Hf=S05aLG00l?3`0IVIV07MgM`14A4@0?Cdm02d];@1BDU80PH6108J6QP0f=SH0;Rh^
04U9B@15ADD0IFEU08N7Q`0h>3P06a/K03hn?P1ADE40I6AT09ZJVP1XJ6P2024Q8@0504m?C`15ADD0
Q8B4071`L00C4a<07?ooool09`1?Cdl0M7Ad06IVIP1;Bd/0GEeM07IfMP0j>SX0=cLg05aLG00H61P0
=3@d02d];@1OGel0Vi^K065QH@1?Cdl0EEEE04e=C@1?Cdl0Fe]K03hn?P1JFUX0:BTY03lo?`1ADE40
6QXJ04a<C00O7al0H61P065QH@1PH600>c/k06i^KP1]KFd0BDU9065QH@1iNGT0Hf=S06UYJ@0202/[
:`0P04Q8B010@400BDU903dm?@1@D500=cLg038b<P0c<c<0ATI601dM7@15ADD0EUIF03@d=00f=SH0
:b/[0410@01EEED0Fe]K04I6AP0i>CT0FUYJ05mOG`15ADD0De=C06m_K`1OGel0>CTi05EEE@1:BTX0
D51@055AD@12@T82055AD@0=05YJFP0Z:RX092@T05iNGP1IFET0D51@04m?C`1@D500GEeM04U9B@1I
FET0DE5A04M7A`0203/k>`0?05mOG`1PH600G5aL05EEE@17AdL0EEEE03Hf=P1RHV80E5AD03Hf=P1?
Cdl0De=C03Ph>017AdL0F5QH0080CTi>00X0EeMG06][J`1<C4`0Jf][065QH@18B4P0;bl_06ATI01C
De<0EeMG0P1OGel06`1JFUX0B4Q802LW9`1MGEd0;Rh^05]KF`1CDe<0KFe]06MWI`2<S8`0O7al07mo
O`1dM7@0LW9b07UiN@11@D40P82008>3P`2;Rh/0Lg=c06m_K`1MGEd0LG5a096AT@1ADE40JFUY03Lg
=`0204M7A`1:07alO01kNg/0TI6A09NGU`1BDU80O7al05=CD`1?Cdl0Fe]K07EeM@14A4@0Kfm_018B
4P1UIFD0R8R803De=@1NGUh0BDU905]KF`1DE5@0Kfm_055AD@11@D40Cdm?03De=@1FEUH0GUiN04a<
C01RHV80E5AD06MWI`1>CTh0HF5Q02<S8`1:BTX0?Cdm071`L00_;bl0IFEU075aL@0];Bd0@D5103Hf
=P1KFe/0Lg=c03@d=028R8P0KFe]03Ti>@1BDU80De=C03<c<`0e=CD0@D5103Ti>@1_Kfl0DU9B065Q
H@0I6AT0KFe]03Lg=`1mOGd0KVi^02PX:012@T80ADE503De=@1`L700CDe=06][J`1UIFD0EUIF04U9
B@1@D50203dm?@0F05IFEP0a<C40AdM703Hf=P1_Kfl0FEUI03Lg=`1HF5P0;2`/065QH@0k>c/0N7Qh
05MGE`1<C4`0CTi>055AD@1<C4`0@41004a<C00m?Cd0PX:202h^;P80E5AD0P1QHF40:01SHf<0J6QX
05EEE@1WIfL0C4a<051@D01bLW80;bl_05ADE01CDe<0DU9B04i>CP1GEeL0JVYZ069RHP2RXZ80EUIF
092@T01bLW80E5AD06MWI`0X:2P0BTY:04Q8B00i>CT0BDU905aLG01CDe<0CTi>03De=@0k>c/0Bd];
04M7A`1CDe<0JFUY05QHF01OGel0FUYJ08V9R@1ZJVXAooooo`003oooool206EUI@0E09BDU01_Kfl0
IfMW05YJFP25QHD0IVIV069RHP2=SHd0?Cdm04E5A@1ZJVX0De=C075aL@0m?Cd0DU9B07UiN@20P800
?Shn04Q8B01KFe/0<S8b0080HF5Q0;00<S8b04a<C01:BTX0GEeM0::RXP2OWil0>3Ph05ADE01@D500
Bd];07inOP1PH600:2PX02l_;`1GEeL0Fe]K05QHF01aLG40:b/[069RHP1[Jf/0Cdm?07MgM`1;Bd/0
:RXZ03Ti>@1TI6@0OGem06m_K`0k>c/08b<S03Lg=`1OGel0?3`l059BDP1dM7@09bLW04I6AP1MGEd0
AdM706YZJP1IFET0;2`/04=3@`1TI6@0Lg=c0451@@1FEUH0@41005aLG024Q8@0@41003@d=016ATH0
@41004I6AP1DE5@0BDU903hn?P1]KFd0GemO04I6AP29RHT0Hf=S020P800n?Sh0CTi>05IFEP1oOgl0
?clo028R8P1;Bd/0J6QX04Y:BP1MGEd0PH61020P801>CTh0IVIV030`<01`L700Ph>302<S8`0P8200
F5QH065QH@1EEED0D51@028R8P0M7Ad0IfMW07MgM`13@d<0GEeM06IVIP0b<S80KVi^075aL@0g=cL0
G5aL03dm?@0^;Rh0KFe]096AT@0m?Cd0DE5A03Ph>01:BTX0LG5a05]KF`0b<S80Cdm?06EUI@0b<S80
DE5A05]KF`0^;Rh0EEEE06MWI`0a<C40F5QH08F5Q@0Z:RX0:BTY05ADE014A4@0QHF507QhN00Q8B40
;Rh^05UIF@1=CDd0?3`l0:2PX01MGEd0:b/[05EEE@1PH600CDe=07inOP1ADE409BDU038b<P1YJFT0
EEEE08R8R016ATH0@D51051@D01`L700D51@065QH@1[Jf/0@d=307YjNP1EEED0=CDe05]KF`1JFUX0
=CDe04E5A@1_Kfl0D51@04U9B@15ADD0>c/k08^;R`27QhL0;2`/04U9B@16ATH0>3Ph069RHP1WIfL0
9bLW059BDP80E5AD05L0HV9R03<c<`0a<C40DU9B04M7A`2ATI40GemO02PX:01HF5P0HV9R04];B`1g
MgL0GemO02DU9@1fMWH0ADE507emO@1OGel06ATI02l_;`1fMWH0Ng]k07alO01hN7P0=3@d07inOP1]
KFd0?Shn08Z:RP1:BTX0=cLg05aLG01mOGd0G5aL08f=S@0l?3`0CTi>08B4Q02EUID0?Cdm04Q8B01f
MWH0@d=305=CD`2CTi<0BTY:03Ti>@1gMgL0?3`l04A4A01hN7P0Y:BT051@D018B4P0>c/k04=3@`1o
Ogl0QXJ602h^;P17AdL0IVIV051@D01fMWH0HV9R02LW9`18B4P0De=C04i>CP1NGUh0RHV905IFEP0^
;Rh0CTi>06IVIP1LG5`0YZJV04E5A@0N7Qh0?Shn05mOG`19BDT0Cdm?07AdM00T92@0CTi>071`L00j
>SX07?ooool01P1KFe/0EEEE04=3@`1:BTX0IFEU05EEE@80<c<c00X0OGem03dm?@18B4P0@d=3069R
HP1eMGD0De=C05ADE01CDe<0I6AT0P1:BTX06P0e=CD0EeMG03/k>`0m?Cd0EUIF03lo?`1@D5008b<S
055AD@1iNGT0H61P03lo?`1OGel0HV9R059BDP1DE5@0G5aL08n?S`1DE5@0?3`l03Ti>@0g=cL0@410
04M7A`1FEUH0ADE50P0a<C40>01KFe/0B4Q802TY:@0n?Sh0BTY:059BDP0m?Cd0<c<c04i>CP16ATH0
BDU904M7A`13@d<0CDe=055AD@17AdL0Cdm?05aLG01eMGD0GemO06EUI@15ADD0AdM707YjNP1ADE40
@d=304E5A@2UYJD0CDe=03lo?`1dM7@0@41003hn?P1OGel0Bd];051@D01;Bd/0Fe]K04e=C@10@400
>SXj03Hf=P0j>SX0EUIF055AD@1;Bd/0@D5105QHF00Z:RX0CTi>06ATI00g=cL0Hf=S05ADE01FEUH0
HF5Q0P1JFUX0]@1PH600EeMG06=SH`18B4P0F5QH06YZJP1?Cdl0<c<c05EEE@16ATH0GemO04Y:BP13
@d<0@T9204I6AP0V9RH0AdM703<c<`17AdL0=SHf05aLG014A4@0OWin05iNGP1;Bd/0EEEE079bLP2?
Shl0AdM706UYJ@1dM7@0QHF509>CT`1QHF40FEUI06e]K@1gMgL0@d=3061PH00n?Sh0FEUI04I6AP2C
Ti<0RHV907MgM`1cLg<0H61P06QXJ01ADE40FUYJ06UYJ@1gMgL0>c/k05YJFP0Y:BT0Ogmo092@T011
@D40IFEU04I6AP1JFUX0@41005QHF01FEUH0ADE504e=C@0R8R80Bd];05YJFP0b<S80Bd];0410@01W
IfL0>CTi04e=C@0g=cL0EeMG04Q8B01YJFT0;Bd]051@D01DE5@0;Bd]04m?C`0j>SX0D51@061PH00b
<S80PX:207YjNP1BDU80KFe]05=CD`1?Cdl0>3Ph04U9B@0j>SX0MgMg04M7A`1LG5`0>CTi071`L01;
Bd/0Rh^;08Z:RP0_;bl0De=C055AD@0d=3@0IFEU04Y:BP1jNWX0L71`05]KF`1FEUH0G5aL0451@@1@
D500EEEE04=3@`1GEeL0?Shn05UIF@16ATH0>c/k079bLP0m?Cd0H61P03dm?@1QHF40ADE505ADE01<
C4`0FEUI059BDP1:BTX0DU9B04A4A01HF5P0=3@d051@D012@T80Bd];06IVIP25QHD0G5aL07inOP2S
Xj<0ADE506QXJ01EEED0;2`/04U9B@1ADE40JVYZ05iNGP1CDe<0LG5a04Y:BP1WIfL0FUYJ079bLP1X
J6P0GUiN07QhN015ADD0FEUI05aLG015ADD0DE5A06=SH`0n?Sh0BDU904A4A01;Bd/0H61P04=3@`17
AdL0GUiN051@D01FEUH00P1HF5P00`1GEeOoooooooooo`0?ooooo`003oooool0VP23Ph<0NWYj08J6
QP17AdL0R8R805MGE`1kNg/0>3Ph03lo?`2@T900E5AD0410@01>CTh0ATI606IVIP0m?Cd08b<S04Y:
BP1BDU80Bd];05MGE`1nOWh0:b/[02h^;P1LG5`0GEeM09RHV00`<3004Q8B030`<01KFe/0BDU909NG
U`1UIFD0<S8b04E5A@1OGel0DU9B06IVIP1dM7@02@T9024Q8@0o?cl0GemO0:b/[00m?Cd07AdM04M7
A`1TI6@0=CDe051@D01DE5@06a/K038b<P1WIfL0:RXZ04e=C@0h>3P07alO03@d=01JFUX0?3`l0451
@@0T92@08B4Q05]KF`2<S8`0;Bd]02`/;019BDT0;bl_03@d=01^KVh0820P03Hf=P0/;2`0=cLg065Q
H@1gMgL0=cLg02@T900^;Rh0@d=308N7Q`2@T900:2PX038b<P15ADD0HF5Q04M7A`2/[:`0EUIF03<c
<`1QHF40FUYJ055AD@2QXJ40Ogmo01DE5@11@D40F5QH04m?C`2=SHd0ADE5020P8012@T80Kfm_06a/
K01=CDd0Cdm?02LW9`19BDT0X:2P04U9B@0];Bd0GEeM03De=@0];Bd0D51@06YZJP12@T80EEEE03@d
=01DE5@0MgMg08B4Q00`<300;Rh^05aLG00g=cL0IfMW02h^;P0P8200@41003`l?00c<c<0PH610:2P
X00Z:RX0;2`/05=CD`1QHF40T92@079bLP0Y:BT0<S8b06MWI`1JFUX0A4A405aLG00M7Ad0DE5A06][
J`0f=SH205MGE`1901TI6@0K6a/0Fe]K06m_K`19BDT0Lg=c01dM7@0U9BD0HF5Q08j>SP1;Bd/0HV9R
059BDP0c<c<0EEEE06IVIP0`<300CTi>05IFEP0S8b<0?clo08V9R@1;Bd/0@D510492@P1>CTh0MGEe
06ATI00R8R809BDU0492@P1LG5`0KFe]0492@P0J6QX0=3@d04M7A`1ADE40Vi^K06e]K@0K6a/0=3@d
059BDP1HF5P0Zj^[0410@00b<S80EUIF04U9B@1>CTh0KFe]02PX:016ATH0Q8B404I6AP2ATI409BDU
02XZ:P1CDe<0Cdm?03`l?01fMWH07AdM034a<@1JFUX0AdM705ADE01CDe<09RHV04A4A01RHV80@T92
075aL@0203<c<`0k06ATI01jNWX0<C4a0451@@1OGel0ATI608B4Q01fMWH0@41004];B`1MGEd0?Cdm
07]kN`2SXj<0?clo02`/;01;Bd/0@T9208N7Q`2NWYh0FUYJ02DU9@0];Bd0>3Ph065QH@2GUiL0?Shn
02@T901BDU80Jf][04I6AP2ATI40NGUi02TY:@0l?3`0R8R804E5A@2][Jd0Ng]k02PX:00Y:BT0G5aL
07QhN01_Kfl0R8R802@T900g=cL0N7Qh08B4Q00`<300?clo05YJFP0R8R808b<S05UIF@0g=cL0?clo
02/[:`0U9BD07?ooool0CP1:BTX0EUIF04I6AP0j>SX0Cdm?05YJFP0k>c/0;bl_06a/K00T92@0@410
03Xj>P1DE5@0IFEU05IFEP1HF5P0Lg=c055AD@19BDT0Jf][028R8P1HF5P0<C4a03dm?@1ADE407AdM
04M7A`0m?Cd0GUiN06EUI@1LG5`0>CTi07=cL`1bLW80BDU906i^KP1kNg/0GUiN06a/K00c<c<09bLW
03`l?00n?Sh0CDe=03Xj>P1GEeL0;bl_030`<00j>SX0CTi>028R8P0d=3@0CDe=038b<P0k>c/0:BTY
03dm?@1?Cdl0C4a<02TY:@0];Bd0D51@05EEE@0e=CD0AdM706YZJP1MGEd0?Shn055AD@1GEeL0G5aL
05MGE`1VIVH0DE5A061PH01dM7@0;bl_01dM7@80CDe=0<80CTi>0451@@0n?Sh0A4A403Hf=P19BDT0
DU9B03Hf=P0];Bd0;2`/055AD@12@T80ADE504i>CP0Y:BT0=cLg02DU9@1ADE40ADE502HV9P10@400
CTi>03dm?@1?Cdl0Lg=c05UIF@1TI6@0MWIf08j>SP1HF5P0JVYZ06=SH`18B4P0@T92071`L00m?Cd0
FEUI065QH@1mOGd0GemO04m?C`0T92@0GemO02XZ:P1=CDd0>SXj06=SH`0o?cl0E5AD05UIF@18B4P0
@T92055AD@1QHF40De=C07YjNP1eMGD0JFUY05QHF01LG5`0B4Q805YJFP29RHT0CTi>04a<C00g=cL0
@41004A4A03>c/h0Ph>30861P@2;Rh/0BTY:09>CT`1GEeL0Hf=S06e]K@2FUYH0EEEE075aL@1:BTX0
H61P06UYJ@18B4P0EUIF0410@01LG5`0De=C05EEE@1YJFT0KVi^06a/K012@T80BDU905UIF@1SHf<0
NGUi06=SH`1UIFD0D51@05mOG`0i>CT0E5AD059BDP1LG5`092@T05YJFP1SHf<0<30`04Q8B00`<300
DE5A06][J`1<C4`0TI6A07IfMP18B4P0EEEE069RHP1IFET0?3`l05]KF`0_;bl0P82004=3@`1SHf<0
@D5108J6QP1ADE40MgMg06i^KP0c<c<0E5AD05MGE`0l?3`0EUIF059BDP1gMgL0HV9R075aL@1ADE40
Cdm?0492@P1?Cdl0EUIF04=3@`1EEED0@T92075aL@1UIFD0?clo05mOG`0V9RH0De=C03Ph>01`L700
De=C055AD@15ADD0KFe]04m?C`0l?3`0EUIF04a<C01@D500ADE504Q8B01CDe<0EEEE04a<C00o?cl0
CDe=06EUI@1fMWH0GEeM0;Rh^01mOGd0KVi^06ATI01PH600Hf=S05mOG`1lO7`0WinO05mOG`1UIFD0
HF5Q09fMW@1jNWX0Hf=S065QH@0o?cl0@d=30451@@80@41000h0AdM704I6AP0l?3`0?Cdm05YJFP1R
HV80;bl_04m?C`2g]kL0FUYJ06UYJ@1LG5`0H61P07EeMA7ooooo000?ooooo`0d07alO02b/[80TI6A
04Q8B020P800U9BD0<_;b`0n?Sh0BDU904e=C@1JFUX0S8b<08R8R00d=3@0C4a<05MGE`1MGEd0O7al
04a<C00X:2P0?3`l059BDP1<C4`0JVYZ05aLG00_;bl0KFe]09:BTP1GEeL0IfMW06UYJ@0^;Rh0;2`/
04m?C`0j>SX0FEUI02d];@0b<S80>c/k06QXJ01IFET0;Bd]0410@00a<C40D51@04a<C00P8200=CDe
04];B`1:BTX0H61P0:j^[P80?Cdm03`0C4a<05YJFP24Q8@0RXZ:01PH600k>c/0GEeM05QHF01aLG40
;Bd]010@401=CDd0QXJ607]kN`1ZJVX0W9bL01hN7P0C4a<0@d=303De=@1KFe/0FEUI014A4@0^;Rh0
>SXj05]KF`0X:2P0EeMG04E5A@0T92@0EUIF065QH@0_;bl0MGEe04I6AP0N7Qh0>CTi04A4A00W9bL0
EEEE038b<P0L71`0GemO08b<S00_;bl0>SXj04U9B@0^;Rh0Ogmo08^;R`0G5aL0>c/k04A4A01LG5`0
M7Ad0;bl_016ATH092@T06EUI@1ZJVX2069RHP0;02/[:`0I6AT0?Cdm06IVIP1SHf<0VIVI02PX:00]
;Bd0CTi>05mOG`1BDU800P1dM7@0X@0W9bL0EUIF06a/K00k>c/0MWIf01XJ6P0^;Rh0C4a<075aL@15
ADD0GUiN03Hf=P11@D40GEeM08R8R01BDU80IVIV07MgM`16ATH0EUIF07MgM`0/;2`0E5AD0492@P1=
CDd0EUIF08J6QP0Y:BT06a/K05=CD`1NGUh0I6AT0:6QX@0b<S806ATI0492@P1FEUH0>CTi07alO02G
UiL0:BTY05MGE`1IFET0B4Q808n?S`2JVYX09BDU0492@P1<C4`0GEeM08>3P`0V9RH08B4Q0492@P1Z
JVX0I6AT079bLP1kNg/071`L03lo?`1/K6`0>c/k07AdM019BDT08B4Q03lo?`1hN7P0@D5105YJFP0_
;bl0<S8b07=cL`1gMgL0?3`l059BDP0K6a/0<c<c09JFUP1FEUH0De=C02XZ:P1FEUH0N7Qh06MWI`0a
<C40EUIF04=3@`0k>c/0^[Zj038b<P0n?Sh0FEUI03dm?@22PX80];Bd03/k>`0];Bd0HF5Q06MWI`2o
_kl0:BTY02<S8`1KFe/0SXj>05MGE`1]KFd0PH6104m?C`1dM7@0J6QX04=3@`1kNg/0M7Ad02HV9P0b
<S80W9bL06a/K01JFUX0C4a<03Ti>@0_;bl0OWin08>3P`0o?cl0DE5A05IFEP0f=SH0Lg=c07inOP1>
CTh0Hf=S0492@P0`<300=3@d07QhN01ADE40Cdm?02TY:@0/;2`0@d=307QhN018B4P0=cLg059BDP0Z
:RX0<S8b069RHP0k>c/0=CDe03@d=01<C4`0L71`09:BTP1cLg<0;Rh^02TY:@15ADD0AdM709^KV`25
QHD08B4Q01cooooo00X0EeMG06YZJP1NGUh0@d=304];B`1EEED0@D5104U9B@1gMgL0>3Ph0P0Z:RX0
J`1>CTh0KVi^05=CD`11@D40FUYJ04m?C`1>CTh0GUiN04m?C`1>CTh0B4Q804I6AP1BDU80;bl_04m?
C`0Y:BT0@D5105]KF`1DE5@0CTi>065QH@1YJFT0KVi^06e]K@1^KVh0UYJF06IVIP0l?3`0?Cdm04e=
C@1GEeL0F5QH05]KF`1UIFD0@D5103Ph>01KFe/0Jf][02`/;01MGEd0GemO04e=C@1;Bd/0;2`/05YJ
FP18B4P0AdM703lo?`0c<c<0Fe]K059BDP0g=cL0CDe=05YJFP24Q8@0@d=306UYJ@0d=3@0=CDe07Ee
M@12@T80?3`l02d];@1NGUh0=cLg02/[:`1SHf<0;bl_030`<01?Cdl0B4Q803dm?@14A4@0EEEE03Lg
=`19BDT0=SHf02l_;`0];Bd0Cdm?04i>CP13@d<0@T9204a<C00M7Ad0;bl_05eMG@0Q8B40CDe=04E5
A@1:BTX0DU9B04M7A`1@D500CTi>04Y:BP1<C4`0>c/k04a<C01`L700ADE503<c<`1CDe<0Fe]K07Mg
M`1DE5@0?Shn0080BTY:0980=CDe05YJFP0U9BD0De=C04i>CP2MWId0BTY:09NGU`1WIfL0G5aL04e=
C@2@T900Zj^[051@D029RHT0VYZJ0:BTY02l_;`0MGEe06ATI01bLW80TY:B055AD@1QHF40<C4a05eM
G@1IFET0N7Qh08Z:RP25QHD0QhN705=CD`1=CDd0A4A405MGE`1VIVH0NGUi05eMG@2EUID051@D079b
LP2DU9@0De=C05aLG01ZJVX0IfMW06EUI@12@T80FUYJ03hn?P1EEED0:BTY04E5A@19BDT0ADE5051@
D01FEUH0EEEE0410@015ADD0:b/[04Q8B01CDe<0LG5a03/k>`1UIFD0GEeM03Ti>@1DE5@0D51@05EE
E@1NGUh0<30`09:BTP20P800DU9B05UIF@1EEED0Jf][04Q8B01=CDd0>c/k06MWI`0n?Sh0De=C038b
<P1aLG40=CDe075aL@1SHf<05ADE05UIF@1JFUX0<30`05=CD`0m?Cd0IFEU05EEE@1HF5P0D51@04I6
AP0i>CT0HF5Q05mOG`14A4@0MGEe04Y:BP1BDU80CTi>03De=@1nOWh0=CDe05UIF@0k>c/0?clo0492
@P18B4P0?Cdm079bLP1YJFT0F5QH07=cL`1;Bd/0I6AT03@d=01CDe<0?Cdm038b<P1YJFT0MGEe03Ph
>00j>SX0D51@04E5A@1UIFD0PX:2079bLP14A4@0@d=305=CD`1GEeL0@410059BDP0K6a/0De=C04Q8
B080H61P01D0De=C0820P00b<S80BDU903`l?00b<S80@41005YJFP0i>CT0C4a<04i>CP1iNGT0Ogmo
04A4A01DE5@0][Jf05=CD`1UIFD0F5QH08^;R`1XJ6P04Oooool000oooooo0?l0MGEe04m?C`1oOgl0
G5aL06UYJ@1<C4`0GUiN06ATI01RHV80VYZJ03Ti>@0`<300N7Qh06=SH`1ZJVX0@D5104=3@`1OGel0
L71`030`<019BDT0A4A403Xj>P19BDT0GemO02TY:@1ADE40:RXZ05eMG@2MWId0K6a/02LW9`0h>3P0
C4a<04Y:BP2QXJ40QhN701lO7`0a<C40<30`03`l?01?Cdl0VIVI03<c<`1GEeL0CDe=03dm?@1]KFd0
De=C01DE5@0d=3@0E5AD06][J`1^KVh0;bl_02DU9@16ATH0Kfm_04U9B@1=CDd0=3@d02PX:01JFUX0
KFe]02HV9P1NGUh0A4A402XZ:P15ADD0LG5a06ATI00T92@0AdM703Ti>@1XJ6P0MgMg01lO7`0S8b<0
B4Q80410@019BDT0De=C04A4A00^;Rh0>c/k04I6AP0o?cl0Shn?06UYJ@0R8R80?clo04Q8B01BDU80
YjNW04M7A`0L71`0CDe=04];B`0c<c<0OGem09fMW@0[:b/0<c<c05iNGP0l?3`0LG5a051@D00K6a/0
>c/k0451@@1]KFd0EeMG04U9B@0M7Ad0<c<c07EeM@1KFe/0;Bd]04Q8B01CDe<0=CDe09^KV`1:BTX0
?Cdm05ADE00[:b/08R8R051@D02;Rh/0?Shn03De=@0^;Rh0JVYZ092@T00l?3`07alO02l_;`0n?Sh0
<c<c092@T01QHF409bLW03<c<`16ATH0AdM70861P@2TY:@071`L04A4A01BDU80=SHf08N7Q`1XJ6P0
8R8R03dm?@2FUYH0N7Qh05]KF`2a/K40De=C05EEE@21PH40R8R80492@P1lO7`0Cdm?030`<01EEED0
UYJF05aLG01kNg/0<C4a03/k>`1WIfL0Rh^;05aLG01EEED0N7Qh03Xj>P1GEeL0IFEU038b<P1=CDd0
?Shn03Hf=P1EEED0RXZ:02l_;`10@400@d=30451@@2RXZ80Ti>C02HV9P14A4@0B4Q803@d=02BTY80
@41003<c<`1IFET0@T9204Q8B01lO7`07alO01@D501FEUH0C4a<07YjNP0O7al0>CTi05MGE`1VIVH0
Bd];079bLP14A4@08b<S09BDU01@D500Ph>305mOG`0V9RH0?Cdm08N7Q`1_Kfl0ATI60492@P0k>c/0
LG5a05aLG00d=3@0J6QX03/k>`13@d<0KVi^06e]K@0g=cL0G5aL04I6AP1@D500MgMg07inOP0i>CT0
?3`l05MGE`0_;bl0G5aL05mOG`0O7al0:BTY04=3@`1DE5@0GEeM07IfMP1hN7P002<07AdM03Ti>@1N
GUh0CTi>09^KV`11@D40;2`/05ADE01:BTX0Fe]K08n?S`0Z:RX0?clo06YZJP1WIfL0FUYJ05EEE@2;
Rh/0=cLg028R8P1CDe<0A4A405IFEP1NGUh0:b/[02<S8`1<C4`0MWIf05aLG01:BTX0BDU9020P8014
A4@0Rh^;04E5A@0Looooo`0X055AD@1OGel0Bd];04Y:BP1CDe<0E5AD03Hf=P0d=3@0O7al024Q8@11
@D40ATI6065QH@2BTY80KVi^04U9B@2ATI40LG5a04U9B@1YJFT08R8R05iNGP0j>SX0ATI605]KF`14
A4@0@T9204Y:BP1@D500K6a/05EEE@0k>c/0De=C069RHP0l?3`0C4a<05aLG01KFe/0G5aL02l_;`80
=3@d00@0<S8b04M7A`16ATH0C4a<0P0f=SH08P13@d<0C4a<03<c<`0a<C40@410051@D00j>SX0=cLg
051@D01=CDd0C4a<059BDP1?Cdl0De=C05EEE@1<C4`0CTi>05QHF01kNg/0KVi^07]kN`14A4@0ADE5
06][J`1JFUX0DU9B0451@@1/K6`0EEEE0451@@1_Kfl0D51@04A4A01DE5@20492@P0m05EEE@1;Bd/0
ADE504M7A`1>CTh0C4a<030`<01>CTh0Cdm?04Q8B011@D40DU9B034a<@0o?cl0FEUI03lo?`1HF5P0
E5AD061PH01QHF40H61P05eMG@1NGUh0Fe]K06YZJP1BDU80A4A4065QH@13@d<0<c<c061PH01?Cdl0
@d=304U9B@1:BTX0DE5A04U9B@0P8200?clo04];B`1BDU80:b/[04];B`11@D40X:2P06ATI011@D40
>CTi04m?C`1OGel0=CDe05eMG@1DE5@0EEEE061PH019BDT0>c/k07]kN`1gMgL0ADE505MGE`0205UI
F@1K02l_;`1oOgl0CTi>06EUI@1[Jf/0ATI607moO`1?Cdl0MWIf08^;R`1hN7P0A4A4059BDP0M7Ad0
L71`0861P@1IFET0[jn_05]KF`1JFUX0OGem07=cL`21PH40F5QH07=cL`0o?cl0GUiN05QHF00k>c/0
L71`05iNGP19BDT0@41005=CD`0W9bL0FEUI061PH01iNGT0?Cdm06EUI@1IFET0>SXj03Ph>011@D40
C4a<06IVIP14A4@0PX:207alO01SHf<0Rh^;04Q8B01ADE40ATI6061PH00S8b<0EeMG04M7A`1oOgl0
<C4a06YZJP0h>3P0SHf=07]kN`0B4Q80A4A4055AD@1=CDd0UiNG06e]K@2;Rh/0NGUi06UYJ@1IFET0
E5AD04Y:BP1MGEd0Bd];03Hf=P0l?3`0;Rh^05]KF`1=CDd0=3@d06ATI00_;bl0GemO02/[:`1SHf<0
De=C06i^KP02055AD@0703/k>`1ADE40I6AT05EEE@15ADD0FUYJ06QXJ00204E5A@0I03lo?`0m?Cd0
<30`05MGE`1dM7@0<c<c03Ti>@1KFe/0;bl_04A4A019BDT0MGEe07QhN01BDU80MGEe02h^;P1lO7`0
@D5107emO@1EEED0NGUi09nOW`0o?cl0CDe=03Hf=P0204A4A00>04a<C00S8b<0?3`l03Lg=`28R8P0
Ng]k03Xj>P1FEUH0XJ6Q05EEE@1LG5`0C4a<05=CD`1QHF4Aooooo`003oooool09@1]KFd0DE5A05QH
F01KFe/0Ph>304m?C`1UIFD0KFe]092@T03=cLd0@D510492@P18B4P0Bd];08B4Q00U9BD0?Shn07Yj
NP21PH40BDU907IfMP1WIfL0820P03`l?01dM7@0GemO0:ZZZP0Q8B406ATI04=3@`1TI6@0F5QH07mo
O`1[Jf/06a/K03Xj>P1jNWX00P1JFUX0e01ADE40820P01lO7`1GEeL0GUiN065QH@0f=SH0:BTY06YZ
JP2<S8`09bLW04A4A016ATH08R8R061PH01=CDd06a/K03Ph>01;Bd/0;2`/06UYJ@1_Kfl08b<S0492
@P1hN7P0<S8b079bLP20P80061PH0492@P1ADE40L71`05IFEP1oOgl07alO04=3@`1RHV80EUIF069R
HP2RXZ80:2PX02HV9P0g=cL0@41005IFEP22PX8051@D02/[:`0c<c<0IFEU04];B`1MGEd0@D5102PX
:014A4@0Hf=S02l_;`1ADE40A4A402LW9`19BDT0HV9R03hn?P1KFe/0<30`051@D01OGel0NGUi02XZ
:P0k>c/0Cdm?02/[:`1gMgL0CDe=02@T900l?3`0AdM704Y:BP0o?cl0TI6A071`L00/;2`0D51@05MG
E`1NGUh0V9RH03Ph>00G5aL0=3@d05iNGP1_Kfl0KVi^01XJ6P0R8R80CDe=06e]K@0_;bl0Jf][06a/
K00a<C40>3Ph05IFEP0m?Cd0MGEe02l_;`0U9BD0>CTi08n?S`1WIfL0<S8b03`l?00N7Qh0EEEE08>3
P`0/;2`0=3@d0492@P0f=SH0>c/k06a/K01HF5P0;bl_05EEE@0g=cL0JFUY0:FUY@1XJ6P08B4Q03/k
>`1;Bd/0GEeM0<71`@1ADE408B4Q03Hf=P1HF5P0Bd];0861P@2g]kL0?3`l04U9B@1<C4`0EeMG06=S
H`1DE5@071`L05IFEP1TI6@0B4Q806e]K@13@d<0>c/k05MGE`2@T900FEUI06][J`17AdL0:BTY04Y:
BP1GEeL0I6AT07EeM@0];Bd0?clo079bLP11@D40>SXj08:2PP0c<c<0M7Ad03Xj>P0T92@0C4a<03Hf
=P0i>CT0Shn?079bLP0R8R80@D5103Lg=`1=CDd0RXZ:04=3@`12@T80A4A404m?C`2ATI40H61P02d]
;@1OGel0EUIF06=SH`2f][H0Fe]K01lO7`1HF5P0NWYj06MWI`3:b/X0@41002/[:`1MGEd0MGEe03hn
?P1^KVh0Z:RX03Hf=P0l?3`0TY:B04a<C020P800V9RH0P15ADD09@1]KFd0Ti>C04U9B@1YJFT0;bl_
03<c<`2;Rh/0XJ6Q03Ti>@1XJ6P0NGUi02d];@1UIFD0TY:B02TY:@19BDT0=CDe030`<010@400SHf=
05iNGP0S8b<0?Shn02d];@1JFUX0GemO03dm?@0U9BD0=cLg04e=C@0e=CD0LW9b06QXJ00W9bL0<C4a
059BDP12@T807?ooool0G01GEeL0HV9R055AD@0h>3P0?clo05EEE@0c<c<0;2`/05]KF`0Y:BT0GemO
071`L01DE5@0N7Qh06EUI@1?Cdl0NGUi04m?C`1;Bd/0Hf=S02@T901=CDd0=SHf0451@@1IFET06a/K
04=3@`0Z:RX0EeMG05iNGP1MGEd0?clo07moO`1cLg<0HV9R07=cL`1iNGT0IVIV06i^KP0];Bd09RHV
02XZ:P0j>SX0Fe]K05=CD`1mOGd0C4a<051@D019BDT0IVIV02h^;P1@D500IFEU0492@P15ADD0:2PX
04i>CP1;Bd/0@41003Ph>00[:b/0De=C04];B`0/;2`0@d=304e=C@1CDe<0=3@d055AD@1<C4`0BTY:
07IfMP13@d<0G5aL04E5A@25QHD0?3`l02<S8`1QHF40ADE503`l?01@D500A4A4055AD@0k>c/0DU9B
0410@01<C4`0<30`02XZ:P0[:b/0DU9B0P16ATH203hn?P0701TI6@0a<C40Bd];02<S8`0n?Sh0@d=3
0410@00204U9B@0G04Q8B01>CTh0EeMG06UYJ@1LG5`0De=C06EUI@1JFUX0G5aL07IfMP1/K6`0FUYJ
06ATI01iNGT0Lg=c04M7A`0g=cL0EEEE02<S8`1ADE40?Shn07]kN`1@D5000P1nOWh0A@1SHf<0GemO
071`L02TY:@0HF5Q06EUI@1cLg<0Ng]k06YZJP1nOWh0BDU904e=C@1OGel0E5AD06=SH`0d=3@0BDU9
03hn?P2OWil0QHF507MgM`1VIVH0@41004i>CP17AdL0?3`l04];B`1nOWh0H61P08N7Q`0Q8B40PH61
08F5Q@0i>CT0C4a<04Q8B01IFET0IfMW0410@01BDU80H61P06UYJ@0h>3P0MWIf075aL@1UIFD0Ph>3
04U9B@1hN7P0>3Ph051@D00h>3P0LW9b04m?C`23Ph<0Jf][08N7Q`20P800?3`l04Q8B00i>CT0IVIV
08f=S@1<C4`0SXj>07]kN`18B4P0AdM7051@D002055AD@1005ADE014A4@0FUYJ03lo?`1>CTh0D51@
07AdM012@T80Cdm?05aLG00o?cl0Bd];05=CD`12@T80Bd];05ADE01YJFT0D51@05eMG@16ATH0ADE5
03hn?P19BDT0IVIV065QH@1@D500AdM708:2PP1lO7`0BDU907MgM`0e=CD0LG5a04a<C01`L700FEUI
05ADE01EEED0R8R8096AT@1mOGd0KFe]075aL@2ATI40>c/k061PH01TI6@0CTi>059BDP1bLW80A4A4
0410@017AdL0<c<c04i>CP1VIVH0HF5Q06EUI@12@T80ATI605EEE@1;Bd/0LG5a01lO7`80EEEE01L0
Y:BT04i>CP1@D500Lg=c04m?C`1eMGD0ADE503Ph>01:BTX0N7Qh04=3@`1>CTh092@T04I6AP1ADE40
D51@04Y:BP2<S8`0DU9B04a<C018B4P0H61P07=cL`0Aooooo`003oooool0o`2NWYh0Xj>S06ATI01<
C4`0HV9R07AdM023Ph<0?3`l061PH02^[Zh0PX:204Y:BP1]KFd0A4A405aLG01SHf<0;2`/06EUI@1D
E5@0>3Ph04m?C`1ADE40=CDe051@D00m?Cd0@T9209ZJVP1RHV808B4Q075aL@0f=SH09RHV06][J`1h
N7P09bLW04i>CP0h>3P0KVi^0:6QX@1]KFd0;Rh^024Q8@0l?3`0CTi>0:VYZ@0e=CD05QHF02h^;P23
Ph<0Lg=c08N7Q`2IVIT07alO02h^;P1NGUh0>SXj08j>SP10@400:b/[03Ti>@1RHV80A4A405MGE`0I
6AT0>SXj04];B`1]KFd0@D5106a/K02:RXX09bLW02h^;P1SHf<0>CTi03`l?00g=cL07QhN03Xj>P1E
EED0BDU902HV9P1@D500=SHf04i>CP24Q8@0@D51024Q8@1FEUH0>3Ph04m?C`1nOWh0EEEE02HV9P15
ADD0GemO05MGE`2DU9@0JVYZ01DE5@1<C4`0B4Q805EEE@2CTi<0?clo02PX:00k>c/0AdM705UIF@1W
IfL0M7Ad01lO7`0T92@0MWIf0451@@1UIFD0HV9R01/K6`0[:b/0>SXj07MgM`1MGEd0Bd];02<S8`13
@d<0FEUI079bLP15ADD0HV9R0410@00f=SH0Fe]K04Y:BP0h>3P0MGEe03<c<`11@D40IFEU06UYJ@0L
71`0=SHf04Q8B01MGEd0QXJ6059BDP0S8b<0=CDe03dm?@1XJ6P0P82007=cL`0W9bL0;bl_05MGE`13
@d<0N7Qh09jNWP0J6QX0<C4a03lo?`1?Cdl0JFUY09NGU`0/;2`07QhN0451@@1TI6@0@D5107alO01=
CDd0:b/[05]KF`1nOWh0=SHf05QHF00d=3@0820P03dm?@1NGUh0ATI605eMG@0D51@0=SHf069RHP1N
GUh0:2PX0492@P1TI6@07alO07IfMP1bLW80:BTY06][J`11@D40?clo09jNWP2EUID09BDU0492@P1@
D500PX:20;Zj^P0k>c/0=SHf07EeM@1MGEd0A4A40:n_[`0d=3@0EEEE04U9B@1nOWh0Shn?02`/;00V
9RH0IVIV08j>SP22PX80MGEe02LW9`14A4@0M7Ad05ADE02FUYH0HF5Q024Q8@1CDe<0Ti>C05IFEP1T
I6@08B4Q03De=@1bLW80MgMg0451@@1lO7`0HV9R03/k>`2HV9P0P82004=3@`1TI6@0D51@03`l?01M
GEd0Vi^K05iNGP15ADD0=cLg03@d=01:BTX0T92@04e=C@0[:b/0BDU903Ti>@008`0R8R80Q8B405aL
G00f=SH0BTY:05IFEP1>CTh0LW9b09ZJVP0h>3P0?Shn06MWI`1aLG40VYZJ04A4A00T92@0=CDe06=S
H`2CTi<0IFEU079bLP11@D40DE5A06EUI@1SHf<0BTY:06UYJ@1RHV8071`L02`/;01eMGD0@D5105eM
G@11@D408B4Q01cooooo02h0HV9R07alO01VIVH0AdM704U9B@1UIFD0HF5Q05=CD`1_Kfl0?Cdm05eM
G@0n?Sh0CDe=07IfMP1WIfL0Kfm_06e]K@1CDe<0D51@07QhN01?Cdl0IVIV05=CD`1NGUh0HF5Q030`
<01EEED0<C4a05IFEP1`L700Hf=S05QHF01_Kfl0F5QH0410@01/K6`0QhN707moO`1^KVh0@d=302/[
:`0X:2P0A4A4059BDP1?Cdl0PX:20P12@T80:@19BDT0C4a<01`L7010@400BTY:0410@018B4P0BTY:
05aLG017AdL0@d=304a<C013@d<0HF5Q05]KF`0i>CT0CDe=059BDP27QhL0@41006m_K`17AdL0A4A4
07moO`13@d<0Jf][0492@P1MGEd0?Shn02/[:`1`L700@d=303`l?01VIVH0@T920410@00f=SH0BTY:
0492@P14A4@0>c/k0080;bl_0100BTY:05UIF@1EEED0B4Q805YJFP0];Bd0<C4a05mOG`0m?Cd0GemO
04i>CP0n?Sh0IfMW05=CD`1EEED0DE5A0P1EEED0]@0m?Cd0>CTi05=CD`17AdL0>CTi05EEE@1KFe/0
FUYJ051@D011@D40Cdm?03dm?@0l?3`0EEEE03Ti>@1MGEd0=cLg08V9R@1UIFD0/[:b07alO01cLg<0
G5aL07AdM02ATI40GUiN0;2`/02/[:`0M7Ad069RHP1PH600GUiN05EEE@1GEeL0<c<c04I6AP0e=CD0
EEEE04E5A@1jNWX0OGem07alO023Ph<0E5AD04m?C`1LG5`0H61P075aL@1WIfL0CDe=08R8R00[:b/0
Fe]K07alO01<C4`0UYJF05QHF01YJFT0I6AT051@D01fMWH0LG5a071`L00d=3@0Ogmo05aLG00m?Cd0
De=C051@D01UIFD0De=C065QH@0V9RH0D51@04Q8B01eMGD0Cdm?04M7A`15ADD0?3`l05=CD`11@D40
?Shn05YJFP0X:2P0[jn_08j>SP1@D500G5aL05iNGP1dM7@0@D5106=SH`0/;2`0SHf=0451@@1QHF40
E5AD092@T01JFUX0OWin07]kN`0H61P0FUYJ071`L00j>SX0HV9R04Q8B02:RXX0G5aL079bLP1NGUh0
FEUI03Xj>P1FEUH0C4a<05MGE`1BDU80@41004I6AP1DE5@0=CDe07YjNP0X:2P0HV9R030`<01VIVH0
EEEE075aL@0l?3`0ATI603/k>`0g=cL0C4a<03@d=00i>CT0;bl_04A4A00e=CD0=3@d03Ph>014A4@0
:2PX034a<@1@D500=SHf04E5A@14A4@0?Cdm0451@@1:BTX0P82007QhN01iNGT0ZZZZ0451@@2>SXh0
Jf][0;2`/01cLg<0Xj>S0:RXZ011@D40A4A403lo?`1<C4`0BDU90492@P0V9RH0CDe=03hn?P1BDU80
Bd];03<c<`13@d<0Kfm_04M7A`1<C4`0Bd];07alO01HF5P04Oooool000oooooo0?l0GUiN08N7Q`1d
M7@0B4Q8069RHP1jNWX0QhN703Hf=P0i>CT0FUYJ07MgM`1^KVh0QXJ603@d=012@T80Lg=c07UiN@2_
[jl0NGUi01PH600c<c<0Bd];04a<C02QXJ40JVYZ04=3@`0l?3`0Kfm_071`L03Bd]80Cdm?03De=@17
AdL0CTi>05IFEP2ATI40:2PX014A4@1CDe<0IVIV03`l?01GEeL0F5QH01/K6`1FEUH0PH6103Lg=`1O
Gel0:BTY02HV9P0n?Sh0J6QX03dm?@16ATH08R8R02LW9`1VIVH0L71`02LW9`0m?Cd0?3`l0492@P1T
I6@0CTi>01/K6`0l?3`0EeMG03Ph>01GEeL0YZJV051@D00G5aL0De=C05mOG`2@T900IfMW01XJ6P0S
8b<0D51@06MWI`1<C4`0WinO0451@@0e=CD0Fe]K07MgM`1OGel0bl_;034a<@0R8R80=SHf04Y:BP1a
LG40S8b<01lO7`0e=CD0GUiN07AdM00d=3@0GEeM069RHP0S8b<0Fe]K06=SH`0j>SX0JFUY04U9B@0^
;Rh0H61P06QXJ016ATH0>SXj03Ph>00l?3`0T92@08B4Q00j>SX06a/K03lo?`0e=CD0IfMW0:JVYP0W
9bL0>c/k05IFEP1IFET0EUIF0:NWY`26QXH08B4Q04m?C`15ADD0G5aL0;Zj^P0d=3@06a/K05eMG@2E
UID0De=C06QXJ00l?3`0:b/[05aLG01GEeL0=SHf05]KF`1cLg<03Ph>01`L701SHf<0820P04];B`0g
=cL0820P02l_;`23Ph<0BTY:02HV9P1MGEd0;2`/04Q8B02VYZH0JVYZ02HV9P1?Cdl0<C4a04=3@`1Q
HF40R8R802TY:@1FEUH0@d=307IfMP2[Zj/0PH6102@T9010@400FUYJ055AD@2^[Zh0;2`/01/K6`0e
=CD0De=C04a<C01TI6@0S8b<01dM7@0a<C40PH6105YJFP3=cLd0?Shn02l_;`12@T80TY:B05EEE@1Q
HF40>SXj06MWI`23Ph<0Kfm_051@D01ZJVX06ATI038b<P1aLG40F5QH05]KF`0/;2`0=3@d08V9R@1L
G5`0?clo04m?C`0d=3@0GEeM08J6QP0T92@0@d=30451@@0e=CD0NWYj09BDU00V9RH0<c<c04U9B@1P
H600YJFU02l_;`0O7al0CDe=06MWI`1CDe<0Xj>S0;>c/`0[:b/0JFUY071`L01;Bd/0][Jf06EUI@0Q
8B40<C4a08F5Q@1cLg<0WYjN04];B`0`<300=cLg06IVIP1cLg<0EeMG07YjNP11@D4002<0<S8b05EE
E@1lO7`0LG5a0:6QX@10@400?3`l04];B`1hN7P0HF5Q05YJFP0[:b/0;Bd]05=CD`24Q8@0>CTi04I6
AP1SHf<0>CTi03@d=01=CDd0>CTi03<c<`15ADD0=CDe03dm?@1UIFD0P82002HV9P0U9BD0>SXj04Q8
B01kNg/0L71`01lO7`0Looooo`0I07emO@1VIVH0DE5A04I6AP1OGel0EEEE0492@P1<C4`0T92@055A
D@18B4P0AdM705UIF@2<S8`0G5aL04m?C`1[Jf/0Kfm_05UIF@1QHF40?Shn04];B`11@D40ATI605QH
F00204U9B@3B03Ti>@1=CDd0GemO05EEE@11@D40EeMG05iNGP18B4P0C4a<055AD@1_Kfl0GUiN0492
@P16ATH0A4A403hn?P16ATH0Fe]K05UIF@19BDT0Cdm?055AD@1DE5@0820P03Hf=P1>CTh0Fe]K04Q8
B00T92@0Cdm?04U9B@0l?3`0D51@04Y:BP1>CTh0EEEE04I6AP13@d<0CDe=06i^KP1_Kfl0S8b<04m?
C`17AdL0Ti>C04I6AP1fMWH0@D5106YZJP1;Bd/0GUiN06MWI`0m?Cd0>c/k05aLG013@d<0?Cdm051@
D01GEeL0@41004m?C`0j>SX0>3Ph02XZ:P1EEED0DE5A04Y:BP0d=3@0Cdm?02HV9P0_;bl0BTY:020P
8018B4P0D51@05aLG01SHf<0CDe=05aLG01HF5P0FUYJ06=SH`1PH600@d=3065QH@1JFUX0A4A407mo
O`1_Kfl0KFe]06][J`1;Bd/0E5AD0451@@0i>CT0BTY:03@d=01BDU80@D5106EUI@1>CTh0LG5a06QX
J01QHF40M7Ad08b<S02HV9P0JFUY04I6AP1?Cdl0Hf=S06UYJ@1dM7@0B4Q805MGE`1WIfL0?3`l04e=
C@12@T80HV9R03lo?`2@T900RXZ:07QhN01HF5P0BTY:05]KF`1LG5`0E5AD08J6QP2ATI40D51@05MG
E`0];Bd0I6AT06][J`0k>c/0@410038b<P15ADD0D51@03Ph>01?Cdl0EUIF05MGE`0W9bL0?clo04e=
C@0e=CD0G5aL03hn?P1FEUH0<S8b0451@@0m?Cd0Ogmo05EEE@29RHT0Cdm?07inOP1kNg/0=CDe055A
D@10@400HF5Q07UiN@0g=cL0G5aL05UIF@1OGel0VYZJ065QH@1ADE40FEUI061PH00i>CT0Hf=S05iN
GP1kNg/0BDU90:f][@0i>CT0S8b<096AT@0`<300DU9B06IVIP1TI6@0S8b<05aLG01^KVh0IfMW04i>
CP1:BTX0M7Ad04E5A@1<C4`0Kfm_07=cL`24Q8@0G5aL092@T029RHT0BTY:08n?S`16ATH0LG5a04i>
CP1BDU80?Cdm0P10@4009P1;Bd/0Cdm?04Y:BP1CDe<0BDU906=SH`0c<c<0ADE504=3@`1DE5@0?clo
05mOG`0a<C40Bd];06ATI01NGUh0AdM7061PH01@D500Fe]K04Y:BP1FEUH0Hf=S065QH@2:RXX0=cLg
07]kN`1DE5@0TY:B065QH@1=CDd0IFEU05=CD`1fMWH0EUIF02l_;`0d=3@0G5aL0P15ADD02`0c<c<0
HF5Q06=SH`13@d<0EeMG08n?S`1;Bd/0H61P04M7A`1=CDd0IFEU017ooooo000?ooooo`0705QHF01G
EeL0PH6108R8R01UIFD0EeMG07emO@0207]kN`1a09JFUP0_;bl0CTi>051@D01WIfL0WIfM01lO7`0g
=cL0EEEE06IVIP1CDe<0JFUY03lo?`0W9bL0?Shn04U9B@1@D500FEUI01DE5@0e=CD0OGem0:FUY@0l
?3`0=3@d02h^;P0o?cl0YJFU0:RXZ00[:b/0;Bd]04I6AP0/;2`0GEeM08:2PP0R8R80>3Ph05QHF01C
De<0V9RH05mOG`0F5QH0:RXZ0451@@0l?3`0QXJ601dM7@0_;bl0IFEU065QH@1KFe/0G5aL0410@00M
7Ad0Hf=S07=cL`0k>c/0OGem03Ph>00M7Ad0=CDe06ATI01KFe/0@D510492@P0E5AD0<S8b06MWI`0T
92@0;Rh^04m?C`0O7al08B4Q04=3@`0m?Cd0<S8b02`/;00Y:BT0>c/k09BDU01SHf<061PH03@d=00X
:2P0De=C09:BTP0g=cL07alO03/k>`0c<c<0>3Ph09bLW02k^k/07alO02d];@1ADE40DU9B09bLW02?
Shl08B4Q038b<P19BDT0Cdm?06m_K`0`<3006ATI03/k>`1XJ6P0PX:204];B`2:RXX0>CTi02d];@1d
M7@00P1BDU808`1ADE40;2`/03Hf=P1@D500I6AT05MGE`1LG5`07AdM03<c<`1ZJVX0Lg=c02l_;`1H
F5P0DU9B03@d=021PH40G5aL03Lg=`1@D500DU9B03De=@20P800]kNg02<S8`0M7Ad0EUIF0451@@2?
Shl0De=C02DU9@15ADD0Lg=c04Q8B02:RXX0Z:RX0080=SHf0840F5QH07UiN@1NGUh0T92@02<S8`0X
:2P0?clo061PH01YJFT0[jn_02XZ:P0X:2P0IfMW0861P@0g=cL0C4a<051@D00f=SH0M7Ad069RHP13
@d<0FUYJ0410@00];Bd0IVIV08B4Q01<C4`0A4A4038b<P15ADD0O7al079bLP0Q8B40GEeM03`l?016
ATH0HF5Q04I6AP1?Cdl0FEUI061PH01mOGd0WIfM01`L700P8200Fe]K05QHF01cLg<08R8R03Ti>@1>
CTh0A4A405eMG@2MWId0Bd];02@T901gMgL0>c/k06m_K`0i>CT0@41004M7A`27QhL0HV9R06MWI`1L
G5`0@41007inOP1IFET0A4A406=SH`0Z:RX0@T9206][J`26QXH0E5AD06m_K`0P8200Bd];08>3P`26
QXH0>SXj030`<01IFET092@T05aLG01eMGD09RHV03`l?01NGUh0>CTi0492@P2IVIT0Vi^K024Q8@16
ATH0?Shn065QH@2SXj<0IFEU02<S8`15ADD0BDU905=CD`22PX80?Cdm02LW9`1<C4`0DU9B03Hf=P1N
GUh0W9bL02/[:`0f=SH0BDU904m?C`1JFUX0IFEU01/K6`0[:b/0Cdm?079bLP17AdL0GemO04I6AP0^
;Rh0KVi^06UYJ@0a<C407?ooool0T@1FEUH0Fe]K05QHF01CDe<0>CTi05mOG`1DE5@0>SXj06a/K00k
>c/0G5aL06QXJ01TI6@0KFe]06ATI01cLg<0LW9b04i>CP18B4P0NGUi02h^;P1GEeL0De=C04i>CP1W
IfL0?Shn06=SH`14A4@0Fe]K05UIF@1SHf<0FUYJ07=cL`1]KFd0JFUY07MgM`1nOWh0Hf=S06MWI`0f
=SH07AdM01hN7P12@T80BTY:03dm?@1QHF40@41005EEE@0k>c/0CTi>01TI6@0i>CT0De=C03<c<`10
@400;Bd]04i>CP1FEUH0DU9B04I6AP0m?Cd0GEeM06a/K01?Cdl0EEEE06MWI`20P800>CTi05IFEP15
ADD0@D510820P01jNWX0Hf=S038b<P1=CDd0De=C038b<P1MGEd0ADE504];B`1[Jf/0?Cdm0410@00b
<S80ADE503Ph>017AdL0?Cdm02LW9`0[:b/0@d=304I6AP1:BTX0Bd];051@D00M7Ad0<30`05aLG00V
9RH0E5AD04U9B@14A4@0Cdm?04=3@`1LG5`0IFEU059BDP1LG5`0D51@05YJFP1KFe/0Bd];051@D01m
OGd0F5QH06ATI01cLg<0JVYZ06UYJ@1CDe<0?clo06a/K011@D40HF5Q03Xj>P1gMgL0LW9b0;^k^`2S
Xj<0N7Qh06MWI`2GUiL0V9RH04U9B@1OGel0FUYJ05mOG`1^KVh0Jf][04];B`0l?3`0GUiN03/k>`1?
Cdl00P19BDT0R`0`<300MgMg07=cL`1^KVh0F5QH04];B`1lO7`0SXj>05UIF@1BDU80GUiN05aLG01H
F5P08R8R07=cL`2=SHd0@41005UIF@14A4@0GemO06ATI012@T80GemO071`L01RHV808B4Q04E5A@1<
C4`0;bl_06EUI@0h>3P0E5AD04a<C01?Cdl09bLW03`l?00];Bd0MWIf0451@@1GEeL0IFEU03<c<`1>
CTh0>3Ph04a<C01IFET0820P07AdM01RHV80<S8b051@D015ADD0CDe=03Ph>015ADD08B4Q05iNGP0n
?Sh0Bd];03Ti>@1kNg/0@D5106IVIP1CDe<06a/K04A4A01@D500;Rh^05]KF`0m?Cd0EEEE04m?C`1E
EED0ATI604m?C`0[:b/0ATI603lo?`10@400ATI602l_;`0l?3`0HV9R03dm?@1IFET08b<S04m?C`0i
>CT0I6AT05ADE014A4@0ADE505MGE`16ATH0=SHf051@D018B4P0HV9R028R8P15ADD0;bl_03Hf=P1?
Cdl0Ogmo04m?C`0o?cl0ADE505IFEP16ATH0@D5104Y:BP19BDT0AdM705aLG01PH600SHf=0:f][@0[
:b/0QhN707MgM`2i^KT0IVIV06YZJP1oOgl0<30`03dm?@0d=3@0ATI602d];@1=CDd0?Cdm0492@P0^
;Rh0A4A405QHF018B4P0BDU906][J`1?Cdl00P19BDT00`1FEUH0HF5Qooooo`0@ooooo`003oooool0
L`20P800QXJ606][J`1GEeL0L71`05YJFP1MGEd0JVYZ0;2`/032`/80GemO03De=@1KFe/0>3Ph07Ui
N@1RHV80<30`059BDP16ATH0JVYZ0<K6aP2DU9@07alO03`l?00j>SX0RXZ:0=3@d015ADD0;bl_03De
=@1jNWX0CTi>09>CT`16ATH0;2`/02h^;P23Ph<0Hf=S08V9R@11@D406ATI01dM7@16ATH0Jf][08>3
P`0J6QX07alO04];B`1jNWX0C4a<06m_K`22PX809bLW04i>CP1^KVh0?3`l059BDP0Z:RX09RHV05mO
G`1PH6008b<S04=3@`1VIVH0?Shn0861P@16ATH0820P02/[:`1CDe<0>c/k0410@01XJ6P0820P02h^
;P1JFUX0M7Ad06MWI`2:RXX0820P028R8P0d=3@0E5AD07AdM01_Kfl051@D02PX:013@d<0GUiN06=S
H`29RHT0;2`/03De=@1<C4`0G5aL05MGE`2b/[80<30`01lO7`0];Bd0G5aL051@D01VIVH0820P01TI
6@1ADE40TY:B05UIF@1@D500FEUI02DU9@1EEED0KVi^028R8P0b<S800P0c<c<02`0j>SX0Ph>309BD
U00[:b/0>SXj034a<@1HF5P0R8R803`l?00S8b<0EUIF0080E5AD0:00O7al01HF5P0M7Ad0@T92069R
HP1@D500VIVI05mOG`0Y:BT0@41005IFEP1WIfL0SHf=03`l?011@D40BDU907emO@19BDT0CDe=04];
B`0f=SH0G5aL0<30`00l?3`0GEeM04];B`0N7Qh0>3Ph08N7Q`1BDU80?clo069RHP0V9RH0L71`0:ZZ
ZP1bLW80=cLg06YZJP1?Cdl0?clo0<G5a@20P800:RXZ04E5A@1KFe/0FEUI09>CT`2@T900=cLg05mO
G`1@D500GemO0:j^[P1PH6007alO04A4A01WIfL0FEUI07inOP0^;Rh07alO05ADE029RHT0EeMG0:FU
Y@1EEED07AdM03lo?`1ADE40PX:205eMG@0I6AT0?clo09bLW01KFe/0BDU905MGE`0a<C40JFUY059B
DP1=CDd0HV9R01dM7@0g=cL0J6QX08n?S`0n?Sh0@D5104I6AP1mOGd0FUYJ02<S8`16ATH0B4Q8038b
<P1TI6@0WIfM030`<01ZJVX0F5QH06ATI023Ph<0;bl_02HV9P1ADE40H61P06MWI`37alL0>SXj020P
801YJFT0XZ:R069RHP1cLg<0ZZZZ03hn?P0j>SX0SXj>069RHP24Q8@0YZJV03hn?P15ADD0GEeM07Yj
NP13@d<0JVYZ02h^;P17AdL0Cdm?05QHF01DE5@0JFUY05UIF@0_;bl0LG5a059BDP1?Cdl0KVi^05eM
G@0h>3P0>CTi06e]K@1[Jf/0<30`04];B`0S8b<0>c/k06QXJ01FEUH0:b/[03Ti>@13@d<0@41004Q8
B01aLG4092@T04E5A@1=CDd0DU9B7?ooool04@1[Jf/0Hf=S05=CD`19BDT0GemO06EUI@1CDe<0D51@
09jNWP1cLg<0BTY:04M7A`1@D500M7Ad06EUI@0j>SX0JFUY0080Cdm?0340HV9R03`l?01ADE40F5QH
05iNGP1QHF40>3Ph05]KF`1BDU80F5QH06UYJ@1<C4`0@T9206UYJ@1JFUX0<S8b05EEE@1WIfL0N7Qh
05YJFP12@T80;Rh^034a<@17AdL0BDU904I6AP1GEeL0?Cdm03Ph>01FEUH0FUYJ01hN7P17AdL0E5AD
0492@P1HF5P0Cdm?05mOG`12@T80@D5106MWI`1PH600De=C04Y:BP1@D500AdM703/k>`1TI6@0B4Q8
0080H61P0=`0BDU905UIF@0m?Cd0EUIF03`l?01GEeL0?3`l02PX:01>CTh0=SHf03Ph>01@D500>3Ph
03/k>`0i>CT0ADE503/k>`0o?cl0?Shn038b<P0j>SX0EUIF04A4A00l?3`0BTY:04a<C00J6QX0<C4a
03Ph>00o?cl0BDU904A4A01dM7@0FEUI05eMG@1HF5P0DE5A05=CD`1DE5@0C4a<0451@@1LG5`0A4A4
01TI6@25QHD0Cdm?06=SH`1bLW80CDe=05EEE@16ATH0BTY:06a/K011@D40EeMG04E5A@2FUYH0O7al
0;Zj^P2NWYh0MGEe06UYJ@2;Rh/0]kNg05UIF@1RHV80O7al06e]K@1NGUh0HV9R06EUI@1?Cdl0H61P
04I6AP1TI6@0<30`059BDP0l?3`0GemO06UYJ@2=SHd0PH6105mOG`11@D40GUiN07QhN028R8P0Ph>3
03lo?`1OGel09BDU05mOG`1/K6`0?Cdm07UiN@1GEeL0AdM705ADE00d=3@0H61P03/k>`1=CDd071`L
05]KF`1ADE406a/K04M7A`0f=SH0E5AD051@D01NGUh0:RXZ05=CD`0_;bl0Shn?05aLG01FEUH0GemO
034a<@1QHF40AdM704E5A@1;Bd/0:RXZ07]kN`1^KVh0>c/k05IFEP1=CDd0KFe]03Ph>01BDU806a/K
07inOP0_;bl0AdM703<c<`1HF5P0?clo06UYJ@1XJ6P06QXJ06=SH`1^KVh0?3`l06EUI@1ADE40GEeM
051@D01JFUX0CTi>051@D00e=CD0Cdm?0492@P1CDe<0NGUi04M7A`1@D500LG5a04I6AP1XJ6P0=3@d
05ADE00`<300@T9203Lg=`1>CTh0=cLg04E5A@16ATH0>c/k0410@00d=3@0C4a<02@T901>CTh0ATI6
03lo?`0l?3`0DU9B034a<@0k>c/0CTi>04U9B@1nOWh0=cLg04I6AP18B4P0De=C07UiN@2GUiL0FEUI
07alO01BDU80R8R80492@P1^KVh0E5AD069RHP1FEUH0;bl_04];B`0e=CD0;bl_03Hf=P10@400>CTi
04a<C00n?Sh0GEeM04I6AP0l?3`0D51@0861P@1=CDd0GemO05=CD`1WIfL0JVYZ4Oooool000oooooo
02T0SHf=0:b/[01nOWh0ADE506=SH`2@T900IfMW03Ph>01;Bd/0^;Rh09:BTP1gMgL0QHF503De=@1L
G5`0SHf=05UIF@1]KFd0>c/k01PH6011@D40O7al04e=C@2;Rh/0>c/k02DU9@1HF5P0Jf][04E5A@1G
EeL08B4Q02`/;012@T80BTY:0410@013@d<0:RXZ02d];@1CDe<0Fe]K02TY:@0203dm?@2[03De=@26
QXH0@d=302LW9`1@D500Cdm?0492@P1WIfL0NWYj02@T900n?Sh0?Cdm06ATI02FUYH09RHV04=3@`19
BDT0Kfm_04I6AP1WIfL0<c<c02/[:`1EEED0GUiN05MGE`1kNg/0YZJV02DU9@0g=cL0@d=305EEE@20
P800GUiN01TI6@0X:2P0;Rh^05]KF`0f=SH0DU9B02XZ:P1DE5@0EEEE02XZ:P10@400Jf][02<S8`0M
7Ad0L71`04e=C@0[:b/0Cdm?02XZ:P0[:b/0O7al065QH@0B4Q80>SXj05ADE017AdL0W9bL03Xj>P0Q
8B40;Bd]059BDP13@d<0GUiN08Z:RP0T92@0<C4a0861P@1[Jf/0PX:206i^KP0H61P0<C4a055AD@2@
T900D51@04I6AP0B4Q80<c<c03De=@15ADD0AdM705mOG`19BDT051@D07IfMP18B4P0E5AD05=CD`0T
92@0<C4a065QH@20P800:2PX03Ph>00j>SX0=SHf0861P@1aLG409BDU03/k>`1LG5`0EeMG04m?C`1/
K6`07alO04Y:BP1?Cdl0@D5108:2PP2>SXh0820P02PX:00j>SX0EUIF06QXJ02UYJD0;2`/030`<01?
Cdl0Lg=c04=3@`2=SHd0EeMG03`l?017AdL0PH61059BDP21PH40<c<c01PH601@D500IVIV05]KF`2:
RXX0;bl_02@T901OGel0K6a/02TY:@1EEED0D51@02TY:@1]KFd0IFEU04e=C@24Q8@0>CTi02XZ:P2?
Shl0^;Rh05QHF01RHV80>CTi06i^KP28R8P0<S8b05=CD`0j>SX0D51@08b<S01hN7P0?clo05UIF@0g
=cL0MWIf09VIV@0E5AD071`L0080C4a<0380E5AD07alO00Y:BT0IVIV07UiN@10@400KVi^04Y:BP0Z
:RX0=cLg08N7Q`1lO7`0V9RH024Q8@13@d<0DU9B05eMG@1=CDd0TY:B05iNGP1@D500QhN706a/K01G
EeL0SXj>04Y:BP0g=cL0EeMG07QhN015ADD0B4Q802PX:00h>3P0GUiN09bLW01jNWX071`L03Ph>00d
=3@0AdM707QhN01[Jf/0;Bd]05MGE`0X:2P0C4a<0:JVYP2j^[X0Cdm?04Y:BP80AdM701H0PX:2069R
HP0e=CD09BDU05YJFP1iNGT0FEUI09JFUP0Z:RX0:2PX05mOG`1ZJVX0LW9b075aL@0o?cl09BDU03/k
>`1VIVH0I6AT0861P@0m?Cd0<c<c7?ooool0901WIfL0GemO05EEE@1<C4`0G5aL05mOG`1>CTh0=cLg
06m_K`0i>CT0CTi>05YJFP1YJFT0UYJF06m_K`1@D500KVi^06][J`1dM7@0Fe]K038b<P1EEED0?Shn
04E5A@1@D500>c/k04E5A@0e=CD0@41007YjNP1EEED0?3`l05=CD`1DE5@0@410059BDP80Cdm?03L0
DE5A03lo?`0[:b/0;Rh^038b<P16ATH0Fe]K05ADE011@D40ADE506a/K01TI6@09RHV03Ph>01IFET0
IFEU04Q8B00R8R80CTi>059BDP1>CTh0AdM702XZ:P1<C4`0EEEE04I6AP18B4P0DE5A06YZJP1OGel0
MWIf04I6AP0l?3`0IVIV06][J`0k>c/06a/K04=3@`1CDe<0Bd];05aLG00n?Sh0ATI605ADE00^;Rh0
=CDe04i>CP16ATH0<30`03lo?`0j>SX0:RXZ02DU9@10@400@T920080A4A404H0BDU9030`<00^;Rh0
F5QH020P8014A4@0ATI603De=@0o?cl0>CTi05ADE01JFUX0Bd];055AD@1PH600N7Qh06e]K@1ADE40
?Cdm08>3P`1CDe<0P82006a/K01@D500GemO04e=C@0j>SX0De=C03Xj>P1BDU80?clo051@D01OGel0
YjNW09FEU@2>SXh0M7Ad08N7Q`33`l<0Ng]k0;^k^`2ZZZX0Jf][06UYJ@2@T900De=C059BDP1/K6`0
9bLW04E5A@0c<c<0AdM7038b<P1WIfL0JFUY06ATI017AdL0DU9B03Hf=P25QHD0BTY:04i>CP1WIfL0
?Cdm05=CD`19BDT0J6QX07EeM@0j>SX0BTY:0P1GEeL0B01YJFT0A4A405IFEP1<C4`0J6QX03Ti>@18
B4P0BTY:01dM7@1eMGD0Bd];04m?C`1<C4`0De=C02l_;`1YJFT0:b/[05iNGP1ADE40G5aL05]KF`0X
:2P0>3Ph02d];@1CDe<0Hf=S01TI6@1WIfL0HV9R03`l?01RHV80ADE503lo?`0[:b/0?Shn01<C4`1F
EUH0<S8b059BDP0];Bd0K6a/03De=@1`L700S8b<01PH600m?Cd0AdM70492@P1jNWX0GUiN06i^KP1R
HV80EUIF04];B`1GEeL0>3Ph04Q8B01=CDd0EEEE0492@P0^;Rh0DU9B061PH00_;bl0DU9B01HF5P1X
J6P0<30`05EEE@0i>CT0?clo03@d=080BDU90240?Cdm04];B`14A4@0Cdm?03Ph>01_Kfl0B4Q804Y:
BP1>CTh0F5QH03<c<`1DE5@0M7Ad06MWI`1EEED0@D51055AD@1EEED0@d=305MGE`1XJ6P0LG5a09:B
TP0a<C40Rh^;05UIF@2ATI40UYJF07emO@1kNg/0Hf=S0820P01HF5P00P0j>SX03P1:BTX0=cLg04E5
A@0K6a/0G5aL05ADE018B4P0Cdm?0861P@1;Bd/0De=C04m?C`1IFET0I6AT4Oooool000oooooo0580
F5QH07inOP23Ph<0Jf][05aLG01XJ6P0T92@05IFEP1oOgl0SHf=03lo?`1PH600S8b<04i>CP1NGUh0
>3Ph04Y:BP27QhL0QXJ604A4A01LG5`0?3`l03Ti>@1[Jf/0EeMG04Y:BP1JFUX0=CDe05EEE@2CTi<0
K6a/03<c<`1BDU80@41006][J`29RHT0?Shn030`<01HF5P0?Cdm02h^;P1SHf<0MGEe030`<01?Cdl0
A4A404I6AP1^KVh0BDU902`/;01FEUH0Cdm?03`l?01TI6@0:b/[02<S8`1KFe/0GUiN04M7A`1KFe/0
>SXj01/K6`0o?cl0GUiN05IFEP1hN7P0=3@d01lO7`15ADD0IfMW05ADE00k>c/0@T9202XZ:P0m?Cd0
GemO03Ti>@11@D40HF5Q02DU9@0d=3@0JFUY0P1;Bd/0E017AdL09BDU04Q8B01]KFd0>CTi01hN7P12
@T80>c/k04e=C@1ZJVX0@d=302l_;`17AdL0ATI604M7A`1nOWh0M7Ad03<c<`1DE5@0DU9B03Ph>01m
OGd0De=C01`L700d=3@0IVIV04U9B@1YJFT0;bl_02`/;017AdL0K6a/04A4A01JFUX0Rh^;03/k>`0j
>SX0LW9b03Lg=`14A4@0DE5A02HV9P0a<C40Lg=c07AdM00d=3@0ATI6034a<@1CDe<0L71`04Q8B00e
=CD0M7Ad04];B`10@400Jf][04i>CP0e=CD0Fe]K059BDP0k>c/0IVIV08b<S00a<C40BDU904];B`0a
<C40Q8B403Ti>@0X:2P0Cdm?065QH@1DE5@0C4a<07YjNP0`<300C4a<06ATI017AdL0J6QX08b<S00V
9RH0<30`05UIF@80HF5Q01d0RXZ:03@d=01EEED0LW9b06UYJ@0j>SX0Fe]K05=CD`15ADD0TY:B0861
P@1CDe<0M7Ad06QXJ00f=SH0L71`08F5Q@0];Bd0CTi>04M7A`1FEUH0MgMg04U9B@0Z:RX0FUYJ05iN
GP1>CTh0M7Ad059BDP0205aLG00W0492@P2:RXX0P82002TY:@15ADD0LG5a04Y:BP1ADE40:BTY03Xj
>P1gMgL0DU9B05mOG`23Ph<0<c<c024Q8@1TI6@0>CTi07]kN`0i>CT0<30`04i>CP2@T900CTi>06=S
H`1QHF40>CTi0:2PX01mOGd0D51@08J6QP0c<c<0?clo07QhN028R8P0DU9B07]kN`0l?3`0EUIF0080
U9BD0300@d=304Y:BP1iNGT0ATI607]kN`1FEUH0:RXZ04I6AP1cLg<0J6QX05EEE@1mOGd0J6QX02LW
9`1EEED0FEUI05mOG`2=SHd0FUYJ02HV9P14A4@0EeMG05IFEP1fMWH0LW9b03Hf=P1<C4`0D51@059B
DP1aLG40IfMW02LW9`0l?3`0IVIV069RHP1bLW80KVi^01dM7@0l?3`0FEUI07MgM`1=CDd0GEeM04m?
C`0k>c/0L71`06=SH`0j>SXLooooo`0h05mOG`1fMWH0EeMG0410@01?Cdl0IFEU04i>CP0_;bl0L71`
03Hf=P14A4@0DU9B05UIF@1_Kfl0IFEU061PH01dM7@0GEeM05MGE`1`L700@D5106IVIP1<C4`0ADE5
055AD@0g=cL0DU9B03Hf=P1CDe<0IfMW061PH011@D40L71`06YZJP1BDU80IfMW07]kN`1hN7P0KFe]
03`l?00o?cl0?3`l03hn?P1@D500>SXj065QH@18B4P0ADE504A4A01LG5`09bLW04I6AP1MGEd0ADE5
04I6AP0e=CD204];B`0O03`l?018B4P0>CTi055AD@1CDe<0@d=304];B`1LG5`0LW9b04I6AP1RHV80
D51@04M7A`1]KFd0?3`l04a<C00o?cl0CTi>03Ti>@0U9BD0G5aL04Q8B010@400FEUI03Lg=`0n?Sh0
ADE504a<C00i>CT0ADE503Ph>00202l_;`2604e=C@12@T80CTi>04];B`11@D407alO04E5A@1CDe<0
:BTY04I6AP18B4P0DE5A05EEE@1CDe<0CTi>04Q8B01HF5P0HF5Q04I6AP15ADD0IfMW04Q8B00O7al0
L71`03Lg=`1CDe<0GEeM05]KF`1=CDd0>CTi04I6AP1@D500>3Ph04E5A@0n?Sh0KFe]03Xj>P1/K6`0
MGEe07QhN01HF5P0O7al092@T01OGel0G5aL07AdM01NGUh0Hf=S075aL@1MGEd0D51@05YJFP0o?cl0
D51@03/k>`14A4@0=CDe05YJFP1ADE40GemO06ATI01NGUh0B4Q807AdM01=CDd0FEUI07=cL`0k>c/0
H61P03dm?@1`L700QhN704U9B@1ADE40De=C05ADE024Q8@0?Shn06UYJ@1VIVH0NGUi03De=@1ADE40
EUIF02/[:`1=CDd0ADE5051@D019BDT0Hf=S04Q8B01PH600?3`l06UYJ@1SHf<0Fe]K06YZJP0o?cl0
HF5Q03hn?P1@D500ADE502`/;01mOGd0KFe]03De=@1;Bd/0ATI604i>CP0n?Sh0E5AD02DU9@1HF5P0
?clo04e=C@0h>3P0IFEU03/k>`1iNGT0P820038b<P1QHF40Jf][0410@01KFe/0IFEU07EeM@1IFET0
HF5Q05UIF@1?Cdl0>CTi051@D019BDT2059BDP0C04Y:BP1DE5@0OWin03`l?01SHf<0:2PX04e=C@0g
=cL0FUYJ04Q8B019BDT0AdM705ADE01=CDd0BTY:05mOG`1;Bd/0DU9B03/k>`0204Y:BP070492@P1D
E5@0Fe]K05YJFP1:BTX0FUYJ04M7A`0206=SH`0Q06YZJP1XJ6P0JVYZ07EeM@2QXJ40U9BD0<30`01?
Cdl0QhN7071`L02NWYh0EeMG08:2PP1iNGT0>SXj04];B`15ADD0BDU903`l?01TI6@0BTY:059BDP0^
;Rh0KVi^05QHF01@D500=CDe07QhN01<C4`0GEeM04E5A@1IFET0JVYZ017ooooo000?ooooo`0f08Z:
RP2OWil0I6AT05YJFP1bLW80Rh^;04e=C@13@d<0Jf][0;:b/P1hN7P0CTi>05QHF00e=CD0Ng]k04U9
B@0e=CD0BDU903Ph>00Y:BT0HF5Q07]kN`0S8b<0AdM703Ti>@1CDe<0SXj>038b<P0Q8B40EeMG05eM
G@1?Cdl0VIVI02d];@0d=3@0F5QH06ATI01gMgL0VIVI08J6QP0K6a/0De=C06=SH`1WIfL0Z:RX02l_
;`0J6QX0JFUY08^;R`1GEeL0[jn_05EEE@0I6AT0A4A40P1CDe<0;@1hN7P09BDU034a<@10@400GemO
04A4A01nOWh05ADE02`/;01YJFT0RHV903hn?P1VIVH0QhN703Hf=P0k>c/0FUYJ01hN7P1@D500;2`/
01XJ6P0m?Cd0Rh^;0451@@0T92@0D51@04Q8B01hN7P0MWIf01LG5`0f=SH0De=C0451@@1ADE40QHF5
024Q8@0W9bL0ADE503dm?@1TI6@0OWin03Lg=`0=3@d0<30`06UYJ@02065QH@0?03@d=00[:b/0?3`l
05aLG017AdL0GemO03/k>`0A4A40Bd];04U9B@0h>3P0FEUI02PX:00Y:BT0ADE50080I6AT01`0?clo
03Ti>@0Y:BT0>c/k08R8R01CDe<0;2`/04i>CP0b<S80@T9209:BTP0V9RH0:b/[03dm?@0f=SH0HF5Q
0;>c/`1fMWH05QHF02@T9018B4P0MGEe0:j^[P1IFET08B4Q034a<@1[Jf/0D51@0P1fMWH0S00Q8B40
A4A407UiN@15ADD0V9RH05QHF00Q8B40BDU903Xj>P17AdL0Ogmo0861P@0];Bd09RHV065QH@1bLW80
EUIF04e=C@0i>CT0?3`l06m_K`1NGUh0;Rh^05QHF00m?Cd0;2`/05iNGP21PH40?clo05]KF`0W9bL0
>3Ph09BDU02@T900;Bd]02h^;P0i>CT0Fe]K07inOP0j>SX0<c<c059BDP1;Bd/0E5AD08f=S@0g=cL0
6a/K04m?C`1PH600Ti>C03hn?P0Q8B40H61P0:VYZ@1:BTX0Hf=S069RHP0g=cL0J6QX059BDP1FEUH0
EeMG02PX:01>CTh0HF5Q04m?C`10@400Cdm?02@T901MGEd0Jf][038b<P15ADD0:RXZ03Lg=`0l?3`0
KFe]04=3@`1YJFT0<S8b0492@P1TI6@0G5aL02l_;`1PH600@T9205MGE`2n_[h0ATI602@T901ADE40
JVYZ055AD@2NWYh0Y:BT02l_;`0f=SH0IVIV06=SH`1dM7@0/k>c04A4A00V9RH0@d=307UiN@16ATH0
Shn?034a<@13@d<0G5aL08b<S01>CTh0UYJF04m?C`0e=CD0GUiN06i^KP1TI6@0Ng]k03Hf=P0V9RH0
ADE507]kN`20P800A4A405]KF`0];Bd0=CDe06e]K@1>CTh0=cLg03Xj>P0d=3@0;bl_034a<@1HF5P0
=3@d04e=C@0k>c/0:b/[7?ooool06P20P800IFEU061PH01:BTX0M7Ad04Y:BP0a<C40;2`/08j>SP0h
>3P0;2`/03/k>`1:BTX0MgMg05ADE01@D500H61P08F5Q@1<C4`0D51@02XZ:P13@d<0>3Ph0492@P1<
C4`0?clo0P0k>c/03@19BDT0I6AT04E5A@0c<c<0DU9B04I6AP0a<C40?clo04m?C`1eMGD0H61P03<c
<`15ADD00P0c<c<0<P0n?Sh0Fe]K04Y:BP13@d<0?3`l05eMG@1>CTh07alO03Lg=`13@d<0GemO03`l
?00c<c<0BDU904E5A@1:BTX0GUiN04U9B@1EEED0HF5Q05eMG@1GEeL0HF5Q08Z:RP1QHF40P82005QH
F017AdL0Q8B4079bLP1[Jf/0@T9205YJFP1?Cdl0@T9206][J`18B4P0@41006ATI01ADE40ADE504A4
A017AdL0>SXj04I6AP0n?Sh0=cLg02PX:00n?Sh0B4Q80P17AdL0:@1>CTh0?Cdm03hn?P1>CTh0=3@d
04Y:BP1ADE40EEEE05mOG`1MGEd0GemO05IFEP1=CDd0ATI604a<C017AdL0CTi>04A4A00n?Sh0K6a/
03hn?P19BDT0Bd];04m?C`17AdL0>SXj03<c<`15ADD0>3Ph04a<C01>CTh0J6QX03Hf=P1=CDd0F5QH
05=CD`1<C4`0Shn?09BDU01LG5`0H61P0080IFEU02`0Shn?06YZJP17AdL0De=C06IVIP0d=3@0DE5A
059BDP1CDe<07alO03lo?`1OGel0GUiN03lo?`1>CTh0=cLg05IFEP1ADE40NGUi09jNWP19BDT0B4Q8
03`l?01TI6@0TY:B03Ph>01OGel0Hf=S05iNGP28R8P0?clo07UiN@1VIVH0Ph>303Ti>@1IFET0GUiN
03Hf=P1ADE40@T9206EUI@0k>c/0E5AD03/k>`80EUIF02<0PX:205aLG01BDU80EUIF034a<@13@d<0
<30`04];B`1:BTX07QhN07QhN01ADE40:b/[04=3@`1;Bd/0Ogmo03Hf=P1KFe/0?Shn07inOP0l?3`0
B4Q80410@01LG5`0>CTi07IfMP1lO7`0:BTY04a<C01OGel0C4a<079bLP1iNGT0L71`06YZJP0205=C
D`1506MWI`12@T80@d=303lo?`1@D500OWin04];B`1ADE40N7Qh03lo?`2CTi<0@41004e=C@0b<S80
J6QX04i>CP1CDe<0?clo05YJFP1?Cdl0Bd];055AD@0d=3@0@D510410@01KFe/0ADE503Lg=`1@D500
F5QH04U9B@1fMWH0Xj>S0451@@1;Bd/0@D5106=SH`1mOGd0A4A406IVIP1iNGT0IfMW08^;R`0W9bL0
PX:205UIF@2e]KD0K6a/0:NWY`29RHT0IfMW08:2PP1;Bd/0?Cdm069RHP27QhL0Fe]K05YJFP0l?3`0
Rh^;04m?C`1CDe<0?clo07=cL`1>CTh0Kfm_05=CD`1[Jf/0Kfm_017ooooo000?ooooo`1L05EEE@2[
Zj/0JVYZ05QHF01YJFT0Rh^;04m?C`0c<c<0A4A406QXJ01lO7`0P82008:2PP0/;2`0CTi>06m_K`1Y
JFT0YJFU03Lg=`0b<S80Bd];06UYJ@1UIFD0UIFE03hn?P1FEUH0IFEU05]KF`16ATH0C4a<01dM7@13
@d<0N7Qh05mOG`1bLW80Ph>302TY:@0f=SH0KVi^09ZJVP1EEED0G5aL0492@P0d=3@0Ng]k07alO01?
Cdl0KVi^034a<@0e=CD0O7al0::RXP0k>c/0De=C03Ti>@1VIVH0X:2P04=3@`0_;bl0<S8b030`<012
@T80T92@03`l?00M7Ad0=CDe03Ti>@10@400S8b<0;Ng]`0/;2`0<C4a05YJFP11@D40XZ:R04Y:BP0=
3@d0@41004m?C`1HF5P0D51@0:f][@0Y:BT0@d=305IFEP0o?cl0E5AD06e]K@0I6AT07QhN04a<C01?
Cdl206YZJP0601dM7@0P8200GemO05iNGP0/;2`0>c/k0P0[:b/0101WIfL0<C4a01/K6`15ADD202XZ
:P2B0820P02DU9@07QhN03`l?00_;bl0H61P08R8R01@D5002`/;03De=@1VIVH0IFEU05UIF@1ADE40
:BTY02XZ:P1;Bd/0EUIF04i>CP1gMgL0Bd];02HV9P1EEED0?3`l04];B`1BDU809RHV03Lg=`1VIVH0
S8b<03/k>`1DE5@0<S8b04M7A`1UIFD0KFe]030`<01KFe/0ADE502l_;`1CDe<0IFEU03Ph>01ADE40
9RHV04Q8B01MGEd0RHV903@d=00i>CT0D51@04Y:BP1]KFd0KVi^03hn?P0g=cL0?Cdm030`<01BDU80
UIFE06ATI00a<C40E5AD05=CD`1SHf<0[jn_07]kN`0N7Qh0EEEE079bLP1VIVH0^KVi024Q8@0K6a/0
AdM7069RHP18B4P0Lg=c04M7A`0G5aL0EEEE06UYJ@16ATH0QXJ601lO7`0Z:RX0FEUI05]KF`15ADD0
K6a/03Ph>01XJ6P0L71`02`/;01NGUh0G5aL028R8P17AdL0UYJF03Ph>014A4@0:RXZ05IFEP2EUID0
>CTi034a<@1fMWH0ATI603Ti>@1hN7P07QhN03hn?P1JFUX0Cdm?08B4Q00b<S80:2PX05aLG01HF5P0
I6AT0;no_`0a<C40:BTY09NGU`1kNg/0G5aL08F5Q@1=CDd0<S8b0<G5a@2LW9`0H61P08^;R`0f=SH0
C4a<055AD@2_[jl0N7Qh06YZJP0Z:RX0=CDe04A4A01MGEd0IVIV0410@01hN7P202XZ:P0R07QhN01g
MgL0E5AD075aL@0W9bL0>c/k05mOG`1WIfL0;Bd]04=3@`0c<c<0DE5A06YZJP1`L700:RXZ03dm?@0f
=SH0AdM704Y:BP2=SHd09RHV038b<P0n?Sh0CDe=06m_K`1bLW80DE5A02XZ:P11@D40D51@061PH01f
MWH0?Cdm02l_;acooooo0380De=C05]KF`1EEED0>CTi04Y:BP1<C4`0=3@d01PH601/K6`0;bl_03@d
=01BDU80EEEE06UYJ@1bLW80L71`06IVIP1GEeL0@41006MWI`0[:b/0BTY:03Ph>010@400CDe=02d]
;@15ADD0=cLg05MGE`1RHV80EEEE03Ph>01JFUX0MWIf065QH@1DE5@0Hf=S06a/K01XJ6P0<30`0451
@@0h>3P0:b/[059BDP0m?Cd0Hf=S04=3@`0`<300>3Ph05IFEP80;Bd]00@0Bd];0451@@0d=3@09bLW
0P0l?3`08@0o?cl0=SHf02<S8`18B4P0De=C02XZ:P0k>c/0IfMW04e=C@0^;Rh0@d=305MGE`1NGUh0
EUIF03Lg=`1?Cdl0GemO06=SH`0j>SX0820P0492@P1?Cdl0?Shn03`l?00e=CD0>CTi03Hf=P0d=3@0
@T9203/k>`0Z:RX092@T030`<00204];B`35051@D018B4P0?3`l02DU9@1BDU80GemO030`<01;Bd/0
F5QH03Xj>P1CDe<0Ng]k065QH@1HF5P0EEEE05eMG@1BDU80FUYJ05eMG@1?Cdl0=3@d06UYJ@0l?3`0
GUiN06][J`1?Cdl0J6QX04A4A00Q8B40G5aL03Xj>P1DE5@0>CTi08F5Q@1EEED0Rh^;08>3P`1UIFD0
SXj>08N7Q`2i^KT0M7Ad05EEE@1_Kfl0H61P05eMG@1aLG40CTi>02l_;`1<C4`0=3@d04];B`0L71`0
=CDe028R8P1UIFD0?3`l04m?C`16ATH0Cdm?04e=C@1LG5`0;bl_04a<C01WIfL0A4A405QHF00`<300
Jf][08R8R00k>c/0@d=304Y:BP1@D500FUYJ03Ti>@1FEUH0EEEE05QHF00/;2`0C4a<055AD@0e=CD0
J6QX038b<P1<C4`0A4A405aLG00f=SH0Lg=c02`/;01EEED0Fe]K04e=C@1OGel0=cLg0492@P1?Cdl0
JVYZ04];B`0l?3`0O7al05YJFP0/;2`0=3@d04Y:BP20P800E5AD06e]K@0W9bL0FUYJ05=CD`1LG5`0
D51@08J6QP0a<C40Lg=c0820P00L71`0Jf][08:2PP0h>3P0?Shn04a<C01OGel0ADE505]KF`13@d<0
>c/k02d];@1:BTX0>CTi04m?C`1@D500>CTi07IfMP2KVi/0B4Q805mOG`0a<C40Hf=S03dm?@1LG5`0
E5AD0451@@0o?cl0EeMG04Y:BP13@d<0BTY:05QHF01JFUX0;bl_04I6AP14A4@0CDe=05ADE01GEeL0
F5QH04Q8B01@D500A4A405QHF01IFET0C4a<05YJFP1HF5P0VYZJ08n?S`1_Kfl0XJ6Q03Lg=`2SXj<0
YJFU0>WYj@1@D500IfMW06QXJ00e=CD0CTi>03<c<`0i>CT0?3`l05QHF00k>c/0ATI602DU9@1KFe/0
F5QH07UiN@14A4@0MgMg069RHP1/K6`0H61P07moO`26QXH04Oooool000oooooo02L0DU9B06MWI`1f
MWH0Ogmo05UIF@1kNg/0QXJ605aLG02JVYX0UYJF0492@P1iNGT0M7Ad03Ph>01TI6@0@D5104I6AP1W
IfL0JFUY02h^;P1[Jf/0=SHf03De=@1YJFT0Cdm?02`/;01?Cdl0HV9R05IFEP2DU9@0CTi>01`L7019
BDT0AdM707moO`1hN7P08R8R02@T9014A4@00P1@D5007`2UYJD0OWin01hN7P1;Bd/0DE5A06ATI033
`l<0=3@d01dM7@0`<300Fe]K04];B`26QXH05QHF04=3@`20P800LG5a05]KF`28R8P0?Cdm03hn?P1R
HV80Kfm_05mOG`2@T900;Bd]03`l?013@d<0WYjN09:BTP0e=CD00P14A4@08@1DE5@0MgMg02d];@17
AdL0I6AT01TI6@0K6a/0FEUI04=3@`1BDU80>CTi03Hf=P18B4P0R8R804I6AP0S8b<0AdM702TY:@2C
Ti<0YZJV02/[:`0U9BD0AdM704A4A015ADD0Shn?05eMG@0P8200?Shn04M7A`1PH600M7Ad01hN7P02
038b<P0>0820P01:BTX0IVIV02DU9@0X:2P0L71`08f=S@0m?Cd0Bd];07YjNP0[:b/0>3Ph05IFEP0X
:2P204];B`0=02XZ:P0];Bd0EEEE06QXJ00e=CD0DU9B04a<C01LG5`0JFUY034a<@0Q8B40?3`l05EE
E@0206IVIP0M038b<P0W9bL0AdM705aLG011@D40KVi^06UYJ@0V9RH0:2PX06YZJP19BDT0QhN702d]
;@0D51@0D51@0:>SX`1KFe/0KVi^061PH00^;Rh0CDe=06IVIP1:BTX0FUYJ05MGE`0I6AT0=CDe05=C
D`1]KFd00P1;Bd/0;00K6a/0?Shn06YZJP23Ph<0AdM7051@D00n?Sh0:b/[08V9R@1cLg<0?Cdm051@
D00f=SH0:BTY06i^KP1cLg<0;Bd]03`l?010@400F5QH0;6a/@1ZJVX0;2`/04e=C@0f=SH0F5QH0:VY
Z@1@D500De=C055AD@18B4P0YJFU0;:b/P0g=cL0;Rh^055AD@1=CDd0IfMW02DU9@0o?cl0FEUI04a<
C017AdL0UYJF0P0d=3@0B@1WIfL0De=C09>CT`1GEeL0;bl_06][J`1jNWX0>SXj06i^KP1?Cdl0@D51
09ZJVP2:RXX0>SXj07UiN@10@400=CDe06e]K@27QhL0=cLg04Y:BP1BDU80Cdm?08b<S01NGUh09RHV
05eMG@1LG5`0FUYJ07MgM`0k>c/0;bl_04i>CP10@400F5QH05UIF@26QXH0A4A402LW9`17AdL0EEEE
05QHF02RXZ80=cLg02LW9`1CDe<0JVYZ05UIF@2>SXh0<30`02LW9`1ADE40T92@08n?S`2KVi/0Kfm_
01dM7@0^;Rh0KVi^04m?C`1IFET0Fe]K01PH600g=cL0Bd];08b<S01?Cdl0A4A403@d=00h>3P0TI6A
09NGU`0d=3@07?ooool02@1IFET0Jf][06m_K`0m?Cd0FEUI05MGE`1<C4`0=3@d075aL@020410@01G
04E5A@11@D40LG5a05IFEP15ADD0De=C05MGE`1<C4`0GEeM04m?C`1=CDd0A4A4065QH@13@d<0=3@d
04e=C@0n?Sh0CTi>05YJFP1BDU80ADE504];B`1CDe<0?clo04a<C018B4P0FUYJ05UIF@1GEeL0Bd];
0410@01JFUX0GUiN04M7A`1YJFT0CTi>0451@@1;Bd/0H61P01HF5P1DE5@0I6AT051@D013@d<0<S8b
059BDP10@400?Shn04i>CP0];Bd0CTi>05aLG00d=3@0De=C05]KF`1gMgL0ATI6079bLP1@D500?3`l
08b<S016ATH0C4a<024Q8@0j>SX0=SHf02`/;01JFUX0=3@d03<c<`1EEED0ADE503Lg=`1=CDd0ADE5
038b<P1;Bd/0CTi>03/k>`0U9BD0C4a<03dm?@0n?Sh0De=C04U9B@0K6a/0;Rh^0080Bd];0580De=C
03Xj>P1;Bd/0B4Q804E5A@17AdL0CDe=05YJFP1WIfL0A4A404M7A`1dM7@0GEeM04Y:BP1]KFd0GemO
08F5Q@1VIVH0H61P04U9B@1BDU809bLW05ADE01CDe<0Cdm?04A4A01RHV80=CDe0<k>cP2ZZZX0KVi^
09RHV025QHD0YjNW08F5Q@2>SXh0Vi^K05iNGP1ZJVX0Fe]K05aLG02?Shl0O7al02l_;`17AdL0?3`l
059BDP0f=SH0;bl_05iNGP1GEeL0Cdm?05YJFP0m?Cd0AdM70451@@1mOGd0VYZJ03`l?01VIVH0:b/[
05UIF@22PX80?Cdm065QH@1PH600ADE506EUI@15ADD0H61P05=CD`1UIFD0;2`/05aLG01BDU805ADE
04M7A`15ADD0RHV9059BDP1WIfL09BDU0P14A4@0CP1iNGT0GEeM03Ph>01BDU80<30`05UIF@0j>SX0
=3@d03Hf=P0W9bL0N7Qh05EEE@0];Bd0ADE502d];@1>CTh0<30`04a<C00N7Qh0Kfm_02h^;P19BDT0
:b/[08f=S@0o?cl0OWin08j>SP0X:2P0?Cdm05MGE`1BDU80MgMg05UIF@1WIfL0G5aL04A4A01;Bd/0
Cdm?038b<P10@400<c<c0492@P1XJ6P0>SXj02/[:`1@D500?Cdm07moO`0g=cL0=CDe02XZ:P0o?cl0
>3Ph0451@@0d=3@0C4a<051@D00j>SX0=SHf03<c<`0m?Cd0@d=3061PH011@D40:BTY05eMG@1TI6@0
@41004Y:BP1OGel0CDe=06EUI@1lO7`0LG5a05UIF@1LG5`0FUYJ05QHF080UiNG01X0JVYZ07EeM@1f
MWH0TI6A06YZJP1dM7@0Q8B404E5A@1@D500FEUI05QHF01QHF40H61P04M7A`1fMWH0Cdm?07YjNP0c
<c<0C4a<03Ti>@1WIfL0CDe=06QXJ01?Cdl0F5QH071`L17ooooo000?ooooo`0307EeM@21PH40HF5Q
00<0Hf=S0?l0Cdm?05ADE01_Kfl0b/[:06YZJP1<C4`0FEUI05QHF01mOGd0=3@d034a<@1GEeL0KFe]
08b<S02GUiL0<c<c02TY:@0l?3`0KVi^0820P01KFe/0<c<c02d];@1^KVh0I6AT05UIF@2NWYh0<C4a
0451@@1dM7@0J6QX075aL@2][Jd0=3@d0451@@1YJFT0F5QH059BDP1HF5P05QHF038b<P1<C4`0ADE5
03@d=01iNGT0;Bd]01PH601;Bd/0;bl_04A4A01=CDd0<C4a0492@P1RHV80De=C01XJ6P0h>3P0CTi>
05EEE@1HF5P06QXJ020P800h>3P0FUYJ08>3P`1NGUh0D51@01hN7P1TI6@0PH6105=CD`1/K6`0Xj>S
02HV9P0[:b/0Hf=S05]KF`22PX80Kfm_01XJ6P0o?cl0Fe]K06=SH`1@D500IVIV020P801=CDd0VYZJ
06UYJ@0l?3`0EeMG01TI6@0_;bl0EUIF09bLW00m?Cd0@d=302/[:`0k>c/0PH6107IfMP0^;Rh0NGUi
02d];@0[:b/0Jf][0410@00f=SH0D51@03@d=01GEeL0Fe]K09ZJVP1eMGD0>CTi05IFEP11@D40L71`
0:>SX`0U9BD09RHV04i>CP1OGel0B4Q808b<S00M7Ad0De=C065QH@1HF5P0J6QX09NGU`0g=cL0>3Ph
069RHP1>CTh0IfMW0861P@0`<3006a/K05QHF01dM7@09bLW04Y:BP1CDe<0@D51075aL@1OGel0?3`l
05aLG00a<C40?Shn05ADE01oOgl0:RXZ04i>CP1:BTX0ADE507=cL`2NWYh0E5AD01/K6`1EEED0GUiN
06e]K@1_Kfl07AdM020P8014A4@0MgMg061PH027QhL0Jf][02DU9@14A4@0Hf=S05=CD`2GUiL0<30`
034a<@1ZJVX0HF5Q051@D01fMWH0:b/[03Ph>02JVYX0ZJVY04U9B@1TI6@0820P04];B`21PH40JVYZ
075aL@0b<S809BDU05=CD`2HV9P0I6AT04Y:BP1bLW80;bl_08B4Q012@T80CTi>069RHP0S8b<0De=C
0;Jf]P1fMWH0<30`04A4A01?Cdl0R8R808Z:RP0k>c/0HF5Q03hn?P1;Bd/0X:2P04U9B@0g=cL0LG5a
061PH01FEUH0][Jf04I6AP1>CTh0IFEU09BDU02?Shl0Ogmo034a<@0m?Cd0MGEe0:JVYP1ZJVX0TY:B
06=SH`0d=3@0GUiN07YjNP1VIVH0_kno06UYJ@0I6AT0BTY:07MgM`1dM7@0De=C08>3P`0K6a/0BTY:
07=cL`1iNGT001d0?3`l071`L00];Bd0=3@d065QH@1CDe<0B4Q805eMG@0H61P0<c<c08b<S02IVIT0
@T9202d];@1<C4`0A4A4092@T02GUiL0;2`/034a<@0l?3`0D51@07IfMP1aLG40?clo02<S8`0d=3@0
Fe]K065QH@0Looooo`2O069RHP1WIfL0G5aL04Y:BP1hN7P0E5AD03/k>`19BDT0WYjN07=cL`0c<c<0
ADE505UIF@2MWId0MGEe05ADE01]KFd0MGEe06EUI@1RHV80@41005ADE00k>c/0A4A405aLG01GEeL0
@d=302LW9`1DE5@0SHf=05ADE00a<C40Bd];06IVIP16ATH0@D5105UIF@2CTi<0OWin04E5A@1:BTX0
=3@d02h^;P0o?cl0GEeM05ADE013@d<0:RXZ055AD@1@D500;2`/038b<P1@D500Cdm?0492@P0c<c<0
?Cdm03<c<`0k>c/0HF5Q04m?C`1;Bd/0GEeM05IFEP1GEeL0FEUI07MgM`1FEUH0PX:205eMG@1:BTX0
LW9b05iNGP1IFET0>CTi05UIF@1EEED0EUIF04];B`0f=SH0=CDe04m?C`0g=cL0>SXj04A4A01>CTh0
>CTi04=3@`0^;Rh0=3@d02TY:@0e=CD0@D5104=3@`0k>c/0@D5103<c<`0j>SX0C4a<038b<P12@T80
@41005UIF@10@400C4a<05YJFP1]KFd0FEUI05ADE015ADD0Bd];0410@00j>SX0;Rh^04i>CP0I6AT0
@D5104=3@`1EEED0BTY:02TY:@0N7Qh0BDU902l_;`1CDe<0ADE506YZJP1@D500Jf][05ADE01:BTX0
Lg=c09:BTP2GUiL0IfMW04Y:BP1XJ6P0IfMW0:f][@2:RXX0ATI603lo?`1FEUH0:b/[0451@@0Z:RX0
:b/[03De=@1@D500=SHf03Xj>P0d=3@0FUYJ04I6AP1KFe/0:RXZ03Xj>P1>CTh0=CDe0080CDe=02H0
Rh^;0:^[Z`0j>SX0>3Ph04];B`1HF5P0NGUi03Ti>@1OGel0IfMW07]kN`0i>CT0@D5103dm?@0X:2P0
Jf][05]KF`19BDT0?Shn04U9B@18B4P0IFEU04i>CP1CDe<0D51@05ADE01XJ6P0A4A403dm?@17AdL0
BTY:05eMG@14A4@0GemO04M7A`0c<c<0EEEE03lo?`80De=C05T0JVYZ02@T901EEED0?clo05MGE`12
@T80G5aL03Hf=P1<C4`0EeMG03`l?019BDT0Cdm?0492@P19BDT0G5aL05]KF`1@D500Cdm?04Y:BP1C
De<0AdM70492@P14A4@0GEeM04M7A`0];Bd0:RXZ06i^KP0Z:RX0CDe=024Q8@1WIfL0>3Ph04E5A@12
@T80CDe=03`l?00k>c/0ATI603dm?@18B4P0CTi>04a<C01EEED0FUYJ0861P@1GEeL0ATI604];B`0n
?Sh0JVYZ05YJFP0h>3P0EUIF03`l?010@400GemO0410@01WIfL0PH6104m?C`1fMWH0KFe]08J6QP2A
TI40a/K60:f][@2`/;00OGem04Q8B01CDe<0?Cdm03@d=019BDT0EeMG059BDP1HF5P0>CTi079bLP1D
E5@0G5aL034a<@1:BTX0ATI605=CD`13@d<0G5aL075aL@0Aooooo`003oooool08P1fMWH0d];B051@
D01`L700OWin0;6a/@1MGEd0?clo05EEE@1]KFd0RHV90:j^[P1gMgL0:RXZ04Q8B01@D500KFe]08F5
Q@0[:b/0<C4a07YjNP1NGUh0@D5105UIF@0c<c<0EEEE09nOW`0o?cl0>c/k0410@00V9RH0<30`08J6
QP1BDU8203Ph>00a02TY:@0h>3P0MWIf04U9B@0I6AT0@d=304I6AP1TI6@0]kNg02/[:`0R8R80FEUI
03dm?@1;Bd/0_[jn07IfMP0>3Ph0CDe=04a<C02>SXh0Zj^[020P800Y:BT0GEeM061PH012@T80J6QX
02TY:@0];Bd0IfMW06][J`0Z:RX0=SHf04I6AP0U9BD0>3Ph05IFEP0b<S80HF5Q02@T900M7Ad0>CTi
061PH019BDT0>3Ph05]KF`0^;Rh0A4A406a/K002020P803;02h^;P0a<C40EEEE079bLP0e=CD0<c<c
03Lg=`0b<S80Hf=S08V9R@0Q8B406QXJ02/[:`1OGel0GEeM06YZJP0K6a/0;Rh^03Xj>P1HF5P0ATI6
0;6a/@1>CTh06QXJ051@D00m?Cd0DU9B07MgM`0e=CD06QXJ02HV9P1IFET0[Zj^069RHP0_;bl09BDU
03lo?`1RHV80Lg=c03<c<`1gMgL08R8R020P801`L700<S8b03hn?P1XJ6P05aLG03Ti>@2<S8`0NGUi
02h^;P0l?3`0<C4a04E5A@2SXj<0D51@018B4P0l?3`0IfMW04=3@`1FEUH0NGUi024Q8@1HF5P0Lg=c
06=SH`2LW9`0Kfm_01`L700g=cL0OGem06][J`23Ph<0DU9B01lO7`15ADD0Rh^;07alO01OGel0O7al
02HV9P1?Cdl0G5aL04i>CP1^KVh0Ph>303`l?011@D40J6QX06i^KP18B4P0IVIV038b<P0i>CT0I6AT
06a/K00K6a/0Cdm?05mOG`0S8b<0NWYj04];B`14A4@0G5aL03Ph>019BDT0TI6A04a<C00O7al0H61P
05MGE`2KVi/0Fe]K02XZ:P14A4@0H61P05ADE01/K6`0ZJVY02XZ:P18B4P0Bd];075aL@2PX:006QXJ
03<c<`23Ph<0IFEU06ATI01RHV80;Bd]06IVIP2?Shl0D51@08f=S@0n?Sh0:2PX05aLG01kNg/0EUIF
09ZJVP0a<C40>c/k06m_K`1JFUX0?clo07YjNP0e=CD0De=C09RHV01GEeL0CDe=08f=S@0l?3`0CTi>
06EUI@20P800=SHf0451@@0h>3P0HV9R06m_K`2BTY80E5AD02/[:`1HF5P0>CTi03hn?P2KVi/0E5AD
038b<P1BDU80DE5A04U9B@20P800ADE502<S8`1BDU80Fe]K06i^KP2[Zj/0;2`/01TI6@0e=CD0IVIV
08j>SP1gMgL0Fe]K03Xj>P0h>3P0FEUI04e=C@1TI6@0Q8B401/K6`0P8200>CTi03Xj>P1JFUX0Fe]K
0451@@0];Bd07?ooool0C01/K6`0E5AD05YJFP1EEED0DE5A059BDP10@4008R8R04i>CP10@400<C4a
04M7A`13@d<0Cdm?05UIF@1[Jf/0DE5A03dm?@12@T80Cdm?0451@@0c<c<0>c/k06MWI`16ATH0?Cdm
05mOG`10@400@D5104a<C01VIVH0Jf][05YJFP1GEeL0GemO04A4A00f=SH0?3`l05QHF00m?Cd0=cLg
02XZ:P18B4P0CTi>02d];@1:BTX0?Shn02@T900c<c<0@T9202<S8`0i>CT0@T9204U9B@0e=CD0;Bd]
03Ph>016ATH0DU9B0492@P0U9BD0@D5104A4A00[:b/0;2`/065QH@14A4@0=CDe03hn?P1@D500EEEE
04Q8B00e=CD0DE5A05EEE@1DE5@202HV9P0>05UIF@1BDU80C4a<05YJFP0m?Cd0ATI604=3@`16ATH0
CTi>04e=C@0j>SX0=3@d03hn?P1>CTh3055AD@1C04Q8B00Y:BT0@d=305eMG@0i>CT0DU9B04e=C@1:
BTX0GemO04M7A`19BDT0>c/k04Q8B01ADE40BTY:05mOG`1EEED0GUiN059BDP1`L700:2PX05MGE`1;
Bd/0@D5104E5A@0_;bl0=SHf05UIF@11@D40H61P05IFEP26QXH0CTi>0::RXP1kNg/0E5AD061PH02?
Shl0Ti>C06a/K01MGEd0IFEU03lo?`1?Cdl0HF5Q07IfMP1>CTh0JFUY07=cL`1jNWX0<30`03<c<`11
@D40=SHf04U9B@11@D40Hf=S05eMG@0k>c/0EEEE04];B`1:BTX0J6QX04Y:BP1RHV80<C4a04Y:BP1?
Cdl0BTY:05=CD`1LG5`0?Shn04m?C`0c<c<0L71`03Xj>P1;Bd/0;Rh^06e]K@1KFe/07alO04=3@`0e
=CD00P1CDe<02@1NGUh0<S8b03/k>`0c<c<0EEEE05=CD`0f=SH0C4a<038b<P0203`l?01S038b<P1@
D500ADE505IFEP14A4@0>c/k051@D00o?cl0KVi^03/k>`1LG5`061PH065QH@0h>3P0E5AD0410@01f
MWH0>CTi07UiN@1bLW8051@D04A4A01CDe<0?clo06=SH`1:BTX0FUYJ05ADE013@d<0>3Ph04a<C00a
<C40ADE503Lg=`1FEUH0AdM702XZ:P0m?Cd0EeMG03hn?P1LG5`07QhN034a<@13@d<0ATI603lo?`1;
Bd/0>SXj04E5A@1ADE40C4a<061PH01hN7P0MWIf03/k>`0g=cL0>c/k02PX:01CDe<0MgMg03dm?@1Q
HF40MgMg06i^KP1HF5P0Ogmo08N7Q`1oOgl0Q8B409RHV01hN7P0J6QX0:n_[`1nOWh0^;Rh0=WIf@3_
knl0D51@05IFEP1QHF40GUiN06][J`14A4@0BDU9065QH@1/K6`0BTY:069RHP1TI6@0MgMg06YZJP1U
IFD0?clo06QXJ01fMWH0FEUI04i>CP1]KFd0NGUi017ooooo000?ooooo`1H05UIF@2ATI40MGEe075a
L@1OGel0MWIf079bLP0i>CT0L71`059BDP1QHF40MgMg08F5Q@0c<c<0@d=306ATI01gMgL0YJFU034a
<@0[:b/0@D5106e]K@1?Cdl0M7Ad034a<@0/;2`0OGem06a/K01dM7@0J6QX01hN7P1:BTX0>c/k05mO
G`1dM7@0Fe]K01<C4`0a<C40ATI605]KF`0o?cl0Ng]k04];B`0X:2P0DU9B03Lg=`1@D500J6QX02<S
8`0];Bd0?3`l07emO@1:BTX0ATI602LW9`0_;bl0FUYJ04U9B@1<C4`0CDe=02DU9@13@d<0Hf=S024Q
8@0R8R80<c<c04];B`1EEED0OGem07EeM@0M7Ad08R8R03@d=01IFET0XJ6Q04i>CP0H61P0@D5103/k
>`1ADE40OGem0<_;b`0Y:BT0>SXj04E5A@0/;2`0Hf=S096AT@8092@T04d0@D5104=3@`26QXH0Fe]K
020P800i>CT0LG5a05UIF@16ATH0MGEe03Hf=P0l?3`0NWYj04Y:BP0f=SH0A4A401LG5`0c<c<0FUYJ
05iNGP0Z:RX0B4Q801lO7`1IFET0Zj^[08R8R00d=3@0;bl_04i>CP0a<C40P82004i>CP0J6QX0A4A4
05YJFP0j>SX0C4a<0<?3``1JFUX04Q8B05QHF01ADE40Rh^;0:BTY00Y:BT09BDU06=SH`1RHV80DU9B
08Z:RP10@400@T9204a<C01XJ6P0ADE509ZJVP1cLg<06QXJ034a<@1NGUh0D51@061PH00E5AD0>c/k
04];B`1fMWH0@T9204E5A@1`L700:b/[0861P@1mOGd0<30`02d];@0k>c/0<C4a03Ph>00207QhN01L
02d];@19BDT0Cdm?08n?S`2ATI40?Shn02TY:@16ATH0FEUI05ADE02i^KT0<c<c02PX:00o?cl0De=C
04];B`2QXJ40OGem02@T901?Cdl0H61P09:BTP2j^[X0:b/[0451@@1:BTX0LW9b05QHF02][Jd0?Cdm
07moO`26QXH0Kfm_07alO01KFe/0:BTY04i>CP2UYJD0KVi^0410@00M7Ad0ADE50:JVYP1SHf<0=SHf
05eMG@0c<c<0?Cdm07UiN@0U9BD0@41003`l?012@T80QhN708j>SP0T92@0Cdm?04M7A`1FEUH0`/;2
04a<C00j>SX0NGUi065QH@1MGEd0X:2P08J6QP0i>CT0UiNG075aL@1/K6`0][Jf05UIF@0W9bL0EeMG
0;:b/P1JFUX0JVYZ024Q8@0e=CD0EEEE08f=S@1nOWh0Fe]K09fMW@0e=CD0@41007QhN01lO7`0IfMW
07MgM`0Q8B4205eMG@0K04Q8B00g=cL0BDU901lO7`1_Kfl0VYZJ06ATI013@d<0IFEU04U9B@0U9BD0
De=C05UIF@0[:b/0A4A402d];@19BDT0BTY:096AT@1[Jf/09BDU03Xj>P0d=3@0OWin0:VYZ@0n?Sh0
:RXZ01cooooo01<0I6AT07moO`2ATI40AdM704i>CP1MGEd0IFEU01TI6@1/K6`0C4a<03Ph>01MGEd0
Cdm?07AdM01^KVh0OWin065QH@1@D500?Cdm0080@d=301D0?clo03De=@0h>3P0A4A403`l?00o?cl0
>3Ph04i>CP1QHF40Bd];038b<P1DE5@0EEEE04a<C01MGEd0@D51051@D012@T80?3`l0410@00];Bd0
0P13@d<0<00`<300B4Q8051@D00W9bL0ATI604Q8B00L71`0KVi^06QXJ018B4P0A4A4030`<01>CTh0
?Shn02d];@16ATH0=CDe04i>CP1;Bd/0@D5102/[:`10@400HF5Q0492@P1ZJVX0Cdm?03Xj>P1bLW80
B4Q804e=C@0M7Ad0@d=302LW9`0^;Rh0ADE5024Q8@0O7al0>SXj02h^;P0W9bL0@T9202d];@0T92@0
?3`l03Xj>P0^;Rh08B4Q03lo?`80<C4a01/0@d=304A4A00N7Qh0:b/[04A4A01>CTh0@4100451@@1H
F5P0?Shn04Q8B017AdL0EUIF04m?C`1TI6@0>SXj03dm?@1PH600CDe=03De=@1?Cdl0Fe]K07IfMP1=
CDd0?clo05]KF`12@T800P0i>CT0H00a<C40BDU905MGE`25QHD0EUIF0;no_`2@T900Cdm?09NGU`1U
IFD0L71`0820P02KVi/0M7Ad059BDP1UIFD0EUIF04i>CP1ADE40G5aL02l_;`15ADD0:b/[0451@@16
ATH0FUYJ03dm?@1DE5@0;Bd]02l_;`0`<300FEUI038b<P14A4@0FUYJ03`l?01HF5P0=CDe061PH01[
Jf/0?Shn05MGE`1IFET0;Bd]05aLG01<C4`0KVi^05MGE`1IFET0Bd];038b<P0l?3`0<30`04i>CP1R
HV80EEEE03`l?01EEED0<C4a04=3@`1@D500IFEU06IVIP19BDT0EEEE03/k>`1<C4`0DE5A04A4A01L
G5`0EEEE06][J`0i>CT0B4Q805mOG`0g=cL0I6AT03dm?@1DE5@0@T9208>3P`1KFe/0EEEE04M7A`23
Ph<0=SHf06][J`1RHV806ATI04m?C`1kNg/0@D5106=SH`18B4P0KFe]061PH080DU9B04D0CTi>03`l
?01ADE40?Cdm05QHF01WIfL0>c/k03lo?`1<C4`0?Shn08J6QP0c<c<0A4A404I6AP1IFET0ADE50451
@@0k>c/0B4Q805iNGP0h>3P0Bd];04E5A@17AdL0@D5104e=C@15ADD0?clo0410@019BDT0Kfm_04i>
CP17AdL0Cdm?08Z:RP17AdL0Fe]K04a<C014A4@0HF5Q05ADE02<S8`0WIfM03Ti>@1;Bd/0@d=307Qh
N01IFET0MgMg079bLP14A4@0EUIF06][J`1bLW80B4Q804U9B@1ZJVX0M7Ad04e=C@1MGEd0AdM706m_
K`1dM7@0IFEU04a<C01DE5@0IfMW08>3P`1SHf<04Oooool000oooooo0280D51@079bLP21PH40Z:RX
05ADE01PH600Rh^;071`L02QXJ40MgMg04Y:BP1PH600LW9b04Y:BP1lO7`0<S8b04I6AP1dM7@0GemO
08R8R01dM7@0=3@d03Ph>01ZJVX0IfMW04Y:BP0h>3P0<C4a04a<C01iNGT0>SXj030`<016ATH0=3@d
0P28R8P01`0];Bd0>CTi071`L00W9bL0<c<c079bLP1TI6@00P0i>CT0g@0[:b/0CDe=09:BTP1@D500
:2PX04a<C00e=CD0Bd];075aL@0/;2`0Bd];04I6AP0n?Sh0SXj>0;Bd]00V9RH09bLW059BDP0k>c/0
L71`09FEU@0O7al08B4Q04i>CP1nOWh0I6AT07YjNP1ADE40;bl_06YZJP1UIFD0<30`0;no_`1`L700
6ATI04Y:BP1YJFT0Fe]K0820P00_;bl08b<S03`l?01PH600;Rh^038b<P1HF5P09RHV0820P01PH600
9RHV02XZ:P12@T80=3@d038b<P1mOGd0J6QX02LW9`1=CDd0FEUI06MWI`1fMWH0820P024Q8@17AdL0
L71`05ADE01bLW806ATI02XZ:P1fMWH0]kNg03Ph>01LG5`0O7al01lO7`1BDU80SHf=03<c<`1eMGD0
GemO02@T900g=cL0GemO06ATI00o?cl0JVYZ034a<@1DE5@0QHF5059BDP15ADD0G5aL03/k>`1ADE40
IfMW06YZJP0^;Rh0EUIF03/k>`0b<S80QHF50:j^[P0W9bL0:b/[04M7A`1CDe<0Z:RX04];B`0^;Rh0
Hf=S07alO01JFUX0OGem0;Fe]@0a<C40BTY:06IVIP1TI6@0LG5a06QXJ00C4a<0>c/k04=3@`1`L700
JVYZ03/k>`0F5QH0>3Ph06UYJ@1fMWH0AdM70861P@1WIfL0<C4a04a<C01LG5`0A4A406MWI`0^;Rh0
7alO05IFEP1oOgl0<C4a05=CD`0];Bd0?clo09VIV@1jNWX0=cLg05]KF`0a<C40=SHf0861P@1LG5`0
FUYJ06][J`1_Kfl0SXj>06i^KP0g=cL0?clo061PH01YJFT0PH6101lO7`0d=3@0EUIF06i^KP1LG5`0
YjNW0492@P0[:b/0Ng]k05EEE@1mOGd08b<S03Ti>@1?Cdl0Ng]k05IFEP2d];@0@D5103Ph>01GEeL0
IFEU065QH@2MWId0;Rh^0451@@17AdL0UYJF069RHP13@d<0;Rh^03dm?@1BDU80IVIV04E5A@1hN7P0
H61P0451@@1;Bd/0EeMG0410@01FEUH0?3`l02l_;`0i>CT0Hf=S04m?C`0a<C40A4A403Ti>@1QHF40
KFe]038b<P0m?Cd0HF5Q03/k>`16ATH0RXZ:0080;2`/01H0LG5a06YZJP1UIFD0RHV906IVIP0R8R80
;2`/051@D01QHF40WYjN04E5A@0[:b/0>CTi04U9B@23Ph<0FEUI08^;R`11@D40>CTi05=CD`1=CDd0
E5AD7?ooool0:@1ZJVX0Cdm?03lo?`0f=SH0Lg=c04Y:BP0a<C40=3@d075aL@1UIFD0:BTY03lo?`16
ATH0NGUi061PH01DE5@0Hf=S06a/K01?Cdl0F5QH04I6AP1@D500B4Q804a<C01EEED0De=C05MGE`0m
?Cd0Hf=S08J6QP1SHf<0?Shn05]KF`1]KFd0Bd];04e=C@1IFET0R8R807YjNP1>CTh0ATI60080A4A4
0100GEeM03Xj>P1FEUH0BDU9024Q8@0o?cl0Cdm?018B4P0_;bl0@D5105QHF00m?Cd0BTY:04m?C`0g
=cL0<c<c0P1HF5P01@12@T80C4a<04M7A`0a<C40Cdm?0080AdM70=h0GemO04=3@`0o?cl0EUIF069R
HP1=CDd0?Cdm05]KF`17AdL0B4Q804=3@`0Z:RX0;Rh^03Lg=`0e=CD09RHV03Ph>00];Bd0;2`/034a
<@0b<S80;Rh^02l_;`0d=3@0?3`l03Xj>P0n?Sh0>c/k030`<00_;bl0@41003De=@0i>CT0@T9204I6
AP0l?3`0B4Q8055AD@1PH600@T9204I6AP15ADD0LW9b04m?C`1>CTh0?Shn05UIF@0/;2`0B4Q803Ph
>011@D40BDU9034a<@0];Bd0?Shn0451@@0k>c/0Bd];04m?C`1CDe<0[Jf]08R8R01GEeL0Lg=c07al
O028R8P0DU9B0410@01dM7@0L71`08>3P`1eMGD0GEeM07]kN`1hN7P0?Shn05aLG00n?Sh0FUYJ0451
@@1aLG40BDU906YZJP0i>CT0@T9202d];@1ADE40C4a<06m_K`2:RXX0?3`l04E5A@1EEED0GemO07Qh
N01LG5`0?Cdm04A4A00/;2`0GEeM02XZ:P1<C4`0B4Q8061PH019BDT0?clo04e=C@0P8200AdM705eM
G@19BDT0>3Ph04m?C`1LG5`0EeMG065QH@1FEUH0FEUI05aLG01oOgl0ADE503dm?@15ADD0Ti>C07Mg
M`0b<S80:BTY038b<P1gMgL0RXZ:0410@01ADE40E5AD07alO00`<300H61P0492@P1TI6@0IFEU05QH
F012@T80PX:207YjNP1:BTX0@41004m?C`0n?Sh0Lg=c05ADE01GEeL0JFUY04=3@`0n?Sh0FUYJ02h^
;P0d=3@0;Rh^065QH@10@400<30`03hn?P11@D40=SHf04i>CP0V9RH0JVYZ03Ph>00l?3`0@T9205iN
GP12@T80<30`0492@P1BDU80Cdm?05=CD`0n?Sh0;Bd]03lo?`18B4P0GemO04a<C01:BTX0?Shn05=C
D`1FEUH0EeMG0410@016ATH0HF5Q05YJFP1>CTh0OWin05=CD`15ADD0O7al01lO7`1RHV80?3`l04I6
AP20P800WYjN07EeM@1]KFd0LW9b03`l?00m?Cd0D51@061PH010@400Cdm?03@d=029RHT0Cdm?055A
D@1;Bd/0GUiN05EEE@1RHV80E5AD069RHP2MWIdAooooo`003oooool0I@21PH40ZZZZ04i>CP1OGel0
MgMg0:6QX@1BDU80@41006a/K023Ph<0BTY:075aL@1:BTX0=cLg07MgM`0h>3P0Jf][06ATI00V9RH0
BTY:07=cL`0^;Rh07QhN04A4A01LG5`0PX:2059BDP0V9RH0:RXZ05aLG01nOWh0P82008j>SP0Z:RX0
?3`l06QXJ017AdL0SXj>0<K6aP0S8b<06ATI05ADE01LG5`0Jf][06EUI@0I6AT0:2PX06m_K`1dM7@0
Jf][07emO@0C4a<08B4Q04M7A`1>CTh0De=C04I6AP0H61P0<S8b06YZJP1YJFT0;Bd]04Y:BP0Z:RX0
Fe]K07emO@0m?Cd0820P03hn?P0_;bl09RHV06UYJ@1LG5`06QXJ030`<00e=CD09RHV075aL@1XJ6P0
6ATI02`/;015ADD0Cdm?0:n_[`2=SHd04A4A04=3@`1/K6`0DU9B05UIF@2@T9009BDU04E5A@20P800
HV9R06QXJ01^KVh04Q8B03@d=00m?Cd0K6a/0080De=C08X06ATI059BDP1WIfL0Fe]K04M7A`1GEeL0
9BDU038b<P1bLW80;bl_02HV9P0g=cL0:RXZ038b<P1IFET0OGem03Xj>P0f=SH0=cLg02h^;P1lO7`0
TI6A034a<@0_;bl0JVYZ03/k>`0a<C40X:2P01lO7`0Y:BT0FUYJ04U9B@1FEUH0Zj^[04i>CP0W9bL0
F5QH07moO`1]KFd0R8R803Ph>00Q8B40@41008b<S029RHT0D51@05MGE`13@d<0JFUY06MWI`1NGUh0
G5aL02/[:`0g=cL0CTi>075aL@1ADE40HF5Q059BDP0b<S80Kfm_0861P@12@T80<c<c05EEE@0a<C40
Bd];07UiN@0U9BD0:b/[04i>CP10@400B4Q807=cL`25QHD0;bl_05eMG@15ADD0Ng]k09BDU00m?Cd0
9bLW03hn?P1BDU80ADE509:BTP0Q8B40>SXj04A4A01ZJVX0LG5a09:BTP0R8R80<c<c0492@P1YJFT0
GemO04U9B@0P8200B4Q805aLG00m?Cd0IfMW0820P00j>SX0NGUi038b<P1?Cdl0IFEU02DU9@13@d<0
MGEe079bLP0j>SX0H61P03Xj>P25QHD0DU9B02<S8`16ATH0:BTY02`/;025QHD0NWYj03Xj>P1LG5`0
<c<c05UIF@2DU9@0Cdm?03Xj>P1KFe/0?clo08R8R01_Kfl0:b/[05IFEP1GEeL204e=C@0_08j>SP2Y
ZJT0?3`l05IFEP0m?Cd0JFUY0:f][@1YJFT08B4Q05ADE01OGel0>c/k061PH02>SXh08B4Q05QHF02V
YZH0?Cdm075aL@2m_Kd0;bl_03Ph>02BTY80L71`05ADE01NGUh0<C4a03<c<`19BDT0K6a/03lo?`1G
EeL0AdM70492@P1LG5`0JFUY03Hf=P0g=cL0DU9B01hN7P0h>3P0AdM704A4A00^;Rh0Cdm?03hn?P11
@D407?ooool0/@1HF5P0I6AT05ADE01:BTX0?Cdm055AD@1BDU806QXJ06a/K01BDU80;Bd]04E5A@1J
FUX0GUiN071`L01kNg/0EeMG03Xj>P0g=cL0De=C03Hf=P0j>SX09RHV04A4A01>CTh0<C4a04Q8B01:
BTX0D51@04i>CP1BDU80?clo04I6AP1?Cdl0HF5Q05UIF@1?Cdl0@D5105UIF@0i>CT0ADE503dm?@0l
?3`0D51@05ADE01OGel0BDU902TY:@19BDT0CDe=02TY:@0o?cl0FEUI03@d=00`<300820P03Xj>P1D
E5@0EEEE03`l?00T92@0De=C06EUI@0o?cl0AdM705IFEP1LG5`0=CDe055AD@1FEUH0CDe=07YjNP0i
>CT0BTY:0492@P1BDU808B4Q01lO7`0m?Cd0<C4a038b<P1<C4`0<c<c03dm?@17AdL0@d=303Hf=P1:
BTX0@D5104i>CP0k>c/0DE5A04e=C@1>CTh0Hf=S04i>CP0n?Sh0>CTi069RHP0k>c/0DE5A04I6AP1<
C4`0DE5A03Xj>P1ADE40ATI604m?C`1;Bd/0>CTi03@d=01<C4`0@d=3059BDP1iNGT0>CTi05IFEP17
AdL0L71`05IFEP0c<c<0BTY:05UIF@0d=3@0A4A408V9R@1hN7P0K6a/08>3P`1RHV80?Cdm059BDP17
AdL0Bd];04e=C@1/K6`0IVIV04=3@`1>CTh0Cdm?0492@P14A4@0De=C04I6AP17AdL0;Rh^02TY:@0h
>3P0MgMg04a<C01=CDd0A4A404];B`1:BTX0I6AT03/k>`0`<300ADE5034a<@1FEUH0ADE50861P@2K
Vi/0@d=304M7A`1NGUh0D51@07AdM00l?3`0L71`06EUI@1cLg<0@D5104E5A@1>CTh0B4Q807AdM002
059BDP0M05ADE01ZJVX0A4A403dm?@0c<c<0FEUI06MWI`0j>SX0E5AD02HV9P0e=CD0BTY:03/k>`1/
K6`0JFUY038b<P0a<C40F5QH05mOG`15ADD0NGUi0492@P1NGUh0?Shn092@T01FEUH0IVIV05QHF01]
KFd00P1:BTX0<@1;Bd/0>3Ph03hn?P1EEED0B4Q8051@D01TI6@0Fe]K05QHF01PH600Fe]K04];B`16
ATH0EEEE04A4A01HF5P0L71`0410@01NGUh0J6QX04=3@`1PH600<30`04E5A@1DE5@0Hf=S04Y:BP1<
C4`0FEUI05ADE01<C4`0@d=304A4A01LG5`0Bd];06EUI@1VIVH0EUIF051@D01:BTX0GemO04i>CP1d
M7@0R8R805ADE01JFUX0ADE504m?C`28R8P00P1RHV805P1eMGD0De=C08:2PP18B4P0Ogmo04Y:BP1S
Hf<0Fe]K07=cL`1TI6@0>SXj04i>CP1<C4`0AdM704Q8B017AdL0D51@05QHF01:BTX0GEeM0492@P1<
C4`204i>CP05059BDP1OGel0EUIF061PH01YJFT04Oooool000oooooo0<X0Kfm_0;2`/01kNg/0OWin
069RHP2>SXh0Q8B4059BDP1YJFT0Lg=c06YZJP2OWil0HV9R04A4A01QHF40@D51079bLP2:RXX0>CTi
04i>CP1WIfL0ADE5065QH@28R8P0>CTi05UIF@1BDU80=SHf07=cL`1`L700;bl_03`l?01ADE40>SXj
08b<S01OGel0<30`03<c<`1KFe/0Cdm?04M7A`29RHT0?3`l03Ti>@1PH600;bl_05MGE`1XJ6P09BDU
03lo?`1cLg<0ATI603Ph>00n?Sh09bLW065QH@25QHD0;Bd]03Lg=`17AdL0=CDe0410@01nOWh0:2PX
04i>CP1EEED0=3@d04A4A01gMgL0GEeM024Q8@1;Bd/0ATI604e=C@1gMgL0:RXZ01lO7`1ADE40A4A4
03Hf=P1eMGD0YjNW02`/;01:BTX0De=C03De=@1GEeL0Jf][01/K6`0O7al0@D510410@01VIVH0>3Ph
02DU9@0j>SX0G5aL03hn?P0f=SH0I6AT02h^;P0c<c<0LW9b05ADE00n?Sh0HF5Q03`l?014A4@0I6AT
04=3@`0[:b/0FUYJ03Hf=P1EEED0TY:B04e=C@0V9RH0GUiN07=cL`17AdL0NWYj03`l?00L71`0?Shn
06a/K01:BTX0Fe]K09NGU`0g=cL071`L061PH01MGEd0JVYZ06=SH`0Y:BT0A4A407AdM01QHF40Fe]K
08J6QP0l?3`0<S8b06a/K01[Jf/0?Cdm08N7Q`1DE5@0:2PX05UIF@1NGUh0=SHf05IFEP0W9bL0?Cdm
07moO`1UIFD0=CDe051@D01OGel0ADE508V9R@1bLW80>c/k055AD@1HF5P0=SHf05IFEP2=SHd0FUYJ
03lo?`1DE5@0A4A407AdM02CTi<0;bl_038b<P16ATH0De=C05QHF02RXZ80;Rh^02d];@1GEeL0DE5A
04M7A`1mOGd0>3Ph02d];@1?Cdl0@D5105MGE`1bLW809RHV03hn?P1[Jf/0GUiN05UIF@2BTY80<C4a
07]kN`29RHT0?clo0P1>CTh0400j>SX0IVIV0:NWY`1KFe/0CDe=0410@01SHf<0L71`02TY:@0g=cL0
Hf=S04a<C019BDT0Kfm_03Hf=P1FEUH20410@00d08J6QP13@d<092@T051@D01>CTh0De=C08n?S`0b
<S80ATI605aLG01FEUH0KVi^08J6QP1KFe/0FUYJ08F5Q@18B4P0TI6A0:6QX@0k>c/0>CTi06i^KP24
Q8@0EEEE07MgM`0/;2`0>CTi059BDP1bLW80EeMG06QXJ01kNg/08b<S02TY:@1]KFd0GemO07inOP1O
Gel092@T04A4A01eMGD0H61P04Y:BP1RHV80@T9204a<C01YJFT0EUIF0451@@1IFET0Cdm?03Hf=P80
M7Ad00h0<S8b05=CD`1=CDd0?Cdm065QH@2FUYH0Cdm?024Q8@1@D500AdM704U9B@1`L700>CTi02d]
;Acooooo00D0L71`075aL@1LG5`0?clo065QH@0205QHF01503@d=01fMWH0Hf=S03<c<`0l?3`0DU9B
07YjNP1JFUX0BDU905QHF01EEED0CDe=05IFEP0k>c/0ATI60492@P0o?cl0EUIF04Q8B019BDT0<30`
05=CD`1hN7P0G5aL03Ti>@1GEeL0IFEU05EEE@1@D500G5aL06e]K@1NGUh0>3Ph04i>CP0n?Sh0?Cdm
04M7A`14A4@0DE5A0451@@0[:b/0E5AD05EEE@0N7Qh0=CDe05]KF`19BDT0;Rh^02/[:`12@T80C4a<
0410@011@D40=3@d04a<C01FEUH0H61P04Q8B01EEED0Bd];03lo?`1:BTX0DE5A051@D01YJFT0CTi>
05IFEP11@D40GUiN00<0=cLg0P13@d<04`17AdL0?Shn03Hf=P0o?cl0;bl_03<c<`0f=SH0=CDe03Lg
=`0b<S80@D510492@P18B4P0ATI604A4A00e=CD0A4A404e=C@0l?3`00P18B4P09@1JFUX0Cdm?04U9
B@1CDe<0GEeM05MGE`1LG5`0@41004Y:BP1SHf<0FUYJ04M7A`1kNg/0DU9B05=CD`1?Cdl0<S8b05EE
E@0c<c<0>SXj03hn?P11@D40AdM706QXJ013@d<0JVYZ0:2PX01hN7P0BTY:06EUI@1TI6@0Ph>307Ad
M01`L700Kfm_069RHP1eMGD00P1CDe<01@1XJ6P0JFUY04i>CP1RHV80B4Q80080ATI601d0DU9B05AD
E01/K6`0FEUI05aLG00g=cL0C4a<0451@@1WIfL0MGEe030`<01;Bd/0?clo05ADE01QHF40AdM70492
@P18B4P0?3`l061PH00b<S80F5QH04i>CP1NGUh0ADE504a<C019BDT0<S8b059BDP0205=CD`0l03hn
?P19BDT0;2`/04Q8B00b<S80IFEU04E5A@1ADE40KVi^03Lg=`1:BTX0ADE505mOG`1TI6@0?Cdm08b<
S019BDT0HF5Q079bLP1:BTX0IFEU051@D01[Jf/0@d=306UYJ@1BDU80F5QH04a<C01^KVh0>SXj07If
MP1QHF40<S8b0451@@1eMGD0>c/k04e=C@1KFe/0IFEU05]KF`1FEUH0DE5A05IFEP12@T80ADE504M7
A`1DE5@0Cdm?055AD@1^KVh0EeMG059BDP1dM7@0Bd];07UiN@1LG5`0MWIf05eMG@1ADE40BTY:0P1;
Bd/0801RHV80KFe]05ADE01<C4`0Fe]K05aLG00^;Rh0?3`l05mOG`1DE5@0>CTi06ATI01NGUh0Cdm?
06MWI`1<C4`0H61P07alO01JFUX0LW9b06=SH`1VIVH0QhN704Q8B01QHF40MGEe08j>SP1@D500KVi^
05UIF@1TI6@0KVi^0P0h>3P03`10@400D51@03Xj>P1CDe<0B4Q80::RXP13@d<0H61P07UiN@1JFUX0
GEeM06=SH`1MGEd0JFUY07emO@0Aooooo`003oooool04@1JFUX0I6AT05]KF`2?Shl0F5QH05UIF@1Z
JVX0IfMW0;Rh^01RHV80<S8b07AdM01WIfL0De=C079bLP0U9BD0<30`0080P8200:`0LG5a06][J`0Q
8B40820P061PH01/K6`0KVi^03<c<`14A4@0@D5104a<C00n?Sh0E5AD06i^KP0X:2P0;bl_05ADE00m
?Cd0Cdm?05aLG00U9BD0;bl_04I6AP1MGEd0BDU90451@@0[:b/0BDU906MWI`1<C4`0ATI6069RHP0S
8b<0:RXZ06=SH`0E5AD0>3Ph03Ti>@0b<S80LW9b0;Fe]@0X:2P07QhN0492@P0g=cL0WIfM0:NWY`0C
4a<0;bl_03Hf=P19BDT0@D51092@T013@d<0EeMG07=cL`12@T80A4A409JFUP1IFET04Q8B04I6AP1[
Jf/0GEeM0;2`/018B4P0>3Ph05UIF@1LG5`0@T9205EEE@1GEeL08R8R03/k>`1XJ6P0?clo06=SH`1Z
JVX06a/K04A4A01JFUX0H61P03dm?@0O7al0;Rh^05iNGP1HF5P0?Cdm038b<P1@D5009RHV02@T901j
NWX092@T02/[:`19BDT0DU9B03<c<`2OWil0TY:B02<S8`1<C4`0IFEU03Ti>@21PH40Kfm_01DE5@0h
>3P0DU9B04];B`14A4@0G5aL01XJ6P1FEUH0IVIV04Y:BP10@400R8R803Ph>00S8b<0E5AD06][J`1d
M7@0I6AT02TY:@0a<C40EeMG07=cL`0U9BD0@d=3030`<01XJ6P0WinO03Hf=P0T92@0?3`l04E5A@0_
;bl0QHF507AdM00R8R80@d=306UYJ@1EEED0JFUY071`L00E5AD0BTY:051@D024Q8@0KVi^07EeM@0K
6a/0Bd];08>3P`13@d<0J6QX09>CT`1:BTX0=CDe09RHV022PX80EEEE065QH@0V9RH0:RXZ04M7A`1Y
JFT0IFEU05=CD`0T92@0?3`l0P1IFET0H@1RHV80J6QX02TY:@0h>3P0JFUY03Hf=P1kNg/0ATI603hn
?P1NGUh0IFEU02<S8`17AdL0@D5106YZJP2ATI405aLG0451@@1IFET0Fe]K06IVIP2BTY809BDU02TY
:@1RHV80GemO07emO@0S8b<0;Bd]06i^KP1RHV80?Cdm079bLP0i>CT0=3@d07inOP14A4@0I6AT07Mg
M`0V9RH0;bl_07IfMP2HV9P0Jf][069RHP1EEED0DE5A05eMG@23Ph<0CDe=0;bl_00`<300@T9205MG
E`1KFe/0IFEU07MgM`0b<S80?3`l04Q8B01KFe/0G5aL051@D01BDU80;Rh^07emO@2:RXX0BTY:051@
D01QHF40=CDe03@d=01VIVH0<C4a03Ph>00i>CT08R8R05IFEP2TY:@0GUiN01lO7`11@D40>c/k065Q
H@2ATI40?Cdm02<S8`0R8R80=SHf05eMG@1;Bd/0Shn?03dm?@1<C4`0CDe=05]KF`1?Cdl07?ooool0
9`1CDe<0GEeM05UIF@12@T80?3`l04m?C`1;Bd/05aLG07YjNP1@D5009bLW04a<C01UIFD0UiNG07Yj
NP1QHF40Jf][05=CD`1<C4`0Hf=S02`/;00m?Cd0:b/[03<c<`1LG5`0=cLg04];B`12@T80EeMG06QX
J01WIfL0=cLg05aLG01_Kfl0H61P08>3P`1fMWH0E5AD05aLG00202TY:@0`020P800`<300Bd];03Ph
>019BDT0A4A403Ph>017AdL0J6QX030`<00Z:RX0I6AT03hn?P0X:2P07alO04m?C`14A4@0>SXj03Lg
=`0Z:RX0DE5A0451@@1BDU80A4A403Lg=`1EEED0?Shn05ADE01:BTX09BDU05IFEP0e=CD0FEUI059B
DP1>CTh08R8R01lO7`0g=cL0CDe=04U9B@15ADD0=SHf03hn?P0g=cL0;2`/04U9B@11@D40=CDe0P12
@T803P16ATH0C4a<05YJFP1;Bd/0>CTi03@d=01IFET0H61P03Ti>@1ADE40F5QH04a<C01CDe<0E5AD
0P16ATH0801PH600O7al04Q8B016ATH0CTi>05IFEP1OGel0Ph>306UYJ@1`L700=SHf055AD@18B4P0
=CDe03Ph>00l?3`0:RXZ03De=@15ADD0>SXj04U9B@1BDU80Hf=S06ATI01]KFd0I6AT07emO@1XJ6P0
Jf][05EEE@0j>SX0DU9B0P12@T80G015ADD0DE5A03Xj>P17AdL0:BTY02d];@13@d<0GUiN0492@P1c
Lg<0@d=3055AD@1BDU80De=C03<c<`0K6a/0=SHf02LW9`14A4@0?3`l075aL@2JVYX0DE5A04M7A`1A
DE40A4A4079bLP0P8200EeMG055AD@1nOWh0G5aL04=3@`17AdL0>c/k08J6QP1UIFD0F5QH04m?C`1W
IfL0;Rh^03Ti>@0m?Cd0P820061PH00[:b/0;2`/03Hf=P1EEED0?Shn02DU9@0o?cl0BTY:0;>c/`26
QXH08B4Q02l_;`0n?Sh0P82002LW9`11@D40;bl_0:VYZ@1:BTX0:2PX03<c<`2?Shl0=SHf0410@012
@T80<30`03dm?@1[Jf/0;Bd]05EEE@1BDU80Hf=S04i>CP1jNWX0B4Q803lo?`17AdL0CTi>03Hf=P1:
BTX0V9RH05IFEP15ADD0A4A404m?C`2RXZ808B4Q0P0n?Sh08P1iNGT0F5QH03De=@1>CTh0E5AD04Y:
BP0o?cl0De=C05]KF`13@d<0GUiN06QXJ01JFUX0F5QH05ADE01EEED0:RXZ051@D01GEeL0>CTi05QH
F01EEED0>CTi03Lg=`0i>CT0?3`l04A4A01iNGT0QXJ60492@P0o?cl0<30`03Ph>019BDT2061PH00C
03Hf=P17AdL0@D5104M7A`0f=SH0<c<c030`<010@4009bLW04A4A01LG5`0M7Ad0451@@1QHF40O7al
05=CD`1_Kfl0Ng]k08^;R`0Aooooo`003oooool0o`2?Shl0TI6A04m?C`1fMWH0JFUY07UiN@12@T80
EEEE08B4Q02>SXh0Fe]K065QH@0k>c/0ATI609BDU01EEED0JFUY05ADE010@400GEeM0:VYZ@1OGel0
@d=30410@011@D40QhN708:2PP0i>CT0DE5A04E5A@16ATH0GemO07moO`0g=cL0CDe=03dm?@0h>3P0
I6AT09:BTP0Y:BT0;Bd]04e=C@1ADE40Kfm_07YjNP0C4a<0<C4a05eMG@15ADD0Cdm?061PH00j>SX0
7AdM05mOG`0j>SX0QHF503Lg=`0N7Qh0:2PX06EUI@0d=3@0:b/[04E5A@0U9BD0C4a<08B4Q00_;bl0
=3@d06EUI@0W9bL051@D04i>CP1DE5@07alO03De=@0K6a/05ADE05iNGP1PH6006QXJ03Lg=`12@T80
@d=304];B`1DE5@06a/K04Y:BP1ADE40<c<c079bLP2XZ:P0;Rh^03Xj>P15ADD0@d=308Z:RP2?Shl0
71`L02h^;P0o?cl0Cdm?07YjNP0a<C40820P030`<01RHV80FEUI05aLG01gMgL0:b/[02DU9@1HF5P0
A4A403Lg=`1UIFD06a/K03hn?P13@d<0OGem06YZJP1QHF40;2`/02TY:@18B4P0Rh^;05YJFP0i>CT0
M7Ad034a<@0f=SH0OGem02TY:@0f=SH0I6AT0451@@1>CTh0[jn_05mOG`0a<C40=cLg04Y:BP2EUID0
U9BD034a<@0E5AD0@T920820P00j>SX0LG5a04i>CP0O7al0Cdm?05mOG`1JFUX0Ng]k02XZ:P0^;Rh0
?Shn075aL@1SHf<0Ogmo03`l?00e=CD0EUIF059BDP0d=3@0=SHf05IFEP0Q8B40CDe=092@T00j>SX0
?clo04Q8B00T92@0BDU906][J`29RHT09bLW04E5A@0l?3`0B4Q807MgM`18B4P0:BTY03lo?`0Q8B40
OWin096AT@0U9BD0CTi>0451@@1EEED0Kfm_09:BTP0U9BD0>SXj05=CD`1>CTh0YjNW05eMG@0P8200
DE5A05]KF`0k>c/0PX:203hn?P0d=3@0SXj>04Y:BP22PX80GEeM02@T901DE5@0LW9b04m?C`0h>3P0
EUIF05EEE@1jNWX0GEeM02d];@14A4@0=SHf04];B`1hN7P0GUiN04I6AP0n?Sh0AdM705mOG`2OWil0
Cdm?03Hf=P1CDe<0C4a<08J6QP2/[:`0Cdm?06MWI`1JFUX0DE5A059BDP2OWil0OGem03@d=018B4P0
BTY:07EeM@2c/k<0IVIV02l_;`19BDT0EEEE04i>CP008`1eMGD0TI6A02`/;011@D40IFEU04e=C@1m
OGd0V9RH02l_;`0h>3P0IVIV07=cL`24Q8@0KVi^024Q8@0a<C40EUIF08f=S@1/K6`0Ti>C06EUI@0]
;Bd0DE5A0861P@13@d<0Kfm_05UIF@0h>3P09bLW05]KF`1DE5@0@4100492@P0];Bd0=cLg01cooooo
01@0G5aL079bLP1?Cdl0;Bd]055AD@1@D500Cdm?01hN7P1_Kfl0IFEU03/k>`1RHV80JFUY09RHV01i
NGT0JVYZ05iNGP1DE5@0Bd];05QHF080B4Q806H0@d=304U9B@1PH600=CDe05ADE00Y:BT0Cdm?04a<
C01JFUX0Cdm?055AD@1NGUh0EeMG05]KF`1FEUH0DU9B05iNGP14A4@0@T9202h^;P0b<S80F5QH04i>
CP1LG5`0B4Q803Ph>01;Bd/0Jf][01XJ6P0a<C40IVIV0410@00X:2P0=CDe04E5A@17AdL0@41003Hf
=P0U9BD0EUIF05ADE01XJ6P0IFEU05iNGP1bLW80@D5106a/K01VIVH0AdM708:2PP1=CDd0JFUY0451
@@1jNWX0@D5103Ph>01>CTh0>3Ph03dm?@1EEED0?Shn0492@P0o?cl0>SXj0410@01;Bd/0=SHf05QH
F00k>c/0>CTi05IFEP1EEED0GEeM04Y:BP16ATH0?3`l05]KF`0a<C40DU9B04a<C018B4P0GEeM0451
@@1>CTh0Cdm?051@D01<C4`0EEEE04i>CP1]KFd0GEeM04U9B@1XJ6P0KVi^07AdM00h>3P08R8R03dm
?@12@T80<S8b03`l?01<C4`204e=C@2T05MGE`27QhL0]kNg09FEU@11@D40Hf=S06i^KP2JVYX0NWYj
04Y:BP1cLg<0NGUi07emO@1nOWh0Cdm?05aLG021PH40>c/k055AD@12@T80A4A404I6AP1LG5`0ATI6
06QXJ01>CTh0EeMG034a<@1@D500BDU902LW9`0m?Cd0CTi>079bLP0o?cl0>CTi03Lg=`0a<C40BDU9
04Y:BP0Z:RX0AdM701dM7@13@d<07AdM03@d=00[:b/0AdM70492@P0J6QX0A4A404i>CP1EEED0<S8b
03dm?@15ADD0BDU903hn?P14A4@0C4a<05ADE01QHF40>c/k069RHP1:BTX0ADE504m?C`0g=cL0QXJ6
05iNGP1DE5@0GEeM03Xj>P1@D500?Cdm055AD@16ATH0BDU904=3@`0m?Cd0;Bd]05UIF@0X:2P0GEeM
04i>CP0R8R80B4Q807AdM00i>CT0AdM704I6AP1EEED0BTY:03Lg=`10@400B4Q802@T900d=3@0A4A4
04e=C@0e=CD0DU9B06YZJP1?Cdl0:2PX04Q8B01EEED0G5aL04=3@`18B4P0ADE503Xj>P11@D40B4Q8
06IVIP14A4@0H61P07EeM@1DE5@0JVYZ05iNGP0d=3@09RHV03<c<`0j>SX0;bl_0820P01gMgL0EEEE
06i^KP10@400;Rh^05UIF@0a<C40E5AD04=3@`0e=CD0AdM702TY:@19BDT0>SXj06UYJ@1[Jf/0[Jf]
07QhN01?Cdl0FUYJ03<c<`0l?3`0@T9204U9B@17AdL0Lg=c04m?C`21PH40;bl_05IFEP1RHV80HF5Q
04Y:BP1SHf<0NWYj07=cL`1TI6@Aooooo`003oooool0>P1TI6@0[jn_071`L01LG5`0OWin09bLW01>
CTh0<C4a05iNGP1KFe/0K6a/0;Ng]`13@d<0>SXj05=CD`1;Bd/0PX:207=cL`0_;bl0@41007UiN@1S
Hf<0Jf][08B4Q00b<S80JVYZ0;Bd]01`L700Y:BT03lo?`0I6AT0@D5107IfMP1;Bd/0`L7104i>CP0V
9RH0;Bd]0451@@1>CTh0ATI6069RHP0K6a/0?clo05aLG00o?cl0F5QH03`l?00F5QH0<30`06][J`0o
?cl0A4A404Q8B011@D40A4A40492@P0H61P203De=@3V04=3@`16ATH0Jf][01TI6@0U9BD0ATI604Y:
BP1DE5@0WinO03De=@0I6AT09bLW04i>CP1YJFT0OGem01dM7@0W9bL0<c<c07QhN00d=3@0MgMg07Ee
M@0W9bL0>CTi04e=C@0T92@0PX:20451@@0U9BD0AdM705aLG00j>SX0JVYZ02<S8`0H61P0DU9B06YZ
JP0m?Cd0>SXj05IFEP0O7al0=cLg059BDP0c<c<0E5AD03dm?@0X:2P0@T92075aL@0[:b/06a/K0410
@01<C4`0B4Q808>3P`0S8b<07QhN02XZ:P0m?Cd0ATI609:BTP0W9bL07AdM02/[:`17AdL0?clo07Mg
M`2n_[h0;Rh^04A4A01VIVH0JFUY08J6QP1mOGd07alO04A4A01BDU80EEEE079bLP2JVYX0>SXj04E5
A@1^KVh0EeMG03dm?@1bLW80I6AT02`/;01@D500Kfm_030`<01?Cdl08R8R0410@019BDT0IVIV024Q
8@15ADD0@D5103Hf=P2OWil0NWYj02h^;P14A4@0DU9B04a<C01PH600UYJF03<c<`0/;2`0L71`05aL
G01nOWh0HV9R01dM7@0Y:BT0ATI606e]K@1YJFT0WYjN01dM7@1GEeL0MGEe055AD@12@T80QXJ602/[
:`0S8b<0MgMg04];B`1DE5@0=CDe03Lg=`1VIVH0PH6104i>CP1[Jf/0Ogmo030`<01YJFT0NWYj04a<
C01=CDd0G5aL02XZ:P1PH600Rh^;05EEE@0g=cL0<30`069RHP2BTY809bLW04I6AP1RHV80?Cdm05aL
G01SHf<0:BTY06e]K@1VIVH0GemO09nOW`0o?cl071`L05iNGP1]KFd0LW9b07alO00_;bl0ADE5096A
T@21PH40IFEU08>3P`0c<c<0D51@0:f][@1WIfL0XZ:R08^;R`0k>c/0M7Ad096AT@2>SXh0Fe]K06UY
J@0T92@0@41007alO02EUID0EEEE05mOG`1LG5`0820P04I6AP20P800DU9B05]KF`0g=cL0:RXZ06a/
K01eMGD0EeMG03Ti>@1=CDd08b<S06i^KP1mOGd0DU9B03De=@1WIfL0=CDe02PX:01fMWH0KFe]030`
<01FEUH0<c<c034a<@1TI6@0QhN702TY:@0/;2`0BTY:04Q8B022PX80XJ6Q02XZ:P0a<C4Looooo`1J
05mOG`1_Kfl0Bd];03`l?01EEED0B4Q8065QH@0n?Sh0JVYZ07=cL`0_;bl0AdM704a<C02DU9@0GEeM
04I6AP1?Cdl0H61P05UIF@1>CTh0>CTi04I6AP0_;bl0;Rh^051@D01DE5@0CTi>03De=@1=CDd0LW9b
04];B`0a<C40DU9B05MGE`1_Kfl0IFEU05eMG@1_Kfl0G5aL03De=@0m?Cd0ATI605YJFP1QHF40Cdm?
05aLG01DE5@0Bd];04i>CP1QHF40:BTY04e=C@1DE5@0CDe=02<S8`0O7al0:BTY030`<00i>CT0CDe=
03Ti>@1GEeL0F5QH04I6AP1HF5P0GUiN07EeM@13@d<0J6QX06UYJ@19BDT0Ph>306=SH`1GEeL0A4A4
07MgM`1EEED0ADE50410@00b<S80?3`l061PH01;Bd/0@D510492@P0g=cL0AdM704];B`13@d<0FUYJ
0P11@D40aP1?Cdl0CDe=05YJFP1CDe<0CDe=0492@P1SHf<0>CTi05QHF01JFUX0ADE5061PH01ADE40
H61P059BDP1MGEd0GemO06i^KP1>CTh0E5AD06EUI@1ADE40OWin04i>CP1fMWH0IVIV03Lg=`1CDe<0
BDU904m?C`15ADD0ATI605MGE`1;Bd/0D51@07QhN01ZJVX0IfMW03hn?P1TI6@0QhN7092@T01VIVH0
Fe]K05IFEP17AdL0EUIF051@D01DE5@0@T9206EUI@1;Bd/0AdM70492@P0m?Cd0>SXj05iNGP1?Cdl0
JFUY03`l?01UIFD0?3`l055AD@0i>CT0=cLg05MGE`0O7al0<S8b05YJFP1FEUH0FUYJ04];B`10@400
Bd];03`l?01;Bd/09RHV04e=C@0a<C40Cdm?03hn?P12@T80Cdm?02<S8`1JFUX0KFe]0820P00d=3@0
CTi>04E5A@1LG5`0ADE507=cL`1RHV80DE5A065QH@0Z:RX0BDU903Ti>@1IFET0CTi>02l_;`1CDe<0
LW9b06QXJ01lO7`0?3`l051@D011@D40IfMW03`l?01aLG40HF5Q04m?C`0m?Cd0L71`02LW9`1_Kfl0
Jf][03De=@0/;2`0EEEE03Ph>01/K6`0DE5A06YZJP1LG5`0Cdm?0492@P1XJ6P0<30`02l_;`0b<S80
A4A405IFEP17AdL0];Bd05ADE00l?3`0NWYj04Y:BP1QHF40CDe=0820P01RHV80LW9b04];B`11@D40
E5AD05QHF01PH600EeMG03Xj>P1LG5`0GEeM05MGE`0h>3P0Cdm?04a<C00b<S80EEEE059BDP1CDe<0
FUYJ06m_K`11@D40IfMW0451@@2<S8`0Bd];05IFEP1iNGT0;Bd]06IVIP1RHV80N7Qh0451@@1YJFT0
GEeM04Y:BP1KFe/0>3Ph0410@00m?Cd0Bd];03<c<`1:BTX0ADE508f=S@18B4P0D51@079bLP1HF5P0
EUIF05EEE@1GEeL0FEUI08N7Qa7ooooo000?ooooo`0P05=CD`21PH40P82009JFUP1=CDd0IfMW09^K
V`2BTY80];Bd05=CD`1;Bd/0LW9b06YZJP1?Cdl0HV9R03Ph>01TI6@0O7al05iNGP1eMGD0RHV902XZ
:P1FEUH0QXJ604a<C01]KFd0>3Ph04U9B@2HV9P0Hf=S01hN7P0d=3@203`l?03o08j>SP1oOgl0:BTY
03<c<`15ADD0D51@065QH@2EUID0@41003hn?P19BDT0@d=307MgM`1bLW805QHF02HV9P13@d<0=CDe
06MWI`1_Kfl0;Bd]03lo?`1SHf<0A4A407EeM@1?Cdl08b<S02/[:`1GEeL0AdM706UYJ@1DE5@06ATI
03@d=01ZJVX0MgMg03Lg=`1NGUh092@T04E5A@1RHV80>SXj02HV9P1MGEd07QhN024Q8@1MGEd0QHF5
030`<01>CTh0:RXZ03`l?01SHf<0IfMW02XZ:P0_;bl0Bd];04A4A01hN7P0IFEU01HF5P0H61P0ADE5
04I6AP1DE5@0MgMg02/[:`0j>SX0GEeM05=CD`25QHD0OGem01dM7@0K6a/0Cdm?04U9B@14A4@0Ph>3
0451@@0m?Cd0G5aL08N7Q`18B4P0OGem059BDP0k>c/0Fe]K07YjNP18B4P0K6a/05mOG`0G5aL0=SHf
06i^KP1KFe/0;Bd]051@D00I6AT0De=C09RHV00a<C40;Rh^07AdM01GEeL0?Shn06m_K`1@D500:BTY
05]KF`0j>SX0@D5108j>SP1TI6@09RHV03De=@1VIVH0Kfm_09NGU`0];Bd0>CTi04I6AP1WIfL0?Cdm
07EeM@1hN7P0:BTY061PH01hN7P0GUiN0820P01/K6`09bLW02l_;`1OGel0Lg=c05EEE@0k>c/07AdM
05iNGP2;Rh/0FEUI034a<@22PX80?clo03Xj>P1dM7@0HF5Q030`<01cLg<0<S8b02h^;P1OGel0DE5A
03De=@10@400@d=308N7Q`1WIfL07alO055AD@1LG5`0@41006YZJP2f][H0;bl_07MgM`1SHf<0TY:B
0;:b/P1IFET08R8R038b<P1VIVH0SXj>05iNGP0a<C40De=C06UYJ@1UIFD0PH610:BTY00_;bl0FEUI
06i^KP1<C4`0J6QX028R8P13@d<0TI6A079bLP0k>c/0EUIF034a<@16ATH0QXJ602TY:@1IFET0CDe=
02XZ:P1MGEd0L71`05MGE`15ADD0Bd];04M7A`1FEUH0Kfm_04U9B@0i>CT0GEeM03hn?P1@D500P820
02XZ:P0^;Rh0@D51065QH@1aLG40QXJ60820P00U9BD0820P04i>CP1?Cdl0LW9b05IFEP0G5aL0Bd];
05mOG`1KFe/0D51@08b<S00J6QX0A4A406=SH`1YJFT0De=C08f=S@0c<c<05aLG04=3@`1PH600Hf=S
0:BTY019BDT09BDU03Ti>@1QHF40FEUI04=3@`25QHD0:RXZ03lo?`1>CTh0=cLg00409RHV7?ooool0
l@1cLg<0Ng]k06m_K`1CDe<0IFEU04e=C@1WIfL08b<S04Q8B01EEED0;Rh^051@D021PH40M7Ad06a/
K02EUID0HV9R04I6AP14A4@0Fe]K04m?C`0i>CT0<30`059BDP1MGEd0@d=304i>CP0k>c/0@4100451
@@1HF5P0E5AD0492@P14A4@0F5QH06IVIP1`L700EEEE05]KF`0n?Sh0;bl_02<S8`0f=SH0@D5105AD
E01KFe/0@T9203@d=01NGUh0De=C03Ph>01?Cdl0BDU903Lg=`0Z:RX0Cdm?04e=C@1DE5@0C4a<03<c
<`0S8b<0?clo05ADE01IFET0EUIF059BDP1WIfL0CTi>065QH@1<C4`0@d=305aLG00i>CT0@T920410
@022PX80>SXj03Ph>01;Bd/0@D5104E5A@1:BTX0=cLg03/k>`13@d<0?clo04A4A011@D40?3`l04I6
AP15ADD0;Rh^04Y:BP14A4@0Bd];03De=@12@T80@41004];B`1@D500FEUI05MGE`1OGel0De=C04a<
C01JFUX0GUiN05]KF`1JFUX0De=C04a<C01GEeL0N7Qh04U9B@1iNGT0IfMW08:2PP1`L700@41004];
B`1IFET0DE5A04I6AP19BDT0GUiN04M7A`1<C4`0S8b<0:2PX027QhL0?3`l075aL@27QhL0WIfM09VI
V@2WYjL0Ogmo06YZJP1KFe/0>CTi04Y:BP1=CDd0Bd];02XZ:P0k>c/0:RXZ03Lg=`11@D40Bd];05YJ
FP1MGEd0A4A405IFEP1CDe<0EUIF03Xj>P15ADD0EeMG02`/;00i>CT0CDe=05=CD`1jNWX0DE5A05AD
E01HF5P0>c/k059BDP0U9BD0Fe]K02TY:@10@400;2`/0492@P13@d<0@D5105iNGP1DE5@0DE5A04Y:
BP1IFET0E5AD06=SH`1LG5`0QhN707UiN@1UIFD0T92@02DU9@1CDe<0@D5107YjNP1SHf<0>c/k09:B
TP1nOWh0B4Q8055AD@0g=cL0IVIV04U9B@1CDe<0?3`l07]kN`0k>c/0R8R803`l?01mOGd0BTY:079b
LP1oOgl07alO02XZ:P1NGUh08B4Q04I6AP19BDT0JFUY061PH01<C4`0Bd];05eMG@0j>SX0=3@d04];
B`1MGEd0Bd];0492@P1ADE40;bl_055AD@2RXZ80AdM708V9R@14A4@0N7Qh04];B`0o?cl0Bd];03/k
>`1PH6000P0o?cl0101ZJVX0EEEE04E5A@15ADD203Lg=`0704M7A`1;Bd/0>c/k06i^KP1HF5P0>c/k
06IVIP0205=CD`0P0820P01JFUX0B4Q805IFEP1;Bd/0Ph>306QXJ01aLG40KFe]09jNWP17AdL0];Bd
079bLP16ATH0AdM702TY:@10@400=SHf03hn?P0o?cl0EeMG030`<01@D500@D5105iNGP1CDe<0GEeM
06i^KP1?Cdl0Kfm_06][J`1iNGTAooooo`003oooool0?01^KVh0L71`04Q8B01`L700HV9R061PH00m
?Cd0EEEE0:>SX`1KFe/0?Cdm04m?C`0m?Cd0?3`l06][J`0T92@0?Cdm05IFEP0a<C40K6a/0:FUY@12
@T807alO05=CD`1QHF40SXj>02XZ:P0c<c<0ATI606EUI@1fMWH0SXj>05ADE00e=CD0D51@075aL@1N
GUh0JVYZ06a/K00Y:BT0>SXj071`L01VIVH0EeMG03/k>`0Y:BT0?clo092@T01ADE40AdM705MGE`0M
7Ad0>CTi06QXJ00[:b/0JFUY04=3@`0T92@0OWin08>3P`80;Rh^0>@0>c/k02TY:@1gMgL0QXJ601PH
600P8200?Shn03<c<`28R8P0UIFE02LW9`0/;2`0?clo02l_;`1=CDd0[:b/03Ph>00O7al0B4Q804E5
A@1DE5@0S8b<02d];@0P8200KFe]08:2PP1GEeL0Kfm_07]kN`0V9RH0JVYZ0:f][@1bLW80M7Ad03dm
?@0O7al0ATI607AdM01mOGd0Fe]K01`L700a<C40FEUI08n?S`1?Cdl0=cLg06UYJ@0R8R806a/K05iN
GP0S8b<0;Rh^04i>CP0b<S80=CDe061PH01QHF40:b/[03lo?`1:BTX0>CTi0:2PX01kNg/0:BTY02d]
;@1PH600GUiN061PH01_Kfl07QhN03Xj>P28R8P0IFEU03dm?@26QXH0@T9202`/;018B4P0F5QH0820
P02=SHd0=cLg02DU9@1fMWH0aLG503/k>`1LG5`0B4Q8030`<01MGEd0Kfm_03/k>`1jNWX0<C4a02`/
;019BDT0HV9R0451@@1nOWh07AdM04A4A01/K6`0M7Ad02XZ:P0_;bl0?Shn05ADE020P800A4A401dM
7@0^;Rh0G5aL08J6QP1SHf<0ZZZZ04m?C`0f=SH0ADE507IfMP1JFUX0ZZZZ02`/;00];Bd0Jf][061P
H01MGEd0GemO01TI6@1=CDd0KVi^02`/;01XJ6P0DU9B02HV9P0m?Cd0NWYj04U9B@2NWYh0<S8b02TY
:@1_Kfl0[Zj^04m?C`1OGel0;Bd]05YJFP1lO7`0?Cdm05UIF@1WIfL08B4Q06=SH`2WYjL0De=C0492
@P1CDe<0?clo09FEU@1>CTh0:b/[04e=C@1>CTh0EUIF06i^KP1:BTX0<S8b04m?C`19BDT0[:b/09jN
WP0];Bd0ADE506m_K`1UIFD0QHF5075aL@0/;2`0@41006UYJ@1HF5P0M7Ad0;>c/`1LG5`0>3Ph05QH
F00n?Sh0FEUI06EUI@0];Bd0<C4a05IFEP1jNWX0J6QX059BDP1QHF40E5AD071`L01bLW80<C4a04e=
C@1WIfL09BDU03`l?02ATI40K6a/061PH01SHf<0:BTY03Ph>02?Shl0I6AT030`<00m?Cd0?clo03dm
?@1KFe/0GemO01`L700b<S80A4A402LW9`1IFET0YjNW02`/;012@T80ADE503Lg=`1JFUXLooooo`0?
06=SH`1NGUh0H61P04U9B@0j>SX0DU9B04a<C00`<300GemO06UYJ@0l?3`0Lg=c08>3P`2i^KT0Jf][
0080FUYJ00<0JVYZ05EEE@1XJ6P00P0h>3P0>@0f=SH0BTY:05eMG@0g=cL0De=C04a<C01EEED0G5aL
05IFEP0e=CD0BTY:065QH@20P800L71`0820P01RHV80Jf][05EEE@0i>CT0:BTY05=CD`1SHf<0@T92
05]KF`1BDU80<30`03De=@1CDe<08B4Q02d];@1NGUh0@41001<C4`0V9RH0?Cdm03Xj>P0X:2P0>3Ph
030`<013@d<0?3`l02`/;00f=SH0@41004E5A@0_;bl0AdM705EEE@18B4P0KFe]04Q8B01QHF40H61P
08>3P`17AdL0?Cdm03hn?P0203/k>`0Y03`l?00h>3P0<30`03Ph>00/;2`0?3`l03/k>`0e=CD0ATI6
02XZ:P0k>c/0@410030`<01<C4`0@D5103Ti>@0h>3P0BTY:02d];@14A4@0?3`l03/k>`14A4@0EEEE
04M7A`0o?cl0GUiN06i^KP1CDe<0F5QH05IFEP1ZJVX0AdM706=SH`1UIFD0P820075aL@1IFET0DU9B
04M7A`1FEUH00P16ATH0201QHF40F5QH061PH01gMgL0S8b<08>3P`1ADE40HV9R0P24Q8@0W01?Cdl0
;Bd]05iNGP1dM7@0EEEE092@T01MGEd0CTi>06QXJ00k>c/0B4Q803@d=00c<c<0De=C05EEE@16ATH0
BTY:03De=@1LG5`0@d=304a<C00^;Rh0BTY:05IFEP0J6QX0ATI604A4A00`<300CTi>04M7A`18B4P0
CDe=03@d=01@D5006ATI04A4A00W9bL0BDU902TY:@0j>SX0A4A402PX:00g=cL0De=C06EUI@0a<C40
C4a<0410@01ADE40ADE5079bLP1SHf<0ATI605UIF@0e=CD0F5QH04e=C@1aLG40MGEe02<S8`1DE5@0
DE5A06a/K02JVYX07alO04i>CP0^;Rh0HF5Q03Hf=P1KFe/0?clo06ATI00L71`0PH6101dM7@1>CTh0
Cdm?01XJ6P0Z:RX0GUiN02PX:01ZJVX0F5QH055AD@1CDe<0ADE503Ti>@13@d<0<30`02TY:@0[:b/0
BTY:055AD@17AdL0TY:B06=SH`0W9bL0DU9B05eMG@1aLG40C4a<05IFEP1<C4`0Hf=S0410@00Z:RX0
=cLg03Ti>@0[:b/0AdM7034a<@15ADD0AdM7051@D00/;2`0FEUI061PH00n?Sh0JVYZ05ADE00e=CD0
IFEU0451@@0[:b/0EEEE04M7A`1oOgl0GemO05EEE@2CTi<0@T9204A4A00l?3`0IfMW04=3@`1JFUX0
IVIV04=3@`1<C4`0;2`/0492@P0`<300>SXj02PX:016ATH0=SHf05=CD`0e=CD0ADE505IFEP1<C4`0
BDU905=CD`1dM7@0HF5Q071`L17ooooo000?ooooo`3o09VIV@2EUID0EEEE04m?C`1kNg/0[:b/03@d
=015ADD0NGUi06][J`1cLg<0[Zj^04];B`19BDT0Q8B404m?C`1[Jf/0G5aL04A4A013@d<0HF5Q061P
H01MGEd0GemO03Xj>P1=CDd0=SHf04m?C`1dM7@0=CDe02h^;P1JFUX0YJFU03<c<`1FEUH0>3Ph02h^
;P1EEED0D51@02<S8`0];Bd0Bd];03<c<`1LG5`0@d=302d];@0g=cL0@D5105=CD`1`L700Hf=S01TI
6@0d=3@0>CTi05IFEP2VYZH0FEUI01@D500j>SX0BDU904I6AP1ZJVX0FEUI03Lg=`0e=CD0I6AT05EE
E@1kNg/0YjNW01lO7`0/;2`0BTY:051@D01WIfL0DE5A01XJ6P0^;Rh0ATI606m_K`0R8R80Fe]K05iN
GP0i>CT0EUIF069RHP0^;Rh0HV9R02TY:@0`<300BTY:06][J`0P8200De=C02l_;`0c<c<0QHF505MG
E`0G5aL06ATI030`<01:BTX0G5aL03De=@0F5QH0A4A4065QH@1WIfL0P82009bLW00W9bL05aLG051@
D01FEUH0Lg=c07UiN@0G5aL0=cLg05=CD`1KFe/0A4A406MWI`0N7Qh0;Bd]06MWI`1gMgL0?clo05QH
F01fMWH05ADE04Y:BP1nOWh0;2`/051@D00S8b<0>3Ph059BDP1bLW80>CTi0451@@15ADD0<c<c05iN
GP2WYjL0@41001dM7@1GEeL0UYJF0451@@1lO7`0L71`04=3@`14A4@0ADE506MWI`2a/K40A4A401TI
6@1CDe<0KFe]05YJFP32`/80EUIF02<S8`1@D500Shn?06IVIP1JFUX0K6a/03@d=01>CTh0NWYj04U9
B@1CDe<0>c/k02/[:`1<C4`0Q8B409BDU01EEED0EUIF02`/;01>CTh0Q8B406i^KP0e=CD0CTi>02`/
;01DE5@0R8R80451@@14A4@0BTY:03<c<`2=SHd0MgMg020P800];Bd0EeMG04a<C02n_[h0BDU902LW
9`17AdL0FUYJ05UIF@2DU9@0De=C034a<@1^KVh0ADE507=cL`1VIVH07AdM0451@@29RHT0AdM707Mg
M`1GEeL08B4Q061PH01nOWh0F5QH0:RXZ00T92@0;Bd]04Q8B01IFET0EEEE04I6AP0j>SX0>CTi07al
O01:BTX0ATI606ATI00k>c/0E5AD0;no_`1KFe/0Ng]k07QhN00j>SX0=SHf07QhN02KVi/0CTi>04e=
C@0e=CD0RHV906a/K01SHf<0D51@05]KF`1BDU808B4Q000S04a<C01RHV80<C4a05aLG01FEUH0>SXj
07EeM@2e]KD0<C4a02TY:@0o?cl0=cLg09FEU@2j^[X0:BTY03Ti>@15ADD0E5AD06MWI`1nOWh0C4a<
020P800X:2P0B4Q803De=@1;Bd/0IfMW01hN7P0K6a/0EUIF03hn?P1EEED0FEUI024Q8@0T92@07?oo
ool06P1KFe/0KVi^04M7A`0`<300CDe=079bLP1ADE406QXJ06i^KP1nOWh0<30`04M7A`1CDe<0GUiN
05IFEP1WIfL0DE5A03lo?`18B4P0DU9B03De=@0];Bd0:RXZ0451@@1=CDd0BTY:0P1<C4`0F`0o?cl0
@T9204U9B@0n?Sh0ATI605=CD`1YJFT0GEeM04M7A`1HF5P0Hf=S04U9B@0g=cL0>3Ph03hn?P1CDe<0
L71`06e]K@1?Cdl0<S8b05eMG@1bLW80:b/[03`l?01YJFT0HF5Q028R8P0X:2P0ADE503dm?@0a<C40
@T9203Hf=P16ATH0A4A404Q8B014A4@0?Shn04m?C`19BDT0FUYJ04E5A@0c<c<0Fe]K06e]K@0i>CT0
;bl_04Y:BP10@400A4A403De=@0`<300>c/k0492@P18B4P0;Bd]04];B`0i>CT0:b/[04M7A`1=CDd0
BDU902PX:00g=cL0>c/k03Ti>@1BDU80CDe=03hn?P0i>CT0DE5A04m?C`1HF5P0CTi>06UYJ@1=CDd0
@d=305ADE01EEED0A4A403`l?010@400>SXj05=CD`1VIVH0JVYZ07]kN`1FEUH0JFUY04I6AP12@T80
0P15ADD05P19BDT0<c<c03/k>`17AdL0@D5103@d=01ADE40Q8B406m_K`1EEED0J6QX0861P@2@T900
QhN705eMG@1TI6@0H61P051@D02CTi<0Hf=S04U9B@1XJ6P304=3@`1:055AD@1;Bd/0AdM704i>CP1T
I6@0FUYJ06IVIP0l?3`0DE5A051@D01RHV80MgMg051@D00j>SX0FUYJ04Y:BP1UIFD0CDe=03`l?01>
CTh0@41005EEE@0N7Qh0C4a<03Ph>01bLW8051@D03Hf=P11@D407alO04U9B@1=CDd0Bd];03Ti>@1;
Bd/0ADE505ADE01:BTX0LW9b04a<C01:BTX0F5QH02LW9`16ATH0<C4a03@d=018B4P0<c<c06i^KP1=
CDd0@d=303hn?P0];Bd0N7Qh02LW9`1DE5@0820P069RHP0Z:RX0B4Q802TY:@1HF5P0>c/k08b<S02:
RXX0=3@d01/K6`1>CTh06ATI0492@P1CDe<0IFEU059BDP1IFET204e=C@0a03lo?`18B4P0?Shn05=C
D`1_Kfl0FEUI06=SH`1fMWH0De=C08J6QP1JFUX0GUiN04I6AP1^KVh0@T9203De=@0k>c/06ATI0451
@@0Z:RX0:b/[069RHP1CDe<0I6AT05mOG`17AdL0:2PX0451@@15ADD0?clo07IfMP1CDe<0HV9R07Ee
M@14A4@0DE5A05YJFP0h>3P0DU9B0492@P0`<300HF5Q05eMG@1QHF40F5QH07EeM@0g=cL0PH61071`
L00205IFEP0A030`<016ATH0?Shn04i>CP0h>3P0BTY:05ADE01mOGd0EUIF04a<C029RHT0Cdm?05=C
D`1IFET0I6AT05=CD`1TI6@04Oooool000oooooo0?l0FUYJ08j>SP1OGel0NGUi04Q8B027QhL0RXZ:
06YZJP2<S8`0@T9205=CD`1/K6`0BTY:03lo?`1BDU80H61P0:FUY@1NGUh0;bl_0451@@1GEeL0>SXj
06i^KP2IVIT0=3@d051@D00a<C40BDU908n?S`0];Bd0;2`/038b<P1GEeL0F5QH0820P00S8b<08R8R
03Hf=P28R8P0E5AD06a/K01iNGT0820P04A4A01WIfL0F5QH05aLG00a<C40820P04A4A01@D500>3Ph
04U9B@16ATH092@T04A4A01^KVh0:b/[04I6AP0i>CT0820P03/k>`1<C4`07QhN04e=C@0V9RH061PH
04M7A`2RXZ80Bd];024Q8@1ADE40;Bd]06][J`1nOWh0:RXZ028R8P1@D500B4Q802h^;P28R8P0Vi^K
02d];@1GEeL0BDU904E5A@2g]kL0OWin01@D500i>CT0MGEe04e=C@2UYJD0BTY:01`L700W9bL0K6a/
03/k>`1RHV80KVi^014A4@0n?Sh0C4a<028R8P1`L700Jf][01DE5@0c<c<0H61P069RHP0a<C40C4a<
024Q8@1`L700]KFe051@D00I6AT0?clo04Q8B00Z:RX0Q8B402l_;`0K6a/0<c<c06IVIP15ADD0JFUY
0;>c/`0X:2P08R8R071`L01kNg/0VYZJ02h^;P0V9RH0?3`l0861P@1XJ6P0LG5a0:VYZ@0c<c<0F5QH
06m_K`1CDe<0ATI607emO@0k>c/09RHV05MGE`21PH40EUIF05mOG`0K6a/0;bl_06QXJ02GUiL0=SHf
05EEE@1YJFT0>CTi0492@P1QHF40BDU905]KF`12@T80<C4a05=CD`1FEUH0:RXZ04];B`10@400Bd];
0;:b/P1eMGD07QhN03lo?`1DE5@0@d=3096AT@2ZZZX0820P03De=@1`L700CDe=05iNGP28R8P09BDU
01`L701CDe<0DE5A08B4Q00e=CD07QhN04I6AP2TY:@0H61P07UiN@1nOWh0?Shn05IFEP1GEeL0BDU9
06a/K00c<c<0B4Q8061PH01TI6@0B4Q804E5A@0S8b<0I6AT09fMW@0k>c/0G5aL0492@P0b<S80BDU9
07QhN014A4@0Cdm?02d];@0b<S80PH61069RHP0S8b<0CDe=03<c<`1hN7P0GUiN024Q8@1ADE40F5QH
055AD@2EUID0XJ6Q02h^;P0n?Sh0NGUi05iNGP2RXZ80WYjN03@d=00l?3`0=3@d061PH01RHV80VIVI
02TY:@0h>3P0Fe]K061PH01EEED0MGEe06e]K@0b<S8002409RHV06YZJP13@d<0HF5Q04I6AP0n?Sh0
>3Ph04m?C`1UIFD0@T9205iNGP0W9bL0@T92065QH@0k>c/0B4Q806EUI@0V9RH08R8R0861P@1kNg/0
:BTY05=CD`0`<3009bLW07]kN`2PX:00AdM703@d=016ATH0<30`07YjNP2JVYX00P0^;RhLooooo`1F
07IfMP1gMgL0Bd];02HV9P1EEED0De=C051@D00K6a/0F5QH05=CD`0_;bl0IVIV06i^KP1iNGT0Ng]k
08b<S01QHF40BDU904e=C@1[Jf/0<c<c02/[:`0Q8B40<S8b05aLG00a<C40DE5A02h^;P1EEED0B4Q8
059BDP0`<300CTi>05QHF027QhL0Hf=S079bLP1EEED0IVIV04=3@`0X:2P08B4Q03Ph>01IFET09bLW
03lo?`18B4P0>CTi03lo?`13@d<09bLW03hn?P1:BTX0?clo01hN7P0a<C40?Shn04m?C`1;Bd/0;bl_
020P801GEeL0KVi^04Q8B01;Bd/0FUYJ05QHF00l?3`0EeMG055AD@19BDT0K6a/04A4A01DE5@0Cdm?
06][J`0d=3@0?Shn04e=C@1/K6`0GEeM04Y:BP11@D409bLW03Hf=P0U9BD203dm?@0j02/[:`0m?Cd0
=cLg03hn?P1<C4`0Bd];055AD@0j>SX0>CTi04I6AP1;Bd/0>CTi04a<C01HF5P0?Cdm04Q8B01HF5P0
Cdm?055AD@1;Bd/0Cdm?04e=C@1NGUh0?3`l03dm?@16ATH0Cdm?04];B`1HF5P0CTi>07moO`1KFe/0
>3Ph04I6AP10@400=SHf03Lg=`17AdL0JVYZ06ATI02:RXX0KFe]04U9B@1JFUX0Ng]k0:>SX`2<S8`0
GUiN07IfMP1JFUX0BDU909>CT`1RHV80IfMW07IfMP18B4P0ADE502PX:080=SHf08P0CDe=06EUI@1N
GUh0=cLg04M7A`0o?cl0ATI603De=@0l?3`0IfMW02TY:@15ADD0FUYJ04=3@`2<S8`0LG5a04Q8B017
AdL0@410065QH@0Z:RX0ATI602/[:`15ADD06a/K03hn?P18B4P0?Shn05eMG@1IFET0H61P03dm?@1?
Cdl0BTY:055AD@1<C4`0M7Ad06EUI@1?Cdl0IVIV02d];@1>CTh0BDU905mOG`1bLW80@D5109:BTP20
P800EEEE065QH@0U9BD0B4Q803dm?@1NGUh0@D5107AdM00^;Rh0GemO03@d=01TI6@07AdM04Y:BP18
B4P0<30`01PH601MGEd0>3Ph04Q8B01HF5P0IFEU04e=C@10@400?clo04=3@`0Y:BT0?3`l0410@014
A4@0BTY:04E5A@2IVIT0^k^k04I6AP27QhL0L71`075aL@13@d<0Kfm_04e=C@1BDU80CTi>03dm?@1A
DE40?Cdm05EEE@1PH600BDU907]kN`1MGEd0D51@02<S8`18B4P0CDe=03hn?P1QHF40Bd];03`l?00n
?Sh0DU9B0451@@1JFUX0F5QH061PH01=CDd092@T08^;R`0f=SH0@d=304Y:BP1aLG40@d=309FEU@1D
E5@0ADE504i>CP1DE5@0EEEE03<c<`1:BTX0ATI604];B`0k>c/0Fe]K04];B`0g=cL0IFEU0P1BDU80
101JFUX0J6QX05eMG@1cLg<Aooooo`003oooool0=01EEED0IFEU09:BTP2ATI40C4a<06m_K`20P800
YjNW0;Bd]00_;bl0BTY:06a/K01FEUH0PX:209>CT`0R8R80JVYZ07YjNP1HF5P0T92@06e]K@0b<S80
;bl_07AdM01hN7P0S8b<02LW9`0j>SX0DE5A06IVIP17AdL0OGem03Ph>011@D40EEEE04m?C`0i>CT0
FEUI02d];@0h>3P0D51@07inOP14A4@0B4Q803<c<`15ADD0O7al079bLP0S8b<0?Cdm0410@018B4P2
06IVIP0K020P800e=CD0?3`l05MGE`2;Rh/0HV9R01hN7P0g=cL0B4Q805iNGP2BTY80=CDe02<S8`0c
<c<0M7Ad05=CD`1XJ6P0T92@020P8019BDT0Fe]K03hn?P1BDU80];Bd030`<00R8R80@D510080De=C
0740H61P01XJ6P0_;bl0@d=307inOP16ATH0<30`04=3@`0N7Qh0E5AD07moO`0h>3P0>SXj0451@@0C
4a<0AdM709FEU@19BDT092@T03lo?`0j>SX0KFe]08b<S00b<S805aLG05MGE`1WIfL0>c/k08B4Q00V
9RH0=SHf05UIF@2FUYH0F5QH08B4Q01BDU80@41005YJFP1GEeL0?clo061PH00n?Sh0:BTY04];B`1c
Lg<0N7Qh04m?C`15ADD0ATI609JFUP2DU9@06a/K04Q8B01=CDd0;Bd]02XZ:P1lO7`0@d=30492@P1N
GUh0B4Q806ATI02ATI40NGUi02DU9@0i>CT0EEEE0820P02?Shl06a/K02HV9P10@400NWYj05EEE@1n
OWh0WinO03Hf=P1GEeL0Bd];055AD@2/[:`0T92@01LG5`17AdL0OWin05MGE`1ZJVX0EUIF01dM7@1>
CTh0WinO04Y:BP2=SHd0UYJF03Ti>@11@D40/k>c04a<C01`L700M7Ad03Ph>00[:b/0OGem079bLP12
@T80=cLg03<c<`1ADE40Lg=c02l_;`1ADE40>3Ph038b<P0207IfMP0904U9B@1[Jf/0;2`/04a<C02N
WYh0OWin02l_;`15ADD0HF5Q0080JFUY05407alO04M7A`1?Cdl0AdM709ZJVP24Q8@0:2PX03lo?`1?
Cdl0K6a/092@T00Z:RX0;Bd]04a<C01aLG40B4Q806ATI00U9BD0GEeM051@D00j>SX0PH6106MWI`0a
<C40I6AT0::RXP2=SHd0HV9R03<c<`16ATH0LW9b0:j^[P1JFUX0IfMW07]kN`0n?Sh0AdM709:BTP1@
D500;bl_05IFEP0c<c<0>SXj0820P030`<00GEeM02d];@18B4P0FEUI0:FUY@28R8P0;Bd]03Ti>@1:
BTX0<c<c06MWI`2LW9`0:RXZ02h^;P1>CTh0@d=305UIF@2][Jd0<30`02h^;P0_;bl0KFe]04Q8B02`
/;00<c<c03Xj>P1@D500IFEU04I6AP0k>c/0GEeM02`/;01<C4`0CDe=04];B`0o?cl07?ooool08P1N
GUh0LG5a04i>CP0V9RH0A4A406QXJ01OGel0:2PX065QH@2;Rh/0>SXj03<c<`1TI6@0ZZZZ07inOP19
BDT0EEEE06i^KP1IFET0EEEE04A4A01<C4`0AdM70451@@1IFET0BDU905mOG`0o?cl0H61P07YjNP1Q
HF40B4Q804e=C@1EEED204m?C`0405ADE01QHF40L71`04Y:BP80<c<c02L0EeMG061PH00k>c/0FUYJ
06MWI`0k>c/0@41005aLG014A4@0EEEE05IFEP0g=cL04Q8B03@d=00k>c/0:BTY020P800a<C408b<S
03dm?@0f=SH0=CDe03Ph>00R8R80<C4a03lo?`16ATH0ADE502l_;`1ADE40ADE503Xj>P0`<300E5AD
030`<00l?3`0CDe=01dM7@0K6a/00P0a<C40aP0X:2P0;Rh^02HV9P0c<c<0=3@d02h^;P0n?Sh0:BTY
03<c<`0f=SH0<c<c03/k>`14A4@0>c/k02HV9P1FEUH0?clo04A4A00i>CT0A4A40492@P0l?3`0=SHf
04Y:BP18B4P0CTi>04I6AP1:BTX0CDe=059BDP1LG5`0JFUY034a<@1:BTX0C4a<03`l?014A4@0>CTi
034a<@0e=CD0@41004Q8B011@D40>3Ph04];B`1jNWX0JVYZ04=3@`1BDU80E5AD06UYJ@1gMgL0R8R8
07=cL`1[Jf/0Fe]K07]kN`1<C4`0@d=305UIF@1GEeL0G5aL038b<P0k>c/0?clo04i>CP1EEED0FEUI
059BDP19BDT0>CTi03Xj>P0k>c/0Fe]K06ATI00_;bl0D51@055AD@0h>3P0F5QH05=CD`1OGel0FEUI
0492@P1[Jf/0;Rh^04E5A@0U9BD0C4a<01PH601CDe<0CDe=02`/;01CDe<0FEUI059BDP0k>c/0Bd];
03/k>`1:BTX0GUiN09ZJVP1gMgL0@d=308F5Q@15ADD0Ph>305mOG`1WIfL0KVi^04=3@`1DE5@0IFEU
05aLG023Ph<0<c<c04a<C00d=3@0IfMW03Ph>01@D500<c<c055AD@14A4@0WinO02/[:`1OGel0FEUI
01/K6`0U9BD0Lg=c02LW9`0o?cl0Bd];05QHF01CDe<0A4A403dm?@1>CTh0=cLg02h^;P0h>3P0Bd];
05EEE@1<C4`0UYJF0>WYj@2?Shl0OWin05YJFP1`L700ADE50861P@1=CDd0Cdm?04a<C01BDU80De=C
055AD@15ADD0IVIV04Q8B01JFUX0@D5103<c<`0^;Rh0De=C05EEE@10@400BTY:05YJFP1MGEd0EeMG
061PH01[Jf/0N7Qh06YZJP1YJFT0KFe]06EUI@2<S8`0DE5A06QXJ01jNWX0TY:B05YJFP2FUYH0GemO
04Q8B011@D40;Rh^0492@P1BDU80EEEE04U9B@1[Jf/0HV9R07QhN080FUYJ00L0L71`05=CD`1YJFT0
J6QX08N7Q`1TI6@0IVIV017ooooo000?ooooo`3o09jNWP1dM7@0CTi>06i^KP1QHF40PH6103/k>`1e
MGD0]KFe07=cL`1MGEd0QHF504Q8B00k>c/0R8R803`l?01XJ6P0?Cdm02LW9`14A4@0LG5a03De=@15
ADD0EEEE05MGE`2PX:00<c<c02d];@1LG5`0?clo03Hf=P24Q8@0CDe=02PX:00d=3@0=cLg04I6AP20
P800?Shn02`/;010@400Ng]k05IFEP1gMgL0<c<c03Lg=`1LG5`0H61P05EEE@22PX80E5AD02@T901?
Cdl0G5aL03dm?@1aLG40ATI601dM7@0^;Rh0GEeM03<c<`0n?Sh0>CTi03`l?01IFET0MgMg01`L7017
AdL0EUIF02TY:@0/;2`0PH6104Q8B00f=SH0@41003Ph>014A4@0Ti>C07MgM`0R8R80?Cdm034a<@1;
Bd/0WinO04U9B@0R8R80BDU903lo?`1PH600IVIV09>CT`0Z:RX0?clo065QH@1GEeL0T92@079bLP0U
9BD0;Rh^03`l?01UIFD0Cdm?01lO7`0W9bL0A4A406YZJP1dM7@0@41008F5Q@0U9BD0820P05mOG`0X
:2P0<30`05iNGP0Z:RX0@41004Y:BP1FEUH07AdM04m?C`0`<300@4100:VYZ@29RHT09BDU03`l?017
AdL0BTY:05eMG@1/K6`09BDU03Xj>P1MGEd0>3Ph08N7Q`2:RXX0:BTY03De=@1:BTX0Hf=S09nOW`2N
WYh0:b/[03Lg=`1[Jf/0NWYj05EEE@2@T900AdM704I6AP25QHD0Ogmo06UYJ@2LW9`06a/K038b<P15
ADD0MgMg0492@P1IFET09RHV02l_;`1OGel0WYjN0492@P15ADD0E5AD030`<01=CDd0Hf=S02<S8`1A
DE40EUIF01dM7@1GEeL0X:2P04A4A00a<C40@d=304];B`2f][H0a<C403Ti>@0[:b/0@d=304A4A01i
NGT0M7Ad02TY:@14A4@0Cdm?05ADE02VYZH0JFUY01PH6016ATH0MWIf05eMG@1hN7P09BDU028R8P1i
NGT0OWin04E5A@1JFUX07QhN04=3@`1dM7@0>SXj08V9R@0b<S807alO04M7A`1TI6@0BDU903`l?00i
>CT0<C4a06][J`1@D500<c<c06][J`0/;2`0IFEU09ZJVP10@400ADE504Q8B00a<C40KFe]08R8R00T
92@0<30`06m_K`1aLG40SHf=04A4A00e=CD0B4Q80861P@1]KFd0TY:B0<S8b00n?Sh0>CTi06YZJP1l
O7`0NWYj08>3P`0_;bl0=3@d04Q8B024Q8@0W9bL000S071`L01ADE40?Shn07inOP1gMgL0FEUI07Mg
M`1iNGT071`L04U9B@20P800Bd];07]kN`1]KFd0<C4a03hn?P1kNg/0D51@020P800n?Sh0>3Ph02HV
9P1MGEd0Lg=c01/K6`0d=3@0=CDe03Hf=P1IFET0G5aL03De=@0j>SX0C4a<028R8P1PH6007?ooool0
6@1GEeL0Ph>306][J`14A4@0P82004e=C@12@T80;bl_059BDP1NGUh0=3@d03Ti>@1PH600Kfm_06a/
K01NGUh0Cdm?04U9B@1ADE40G5aL02d];@0a<C40>SXj02PX:01CDe<00P19BDT0200h>3P0Bd];05=C
D`1GEeL0<C4a04E5A@1PH600GemO0P1CDe<00`17AdL0G5aL04a<C00203Hf=P0>03@d=00i>CT0C4a<
05=CD`10@400>SXj065QH@1GEeL0:BTY034a<@1KFe/0CDe=014A4@0M7Ad204Q8B03X03Lg=`19BDT0
>3Ph04A4A018B4P0ATI605YJFP12@T80BTY:05QHF01KFe/0DE5A03@d=01ZJVX0GemO04e=C@11@D40
MGEe05QHF01EEED0DU9B03<c<`0d=3@0DU9B04Q8B00c<c<0CTi>03Xj>P0d=3@0ATI604Q8B019BDT0
8R8R03`l?019BDT0B4Q804U9B@0i>CT0?Shn03Ph>016ATH0ADE504A4A01CDe<0IVIV05IFEP11@D40
FEUI04m?C`14A4@0>3Ph0451@@18B4P0EUIF05aLG01PH600Ogmo04Y:BP1aLG40DE5A04];B`0e=CD0
<S8b034a<@0d=3@0@D5103Lg=`0k>c/0F5QH0492@P1kNg/0Lg=c04e=C@1^KVh0I6AT08n?S`1bLW80
DU9B06MWI`15ADD0AdM707emO@1ZJVX0JFUY05IFEP0b<S80ADE503@d=00e=CD0;2`/03Ph>01IFET0
FUYJ03Hf=P1DE5@0@41005]KF`0_;bl0=3@d04Q8B00V9RH0>CTi04Q8B011@D40Vi^K06EUI@11@D40
Bd];05MGE`1fMWH0;Rh^06ATI00i>CT0Jf][02`/;00o?cl0ADE502LW9`16ATH0I6AT04Q8B00U9BD0
?Shn03Xj>P0o?cl0DU9B05ADE01QHF40ATI608F5Q@0T92@0A4A405=CD`1RHV80SXj>05ADE01]KFd0
Lg=c05=CD`2EUID0:b/[04m?C`11@D40M7Ad04];B`1MGEd0>3Ph06MWI`1EEED0C4a<02TY:@1SHf<0
HF5Q01hN7P0>3Ph0EeMG02/[:`1BDU80J6QX06IVIP15ADD0FUYJ04a<C00j>SX0?clo04E5A@0l?3`0
CTi>07alO01iNGT0b/[:07moO`1gMgL0Rh^;07IfMP1oOgl0B4Q8055AD@15ADD0C4a<06MWI`0h>3P0
De=C05eMG@0e=CD0@T9202l_;`1ZJVX0?Shn04a<C00a<C40EeMG05iNGP1PH600DU9B04e=C@14A4@0
BTY:03Xj>P0/;2`0B4Q80410@01`L700JVYZ02d];@2KVi/0FEUI06=SH`1KFe/0GEeM0410@023Ph<0
HF5Q05aLG01QHF40?Cdm0451@@18B4P0GEeM02PX:01CDe<0C4a<07=cL`16ATH0CDe=08j>SP1CDe<0
EUIF06YZJP1XJ6P0GEeM08Z:RQ7ooooo000?ooooo`0O06e]K@2WYjL0FUYJ071`L01MGEd0ZJVY06a/
K01lO7`0M7Ad04U9B@1YJFT0SHf=05IFEP1;Bd/0BDU904i>CP2GUiL0RHV903Lg=`1?Cdl0?Cdm03Xj
>P1WIfL0Vi^K03lo?`1NGUh0BTY:04m?C`2;Rh/0C4a<03Xj>P02051@D00D055AD@21PH40<30`02l_
;`0n?Sh0B4Q804];B`1XJ6P0GemO01`L7016ATH0D51@05QHF024Q8@0>SXj02l_;`1FEUH0EeMG03Hf
=P19BDT204Q8B02H06QXJ01DE5@0<c<c05=CD`0o?cl0?Cdm051@D01SHf<0;bl_055AD@18B4P0<S8b
06i^KP1aLG40>c/k03Ti>@1=CDd0?clo07=cL`1WIfL0<C4a030`<016ATH0A4A403Ph>01eMGD0QXJ6
02PX:01RHV80Hf=S04i>CP1oOgl0?3`l01lO7`12@T80De=C06EUI@2?Shl09BDU01hN7P14A4@0G5aL
04a<C01@D500PH6102PX:019BDT0ATI602HV9P1EEED0D51@030`<014A4@0QhN703De=@0g=cL0DE5A
03Xj>P1_Kfl0Rh^;03lo?`0];Bd0D51@05UIF@0a<C40M7Ad04M7A`0K6a/0GUiN07alO01?Cdl0GemO
05IFEP0e=CD0@D5106EUI@1MGEd0X:2P04a<C00Q8B40B4Q809:BTP1FEUH0G5aL08B4Q00];Bd0DU9B
08>3P`17AdL0?Cdm06][J`0d=3@0:b/[05iNGP1ZJVX0HF5Q06EUI@12@T80Bd];07AdM01YJFT0?3`l
07moO`1OGel0BTY:08B4Q01<C4`0?3`l05YJFP14A4@0>c/k05]KF`2<S8`0@D5105IFEP1KFe/0@d=3
06EUI@1^KVh0<S8b04I6AP1SHf<0Bd];05mOG`1gMgL0;Rh^0410@01PH600C4a<04Y:BP1kNg/0=cLg
02h^;P1XJ6P0De=C075aL@0W9bL08R8R06EUI@1WIfL0C4a<06i^KP1XJ6P0>3Ph08j>SP1NGUh0ADE5
07alO01PH600A4A408Z:RP1IFET204E5A@1A04e=C@2NWYh0QXJ602d];@1QHF40DU9B03Hf=P1OGel0
Fe]K04U9B@1CDe<0@41005EEE@2MWId0De=C02d];@1VIVH0CDe=06ATI018B4P0>3Ph06e]K@1RHV80
CTi>06EUI@2GUiL0=SHf05IFEP1fMWH0FEUI06m_K`1hN7P0<C4a03Xj>P19BDT0L71`059BDP2;Rh/0
=SHf03lo?`1UIFD0GEeM04A4A01hN7P0DE5A02TY:@1SHf<0MWIf0451@@1PH600DU9B02d];@1dM7@0
Ti>C03lo?`16ATH0BTY:03hn?P1dM7@0TY:B0492@P1;Bd/0C4a<04A4A00m?Cd0N7Qh06YZJP0e=CD0
ATI604Q8B00b<S80Fe]K07EeM@0T92@0;bl_055AD@0a<C40GEeM07AdM01:BTX0Cdm?01cooooo04l0
GemO06EUI@0n?Sh0;2`/04a<C01kNg/0GUiN02`/;01SHf<0K6a/03Lg=`1GEeL0MWIf08V9R@1mOGd0
PH61065QH@1OGel0FUYJ06MWI`18B4P0=cLg03Ti>@0n?Sh0De=C03lo?`1NGUh0@D51065QH@1GEeL0
GUiN03Lg=`1FEUH0IVIV07YjNP1dM7@0IfMW06IVIP1]KFd0DE5A03Ti>@10@400@D5105=CD`0b<S80
C4a<04e=C@0d=3@0>CTi069RHP15ADD0@d=3069RHP0k>c/08R8R02d];@17AdL0@41003Ti>@0f=SH0
6QXJ051@D019BDT0<C4a03hn?P1;Bd/0F5QH03dm?@1<C4`0GemO0451@@1WIfL0=SHf04I6AP10@400
G5aL02/[:`0h>3P0C4a<0080?Cdm00l0@T9203Lg=`0m?Cd0=3@d02LW9`11@D40>CTi02HV9P13@d<0
9BDU02XZ:P0o?cl0C4a<04A4A00e=CD00P0m?Cd0201CDe<0ADE504m?C`1=CDd0>SXj04I6AP17AdL0
CTi>0P1=CDd205ADE00<04m?C`1<C4`0EEEE061PH01XJ6P0?Cdm05aLG017AdL0EeMG05QHF01<C4`0
B4Q80P11@D40PP1<C4`0EUIF05mOG`1HF5P0NGUi079bLP1EEED0Jf][06UYJ@2<S8`0KVi^06=SH`1Z
JVX0ATI6069RHP1/K6`0EEEE059BDP1MGEd0De=C05mOG`0a<C40?Cdm03Xj>P0l?3`0@41004e=C@10
@400EEEE05IFEP1LG5`0DE5A05mOG`1/K6`0820P0492@P1=CDd0;Rh^06=SH`0o?cl0CTi>04e=C@0l
?3`0F5QH02<S8`1:BTX08B4Q04e=C@0O7al0BDU905YJFP0a<C40Bd];05EEE@18B4P0=cLg05UIF@19
BDT0?Shn05MGE`1fMWH0Ng]k0410@01nOWh0<30`05QHF019BDT0FEUI07YjNP14A4@0S8b<07EeM@1<
C4`0Ti>C02l_;`1JFUX0:BTY06ATI00^;Rh0JVYZ02d];@1MGEd0=SHf07UiN@0/;2`0EEEE05aLG00b
<S808b<S06IVIP0d=3@0=cLg05=CD`1HF5P0EEEE04M7A`1>CTh0EeMG03Ti>@0m?Cd0?3`l05QHF01E
EED0ADE506i^KP3AdM40h>3P08f=S@1WIfL0CTi>04a<C01iNGT0C4a<04=3@`1TI6@0A4A40492@P1L
G5`0IfMW06UYJ@1<C4`0QhN7061PH01FEUH0FUYJ06i^KP1`L700GemO065QH@1CDe<204m?C`0R051@
D00c<c<0I6AT03hn?P1WIfL0AdM704=3@`2:RXX0G5aL04m?C`1]KFd0RXZ:055AD@21PH40EEEE051@
D01KFe/0=3@d04A4A018B4P0De=C03De=@1/K6`0F5QH075aL@1CDe<0CTi>06IVIP1LG5`0JFUY065Q
H@1jNWX0G5aL07MgMa7ooooo000?ooooo`2006UYJ@1JFUX0OGem096AT@18B4P0EEEE04I6AP2BTY80
[jn_03Ph>00l?3`0DE5A05iNGP1MGEd0E5AD02DU9@1BDU80KFe]05iNGP26QXH0EEEE01@D5015ADD0
OGem07AdM02?Shl06QXJ01PH601BDU80KVi^06][J`2?Shl0=3@d04U9B@1TI6@0EeMG055AD@1QHF40
6a/K038b<P1EEED0U9BD05mOG`1@D500;Rh^03Lg=`1ADE40GemO04E5A@1NGUh0?Cdm03Hf=P1>CTh0
IFEU03<c<`0n?Sh0;Bd]04Q8B02;Rh/0@d=302DU9@0a<C40>CTi065QH@2UYJD0:BTY01PH6011@D40
Bd];05MGE`1KFe/0UYJF020P801HF5P0NWYj06ATI022PX80Vi^K02XZ:P0K6a/0?Shn06ATI01XJ6P0
PH6101/K6`0Q8B40CDe=075aL@1KFe/0Shn?04E5A@0N7Qh0G5aL06EUI@0d=3@0NWYj03hn?P0W9bL0
;Bd]05mOG`17AdL0@d=302TY:@0V9RH0IfMW07QhN00Y:BT0:RXZ04U9B@0o?cl0?Cdm06e]K@0G5aL0
7alO05]KF`23Ph<0EeMG092@T01DE5@07AdM03lo?`2SXj<0ADE50:VYZ@1BDU8071`L03dm?@17AdL2
04];B`0?03Ph>00];Bd0Cdm?04e=C@12@T80G5aL059BDP0K6a/0;bl_06a/K01NGUh0O7al04A4A00S
8b<0C4a<0080Jf][03D0=SHf04Y:BP0T92@0TI6A0;:b/P10@400;Rh^05=CD`0^;Rh0C4a<0:2PX02N
WYh0=SHf05IFEP1ADE40D51@08N7Q`1:BTX051@D038b<P1VIVH0KFe]0:RXZ01HF5P061PH04U9B@1V
IVH0EeMG09jNWP2@T900;Bd]04a<C02=SHd0BTY:0::RXP1eMGD0<S8b05EEE@1>CTh0E5AD03@d=00g
=cL0;Bd]08b<S01KFe/0<S8b06EUI@1FEUH0<C4a075aL@2a/K40MGEe05eMG@0202d];@1<08J6QP2@
T900B4Q805UIF@0`<300FEUI04M7A`0d=3@0DE5A038b<P19BDT0XJ6Q08V9R@0W9bL0?Shn05YJFP2_
[jl0Ph>301dM7@16ATH0EeMG05mOG`1UIFD0];Bd03<c<`0k>c/0HF5Q04=3@`2YZJT0E5AD02`/;00g
=cL0Kfm_05ADE02<S8`0820P03Lg=`1TI6@0YJFU07UiN@1EEED0Hf=S020P8013@d<0LW9b061PH01>
CTh0EEEE02DU9@11@D40R8R809^KV`0l?3`0=SHf04E5A@0n?Sh0SXj>0:6QX@1;Bd/0G5aL06MWI`19
BDT0N7Qh05ADE00V9RH0ATI6059BDP0l?3`0V9RH0:^[Z`0Z:RX0;Bd]02h^;P1BDU80M7Ad0:6QX@80
>SXj00X0ADE504m?C`0m?Cd0FUYJ08>3P`0U9BD0?Shn06e]K@15ADD0`L717?ooool03@1ADE40Lg=c
04Q8B016ATH0D51@07MgM`1eMGD0<c<c065QH@29RHT0C4a<0451@@1UIFD00P1[Jf/04`27QhL0D51@
06IVIP1UIFD0HV9R03lo?`0Y:BT0@D5103dm?@1DE5@0?clo04e=C@0j>SX0D51@061PH01EEED0<S8b
04Y:BP1VIVH00P1ZJVX205YJFP0:06e]K@1UIFD0@d=30492@P0m?Cd0?Shn04M7A`1DE5@0@T9203Lg
=`80E5AD03T0?Cdm03Xj>P1HF5P0@d=301LG5`0T92@0CTi>03`l?00g=cL0D51@0451@@1DE5@0Cdm?
04Y:BP1?Cdl0ATI6061PH01GEeL0FEUI05]KF`0l?3`0KVi^05=CD`19BDT0>3Ph07EeM@0`<300@T92
05EEE@0^;Rh0B4Q8069RHP19BDT0?clo04];B`0m?Cd0>3Ph0451@@0n?Sh0EEEE02DU9@0d=3@0@D51
05=CD`1>CTh0BTY:03hn?P0h>3P0Bd];02`/;00l?3`0De=C061PH01NGUh0C4a<05UIF@1CDe<00P1P
H600;`1QHF40ADE504e=C@1JFUX0Bd];06QXJ01@D500KFe]059BDP18B4P0EEEE04i>CP0n?Sh0?Cdm
0451@@1<C4`0CDe=04=3@`1@D500F5QH07alO015ADD0MGEe07inOP2OWil0P820071`L022PX80FUYJ
08f=S@1[Jf/0EUIF071`L01XJ6P0@d=304i>CP0`<300?Shn02/[:`0l?3`0AdM705]KF`1TI6@0E5AD
04=3@`1<C4`0?Cdm0080BTY:08@0:BTY04=3@`1:BTX0=CDe08J6QP1MGEd0@D5105EEE@1DE5@0Ng]k
03Ti>@1:BTX0;bl_06ATI00?3`l0?Cdm04M7A`0I6AT0=SHf04e=C@1CDe<0;Rh^04];B`0g=cL0CDe=
05UIF@1OGel0K6a/03dm?@1lO7`0AdM707]kN`1EEED0RHV908b<S00h>3P0Kfm_05MGE`0g=cL0PX:2
07inOP1?Cdl0ADE505mOG`1?Cdl0JFUY05IFEP1bLW80=3@d05eMG@0U9BD0E5AD05YJFP0a<C409BDU
05QHF01BDU80OWin079bLP1OGel0EeMG055AD@1<C4`0ADE504U9B@17AdL0ATI605mOG`1CDe<0CTi>
05=CD`16ATH0Rh^;08V9R@1RHV80Kfm_05mOG`27QhL0EeMG04Y:BP1EEED0B4Q804Y:BP1KFe/0;bl_
04I6AP0j>SX0XJ6Q06YZJP1?Cdl0AdM709BDU029RHT0FUYJ06QXJ01?Cdl0>c/k04Y:BP1UIFD0CTi>
096AT@1BDU80IFEU05UIF@1?Cdl0Lg=c05IFEP12@T80Jf][07emO@1:BTX0Ph>304Q8B01PH600KVi^
04a<C01DE5@0BTY:04m?C`0o?cl0KFe]05]KF`1dM7@0FUYJ05UIF@1cLg<0DE5A05eMG@1IFET0JVYZ
05]KF`24Q8@Aooooo`003oooool0b`2JVYX0I6AT04m?C`23Ph<0RXZ:0861P@1HF5P0CTi>08n?S`1j
NWX0SXj>09fMW@13@d<0Bd];071`L01DE5@0S8b<03hn?P0k>c/0I6AT09NGU`0o?cl0J6QX06UYJ@0m
?Cd0Hf=S08:2PP0X:2P0G5aL03@d=00i>CT0CDe=04a<C00Q8B40Cdm?03/k>`11@D40GUiN03@d=00@
4100=CDe03Ph>01;Bd/0Kfm_02<S8`0g=cL0De=C03Ti>@1HF5P0NGUi07=cL`0J6QX0FUYJ05IFEP1N
GUh0OWin01HF5P0S8b<0E5AD07YjNP1ADE40Ng]k03Xj>P18B4P0D51@07]kN`0f=SH0MWIf055AD@0A
4A40>c/k04];B`0f=SH0IfMW01TI6@0V9RH0C4a<05QHF014A4@0820P05UIF@0Y:BT0@41008>3P`19
BDT0;2`/06][J`11@D40ATI60:FUY@2DU9@0:2PX03lo?`0b<S80AdM70:VYZ@1HF5P07AdM0451@@1H
F5P0G5aL06m_K`0e=CD05aLG03Hf=P1ZJVX0CDe=06i^KP2GUiL051@D02@T901=CDd0ADE5055AD@1b
LW807QhN03De=@1QHF40L71`02l_;`1PH60092@T03Hf=P1MGEd0MgMg02LW9`1=CDd0>CTi03De=@1e
MGD0Ng]k02d];@1GEeL0FUYJ05ADE02:RXX0WIfM02DU9@0H61P0CDe=055AD@28R8P0Rh^;024Q8@0j
>SX0G5aL092@T01WIfL0WYjN038b<P13@d<0IVIV06][J`1cLg<0[Jf]01dM7@0e=CD0E5AD05aLG01P
H600Ogmo01hN7P0d=3@0CDe=08^;R`0j>SX0EeMG04U9B@0N7Qh0De=C06IVIP11@D40WIfM02h^;P0O
7al0H61P0:>SX`1YJFT0E5AD03<c<`18B4P0OGem07=cL`0f=SH0@D5105UIF@0b<S80MWIf092@T00_
;bl0H61P04Q8B015ADD0YjNW06UYJ@0T92@0:b/[06IVIP1_Kfl0V9RH02h^;P13@d<0@T920080HF5Q
05D0V9RH02@T901;Bd/0>c/k04i>CP1mOGd0<30`01lO7`1FEUH0Ogmo04Q8B01SHf<0:2PX055AD@1m
OGd0>CTi079bLP1_Kfl06a/K034a<@1nOWh0Jf][05ADE00W9bL0;Rh^05eMG@1WIfL0;Rh^05]KF`1:
BTX0<c<c07alO01<C4`07alO04E5A@1>CTh0E5AD06MWI`2?Shl09bLW02XZ:P1DE5@0G5aL06IVIP2@
T900=SHf028R8P1;Bd/0L71`07IfMP1nOWh0HV9R03dm?@1:BTX0Hf=S05QHF02[Zj/0TY:B02LW9`1S
Hf<0L71`05aLG02:RXX0GUiN01PH600n?Sh0PX:206EUI@0f=SH0HF5Q02h^;P15ADD0QhN706MWI`0Z
:RX0Cdm?05iNGP0/;2`0=SHf07IfMP0l?3`0@d=303hn?P0S8b<0>SXj01cooooo02l0LG5a08B4Q01]
KFd0@T9205aLG01MGEd0Fe]K02LW9`1hN7P0HF5Q03/k>`1OGel0K6a/06QXJ01YJFT0R8R804E5A@1=
CDd0BTY:05EEE@1@D500@41004A4A01ADE40G5aL04U9B@1KFe/0ATI6051@D00k>c/0HF5Q04A4A01K
Fe/0GEeM07inOP2QXJ40MGEe05YJFP1bLW80IFEU03dm?@0j>SX0@T9205QHF00a<C40D51@05MGE`02
0410@01[05UIF@0m?Cd0?Shn06ATI00f=SH05aLG020P8010@400?Cdm03@d=00l?3`07alO04=3@`1:
BTX0ATI604Y:BP1;Bd/0EUIF0451@@1?Cdl0IVIV0451@@1GEeL0?Shn04E5A@13@d<0MWIf04M7A`1F
EUH0FEUI04=3@`18B4P0?clo02l_;`0l?3`0=cLg02PX:00o?cl0;2`/02/[:`16ATH0;Rh^02d];@0h
>3P0EEEE04E5A@0o?cl0@d=305YJFP1TI6@0=cLg055AD@1<C4`0?Shn04I6AP1;Bd/0G5aL061PH01X
J6P0HV9R05YJFP1HF5P0EEEE07=cL`1:BTX0PH6105IFEP1iNGT0IVIV051@D01MGEd0I6AT05IFEP0k
>c/0Bd];05=CD`1WIfL0I6AT04m?C`1eMGD0Rh^;04U9B@1UIFD0De=C07AdM01YJFT0FUYJ05ADE01=
CDd0BTY:07inOP1EEED0DU9B06YZJP1>CTh0Fe]K02LW9`0c<c<0<C4a05IFEP1=CDd0DU9B03Ti>@0j
>SX0EeMG065QH@16ATH00P1>CTh09`0X:2P0Bd];06IVIP19BDT0FEUI03dm?@1LG5`0IVIV03Hf=P1:
BTX0=cLg055AD@0^;Rh0CDe=020P801:BTX0CTi>034a<@1SHf<0I6AT059BDP0/;2`0@T9203Lg=`0]
;Bd0EUIF05mOG`1VIVH09bLW051@D00[:b/0DU9B03`l?019BDT0KFe]04=3@`2:RXX0MWIf04=3@`02
0:^[Z`1K08j>SP1;Bd/0L71`055AD@1UIFD0Jf][05eMG@1`L700Kfm_03/k>`26QXH0WIfM0410@00f
=SH0DU9B03@d=00g=cL0D51@05YJFP1?Cdl0BDU903Ph>01<C4`0>SXj03Ti>@0_;bl0CTi>05=CD`1:
BTX0C4a<05MGE`1LG5`0H61P04M7A`1?Cdl0CDe=071`L01?Cdl0DU9B04];B`10@400>c/k03lo?`0l
?3`0Lg=c03Lg=`17AdL0BDU905eMG@0o?cl0@410051@D00];Bd0B4Q805=CD`19BDT0EUIF03dm?@0W
9bL0@T9204U9B@1jNWX0<30`05=CD`1gMgL0FUYJ055AD@1RHV80PH61061PH02WYjL0Kfm_09nOW`1/
K6`0@41004E5A@1?Cdl0?Shn04M7A`1[Jf/0E5AD07=cL`1bLW80F5QH07=cL`1fMWH0PX:206ATI021
PH40GemO07inOP0Aooooo`003oooool0F01TI6@0UYJF04];B`2?Shl0De=C092@T01BDU80F5QH05iN
GP0k>c/0DU9B096AT@0h>3P0@D5103@d=01iNGT0a/K605iNGP0c<c<0<30`04];B`1>CTh0PX:207Ui
N@0];Bd0C4a<06YZJP1UIFD0[jn_03De=@0a<C40ADE5061PH01QHF40Shn?01dM7@0m?Cd0HF5Q05aL
G01]KFd0RXZ:04U9B@0S8b<0Lg=c055AD@1@D500GemO02PX:00Y:BT0Fe]K092@T01?Cdl0Ng]k04I6
AP0c<c<0FEUI04e=C@0_;bl0BTY:02<S8`0f=SH0DE5A04=3@`0S8b<0CTi>03/k>`0c<c<0MgMg08V9
R@0a<C40:2PX055AD@1@D500/K6a051@D00@41009RHV04m?C`1>CTh0D51@08R8R00n?Sh08B4Q04];
B`1LG5`0De=C0:b/[01BDU8202/[:`3808V9R@1YJFT0TI6A01LG5`0Q8B40:RXZ05aLG00j>SX0G5aL
04];B`0>3Ph0:2PX05MGE`0W9bL0BTY:03@d=00[:b/0B4Q805YJFP0a<C409bLW03hn?P1PH600K6a/
09:BTP0[:b/07QhN04=3@`1QHF40MgMg08:2PP0a<C40:2PX0492@P23Ph<0I6AT07]kN`1iNGT061PH
03Hf=P1MGEd0TY:B09jNWP0d=3@0?Cdm0410@01_Kfl0MgMg08j>SP27QhL0=SHf04A4A01gMgL0@D51
05=CD`1`L7009bLW04A4A01mOGd0FUYJ07MgM`0e=CD09BDU04M7A`2GUiL0JVYZ034a<@1YJFT0?clo
04M7A`2YZJT0@T9202/[:`1>CTh0?clo02l_;`25QHD0T92@02HV9P0g=cL0ATI60410@02c/k<0GUiN
01TI6@0W9bL0Fe]K07YjNP2?Shl0@41002DU9@1ADE40SHf=06MWI`26QXH0FUYJ02d];@0`<300QXJ6
06EUI@2d];@0@410030`<00c<c<0J6QX04E5A@16ATH0?clo03Xj>P1VIVH0CDe=04=3@`1CDe<08R8R
05IFEP1IFET0De=C03`l?00[:b/0C4a<0;Zj^P1aLG40;2`/0451@@1:BTX0>3Ph092@T01?Cdl08B4Q
04U9B@0h>3P0TI6A0:6QX@0J6QX0@41004i>CP1?Cdl0Rh^;04m?C`0U9BD0I6AT06][J`1EEED0/k>c
08:2PP0`<300ATI607UiN@1PH600LG5a06e]K@0d=3@0@d=305UIF@1^KVh0@T9207UiN@0h>3P0C4a<
07IfMP1KFe/0ATI606MWI`14A4@0:2PX05mOG`1/K6`0=cLg06YZJP1DE5@0<S8b05YJFP2<S8`0<c<c
03Lg=`0i>CT0<30`08F5Q@2MWId0@D5103lo?`0m?Cd0@D510820P01iNGT0>3Ph01hN7P0c<c<0Bd];
05EEE@2HV9P0R8R8024Q8@0m?Cd0AdM704I6AP2;Rh/0K6a/01lO7`11@D4Looooo`0804A4A01QHF40
=CDe02h^;P15ADD0MWIf08J6QP0f=SH206YZJP0A03`l?00n?Sh0JFUY075aL@1lO7`0TY:B03Ti>@1A
DE40ATI6075aL@13@d<09RHV03dm?@0];Bd0CDe=04A4A01QHF400P1<C4`09P1:BTX0E5AD03hn?P1F
EUH0GUiN05MGE`1NGUh0HV9R06IVIP1aLG40DU9B02XZ:P0^;Rh0E5AD05EEE@0h>3P0C4a<04];B`18
B4P0>c/k05eMG@1@D500@D5105YJFP0g=cL061PH02l_;`1?Cdl0?3`l02l_;`1;Bd/0;bl_04Y:BP15
ADD0@d=304];B`11@D40I6AT0P1PH600/@1fMWH0=SHf07emO@13@d<0A4A403`l?01JFUX0<c<c0451
@@1=CDd0;Bd]03Ph>014A4@0>3Ph034a<@17AdL0>CTi034a<@0d=3@0@D51059BDP0S8b<0?clo030`
<013@d<0BDU905EEE@0k>c/0<c<c04Y:BP1<C4`0DE5A04M7A`1@D500De=C0410@01>CTh0AdM705IF
EP1WIfL0B4Q8061PH01ADE40NWYj08J6QP2d];@0LW9b08>3P`1QHF40M7Ad06e]K@1EEED0HF5Q059B
DP1;Bd/0CDe=03Ti>@0g=cL0B4Q807alO02?Shl0GEeM07QhN01ZJVX0XJ6Q08>3P`1SHf<0JVYZ06e]
K@1TI6@0Ti>C07alO01YJFT0MgMg07EeM@1^KVh0=cLg03Xj>P0f=SH0AdM706ATI01EEED0BDU903dm
?@0o?cl0LG5a04e=C@1<C4`0EEEE02PX:00`<300JVYZ02h^;P1gMgL0EeMG04=3@`1FEUH0=3@d06MW
I`0j>SX0?3`l02DU9@1<C4`092@T04Y:BP1BDU80<c<c03Hf=P16ATH0EeMG04i>CP1BDU80ATI603Ti
>@1YJFT0H61P07emO@0R8R80CTi>02d];@1?Cdl0@d=306IVIP1eMGD0:b/[0<71`@2BTY80?clo08f=
S@1MGEd0P82005QHF01dM7@0>SXj096AT@12@T80K6a/04Y:BP1WIfL04a<C04Q8B00l?3`07alO00d=
3@1ADE409RHV034a<@1DE5@0Jf][05eMG@1JFUX0F5QH06e]K@0k>c/0@41004=3@`1FEUH0P82004i>
CP1ADE40;2`/01TI6@1ADE40=CDe051@D01=CDd0IFEU0451@@18B4P0Fe]K04e=C@15ADD0BTY:03lo
?`1BDU80@41007alO0020410@00Z02HV9P13@d<0F5QH04A4A01QHF40CTi>04A4A01=CDd0@4100451
@@1IFET0GEeM07=cL`1LG5`0UiNG0;2`/022PX80IVIV0:>SX`2OWil0CDe=061PH00l?3`0C4a<05QH
F01?Cdl0KVi^0451@@0k>c/0@T9206ATI01GEeL0D51@04m?C`19BDT0Bd];04I6AP1PH600GemO08j>
SP1KFe/0IFEU4Oooool000oooooo0=00H61P08N7Q`1lO7`0[:b/04Y:BP1aLG40GemO0;Zj^P2CTi<0
?clo05MGE`1cLg<0IVIV08J6QP1LG5`0>CTi06QXJ023Ph<0C4a<05mOG`0_;bl06ATI05IFEP1MGEd0
B4Q80:NWY`0g=cL0:RXZ06MWI`1aLG40@d=3069RHP0V9RH0:BTY06e]K@11@D409bLW04a<C00J6QX0
9bLW0861P@1gMgL071`L034a<@0/;2`0UiNG0;Vi^@1EEED0;2`/03<c<`1=CDd0KFe]0:6QX@0l?3`0
>CTi03`l?01IFET0De=C09^KV`0o?cl051@D04e=C@1cLg<0LG5a08^;R`0f=SH09RHV05=CD`1VIVH0
B4Q804A4A01aLG409BDU05UIF@1VIVH0@D5105ADE01@D5006QXJ03Xj>P1HF5P0OGem03/k>`0m?Cd0
71`L034a<@1UIFD0J6QX02l_;`0j>SX08b<S03/k>`1mOGd0ADE501lO7`19BDT0820P034a<@2XZ:P0
[jn_02/[:`0];Bd0DE5A0492@P2?Shl0OGem01LG5`11@D40Fe]K04e=C@1YJFT0O7al01dM7@0o?cl0
HV9R08R8R011@D40PH6103Ti>@0M7Ad0H61P04I6AP0m?Cd0SXj>020P800/;2`0IVIV07moO`0f=SH0
AdM702`/;00f=SH0MGEe06EUI@0Y:BT0Cdm?034a<@0O7al0EEEE0:BTY019BDT0EeMG03lo?`0g=cL0
LW9b09JFUP0a<C408B4Q03Ti>@1]KFd0Zj^[06ATI00T92@0@41005mOG`1NGUh0I6AT0;>c/`1GEeL0
:RXZ05ADE01JFUX0GUiN08n?S`0b<S80<c<c04A4A01IFET0>SXj08B4Q00T92@08b<S069RHP24Q8@0
@d=30820P01>CTh09RHV05=CD`1hN7P0?clo07EeM@1:BTX0;Bd]07UiN@2YZJT0CTi>03dm?@12@T80
?clo09bLW01=CDd09bLW05ADE00l?3`0IVIV07UiN@27QhL0>SXj04a<C01:BTX0QXJ60;Ng]`0n?Sh0
>SXj05aLG01JFUX0OWin0P0j>SX05@17AdL0LG5a05MGE`2KVi/0>CTi02`/;017AdL0GEeM07AdM01W
IfL06ATI0492@P1`L700>3Ph055AD@1bLW80=cLg05]KF`1YJFT0ATI608F5Q@0202/[:`0i071`L01m
OGd0>SXj05EEE@0f=SH0?Cdm07moO`2SXj<0ADE504];B`1CDe<0@d=30451@@2IVIT0>c/k03Ti>@1E
EED0F5QH05iNGP2FUYH0NGUi01lO7`0Y:BT0DU9B06QXJ027QhL0BDU902HV9P0o?cl0B4Q804M7A`24
Q8@0E5AD02XZ:P1aLG40QhN703De=@1^KVh0H61P02<S8`0];Bd0Kfm_05YJFP1MGEd0ADE502PX:00K
6a/0DU9B09JFUP0j>SX0=SHf05]KF`0Z:RX0AdM706e]K@0i>CT0A4A401cooooo05H0DU9B08N7Q`1d
M7@0EeMG04A4A01;Bd/0AdM702l_;`1oOgl0IVIV055AD@10@400Kfm_075aL@1lO7`0P82005EEE@1F
EUH0BTY:079bLP16ATH0@D5104I6AP0j>SX0CDe=04A4A01^KVh0B4Q805YJFP1;Bd/0LW9b03hn?P1T
I6@0LW9b07QhN01cLg<0KVi^079bLP2>SXh0LW9b05EEE@14A4@0ADE505eMG@1=CDd0EeMG051@D015
ADD0=cLg055AD@19BDT0>c/k04i>CP0m?Cd09BDU03Hf=P19BDT0;Rh^02l_;`17AdL0:BTY03@d=019
BDT0D51@05iNGP14A4@0C4a<06IVIP1MGEd0HF5Q03dm?@26QXH0Bd];04A4A00`<300IFEU04U9B@1E
EED0B4Q8034a<@0f=SH0C4a<03De=@0j>SX0?Cdm03Xj>P80<C4a0800<c<c04a<C00P8200=SHf028R
8P0o?cl0>c/k03Lg=`0n?Sh0<c<c05UIF@0];Bd0ATI604Q8B01VIVH0ADE504i>CP1RHV80JFUY05aL
G01CDe<0EUIF04];B`1?Cdl0F5QH05=CD`1VIVH0N7Qh08b<S01QHF40Jf][06IVIP0n?Sh0EEEE059B
DP15ADD0ATI604A4A025QHD0EEEE079bLP1mOGd0Fe]K07AdM01QHF40YjNW09FEU@2CTi<0Ph>306UY
J@1jNWX0MgMg05EEE@1jNWX0KVi^055AD@1OGel0@T9204Q8B016ATH0EUIF05YJFP1LG5`0Jf][051@
D012@T80HV9R04=3@`1;Bd/0De=C01lO7`12@T80TY:B04Q8B01lO7`0Fe]K04e=C@1MGEd0?Cdm05EE
E@0j>SX0GUiN02LW9`1;Bd/0;2`/04E5A@19BDT0=cLg03/k>`1@D500Bd];038b<P0d=3@0>CTi04M7
A`1GEeL0Fe]K06e]K@0j>SX0Bd];03Hf=P1[Jf/0De=C05IFEP1VIVH09BDU055AD@19BDT0:b/[0820
P02JVYX0][Jf09ZJVP1nOWh0>c/k06UYJ@1:BTX0U9BD059BDP21PH406QXJ05eMG@1RHV8092@T01<C
4`1aLG40=CDe05YJFP80EUIF04P0EEEE05mOG`1:BTX0@41003Ph>01:BTX0=SHf04I6AP1LG5`0@d=3
06YZJP1KFe/07AdM05QHF00o?cl0K6a/04e=C@1kNg/0EUIF06IVIP1;Bd/0@41004E5A@1LG5`0CTi>
05]KF`0b<S80LW9b04Q8B01iNGT0:BTY05EEE@1NGUh0>3Ph05YJFP0a<C40A4A405EEE@1:BTX0=3@d
06m_K`0_;bl0J6QX03hn?P1EEED0F5QH059BDP13@d<0K6a/08Z:RP1JFUX0YJFU04I6AP1ADE40C4a<
03Ph>01<C4`0A4A403@d=00o?cl0CDe=05iNGP1SHf<0FUYJ05UIF@1ADE40E5AD06ATI018B4P0I6AT
04e=C@1ZJVXAooooo`003oooool0BP1mOGd0BTY:05mOG`1jNWX0Kfm_07AdM017AdL0Fe]K06e]K@1=
CDd0Kfm_06EUI@0Y:BT0EEEE07UiN@0f=SH0D51@03`l?01_Kfl0_;bl07YjNP0`<300Fe]K06ATI01L
G5`0^[Zj03Hf=P0W9bL0;bl_04i>CP15ADD0OGem04a<C00n?Sh0CTi>04M7A`1cLg<0S8b<02XZ:P0U
9BD06QXJ05]KF`16ATH0EeMG018B4P0b<S80BDU903`l?00m?Cd0Jf][02l_;`0E5AD0Kfm_04M7A`0m
?Cd0>SXj01`L700n?Sh0BDU905eMG@0R8R80EEEE04M7A`0h>3P0MgMg04A4A00Q8B40@T9203De=@0b
<S80>SXj06UYJ@0U9BD0?Cdm0P0^;Rh0401QHF40Lg=c01dM7@0G5aL0>3Ph07AdM01`L700GemO01TI
6@0U9BD0Bd];05]KF`1dM7@0[:b/03`l?00W9bL207AdM03404E5A@22PX806a/K01<C4`0`<300GemO
059BDP1IFET06ATI01lO7`18B4P0OWin0410@019BDT0EeMG018B4P0X:2P0HF5Q02@T901GEeL0H61P
03Lg=`1:BTX0NGUi04U9B@0X:2P0E5AD02d];@1OGel0]kNg07EeM@0C4a<0@D5106QXJ00`<300HV9R
04e=C@0j>SX0D51@05aLG01JFUX0X:2P05MGE`0F5QH0<S8b05QHF01EEED0ZJVY03De=@0R8R80=3@d
075aL@1<C4`0FUYJ06EUI@0O7al0HF5Q07inOP1<C4`0Rh^;05YJFP0X:2P0=SHf07=cL`28R8P0<c<c
059BDP0i>CT0DE5A07QhN01RHV805ADE05EEE@17AdL0<C4a07emO@1<C4`0820P04a<C00f=SH0LG5a
0<71`@2CTi<0;Bd]03lo?`12@T80OGem0;Zj^P2:RXX0;2`/030`<01JFUX0HF5Q08Z:RP1KFe/0=SHf
05EEE@18B4P0@d=307MgM`0f=SH0=cLg05MGE`26QXH0GEeM04Q8B00c<c<0KFe]0;2`/01[Jf/0EUIF
06QXJ00k>c/0GemO04Y:BP0f=SH0FEUI03<c<`0f=SH0IFEU07QhN00V9RH0@D5103<c<`1RHV80WinO
04E5A@0f=SH0EeMG03<c<`1?Cdl0S8b<03Hf=P11@D40EeMG05mOG`2_[jl0EUIF02TY:@1KFe/0JFUY
04U9B@22PX80:BTY02/[:`1YJFT0Ti>C04i>CP2ATI40MWIf03De=@0k>c/0LG5a07AdM01cLg<0NGUi
02@T901CDe<0BDU9061PH00m?Cd0@d=30410@00i>CT0RHV908j>SP0a<C40GUiN03Ph>00l?3`0FEUI
07QhN00_;bl0C4a<04I6AP1=CDd0OGem08B4Q00j>SX0=3@d04A4A00l?3`0KVi^09>CT`0Y:BT061PH
02TY:@1IFET0@d=307]kN`20P800:2PX05=CD`15ADD0A4A406ATI1cooooo03X0CTi>07QhN00o?cl0
9bLW03/k>`1dM7@0HF5Q02d];@29RHT0J6QX04I6AP11@D40Jf][07inOP1dM7@0KFe]030`<01MGEd0
De=C06i^KP0n?Sh07alO03Lg=`0Y:BT0Bd];04U9B@1PH600=cLg05aLG01^KVh0Jf][03@d=019BDT0
G5aL06YZJP1cLg<0P82007UiN@20P800GemO04Q8B010@400A4A404Y:BP0g=cL0B4Q805ADE011@D40
DE5A06EUI@1:BTX0=SHf065QH@1EEED0:b/[028R8P1=CDd0@d=30P15ADD0iP0Y:BT0FUYJ05YJFP1A
DE40B4Q804];B`1>CTh0@D5104U9B@1WIfL0De=C05mOG`1=CDd0?3`l034a<@1>CTh0;2`/03Ph>01N
GUh0BDU904a<C01ADE40;2`/03`l?00g=cL09BDU02TY:@0e=CD0=cLg05UIF@0M7Ad0A4A4028R8P18
B4P0Cdm?03hn?P16ATH0>c/k06EUI@0a<C40E5AD04m?C`19BDT0EEEE03@d=010@400?Shn051@D01=
CDd0EEEE06IVIP1ADE40LW9b05QHF02XZ:P0S8b<08n?S`1JFUX0?Shn06a/K00g=cL0?3`l02h^;P18
B4P0C4a<04I6AP1=CDd0ADE507QhN021PH40DU9B06QXJ01YJFT0PX:2061PH01>CTh0GemO06ATI01V
IVH0L71`051@D01?Cdl0JVYZ06i^KP1[Jf/09BDU034a<@1JFUX0M7Ad06m_K`1EEED0ATI603Ti>@0o
?cl0I6AT05aLG01@D500GemO02PX:014A4@0V9RH04M7A`1`L700CDe=04a<C01FEUH0BDU906EUI@0e
=CD0DE5A030`<01IFET04a<C04M7A`1<C4`0<S8b03Xj>P1@D500EUIF03Hf=P0k>c/0AdM703Hf=P1L
G5`0CTi>06ATI017AdL0K6a/02l_;`0g=cL0@d=3079bLP1oOgl0<S8b06EUI@14A4@0:2PX09NGU`1d
M7@0[jn_08N7Q`1PH600ADE505aLG013@d<0F5QH0451@@1LG5`06ATI07MgM`2:RXX0:b/[01DE5@1;
Bd/0>c/k03dm?@16ATH0EeMG04e=C@1?Cdl0?clo04Q8B00c<c<0@d=302d];@19BDT0De=C04Y:BP0m
?Cd0=3@d01hN7P1KFe/0@T9204=3@`1;Bd/0GemO0451@@1;Bd/0Jf][04E5A@0i>CT0BTY:03Ph>01^
KVh0=cLg06QXJ00a<C40?Shn02HV9P1WIfL0I6AT06][J`23Ph<0C4a<051@D012@T80GEeM02HV9P1@
D500<c<c069RHP0O7al0N7Qh06e]K@1mOGd0DU9B07moO`1gMgL0CDe=07UiN@1GEeL0N7Qh05UIF@0l
?3`0D51@03Ph>00H61P0<c<c03lo?`1PH600G5aL05iNGP17AdL0DE5A07inOP20P800DE5A07]kN`1N
GUh0KVi^4Oooool000oooooo0:T0X:2P061PH01<C4`0HV9R06a/K02FUYH0>3Ph065QH@27QhL0FUYJ
0;Vi^@27QhL0?clo03De=@1LG5`0JVYZ09nOW`0i>CT0>3Ph06EUI@1bLW80?clo07QhN01UIFD0?Shn
09nOW`1/K6`0GEeM07AdM00W9bL0Cdm?04a<C01eMGD0>c/k05iNGP0_;bl0;Bd]07MgM`24Q8@09bLW
06ATI00/;2`0;Bd]07QhN00a<C40?Cdm055AD@0O7al0Cdm?09fMW@1OGel061PH04M7A`12@T80H61P
09^KV`0R8R80<30`05mOG`1MGEd0=cLg071`L00o?cl0;bl_05ADE01;Bd/0ATI60:>SX`1UIFD061PH
03/k>`0j>SX0BDU905]KF`0K6a/0:b/[03Xj>P1BDU80;bl_038b<P15ADD02PX:0492@P1RHV80<c<c
06][J`1HF5P061PH02`/;012@T80HF5Q02`/;00_;bl08B4Q05IFEP1iNGT0@d=301TI6@0a<C40:RXZ
028R8P1gMgL0=CDe018B4P0^;Rh0@d=304Q8B01jNWX0P82001PH600L71`0ADE503Ph>029RHT0Vi^K
01/K6`0G5aL0DU9B08:2PP0^;Rh0P82002`/;00O7al0?3`l07UiN@12@T80IFEU04M7A`0b<S80CTi>
06ATI01OGel0KFe]04I6AP0[:b/0I6AT092@T01ADE40>c/k06UYJ@0d=3@0OWin05mOG`0T92@0?Cdm
04=3@`1>CTh0O7al0:>SX`0];Bd0BTY:05YJFP1CDe<0TY:B0:j^[P0U9BD0>c/k04];B`1NGUh0HV9R
0820P00E5AD08R8R04M7A`1hN7P0ATI60;fm_@1>CTh051@D0080I6AT07L0De=C09VIV@1<C4`05aLG
03Hf=P1oOgl0HV9R06e]K@0V9RH0:BTY04e=C@2:RXX0D51@06=SH`19BDT06QXJ03`l?01bLW80BDU9
06=SH`0G5aL0@d=30:>SX`1GEeL0>CTi0410@011@D40LW9b08j>SP0a<C40<c<c06QXJ01TI6@0J6QX
08J6QP0U9BD0F5QH06a/K02:RXX0Rh^;02DU9@0h>3P0DE5A04m?C`1LG5`0Q8B40410@00f=SH0MWIf
04U9B@1XJ6P0OGem01hN7P0e=CD0FUYJ04M7A`1ADE406ATI03/k>`1=CDd0I6AT03hn?P1MGEd0EeMG
03De=@1NGUh0@T9203<c<`1MGEd0CDe=03Ti>@1LG5`0N7Qh04A4A00^;Rh0CTi>04a<C01HF5P0IfMW
03Lg=`0V9RH0HF5Q04a<C01EEED0OWin04U9B@0_;bl0BTY:069RHP1SHf<0WYjN071`L00Y:BT0DU9B
06ATI01_Kfl0X:2P02`/;00Y:BT0I6AT08^;R`1IFET0GUiN07alO00^;Rh0Bd];09:BTP1aLG40EUIF
05ADE01EEED08B4Q03Ph>02KVi/0B4Q8069RHP1@D5009bLW03dm?@0Looooo`2005]KF`2FUYH0I6AT
030`<011@D40P82006QXJ011@D40RHV908J6QP19BDT0DU9B06ATI01`L700IfMW07YjNP0n?Sh0ADE5
04Y:BP1CDe<0EeMG02d];@0l?3`0;bl_0410@019BDT0Bd];04A4A01DE5@0FEUI06MWI`1@D500J6QX
05mOG`1fMWH0SHf=07emO@2MWId0UiNG06ATI01<C4`0CTi>05EEE@1TI6@0ATI605=CD`1HF5P0C4a<
03Ph>01=CDd0?clo04a<C01PH600?3`l01PH600^;Rh0E5AD04I6AP0e=CD0@d=302l_;`1=CDd0>SXj
04Y:BP15ADD0?clo04i>CP17AdL0CTi>06ATI00/;2`0De=C04A4A01=CDd0B4Q806a/K00g=cL0?Shn
04];B`0S8b<0:b/[04M7A`0^;Rh0;2`/03lo?`0g=cL0>CTi03<c<`0b<S80BDU903dm?@10@400=SHf
04=3@`16ATH0ADE503lo?`18B4P0G5aL03`l?01=CDd0DU9B04U9B@1ADE40DU9B04e=C@1CDe<0G5aL
04m?C`1PH600@41004i>CP1^KVh0HF5Q06][J`1hN7P0Shn?08N7Q`2YZJT0n?Sh0492@P1ADE40?clo
03`l?00m?Cd0FEUI05mOG`1<C4`207]kN`0b05UIF@1hN7P0N7Qh08Z:RP1`L700F5QH08Z:RP1nOWh0
F5QH06a/K01]KFd0GemO061PH00d=3@0GemO02`/;00m?Cd0BTY:0492@P13@d<0F5QH04Q8B01>CTh0
FEUI069RHP1FEUH0PH6107MgM`0R8R80Cdm?08>3P`1MGEd0];Bd06UYJ@1MGEd0De=C03`l?01QHF40
De=C0451@@0`<300B4Q803<c<`18B4P0Cdm?03Xj>P1RHV80I6AT05EEE@0m?Cd203Ph>01003/k>`1J
FUX0?Cdm06UYJ@0S8b<0EEEE03dm?@1;Bd/0Cdm?04Y:BP1OGel0;Rh^06YZJP1=CDd08R8R065QH@1:
BTX0Jf][08Z:RP1SHf<0;2`/06YZJP0g=cL0GemO04];B`1PH6008b<S059BDP1?Cdl0<30`01LG5`1A
DE40ATI603<c<`1<C4`0EEEE05IFEP18B4P0>c/k05IFEP10@400A4A403hn?P1UIFD0G5aL05YJFP1<
C4`0ATI6024Q8@1_Kfl0A4A404i>CP0d=3@0JFUY04E5A@19BDT0C4a<04M7A`1FEUH0B4Q80451@@1H
F5P0ADE507moO`80BDU902X0<c<c06UYJ@1;Bd/0:BTY02l_;`0Q8B40<C4a03De=@18B4P0ATI6061P
H01=CDd0T92@02LW9`1/K6`0DE5A04Y:BP0g=cL0PH6106IVIP1JFUX0UYJF04E5A@1BDU80Bd];05AD
E01cLg<0@T9202XZ:P1;Bd/0C4a<0861P@1hN7P0I6AT07YjNP1LG5`0DE5A05MGE`1<C4`0QhN705EE
E@23Ph<Aooooo`003oooool0h01/K6`0Q8B4059BDP2=SHd0BDU907AdM01JFUX0E5AD05EEE@0h>3P0
Fe]K08J6QP13@d<0=3@d03<c<`0h>3P0OGem06m_K`0M7Ad0?clo04E5A@0h>3P0EeMG079bLP0W9bL0
A4A403<c<`23Ph<0XZ:R02PX:00Q8B40Bd];05YJFP1]KFd0Lg=c02l_;`0l?3`0C4a<04Y:BP1JFUX0
VIVI03Lg=`0`<300C4a<03De=@1^KVh0Shn?01lO7`0Z:RX0F5QH05mOG`1;Bd/0MgMg038b<P12@T80
I6AT04U9B@17AdL0OWin034a<@0^;Rh0De=C05MGE`1:BTX0RXZ:03Lg=`0h>3P0FEUI06MWI`0d=3@0
@41004E5A@0f=SH0JVYZ03<c<`0I6AT0<S8b03hn?P0U9BD0EEEE08J6QP13@d<09bLW03/k>`0c<c<0
Xj>S0:RXZ00J6QX0;2`/04I6AP0j>SX0D51@07QhN00G5aL0;Rh^04e=C@1HF5P09bLW061PH00m?Cd0
9BDU03@d=01[Jf/0@D51079bLP0b<S805ADE0451@@1?Cdl08R8R034a<@0h>3P071`L05]KF`26QXH0
=CDe02`/;01ADE40?3`l0410@01VIVH07QhN034a<@1JFUX0@D5104E5A@2BTY80V9RH034a<@0c<c<0
Cdm?05iNGP1iNGT0ATI602HV9P0m?Cd0LG5a08B4Q01/K6`0TY:B034a<@1NGUh0K6a/051@D02IVIT0
LG5a03Xj>P14A4@0IVIV07UiN@2`/;00>3Ph03Xj>P1CDe<0P82007=cL`1EEED0ZJVY05YJFP14A4@0
M7Ad03Ph>00f=SH0De=C02TY:@0V9RH0OGem08B4Q00/;2`0ATI603/k>`0i>CT0R8R806a/K00g=cL0
ADE50410@016ATH0Q8B4034a<@0^;Rh0=cLg04m?C`1DE5@0V9RH059BDP0H61P0C4a<04Q8B01gMgL0
^[Zj01`L700O7al0CDe=04I6AP1EEED0HV9R03Ph>01BDU80P82004a<C01HF5P0EEEE024Q8@1@D500
Kfm_06IVIP1GEeL0:2PX03lo?`21PH40MgMg03lo?`1aLG40>CTi02d];@1_Kfl0JFUY03@d=010@400
?3`l04e=C@29RHT09BDU0P1;Bd/0@00e=CD0S8b<0410@00h>3P0F5QH071`L01IFET0[:b/08j>SP0V
9RH0E5AD05YJFP1ADE40ZZZZ07UiN@0f=SH0?clo069RHP1_Kfl0DU9B08>3P`0c<c<0B4Q805ADE01?
Cdl0C4a<09bLW01KFe/08b<S05iNGP1<C4`0EEEE0:RXZ00j>SX0?Cdm08n?S`2HV9P0?Shn04U9B@0o
?cl0@T9207=cL`1/K6`0;bl_04A4A018B4P08R8R03Ti>@2=SHd0@D5103Ph>01;Bd/0@41003`l?01_
Kfl0J6QX01/K6`0T92@0?3`l04a<C01oOgl0N7Qh020P800f=SHLooooo`0>05]KF`1cLg<0HV9R03dm
?@1RHV80M7Ad065QH@0i>CT0CTi>05YJFP18B4P0?Shn05ADE01`L70206i^KP2203`l?01IFET0EUIF
06MWI`0o?cl0>3Ph05ADE00i>CT0BDU904Q8B01@D500?clo04i>CP1bLW80Fe]K03Lg=`1;Bd/0HV9R
065QH@1gMgL0MWIf09nOW`2FUYH0FUYJ03dm?@1;Bd/0@D510492@P1HF5P0GemO04i>CP16ATH0EUIF
06ATI00h>3P0=3@d05EEE@1DE5@0=CDe03@d=01DE5@0EeMG04m?C`1VIVH0?clo05IFEP18B4P0DE5A
05=CD`0n?Sh0Bd];06EUI@1TI6@0IVIV03hn?P1jNWX0C4a<05ADE00`<300HF5Q059BDP1=CDd0EEEE
03/k>`0o?cl0EeMG034a<@0i>CT0@d=302HV9P0c<c<0=3@d03Ti>@1HF5P092@T055AD@0`<300C4a<
05iNGP14A4@0C4a<04=3@`18B4P0@T9204E5A@1:BTX0GUiN04m?C`0j>SX0Bd];05MGE`1NGUh0GEeM
04U9B@17AdL0BDU906YZJP1?Cdl0QhN7071`L02FUYH0]KFe0<c<c03Fe]H0Bd];05mOG`1:BTX0AdM7
04Y:BP1[Jf/0KVi^07EeM@2BTY80Ogmo04i>CP1NGUh0JFUY09:BTP24Q8@0SXj>08b<S01MGEd0IfMW
05aLG01ADE40MGEe07QhN013@d<0GemO03Ti>@80BDU901/0F5QH06a/K01TI6@0OGem06=SH`0m?Cd0
AdM703hn?P15ADD0B4Q801/K6`11@D40MgMg04M7A`1RHV80Bd];04I6AP1ADE40C4a<06UYJ@0`<300
>c/k03lo?`1DE5@0:b/[04e=C@1CDe<00P0c<c<204U9B@0R03<c<`1CDe<0@d=303Lg=`1MGEd0ADE5
05aLG00J6QX0Fe]K02PX:01:BTX0ADE505EEE@1^KVh0>SXj05eMG@1;Bd/08B4Q05eMG@0o?cl0Xj>S
03dm?@1VIVH0>3Ph06][J`1GEeL0OGem069RHP1TI6@0:RXZ059BDP1GEeL0B4Q8034a<@80DU9B04D0
B4Q8055AD@1CDe<0E5AD04M7A`0j>SX0BTY:03Xj>P16ATH0>CTi071`L01BDU80EEEE07UiN@1aLG40
=cLg06=SH`19BDT0EeMG0410@01XJ6P0CTi>06a/K01<C4`0=cLg04Y:BP1MGEd0?Shn05iNGP15ADD0
TI6A03dm?@1ADE40;Bd]069RHP1cLg<0DU9B05IFEP0a<C40B4Q8034a<@1IFET0>CTi03lo?`0/;2`0
GemO03Hf=P1OGel0@d=3079bLP1ADE40YJFU07=cL`1oOgl0]kNg05ADE01fMWH0GEeM03lo?`1@D500
@d=30410@00h>3P0@D5105MGE`1DE5@0DE5A04i>CP1HF5P00P1TI6@01019BDT0L71`055AD@1^KVhA
ooooo`003oooool07P1YJFT0GEeM05=CD`2MWId0De=C069RHP1`L700X:2P09NGU`0g=cL0GEeM05YJ
FP1XJ6P0RHV906UYJ@1?Cdl0EUIF06m_K`1PH600WYjN03<c<`0Y:BT0<C4a05UIF@1ZJVX0TI6A01PH
600n?Sh0GemO06MWI`80MGEe02T0EUIF02d];@1ZJVX0?clo05eMG@1VIVH0;bl_01/K6`1?Cdl0KFe]
02<S8`18B4P0:RXZ079bLP1oOgl0=SHf034a<@1MGEd0<30`02HV9P24Q8@0?clo03Ph>00o?cl0?Shn
04m?C`2ATI40BTY:01TI6@0i>CT0AdM706MWI`2BTY80DU9B02<S8`18B4P0=cLg03dm?@1eMGD0LW9b
020P800206ATI03G06=SH`1mOGd0?3`l014A4@10@400DU9B05MGE`19BDT0:b/[020P8016ATH0Hf=S
06e]K@0_;bl0M7Ad02HV9P0_;bl0D51@03Ti>@0g=cL0IVIV02<S8`19BDT0SHf=05IFEP0E5AD0<S8b
02l_;`0e=CD0SXj>07YjNP0U9BD0>SXj04e=C@15ADD0GemO04E5A@0N7Qh0ADE505eMG@0j>SX0IfMW
09VIV@0f=SH0:RXZ05iNGP1?Cdl0EUIF0<71`@0i>CT07AdM05]KF`1jNWX0@T9204a<C00/;2`0>SXj
06e]K@1YJFT0@41005eMG@0N7Qh0<C4a06UYJ@2^[Zh0AdM705YJFP0^;Rh0@D5105IFEP1TI6@0;bl_
04M7A`1ADE40<c<c08:2PP1MGEd07alO05mOG`13@d<0:b/[06e]K@32`/80IfMW03`l?01@D500De=C
08^;R`2FUYH0>3Ph01@D501@D500N7Qh05IFEP2?Shl0;Rh^02d];@15ADD0IfMW075aL@2FUYH0A4A4
02d];@1aLG40KFe]06][J`1PH600=SHf02l_;`1OGel0UiNG04U9B@1aLG40ATI604];B`2d];@0M7Ad
04Q8B01OGel0ADE503hn?P2RXZ80RXZ:03@d=01oOgl0G5aL08j>SP26QXH0:BTY02d];@1>CTh0CDe=
08V9R@0k>c/0=SHf04U9B@10@400I6AT0;>c/`1LG5`071`L03lo?`1fMWH0JVYZ07UiN@0L71`0<S8b
05aLG00o?cl0LW9b07inOP0c<c<0CTi>04Q8B01NGUh0KFe]02`/;013@d<0EEEE06MWI`0o?cl0GUiN
02XZ:P17AdL0Bd];06ATI013@d<0C4a<04M7A`0f=SH0ATI606i^KP0k>c/0Cdm?04i>CP0k>c/0ADE5
07YjNP26QXH0;Rh^05YJFP19BDT0HV9R0<C4a02e]KD0=cLg04A4A01WIfL0EeMG079bLP13@d<0=SHf
04Y:BP1CDe<0@410075aL@1JFUX09BDU01dM7@1<C4`0GemO06YZJP1PH600820P04e=C@1aLG40KVi^
024Q8@18B4P0IFEU03De=@16ATH0MWIf02@T9014A4@07?ooool0601<C4`0MgMg06a/K016ATH0?Cdm
05QHF01IFET0?3`l06ATI01aLG40Bd];06IVIP20P800HF5Q07UiN@2>SXh0?clo0492@P15ADD0NWYj
05iNGP0U9BD0=CDe02/[:`80B4Q800X0GEeM0492@P1PH600C4a<075aL@13@d<0Bd];079bLP1oOgl0
LW9b0P2][Jd0=02DU9@0IfMW0492@P1ADE40@41005iNGP0e=CD0Cdm?05=CD`18B4P0CTi>05ADE00c
<c<0>SXj06=SH`15ADD06ATI02LW9`1@D500Cdm?04U9B@16ATH07alO03hn?P1ADE40BTY:04U9B@1E
EED0EUIF03`l?014A4@0DU9B04m?C`1aLG40GemO05eMG@1@D500L71`03lo?`0l?3`0HV9R03lo?`13
@d<0ADE503Ph>00i>CT0?3`l03De=@13@d<0;Bd]03Lg=`15ADD203Ph>03602l_;`1;Bd/0=SHf0451
@@1?Cdl0BDU906MWI`11@D40De=C05ADE00m?Cd0ADE505IFEP1IFET0E5AD059BDP1:BTX0EeMG05EE
E@1BDU80NGUi05ADE02:RXX0N7Qh08J6QP2b/[80d=3@0;Bd]01VIVH0JFUY04i>CP0o?cl0ATI605aL
G01lO7`0GemO0:VYZ@2BTY80MGEe092@T01aLG40JVYZ04U9B@1EEED0LG5a071`L01oOgl0L71`04M7
A`0m?Cd0Fe]K04a<C01ADE408B4Q03/k>`1IFET0Fe]K069RHP0k>c/0>SXj03hn?P0j>SX0E5AD07in
OP1jNWX0Jf][00/;2`16ATH0MGEe05iNGP2h^;P0IFEU051@D01:BTX0@d=305]KF`10@400>c/k03Lg
=`1=CDd061PH04=3@`17AdL0>SXj061PH01IFET0CTi>03De=@19BDT0<S8b03Hf=P1:BTX0>SXj05MG
E`0/;2`0D51@04Y:BP1kNg/0FEUI05YJFP1lO7`0=CDe05eMG@1FEUH0AdM705QHF01=CDd0?Cdm030`
<01RHV80?Shn051@D018B4P0GUiN05eMG@1TI6@061PH065QH@1TI6@0GEeM02PX:01CDe<0Cdm?07Yj
NP1IFET0GEeM04A4A01EEED0AdM704Y:BP0o?cl0DE5A038b<P1HF5P0H61P05QHF01:BTX0GUiN03Xj
>P1ZJVX0JFUY06EUI@1FEUH0I6AT04Q8B01NGUh0Cdm?03/k>`0n?Sh0C4a<03hn?P1TI6@0@d=308V9
R@15ADD0DE5A03lo?`1nOWh0EEEE06=SH`29RHT0@4100451@@0_;bl0AdM70492@P1ADE40HV9R0:FU
Y@1@D500N7Qh04e=C@2EUID0DE5A07moO`1HF5P0DU9B08N7Q`1EEED0De=C06IVIP1KFe/0Jf][04I6
AP0b<S80@4100451@@1PH600MGEe05iNGP1[Jf/0De=C06=SH`1MGEd0AdM707moO`1EEED0LG5a4Ooo
ool000oooooo0?l0/K6a05eMG@1=CDd0VYZJ07]kN`1cLg<0>CTi07QhN02KVi/0EeMG08>3P`1kNg/0
<S8b04a<C028R8P0ATI6061PH00f=SH0FUYJ071`L01[Jf/0>CTi05iNGP19BDT0Bd];09jNWP1?Cdl0
@d=305EEE@0M7Ad0?Shn09:BTP1RHV80=3@d03hn?P0i>CT0Jf][08F5Q@0g=cL0:BTY04=3@`1BDU80
GUiN06ATI00G5aL08R8R05]KF`0o?cl0JVYZ0:FUY@11@D407AdM02l_;`17AdL0Ph>308b<S00E5AD0
:BTY03@d=01]KFd0AdM7075aL@0_;bl071`L05QHF01OGel0>c/k07EeM@0f=SH071`L02@T901YJFT0
=SHf04e=C@0@4100ADE509JFUP1PH600=3@d02XZ:P1QHF40>SXj05ADE01eMGD05aLG03@d=012@T80
?Cdm04A4A02@T900@410034a<@1FEUH0@D5105YJFP2OWil04Q8B01/K6`18B4P0GemO03dm?@1@D500
9BDU03Ph>019BDT0IfMW04Y:BP1YJFT0820P02/[:`16ATH0EEEE03Lg=`24Q8@0EUIF02LW9`0X:2P0
C4a<04m?C`0a<C40B4Q802DU9@18B4P0LG5a08R8R00i>CT0Cdm?04Y:BP1ADE40Shn?03Hf=P0S8b<0
ADE505=CD`1ADE40UiNG0492@P0Y:BT0ADE5051@D01/K6`0UiNG02XZ:P14A4@0EeMG05eMG@0f=SH0
IfMW07]kN`0j>SX0A4A4055AD@0m?Cd0Ti>C07=cL`0];Bd0:RXZ05mOG`1]KFd0EEEE07MgM`0Q8B40
=cLg092@T020P800;2`/05IFEP0T92@0>c/k06YZJP13@d<0>3Ph05ADE00N7Qh0>CTi08J6QP2>SXh0
:BTY04];B`0c<c<0V9RH0:NWY`1=CDd09bLW04M7A`0j>SX0I6AT0<o?c`1WIfL0<30`055AD@1HF5P0
Ng]k09NGU`0i>CT09BDU05QHF02IVIT0MGEe0410@01EEED0De=C0:BTY01fMWH0J6QX06EUI@0K6a/0
H61P071`L01JFUX0KFe]024Q8@0`<300Kfm_09nOW`1BDU80JFUY03@d=01XJ6P0Ng]k04=3@`1>CTh0
@T92020P801_Kfl0ZJVY03dm?@15ADD0<C4a04Q8B02RXZ80GemO02h^;P1JFUX0DE5A05MGE`2FUYH0
;Rh^03Lg=`1TI6@0Bd];05eMG@1eMGD0ZJVY02LW9`0j>SX0GemO07alO02IVIT0Vi^K02TY:@0l?3`0
?clo06UYJ@13@d<001T0SXj>0492@P0e=CD0JVYZ096AT@1cLg<0Q8B4065QH@0N7Qh0DU9B079bLP14
A4@0J6QX02PX:00g=cL0DE5A06EUI@0l?3`0BDU9069RHP0^;Rh0?Cdm07UiN@10@4008b<S0080FUYJ
00P0A4A404i>CP1_Kfl09BDU03Ti>@0_;bl0=cLg05YJFQcooooo08h0KVi^079bLP1@D500=CDe055A
D@1aLG40EUIF04Q8B01gMgL0IVIV04E5A@11@D40HF5Q08b<S02QXJ40FEUI03dm?@1DE5@0BTY:06QX
J019BDT0<C4a03Ph>01EEED0CDe=03Ti>@1]KFd0IfMW06ATI01<C4`0K6a/06][J`1]KFd0MGEe09ZJ
VP2i^KT0X:2P08f=S@2>SXh0QXJ602HV9P12@T80HF5Q06m_K`13@d<0EUIF061PH01FEUH0D51@05EE
E@0U9BD0@D5107QhN019BDT06ATI02/[:`1TI6@0GEeM04i>CP1LG5`0;2`/05aLG00n?Sh0E5AD04e=
C@1FEUH0E5AD04Q8B01DE5@0I6AT03<c<`1XJ6P0A4A405UIF@0e=CD0J6QX0492@P11@D40NWYj03/k
>`12@T80IVIV03`l?00h>3P0A4A402h^;P0];Bd0;bl_03@d=01KFe/0;Bd]03De=@0T92@0Bd];03dm
?@0i>CT0A4A403Hf=P1;Bd/0>c/k04I6AP0n?Sh0?3`l04];B`10@400BDU904];B`1<C4`0DU9B04Q8
B011@D40Bd];06UYJ@1[Jf/0QhN705eMG@1oOgl0U9BD020P801:BTX0HF5Q04];B`0o?cl0BDU905EE
E@1IFET0J6QX07moO`2XZ:P0R8R805mOG`1gMgL0S8b<0;Fe]@1kNg/0Hf=S075aL@1dM7@0IFEU06m_
K`1NGUh0CTi>0P1MGEd0TP1[Jf/0=3@d03hn?P1<C4`0I6AT079bLP1TI6@0BDU905IFEP1EEED0GUiN
038b<P0o?cl0DE5A02XZ:P1CDe<0CTi>04E5A@1PH600FUYJ059BDP1NGUh0EEEE07alO01IFET0Cdm?
03hn?P1CDe<0=CDe059BDP1HF5P0?clo03Lg=`19BDT0>SXj03/k>`12@T80;Bd]02<S8`16ATH0EUIF
06m_K`0N7Qh0CDe=030`<01NGUh0D51@061PH02BTY80@T92059BDP1LG5`0>3Ph06i^KP1=CDd0@410
01hN7P1DE5@0ADE509JFUP1`L700F5QH05IFEP1fMWH0;2`/05YJFP1PH600?Shn020P801PH600FUYJ
04m?C`10@400C4a<05ADE013@d<0A4A405ADE00o?cl0?Cdm03Ph>01JFUX0GEeM05UIF@1CDe<0M7Ad
034a<@1ZJVX0ATI6055AD@15ADD0GemO04M7A`15ADD0JVYZ03lo?`15ADD0EUIF03Ph>01MGEd0ADE5
07inOP14A4@0BTY:01/K6`1?Cdl0ATI604A4A01CDe<0<c<c05=CD`1JFUX0CDe=03Xj>P10@400?clo
05MGE`0k>c/0KVi^071`L01VIVH0CTi>0=7Ad@2GUiL0R8R809nOW`1CDe<0DU9B03hn?P0_;bl0@d=3
05]KF`0Z:RX0?clo03`l?02<S8`0Fe]K0820P01kNg/0EEEE06i^KP1]KFd0F5QH0::RXP19BDT0OGem
4Oooool000oooooo0?l0Jf][07EeM@1DE5@0M7Ad05=CD`2EUID0Cdm?05MGE`1JFUX0CDe=07]kN`2H
V9P0DE5A04e=C@19BDT0G5aL08j>SP1^KVh0<C4a06i^KP17AdL0Cdm?07=cL`1UIFD0ADE507]kN`19
BDT0PH6108n?S`12@T80<S8b05YJFP1TI6@0IFEU05YJFP0Y:BT0;Rh^04=3@`1>CTh0De=C09^KV`0l
?3`07QhN05=CD`0b<S80IFEU07alO00U9BD0=3@d06IVIP1[Jf/0E5AD0861P@0d=3@0AdM705MGE`17
AdL0DE5A0820P00c<c<0:BTY05mOG`1MGEd0CDe=05EEE@0W9bL0Bd];08B4Q029RHT0<C4a0410@012
@T80?3`l06i^KP12@T80:BTY04E5A@0g=cL0=3@d04E5A@1gMgL0>CTi03Xj>P17AdL0:RXZ07=cL`1_
Kfl07alO02PX:01<C4`0De=C04U9B@1DE5@05aLG02/[:`1GEeL0=SHf03<c<`1UIFD0=3@d02XZ:P1O
Gel0=cLg03hn?P1YJFT0>3Ph03Lg=`1CDe<0Bd];020P8012@T80@41003/k>`1lO7`0OWin02XZ:P0l
?3`0C4a<02d];@11@D40Q8B402LW9`0/;2`0DU9B0492@P0i>CT0PH6109bLW00V9RH0@d=30410@01=
CDd0Ng]k0492@P0e=CD0E5AD061PH00f=SH0Fe]K07MgM`0^;Rh0GemO05]KF`0i>CT0C4a<04m?C`0N
7Qh0D51@07QhN016ATH0Kfm_02@T900X:2P0QHF508V9R@0P8200;bl_05YJFP0m?Cd0GemO07moO`0^
;Rh0<C4a06IVIP1CDe<0B4Q807IfMP1PH600>c/k05aLG01;Bd/0HV9R07alO012@T809bLW04a<C01E
EED0?3`l07]kN`0`<300=SHf05EEE@12@T80EeMG08F5Q@1UIFD0:RXZ04Y:BP1GEeL0Hf=S08B4Q00R
8R807alO075aL@1dM7@0?Cdm06EUI@0e=CD0Bd];05IFEP12@T80Fe]K05aLG00b<S80F5QH06i^KP10
@400G5aL034a<@1>CTh0RHV903Xj>P0d=3@0Bd];03@d=00j>SX0L71`059BDP1@D500@D5104I6AP1a
LG40KFe]02<S8`18B4P0?clo03@d=01kNg/0=CDe038b<P1BDU80B4Q806][J`2VYZH0GemO03De=@1L
G5`0ATI6061PH02MWId0JVYZ03De=@1@D500Hf=S04];B`20P800K6a/02HV9P1>CTh0Fe]K055AD@1J
FUX0SXj>04Q8B00Y:BT002<0HF5Q051@D01ZJVX0Ogmo03Lg=`0o?cl0OWin08^;R`10@400FUYJ03De
=@1DE5@0RHV906MWI`0/;2`0Bd];03lo?`0e=CD0Cdm?092@T01>CTh0A4A404m?C`10@400CDe=09:B
TP1CDe<0:BTY0492@P10@400@D5108V9R@1PH6009BDU03Hf=P0Looooo`0_05MGE`1_Kfl0JFUY051@
D016ATH0HV9R05]KF`0l?3`0JFUY06e]K@1>CTh0H61P07AdM01gMgL0O7al08^;R`0i>CT0BTY:04U9
B@1SHf<0Cdm?02@T900m?Cd0?3`l055AD@15ADD0Cdm?04a<C01CDe<0CTi>051@D01>CTh0HF5Q05aL
G01]KFd0OWin06][J`23Ph<0O7al059BDP0h>3P0?clo055AD@1GEeL0@D5105=CD`1>CTh00P1=CDd0
2@1IFET0@41005mOG`1MGEd0CTi>02h^;P1:BTX0FEUI05ADE00205YJFP0603dm?@1;Bd/0F5QH061P
H01RHV80IFEU0P1ZJVX0VP1TI6@0FUYJ04=3@`1[Jf/0EUIF061PH012@T80Lg=c06EUI@1?Cdl0IVIV
0451@@14A4@0HV9R03/k>`0e=CD0Cdm?03hn?P0b<S80>CTi04];B`1JFUX0?Shn0492@P0U9BD0ATI6
04Y:BP15ADD0C4a<03`l?01JFUX0BDU9059BDP1>CTh0C4a<04U9B@1CDe<0GEeM059BDP1ADE40B4Q8
05MGE`1MGEd0D51@06e]K@1>CTh0MGEe06e]K@1XJ6P0MWIf04m?C`1bLW80GUiN05mOG`1@D500?Shn
04U9B@1YJFT0Ng]k07moO`1fMWH0PH6107IfMP2BTY80XZ:R0:VYZ@1NGUh0OWin07EeM@1]KFd0Shn?
05aLG01IFET0Cdm?06QXJ011@D40D51@02d];@14A4@0?clo04Y:BP1dM7@0AdM704Q8B017AdL0>CTi
05ADE01ADE40E5AD06YZJP0W9bL0ADE5065QH@1SHf<0RXZ:059BDP1<C4`0DU9B05MGE`1PH600AdM7
0492@P14A4@0Cdm?02@T900o?cl0CDe=03hn?P17AdL0GUiN04Q8B00o?cl0ADE503lo?`0T92@0@410
03@d=01>CTh092@T038b<P0T92@0C4a<03dm?@13@d<0HF5Q02LW9`1nOWh0IVIV01lO7`18B4P0<C4a
04=3@`0V9RH0FUYJ03Hf=P1`L700CTi>06=SH`1KFe/0PX:202XZ:P1WIfL0JFUY03Hf=P0^;Rh0FUYJ
05MGE`1hN7P0Cdm?05eMG@1?Cdl0EUIF04E5A@16ATH204=3@`0Q03Hf=P1FEUH0F5QH059BDP1MGEd0
JFUY03Ph>01hN7P0BDU906ATI013@d<0Kfm_04Y:BP1@D500FUYJ03@d=00V9RH0CDe=02h^;P1KFe/0
@D51096AT@17AdL0CTi>03De=@1QHF40BTY:06MWI`1bLW80@d=304];B`0Z:RX0CDe=0080ATI601l0
Bd];05IFEP0W9bL0GUiN0451@@1_Kfl0E5AD07QhN01@D500Bd];07=cL`1FEUH0KFe]05iNGP13@d<0
CTi>04I6AP0_;bl0>SXj04=3@`1NGUh0DU9B05aLG01YJFT0DU9B05eMG@1OGel0E5AD06=SH`1FEUH0
Ng]k017ooooo000?ooooo`3T06][J`1=CDd0Cdm?09jNWP1EEED0IVIV04U9B@1kNg/0SHf=03Ph>01:
BTX0CTi>055AD@2SXj<0BTY:02@T901HF5P0C4a<06ATI032`/80;Bd]02@T900a<C40HV9R06a/K02?
Shl0:b/[024Q8@13@d<0FEUI079bLP31`L40@T9204M7A`1DE5@0GemO07inOP29RHT06QXJ04I6AP1U
IFD0Kfm_05MGE`1lO7`0:BTY03/k>`1FEUH0E5AD06a/K02NWYh09BDU02LW9`19BDT0FEUI07QhN00m
?Cd07AdM02`/;01iNGT0FUYJ02PX:019BDT07QhN0492@P23Ph<0>SXj01TI6@0h>3P0D51@03Ph>01/
K6`0C4a<01PH6010@400=3@d069RHP2/[:`0<30`01LG5`0Z:RX0Hf=S059BDP22PX80@41002XZ:P0O
7al0EeMG059BDP1DE5@0Vi^K018B4P0/;2`0N7Qh059BDP1TI6@0QHF501@D500K6a/0=cLg05UIF@0S
8b<0LG5a01DE5@0D51@0FUYJ0492@P0H61P0Cdm?01dM7@0T92@0@d=305UIF@0J6QX0EEEE04];B`0e
=CD0LW9b09>CT`0a<C406a/K04A4A012@T80K6a/07alO00G5aL05QHF03/k>`1VIVH0EeMG07alO016
ATH09bLW05eMG@1_Kfl0MGEe05iNGP0m?Cd0<c<c04U9B@1DE5@0F5QH06ATI00Z:RX0<c<c05=CD`1F
EUH071`L03Ph>013@d<0B4Q809JFUP1ZJVX09bLW04A4A01ADE40<c<c06][J`2VYZH0ADE502PX:01B
DU80>SXj06=SH`1mOGd0>c/k02@T901JFUX0@d=30451@@2ZZZX09bLW02`/;01NGUh0GEeM04m?C`2P
X:00Hf=S02HV9P1UIFD0Cdm?07AdM021PH40>c/k020P800n?Sh0QXJ6051@D01JFUX0E5AD0492@P1O
Gel0JFUY05YJFP1XJ6P0@4100492@P1]KFd0EUIF04I6AP0g=cL0:b/[06e]K@2MWId0IFEU03hn?P1J
FUX0<c<c06UYJ@19BDT0=cLg04i>CP0i>CT0MgMg09fMW@0n?Sh06ATI03Hf=P15ADD0ZZZZ065QH@0P
8200CTi>05EEE@1;Bd/0P82005IFEP0M7Ad0GEeM0P1RHV80:P2=SHd09BDU03Ti>@1LG5`0QXJ605aL
G01cLg<0AdM7055AD@1LG5`0I6AT05MGE`1]KFd0HF5Q02/[:`0k>c/0GemO03Ti>@1BDU80?clo028R
8P1>CTh0O7al06=SH`17AdL0KFe]030`<01KFe/0RHV905ADE00];Bd0Hf=S03Lg=`0`<300JVYZ05UI
F@0S8b<0?Cdm03hn?P1DE5@0JVYZ055AD@80820P0100?Shn04e=C@2<S8`0Ng]k01dM7@0O7al0De=C
08:2PP0m?Cd0QXJ606UYJ@0[:b/0AdM707=cL`1=CDd0L71`7?ooool02@1@D500N7Qh05IFEP0Z:RX0
=SHf071`L01lO7`0BTY:05eMG@0205ADE014051@D01gMgL0Y:BT09fMW@1YJFT0?Cdm05mOG`1MGEd0
JFUY04];B`0];Bd0ADE503Lg=`1<C4`0?Cdm05aLG01<C4`0PH6104a<C01KFe/0@T9204m?C`1FEUH0
KFe]05aLG01nOWh0Z:RX09BDU01iNGT0;Rh^02TY:@0c<c<0B4Q803/k>`1>CTh0DE5A04i>CP17AdL0
EeMG03Ti>@1MGEd0IFEU04U9B@0X:2P0K6a/07=cL`1BDU80BDU9071`L01IFET0Fe]K04a<C01bLW80
OWin04];B`1@D500JVYZ05YJFP1KFe/0DE5A06YZJP19BDT0JVYZ05IFEP1]KFd0ATI603Hf=P1dM7@2
05EEE@0G061PH00d=3@0>SXj051@D00f=SH0@41002d];@0k>c/0D51@03dm?@0h>3P0820P059BDP1E
EED0?Cdm04];B`1<C4`0EeMG04Y:BP1EEED0B4Q805eMG@1=CDd00P1EEED0CP1BDU80GEeM04i>CP1L
G5`0?clo04M7A`1PH600JVYZ06i^KP1NGUh0EeMG05aLG017AdL0Fe]K05YJFP1BDU80>SXj0492@P18
B4P0IfMW04a<C01cLg<0QXJ607moO`2NWYh0a<C40>GUi@3Jf]X0L71`0=3@d02?Shl0P82009NGU`1X
J6P0IfMW04Y:BP1XJ6P0C4a<06EUI@0a<C40@41003hn?P1VIVH0MGEe04E5A@1;Bd/0KFe]04A4A01@
D500>CTi04m?C`1LG5`06ATI05]KF`1HF5P0DU9B06MWI`1:BTX0IVIV06=SH`1JFUX0IfMW06QXJ01E
EED0?clo04a<C00_;bl0>SXj04];B`0b<S80BDU905MGE`18B4P0BTY:069RHP0m?Cd09bLW04e=C@80
DE5A02D0?Shn03/k>`0R8R80EUIF03Hf=P1;Bd/0JFUY01hN7P1@D500FUYJ02d];@1fMWH07QhN03hn
?P0K6a/0BTY:03Hf=P1FEUH0A4A404Y:BP1?Cdl0M7Ad01`L701SHf<0Ng]k03Xj>P0_;bl0IFEU06YZ
JP1VIVH0DE5A05eMG@1LG5`0@T9203Xj>P1FEUH0?Shn0080<c<c0440FUYJ055AD@1KFe/0Lg=c06MW
I`0b<S80Ph>303Hf=P0o?cl0<c<c05iNGP14A4@0C4a<059BDP1<C4`0EeMG04i>CP1DE5@0D51@04E5
A@1nOWh0=3@d04a<C00N7Qh0M7Ad071`L01nOWh0RHV903<c<`1gMgL0=3@d04];B`1kNg/0J6QX07]k
N`1oOgl0?clo08n?S`13@d<0I6AT0410@02e]KD0IFEU055AD@1kNg/0E5AD05UIF@1;Bd/0B4Q8055A
D@13@d<07AdM051@D01CDe<0XJ6Q05eMG@1ZJVX0I6AT06IVIP1fMWH0H61P05YJFP1dM7@0C4a<05eM
G@0Aooooo`003oooool0X@2/[:`0CTi>04e=C@1LG5`0Lg=c08:2PP12@T80Hf=S07alO01BDU80UiNG
04e=C@0j>SX0MWIf071`L01=CDd0MgMg059BDP0m?Cd0MgMg09RHV01QHF40JFUY02d];@0g=cL0Kfm_
04U9B@1RHV80G5aL02<S8`0];Bd0F5QH08:2PP16ATH0B4Q801`L701SHf<0ZJVY05eMG@0X:2P0>3Ph
03De=@0a<C40IVIV01TI6@0b<S80;Rh^024Q8@1BDU80WinO04I6AP0L71`0<S8b04a<C02LW9`0QhN7
02XZ:P0e=CD0E5AD04I6AP1FEUH0TI6A02`/;00R8R80EeMG06e]K@1CDe<0RHV903Ph>00X:2P0>CTi
06a/K01NGUh0GEeM01XJ6P0U9BD0De=C06=SH`0e=CD0Fe]K06ATI00T92@0AdM7061PH00W9bL0=SHf
03Ti>@0H61P0<S8b07UiN@0m?Cd0>3Ph03Hf=P0e=CD0Cdm?09ZJVP0W9bL06QXJ02l_;`0b<S809BDU
08:2PP0S8b<07AdM02LW9`1:BTX0JVYZ0820P00c<c<051@D02HV9P1ADE40EEEE08V9R@1YJFT05ADE
038b<P2DU9@0Lg=c05YJFP1>CTh08b<S03dm?@1nOWh0IVIV02@T901CDe<09BDU01lO7`1WIfL0FUYJ
02l_;`0k>c/09BDU03Lg=`24Q8@0Kfm_01lO7`0n?Sh0>SXj05]KF`2f][H0GemO02DU9@1GEeL0EEEE
02d];@1IFET0L71`028R8P1nOWh0NWYj06UYJ@27QhL0?Cdm0410@019BDT0IVIV06QXJ01ZJVX0@T92
0080:BTY04@0IFEU075aL@1<C4`0RHV904a<C00];Bd0LG5a05iNGP15ADD0GEeM01`L700U9BD0Fe]K
0820P00a<C40C4a<038b<P0h>3P0V9RH06EUI@0[:b/0ADE505=CD`0a<C40Ph>305]KF`14A4@0ATI6
034a<@1fMWH0dM7A0820P00/;2`0IVIV05IFEP1/K6`0FUYJ02PX:00a<C40M7Ad05aLG01CDe<0G5aL
02LW9`1FEUH0DU9B05iNGP1/K6`06a/K04E5A@1[Jf/0N7Qh0410@01^KVh0;bl_059BDP1oOgl0?3`l
04Y:BP0g=cL0;bl_05YJFP1iNGT0=cLg05ADE011@D40@T9205mOG`80AdM703T0H61P03Xj>P15ADD0
Ti>C03De=@19BDT0ATI603Lg=`1>CTh0Ph>306MWI`0S8b<0ATI605EEE@1GEeL0XJ6Q0:RXZ00T92@0
:BTY06ATI01GEeL0C4a<0;bl_014A4@0>SXj06e]K@28R8P0DU9B0;Jf]P1[Jf/0820P05EEE@1KFe/0
ADE5079bLP0Y:BT0;bl_05IFEP1GEeL0;bl_04A4A01hN7P0<c<c0451@@26QXH0DU9B02HV9P17AdL0
6ATI030`<01;Bd/0GUiN02`/;015ADD0=cLg034a<@1IFET07?ooool0:@1CDe<0PH6109:BTP1<C4`0
>SXj04m?C`14A4@0:2PX06a/K024Q8@0De=C04m?C`1NGUh0HV9R08J6QP1VIVH0EEEE04i>CP17AdL0
R8R804M7A`0N7Qh0>CTi03Ph>01:BTX0@d=3055AD@19BDT0HV9R06][J`1XJ6P0AdM705EEE@1bLW80
N7Qh07inOP1cLg<0QhN709VIV@29RHT0C4a<0080?Shn0480F5QH05MGE`1ZJVX0I6AT05mOG`1XJ6P0
LW9b02XZ:P0j>SX0Fe]K05MGE`0Q8B40;Bd]051@D01RHV80IfMW04U9B@0[:b/0C4a<055AD@1WIfL0
F5QH04];B`1EEED0C4a<04i>CP16ATH0>CTi05mOG`1PH600BTY:02`/;01DE5@0JVYZ05QHF01NGUh0
=CDe02LW9`1EEED0>c/k02PX:01=CDd0@T9202@T900k>c/0E5AD059BDP0d=3@0?3`l02LW9`0l?3`0
@D5103Ti>@0g=cL0;Rh^04E5A@0k>c/0?clo04=3@`0l?3`0>SXj03Ph>018B4P0E5AD04I6AP17AdL2
051@D00E05=CD`1]KFd0B4Q807YjNP1`L700EeMG07inOP1cLg<0X:2P059BDP1/K6`0JVYZ04U9B@1B
DU80I6AT06QXJ027QhL0WinO0;:b/P1`L700OGem0080d];B01d0GUiN04a<C016ATH0EUIF07]kN`1R
HV80CDe=04Q8B01FEUH0ATI605iNGP0i>CT0?Shn02XZ:P11@D40OGem06IVIP1]KFd0FEUI04A4A01@
D500DE5A04I6AP1LG5`08b<S03lo?`1GEeL0J6QX08^;R`0204Y:BP1m04M7A`1@D500HV9R03dm?@16
ATH0D51@05MGE`0i>CT0D51@05QHF00j>SX0?clo05aLG01JFUX0>CTi0451@@1?Cdl0:b/[0451@@0X
:2P0FEUI028R8P0e=CD0A4A405eMG@16ATH0:b/[04Q8B00F5QH0GEeM07UiN@0U9BD0DE5A028R8P18
B4P0<c<c05]KF`19BDT0H61P05YJFP1LG5`0EEEE08b<S00f=SH0Jf][06ATI01JFUX0ADE506m_K`1<
C4`0PX:205MGE`1OGel0FUYJ05IFEP18B4P0De=C04U9B@18B4P0@T9206UYJ@1EEED0FEUI059BDP1Q
HF40?clo06QXJ01ADE40J6QX04A4A025QHD0JVYZ05iNGP1>CTh0@T9204Q8B01PH600=cLg05MGE`11
@D40DU9B04M7A`18B4P0;bl_04a<C00k>c/0LG5a05EEE@0e=CD0@T9201`L7013@d<0CDe=03<c<`18
B4P0CDe=04=3@`1`L700>c/k07MgM`19BDT0Kfm_04e=C@1SHf<0XZ:R04Q8B01IFET0C4a<04];B`1M
GEd0N7Qh04Y:BP19BDT0<c<c061PH01NGUh0GEeM08N7Q`1/K6`0Hf=S05eMG@1EEED0GEeM05UIF@1k
Ng/04Oooool000oooooo00H0MgMg06i^KP1FEUH0NGUi04];B`2WYjL205IFEP1/04e=C@11@D40SXj>
09ZJVP1>CTh0DE5A05aLG01KFe/0GUiN03dm?@0_;bl0I6AT04e=C@25QHD0YjNW03Hf=P0[:b/0FEUI
03dm?@1>CTh0S8b<03@d=00X:2P0CDe=06=SH`1dM7@0>CTi02HV9P0M7Ad0DU9B05MGE`1mOGd0Kfm_
01@D500N7Qh0IFEU0492@P27QhL0H61P01`L700K6a/0AdM705iNGP1:BTX0TI6A02DU9@1JFUX0Fe]K
04Y:BP12@T80RXZ:02TY:@0U9BD0HF5Q0492@P0a<C40?3`l02LW9`0T92@0B4Q804i>CP0U9BD0E5AD
02l_;`1>CTh0Ogmo02<S8`0M7Ad0=cLg03De=@0a<C40IVIV07UiN@0N7Qh0:RXZ04i>CP16ATH0MGEe
07IfMP0P8200;2`/04A4A022PX80LG5a04M7A`0_;bl0>c/k05MGE`1DE5@0CDe=05mOG`0K6a/08R8R
03`l?010@400;bl_061PH00G5aL0;Rh^0451@@1BDU807AdM034a<@0k>c/0<C4a05aLG01WIfL07QhN
0P0c<c<0A00l?3`0KVi^06EUI@0B4Q809RHV03Ph>01<C4`0DE5A0:>SX`1EEED03`l?02LW9`1BDU80
LW9b06a/K00a<C40:BTY04Y:BP1TI6@0EeMG08>3P`1KFe/0:RXZ03`l?028R8P0FEUI08>3P`1OGel0
:BTY04U9B@1=CDd0@d=306YZJP0Q8B40AdM706EUI@1ZJVX0:BTY04Y:BP2DU9@0CTi>075aL@2EUID0
9RHV03/k>`1JFUX0:BTY03dm?@2`/;00Hf=S02DU9@0m?Cd0IVIV06][J`2/[:`0;2`/034a<@16ATH0
MWIf06IVIP1dM7@08b<S038b<P0g=cL0KFe]05eMG@1oOgl0AdM70P0_;bl0=01EEED0VIVI09FEU@0R
8R80820P059BDP23Ph<0C4a<06i^KP0e=CD0;Rh^065QH@0f=SH0A4A4038b<P0V9RH0@d=305]KF`0h
>3P0A4A402TY:@1HF5P0Y:BT04i>CP0i>CT0Bd];04A4A00d=3@0PH6105EEE@0_;bl0>CTi04i>CP2:
RXX0BDU902DU9@15ADD0>SXj0492@P2PX:00;bl_05UIF@1HF5P0ADE50861P@2XZ:P0Fe]K030`<01L
G5`0CDe=07=cL`1gMgL203De=@0`09>CT`2^[Zh0BTY:07UiN@1CDe<0;bl_0492@P1aLG40IFEU05aL
G02=SHd0>3Ph02TY:@1HF5P0FUYJ0410@019BDT09bLW03/k>`1[Jf/0MGEe03lo?`1FEUH0>c/k04];
B`2?Shl0B4Q801lO7`17AdL0?Shn01hN7P1:BTX0WinO03/k>`14A4@0ADE50492@P1]KFd0/K6a02DU
9@0`<300<C4a05eMG@0f=SH0Q8B402/[:`1>CTh0Bd];7?ooool0>@1>CTh0QHF505MGE`0L71`0?clo
07YjNP1GEeL0:RXZ04I6AP1OGel0LW9b04M7A`1YJFT0Ogmo09JFUP24Q8@0AdM705UIF@1?Cdl0RXZ:
06UYJ@0a<C40Cdm?05IFEP1CDe<0CDe=06e]K@14A4@0QhN705ADE01UIFD0Bd];04i>CP1/K6`0TI6A
08V9R@2KVi/0UYJF07emO@1dM7@0<C4a03Xj>P0e=CD0EeMG03Hf=P16ATH0CDe=04Y:BP12@T80HV9R
03@d=00n?Sh0Hf=S04Y:BP0];Bd0>c/k05QHF00204A4A00304a<C00f=SH0DU9B0080IVIV03/0I6AT
06UYJ@1/K6`0CDe=05MGE`1TI6@0E5AD051@D00d=3@0G5aL061PH01ZJVX0C4a<02DU9@1RHV80>SXj
03lo?`1DE5@0>3Ph03lo?`1:BTX0=cLg03/k>`0^;Rh0:RXZ04M7A`15ADD0>CTi03Ph>01;Bd/0CTi>
03lo?`19BDT0CDe=05QHF00m?Cd0BTY:059BDP19BDT0Cdm?05]KF`1=CDd0A4A404i>CP18B4P0G5aL
06YZJP17AdL0Bd];05UIF@1oOgl0CDe=0410@01RHV80B4Q8071`L01=CDd0E5AD03dm?@0203lo?`2U
06=SH`1QHF40Jf][07emO@1aLG40[:b/0;:b/P3YjNT0gMgM07EeM@20P800PH61079bLP2MWId0GemO
05aLG01@D500Fe]K06m_K`1QHF40:BTY02d];@1:BTX0Jf][065QH@1:BTX0@41004];B`0n?Sh0AdM7
07emO@23Ph<0S8b<03`l?01=CDd0>SXj07emO@34a<@0KFe]04U9B@14A4@0>CTi051@D019BDT0CDe=
04E5A@13@d<0:BTY03Lg=`17AdL0;Bd]055AD@1GEeL0GUiN024Q8@15ADD09bLW03Ph>019BDT0;Rh^
05eMG@16ATH0BTY:02l_;`15ADD0>CTi04Q8B01QHF40DU9B03lo?`1QHF40A4A4079bLP15ADD0@D51
02PX:01ADE40?Shn06QXJ01JFUX0AdM705MGE`1RHV80:BTY06ATI01eMGD0ATI602d];@13@d<0BTY:
065QH@1XJ6P0JFUY04Y:BP1VIVH0Cdm?04Y:BP1ADE40ATI603Ph>01LG5`0P82006m_K`1CDe<0DE5A
03Hf=P1UIFD0?Shn04a<C00l?3`0HF5Q04M7A`1CDe<0UIFE05eMG@1EEED0BTY:03Ti>@1HF5P0E5AD
08b<S00`<300ATI601/K6`1CDe<0=SHf05iNGP1HF5P0=CDe04e=C@0R8R80C4a<04m?C`11@D40F5QH
05UIF@1_Kfl0X:2P03Lg=`20P800E5AD08:2PP13@d<0GemO07inOP1gMgL0VYZJ075aL@1<C4`0CTi>
03Hf=P0J6QX0?Cdm02HV9P1NGUh0BTY:05=CD`1FEUH0BTY:065QH@1MGEd0I6AT06UYJ@1PH600JFUY
017ooooo000?ooooo`0M05YJFP1jNWX0J6QX09nOW`19BDT0PX:207EeM@2[Zj/0MGEe03De=@1JFUX0
Xj>S07YjNP2`/;00BTY:0492@P1VIVH0GEeM07alO02n_[h0>3Ph028R8P1VIVH0P820061PH01eMGD0
820P04A4A01TI6@00P1;Bd/0O`1RHV8092@T04M7A`1dM7@0=3@d05MGE`15ADD06a/K03lo?`1iNGT0
?clo02@T9015ADD0?Shn08R8R02ATI40<30`03Hf=P0a<C40CDe=05IFEP2@T900:b/[03lo?`1RHV80
DU9B06][J`2OWil0@D5101dM7@1@D500E5AD06UYJ@2TY:@09RHV02l_;`0c<c<0IVIV05MGE`24Q8@0
<C4a01lO7`1BDU80?Shn0492@P2>SXh0820P01hN7P0a<C40F5QH04i>CP1EEED06ATI01XJ6P0c<c<0
EeMG02d];@0e=CD0Kfm_02TY:@16ATH0@T92014A4@0a<C40DU9B024Q8@1CDe<0S8b<02d];@0L71`0
>CTi03Ph>01LG5`0OWin028R8P0N7Qh0@D5104A4A00k>c/0H61P04i>CP0c<c<0EEEE06m_K`19BDT0
KFe]09FEU@0R8R80>3Ph07moO`0k>c/0>SXj05iNGP0V9RH0>CTi07AdM02KVi/0ADE504U9B@0_;bl0
>3Ph06a/K00l?3`0>CTi05mOG`0j>SX0;Bd]07QhN02TY:@0?clo05iNGP10@400<30`08>3P`20P800
7QhN04M7A`1QHF40G5aL075aL@0n?Sh07alO059BDP1mOGd0B4Q807YjNP2XZ:P00P10@400H`2YZJT0
Bd];07UiN@2HV9P08b<S02PX:01HF5P0^KVi04i>CP1iNGT06ATI04I6AP21PH40Q8B402`/;02BTY80
<c<c03Hf=P1ZJVX0>CTi03dm?@1;Bd/0:RXZ03`l?01jNWX0XZ:R03lo?`1FEUH0<S8b08V9R@34a<@0
IVIV02l_;`1ADE40?Cdm051@D02WYjL0RHV904];B`1@D500J6QX0:BTY023Ph<07AdM03Ti>@1FEUH0
@D510861P@0O7al0CTi>06IVIP1;Bd/0HV9R08n?S`0P8200;Rh^05=CD`1PH600R8R8034a<@0M7Ad0
EEEE06ATI01=CDd0EeMG02@T900M7Ad0Jf][04Y:BP14A4@0GUiN02LW9`1JFUX0LG5a06=SH`16ATH0
EeMG03De=@1MGEd0UiNG0492@P0U9BD0@d=305]KF`1GEeL0GUiN07QhN00U9BD0FEUI04E5A@1MGEd0
HF5Q0;Rh^01BDU80=SHf03hn?P18B4P0TY:B0:6QX@0202h^;P0M06ATI01PH600EEEE0;>c/`1XJ6P0
=SHf06ATI01PH600B4Q8075aL@0c<c<08R8R04Y:BP19BDT0I6AT04I6AP1UIFD07QhN01dM7@1QHF40
GemO01lO7`1>CTh0:b/[02@T901ZJVX0DU9B02DU9@1IFET07?ooool0I01]KFd0N7Qh04i>CP0Q8B40
JFUY06a/K01BDU80?3`l07alO01jNWX0QXJ605YJFP1VIVH0UIFE08Z:RP1ADE40F5QH06][J`1TI6@0
HF5Q04U9B@0_;bl0G5aL04];B`1/K6`0F5QH07MgM`17AdL0Ogmo06i^KP1]KFd0G5aL05MGE`1kNg/0
T92@0:j^[P2XZ:P0/K6a0:b/[02?Shl0?3`l04=3@`14A4@0IFEU04U9B@1JFUX0Cdm?04i>CP1?Cdl0
GEeM03De=@1EEED0KVi^05IFEP0`<300=CDe06IVIP1EEED0BTY:06QXJ00_;bl0IFEU04I6AP18B4P0
ADE503dm?@1HF5P0Bd];069RHP1MGEd0@D51075aL@19BDT0IVIV03dm?@1ADE40@d=303dm?@1PH600
FUYJ06EUI@1BDU80>3Ph03dm?@10@400<c<c03@d=00[:b/0;Bd]04a<C00/;2`0>CTi01dM7@0k>c/0
DE5A02d];@0m?Cd0<30`05YJFP19BDT204];B`1`04E5A@1DE5@0?Shn03dm?@1?Cdl0EUIF06=SH`1J
FUX0AdM705aLG01jNWX0@D5106ATI01aLG40GEeM09^KV`1PH600Ti>C05eMG@1/K6`0DE5A05=CD`15
ADD0LW9b05QHF02ATI40Zj^[08R8R01]KFd0L71`08V9R@1iNGT0EeMG0;Rh^02b/[80GemO07EeM@0l
?3`0BTY:02d];@1<C4`0:BTY04];B`0T92@0@D5102PX:00g=cL0MGEe05YJFP1YJFT0IfMW051@D013
@d<0=SHf02/[:`11@D407AdM04m?C`0S8b<0=SHf069RHP0l?3`0DE5A04m?C`1CDe<0JVYZ034a<@14
A4@0=cLg04U9B@0S8b<0<S8b0451@@0L71`0=CDe04Q8B01=CDd0?Shn06MWI`0Y:BT09bLW02`/;01=
CDd0Lg=c02/[:`1KFe/0<C4a03hn?P18B4P0CDe=06=SH`16ATH0=CDe06YZJP1?Cdl0EUIF05aLG01X
J6P0A4A4051@D01KFe/0Ph>308j>SP1JFUX0CDe=07IfMP0Z:RX0G5aL061PH00c<c<0B4Q808N7Q`80
E5AD00X0=3@d04a<C018B4P0CTi>03`l?01;Bd/0@41003Ph>00e=CD0CTi>0P16ATH0?P19BDT0@D51
03`l?01_Kfl0Cdm?05EEE@10@400SXj>071`L017AdL0EeMG04M7A`1?Cdl0L71`02l_;`1TI6@0<30`
05IFEP0m?Cd0@D5103`l?02CTi<0GemO051@D01LG5`09bLW05IFEP0S8b<0@410061PH015ADD0IVIV
04Q8B014A4@0GemO059BDP1mOGd0IVIV0<o?c`1OGel0Jf][071`L012@T80B4Q805]KF`1>CTh0EUIF
04m?C`0j>SX0Bd];03hn?P2KVi/0PX:207YjNP2@T900F5QH05mOG`1@D500Cdm?05QHF01OGel0MWIf
4Oooool000oooooo0><0Xj>S05IFEP1UIFD0Ph>306=SH`1PH600?3`l06m_K`24Q8@0Cdm?069RHP0o
?cl0CTi>06UYJ@1TI6@0?3`l04Q8B00Y:BT0?Shn07moO`1=CDd0>CTi05EEE@0k>c/0EeMG07]kN`0a
<C40>CTi05EEE@1CDe<0VIVI0;bl_00b<S80:b/[04U9B@1CDe<0WinO06m_K`0K6a/05QHF03<c<`0i
>CT0H61P07emO@0E5AD0=CDe04e=C@10@400P820075aL@0M7Ad0:BTY06e]K@1XJ6P0N7Qh05=CD`0O
7al0@T9207]kN`2UYJD0@D5106EUI@0d=3@0@T9204e=C@1BDU80;bl_04m?C`0M7Ad0@D5104i>CP1O
Gel0:RXZ04I6AP0^;Rh0F5QH07UiN@0d=3@06ATI03@d=00k>c/0A4A406QXJ01KFe/03Ph>03De=@1=
CDd0ADE505IFEP2OWil09BDU03lo?`1YJFT0Bd];075aL@25QHD07QhN01TI6@1TI6@0K6a/03Xj>P1;
Bd/0:BTY038b<P25QHD0Jf][03Xj>P19BDT0<C4a01lO7`0b<S80AdM701`L701XJ6P0<30`02PX:01:
BTX0IfMW03Ph>00[:b/0?clo04E5A@1GEeL0H61P02/[:`0M7Ad0>3Ph059BDP1>CTh0IfMW0410@00M
7Ad0DE5A06ATI01PH600WIfM02d];@0f=SH0ADE505MGE`1PH600aLG5030`<00^;Rh0E5AD06ATI014
A4@0NWYj0861P@0b<S80IFEU06ATI018B4P0KFe]04Q8B00M7Ad0D51@06][J`1NGUh0=SHf04=3@`0Y
:BT0EEEE0:RXZ00e=CD09BDU04Y:BP16ATH0A4A40:b/[00^;Rh06a/K03/k>`1:BTX0F5QH0;Fe]@1f
MWH09bLW05mOG`1BDU80OWin08>3P`0V9RH0?Shn05QHF02`/;00P82009:BTP0k>c/0Bd];05EEE@1Y
JFT0L71`08B4Q01<C4`0;bl_03dm?@1gMgL0T92@05QHF00R8R80NWYj0;Jf]P1RHV80DE5A06a/K00_
;bl0GemO0410@00i>CT0?3`l01dM7@1HF5P0Lg=c051@D00R8R80GEeM04U9B@1ZJVX0G5aL020P8012
@T80>CTi05aLG02f][H0EeMG02PX:00204a<C00m0:NWY`2`/;00;Bd]02l_;`1UIFD0JVYZ059BDP2W
YjL0<30`04Y:BP1FEUH0JFUY05mOG`2;Rh/0?3`l03Ti>@1BDU80I6AT03lo?`2LW9`0JVYZ02h^;P0l
?3`0IVIV06QXJ017AdL0SHf=04E5A@0l?3`0MGEe05eMG@0k>c/0MGEe02LW9`0];Bd0EEEE07moO`10
@400IFEU02LW9`12@T80Ti>C06IVIP0V9RH0<S8b05IFEP0g=cL0Vi^K09:BTP0_;bl0:2PX059BDP1D
E5@0>3Ph07]kN`1]KFd07AdM075aL@1UIFD0B4Q807emO@0Looooo`0o04I6AP1iNGT0D51@03De=@0n
?Sh0OWin06YZJP16ATH0MgMg09bLW01DE5@0=SHf051@D01VIVH0Shn?06i^KP1SHf<0CTi>04];B`2B
TY80Bd];02TY:@0d=3@0=cLg04U9B@1<C4`0B4Q804A4A01DE5@0S8b<07YjNP16ATH0Cdm?07EeM@1@
D500H61P05=CD`1nOWh0PH6106ATI011@D40Bd];0451@@15ADD0H61P06=SH`15ADD0?clo06IVIP1[
Jf/0<C4a03Hf=P17AdL0EEEE03Ph>011@D40H61P05QHF01BDU80L71`0451@@1QHF40BTY:0080F5QH
07@0CTi>05mOG`1XJ6P0PX:206QXJ017AdL0MgMg04Q8B023Ph<0@T9207=cL`1bLW80@D5107EeM@0c
<c<0?Cdm05aLG00l?3`0<C4a051@D013@d<0=CDe03/k>`0g=cL0GUiN04E5A@0m?Cd0;Rh^04E5A@1J
FUX0=cLg04E5A@14A4@0IVIV05EEE@1CDe<0GEeM05QHF01PH600DU9B05=CD`1:BTX0H61P04e=C@1L
G5`0Bd];04m?C`1FEUH0?Cdm05MGE`1[Jf/0I6AT06e]K@1ADE40NWYj04=3@`1=CDd0?Shn04e=C@16
ATH0E5AD059BDP2GUiL0c/k>0;jn_P2;Rh/0MgMg08f=S@2OWil0HV9R05aLG01WIfL0DE5A071`L01>
CTh0EUIF04Q8B01/K6`0@D5105MGE`0l?3`0Fe]K02l_;`1=CDd0UIFE079bLP18B4P0Cdm?03Ph>017
AdL0N7Qh05MGE`1OGel08B4Q051@D017AdL0Ng]k0;jn_P17AdL0@4100451@@1WIfL0I6AT03lo?`0k
>c/0Cdm?04a<C00V9RH0?3`l0410@00H61P0BTY:05]KF`1=CDd07alO0410@080<c<c06/0@41004];
B`26QXH08R8R04a<C00X:2P0De=C02TY:@14A4@0F5QH01hN7P0/;2`0KFe]030`<01ZJVX0Bd];03Xj
>P0L71`0EEEE02@T9013@d<0ATI604m?C`1PH600XJ6Q02PX:01JFUX0Fe]K04i>CP13@d<0EeMG04m?
C`1VIVH0E5AD06e]K@1HF5P0LG5a055AD@18B4P0C4a<04e=C@13@d<0EUIF07]kN`1jNWX0FEUI04U9
B@13@d<0SXj>04=3@`1=CDd0Bd];08Z:RP1>CTh0GEeM07YjNP1KFe/0ADE5059BDP0o?cl0A4A403Ti
>@2?Shl0@D5104=3@`0];Bd0@D5102<S8`1@D500DE5A01lO7`1@D500=SHf0492@P1OGel0BDU905IF
EP16ATH0Bd];07UiN@1<C4`0S8b<04I6AP1JFUX0CTi>07QhN022PX80>SXj051@D00m?Cd0A4A4055A
D@1UIFD0?Cdm0451@@0f=SH0GEeM04M7A`1EEED0X:2P05iNGP1kNg/0M7Ad06QXJ01SHf<0Cdm?05eM
G@0Aooooo`003oooool0>01XJ6P0MgMg04Q8B01RHV80PH6108N7Q`0c<c<0ADE5069RHP1iNGT0Ti>C
04E5A@0e=CD0?Shn07YjNP2UYJD0Lg=c02`/;010@400CDe=06EUI@1SHf<0WIfM02l_;`0o?cl0^[Zj
07MgM`1mOGd0BTY:03`l?01>CTh0EUIF06IVIP1PH600<S8b01lO7`1dM7@0^[Zj051@D011@D40F5QH
01hN7P0U9BD0JVYZ02LW9`1>CTh09RHV02DU9@10@400Kfm_03Ph>00d=3@0ATI603@d=01KFe/0J6QX
0P0Q8B40a`10@400Cdm?051@D01gMgL0=3@d03Ti>@16ATH0De=C06e]K@2HV9P0:b/[02HV9P1GEeL0
PX:204i>CP12@T80=3@d02TY:@1aLG40Jf][02/[:`1_Kfl0QXJ602DU9@19BDT0OGem02TY:@1GEeL0
BDU901LG5`0^;Rh0F5QH07emO@1BDU80<c<c02l_;`18B4P0M7Ad02d];@0P8200Cdm?01dM7@1ADE40
JVYZ01DE5@0V9RH0=cLg02HV9P1OGel0T92@02XZ:P0D51@09BDU0451@@1BDU80YJFU05QHF00S8b<0
=cLg05=CD`1GEeL0Jf][06a/K00E5AD0=3@d075aL@1bLW80D51@079bLP0M7Ad0:BTY0410@01WIfL0
?Cdm05=CD`0];Bd0=3@d05]KF`1IFET09BDU03Xj>P0n?Sh0<c<c0820P01iNGT0<c<c05aLG00d=3@0
:b/[05mOG`23Ph<092@T03dm?@1=CDd0DU9B09:BTP1MGEd07alO02d];@18B4P0Ph>308V9R@1`L700
820P03hn?P1aLG40QhN7065QH@2^[Zh0=SHf03Ti>@1PH600FUYJ06][J`1HF5P051@D03Lg=`1JFUX0
OWin03Ti>@15ADD07QhN051@D01LG5`0@T9202h^;P1MGEd0>CTi04M7A`2d];@0GUiN03dm?@1:BTX0
7QhN04Q8B02g]kL0IfMW030`<014A4@0;2`/07AdM02CTi<0:b/[03hn?P1JFUX0Kfm_07]kN`22PX80
8b<S03dm?@1WIfL0PH6108b<S00Q8B40:2PX065QH@1UIFD0EUIF0;Ng]`0_;bl0Hf=S04a<C010@400
EeMG024Q8@0U9BD0J6QX0:2PX01GEeL0MGEe03Lg=`1=CDd0Hf=S04E5A@13@d<0BTY:02`/;00c<c<0
NGUi05EEE@1>CTh0K6a/03Lg=`1cLg<0^;Rh09JFUP0/;2`0@D5105ADE00a<C40J6QX08f=S@0X:2P0
?clo04A4A013@d<0J6QX09BDU01TI6@00P0n?Sh03@13@d<0MWIf09:BTP0];Bd0>CTi04Y:BP1LG5`0
K6a/0;^k^`15ADD0B4Q8061PH01cLg<00P1>CTh0402JVYX0BTY:06=SH`1VIVH0?Cdm03Ti>@1HF5P0
7alO02/[:`1PH600FUYJ0410@01IFET08R8R03De=@1LG5`Looooo`0i06ATI02HV9P0QhN703lo?`17
AdL0HF5Q04E5A@0g=cL0GEeM06QXJ01fMWH0?Shn05eMG@1cLg<0Vi^K07YjNP1ADE40CTi>05EEE@2>
SXh0E5AD01lO7`19BDT0D51@04i>CP0l?3`0FUYJ03/k>`1iNGT0GemO06MWI`15ADD0D51@07YjNP2J
VYX0Q8B409FEU@2b/[80Z:RX09FEU@1FEUH0CTi>051@D01XJ6P0B4Q8069RHP1BDU80ATI604];B`1T
I6@0AdM703`l?01TI6@0CDe=03hn?P0V9RH0A4A40080C4a<06T0A4A402TY:@10@400I6AT03Ph>00n
?Sh0GemO05=CD`0f=SH0@T9205eMG@1bLW80KFe]05eMG@1WIfL0CDe=06=SH`1UIFD0B4Q804i>CP1E
EED0Hf=S04I6AP0[:b/0@D5103/k>`0/;2`0C4a<03Lg=`0l?3`0BDU9059BDP0o?cl0?Cdm04I6AP0d
=3@0<C4a03lo?`1PH600ATI602XZ:P0m?Cd0EUIF030`<01=CDd0Ng]k069RHP1GEeL0DU9B05YJFP1e
MGD0De=C05IFEP1WIfL0>3Ph04i>CP20P800LG5a09VIV@1`L700QhN705ADE01/K6`0BTY:055AD@0k
>c/0JVYZ04Y:BP1mOGd0Ph>306e]K@1/K6`0Ng]k0;Rh^035aLD0L71`07EeM@2SXj<0CDe=0;2`/01?
Cdl0@D5105MGE`1MGEd0@T9204A4A00a<C40ATI602d];@15ADD0GEeM051@D01<C4`0GUiN05QHF01E
EED0=cLg04a<C01PH6005ADE04=3@`0J6QX0K6a/07]kN`0j>SX00P16ATH0O01<C4`0IfMW0451@@18
B4P0EeMG05ADE00d=3@0<S8b03Ph>00V9RH0;2`/0410@00m?Cd0<S8b05MGE`0W9bL092@T028R8P1Z
JVX0K6a/04=3@`1_Kfl0;2`/06=SH`15ADD0?3`l05EEE@0[:b/0MgMg08F5Q@10@400Jf][05=CD`1>
CTh0;2`/03hn?P0m?Cd0EeMG05eMG@1DE5@0CDe=05MGE`0U9BD0IVIV0820P01BDU80?3`l055AD@0m
?Cd0BTY:02LW9`16ATH0?Cdm04I6AP13@d<0@T9204U9B@1>CTh0>SXj04I6AP1<C4`0CDe=04Y:BP0o
?cl0FEUI06][J`0k>c/0Bd];04e=C@1gMgL0C4a<03Ti>@1BDU80B4Q803Ti>@1UIFD0=cLg04i>CP1D
E5@0Ph>303Hf=P0h>3P06ATI05MGE`0Y:BT0@T9205UIF@0k>c/0FEUI02HV9P10@400FEUI0492@P1V
IVH0E5AD06i^KP2IVIT0:b/[05eMG@1=CDd0NGUi03De=@1KFe/0KVi^06MWI`2:RXX0D51@03Xj>P16
ATH0BTY:03Lg=`16ATH0A4A4075aL@1<C4`0F5QH07inOP1GEeL0S8b<06i^KP1MGEd0Fe]K08^;R`2H
V9PAooooo`003oooool0o`1LG5`0MgMg08J6QP2PX:00BTY:06EUI@1IFET0Vi^K06ATI00a<C40H61P
06QXJ01RHV80O7al04a<C015ADD0TI6A051@D01<C4`0BTY:03<c<`0^;Rh0Shn?07=cL`0k>c/0<30`
03/k>`1EEED0Jf][03@d=017AdL0IfMW051@D01UIFD0;bl_01PH600g=cL0HV9R075aL@1MGEd0KFe]
01LG5`0K6a/0E5AD05EEE@2IVIT0JFUY01@D500i>CT0C4a<05ADE01TI6@0QXJ602PX:01BDU80UIFE
05mOG`1CDe<0UIFE02<S8`12@T80BTY:03lo?`1<C4`0<c<c01/K6`0n?Sh0E5AD06IVIP16ATH0Bd];
02<S8`1IFET0EEEE02LW9`0Y:BT0AdM7034a<@0T92@0H61P08B4Q00_;bl0<30`0492@P11@D40I6AT
0451@@0H61P0820P034a<@1JFUX0MGEe059BDP0K6a/0:b/[04Q8B01DE5@0IfMW09FEU@0L71`04A4A
05]KF`0h>3P0BTY:06m_K`0D51@07alO04Y:BP1HF5P0;2`/04a<C00b<S80:2PX05UIF@2<S8`0<c<c
04e=C@1ADE406ATI0451@@1WIfL08b<S03<c<`12@T808R8R04m?C`2?Shl0BDU901@D501KFe/0>c/k
06IVIP2=SHd092@T02HV9P1ADE40I6AT04];B`2ATI40IfMW028R8P1HF5P0J6QX061PH036a/H0?clo
01lO7`0h>3P0HV9R065QH@1OGel0;Bd]04a<C01RHV80Shn?0410@01BDU80IfMW02DU9@1;Bd/0OGem
03Hf=P1HF5P0B4Q8030`<012@T80IVIV079bLP0L71`0@T920451@@1PH600Ph>303dm?@0R8R80Bd];
06IVIP1GEeL0PX:201hN7P18B4P0D51@06MWI`1EEED0XZ:R05MGE`0P8200JFUY07YjNP28R8P0PH61
02`/;00Y:BT0?clo06=SH`1:BTX0MWIf02HV9P13@d<0V9RH05mOG`1WIfL0@D5102l_;`1YJFT0Ph>3
03/k>`1CDe<07alO065QH@27QhL0CDe=04I6AP1IFET09BDU03De=@25QHD0@T9204e=C@0b<S80=SHf
07emO@19BDT071`L030`<00h>3P0BTY:07EeM@0W9bL0?Shn04];B`1?Cdl0JVYZ07IfMP0_;bl0>SXj
05=CD`1LG5`0QHF509nOW`0k>c/0@41006QXJ02FUYH0=cLg06MWI`1QHF40>CTi05UIF@2?Shl0FEUI
0861P@2IVIT0:2PX02d];@008`1:BTX0GEeM05mOG`1UIFD0;bl_04Q8B01hN7P0LW9b03Hf=P1XJ6P0
>3Ph02XZ:P1aLG40O7al028R8P1VIVH0=CDe024Q8@0m?Cd0GEeM02`/;014A4@0FEUI04=3@`1MGEd0
N7Qh04I6AP0O7al0A4A403Xj>P19BDT0VYZJ03Ph>00M7Ad0@d=301cooooo0;40EeMG09NGU`1FEUH0
A4A407AdM01`L700F5QH03hn?P1bLW80HF5Q07AdM01IFET0Kfm_08J6QP2?Shl0ATI605IFEP1ADE40
G5aL06ATI015ADD0;Bd]059BDP1=CDd0EUIF04];B`1RHV80ATI607UiN@1KFe/0IFEU05UIF@1:BTX0
LG5a0820P02>SXh0TY:B0;:b/P2PX:00K6a/0451@@0k>c/0FUYJ06IVIP15ADD0DU9B05UIF@1;Bd/0
CTi>05mOG`0V9RH0@d=306QXJ01ADE40C4a<02TY:@1YJFT0E5AD04U9B@1aLG40<30`07alO01:BTX0
EUIF04A4A01LG5`0EUIF04M7A`1PH600CDe=034a<@1LG5`0@D5105IFEP1;Bd/0DU9B05=CD`0e=CD0
GUiN038b<P0c<c<0EUIF03Xj>P0n?Sh0@d=302h^;P0e=CD0<S8b03Ph>019BDT0>3Ph03Xj>P0T92@0
>3Ph05MGE`0j>SX0BDU903Xj>P1OGel0>3Ph055AD@1@D500BDU905YJFP0o?cl0>c/k03dm?@1CDe<0
M7Ad055AD@15ADD0Cdm?065QH@10@400Q8B409>CT`2[Zj/0WIfM06e]K@1WIfL0FUYJ05QHF017AdL0
C4a<04E5A@1MGEd0J6QX0820P02/[:`0];Bd07AdM01NGUh0VIVI09RHV018B4P0MWIf07QhN01BDU80
HF5Q03Lg=`1<C4`0CTi>07YjNP1<C4`0HF5Q03@d=01@D500?clo06IVIP1]KFd0Kfm_0451@@1OGel0
CDe=05ADE01BDU80D51@07EeM@0W9bL0KVi^01@D501_Kfl0Ph>303@d=01WIfL0CTi>055AD@1IFET0
@41004i>CP0o?cl0@d=301/K6`1HF5P0IfMW01/K6`0n?Sh00P17AdL04`0_;bl0ADE5038b<P0V9RH0
>SXj03dm?@1;Bd/092@T03hn?P0P8200IVIV03De=@1ADE40EEEE01dM7@1cLg<0SHf=03Ti>@0k>c/0
0P0/;2`02@0D51@0?clo01LG5`0m?Cd0ADE50410@012@T80V9RH03hn?P020451@@1?02XZ:P1@D500
Ph>30410@01@D500@41004e=C@1>CTh0De=C04e=C@1YJFT0Cdm?05=CD`1=CDd0EEEE05iNGP1RHV80
BTY:02HV9P1HF5P0Shn?04M7A`1<C4`0=3@d0:RXZ01IFET0@T9206ATI01WIfL0HF5Q06IVIP1DE5@0
MWIf0410@01eMGD0>SXj03<c<`0K6a/0M7Ad02l_;`1KFe/0GEeM02`/;01JFUX0?Shn05QHF01JFUX0
FEUI06ATI01DE5@0GUiN06UYJ@19BDT0L71`04Q8B02;Rh/0>CTi05iNGP1fMWH0BTY:05=CD`19BDT0
@410059BDP1JFUX0?3`l07EeM@1/K6`0PH6105EEE@1PH600Ng]k04m?C`1[Jf/0De=C06YZJP1YJFT0
G5aL05QHF00Aooooo`003oooool0?@1oOgl0FUYJ06UYJ@30`<00GUiN059BDP14A4@0VYZJ09^KV`10
@400EEEE04a<C01MGEd0J6QX05YJFP0`<300ATI606QXJ01aLG40];Bd038b<P0g=cL0?3`l06MWI`1f
MWH0<S8b03Ph>01QHF40GemO05eMG@2KVi/0P82001`L700c<c<0E5AD06QXJ02^[Zh0E5AD034a<@18
B4P0N7Qh051@D00n?Sh0FUYJ02LW9`1GEeL0PH6103De=@0l?3`0;Bd]01/K6`11@D40E5AD04m?C`1b
LW80@d=303dm?@1=CDd0NGUi05MGE`0R8R800P16ATH02P1`L700GemO01LG5`0e=CD0ADE505MGE`1E
EED0XJ6Q03Ti>@0T92@2055AD@2@07UiN@2o_kl0<C4a03@d=00W9bL0DE5A06MWI`1`L700820P02PX
:016ATH0K6a/051@D01DE5@0NGUi01`L701?Cdl0MWIf03hn?P1FEUH0NWYj01@D5010@400KVi^05YJ
FP0O7al0>SXj01hN7P1IFET0N7Qh02l_;`0[:b/0=SHf02l_;`0g=cL0Kfm_04U9B@0B4Q80<S8b071`
L01?Cdl0S8b<09BDU00V9RH0?Shn04e=C@13@d<0Ogmo06a/K00W9bL0ADE504I6AP1cLg<0?3`l05aL
G00/;2`0EEEE07EeM@15ADD0:2PX06ATI00Z:RX0A4A404m?C`1]KFd0BTY:08B4Q00E5AD0A4A408N7
Q`1LG5`09bLW0492@P1>CTh0ATI609BDU00];Bd0<c<c04U9B@16ATH0?Shn08N7Q`2YZJT0@41003Ph
>01SHf<0AdM70::RXP2SXj<0:BTY02/[:`1MGEd0Rh^;05UIF@2HV9P08R8R04=3@`1cLg<0LG5a06][
J`2JVYX0CTi>028R8P1/K6`0@4100492@P0l?3`08B4Q03Ph>01ZJVX0OWin02l_;`11@D40<C4a04i>
CP1hN7P0?Shn034a<@1PH600?Cdm03Ph>01aLG40Cdm?04A4A00i>CT0K6a/09NGU`1IFET09BDU05EE
E@1;Bd/0@D5108Z:RP0O7al0>CTi071`L01?Cdl0CTi>08b<S00f=SH0;Rh^04Q8B01EEED0VYZJ0P11
@D405`1]KFd0MWIf04A4A01[Jf/0;Rh^02XZ:P1]KFd0HF5Q07YjNP1cLg<09bLW04i>CP1?Cdl0?Shn
05QHF01cLg<09BDU05ADE01KFe/0F5QH03Ti>@1`L700De=C0080=cLg00<0H61P02XZ:P22PX800P10
@400601<C4`0Ph>304A4A00T92@0BDU904A4A021PH40O7al02PX:00o?cl0Cdm?05MGE`1<C4`0[:b/
05aLG00i>CT0@d=3059BDP1:BTX0U9BD09FEU@0M7Ad08R8R05YJFP80L71`00d0R8R8020P800h>3P0
DU9B05ADE013@d<0MGEe03hn?P0P8200FUYJ06IVIP1?Cdl0NWYj01cooooo01l0PH610:FUY@1OGel0
@d=304A4A01XJ6P0HF5Q04E5A@1kNg/0Lg=c05EEE@0d=3@0ATI6065QH@27QhL0FUYJ07IfMP1ADE40
C4a<09nOW`1?Cdl0:b/[03De=@0n?Sh0DU9B05ADE01>CTh0ATI6051@D01<C4`0Jf][0080EEEE00l0
O7al05YJFP1QHF40Kfm_06MWI`1lO7`0JVYZ04a<C00m?Cd0@T9204];B`1FEUH0De=C04Q8B00i>CT0
0P1>CTh0800U9BD0>CTi04e=C@1=CDd0DU9B0410@01RHV80C4a<04M7A`1eMGD0?Cdm07moO`1<C4`0
GUiN05ADE01KFe/0HV9R05aLG01fMWH0GEeM04];B`1lO7`0D51@08:2PP0o?cl0GUiN07EeM@1JFUX0
Hf=S03lo?`0m?Cd0D51@0P0f=SH07`1CDe<0AdM704E5A@13@d<0<S8b061PH01<C4`0BDU903Lg=`1:
BTX0I6AT03lo?`19BDT0A4A4065QH@1@D500EUIF05]KF`1SHf<0Jf][05aLG01DE5@0@d=305MGE`1?
Cdl0E5AD055AD@1HF5P0EUIF03lo?`1DE5@00P1IFET0<01[Jf/0Kfm_07=cL`1:BTX0D51@03`l?015
ADD0?3`l0410@01@D500GUiN0:VYZ@2HV9P0O7al065QH@2?Shl0];Bd06ATI02/[:`0YJFU05QHF01l
O7`0D51@05mOG`22PX80I6AT03dm?@13@d<0A4A404e=C@0V9RH0>SXj07inOP1JFUX0DE5A04];B`17
AdL0@T9205YJFP1dM7@0IVIV020P801ZJVX07alO05UIF@1eMGD0<c<c03lo?`80A4A407/0Kfm_03dm
?@1BDU80>c/k0410@00B4Q808b<S03Xj>P0L71`0?Shn04E5A@1HF5P071`L04Q8B00`<300?3`l03/k
>`1WIfL0H61P02@T9017AdL0=SHf03/k>`16ATH0>c/k04E5A@0e=CD0@d=306][J`0f=SH0CTi>0451
@@16ATH0<30`06IVIP0R8R80DE5A05YJFP14A4@0;Rh^04m?C`0N7Qh0ATI604M7A`0U9BD0=CDe0410
@01@D500TY:B05QHF01GEeL0DU9B051@D013@d<0B4Q804A4A01=CDd0=cLg03hn?P1RHV80KVi^09VI
V@1WIfL0C4a<06EUI@0n?Sh0Cdm?03/k>`1UIFD0H61P07EeM@1DE5@0ATI603`l?01KFe/0AdM704];
B`1ADE40SXj>03Lg=`0i>CT0@41006MWI`17AdL0IFEU05YJFP0l?3`0G5aL03dm?@10@400F5QH05mO
G`27QhL0EUIF06m_K`2>SXh0Bd];06QXJ01KFe/0PX:204a<C01OGel0KVi^04Y:BP1KFe/0IVIV06a/
K01UIFD0E5AD03De=@1ADE40J6QX06EUI@1?Cdl0FEUI06=SH`1FEUH0Fe]K05iNGP18B4P0BDU905]K
F`1YJFT04Oooool000oooooo0440Shn?06UYJ@1LG5`0N7Qh07moO`24Q8@0@d=3071`L01fMWH0Ng]k
09fMW@17AdL0ADE505UIF@1WIfL0TI6A08:2PP0_;bl0ATI6051@D010@400HV9R08n?S`0];Bd0?Cdm
06EUI@1@D500RHV904E5A@0T92@0A4A407]kN`1GEeL0HV9R01DE5@0S8b<0D51@07IfMP0m?Cd0Bd];
06e]K@0Z:RX0@d=305IFEP0X:2P0EeMG03lo?`0a<C40H61P04U9B@0N7Qh0;2`/04M7A`0d=3@0OWin
08R8R012@T80?Cdm05mOG`18B4P0>3Ph06MWI`0c<c<0Cdm?06UYJ@0204];B`1806][J`0W9bL0;Bd]
04Y:BP1NGUh0BDU904i>CP0M7Ad08B4Q051@D01PH600=3@d07AdM01aLG4092@T04];B`1@D500=CDe
06=SH`17AdL08R8R04=3@`1dM7@0CDe=05MGE`0l?3`0:BTY05]KF`2BTY80?clo03Lg=`1LG5`0>CTi
03Xj>P1EEED09RHV03hn?P1:BTX0:b/[055AD@1dM7@0=CDe02PX:00o?cl0BTY:04M7A`1lO7`0=3@d
01DE5@19BDT0AdM70492@P1<C4`0GemO01/K6`19BDT0S8b<04m?C`18B4P0Lg=c020P800W9bL0GUiN
05]KF`19BDT0FEUI02/[:`1<C4`0Ph>3061PH00e=CD0E5AD0P1EEED0U@2:RXX0?3`l02`/;01=CDd0
=cLg02HV9P1`L700I6AT038b<P1HF5P0A4A404Y:BP2HV9P0CTi>02PX:00g=cL0I6AT05QHF01gMgL0
G5aL03Ph>018B4P0CTi>05UIF@1RHV80RXZ:03/k>`0`<300Hf=S03hn?P1IFET0JFUY02XZ:P0`<300
L71`06e]K@0g=cL0Hf=S03<c<`1cLg<0T92@03Ph>019BDT0Q8B404U9B@0o?cl0UIFE05QHF01<C4`0
EUIF04];B`1?Cdl0PX:204I6AP0j>SX0FUYJ03hn?P22PX80CTi>02l_;`1YJFT0E5AD03Ph>02NWYh0
QXJ602LW9`1IFET0De=C05IFEP1NGUh092@T03@d=018B4P0DU9B06EUI@27QhL0;bl_07MgM`1/K6`0
ADE5075aL@0/;2`0?3`l06m_K`1PH600ADE506a/K00Y:BT0IVIV092@T01LG5`0EUIF05UIF@0];Bd0
De=C08j>SP0h>3P0G5aL065QH@0i>CT0CTi>08j>SP2CTi<0=3@d04E5A@1@D500?Shn07AdM01aLG40
=3@d059BDP1KFe/0?Cdm03hn?P2ATI40Cdm?051@D01CDe<0BDU906YZJP25QHD0ATI603Hf=P1DE5@0
EEEE06=SH`2VYZH0>SXj02`/;01BDU80Jf][04E5A@1MGEd0T92@03@d=016ATH0OWin05=CD`1<C4`0
IfMW02PX:00m?Cd0D51@075aL@1<C4`0EUIF038b<P0e=CD0JFUY01cooooo0?l0GUiN08:2PP1WIfL0
BDU905mOG`1[Jf/0F5QH03Ph>01fMWH0LG5a07AdM00n?Sh0HV9R07emO@29RHT0I6AT05aLG01IFET0
CTi>07]kN`1CDe<09bLW0410@01>CTh0GEeM04U9B@1VIVH0Cdm?07inOP19BDT0E5AD05QHF019BDT0
MgMg08b<S02HV9P0UiNG09VIV@2KVi/0NGUi05EEE@16ATH0F5QH065QH@17AdL0Bd];04i>CP12@T80
BTY:059BDP0e=CD0AdM705aLG01DE5@0EUIF02DU9@1GEeL0DU9B04U9B@1ZJVX0@d=3071`L01:BTX0
Cdm?04];B`1=CDd0E5AD04=3@`1IFET0EEEE04=3@`1VIVH0C4a<06a/K01?Cdl0F5QH05iNGP0i>CT0
E5AD0451@@0k>c/0D51@02l_;`0m?Cd0AdM703hn?P0m?Cd0>CTi03lo?`1CDe<0?clo0451@@0f=SH0
@D5104a<C015ADD0ATI604A4A01ADE40@d=304m?C`1@D500CTi>05MGE`1DE5@0CTi>04e=C@1OGel0
G5aL061PH01BDU80EUIF065QH@0m?Cd0JFUY09NGU`2RXZ80U9BD06MWI`1cLg<0G5aL05mOG`0n?Sh0
EUIF04a<C01EEED0BTY:069RHP2CTi<0V9RH05QHF01XJ6P0ZJVY09VIV@1=CDd0KVi^06m_K`19BDT0
Ph>303<c<`1<C4`0Bd];061PH00f=SH0G5aL02/[:`1:BTX0:b/[04A4A01bLW80IFEU03<c<`1=CDd0
F5QH05eMG@1=CDd0?clo069RHP0Y:BT0JFUY01XJ6P1?Cdl0M7Ad038b<P1NGUh0CDe=04i>CP1UIFD0
>SXj05aLG015ADD0ATI601dM7@0n?Sh0EUIF02l_;`12@T80A4A405]KF`0Z:RX0BDU902d];@0e=CD0
:BTY05MGE`1ADE40>3Ph07UiN@0Z:RX0<c<c03Xj>P1LG5`0I6AT02HV9P1FEUH0Hf=S03`l?01aLG40
ADE503dm?@0I6AT0A4A4020P801=CDd0DE5A04];B`16ATH0GemO03Ti>@1JFUX0HV9R03Xj>P0Z:RX0
>c/k02PX:01HF5P0:RXZ05EEE@1;Bd/0EUIF055AD@1NGUh0BDU905UIF@1EEED0EUIF05aLG01UIFD0
J6QX03Hf=P1@D500Jf][04A4A01gMgL0@d=306a/K01;Bd/0>c/k05mOG`1=CDd0BDU904m?C`0d=3@0
KFe]04i>CP1jNWX0Bd];04A4A00c<c<0K6a/0410@01^KVh0Lg=c04];B`1^KVh002<0GEeM05=CD`1N
GUh0@d=3065QH@0k>c/0GEeM0820P01DE5@0JVYZ06IVIP1oOgl0HF5Q07AdM01lO7`0Fe]K06a/K00j
>SX0>c/k04Q8B01ADE40>SXj06i^KP1JFUX0IFEU05EEE@1;Bd/0IfMW04A4A01kNg/0DU9B06UYJ@1c
Lg<0JFUY08f=S@0Aooooo`003oooool0501XJ6P0P82008n?S`36a/H0@d=3075aL@1bLW80`/;204Y:
BP19BDT0G5aL05QHF01]KFd0XJ6Q0451@@0h>3P0J6QX05QHF02[Zj/0P8200P0b<S80J01ADE40JFUY
05YJFP0I6AT0<30`0492@P1;Bd/0<C4a059BDP1iNGT09BDU04];B`12@T80;bl_05YJFP0h>3P0<C4a
05iNGP28R8P0;2`/034a<@0n?Sh0>c/k09JFUP1^KVh05aLG03lo?`1RHV80@T9203Xj>P1DE5@05ADE
03/k>`2RXZ80WIfM05aLG02ATI40?Shn02DU9@14A4@0F5QH09fMW@1HF5P061PH02h^;P1EEED0J6QX
0410@01hN7P071`L024Q8@1ZJVX0ATI603dm?@28R8P0;2`/01/K6`0o?cl0GEeM04a<C01BDU8051@D
01lO7`0/;2`0IFEU024Q8@19BDT0?Cdm014A4@1UIFD0@D5101DE5@0Y:BT0=cLg038b<P24Q8@0[jn_
02/[:`0E5AD0?3`l03hn?P2=SHd0IfMW01XJ6P0M7Ad0>c/k05QHF014A4@0Shn?038b<P0m?Cd0Cdm?
05mOG`0a<C40EeMG071`L00I6AT0@D5105]KF`0S8b<0B4Q804U9B@0W9bL0Cdm?0P1>CTh0T00W9bL0
MGEe03De=@1]KFd0T92@02TY:@0K6a/0?clo05UIF@1DE5@0[jn_04=3@`0d=3@0GUiN065QH@1NGUh0
YjNW02l_;`0/;2`0>CTi07MgM`1WIfL0Ph>302DU9@0n?Sh0@41008^;R`1>CTh0Hf=S08B4Q00S8b<0
<c<c06MWI`13@d<0JVYZ04Y:BP0S8b<0;bl_06i^KP2IVIT0=SHf03dm?@0U9BD0?Shn07inOP1=CDd0
?3`l051@D00/;2`0CTi>07YjNP0T92@0;2`/04A4A00b<S80HV9R0<K6aP1?Cdl0:RXZ02l_;`0n?Sh0
MWIf06e]K@0S8b<0Bd];07QhN01@D500FEUI08f=S@0T92@0>SXj08n?S`17AdL0[jn_04Q8B00`<300
F5QH07AdM00o?cl0E5AD02LW9`1YJFT0Q8B404=3@`1IFET0EeMG01dM7@11@D40VYZJ05ADE01CDe<0
:b/[02h^;P1gMgL0NGUi038b<P1aLG409bLW03`l?02DU9@0<S8b06m_K`0l?3`0<S8b09VIV@2UYJD0
ADE503Ti>@19BDT0?Shn06i^KP2LW9`0CTi>02PX:014A4@0BDU9061PH01bLW80N7Qh02/[:`1GEeL0
B4Q806QXJ02PX:00MgMg02<S8`0k>c/0JFUY07IfMP2a/K40B4Q802`/;014A4@0JVYZ0861P@1;Bd/0
SXj>03`l?014A4@0FEUI08^;R`11@D40MgMg02h^;P80;bl_0100NWYj06ATI01CDe<0AdM702PX:00b
<S80IfMW055AD@11@D40ATI602DU9@16ATH0MWIf03Ti>@0/;2`0=cLg7?ooool0=@1FEUH0PX:205UI
F@0_;bl0B4Q807YjNP1MGEd0CDe=08:2PP1oOgl0KFe]05UIF@1YJFT0LW9b08f=S@1<C4`0BTY:04E5
A@1ADE40Cdm?04A4A00_;bl0=SHf03Xj>P1QHF40Fe]K05QHF00i>CT0EEEE04U9B@1JFUX0C4a<0492
@P1/K6`0DU9B06YZJP1KFe/0EEEE06i^KP1HF5P0E5AD04];B`15ADD0F5QH06EUI@1VIVH0Bd];03`l
?01SHf<0H61P03Lg=`0R8R80=SHf0080G5aL04T0@D5105eMG@1KFe/0BDU908F5Q@16ATH0TY:B04I6
AP1OGel0BTY:04a<C01EEED0ATI605eMG@1LG5`0@D5107QhN01CDe<0N7Qh03Xj>P1EEED0Lg=c055A
D@1GEeL0HV9R079bLP1GEeL0=cLg03Hf=P0o?cl0?Cdm03<c<`0_;bl06QXJ03hn?P0m?Cd0?clo02`/
;011@D40EeMG03@d=01<C4`0>c/k05MGE`0b<S80@D5104m?C`1/K6`0G5aL04M7A`1DE5@0C4a<05QH
F012@T80De=C04U9B@1IFET0K6a/03dm?@1YJFT0RXZ:05aLG01jNWX0BDU905aLG01JFUX0De=C03`l
?01BDU80@D51065QH@1EEED0NWYj0080M7Ad0380GemO07emO@35aLD0aLG504Q8B027QhL0Ph>304=3
@`23Ph<0=SHf06EUI@19BDT0G5aL04a<C01TI6@0?clo04m?C`0n?Sh0EEEE07moO`1^KVh0ADE5059B
DP18B4P0GEeM04Y:BP1?Cdl0GemO02l_;`0l?3`06QXJ05aLG01KFe/0;bl_04Y:BP1GEeL0CTi>08>3
P`12@T80BDU903De=@0f=SH030`<02l_;`17AdL07alO03dm?@0o?cl0@T9201HF5P80=3@d06`0EeMG
03`l?01TI6@0B4Q8030`<01;Bd/0;2`/03Hf=P0e=CD0ATI604E5A@0A4A40Lg=c071`L018B4P0/K6a
05QHF017AdL0>CTi06MWI`0f=SH0G5aL05iNGP1bLW80De=C06YZJP0A4A40Cdm?05IFEP0Q8B40?Cdm
04e=C@1<C4`0N7Qh0492@P1EEED0DE5A04e=C@0i>CT0B4Q80492@P1@D500?clo05=CD`1MGEd0IfMW
0:NWY`0/;2`0L71`08N7Q`0i>CT0FEUI04A4A02FUYH0L71`051@D01FEUH0Bd];03Ti>@1>CTh0;2`/
05MGE`19BDT0Jf][03Lg=`11@D40D51@07YjNP1DE5@0G5aL051@D00d=3@0F5QH04A4A00o?cl0NWYj
03Lg=`1`L700<C4a0410@014A4@08B4Q06UYJ@1BDU80U9BD03dm?@1OGel0C4a<03Xj>P1IFET0ADE5
075aL@1XJ6P0Bd];03hn?P1=CDd0J6QX07QhN01JFUX0EEEE06QXJ013@d<0EeMG0451@@1<C4`0GUiN
05IFEP1JFUXAooooo`003oooool0D02MWId0CTi>051@D01ZJVX0Jf][04U9B@10@400Rh^;07EeM@0c
<c<0Cdm?03dm?@1<C4`0U9BD071`L01?Cdl0@D5102`/;01ZJVX0V9RH02d];@0l?3`0A4A405]KF`1e
MGD0>c/k02l_;`1BDU80B4Q804=3@`2GUiL0`<3004];B`0n?Sh0LW9b06i^KP2YZJT0Fe]K010@400f
=SH0FEUI04a<C02=SHd0KVi^02LW9`1BDU80KVi^04M7A`1bLW80BTY:02HV9P0j>SX0FEUI038b<P13
@d<0R8R808j>SP0n?Sh0AdM707UiN@1:BTX0JVYZ01lO7`17AdL0L71`02DU9@0/;2`0DU9B04M7A`1A
DE40OWin0492@P0Z:RX0A4A404I6AP1aLG40QhN702d];@0H61P0@D510P1@D500302;Rh/07QhN028R
8P0/;2`0K6a/04A4A027QhL0OWin01TI6@0_;bl0EUIF02LW9`80Cdm?03l02`/;02h^;P1ZJVX0FEUI
04a<C00b<S806a/K03dm?@1nOWh0AdM702d];@0/;2`06a/K02d];@1:BTX0DE5A02h^;P1PH600C4a<
04E5A@1SHf<0XJ6Q02h^;P0M7Ad0F5QH03`l?020P800Lg=c02PX:00[:b/0Cdm?03@d=01NGUh0^[Zj
05aLG01;Bd/0QHF506YZJP1GEeL0QhN702@T900L71`0EEEE08J6QP1UIFD0NGUi02TY:@12@T80DE5A
0451@@0X:2P0BDU903De=@13@d<0GemO03`l?00T92@0De=C02<S8`0a<C40DE5A09jNWP1>CTh00P0j
>SX0P@1LG5`0Ogmo05QHF00O7al0:2PX03Lg=`1[Jf/0EEEE08F5Q@0S8b<0C4a<055AD@17AdL0Kfm_
0;Zj^P0X:2P0<30`06][J`1PH600P82007AdM00/;2`0ATI605iNGP2YZJT0FEUI08Z:RP0d=3@0F5QH
08j>SP13@d<0EEEE06UYJ@0c<c<0CTi>07emO@21PH40AdM7038b<P0i>CT0Lg=c0820P00Y:BT0Bd];
05ADE011@D40Ph>303@d=00k>c/0BTY:03/k>`1QHF40OGem02d];@0S8b<0C4a<06MWI`2@T900=3@d
01/K6`0l?3`0Bd];055AD@2k^k/0>3Ph01XJ6P12@T80?Cdm0:>SX`1/K6`05ADE02TY:@1dM7@0FUYJ
06MWI`24Q8@0B4Q804E5A@1GEeL0?clo05MGE`23Ph<0De=C02DU9@1NGUh0HF5Q04a<C027QhL0?Shn
02LW9`1JFUX0IFEU03<c<`0_;bl0IfMW0492@P1VIVH0Q8B403Ti>@1?Cdl0FEUI03Ti>@13@d<0NGUi
061PH00_;bl0@D5104U9B@1>CTh0UIFE05aLG00N7Qh0=SHf03Lg=`1KFe/0PH6107YjNP0_;bl0?clo
0451@@14A4@0Jf][08B4Q00P8200@T9205YJFP1@D500@T9205MGE`0Looooo`1I05eMG@2/[:`0LG5a
03Hf=P13@d<0Kfm_06][J`15ADD0O7al0861P@1KFe/0<S8b0451@@0o?cl0JFUY06i^KP1IFET0DU9B
04M7A`2ATI40Cdm?034a<@0m?Cd0CDe=04Y:BP0c<c<0C4a<0492@P1FEUH0@d=305IFEP16ATH0>SXj
04I6AP1/K6`0Ogmo07alO02ATI40YJFU06m_K`1@D500@T9204M7A`1<C4`0@41004=3@`0a<C40;bl_
03Ti>@0e=CD09BDU03@d=018B4P0<30`03<c<`0Q8B40>c/k059BDP1/K6`0FEUI0410@01;Bd/0KFe]
04U9B@13@d<0EEEE04i>CP1?Cdl0GUiN06ATI01PH600NWYj071`L01ZJVX0A4A4055AD@1;Bd/0<c<c
03Lg=`0e=CD09bLW04M7A`0/;2`0ATI604e=C@0f=SH0?3`l03Xj>P0a<C400P1HF5P03`12@T80?3`l
05MGE`1MGEd0?clo059BDP1ADE40H61P03Ph>01?Cdl0F5QH04Y:BP1CDe<0AdM704a<C00204m?C`09
04i>CP1KFe/0C4a<051@D01DE5@0ADE506YZJP2PX:00RXZ:0080MGEe00d0AdM7061PH01MGEd0DE5A
05aLG012@T80JVYZ05]KF`1_Kfl0MgMg08V9R@1YJFT0Shn?0080Z:RX09`0Fe]K08B4Q020P800ADE5
07emO@16ATH0CTi>04M7A`1HF5P0?3`l04e=C@0e=CD0@T9203hn?P25QHD0Jf][05MGE`0a<C40GEeM
04e=C@1MGEd0E5AD06=SH`1kNg/06ATI03<c<`0Z:RX0Fe]K06MWI`0d=3@0BTY:05EEE@18B4P0OWin
02/[:`1QHF40>c/k04U9B@0];Bd0=SHf04];B`0b<S80>c/k04];B`1EEED04A4A03Xj>P0[:b/0;Rh^
02LW9`1KFe/0F5QH05YJFP2;Rh/0<30`0492@P0m?Cd0QXJ606IVIP0T92@0BDU904m?C`0T92@0H61P
03hn?P17AdL071`L04];B`0H61P0CDe=04I6AP1;Bd/0GUiN0861P@0o?cl0SXj>09BDU015ADD0=SHf
03Ph>013@d<0Fe]K02LW9`13@d<0@41005UIF@0j>SX0EEEE04A4A01BDU80D51@04];B`1QHF40IfMW
06QXJ00[:b/0FEUI05mOG`1?Cdl0RHV903Ti>@1PH600C4a<04M7A`1HF5P0@T9204A4A01KFe/0CDe=
07EeM@19BDT0LW9b05UIF@1ADE40<S8b04U9B@0j>SX0I6AT05]KF`1BDU80LW9b055AD@17AdL0GemO
03<c<`21PH40=cLg05iNGP1;Bd/0:BTY07QhN015ADD0OWin02l_;`2<S8`0Jf][05UIF@1^KVh0?Shn
0410@00o?cl0BDU90492@P1BDU80?Shn07=cL`1CDe<0F5QH08Z:RP1WIfL0L71`05MGE`1^KVh0MGEe
051@D01XJ6PAooooo`003oooool02`2e]KD0JVYZ04];B`1MGEd0MgMg075aL@10@400G5aL06UYJ@2=
SHd0Vi^K0080<C4a0<80K6a/0861P@2][Jd0EUIF02`/;014A4@0O7al04e=C@1KFe/0KVi^02DU9@1V
IVH0RHV9059BDP29RHT0<S8b034a<@10@400QhN7075aL@1TI6@05QHF03/k>`1GEeL0Ph>304e=C@1C
De<0CDe=02PX:01>CTh0Rh^;03dm?@1BDU80D51@03Lg=`1]KFd0SHf=03Ti>@17AdL0E5AD02`/;00j
>SX0:b/[05EEE@1=CDd0BTY:03dm?@1SHf<0/K6a02h^;P0c<c<0Q8B4059BDP1^KVh0Zj^[024Q8@0j
>SX0IfMW06=SH`1nOWh0EUIF020P800b<S80Hf=S07emO@0h>3P0Vi^K08V9R@0L71`0B4Q805iNGP0c
<c<0FUYJ03Ti>@0e=CD0FUYJ06a/K00Y:BT0FEUI04M7A`0j>SX0Fe]K06i^KP0];Bd0<30`03/k>`1<
C4`0GUiN04=3@`0H61P08b<S04];B`1cLg<0HV9R05eMG@0I6AT08R8R03/k>`1EEED0Bd];0::RXP0e
=CD08R8R05IFEP2JVYX0N7Qh05ADE012@T808R8R05QHF01nOWh0@d=303dm?@1XJ6P09bLW01PH6019
BDT0JVYZ03`l?01<C4`06ATI05MGE`2c/k<0MGEe02l_;`11@D40?Shn05IFEP1cLg<0:RXZ02DU9@1<
C4`0CDe=05aLG02BTY80Rh^;030`<01MGEd0Jf][05aLG02f][H0GEeM01LG5`0l?3`0HF5Q06UYJ@2;
Rh/0AdM703Ti>@1?Cdl0IVIV05]KF`1HF5P0QXJ601lO7`0`<300GUiN034a<@0c<c<0CTi>02LW9`14
A4@0UiNG08V9R@0/;2`0E5AD03Lg=`1MGEd0SHf=02`/;00f=SH0Fe]K05MGE`1@D500XJ6Q05MGE`0e
=CD0DE5A04E5A@1fMWH0/k>c034a<@0c<c<0Bd];06i^KP2:RXX0HV9R02<S8`1LG5`0JVYZ05QHF025
QHD0E5AD03hn?P80F5QH01L0Ti>C05]KF`0M7Ad0Fe]K05QHF01?Cdl0FUYJ07QhN00k>c/0ZZZZ07Ee
M@0a<C40HV9R02/[:`0S8b<0MWIf08J6QP0j>SX0B4Q8038b<P29RHT0ZZZZ03Xj>P0204M7A`0h034a
<@0j>SX0PX:2030`<01:BTX0G5aL05=CD`1hN7P0ZZZZ09>CT`0Q8B40?3`l04U9B@1cLg<0X:2P09>C
T`0X:2P0B4Q8075aL@1QHF40G5aL0:>SX`0n?Sh0BTY:06=SH`1QHF40Ogmo07IfMP0R8R80FEUI06YZ
JP1HF5P0P82009nOW`0[:b/0FUYJ04i>CP1<C4`0;2`/051@D01CDe<0<30`055AD@1PH600?Shn04m?
C`1>CTh09RHV02@T901QHF40KVi^02l_;`0i>CT0:BTY03/k>`29RHTLooooo`2=05iNGP2RXZ80Lg=c
04];B`11@D40DU9B0410@00f=SH0AdM706ATI01KFe/0F5QH06EUI@1FEUH0GemO055AD@1RHV80DE5A
04Y:BP1VIVH0D51@03Lg=`0o?cl0CDe=06UYJ@1:BTX0IfMW04A4A01]KFd0=cLg051@D01VIVH0AdM7
07alO02ATI40/[:b0:BTY02VYZH0V9RH06QXJ016ATH0CDe=065QH@1VIVH0Cdm?05YJFP0f=SH0<C4a
04a<C01LG5`0;bl_0410@01SHf<0?Cdm06e]K@0U9BD0GemO061PH015ADD0HV9R03hn?P23Ph<0>SXj
0410@00h>3P0<c<c03De=@0c<c<0Bd];05aLG00k>c/0Cdm?03Ph>01GEeL0CTi>04e=C@1BDU80>CTi
05aLG011@D40ADE506=SH`0W9bL0<S8b04Y:BP0e=CD0?Cdm03/k>`0_;bl0ATI604e=C@0k>c/0;Bd]
03<c<`1CDe<0>SXj0492@P0Y:BT0BTY:0410@014A4@0?3`l04Y:BP1?Cdl0?3`l03hn?P15ADD0CTi>
05aLG01EEED0Jf][05UIF@1SHf<0@D5108N7Q`2LW9`0RHV906ATI01PH600EUIF04i>CP1@D500>SXj
05ADE011@D40DE5A03Lg=`1GEeL0MgMg08B4Q01/K6`0WYjN09VIV@2UYJD0K6a/0861P@24Q8@0F5QH
07inOP0d=3@0GemO0080@D5108<0KFe]069RHP0X:2P0?clo04M7A`1?Cdl0L71`07inOP1fMWH0JFUY
04e=C@1KFe/0>SXj03hn?P1[Jf/08R8R04];B`0G5aL0K6a/07alO00^;Rh0DE5A04a<C011@D40H61P
04Q8B01>CTh0ADE50492@P0V9RH0BTY:05IFEP1GEeL0DU9B04e=C@1MGEd0B4Q804m?C`0l?3`0?clo
04E5A@1^KVh0SXj>03dm?@1BDU80:RXZ02d];@0a<C40ATI604a<C00C4a<0GUiN061PH00b<S80LG5a
04Q8B017AdL0=SHf05QHF00/;2`0I6AT05iNGP1?Cdl0HV9R07AdM00n?Sh0BDU905=CD`1>CTh0=cLg
03`l?00];Bd0Fe]K02/[:`1BDU80A4A405QHF00j>SX0EeMG03hn?P1:BTX0@d=304M7A`1HF5P0D51@
09BDU016ATH0Hf=S05IFEP16ATH0EeMG02l_;`1WIfL0ATI603/k>`1XJ6P0De=C04U9B@18B4P0>SXj
05aLG018B4P0OGem04M7A`0h>3P0<C4a05MGE`1BDU80P82006EUI@0R8R80DE5A03Ti>@0h>3P0De=C
05EEE@2=SHd0BDU906EUI@1:BTX0ATI6061PH01VIVH0SXj>065QH@2=SHd0E5AD04I6AP1IFET0BDU9
05UIF@0205EEE@0>05MGE`1VIVH0>SXj06UYJ@1>CTh0BTY:06EUI@16ATH0D51@05MGE`1JFUX0HV9R
05eMG@28R8PAooooo`003oooool0o`1UIFD0OGem08>3P`22PX80@41005QHF01CDe<0UYJF06m_K`10
@400SXj>065QH@1?Cdl0E5AD03lo?`1gMgL0M7Ad02<S8`1;Bd/0F5QH03Ph>01XJ6P0HV9R02d];@0m
?Cd0A4A406e]K@2OWil0=3@d02@T900e=CD0G5aL07QhN01gMgL071`L02DU9@1PH600D51@04i>CP2H
V9P0OWin02@T900Z:RX0Fe]K065QH@1lO7`0;2`/03Xj>P1BDU80G5aL04I6AP1iNGT0Kfm_01/K6`0`
<300@d=305IFEP1YJFT0Hf=S02HV9P0h>3P0GemO04];B`1`L700=cLg024Q8@19BDT0MWIf07alO00l
?3`0K6a/02<S8`1<C4`0Hf=S01lO7`16ATH0De=C03Ti>@0^;Rh0KVi^07moO`0a<C40:b/[05UIF@15
ADD0Lg=c03lo?`0J6QX0=3@d04e=C@0f=SH0UIFE03/k>`0I6AT0B4Q806UYJ@1>CTh0Lg=c08j>SP0V
9RH09BDU07YjNP1EEED0Lg=c04i>CP0I6AT0<S8b069RHP0h>3P06ATI05aLG00T92@0;2`/05]KF`1j
NWX061PH03Ph>015ADD0<30`03Xj>P1LG5`05QHF03De=@1QHF40BTY:06ATI029RHT0@D5101dM7@0_
;bl0JVYZ07MgM`1]KFd06a/K03Ti>@1CDe<0LG5a05YJFP29RHT0<c<c051@D01CDe<0E5AD06EUI@1^
KVh06ATI02@T901RHV80O7al05YJFP1LG5`07QhN04U9B@1`L700SXj>03Xj>P1OGel0NGUi03@d=019
BDT0MGEe01lO7`1IFET0@T9205UIF@1ADE40Ti>C05YJFP0M7Ad0FEUI03dm?@1TI6@0GemO02@T900a
<C40FEUI07=cL`1HF5P0OWin01`L7012@T80KFe]04i>CP1eMGD0UiNG02TY:@0W9bL0DE5A06a/K02@
T900L71`02<S8`17AdL0LG5a05eMG@0k>c/0D51@01TI6@1KFe/0KFe]04=3@`1?Cdl0<C4a02PX:020
P800U9BD02l_;`17AdL0<30`07MgM`2YZJT0CDe=03Ph>016ATH0De=C09FEU@1kNg/0;bl_06YZJP0m
?Cd0NWYj09bLW00Z:RX09bLW03dm?@1hN7P0Q8B4075aL@0P8200Jf][09^KV`1UIFD0ZZZZ08^;R`0^
;Rh0<S8b05aLG01[Jf/0T92@06EUI@0U9BD0;2`/079bLP2@T900ATI606e]K@1FEUH0?3`l071`L02C
Ti<0D51@07QhN01_Kfl09RHV034a<@008`2:RXX0GEeM06e]K@1?Cdl0:BTY069RHP2^[Zh0I6AT02l_
;`1MGEd0@T9205aLG01QHF40IfMW034a<@1FEUH0>3Ph04I6AP2DU9@0PH61030`<016ATH0AdM704=3
@`1kNg/0K6a/03<c<`11@D40?Cdm059BDP1LG5`0H61P0451@@0j>SX0BTY:01cooooo0?l0GUiN07Mg
M`15ADD0>3Ph065QH@1IFET0HV9R051@D01IFET0PH6106EUI@0f=SH0HV9R07moO`2>SXh0Hf=S06YZ
JP1VIVH0EeMG06m_K`1=CDd0@d=304a<C01:BTX0Fe]K04=3@`1HF5P0EUIF05aLG011@D40CTi>059B
DP1>CTh0JVYZ06QXJ01WIfL0MWIf09fMW@2BTY80IfMW04];B`1HF5P0CTi>04U9B@1[Jf/0I6AT04];
B`0k>c/0E5AD055AD@0/;2`0AdM704];B`14A4@0G5aL04];B`1VIVH0J6QX05EEE@1eMGD0F5QH09^K
V`1EEED0Fe]K04];B`1<C4`0Bd];0492@P1RHV80H61P04I6AP1cLg<0DU9B08V9R@11@D40FEUI075a
L@1@D500H61P04I6AP19BDT0I6AT03lo?`0j>SX0C4a<038b<P10@400ATI603<c<`1CDe<0GUiN04A4
A00l?3`0Bd];06=SH`0k>c/0DE5A04M7A`1LG5`0CDe=05iNGP1DE5@0@d=305mOG`12@T80E5AD04I6
AP14A4@0<C4a04=3@`17AdL0IFEU071`L00m?Cd0B4Q805UIF@2EUID0Ng]k05IFEP1KFe/0BTY:04e=
C@0h>3P0FEUI061PH01EEED0Bd];05iNGP2BTY80T92@05=CD`1/K6`0[Jf]08b<S01`L700W9bL08V9
R@1JFUX0N7Qh04m?C`1MGEd0Kfm_05=CD`0j>SX0IFEU02h^;P1BDU80F5QH07=cL`26QXH0Lg=c04Q8
B01@D500AdM705eMG@1QHF40IVIV07MgM`13@d<0JFUY01LG5`1>CTh0IfMW02TY:@0h>3P0ATI603Xj
>P1eMGD0<30`04e=C@0h>3P0BTY:01<C4`0Z:RX0?clo020P8011@D40@4100451@@0J6QX0>c/k03Ti
>@1@D500FEUI06QXJ02EUID0>SXj04Q8B00k>c/0>SXj03Ph>016ATH0Cdm?028R8P1bLW80JVYZ03Ph
>023Ph<0@T9203Ph>00Q8B40BTY:01TI6@1CDe<0C4a<05aLG01TI6@0R8R803Xj>P1KFe/0FUYJ028R
8P14A4@0EEEE03Hf=P1MGEd0Bd];05=CD`19BDT0CTi>03dm?@1<C4`0BTY:061PH01CDe<0IFEU0861
P@1RHV80K6a/04I6AP1CDe<0IfMW03dm?@1=CDd0?Cdm08Z:RP1MGEd0D51@05]KF`19BDT0CDe=05eM
G@0`<300FUYJ05eMG@2;Rh/0Hf=S04m?C`0h>3P0HV9R034a<@1VIVH0Lg=c059BDP1cLg<001H0?3`l
05aLG01FEUH0=cLg0410@00S8b<0=cLg03Hf=P1<C4`0MGEe05YJFP20P800?Cdm09^KV`1XJ6P0GUiN
07=cL`0k>c/0@T9204I6AP0i>CT0<C4a0P11@D402`1TI6@0AdM705EEE@1/K6`0D51@04];B`1FEUH0
FEUI075aL@1`L700IVIV017ooooo000?ooooo`3o07QhN01JFUX0Jf][09nOW`1=CDd0D51@069RHP2]
[Jd0IFEU038b<P1?Cdl0EUIF0820P02l_;`0>CTi05IFEP1dM7@0AdM708j>SP1CDe<0?clo0492@P2B
TY80QHF506e]K@0g=cL0>CTi06IVIP2RXZ80FUYJ07EeM@23Ph<0;bl_06MWI`1OGel0?Shn0:>SX`14
A4@0;bl_03De=@1WIfL0>c/k04I6AP10@400>3Ph069RHP1PH6006ATI0410@00l?3`0;Rh^05EEE@18
B4P071`L02`/;013@d<0@T9207QhN01_Kfl051@D02PX:01;Bd/0BTY:0:2PX01CDe<05ADE01lO7`1F
EUH0ATI6069RHP2?Shl0:BTY030`<02@T900EeMG08b<S02e]KD0;Bd]01LG5`14A4@0Ph>305QHF01J
FUX02PX:020P801IFET0EUIF02HV9P1aLG40FUYJ018B4P1=CDd0H61P01lO7`1TI6@0:RXZ034a<@0o
?cl0JVYZ03Hf=P0[:b/09bLW03<c<`1=CDd0Ogmo03Ti>@0Z:RX0E5AD02/[:`15ADD0V9RH02h^;P0S
8b<0G5aL079bLP1DE5@0VIVI05iNGP0G5aL0B4Q804e=C@16ATH0U9BD02@T900R8R80<c<c04i>CP1]
KFd0@41007]kN`0];Bd0J6QX06IVIP0c<c<0ATI607EeM@0E5AD0?Cdm05EEE@1JFUX0;Rh^05ADE00U
9BD0Kfm_09jNWP0e=CD06a/K059BDP1;Bd/0H61P09FEU@0Z:RX06a/K034a<@0l?3`0Fe]K09^KV`32
`/80:2PX04a<C01[Jf/0EUIF0:VYZ@1lO7`0<C4a05eMG@1EEED0O7al06QXJ02FUYH0;Rh^05YJFP2B
TY80J6QX07EeM@2>SXh0;Rh^03De=@25QHD0Cdm?0410@01JFUX09RHV0451@@2^[Zh0I6AT04A4A01J
FUX0=SHf061PH02HV9P0BTY:038b<P1SHf<0=3@d08R8R02[Zj/0F5QH03hn?P1>CTh0GEeM0;6a/@1X
J6P06QXJ03Hf=P1]KFd0CDe=06][J`0Y:BT0;bl_07emO@2=SHd0OWin06IVIP0J6QX0@41006EUI@1X
J6P0VYZJ02XZ:P0`<300CDe=051@D01UIFD0OGem01TI6@0c<c<0MgMg02HV9P1WIfL0>c/k02DU9@11
@D40LW9b03/k>`0Z:RX0<S8b03@d=01^KVh0OWin02d];@0j>SX0De=C04A4A01GEeL0Ogmo06ATI00b
<S80@d=304Y:BP1DE5@0O7al08n?S`0U9BD0:b/[000M04Y:BP1SHf<0YjNW061PH00Z:RX0?Cdm05YJ
FP1^KVh0MWIf09RHV01;Bd/0?Cdm05=CD`1YJFT0@d=305eMG@0`<3005QHF04a<C01QHF40EEEE07em
O@0a<C406ATI04A4A01^KVh0=3@d04E5A@1CDe<00P0e=CD0102BTY80C4a<02TY:@17AdLLooooo`1g
071`L01cLg<0C4a<03Ph>00_;bl0AdM704i>CP15ADD0I6AT06e]K@1LG5`0>CTi05IFEP1QHF40QHF5
0:RXZ01YJFT0GemO04i>CP2MWId0FUYJ02@T900k>c/0A4A405eMG@0e=CD0@D5103Ph>01?Cdl0@T92
06a/K01JFUX0B4Q806IVIP1mOGd0VYZJ07]kN`1TI6@0Lg=c07alO01@D500?Shn05mOG`1GEeL0DE5A
05MGE`1<C4`0CDe=04a<C014A4@0=3@d04E5A@1EEED0>SXj04i>CP0[:b/0?clo05aLG01^KVh0I6AT
07EeM@1WIfL0GUiN069RHP1?Cdl0IVIV05YJFP1FEUH0GemO05iNGP1EEED0JFUY07=cL`1^KVh0AdM7
05eMG@1BDU80<S8b03hn?P12@T80ATI604e=C@0e=CD0BDU90451@@0f=SH0AdM703hn?P18B4P0BTY:
05QHF00l?3`0<c<c04Y:BP17AdL0<C4a0410@01GEeL0CTi>03Hf=P1=CDd0FEUI04i>CP1@D500CDe=
05]KF`1CDe<0GemO05=CD`1TI6@0A4A4051@D01MGEd0ADE505ADE025QHD0Ng]k06YZJP22PX800P1S
Hf<04`1XJ6P0>CTi05mOG`0m?Cd0KFe]04m?C`1=CDd0LW9b07EeM@1WIfL0_[jn0;Zj^P25QHD0EUIF
04E5A@1IFET0IVIV079bLP0a<C400P0l?3`0100j>SX0A4A406IVIP0f=SH204i>CP0405UIF@2NWYh0
O7al05YJFP80M7Ad0200GemO02DU9@0g=cL0HV9R04U9B@1NGUh0@41007moO`2IVIT0@4100492@P17
AdL0De=C08:2PP10@400F5QH04Q8B01EEED092@T03Lg=`1<C4`07alO04Q8B010@400@d=3014A4@0l
?3`0:RXZ030`<00b<S80;bl_09jNWP80CTi>05<0A4A403/k>`0];Bd0CTi>04m?C`0E5AD0DE5A05QH
F00d=3@0G5aL04E5A@1UIFD0@D5104m?C`0k>c/0Ogmo065QH@10@400DU9B07IfMP0Y:BT0KFe]07If
MP0Y:BT0BDU905IFEP12@T80CDe=03Hf=P13@d<0?3`l05=CD`0e=CD0Bd];03Ti>@1<C4`0?3`l05=C
D`1SHf<0Fe]K07EeM@1:BTX0CDe=05EEE@0h>3P0EUIF02<S8`1RHV80?Cdm03lo?`2=SHd0D51@03Hf
=P0d=3@0<30`08V9R@10@400JFUY04e=C@1LG5`0>SXj065QH@0c<c<0QhN7061PH00P8200DU9B03Lg
=`0_;bl0IFEU03Ti>@1LG5`0<S8b03`l?00L71`0;2`/07IfMP1IFET0NWYj04M7A`1dM7@0IfMW03hn
?P0205EEE@0A055AD@1XJ6P0BDU904E5A@0o?cl0>CTi071`L01BDU80Cdm?08B4Q01EEED0Fe]K06MW
I`1/K6`0JFUY06][J`1fMWH04Oooool000oooooo06`0bLW9051@D01LG5`0WIfM08^;R`18B4P0?clo
07alO02KVi/0KVi^071`L01:BTX0>CTi05=CD`1DE5@0GemO03dm?@0e=CD0DU9B06][J`0f=SH0AdM7
06=SH`0H61P0IfMW04Y:BP0c<c<0D51@03lo?`0];Bd0NGUi09VIV@0d=3@0?clo0410@01VIVH0Rh^;
06IVIP0K6a/0?Cdm05MGE`1>CTh0Ng]k06][J`0];Bd0@d=305ADE015ADD0XJ6Q05ADE00H61P0:RXZ
06ATI01>CTh0QHF5030`<00Q8B40<30`065QH@16ATH0KVi^06IVIP0S8b<0BTY:07]kN`0g=cL0Cdm?
04i>CP0S8b<0;Rh^069RHP18B4P0>3Ph02PX:00Y:BT0@D5105aLG014A4@07QhN03dm?@0a<C40@410
069RHP0K6a/06ATI04a<C01=CDd0D51@07EeM@1gMgL05ADE02XZ:P1IFET0D51@0::RXP15ADD05aLG
02<S8`1PH600@T9205mOG`1<C4`0;Rh^05EEE@0k>c/0C4a<04e=C@1_Kfl202<S8`0g061PH01BDU80
A4A407alO00T92@07alO05mOG`2?Shl0>SXj028R8P0m?Cd0=cLg08Z:RP1hN7P08R8R03@d=01:BTX0
<C4a05MGE`1gMgL0FUYJ030`<01DE5@0;Bd]09FEU@3=cLd0;Rh^01/K6`1EEED0HV9R06i^KP1lO7`0
8b<S034a<@1_Kfl0Fe]K04m?C`2=SHd0I6AT02l_;`1fMWH0BDU904e=C@1VIVH0;Bd]01`L701?Cdl0
T92@05mOG`1EEED0:RXZ02<S8`10@400QhN704E5A@0204M7A`1k02TY:@10@400Vi^K05EEE@0g=cL0
?Cdm03Lg=`1>CTh0TI6A05UIF@0^;Rh0DU9B07YjNP2CTi<0O7al028R8P0`<300HF5Q075aL@1VIVH0
ZJVY03dm?@1MGEd0EUIF04E5A@1PH600[jn_03/k>`0n?Sh0WinO0<G5a@1BDU80<C4a03`l?01KFe/0
R8R804a<C01VIVH0CTi>02/[:`1OGel0?clo05eMG@0W9bL0>3Ph06a/K01RHV80<c<c03Ti>@1CDe<0
=cLg0;Jf]P1TI6@0;2`/05MGE`0g=cL0Jf][0;6a/@0a<C40:2PX04a<C018B4P0NWYj04Y:BP0I6AT0
@d=3069RHP1bLW80OGem04e=C@0O7al0BTY:06][J`1ADE40MgMg08R8R00/;2`0>SXj069RHP24Q8@0
R8R80:j^[P0i>CT0B4Q805YJFP1/K6`0FEUI05=CD`1`L700<30`06MWI`1aLG40B4Q805eMG@1CDe<0
9RHV04];B`1>CTh0Cdm?034a<@1jNWX0>c/k061PH02<S8`0G5aL01`L700S8b<0AdM704=3@`2k^k/0
U9BD024Q8@0/;2`0J6QX04a<C01QHF40P82003Ti>@0U9BD0O7al0861P@1OGel0R8R801cooooo01/0
@T92069RHP1OGel0D51@05aLG01NGUh0KVi^051@D01dM7@0L71`06MWI`1UIFD0KFe]05aLG027QhL0
EEEE06IVIP1OGel0De=C069RHP1=CDd0@41004=3@`1ADE40H61P0410@01MGEd00P1OGel07P12@T80
CDe=05YJFP1DE5@0JVYZ05iNGP1gMgL0Q8B407moO`2DU9@0IFEU03hn?P0m?Cd0G5aL05UIF@0n?Sh0
EeMG065QH@10@400ATI604Y:BP0];Bd0BDU904M7A`0i>CT0HF5Q05=CD`1iNGT0Jf][055AD@80I6AT
02X0KFe]04Q8B01>CTh0@T9203De=@10@400@d=304e=C@1ADE40?clo04=3@`0c<c<0@41003/k>`14
A4@0EeMG03De=@1SHf<0<c<c03Hf=P1dM7@0=3@d02/[:`0l?3`0;2`/03Xj>P0g=cL0:RXZ03Ti>@1@
D500?Shn03@d=00h>3P0DU9B038b<P0n?Sh0:2PX04i>CP11@D40C4a<04];B`0h>3P204Y:BP1804=3
@`16ATH0EeMG07=cL`1TI6@0IFEU06=SH`1[Jf/0IVIV09JFUP2BTY80RHV906i^KP1iNGT0MWIf05=C
D`1BDU80ADE504Y:BP1;Bd/0CDe=0410@018B4P0OWin09bLW01QHF40W9bL0:j^[P2ATI40E5AD0451
@@1HF5P0Bd];07AdM00i>CT0Bd];04e=C@0j>SX0@d=304];B`0i>CT0D51@03De=@0f=SH0G5aL069R
HP11@D40GEeM04E5A@1UIFD0=SHf0492@P1OGel09RHV07QhN012@T80D51@06=SH`1;Bd/0Cdm?04U9
B@0h>3P0HV9R04];B`1<C4`0>c/k059BDP0i>CT0Bd];05ADE014A4@0Fe]K0P1EEED0K`0m?Cd0H61P
03Ti>@0`<300@D5103`l?01mOGd0>3Ph04e=C@0f=SH0>SXj03`l?01KFe/0Cdm?02d];@29RHT0P820
02l_;`1WIfL0<S8b04=3@`0W9bL0@D5101HF5P14A4@0CTi>04a<C01OGel0Vi^K03Ti>@1NGUh0EeMG
024Q8@0b<S80BDU902LW9`15ADD0<C4a04a<C01;Bd/0Fe]K04Q8B013@d<0AdM705=CD`18B4P0QXJ6
06EUI@1HF5P0LW9b059BDP1WIfL0LG5a03lo?`1CDe<0ATI6071`L01;Bd/0;Bd]06IVIP1=CDd0DE5A
04a<C00W9bL0AdM704I6AP26QXH0EEEE03/k>`0^;Rh0EEEE03De=@1/K6`0J6QX03Ph>01BDU808b<S
04M7A`1NGUh0EeMG061PH016ATH0CDe=01DE5@0f=SH0F5QH05iNGP1/K6`0Bd];08>3P`1QHF40AdM7
05QHF01KFe/0Ph>306ATI00n?Sh0Bd];05=CD`0g=cL0Jf][06a/K01`L700MWIf07UiN@1mOGd0GemO
05eMG@1^KVh0QhN708B4Q00Aooooo`003oooool0o`1lO7`0JFUY061PH01HF5P0O7al05eMG@0f=SH0
Cdm?07emO@1iNGT0TI6A03Lg=`0f=SH0FEUI06EUI@2^[Zh0Bd];02<S8`1<C4`0E5AD05aLG01aLG40
WinO02XZ:P17AdL0GEeM07AdM02][Jd0>c/k02l_;`0[:b/0ATI607AdM025QHD05QHF02TY:@1DE5@0
I6AT05IFEP2@T900Rh^;038b<P0_;bl0L71`05MGE`1jNWX0;2`/01dM7@1:BTX0I6AT02XZ:P0f=SH0
@D51034a<@16ATH0Hf=S02HV9P11@D40<c<c01PH601^KVh0Xj>S02HV9P0j>SX0AdM703/k>`1[Jf/0
OWin01TI6@0P8200ADE505=CD`1_Kfl0>CTi01<C4`0l?3`0Lg=c07UiN@0m?Cd0X:2P06EUI@0G5aL0
@D51051@D01=CDd0W9bL02<S8`0H61P0:b/[04Y:BP0`<300Fe]K020P800I6AT0ADE506QXJ00e=CD0
DE5A04U9B@0N7Qh0<c<c07MgM`0W9bL0Kfm_02l_;`0O7al0@T92092@T015ADD051@D038b<P17AdL0
F5QH09BDU00c<c<03Ph>04Y:BP1]KFd0AdM7065QH@1@D5008b<S04i>CP1bLW80=CDe05iNGP1[Jf/0
5aLG02l_;`1VIVH0EEEE06ATI01FEUH0:2PX04i>CP29RHT0Hf=S0451@@1KFe/0=3@d05aLG02BTY80
<30`02h^;P1LG5`09BDU02TY:@1eMGD0PH6102/[:`0g=cL0DE5A06=SH`24Q8@0<30`02DU9@0d=3@0
E5AD05iNGP2JVYX0BDU902DU9@0];Bd0EeMG055AD@1nOWh0^KVi02d];@0e=CD0DU9B05aLG021PH40
@D5101lO7`1DE5@0FEUI065QH@1CDe<0S8b<01DE5@1TI6@0Kfm_03Hf=P1DE5@0Jf][038b<P0X:2P0
M7Ad04i>CP14A4@0?Shn04Q8B01>CTh0SXj>03@d=00^;Rh0ATI603Hf=P2CTi<0Hf=S024Q8@1:BTX0
C4a<04=3@`2CTi<0MWIf02LW9`19BDT0JFUY07UiN@1CDe<06a/K061PH01gMgL0ADE508^;R`1]KFd0
<C4a08>3P`1jNWX0M7Ad09>CT`0k>c/0=3@d06QXJ01[Jf/0IVIV05MGE`0g=cL0E5AD05iNGP0i>CT0
EeMG06ATI00T92@0EUIF08n?S`18B4P0K6a/051@D00/;2`0GEeM07MgM`1EEED09BDU04I6AP13@d<0
Fe]K08Z:RP1fMWH0;Rh^04e=C@0o?cl0Cdm?06EUI@008`2ATI40@T9205EEE@13@d<0Fe]K09fMW@2G
UiL09bLW04E5A@1TI6@0H61P07=cL`2BTY80@D5102XZ:P1CDe<0S8b<04M7A`1>CTh0KVi^02d];@1O
Gel0PH6103Hf=P0g=cL0ATI601HF5P0[:b/0DE5A05]KF`0S8b<0@41002@T9016ATH0D51@01cooooo
02X0M7Ad06MWI`19BDT0>CTi03dm?@1PH600EeMG04A4A01OGel0QhN706e]K@11@D40EEEE08j>SP2l
_;`0[Jf]07inOP1PH600EeMG07MgM`15ADD0<c<c04U9B@0o?cl0@d=3055AD@1CDe<0?Shn06UYJ@1H
F5P0JVYZ07]kN`12@T80UYJF08n?S`1dM7@0Rh^;07MgM`2MWId0KVi^04m?C`19BDT205YJFP0@04M7
A`1]KFd0EEEE03/k>`1IFET0GUiN02PX:00m?Cd0F5QH05ADE01LG5`09bLW0451@@1HF5P0EeMG06IV
IP80JVYZ02P0C4a<075aL@1OGel0CTi>04e=C@1aLG40Lg=c06IVIP19BDT0GUiN05IFEP29RHT0>c/k
059BDP1hN7P0I6AT05mOG`0e=CD0?Shn06m_K`0e=CD0;bl_04a<C00h>3P0<S8b03hn?P18B4P0Cdm?
05MGE`1=CDd0>SXj03/k>`1DE5@0>c/k0410@00d=3@0DU9B04a<C01IFET0C4a<0P1?Cdl0H`0i>CT0
CTi>05=CD`18B4P0?3`l04e=C@0i>CT0De=C05]KF`13@d<0C4a<05YJFP2CTi<0PH6106a/K01aLG40
F5QH059BDP0g=cL0BTY:0451@@1DE5@0?clo055AD@2VYZH0TY:B08F5Q@2NWYh0Shn?0:FUY@1FEUH0
ATI607EeM@1DE5@0OGem059BDP1>CTh0BDU904i>CP1?Cdl0IVIV03Hf=P1=CDd0?Shn04];B`2;Rh/0
Kfm_04E5A@1dM7@0D51@079bLP0k>c/0?Shn06MWI`0`<300JVYZ02TY:@1WIfL0Hf=S02l_;`1ADE40
CTi>03`l?01NGUh0CDe=05MGE`0o?cl0BTY:03Xj>P1@D500HV9R02<S8`0g=cL0BDU904e=C@0F5QH0
;Rh^03Ti>@1EEED0Bd];06=SH`1eMGD0@D5104e=C@0c<c<0IfMW03Ti>@1:BTX0>3Ph00`<300k>c/0
FUYJ0410@023Ph<0A4A40492@P0l?3`0De=C02PX:002059BDP1E03hn?P1JFUX0GemO03@d=01IFET0
G5aL01<C4`12@T80E5AD03lo?`1/K6`0D51@06UYJ@1jNWX0Fe]K04i>CP1WIfL0>3Ph055AD@1NGUh0
MWIf05QHF01WIfL0LW9b08^;R`10@400H61P03lo?`1<C4`0:RXZ08R8R01CDe<0EEEE05iNGP0n?Sh0
FUYJ05QHF019BDT0Fe]K04];B`1nOWh0CDe=0410@00^;Rh0CTi>020P8030`<00TI6A03De=@1EEED0
=SHf03dm?@1gMgL0EUIF06][J`0[:b/0DU9B04Q8B00_;bl0FEUI05]KF`2:RXX0Bd];069RHP1LG5`0
B4Q805UIF@0l?3`0ADE5059BDP11@D40;bl_04Y:BP11@D40Jf][04Y:BP1BDU80Fe]K04a<C01EEED0
Cdm?07EeM@1JFUX0L71`075aL@0Aooooo`003oooool0^@1XJ6P0IfMW0;Bd]01gMgL0C4a<07AdM01Q
HF40]kNg04e=C@1YJFT0U9BD07=cL`1aLG40UYJF03dm?@29RHT0T92@05UIF@1hN7P0LG5a02LW9`1G
EeL0SXj>08:2PP1hN7P06a/K03dm?@13@d<0Cdm?03Ph>01=CDd0EEEE01PH6021PH40A4A403Xj>P1G
EeL0:RXZ01lO7`1`L700SXj>02PX:00Q8B40?clo065QH@29RHT0ATI601`L700o?cl0GEeM04A4A01h
N7P0Lg=c01/K6`13@d<0N7Qh05IFEP2:RXX0EEEE01hN7P0G5aL0GUiN06IVIP20P8009BDU04];B`0o
?cl0GUiN04I6AP1;Bd/0L71`01hN7P0f=SH0G5aL02PX:018B4P0>3Ph03De=@0];Bd0GUiN06MWI`0R
8R80;bl_038b<P1;Bd/0QHF5055AD@0>3Ph0>3Ph03De=@0c<c<0WinO05UIF@0F5QH0@D5102PX:00n
?Sh0OWin08F5Q@0I6AT092@T0451@@14A4@0/k>c04E5A@0Q8B40=cLg03hn?P1FEUH0ADE505UIF@0S
8b<0A4A404];B`1dM7@0;Rh^06i^KP0d=3@08B4Q038b<P1>CTh0<C4a03Lg=`0[:b/0=SHf055AD@1j
NWX0=CDe02HV9P14A4@0E5AD07UiN@1bLW805QHF05EEE@1fMWH0ATI606YZJP2TY:@0;bl_02d];@1g
MgL0DE5A05QHF01bLW807alO01hN7P1UIFD0Ogmo061PH018B4P08R8R03<c<`1mOGd0O7al01/K6`0[
:b/0?3`l02TY:@1>CTh0L71`03De=@1BDU80=3@d02LW9`18B4P0IVIV065QH@0];Bd0EUIF03Xj>P2H
V9P0Kfm_02LW9`13@d<0J6QX02d];@1@D500Xj>S02LW9`0m?Cd0HF5Q04E5A@25QHD0XZ:R0080:BTY
01@0BTY:06][J`23Ph<0EEEE03<c<`19BDT0CTi>04a<C01KFe/0QHF502l_;`0m?Cd0PH6105EEE@1g
MgL0=cLg02HV9P1=CDd0OWin02TY:@80;bl_0540HV9R092@T00o?cl0@d=305eMG@0V9RH0De=C08N7
Q`0o?cl0D51@03Hf=P1;Bd/0QhN704e=C@0/;2`0?Cdm02/[:`1^KVh0S8b<01lO7`1WIfL0EUIF04U9
B@2?Shl0Rh^;02PX:00S8b<0H61P06QXJ02OWil0L71`03<c<`1CDe<0HV9R07IfMP1iNGT0SHf=04i>
CP0f=SH0HF5Q08V9R@1WIfL0TI6A04U9B@0W9bL0=SHf05iNGP1VIVH0QHF506ATI00Z:RX0;bl_06m_
K`1IFET0E5AD06YZJP0_;bl0:BTY07QhN01NGUh0ATI605mOG`0Y:BT0<c<c0451@@1XJ6P0>c/k05=C
D`18B4P0De=C061PH01dM7@08b<S02HV9P0f=SH0ATI605]KF`29RHT09bLW03@d=01LG5`07?ooool0
gP1=CDd0Ng]k06i^KP1FEUH0B4Q806i^KP1?Cdl0@41006ATI01nOWh0HV9R06a/K01aLG40HV9R07Ee
M@1jNWX0IfMW05UIF@1=CDd0P82005UIF@0h>3P0?Shn04=3@`16ATH0@d=3069RHP0j>SX0F5QH03`l
?01GEeL0KFe]03hn?P1kNg/0TY:B06IVIP2<S8`0QHF50:ZZZP1hN7P0FUYJ05ADE01YJFT0FEUI04I6
AP1IFET0D51@04E5A@1;Bd/0G5aL03Ti>@0k>c/0IFEU03Ti>@1RHV80<C4a051@D01lO7`0HV9R065Q
H@1=CDd0IVIV079bLP1BDU80?Shn05YJFP1>CTh0?Cdm04=3@`1GEeL0I6AT04m?C`1TI6@0EUIF03/k
>`1>CTh0HV9R03/k>`1KFe/0@T92059BDP1;Bd/0<C4a04Y:BP0f=SH09bLW03/k>`0b<S809BDU03@d
=01<C4`0;Bd]02h^;P0m?Cd0@d=3020P800k>c/0CTi>055AD@0`<300@41004m?C`0[:b/0@D5103dm
?@12@T80@41004U9B@0m?Cd0GEeM075aL@1HF5P0Fe]K07QhN02UYJD0Shn?071`L01IFET0Ogmo09VI
V@1GEeL0FEUI051@D018B4P0>c/k06IVIP1PH600IFEU07AdM01VIVH0F5QH07UiN@2GUiL0ZJVY05MG
E`1;Bd/0Ng]k04A4A01aLG40AdM705aLG010@400?Cdm059BDP1KFe/0<30`0492@P13@d<0Ph>308n?
S`1gMgL0Jf][06IVIP14A4@0LW9b03lo?`15ADD0KFe]03`l?01hN7P0:RXZ079bLP1fMWH0<S8b04A4
A018B4P0:BTY06i^KP0/;2`0Fe]K03hn?P11@D4061PH03`l?01>CTh0?clo04=3@`1:BTX0DU9B02@T
900g=cL0AdM702/[:`0j>SX0@d=305eMG@1EEED0N7Qh03lo?`0/;2`0@41004Y:BP1;Bd/07alO04];
B`1BDU80=SHf07YjNP1<C4`0=cLg034a<@1BDU80CTi>05EEE@1GEeL0Fe]K065QH@1LG5`05ADE055A
D@1MGEd0?3`l04=3@`0n?Sh0DU9B05eMG@0h>3P0B4Q804Y:BP1CDe<0BTY:04A4A080ADE500X0?clo
069RHP1@D500HF5Q09VIV@1/K6`0@410069RHP1>CTh0H61P0P1UIFD0=P1:BTX0IVIV069RHP1:BTX0
BDU908R8R01;Bd/0K6a/05MGE`29RHT0ADE50410@00h>3P0EEEE030`<01CDe<0D51@0492@P22PX80
@d=304U9B@1<C4`0CDe=07EeM@1BDU80L71`02HV9P0o?cl0FUYJ07inOP2:RXX0?3`l05QHF01SHf<0
F5QH06][J`0o?cl0CDe=05eMG@1@D500:b/[03hn?P0R8R80MgMg05=CD`17AdL0Lg=c051@D01?Cdl0
I6AT07AdM01oOgl0JFUY0::RXQ7ooooo000?ooooo`190861P@1<C4`0FUYJ09nOW`1WIfL0Bd];04U9
B@2EUID0NWYj0492@P1EEED0Bd];05QHF01jNWX0=SHf04U9B@12@T80KFe]07IfMP1@D500<c<c04=3
@`1EEED0EeMG07QhN01;Bd/0:b/[03lo?`1FEUH0Rh^;0:VYZ@2GUiL0820P04e=C@1[Jf/0JFUY09nO
W`0b<S809RHV02DU9@1MGEd0D51@071`L01=CDd09bLW030`<01@D500>3Ph08f=S@1EEED08b<S04U9
B@1_Kfl0=SHf04E5A@0T92@0:b/[055AD@1hN7P08b<S03Ti>@0f=SH0<C4a07alO012@T805aLG038b
<P0m?Cd0?3`l06][J`2FUYH05ADE02XZ:P0205IFEP3G09>CT`1hN7P08b<S0410@01GEeL0EUIF03lo
?`1UIFD051@D02<S8`1MGEd0IVIV03De=@1XJ6P0CTi>01PH6013@d<0KFe]03De=@1bLW80<c<c01/K
6`0U9BD0KVi^05IFEP17AdL0?Shn01lO7`0n?Sh0JVYZ02LW9`0o?cl0@d=302PX:01LG5`0KVi^03@d
=00_;bl0?clo02@T901CDe<0/;2`075aL@0E5AD0:b/[04A4A01NGUh0WinO03Lg=`0Q8B40>CTi05mO
G`1KFe/0D51@07AdM00`<300GemO07=cL`0c<c<0CTi>08b<S00J6QX0=SHf05]KF`1QHF40A4A405=C
D`0Y:BT0@T9204Q8B00g=cL0<S8b05YJFP0Y:BT0CDe=08^;R`0Y:BT0:b/[034a<@1HF5P0DU9B08J6
QP1_Kfl07AdM05MGE`1dM7@0DU9B09bLW00o?cl0820P02HV9P21PH40Q8B4055AD@1kNg/07AdM02d]
;@1bLW80BTY:07emO@1`L700<C4a03<c<`1QHF40IFEU08J6QP1/K6`05aLG03Ti>@20P800Hf=S02l_
;`1OGel0=SHf06EUI@1SHf<0;bl_04a<C01>CTh0;2`/05eMG@2LW9`0HF5Q059BDP0Z:RX0EeMG0;Vi
^@2FUYH08R8R055AD@1IFET0G5aL06MWI`0];Bd0Bd];08j>SP1SHf<0TY:B06MWI`0^;Rh0Fe]K0861
P@1PH600Q8B402/[:`0e=CD0M7Ad06m_K`1jNWX0IFEU01DE5@0_;bl0G5aL05=CD`2EUID0<30`02DU
9@15ADD0XZ:R07UiN@1OGel0?Cdm03/k>`15ADD0IFEU04Y:BP1=CDd0IfMW01TI6@10@400De=C04M7
A`1HF5P0D51@02HV9P14A4@0Hf=S07emO@0h>3P0>CTi03Xj>P1;Bd/0Ti>C06MWI`0W9bL0=cLg03<c
<`16ATH0NGUi0:2PX00i>CT0:2PX03`l?01HF5P0I6AT08B4Q018B4P09BDU04];B`13@d<0Bd];0861
P@0/;2`09RHV05iNGP1BDU80>SXj03lo?`1OGel06a/K03lo?`1ADE40D51@04E5A@1GEeL07?ooool0
@@1EEED0NWYj05MGE`0n?Sh0OWin07YjNP1^KVh0BTY:07AdM02=SHd0K6a/04Q8B01^KVh0R8R80:>S
X`2?Shl0QXJ607UiN@1/K6`0OGem051@D018B4P0F5QH051@D017AdL0B4Q806YZJP1?Cdl0KVi^04Q8
B01GEeL0Ng]k04I6AP2ATI40TY:B09>CT`2JVYX0S8b<09FEU@1gMgL0B4Q8051@D01YJFT0LW9b04=3
@`1SHf<0F5QH03Xj>P1BDU80FEUI02LW9`13@d<0OWin0492@P1kNg/0>CTi05=CD`1cLg<0EeMG06UY
J@1ADE40MgMg04I6AP1KFe/0ADE50080DE5A0=l0ADE506EUI@1fMWH0BDU905aLG01ADE40Q8B405YJ
FP1PH600NWYj0410@01DE5@0?Cdm03/k>`1jNWX0<S8b02l_;`14A4@09bLW02h^;P0h>3P0=cLg0492
@P1IFET0=SHf03@d=00h>3P0DU9B02XZ:P11@D40?clo05eMG@17AdL0CTi>0492@P1;Bd/0EEEE0492
@P15ADD0C4a<05YJFP1FEUH0IVIV03Lg=`1ADE40F5QH05IFEP19BDT0JVYZ06m_K`1dM7@0LW9b06][
J`1HF5P0EUIF03<c<`17AdL0A4A405]KF`0c<c<0DE5A08B4Q023Ph<0Ti>C07YjNP25QHD0O7al06IV
IP1JFUX0Kfm_05UIF@1WIfL0<S8b04I6AP1@D500F5QH05EEE@1FEUH0AdM704Y:BP0f=SH0DE5A08j>
SP1LG5`0A4A405aLG01]KFd0EeMG05]KF`1hN7P0RHV90451@@20P800Bd];08F5Q@1oOgl0EUIF04i>
CP1CDe<0?clo06YZJP0c<c<0GEeM065QH@1JFUX04Q8B04A4A01DE5@06a/K051@D017AdL0DU9B018B
4P1<C4`0=CDe03Ph>01GEeL0CDe=05eMG@0h>3P0?Cdm03<c<`0a<C40Cdm?07emO@1UIFD09bLW04m?
C`1GEeL0>CTi06QXJ00c<c<0C4a<01HF5P0k>c/0=cLg051@D01IFET0>3Ph04Y:BP1OGel0C4a<06YZ
JP23Ph<0EEEE03dm?@0k>c/0?Shn05=CD`17AdL0@41005=CD`1QHF40>SXj04m?C`13@d<0ADE504U9
B@1TI6@0Hf=S05YJFP1UIFD0LG5a03hn?P1IFET0Fe]K08b<S01dM7@0Lg=c04M7A`1=CDd0Ph>3071`
L01/K6`0Kfm_079bLP2@T900F5QH07inOP1CDe<0Bd];02HV9P1FEUH09RHV07alO01>CTh0@41004I6
AP0c<c<0?Cdm05UIF@1HF5P0NWYj04M7A`1IFET0FUYJ04A4A01PH600FUYJ06m_K`19BDT0IFEU04m?
C`0c<c<0BDU90451@@1<C4`0D51@03Ph>011@D40DE5A03<c<`1>CTh0DU9B04Y:BP1EEED0M7Ad07Qh
N01IFET0R8R806m_K`23Ph<0K6a/017ooooo000?ooooo`0J0;6a/@1DE5@0J6QX06m_K`20P800GEeM
051@D01nOWh0GUiN07emO@25QHD0=SHf04E5A@1EEED0D51@0:2PX01CDe<0:BTY051@D01[Jf/0ADE5
08f=S@2@T900;Rh^04e=C@1LG5`2079bLP1Q02DU9@0P8200C4a<07moO`1QHF40O7al01lO7`0f=SH0
C4a<06MWI`0n?Sh0LG5a05=CD`0Z:RX0A4A406UYJ@0c<c<0I6AT02LW9`0_;bl0IfMW08N7Q`1@D500
E5AD06YZJP0c<c<0Jf][05iNGP0i>CT0H61P03Lg=`0_;bl0FEUI07AdM00];Bd0FEUI03Xj>P1;Bd/0
H61P05mOG`0T92@0=cLg0451@@18B4P0HF5Q03Xj>P0S8b<0=3@d04e=C@0i>CT0?clo096AT@1=CDd0
71`L03hn?P0m?Cd0?clo08N7Q`0[:b/07AdM051@D01MGEd0;Bd]05UIF@0];Bd0:BTY05IFEP1IFET0
;Bd]0492@P16ATH0=cLg05UIF@1LG5`0=cLg0451@@0i>CT0?3`l061PH01RHV808R8R02h^;P1=CDd0
?Shn06MWI`1gMgL09bLW02DU9@16ATH0H61P04a<C01=CDd0@d=302l_;`1:BTX0De=C02LW9`0205AD
E00m02XZ:P10@400CTi>04e=C@1GEeL0CDe=03De=@1BDU80OGem03hn?P0_;bl0KVi^03`l?01FEUH0
SXj>02/[:`14A4@0EEEE030`<01ADE40YJFU065QH@0h>3P0Bd];03Xj>P1OGel0QHF503Ph>017AdL0
EEEE06IVIP16ATH0NGUi034a<@0`<300DU9B05mOG`10@400Kfm_07alO00b<S80<30`06e]K@10@400
JFUY04i>CP0[:b/0Fe]K08Z:RP1YJFT0CTi>05EEE@14A4@0Ng]k09JFUP1CDe<0E5AD075aL@0e=CD0
@41008V9R@0204Y:BP1T05MGE`0i>CT0I6AT07YjNP0_;bl0@T9204];B`0k>c/0Lg=c04m?C`0Y:BT0
D51@06QXJ01CDe<0N7Qh05MGE`0h>3P0De=C03hn?P1dM7@0:RXZ024Q8@1KFe/0MGEe03hn?P1QHF40
FUYJ03De=@1LG5`0C4a<06UYJ@27QhL0;Rh^05ADE01hN7P0ADE504a<C011@D40>SXj06YZJP1eMGD0
=3@d06ATI00c<c<0@D5106=SH`1QHF40?Shn059BDP0o?cl0?Cdm06YZJP2JVYX0CTi>03De=@1QHF40
@T9207=cL`2MWId0GEeM03<c<`1MGEd0H61P0410@01mOGd0RXZ:0451@@1hN7P0Ng]k05UIF@1`L700
B4Q802PX:00n?Sh0MgMg05QHF01WIfL0Ng]k02LW9`0j>SX0DE5A069RHP11@D40AdM7075aL@0a<C40
FUYJ08>3P`0j>SX0FEUI05MGE`0[:b/0CTi>07AdM01EEED0AdM704a<C00c<c<0BTY:06m_Kacooooo
02d0KVi^07YjNP1`L700D51@061PH01XJ6P0CDe=0410@01QHF40Kfm_06a/K01JFUX0Kfm_07alO01k
Ng/0Shn?08j>SP1NGUh0DE5A07YjNP1CDe<0D51@04I6AP0m?Cd0DE5A05]KF`1PH600BDU905iNGP19
BDT0Fe]K05YJFP0k>c/0J6QX07QhN01GEeL0MGEe08R8R02CTi<0KFe]05=CD`1<C4`0G5aL05EEE@18
B4P00P1@D500NP0g=cL0DU9B051@D00k>c/0@d=305=CD`11@D40GEeM03Ph>01:BTX0I6AT05EEE@1M
GEd0HV9R06IVIP1JFUX0FEUI04m?C`1NGUh0DU9B05IFEP1UIFD0QHF506QXJ01CDe<0FEUI07alO01E
EED0F5QH071`L010@400H61P04I6AP1=CDd0Kfm_04];B`15ADD0Bd];03@d=00k>c/0?Cdm04A4A018
B4P0FEUI0492@P0Y:BT0@D5105ADE00j>SX0ADE505=CD`1HF5P0BDU904i>CP1<C4`0AdM705IFEP1;
Bd/0EUIF04i>CP1GEeL0B4Q806ATI01GEeL0FUYJ07AdM01cLg<0QhN708n?S`1WIfL0HV9R07IfMP1^
KVh0FEUI05=CD`13@d<0EEEE04I6AP1`L700E5AD05iNGP23Ph<0SHf=06=SH`1jNWX0PX:208B4Q01R
HV80H61P069RHP16ATH0Bd];04M7A`1BDU80?3`l05UIF@13@d<0DE5A03Hf=P0o?cl0@D5106MWI`1R
HV80G5aL059BDP1HF5P0@d=305aLG019BDT0Fe]K05iNGP17AdL0IFEU04=3@`2GUiL0Ph>304I6AP1?
Cdl0E5AD03@d=01TI6@0@d=30P1CDe<0=@1>CTh0<S8b0492@P1@D500:b/[05IFEP1@D500F5QH02HV
9P0l?3`0@d=304M7A`18B4P0De=C05aLG00k>c/0FEUI0410@017AdL0@T9204a<C017AdL09BDU06IV
IP1OGel0>SXj06e]K@0g=cL0;2`/02d];@16ATH0<S8b04Y:BP0h>3P0@d=305EEE@1dM7@0@D5105=C
D`1MGEd0:RXZ04E5A@1<C4`0>CTi05EEE@1>CTh0Bd];055AD@1NGUh0@d=305IFEP0n?Sh0CDe=0080
ATI60400EUIF05eMG@1nOWh0JFUY04E5A@1TI6@0CTi>07QhN01CDe<0Ng]k05=CD`1DE5@0GUiN05EE
E@1ADE40MGEe04Q8B01CDe<0@D5106][J`1SHf<0J6QX04a<C01WIfL0De=C07UiN@1bLW80=cLg05]K
F`0k>c/0?Shn07EeM@1:BTX0LG5a03Xj>P1cLg<0=CDe051@D01XJ6P0GemO06e]K@1:BTX0RXZ:06YZ
JP1;Bd/0BDU903De=@1KFe/0G5aL04=3@`0X:2P0Fe]K03@d=01UIFD0DE5A04U9B@1WIfL0DU9B04e=
C@1/K6`0DU9B05YJFP1_Kfl0S8b<4Oooool000oooooo01@0LG5a06m_K`2c/k<0F5QH04];B`1HF5P0
R8R80<71`@19BDT0?Shn06i^KP1HF5P0MGEe06ATI00U9BD0MGEe07alO01ADE40Ng]k04E5A@80B4Q8
0?l0BDU903`l?029RHT06QXJ03Ti>@1lO7`0IVIV034a<@16ATH0BDU903Ti>@1LG5`0IVIV03dm?@1O
Gel07alO034a<@19BDT0Fe]K03`l?016ATH0CTi>03<c<`1OGel0BDU902TY:@0m?Cd0=CDe02l_;`15
ADD0HF5Q01lO7`0c<c<0<S8b03Xj>P1gMgL0EUIF01XJ6P14A4@0BDU905eMG@2d];@0;Rh^01lO7`0P
8200=CDe04Q8B02?Shl0NGUi00d=3@0_;bl0De=C051@D028R8P0H61P01XJ6P0Z:RX0?clo06a/K010
@400DE5A01/K6`0f=SH0CDe=051@D00N7Qh0DU9B03De=@0Z:RX0CDe=03hn?P0Z:RX0Fe]K02PX:00f
=SH0AdM706ATI00J6QX08R8R03<c<`1NGUh0RHV90492@P0T92@09bLW03dm?@11@D40EUIF08j>SP0_
;bl0@41003lo?`1@D500CTi>06e]K@0f=SH05ADE05=CD`1:BTX0Bd];07EeM@0X:2P0<C4a03/k>`1_
Kfl0ATI604i>CP1cLg<0;bl_05mOG`1RHV80820P04Q8B01XJ6P0@41006UYJ@1nOWh0@41003Ti>@0l
?3`0Cdm?06][J`1oOgl0:BTY01XJ6P1?Cdl0MWIf08:2PP1QHF407alO04];B`1?Cdl0FEUI05iNGP2J
VYX0De=C02DU9@1:BTX0OWin03`l?01QHF40=3@d02XZ:P0b<S80HF5Q08^;R`0m?Cd0DE5A02l_;`0i
>CT0Bd];03Xj>P0l?3`0Bd];01lO7`0k>c/0Ng]k02d];@0b<S80B4Q804e=C@1bLW80Y:BT03lo?`0P
8200?clo06QXJ01oOgl0EEEE01DE5@0l?3`0CTi>04a<C02NWYh0Q8B401TI6@1?Cdl0BDU905iNGP2C
Ti<0<C4a02DU9@1iNGT0L71`03dm?@1>CTh0>c/k05=CD`1TI6@09RHV07AdM00b<S80:b/[05IFEP1/
K6`0@T9204U9B@0R8R80De=C07YjNP1cLg<0E5AD07AdM00O7al0GemO08J6QP0X:2P0>CTi034a<@0g
=cL0QXJ608B4Q00d=3@0;Bd]04];B`1XJ6P0Rh^;0451@@0K6a/0=cLg04m?C`1dM7@0K6a/0:6QX@0o
?cl0A4A405YJFP29RHT0H61P07]kN`14A4@07alO030`<02<S8`0PH6109bLW00h>3P0C4a<07inOP2B
TY80BDU907UiN@2NWYh0?Shn04I6AP1^KVh0C4a<04M7A`1VIVH0@41003De=@1GEeL0EUIF04E5A@1H
F5P000X08B4Q03De=@17AdL0U9BD05EEE@0g=cL0F5QH01dM7@0n?Sh0[Jf]0P0j>SX00`11@D7ooooo
ooooo`0Jooooo`39055AD@1PH600Cdm?03Lg=`1KFe/0QXJ606][J`1ADE40M7Ad07MgM`1PH600>SXj
05eMG@2:RXX0TI6A06YZJP2MWId0Jf][059BDP2IVIT0DU9B05=CD`1ADE40De=C05QHF011@D40Ng]k
04Q8B01fMWH0?Cdm05EEE@1SHf<0@41007YjNP2BTY80Ph>309>CT`23Ph<0SHf=07YjNP1GEeL0B4Q8
07QhN01ZJVX0DE5A04E5A@1WIfL0?clo05EEE@1BDU80<30`04];B`1RHV80=3@d06][J`1<C4`0EUIF
079bLP1@D500Jf][05EEE@1VIVH0AdM705]KF`0k>c/0>3Ph0492@P1ADE40Fe]K07]kN`10@400ATI6
04e=C@1eMGD0>c/k04E5A@1/K6`0=3@d05IFEP0_;bl0:BTY06ATI00g=cL0:b/[0410@00Z:RX0;2`/
038b<P0m?Cd0>c/k04i>CP0g=cL05ADE03De=@1JFUX0;bl_03hn?P0[:b/0Fe]K04U9B@1@D500?clo
04M7A`1CDe<0@T9204M7A`18B4P0Cdm?05YJFP1HF5P0B4Q805MGE`1YJFT0NGUi09BDU01mOGd0JVYZ
07MgM`1^KVh0RHV905]KF`1@D500B4Q8051@D01?Cdl0Jf][04Y:BP1TI6@0Jf][07moO`21PH40U9BD
08f=S@2LW9`0CTi>04U9B@1^KVh0FEUI06][J`0f=SH0@41002/[:`1XJ6P0CDe=06QXJ010@400?Shn
034a<@0i>CT0CDe=06ATI01JFUX0FEUI05eMG@1iNGT0Bd];04Q8B01SHf<0@T9205=CD`0T92@0HF5Q
07AdM01NGUh0?Shn04i>CP0Y:BT0Ng]k02TY:@1OGel0?clo04U9B@0a<C40>3Ph04E5A@0W9bL0>CTi
04Y:BP1?Cdl0;bl_0492@P0g=cL0=3@d059BDP25QHD0S8b<03/k>`16ATH0;bl_03Hf=P12@T80Ng]k
05mOG`0Y:BT0Fe]K05UIF@0Z:RX0E5AD02XZ:P1KFe/092@T0080<30`04l0EEEE02XZ:P0];Bd0>SXj
05=CD`0f=SH0C4a<04Y:BP0k>c/0GEeM065QH@12@T80Bd];0451@@12@T80@D510492@P0b<S80@410
028R8P0l?3`0?Cdm02l_;`15ADD0=3@d06i^KP1>CTh0?Cdm05iNGP0o?cl0HV9R04A4A01SHf<0CTi>
04a<C01dM7@0Hf=S05=CD`1hN7P0@T9205MGE`0/;2`0OWin04A4A01:BTX0@T9205ADE00a<C40JVYZ
05UIF@0g=cL0KFe]03Xj>P1<C4`0BDU904];B`1eMGD0D51@0:VYZ@1YJFT0EEEE09JFUP1WIfL0KFe]
03hn?P1>CTh0BDU905=CD`1ADE40?Shn04m?C`15ADD0H61P030`<01;Bd/0>CTi05EEE@1YJFT0K6a/
0080JVYZ00H0LW9b08R8R01ZJVX0Fe]K05MGE`2IVITAooooo`003oooool0?020P800C4a<05iNGP2O
Wil0K6a/03lo?`17AdL0P82008V9R@1>CTh0F5QH02PX:01VIVH0NGUi03Lg=`1@D500=CDe02l_;`1b
LW80YjNW038b<P0m?Cd0ADE503<c<`27QhL0GUiN02@T9012@T80>3Ph06IVIP2XZ:P0EEEE01TI6@0_
;bl0BTY:06IVIP2j^[X0@T9201/K6`1HF5P0De=C03/k>`23Ph<0IfMW01<C4`1ADE40Jf][03Xj>P1e
MGD092@T02PX:00j>SX0LW9b04i>CP16ATH061PH02HV9P19BDT0MGEe02XZ:P80BDU905T09RHV05QH
F01WIfL0=SHf05UIF@0o?cl05aLG051@D02JVYX0>CTi03Xj>P0M7Ad08b<S065QH@26QXH07AdM01XJ
6P14A4@0B4Q8069RHP1bLW804a<C01`L7016ATH0J6QX05EEE@2<S8`0HV9R01DE5@14A4@0De=C0492
@P1_Kfl09RHV02<S8`0m?Cd0De=C04];B`1bLW80?Cdm03Ph>00W9bL0FUYJ03hn?P1CDe<0=CDe01/K
6`19BDT0JFUY05UIF@14A4@0ADE501XJ6P1LG5`0LG5a08:2PP0^;Rh0=cLg03hn?P17AdL0Ti>C02HV
9P0O7al0:b/[04M7A`0e=CD0MgMg08R8R00U9BD0A4A405ADE01NGUh0Lg=c0:BTY00N7Qh0=cLg06EU
I@1fMWH0Ng]k04e=C@0R8R80CDe=079bLP1VIVH0=SHf06YZJP19BDT0ADE50::RXP020492@P1H06AT
I00X:2P0=3@d07QhN023Ph<0>CTi04e=C@19BDT0FEUI07MgM`1SHf<08b<S03/k>`0^;Rh0FUYJ055A
D@2:RXX09RHV05ADE01:BTX0;2`/06i^KP1jNWX09bLW03Hf=P1:BTX0>CTi06][J`1MGEd0<S8b03dm
?@1:BTX0Vi^K05eMG@2?Shl0<C4a055AD@1dM7@0:2PX04E5A@0k>c/05aLG051@D029RHT0EUIF04m?
C`0N7Qh0?3`l09FEU@1]KFd08R8R04m?C`0j>SX0<c<c06][J`0_;bl0E5AD02l_;`1KFe/0[:b/06YZ
JP0K6a/0?clo061PH01gMgL0OWin02<S8`0b<S80CTi>05MGE`1XJ6P0O7al02l_;`0R8R80IfMW05=C
D`1kNg/09RHV03lo?`1@D500Ph>306ATI01bLW80>CTi05YJFP1HF5P0Hf=S030`<080EUIF01806QXJ
05EEE@1bLW80Fe]K0861P@1cLg<08b<S05ADE02:RXX0MWIf02`/;013@d<0C4a<0410@02ATI40V9RH
03Hf=P14A4@202l_;`0K04];B`28R8P0AdM70451@@0j>SX0@41005iNGP2>SXh0=CDe02HV9P0c<c<0
EUIF04i>CP2QXJ40=3@d01<C4`0g=cL0GUiN04E5A@27QhL0S8b<03@d=012@T80KVi^04I6AP1LG5`0
Lg=c01cooooo01P0DU9B08^;R`1SHf<0@41005UIF@1YJFT0C4a<03De=@25QHD0WinO06EUI@10@400
Cdm?06EUI@21PH40JFUY08>3P`1HF5P0AdM705iNGP1MGEd0CDe=0492@P1>CTh2055AD@3305EEE@1=
CDd0ADE505QHF01]KFd0EEEE051@D01/K6`0FUYJ04e=C@1MGEd0LG5a07]kN`1DE5@0ADE504Y:BP1?
Cdl0CDe=055AD@1LG5`0HF5Q04E5A@1LG5`0F5QH030`<012@T80LG5a051@D01cLg<0<S8b04A4A01B
DU80CDe=07MgM`1mOGd0KFe]059BDP1mOGd0EEEE04m?C`1;Bd/0QhN709>CT`2KVi/0EeMG04Y:BP1K
Fe/0UIFE04U9B@1BDU80Ph>305ADE01@D500=cLg04Q8B01WIfL0?3`l03De=@16ATH0=SHf03Lg=`0d
=3@0DU9B04a<C01WIfL0=SHf01TI6@0o?cl0GUiN03<c<`15ADD0@d=305QHF01;Bd/0Cdm?0451@@15
ADD0D51@055AD@1PH600I6AT06=SH`14A4@0IfMW04];B`1>CTh0EeMG065QH@2;Rh/0MWIf06=SH`26
QXH0Fe]K069RHP1>CTh0C4a<04E5A@1BDU80AdM706ATI01KFe/0HV9R07UiN@2VYZH0FEUI06][J`1`
L700UIFE069RHP1dM7@0NWYj03lo?`1FEUH0=SHf05ADE00[:b/0GUiN04e=C@1;Bd/0?3`l04A4A00_
;bl0Bd];05mOG`1QHF40?Shn04e=C@0[:b/0EUIF06e]K@1NGUh0Hf=S0451@@1:BTX0=CDe07UiN@1l
O7`0EUIF061PH01hN7P0@D5107moO`12@T80De=C03Ph>01?Cdl03`l?03lo?`1GEeL04A4A0410@01D
E5@0FEUI01DE5@0`<300?clo038b<P1DE5@0BDU904e=C@0j>SX0Bd];04Q8B01dM7@0Bd];055AD@1B
DU80=cLg0820P01dM7@0=cLg059BDP0Y:BT0820P024Q8@0m?Cd0>3Ph05MGE`1FEUH0>CTi04Y:BP2T
Y:@0A4A404m?C`1=CDd0:BTY02l_;`0[:b/0<30`05IFEP12@T80DE5A05=CD`1BDU80?3`l0080A4A4
0100EEEE03Ti>@0l?3`0JFUY055AD@1aLG40Cdm?038b<P1YJFT0>3Ph079bLP10@400Z:RX05]KF`19
BDT0JVYZ0P1:BTX0<@1JFUX0?clo04a<C00k>c/0OWin04a<C01ZJVX0Kfm_08F5Q@1<C4`0HF5Q04];
B`0E5AD0DU9B03De=@0m?Cd0PX:205=CD`1lO7`0Cdm?0861P@1GEeL0BDU906MWI`2:RXX0Zj^[05eM
G@1]KFd0F5QH06=SH`1RHV80=CDe04Y:BP0m?Cd0@D5103De=@1<C4`0;2`/06MWI`1HF5P0FEUI07Ui
N@19BDT0Fe]K07YjNP1DE5@0DU9B07inOP1]KFd04Oooool000oooooo04@0T92@055AD@1>CTh0FUYJ
08J6QP15ADD0=cLg07alO01eMGD0RHV908F5Q@0a<C40@41007MgM`1OGel0OWin02/[:`0e=CD0E5AD
09^KV`1GEeL0Lg=c04=3@`0I6AT0BTY:07inOP1IFET0JVYZ02DU9@0P8200DU9B09NGU`1ADE40G5aL
01PH600_;bl0IfMW071`L00S8b<0IfMW02XZ:P0G5aL0>CTi06a/K00n?Sh0GUiN02XZ:P0j>SX0GemO
06MWI`0b<S80EeMG04=3@`1GEeL0FUYJ028R8P0G5aL0<c<c04=3@`0e=CD0PX:206YZJP0K6a/0;bl_
069RHP19BDT0LW9b04e=C@80820P0=`09bLW04M7A`1bLW808b<S01PH6011@D40I6AT04E5A@0m?Cd0
Kfm_02/[:`0K6a/0DE5A03Hf=P1CDe<0OGem01LG5`0^;Rh0B4Q805ADE00F5QH0@41002<S8`0i>CT0
D51@04A4A00G5aL0?3`l02l_;`0f=SH0GemO05EEE@0/;2`0E5AD03<c<`16ATH0NWYj055AD@0@4100
7AdM03hn?P1JFUX0P82007UiN@0I6AT06a/K04A4A02HV9P0DU9B0:^[Z`0m?Cd092@T06][J`1KFe/0
?3`l06IVIP0b<S8051@D03Lg=`2GUiL0C4a<05iNGP0h>3P061PH051@D01[Jf/0@d=303lo?`1GEeL0
9BDU04m?C`1OGel092@T04Q8B019BDT0?Shn04a<C01TI6@0?3`l03De=@1CDe<0ADE509^KV`2PX:00
:2PX03@d=010@400PH6105mOG`2/[:`0>CTi03lo?`1NGUh0NWYj06ATI01oOgl0QHF5038b<P0];Bd0
Shn?05UIF@1]KFd0>SXj02DU9@19BDT0U9BD06UYJ@1:BTX0Hf=S02h^;P20P800O7al03De=@0k>c/0
?3`l02d];@12@T80NGUi03/k>`0n?Sh0C4a<04M7A`1RHV80PH6102HV9P0f=SH0BTY:05QHF02:RXX0
ADE502PX:01TI6@0QXJ60451@@28R8P0<c<c03dm?@1DE5@0=3@d08:2PP0W9bL09BDU09ZJVP2][Jd0
<c<c05MGE`0i>CT0>c/k06QXJ00[:b/0DU9B03Hf=P0j>SX0G5aL06][J`1>CTh0DU9B04I6AP19BDT0
FUYJ04i>CP0b<S80G5aL02/[:`11@D40JFUY06=SH`11@D40EUIF04=3@`1JFUX0MWIf0:NWY`1CDe<0
=3@d051@D00d=3@0Vi^K0<71`@1NGUh0:BTY061PH028R8P0HF5Q07UiN@2IVIT0>CTi06i^KP21PH40
MgMg08f=S@0^;Rh09RHV05iNGP1`L700GemO05EEE@18B4P061PH04I6AP1dM7@0D51@0451@@0h>3P0
ADE503Hf=P1VIVH0S8b<034a<@1ADE40<30`02<S8`16ATH0ZZZZ08:2PP0m?Cd0EUIF02PX:01WIfL0
VIVI7?ooool206e]K@1005QHF013@d<0JVYZ075aL@1BDU80ATI605UIF@1KFe/0OGem05iNGP1bLW80
PX:208B4Q027QhL0RHV9069RHP1;Bd/0Q8B405IFEP1TI6@0CTi>05UIF@1HF5P0@410079bLP14A4@0
J6QX03lo?`1@D500Hf=S03Hf=P1[Jf/0QHF505EEE@2BTY80S8b<09ZJVP1jNWX0GUiN03hn?P1KFe/0
DU9B03`l?00c<c<0DU9B0410@01;Bd/0ADE5024Q8@0o?cl0GUiN03/k>`1EEED0<c<c03Xj>P1]KFd0
IVIV05EEE@11@D40Cdm?061PH01;Bd/0>3Ph05EEE@<0BTY:0<T0Jf][06m_K`1?Cdl0KFe]07YjNP1m
OGd0MgMg05QHF00`<300E5AD04e=C@1DE5@0Hf=S03/k>`1EEED0ADE503Ph>01:BTX0=3@d03/k>`0m
?Cd0F5QH03De=@0R8R80?Cdm03/k>`0S8b<0;bl_04M7A`11@D40<30`03hn?P0k>c/0ATI605ADE01B
DU80FEUI03De=@1LG5`0K6a/06ATI01OGel0FUYJ071`L02IVIT0[:b/09jNWP1FEUH0J6QX07=cL`1T
I6@0H61P05IFEP0m?Cd0G5aL0492@P1bLW80DU9B06][J`1RHV80LG5a05IFEP2:RXX0V9RH0:RXZ01Y
JFT0EEEE061PH01CDe<0H61P03<c<`0b<S80;Bd]05IFEP19BDT0J6QX03Xj>P16ATH0@410055AD@1S
Hf<0IFEU04E5A@1IFET0>CTi06QXJ010@400CDe=06a/K00h>3P0EeMG01HF5P2HV9P0YZJV0410@00o
?cl0DE5A04=3@`25QHD0?clo061PH01<C4`0D51@02PX:011@D40C4a<02DU9@1?Cdl0H61P04I6AP0L
71`0>3Ph03lo?`14A4@0EeMG05QHF01VIVH0;Rh^04m?C`0n?Sh0<c<c04Y:BP1ADE40EUIF03<c<`1=
CDd0BTY:02XZ:P1OGel0?clo03`l?00T92@0>3Ph02h^;P19BDT0A4A404];B`10@400GEeM0492@P1H
F5P0De=C01PH600f=SH0ADE504=3@`1GEeL0F5QH05UIF@1;Bd/0JFUY03Ph>00g=cL0<C4a04i>CP0f
=SH0>SXj05=CD`0n?Sh0E5AD03`l?01@D500GUiN03Ph>01]KFd08B4Q06ATI013@d<0CDe=08>3P`1?
Cdl0?Cdm06MWI`0[:b/0DE5A034a<@1YJFT0=CDe03/k>`0c<c<0DE5A034a<@2DU9@0Lg=c01PH601P
H600=3@d0451@@1JFUX0ADE5061PH01nOWh0XZ:R06e]K@1eMGD0RXZ:05mOG`1JFUX0De=C08F5Q@0c
<c<00P1:BTX02`0b<S80EEEE03hn?P16ATH05QHF03@d=00M7Ad0MWIf04Q8B017AdL0F5QH0080BDU9
00D0GEeM04U9B@1HF5P0Jf][08:2PP0Aooooo`003oooool208J6QP190:j^[P0m?Cd0EUIF06e]K@1h
N7P0Shn?04M7A`1JFUX0MWIf055AD@1JFUX0JVYZ03dm?@1LG5`0A4A402LW9`1YJFT0ATI604e=C@1M
GEd0DU9B02HV9P0j>SX0@D510492@P1_Kfl08R8R01dM7@0n?Sh0CTi>05EEE@1iNGT071`L02<S8`1:
BTX0ATI604a<C02[Zj/0>3Ph01DE5@0O7al0FUYJ05eMG@2UYJD0=3@d03`l?01;Bd/0JVYZ03dm?@2@
T900De=C02/[:`1EEED0@D5104M7A`1ZJVX0820P02TY:@0e=CD0L71`0451@@1GEeL0:2PX02h^;P1H
F5P0JFUY02LW9`1EEED0AdM702PX:01BDU80K6a/02PX:00203Xj>P1K03dm?@16ATH0WIfM05EEE@0I
6AT0@41004I6AP1ADE40VIVI03<c<`0L71`0Bd];04Q8B00b<S80J6QX01dM7@0U9BD0@T9205YJFP0l
?3`0MWIf03De=@0G5aL0?3`l03Ti>@16ATH0IVIV01hN7P0[:b/0GEeM08>3P`1@D500>c/k065QH@0d
=3@0LG5a08n?S`1[Jf/0@41004a<C00[:b/0?3`l06ATI012@T808B4Q0492@P19BDT0ATI608:2PP1<
C4`04a<C01PH601BDU80CDe=0::RXP11@D403Ph>02`/;01RHV80D51@06YZJP2:RXX06a/K03Lg=`1P
H600=CDe06][J`1YJFT0:BTY038b<P1`L700[Zj^06i^KP1cLg<09RHV03De=@2;Rh/0De=C03Ti>@1O
Gel0>CTi01lO7`1GEeL0GemO038b<P1MGEd0<S8b034a<@1nOWh0Ng]k03`l?00203lo?`1h04A4A02O
Wil0LG5a02XZ:P13@d<0AdM706=SH`1lO7`0KFe]02l_;`1FEUH0Cdm?05YJFP27QhL0V9RH01`L700`
<300Jf][05eMG@26QXH0@d=301dM7@1LG5`0P82004m?C`1ADE40EEEE01dM7@1SHf<0Ng]k05iNGP1X
J6P0=3@d02d];@1YJFT0Kfm_03@d=01>CTh0Bd];07UiN@19BDT09bLW06=SH`1OGel0De=C08R8R01b
LW80=CDe04I6AP0l?3`0LW9b05eMG@0H61P0AdM705EEE@14A4@0LW9b069RHP0n?Sh0Ng]k06QXJ01D
E5@0W9bL03lo?`0Y:BT0Bd];06IVIP1ZJVX0L71`02LW9`0_;bl0D51@07EeM@1KFe/0CDe=05=CD`0_
;bl0A4A4075aL@1cLg<0ATI6065QH@10@400=3@d04A4A01VIVH0K6a/09:BTP0h>3P0>CTi06YZJP2>
SXh0<30`03@d=01^KVh0CTi>09ZJVP23Ph<0>3Ph024Q8@13@d<0<30`05]KF`1PH600J6QX02`/;013
@d<0Kfm_05=CD`2SXj<0H61P01XJ6P0a<C40DU9B04U9B@1CDe<0BDU903Hf=P10@400CDe=7?ooool0
:P1>CTh0EeMG04E5A@12@T80D51@096AT@1fMWH0BDU907MgM`1bLW80Lg=c04U9B@1/K6`0Rh^;09^K
V`1/K6`0W9bL079bLP1<C4`0YJFU06ATI01VIVH0BTY:07=cL`1NGUh0DE5A06YZJP13@d<0DU9B04Y:
BP1HF5P0K6a/04U9B@1dM7@0O7al07emO@2QXJ40PX:20:b/[022PX80FEUI03/k>`80HF5Q0=D0A4A4
0410@01[Jf/0@D51059BDP16ATH08R8R04a<C01_Kfl0AdM70861P@0f=SH0A4A407MgM`1<C4`0J6QX
059BDP1LG5`0A4A405IFEP0f=SH0ADE50451@@1>CTh0GemO09>CT`17AdL0C4a<051@D01/K6`0<c<c
0492@P1QHF40>CTi05IFEP0k>c/0=cLg06m_K`13@d<0?3`l04I6AP0e=CD0:BTY0410@00j>SX0?Shn
055AD@12@T807AdM03/k>`1MGEd0;2`/04E5A@0`<300G5aL03Ph>016ATH0=3@d04I6AP1HF5P0;2`/
059BDP14A4@0Cdm?0410@01BDU80>SXj05EEE@1OGel0Hf=S08:2PP1bLW80OGem08b<S01[Jf/0Ph>3
06QXJ01UIFD0CDe=06EUI@1NGUh0H61P07MgM`1QHF40SHf=09jNWP1`L700NWYj079bLP25QHD0@410
04];B`19BDT0;Bd]0492@P0a<C40C4a<04=3@`1QHF40De=C07IfMP0j>SX0@D5105UIF@1aLG40GemO
05=CD`12@T80DU9B061PH01RHV80BDU904Y:BP1FEUH0D51@07inOP0@4100HV9R07inOP0n?Sh0J6QX
06i^KP0e=CD0Jf][02XZ:P1SHf<0DE5A069RHP0d=3@0E5AD05]KF`0f=SH0DE5A05YJFP15ADD0:BTY
0492@P0_;bl0<S8b05IFEP1MGEd0G5aL04U9B@1SHf<0;bl_03@d=016ATH0LG5a065QH@0`<300Ogmo
07=cL`0W9bL0F5QH03Hf=P13@d<0=3@d03hn?P16ATH0PX:205]KF`0m?Cd0?clo06IVIP0h>3P0LG5a
06][J`0i>CT0Hf=S06MWI`0Z:RX0B4Q803De=@1<C4`0Bd];04a<C011@D40=CDe04I6AP1KFe/0>CTi
04];B`1KFe/0A4A406ATI00_;bl0AdM707EeM@14A4@0NGUi04Q8B02`/;00I6AT030`<01dM7@0DU9B
05EEE@1`L700@41007YjNP0[:b/0IfMW03Ph>01CDe<0I6AT079bLP0g=cL0FUYJ059BDP0S8b<0GemO
03dm?@1MGEd00`1YJFT07P1PH600Ph>306EUI@1<C4`0MgMg06ATI01UIFD0?Cdm06EUI@0_;bl0IVIV
05EEE@0P8200>c/k03Hf=P1UIFD0820P02l_;`0c<c<0MWIf05eMG@1jNWX0J6QX05EEE@1RHV80HF5Q
05=CD`1;Bd/0J6QX08F5QA7ooooo000?ooooo`0807moO`1OGel0WYjN05iNGP1BDU80?3`l06][J`2d
];@205ADE01^06MWI`0o?cl0IVIV09:BTP0f=SH0GEeM05YJFP17AdL0Zj^[09:BTP0P8200AdM706=S
H`1;Bd/0Y:BT020P800m?Cd0MWIf08B4Q01QHF40Ti>C04I6AP0^;Rh0GemO03dm?@1_Kfl0Ng]k024Q
8@0V9RH0Fe]K07inOP0Q8B40?clo03De=@0];Bd0GUiN069RHP0j>SX0ATI601XJ6P0_;bl0E5AD07in
OP11@D40DU9B03<c<`0g=cL0Q8B404i>CP0R8R80=3@d03/k>`1XJ6P0Ph>301/K6`0I6AT0?clo0410
@011@D40Kfm_09:BTP0H61P0=CDe07=cL`1EEED0OWin08F5Q@0D51@08B4Q051@D02FUYH0B4Q807mo
O`0H61P0C4a<04i>CP1^KVh0;2`/09^KV`0];Bd05QHF069RHP1:BTX0:BTY05=CD`0U9BD0?Cdm06e]
K@1QHF40<30`03De=@0j>SX0GEeM06e]K@0c<c<07AdM03De=@0n?Sh0<C4a08^;R`2_[jl09bLW03Ti
>@1KFe/0?clo06UYJ@2KVi/08b<S01hN7P0m?Cd205iNGP2E09FEU@0S8b<0:b/[04i>CP1UIFD0BDU9
05EEE@1IFET0;bl_07IfMP22PX80<C4a05QHF01WIfL09RHV04Y:BP1gMgL0ATI603lo?`0T92@0=cLg
05IFEP1cLg<0;Bd]020P801HF5P0DU9B061PH02:RXX09bLW02/[:`1XJ6P0I6AT06EUI@2YZJT0EUIF
02DU9@1>CTh0K6a/075aL@20P800?Shn01lO7`0^;Rh0IFEU04a<C01ADE40C4a<01`L7015ADD0Y:BT
0410@01EEED0F5QH01lO7`0i>CT0Fe]K02l_;`1MGEd0@d=3034a<@11@D40O7al04e=C@0h>3P0JFUY
02d];@1iNGT0Vi^K02TY:@0f=SH0ADE505QHF01dM7@0VIVI03lo?`0j>SX0@D5107UiN@3;bl/0AdM7
02TY:@1<C4`0B4Q805MGE`1[Jf/0<C4a059BDP1XJ6P0CDe=0:JVYP1NGUh0;Rh^069RHP1/K6`0Lg=c
04=3@`0b<S80Jf][05QHF00o?cl0H61P05eMG@0^;Rh0EUIF07QhN00m?Cd0De=C028R8P11@D40I6AT
07AdM00a<C40E5AD03/k>`1LG5`0JVYZ04M7A`0Y:BT0AdM70410@00Z:RX0GemO08b<S00h>3P0;2`/
04=3@`1FEUH0EeMG0820P01FEUH08R8R02h^;P0b<S80G5aL0<c<c015ADD0=3@d04A4A01hN7P0Hf=S
07QhN02JVYX0@T9206ATI025QHD0DU9B07QhN01fMWH00P0Y:BT04@1XJ6P0OGem04A4A01DE5@07AdM
034a<@1EEED0W9bL05ADE00h>3P0<30`02PX:012@T80Lg=c02<S8`0i>CT0=cLg01cooooo0140EeMG
07moO`1KFe/0>CTi05=CD`1UIFD0GEeM055AD@26QXH0SHf=0;Fe]@1GEeL0MWIf09:BTP2JVYX0M7Ad
08n?S`0207alO00306i^KP1CDe<0GemO0080EUIF05P0Cdm?05]KF`1MGEd0ADE504Q8B01XJ6P0Lg=c
05IFEP13@d<0IVIV069RHP1_Kfl0K6a/07emO@27QhL0J6QX04U9B@18B4P0EEEE05QHF01?Cdl0GUiN
05]KF`10@400Bd];04I6AP0K6a/0>c/k05MGE`1:BTX0JVYZ04I6AP1CDe<0LW9b059BDP1eMGD0JVYZ
07=cL`1OGel0LW9b055AD@1=CDd0ATI6061PH01XJ6P0YjNW05=CD`0c<c<0GEeM08B4Q017AdL0EUIF
07=cL`1HF5P0EeMG03dm?@0l?3`0IVIV03`l?00g=cL0BDU903dm?@0d=3@0=CDe04I6AP12@T80EUIF
03/k>`0/;2`0@410069RHP0i>CT0C4a<0410@01PH600?clo04a<C01?Cdl0A4A406UYJ@15ADD0H61P
04U9B@1[Jf/0C4a<079bLP15ADD0DU9B0P1=CDd0E@1JFUX0LG5a04E5A@1OGel0JFUY071`L01LG5`0
FEUI0451@@1CDe<0?Shn05EEE@16ATH0C4a<07IfMP1iNGT0EEEE07UiN@2UYJD0[:b/03Ti>@1KFe/0
DE5A030`<01JFUX0;Rh^04e=C@16ATH0EUIF04I6AP1OGel0A4A404M7A`0o?cl0ADE505]KF`1QHF40
GUiN05EEE@0[:b/0H61P04m?C`1CDe<0FEUI03Lg=`11@D408B4Q071`L023Ph<0CTi>03<c<`1<C4`0
9bLW07IfMP0X:2P0AdM703Lg=`1@D500820P03De=@13@d<051@D03Xj>P1DE5@0CTi>02@T900a<C40
AdM704Y:BP1BDU80HV9R06MWI`0o?cl0DU9B04A4A01?Cdl0Bd];04Q8B01FEUH0<C4a07AdM01NGUh0
;Bd]075aL@0o?cl00P0n?Sh0C`1>CTh09RHV05IFEP0i>CT0=3@d03Ph>02PX:00>c/k05MGE`1?Cdl0
7QhN03dm?@16ATH0@d=306ATI01NGUh0CDe=05MGE`1<C4`0ATI605EEE@17AdL0EUIF04=3@`1KFe/0
HF5Q04A4A01oOgl0DU9B03Ti>@1KFe/0;Rh^05MGE`0W9bL0JVYZ05IFEP0e=CD0HV9R04Q8B01RHV80
FEUI03De=@1:BTX0>3Ph06][J`0k>c/0?3`l03/k>`1FEUH0C4a<06MWI`1TI6@08B4Q05MGE`0k>c/0
DU9B05mOG`1GEeL0NGUi06IVIP2>SXh0LW9b05QHF01hN7P0TY:B07inOP11@D40F5QH03De=@1OGel0
FUYJ03dm?@17AdL0C4a<04M7A`1=CDd0EUIF0451@@1`L7000P1CDe<0201BDU80D51@061PH00o?cl0
EeMG05ADE01bLW80O7al4Oooool000oooooo0;80Z:RX04m?C`1OGel0Lg=c08j>SP1;Bd/0CDe=08N7
Q`2JVYX0RHV9069RHP0b<S80?Shn075aL@1JFUX0Jf][02PX:00`<300CTi>08>3P`18B4P0EeMG03lo
?`0[:b/0Bd];0820P015ADD0Jf][02DU9@0i>CT0ATI605=CD`0R8R80Hf=S03Ti>@1WIfL0K6a/03De
=@0^;Rh0IFEU03@d=01>CTh0WinO05MGE`10@400F5QH03`l?01OGel0Xj>S034a<@0X:2P0Bd];05YJ
FP1VIVH0QhN701PH6012@T80B4Q8055AD@1DE5@0VYZJ04E5A@0_;bl0CTi>030`<00m?Cd0JVYZ02XZ
:P0S8b<0?Cdm05ADE01ADE40DU9B01lO7`0];Bd0De=C06QXJ00P8200;Bd]04U9B@0T92@0=cLg061P
H00F5QH09BDU04=3@`0g=cL0A4A40820P02=SHd03Ph>03`l?01MGEd0AdM706YZJP0[:b/06a/K059B
DP26QXH0DU9B06EUI@12@T809BDU05EEE@1KFe/0;Bd]065QH@0];Bd09BDU034a<@1ZJVX0FUYJ05eM
G@0`<3007alO02/[:`1KFe/0MGEe034a<@1BDU809bLW028R8P1VIVH0CTi>028R8P0o?cl0>CTi01LG
5`1QHF40SXj>02`/;01EEED0Cdm?069RHP1iNGT0SXj>02<S8`0a<C40RHV905ADE028R8P0I6AT00d=
3@1NGUh0Lg=c06a/K01CDe<0YjNW02/[:`1CDe<0QXJ606EUI@1WIfL0LG5a01TI6@11@D40J6QX0:b/
[014A4@0F5QH01PH601>CTh0Fe]K06QXJ00_;bl0>CTi02h^;P0e=CD0MGEe05mOG`0I6AT0;Bd]04Q8
B01=CDd0F5QH06IVIP0M7Ad0=cLg0P1<C4`0:02GUiL0GEeM02<S8`19BDT0E5AD0492@P1]KFd0Xj>S
02HV9P1KFe/0Rh^;059BDP1EEED0B4Q801hN7P11@D40MWIf051@D01JFUX092@T02XZ:P1kNg/0SXj>
03`l?01kNg/0>3Ph01lO7`1UIFD0<30`065QH@0G5aL0@41005MGE`1OGel0;2`/05YJFP0e=CD0Jf][
08>3P`10@40205]KF`1403Lg=`2GUiL0VYZJ034a<@14A4@0DE5A05MGE`2HV9P0F5QH02/[:`1ADE40
De=C05]KF`2CTi<0B4Q806a/K029RHT0QXJ605YJFP2>SXh0UiNG01lO7`0l?3`0GemO06i^KP22PX80
SXj>028R8P0b<S80CTi>06QXJ018B4P0FUYJ05MGE`0l?3`0K6a/09RHV01<C4`0LG5a02h^;P0b<S80
>3Ph06a/K01ZJVX0A4A405UIF@0X:2P0>3Ph07MgM`1jNWX0?Shn03De=@0o?cl0@d=3092@T00k>c/0
:2PX03dm?@1HF5P0LG5a08V9R@1dM7@071`L05eMG@1[Jf/0BTY:07IfMP23Ph<Looooo`0d05QHF01K
Fe/0GemO05IFEP1BDU80V9RH07=cL`1GEeL0/[:b0=;BdP2f][H0DU9B05mOG`21PH40UiNG05=CD`26
QXH0J6QX04Q8B02KVi/0DU9B07MgM`19BDT0IfMW06][J`1QHF40PX:204=3@`1SHf<0@D5106UYJ@1h
N7P0@D5105mOG`21PH40PX:208n?S`29RHT0QHF507IfMP1HF5P0>3Ph05]KF`1ADE40>SXj02d];@1H
F5P0@d=304a<C00o?cl0<30`04I6AP80CDe=01D0DE5A03De=@0l?3`0G5aL05YJFP1FEUH0DE5A05QH
F01]KFd0DE5A03hn?P1CDe<0ADE505MGE`1>CTh0K6a/065QH@15ADD0IVIV06i^KP1NGUh00P1TI6@0
@`12@T80G5aL04M7A`1DE5@0RHV90492@P0j>SX0B4Q80492@P0];Bd08R8R03hn?P0k>c/0A4A402h^
;P0E5AD0:b/[04m?C`0`<300@41003<c<`1>CTh0@D5104e=C@0j>SX0@D5105UIF@11@D40FUYJ05=C
D`1QHF40BTY:07IfMP1>CTh0EeMG05ADE017AdL0Cdm?09RHV01TI6@0J6QX08Z:RP1kNg/0Kfm_075a
L@13@d<0Hf=S04E5A@1SHf<0EeMG07=cL`1oOgl0UiNG05ADE01`L700GemO07MgM`19BDT0IVIV079b
LP0k>c/0R8R801dM7@17AdL0GemO07emO@10@4000P18B4P01`1>CTh0=SHf04M7A`1cLg<0IFEU03<c
<`1CDe<00P1LG5`08@0m?Cd0FUYJ06e]K@15ADD0C4a<03Lg=`2>SXh0YZJV05]KF`1;Bd/0HV9R04E5
A@2?Shl0=SHf05EEE@10@400Cdm?02DU9@0m?Cd0Bd];01hN7P0_;bl0DU9B05EEE@0O7al0<C4a02h^
;P0Q8B40?3`l04U9B@1CDe<0A4A406e]K@0203/k>`1T04Y:BP1nOWh0Hf=S03@d=01KFe/0B4Q8024Q
8@1;Bd/0?Cdm04E5A@0c<c<0?clo03hn?P1SHf<0@d=304a<C011@D40K6a/05IFEP2QXJ40Ph>303Ph
>018B4P0=SHf03Ti>@17AdL0?Shn03`l?010@400ADE503<c<`13@d<0;bl_04Y:BP0];Bd0?3`l051@
D010@400J6QX03<c<`0l?3`0G5aL03hn?P1VIVH0?3`l06m_K`1bLW80IVIV05YJFP1YJFT0IfMW08Z:
RP1RHV80KFe]0492@P1^KVh0EeMG05UIF@0h>3P0EEEE034a<@1^KVh0P82005=CD`1OGel0Cdm?04U9
B@1QHF40K6a/06IVIP1?Cdl0QHF505EEE@22PX80YZJV06IVIP1ADE40HV9R08n?S`1?Cdl0De=C059B
DP0o?cl0JFUY03dm?@17AdL0:RXZ03<c<`0b<S80LG5a051@D01QHF40Lg=c07AdM01XJ6P0FUYJ06m_
K`24Q8@0Lg=c09:BTQ7ooooo000?ooooo`0N065QH@1EEED0LG5a04A4A01KFe/0CTi>04E5A@1mOGd0
@41007alO02GUiL0=CDe03Lg=`1eMGD0CTi>0:ZZZP15ADD0>SXj05ADE01OGel0FUYJ096AT@1dM7@0
9RHV03dm?@1]KFd0Lg=c09FEU@0O7al0>CTi0P1FEUH05019BDT0Vi^K014A4@0e=CD0I6AT04Y:BP1A
DE40S8b<05QHF00M7Ad0BDU906IVIP1ADE40JFUY02LW9`0`<300EeMG075aL@17AdL0KFe]0P0c<c<0
k01UIFD0A4A402DU9@1PH600;Bd]0492@P1BDU80HF5Q02PX:01DE5@0@d=30451@@2ATI40BDU901/K
6`0j>SX0<c<c04i>CP27QhL0=CDe01XJ6P0];Bd0JFUY04m?C`1KFe/0SXj>02TY:@0K6a/0IfMW03Xj
>P1IFET0OGem02DU9@0S8b<0DU9B06ATI00W9bL0HV9R028R8P0d=3@0EUIF05ADE00i>CT0B4Q803dm
?@0M7Ad0OGem07QhN011@D40Cdm?03`l?00f=SH0MGEe06UYJ@0H61P0;Rh^04];B`1:BTX0[Zj^07Mg
M`0N7Qh0:RXZ04M7A`1;Bd/0FUYJ0:FUY@16ATH0=cLg03/k>`1oOgl0F5QH08n?S`1PH6006ATI01XJ
6P1FEUH0CDe=07UiN@0P82008b<S05EEE@1/K6`0CTi>0492@P1ZJVX0<c<c05UIF@2YZJT0;bl_03`l
?01BDU80=CDe03Ti>@25QHD0OGem03Ph>01OGel0>3Ph06=SH`2[Zj/0=cLg020P8012@T80Lg=c04Y:
BP2>SXh09BDU03<c<`1?Cdl0PX:204m?C`1eMGD0GemO01<C4`1;Bd/0MWIf04=3@`2OWil0>SXj01`L
701LG5`0O7al03Ph>017AdL0DE5A03Ti>@2EUID0Ti>C03hn?P1RHV80Cdm?02XZ:P0b<S80W9bL03/k
>`0h>3P0?3`l02TY:@1cLg<0KFe]03Xj>P0l?3`0>3Ph02<S8`2LW9`0=SHf02d];@19BDT0E5AD0410
@02i^KT0DE5A01`L701>CTh0E5AD09^KV`0T92@06a/K04=3@`1IFET0AdM709VIV@0^;Rh0E5AD06QX
J01=CDd0I6AT04I6AP0Y:BT0E5AD08V9R@1:BTX0O7al05IFEP1NGUh0GEeM06QXJ00o?cl0M7Ad03@d
=017AdL0N7Qh05IFEP1:BTX0EEEE024Q8@13@d<0GEeM08j>SP1MGEd0>CTi05]KF`13@d<0HF5Q07Ad
M01?Cdl092@T06][J`13@d<0AdM705mOG`27QhL0@410055AD@1BDU80GUiN09RHV01`L7009RHV04A4
A01MGEd0QHF507moO`1hN7P08B4Q02/[:`14A4@0EUIF05aLG01cLg<0>c/k02HV9P1>CTh0NWYj03@d
=01cLg<0F5QH02<S8`13@d<0JVYZ0410@012@T80<C4a02XZ:P0h>3P0MWIf7?ooool0EP25QHD0CDe=
04E5A@1ADE40SHf=08^;R`1hN7P0I6AT05aLG01_Kfl0M7Ad04i>CP1OGel0Jf][08>3P`28R8P0[jn_
07AdM01<C4`0MGEe04M7A`1hN7P0FUYJ061PH01MGEd0H61P06i^KP1=CDd0MWIf069RHP1KFe/0TY:B
04Y:BP1jNWX0Ti>C08>3P`2QXJ40/k>c0<_;b`29RHT0LW9b04a<C027QhL0JFUY05eMG@1?Cdl0NGUi
05]KF`1LG5`0C4a<02/[:`1FEUH0Kfm_0451@@1[Jf/0?Shn04M7A`1MGEd0<S8b05YJFP1PH600GEeM
04E5A@1;Bd/0@D5103`l?00`<300ADE504e=C@1dM7@0B4Q804a<C019BDT0EEEE03Lg=`0m?Cd0C4a<
04E5A@1<C4`0ADE503@d=01GEeL0CDe=04Y:BP1GEeL0=cLg0P0m?Cd0bP0f=SH0>3Ph04Y:BP16ATH0
<30`03Xj>P1ADE40<c<c03Xj>P0m?Cd0Bd];04E5A@10@400>CTi04Y:BP1@D500Cdm?04A4A00o?cl0
D51@06QXJ01QHF40AdM705eMG@0n?Sh0FEUI08:2PP2NWYh0JVYZ05aLG027QhL0SXj>06m_K`1XJ6P0
Bd];05ADE00l?3`0Cdm?04];B`1QHF40QHF509RHV01/K6`0Ti>C07YjNP2OWil0Cdm?04];B`1=CDd0
6a/K03hn?P0K6a/0Bd];03Lg=`1GEeL0A4A405EEE@0o?cl0?Cdm05IFEP1MGEd0D51@04i>CP0h>3P0
CDe=02l_;`1IFET0?Shn0410@017AdL0=3@d04E5A@0M7Ad0DE5A06QXJ00n?Sh0Fe]K069RHP0/;2`0
GemO04=3@`1QHF40CDe=05aLG00Q8B40@41004U9B@0Y:BT0Cdm?05ADE01BDU80=SHf04];B`0b<S80
;Rh^04=3@`1SHf<0EUIF02DU9@0j>SX0;2`/02TY:@0/;2`0@41004e=C@0T92@0XJ6Q05iNGP0R8R80
Kfm_03Ti>@1IFET0<C4a03lo?`0l?3`0I6AT051@D010@400?Cdm07EeM@0b<S80CTi>04m?C`0M7Ad0
LW9b05=CD`0Y:BT0B4Q8061PH01ADE40EeMG061PH016ATH0DU9B04=3@`1JFUX0?Cdm03lo?`1MGEd0
?Shn06][J`0];Bd0;2`/04];B`15ADD0RHV904Q8B01YJFT0GemO02l_;`1hN7P0KVi^05MGE`1`L700
@d=3075aL@13@d<0X:2P059BDP11@D40Bd];05]KF`1:BTX0R8R808:2PP14A4@0De=C03De=@1ADE40
PH6104Y:BP1cLg<0GEeM08N7Q`1EEED0ATI605]KF`1NGUh0<S8b04=3@`1DE5@0;2`/09fMW@1^KVh0
>CTi04U9B@15ADD0EeMG05YJFP1FEUH0;bl_051@D01SHf<0F5QH055AD@1gMgL0Jf][04M7A`1bLW80
Kfm_08B4Q02c/k<Aooooo`003oooool0=@1UIFD0Jf][0<S8b01>CTh0HF5Q071`L022PX80TY:B05MG
E`1CDe<0TI6A065QH@2ATI40][Jf03Ph>01?Cdl0=SHf065QH@2b/[80<S8b02l_;`0a<C40LW9b04m?
C`1`L7008B4Q04a<C02FUYH0KVi^0451@@1nOWh0>c/k02@T902@T900?3`l03<c<`0f=SH092@T03lo
?`26QXH0D51@01TI6@0Y:BT0@D5109:BTP2g]kL0<30`03De=@1;Bd/0?3`l05aLG02RXZ80BTY:0080
;2`/03/0JFUY06YZJP2<S8`07AdM03Lg=`16ATH0B4Q8059BDP1JFUX08B4Q04A4A00n?Sh0@41004a<
C021PH40Kfm_018B4P1;Bd/0BTY:055AD@1JFUX0?3`l020P8016ATH0GEeM04a<C01:BTX0AdM703Ph
>015ADD0Lg=c02d];@0Y:BT0@D5102l_;`0S8b<0HF5Q03`l?00I6AT0>SXj03@d=01EEED0P82003Hf
=P0I6AT071`L04A4A01LG5`0PX:201XJ6P1=CDd0Bd];07MgM`0a<C40L71`09ZJVP0M7Ad0IFEU0:ZZ
ZP0204U9B@1107EeM@0S8b<0<30`06=SH`1EEED0BTY:05EEE@0Z:RX092@T05EEE@1lO7`07AdM02/[
:`0j>SX0>3Ph0820P01:BTX05aLG03lo?`1=CDd0@T9205=CD`1jNWX0<C4a03Ti>@22PX80CDe=07al
O01iNGT061PH04I6AP1EEED0FEUI07=cL`11@D40<30`04Y:BP1?Cdl0MGEe05YJFP28R8P0@D5102XZ
:P1;Bd/0IVIV05MGE`1gMgL0?clo03/k>`1=CDd0K6a/04Y:BP0i>CT0C4a<02XZ:P1TI6@0P820034a
<@0g=cL0E5AD03Ph>01PH600JVYZ020P8012@T800P17AdL05`1eMGD0YZJV03dm?@0m?Cd0De=C05YJ
FP1jNWX071`L01dM7@0];Bd0PH61065QH@1jNWX0GUiN02HV9P15ADD0Jf][05=CD`1OGel0:BTY024Q
8@1bLW80Ph>30080@T920580?Cdm04i>CP11@D40@D5106UYJ@0e=CD0?Cdm08:2PP1CDe<0<c<c034a
<@19BDT0P82006a/K00K6a/0ADE50451@@0k>c/0JFUY05aLG00`<300EeMG04Y:BP1CDe<0YjNW05mO
G`0[:b/0Fe]K04U9B@2:RXX0WIfM034a<@0U9BD0EeMG08b<S01XJ6P0DE5A07]kN`0Z:RX0A4A409VI
V@2j^[X0IVIV09jNWP12@T80;2`/05aLG02>SXh0G5aL05iNGP0J6QX0ADE505EEE@1cLg<0A4A405aL
G01fMWH09RHV069RHP1XJ6P0=SHf03Lg=`1HF5P08R8R02l_;`1mOGd0RHV902h^;P0e=CD0F5QH059B
DP1mOGd0DU9B01lO7`0f=SH0?3`l05QHF01`L700ATI602XZ:P0k>c/0C4a<7?ooool07@1:BTX0Fe]K
05mOG`0d=3@0?clo06=SH`1JFUX0DE5A07UiN@2NWYh0QXJ605iNGP1^KVh0T92@08b<S01FEUH0WIfM
092@T01[Jf/0RHV904A4A01WIfL0EUIF06a/K01PH600L71`07emO@12@T80FUYJ0080DE5A0780Lg=c
04Q8B01bLW80Lg=c06=SH`1jNWX0Rh^;09BDU01YJFT0C4a<05EEE@1JFUX0D51@05EEE@16ATH0I6AT
04A4A01ZJVX0BDU902/[:`0i>CT0EeMG04M7A`1TI6@0BDU9059BDP1WIfL0C4a<06m_K`1WIfL0JFUY
061PH01`L700@410059BDP1DE5@0De=C05YJFP2_[jl0GemO05iNGP1WIfL0V9RH04A4A01<C4`0JVYZ
04Q8B01FEUH0Cdm?03Ti>@1NGUh0=SHf02TY:@0l?3`0?Shn02HV9P0Y:BT0C4a<04A4A01=CDd0?clo
02<S8`0i>CT0EUIF03Ti>@0l?3`0>c/k04i>CP13@d<0C4a<04A4A01CDe<0GEeM038b<P1>CTh0>c/k
04Q8B00j>SX0HF5Q03hn?P18B4P0?3`l04Y:BP15ADD0HV9R0820P01fMWH0H61P05aLG01@D500A4A4
03dm?@1MGEd0D51@05MGE`17AdL0HV9R09FEU@2CTi<0IVIV07EeM@1YJFT0SXj>05iNGP2RXZ80MgMg
034a<@1DE5@0;Rh^05EEE@1>CTh0EeMG05iNGP1XJ6P203`l?00804];B`13@d<0De=C05iNGP1CDe<0
HV9R0410@01eMGD204M7A`0B05mOG`0Y:BT0D51@024Q8@1`L700Ph>304i>CP0^;Rh0De=C03/k>`1U
IFD0@D5103/k>`0_;bl0?3`l02TY:@1@D500CTi>0P0g=cL0L@1DE5@0GUiN02LW9`0_;bl0@T9204=3
@`1;Bd/0HV9R07AdM00k>c/0CTi>03dm?@1>CTh0@D5104a<C015ADD08B4Q04i>CP0_;bl0=SHf0;Bd
]01@D500<S8b03hn?P1jNWX0AdM707alO01<C4`0GEeM03hn?P26QXH0<c<c08b<S01lO7`08R8R03Lg
=`13@d<0ATI605eMG@15ADD0BDU905EEE@0f=SH0>3Ph05EEE@0c<c<0?clo04Y:BP19BDT0DU9B03/k
>`2FUYH0GEeM04];B`1eMGD0A4A4071`L00O7al0IfMW07emO@1IFET0MgMg05eMG@1QHF40QhN705UI
F@23Ph<0ADE506ATI019BDT0=CDe03Ph>01@D5009RHV05iNGP1dM7@0DU9B07inOP17AdL0FUYJ04m?
C`1KFe/0NGUi05]KF`2=SHd0DU9B07MgM`1jNWX0R8R806QXJ01[Jf/0U9BD03@d=00k>c/0>SXj05AD
E01aLG40EUIF05MGE`17AdL0EEEE03`l?01LG5`0D51@05aLG01QHF40FUYJ05IFEP1:BTX0GemO051@
D01SHf<0QXJ6017ooooo000?ooooo`2J0820P01BDU80IFEU06m_K`1JFUX0BDU904a<C02?Shl0H61P
05UIF@1SHf<0=3@d03hn?P23Ph<0CTi>069RHP0n?Sh0GUiN08^;R`1cLg<09BDU03hn?P1@D500FEUI
07UiN@0R8R80<S8b03hn?P1RHV80JFUY09^KV`0g=cL0:RXZ055AD@1^KVh0Lg=c05ADE00I6AT04Q8B
04m?C`1hN7P0@d=307]kN`0`<3007alO071`L01bLW80GUiN07alO00];Bd0>3Ph03<c<`1UIFD0FUYJ
05QHF00F5QH0@T9206e]K@19BDT0:RXZ05UIF@16ATH0?Shn09fMW@0b<S80<c<c05]KF`0a<C40=SHf
07=cL`2FUYH07AdM03hn?P1BDU80F5QH08f=S@1HF5P04Q8B024Q8@1TI6@0DU9B05QHF01oOgl06a/K
03De=@22PX80JFUY06e]K@2ZZZX0:BTY01XJ6P1<C4`0AdM70492@P14A4@030`<03<c<`11@D40EUIF
02`/;01DE5@0>SXj03Lg=`1BDU80BTY:02d];@1;Bd/0@41002TY:@1DE5@0SXj>03De=@0c<c<0@T92
051@D01NGUh0U9BD02d];@0M7Ad0>3Ph04Q8B01hN7P0ZJVY01dM7@0D51@0BDU9079bLP11@D40Q8B4
06m_K`0d=3@0GEeM08b<S00n?Sh0][Jf06UYJ@0`<300EeMG08J6QP1PH600CTi>03Ti>@0l?3`0LW9b
0;Jf]P1ADE40AdM708N7Q`19BDT0CDe=09VIV@0o?cl0AdM705MGE`80>SXj08H0W9bL08^;R`0c<c<0
Bd];03Ph>01BDU80XJ6Q05aLG00R8R80ATI605eMG@15ADD0Shn?05eMG@0T92@0DU9B06IVIP1TI6@0
QhN708>3P`0V9RH0=cLg06IVIP1MGEd0XJ6Q04I6AP0X:2P0;Bd]05]KF`1GEeL0EEEE08>3P`0d=3@0
KFe]0861P@0[:b/0JFUY03dm?@0];Bd0GUiN08F5Q@0d=3@0?clo04];B`1OGel0UIFE04m?C`0b<S80
A4A404=3@`1EEED0Hf=S03<c<`1OGel0B4Q806e]K@21PH40EUIF02TY:@1aLG40GemO07MgM`0^;Rh0
:RXZ06MWI`1UIFD0Cdm?08R8R01bLW808B4Q065QH@28R8P0?Shn071`L00Q8B40<30`06e]K@21PH40
AdM708>3P`0i>CT0>3Ph0820P02;Rh/0DU9B04m?C`16ATH09BDU05IFEP1dM7@0Cdm?055AD@0n?Sh0
;Rh^03<c<`1hN7P0OGem02HV9P0d=3@0?3`l05EEE@2CTi<0=3@d02PX:01>CTh0C4a<05aLG021PH40
alO703Ti>@0m?Cd0O7al08>3P`19BDT0Kfm_02`/;00a<C40A4A407emO@1ZJVX0L71`01`L700_;bl0
FEUI06][J`0e=CD0IfMW04];B`0P8200@D5107UiN@0l?3`0>SXj04Q8B1cooooo02D0F5QH06ATI01]
KFd0>SXj065QH@2EUID0Jf][07IfMP2YZJT0X:2P0:>SX`19BDT0BTY:09RHV031`L40Ogmo09:BTP1`
L700BDU908V9R@1BDU80Rh^;05=CD`1cLg<0J6QX059BDP26QXH0@d=305EEE@0o?cl0Lg=c08f=S@12
@T80R8R80:BTY02=SHd0QXJ60080`<3001<0SXj>06e]K@1EEED0UYJF065QH@1;Bd/0ADE507IfMP0f
=SH0KFe]065QH@1?Cdl0@d=3061PH01IFET0OWin03<c<`12@T80M7Ad0080GemO07P0EUIF051@D01U
IFD0FEUI04Q8B01OGel0IfMW06a/K01]KFd0PH6106QXJ01eMGD0NGUi07MgM`18B4P0Fe]K06YZJP0m
?Cd0H61P0410@00Z:RX0H61P03hn?P17AdL0Cdm?03Xj>P0h>3P0=cLg03Ph>00k>c/0FEUI03hn?P0[
:b/0@T9205EEE@0i>CT0A4A40492@P1BDU80;Rh^04];B`0k>c/0?3`l04i>CP0h>3P0EUIF04U9B@1S
Hf<0@d=306][J`1=CDd0EeMG05]KF`1^KVh0HV9R0:JVYP1OGel0H61P09BDU01]KFd0HV9R05YJFP0o
?cl0GUiN03hn?P1_Kfl0J6QX08Z:RP25QHD0UIFE06a/K029RHT0QhN709^KV`25QHD0BDU906UYJ@0i
>CT0JFUY03lo?`1BDU80@T9204a<C00n?Sh0D51@055AD@1CDe<0Fe]K05IFEP21PH40MGEe03`l?01:
BTX0A4A4075aL@1MGEd0IfMW06EUI@0d=3@0DU9B01TI6@1YJFT0OGem05IFEP0e=CD0J6QX03hn?P1i
NGT0:RXZ04a<C00R8R80AdM702XZ:P0f=SH0?Shn02@T900_;bl0DU9B04=3@`0L71`202`/;00902DU
9@0c<c<0AdM705EEE@0o?cl0FUYJ04];B`11@D40?Cdm0080G5aL0640;Rh^05iNGP17AdL092@T04e=
C@0l?3`0AdM703dm?@13@d<0@D5105YJFP0f=SH0@41004A4A01LG5`0=cLg04i>CP1GEeL09bLW03<c
<`1:BTX0?Cdm04e=C@11@D40DE5A05eMG@1:BTX0@D5103`l?00Y:BT0Bd];03Ph>00j>SX0CDe=0410
@01RHV80ATI603Ti>@1OGel0A4A40;6a/@0g=cL0RHV907]kN`19BDT0GemO05iNGP13@d<0IVIV03`l
?00j>SX0>CTi08>3P`1VIVH0MWIf0492@P1dM7@0<C4a07moO`20P800ADE505eMG@0j>SX0?clo07Ad
M015ADD0G5aL051@D01jNWX0JFUY055AD@1=CDd0HV9R03Xj>P1@D500EUIF0410@01:BTX0?3`l03@d
=012@T80?Cdm0492@P0[:b/0?Cdm02d];@1IFET0DE5A05QHF01FEUH0IVIV04m?C`1QHF40Jf][05=C
D`24Q8@0S8b<017ooooo000?ooooo`3o09:BTP1FEUH0OGem05MGE`1UIFD0EUIF05iNGP1aLG40JFUY
06QXJ02=SHd0BTY:051@D01NGUh0EeMG08F5Q@0i>CT0ADE505MGE`1PH600CTi>0861P@1PH600;bl_
05mOG`17AdL0OGem06QXJ00O7al0?Shn06][J`1ZJVX0>SXj07YjNP0P8200CTi>07inOP17AdL0G5aL
059BDP0O7al0<C4a061PH01bLW80Hf=S0451@@0U9BD0C4a<06i^KP0l?3`0:BTY06IVIP0_;bl0EEEE
07EeM@0h>3P0=cLg04i>CP0l?3`0@D5108b<S01OGel0?Cdm04Y:BP0i>CT0E5AD07EeM@0n?Sh0:b/[
03Ph>017AdL0?Shn05QHF00X:2P0;bl_04A4A017AdL0?Shn055AD@1[Jf/07QhN02@T901BDU80@d=3
061PH01MGEd07alO0410@01ADE40EeMG02DU9@1DE5@0;Bd]04E5A@1ZJVX0Bd];03Ti>@1LG5`0>CTi
03hn?P1YJFT0EEEE03dm?@1BDU80;Rh^03Ph>01eMGD0DU9B02XZ:P0i>CT0JFUY06=SH`26QXH0AdM7
02<S8`11@D40DU9B03Ph>00l?3`0M7Ad034a<@0l?3`0DE5A05UIF@0n?Sh0XZ:R03dm?@0G5aL0@410
075aL@0c<c<0Fe]K02PX:00W9bL0KFe]08^;R`14A4@0>SXj06UYJ@0k>c/0JFUY07AdM00[:b/0A4A4
061PH00e=CD0Bd];09ZJVP1BDU80AdM705IFEP0o?cl0J6QX09ZJVP1EEED0;2`/06UYJ@1QHF40>CTi
079bLP0/;2`0?Cdm04e=C@1SHf<0EEEE06m_K`15ADD06ATI03dm?@1ZJVX0A4A408R8R00k>c/08R8R
05MGE`1^KVh0@T9204m?C`1JFUX0=SHf07inOP1RHV80=3@d04M7A`0o?cl0>c/k05eMG@2NWYh0ADE5
059BDP0b<S80<c<c07YjNP1WIfL0=cLg04Y:BP1LG5`0@D5107AdM00^;Rh0ADE506YZJP1FEUH0JFUY
092@T00g=cL0A4A405YJFP1?Cdl0U9BD03<c<`0X:2P0KVi^069RHP1@D500SHf=03Lg=`1=CDd0KVi^
04];B`1SHf<0?clo02`/;01ADE40KVi^03lo?`1GEeL0AdM704i>CP1YJFT0DU9B04a<C01/K6`0?clo
04Q8B022PX80Cdm?04e=C@11@D40=CDe04A4A01dM7@0Lg=c03dm?@13@d<0ATI603Ti>@1UIFD0I6AT
02l_;`0m?Cd0EEEE04];B`0l?3`0L71`000C07UiN@0l?3`0N7Qh05IFEP1OGel0TI6A04=3@`0W9bL0
Hf=S07MgM`1PH600Q8B407alO00P8200BTY:07YjNP1LG5`0@D5107AdM002038b<P0>065QH@14A4@0
;Rh^06=SH`0j>SX0<30`05=CD`1VIVH0>CTi0451@@0e=CD0@D5105aLG01/K6`Looooo`1105mOG`1d
M7@0K6a/04a<C01TI6@0SXj>07UiN@1YJFT0V9RH0;2`/02HV9P0F5QH06MWI`1mOGd0Ogmo07MgM`2K
Vi/0R8R806a/K01oOgl0ADE506e]K@1VIVH0Lg=c061PH01[Jf/0MGEe051@D01YJFT0FEUI065QH@2=
SHd0B4Q808b<S028R8P0J6QX08^;R`2VYZH0alO70861P@1KFe/0Hf=S07moO`1LG5`0Hf=S061PH01h
N7P0De=C07=cL`1/K6`0BTY:04a<C01UIFD0A4A407AdM00k>c/0?clo06IVIP1:BTX0Hf=S05QHF01R
HV80F5QH05eMG@0j>SX00P1BDU801`1HF5P0GEeM08^;R`1SHf<0IFEU061PH01ZJVX00P17AdL0:01L
G5`0C4a<05eMG@1;Bd/0>SXj06EUI@12@T80?3`l0492@P0l?3`0>CTi034a<@1>CTh0=SHf059BDP15
ADD07AdM03/k>`1QHF40?3`l03/k>`0o?cl0IFEU04I6AP1EEED0E5AD04I6AP1JFUX0>3Ph059BDP13
@d<0F5QH04U9B@1SHf<0@D5105MGE`1KFe/0JVYZ07QhN02IVIT206i^KP0U09fMW@1nOWh0GemO05aL
G012@T80GemO04Y:BP1TI6@0B4Q807alO02EUID0Vi^K07=cL`1oOgl0HV9R07IfMP1SHf<0OGem07Ui
N@14A4@0GEeM04];B`1HF5P0ATI605]KF`1=CDd0DU9B03/k>`0i>CT0F5QH05YJFP1PH600JVYZ04e=
C@1HF5P0HV9R07EeM@0204=3@`0H061PH00h>3P0FEUI02TY:@1_Kfl0RHV9055AD@1?Cdl0HV9R03Ph
>01cLg<0>3Ph04e=C@0V9RH0DE5A02/[:`14A4@0CTi>01PH600h>3P0G5aL04];B`0J6QX0<S8b0P0W
9bL09@0`<300DE5A06ATI00Y:BT0A4A403Lg=`0i>CT0>c/k03dm?@1=CDd0;Rh^06a/K00b<S80;2`/
09jNWP16ATH0CTi>03hn?P1FEUH0>SXj071`L01=CDd0B4Q804Y:BP1nOWh0?3`l06QXJ01LG5`08R8R
04I6AP1KFe/0=cLg05QHF01DE5@0FEUI06QXJ01JFUX00P14A4@03@0d=3@0BTY:03Ph>011@D40GUiN
03Ph>01fMWH0<S8b03dm?@1OGel0>CTi07MgM`0^;Rh00P1eMGD02P0l?3`0Kfm_05MGE`1UIFD0Q8B4
03dm?@1HF5P0;Rh^08>3P`1=CDd203hn?P0Y04a<C00`<300M7Ad075aL@0k>c/0GUiN038b<P15ADD0
H61P04a<C01PH600GemO065QH@1HF5P0EeMG04I6AP1/K6`0CTi>069RHP1DE5@0?3`l06QXJ01=CDd0
?3`l04U9B@0l?3`0FEUI04i>CP1:BTX0?clo06UYJ@1GEeL0J6QX05=CD`1WIfL0G5aL05YJFP1nOWh0
BTY:07UiN@2RXZ804Oooool000oooooo02D0KVi^05IFEP21PH40M7Ad05=CD`1NGUh0NGUi08^;R`0j
>SX0@D5104m?C`1KFe/0P82009nOW`0c<c<0CDe=04Q8B01WIfL0Xj>S02/[:`0a<C40Bd];09>CT`1M
GEd0M7Ad02TY:@1QHF40J6QX02DU9@1LG5`0KVi^02LW9`0[:b/0T92@034a<@1eMGD0FEUI0080:BTY
0:h0LW9b06ATI00R8R80=CDe02LW9`1FEUH0PH6103dm?@0e=CD0D51@04E5A@1FEUH0VIVI051@D00`
<300A4A40410@01TI6@0JFUY02@T900K6a/0?Shn04e=C@1RHV80@d=301hN7P0k>c/0=3@d0492@P1F
EUH0SHf=07AdM00U9BD0@D5105]KF`1iNGT0XZ:R03<c<`0O7al0CTi>06EUI@1<C4`0JFUY04I6AP0M
7Ad0Cdm?079bLP13@d<0Fe]K07=cL`0J6QX0:b/[059BDP0Y:BT0<C4a04=3@`0M7Ad0DU9B07MgM`0n
?Sh092@T03dm?@0b<S80Rh^;0;Vi^@0[:b/07AdM02@T9011@D40@41007MgM`20P8007alO04M7A`1^
KVh0CDe=0861P@2MWId0>3Ph03lo?`18B4P0DE5A05MGE`1VIVH08R8R01dM7@15ADD0EeMG02HV9P0a
<C40Cdm?02l_;`1CDe<0>SXj02DU9@17AdL0ATI602l_;`13@d<0WinO04i>CP0a<C40ADE505YJFP1`
L700PH6101lO7`0R8R80>SXj05IFEP1hN7P0CDe=02`/;01:BTX0DE5A069RHP1]KFd0_Kfm03Xj>P0R
8R80IVIV0451@@24Q8@0TY:B04E5A@0W9bL0JVYZ09BDU016ATH0AdM704U9B@0h>3P0ADE507alO00n
?Sh0P820051@D00Z:RX0<30`05QHF011@D40H61P03Hf=P0h>3P0QHF5092@T00V9RH0;Rh^04m?C`13
@d<0Vi^K02HV9P0a<C40E5AD04Y:BP18B4P0Rh^;06m_K`0I6AT0Hf=S04M7A`1;Bd/0VIVI03Hf=P12
@T80O7al04e=C@1NGUh0AdM702l_;`1iNGT0EeMG04U9B@1iNGT204E5A@1905MGE`1<C4`0F5QH0410
@015ADD0I6AT05EEE@0c<c<0PX:203hn?P0b<S80QhN706e]K@0k>c/0?Shn04A4A00m?Cd0R8R806UY
J@0/;2`0CTi>0492@P1hN7P0XZ:R04M7A`0b<S80C4a<0451@@10@400MGEe0;:b/P0j>SX0E5AD04I6
AP1DE5@0GEeM0:f][@0[:b/0=3@d05mOG`1jNWX0HV9R06i^KP0g=cL0@D5107MgM`2SXj<0BDU90:2P
X01nOWh0<S8b05EEE@2FUYH0GEeM05=CD`1NGUh08B4Q03<c<`1ZJVX0L71`03`l?00a<C40=cLg04I6
AP1VIVH0@T9201`L700`<300=SHf04=3@`1XJ6P0De=C01TI6@0204A4A1cooooo0380DE5A05QHF01^
KVh0Cdm?05mOG`2NWYh0KVi^04m?C`2TY:@0f][J0:RXZ01;Bd/0CDe=08B4Q02:RXX0Xj>S09:BTP15
ADD0>3Ph04Q8B01?Cdl0CDe=030`<01@D500EeMG04Q8B01>CTh0>SXj04=3@`0_;bl0Jf][06QXJ00n
?Sh0Bd];05eMG@1RHV80Lg=c07YjNP1]KFd0IfMW04e=C@11@D40JVYZ05IFEP0n?Sh0;bl_055AD@12
@T80CDe=0410@080>CTi0180ATI604E5A@10@4008b<S02LW9`1HF5P0M7Ad04Q8B00i>CT0>SXj06UY
J@0o?cl0;Rh^059BDP1PH600?clo03<c<`1GEeL207inOP0Y055AD@1[Jf/0O7al06UYJ@1=CDd0<c<c
04M7A`1DE5@0MGEe05mOG`0i>CT0E5AD03dm?@0i>CT0AdM703/k>`0f=SH0=CDe05EEE@0g=cL08R8R
04U9B@14A4@09bLW03Lg=`1LG5`0FUYJ034a<@1;Bd/0B4Q803dm?@1<C4`0ATI605YJFP1GEeL0Hf=S
04E5A@1]KFd0Hf=S069RHP1jNWX00P1kNg/0T@2LW9`0HF5Q06a/K023Ph<0IVIV05YJFP1KFe/0=SHf
061PH00n?Sh0KFe]05MGE`2MWId0[jn_0;Bd]01[Jf/0Ti>C0;Bd]02QXJ40KVi^07MgM`1fMWH0:BTY
06m_K`2:RXX0RHV904A4A01>CTh0F5QH055AD@1DE5@0DE5A06EUI@1=CDd0Q8B405mOG`0h>3P0FUYJ
06YZJP1hN7P0CDe=05]KF`1oOgl0Hf=S0410@01;Bd/0Ph>308R8R01CDe<0<c<c05]KF`16ATH0Lg=c
034a<@0n?Sh0;bl_04m?C`0a<C40?clo04I6AP0I6AT0CTi>05]KF`0i>CT06a/K03lo?`0L71`0=CDe
02h^;P15ADD0DE5A02PX:01=CDd0>c/k05QHF00m?Cd0Cdm?05EEE@0P8200F5QH024Q8@0@4100CDe=
03Lg=`1>CTh0>CTi04a<C00l?3`0Jf][04A4A01EEED0@41005QHF00Z:RX0PH6107inOP0Q8B40BTY:
04];B`0i>CT0Cdm?04=3@`1<C4`0HF5Q05aLG00f=SH0<c<c02TY:@18B4P0=SHf03Ti>@1SHf<0=cLg
06e]K@0P8200=CDe05iNGP0T92@0Ogmo038b<P1SHf<0JVYZ03Xj>P1/K6`0BDU905IFEP1`L700CDe=
08B4Q00Q8B40Jf][04I6AP14A4@0ATI604Y:BP0O7al0YjNW08J6QP0g=cL0DU9B02HV9P19BDT0E5AD
05UIF@1VIVH00P1HF5P0301hN7P0IfMW04m?C`1aLG40Fe]K08J6QP1TI6@0=SHf0451@@10@400B4Q8
05EEE@80@d=300h0;bl_04e=C@1BDU80JVYZ059BDP1HF5P0GUiN08>3P`1UIFD0GEeM0:VYZ@1GEeL0
NGUi08:2PQ7ooooo000?ooooo`3o09bLW01PH600J6QX0861P@20P800?Shn06=SH`2?Shl0Kfm_092@
T023Ph<0=SHf04e=C@1YJFT0FUYJ06EUI@0^;Rh0?3`l05iNGP24Q8@0?3`l08N7Q`0i>CT0;Bd]04];
B`0_;bl0@T9205EEE@0l?3`0CDe=07=cL`0g=cL08B4Q04E5A@0m?Cd0KFe]07emO@0O7al08R8R03@d
=01cLg<0Hf=S09jNWP0j>SX0>CTi05ADE018B4P0GUiN07moO`0S8b<09RHV03hn?P1RHV80J6QX065Q
H@0E5AD0<30`05ADE018B4P0Hf=S08V9R@0g=cL0>SXj06i^KP0W9bL0;bl_05eMG@0O7al09RHV05IF
EP24Q8@0<S8b02l_;`0V9RH0>c/k07YjNP2;Rh/07AdM03Lg=`12@T809BDU03dm?@1SHf<08b<S03dm
?@0l?3`0>SXj05YJFP27QhL0:RXZ01<C4`1?Cdl0<30`06][J`1fMWH06ATI020P801PH600LG5a04m?
C`1oOgl0;Rh^04E5A@1CDe<0T92@05ADE01`L7006ATI02<S8`0o?cl0IfMW04Q8B01TI6@0=SHf02`/
;01BDU80SXj>04U9B@0M7Ad0@T92038b<P1>CTh0RHV903@d=00X:2P0B4Q804M7A`0^;Rh0Ph>30:NW
Y`0N7Qh0>c/k04A4A01SHf<0YZJV07AdM00M7Ad0A4A405MGE`1PH600GEeM02PX:00_;bl0BDU908J6
QP1;Bd/0F5QH05UIF@0P8200FUYJ0:^[Z`0k>c/0GemO03hn?P0];Bd0EUIF09:BTP1EEED0:b/[0451
@@0c<c<0UIFE09VIV@0];Bd09RHV03Xj>P1>CTh0BDU906a/K01=CDd0;bl_04];B`1>CTh0AdM70;:b
/P1gMgL092@T04Q8B00o?cl0J6QX0:FUY@14A4@09BDU05EEE@1cLg<0>c/k04U9B@1mOGd0<S8b08b<
S01YJFT0De=C09JFUP0`<3007AdM05QHF021PH40?clo04=3@`0W9bL0@d=3096AT@1^KVh0=3@d05MG
E`0U9BD0Lg=c06QXJ00m?Cd0IFEU03Xj>P1=CDd0Y:BT065QH@0n?Sh0JFUY04Q8B01YJFT0ADE502XZ
:P1^KVh0H61P051@D01aLG40=SHf024Q8@1IFET0HV9R06QXJ01GEeL0<30`04m?C`1XJ6P0U9BD065Q
H@2ZZZX0:RXZ07AdM02JVYX0BTY:05YJFP1OGel0?clo02LW9`19BDT0MgMg06=SH`1WIfL0>CTi01`L
700i>CT0J6QX07alO00h>3P0JFUY000S030`<00_;bl0KVi^020P8010@400E5AD02TY:@1NGUh0UYJF
075aL@0Z:RX0CTi>04m?C`14A4@0W9bL09RHV00T92@0:b/[04A4A01KFe/0P82005aLG00H61P0@D51
05ADE01JFUX0Cdm?09RHV01RHV807alO04Y:BP21PH40BTY:08n?S`1_Kfl07?ooool0?P1QHF40FEUI
06ATI013@d<0Ogmo0861P@1nOWh0LG5a0410@01FEUH0IFEU06ATI026QXH0OWin05=CD`0j>SX0Jf][
0861P@1IFET0MGEe03`l?01SHf<0BDU906IVIP1[Jf/0FEUI07emO@17AdL0De=C03Xj>P0o?cl0GemO
04a<C01VIVH0Kfm_08B4Q02d];@0YJFU0:j^[P2<S8`0GEeM051@D01dM7@0IFEU04m?C`12@T80MWIf
055AD@1EEED0DE5A04];B`1?Cdl0JVYZ04M7A`1gMgL0820P02d];@1QHF40De=C05iNGP17AdL0De=C
0P17AdL0:00Y:BT0B4Q80451@@17AdL0ATI607moO`1IFET0Bd];05EEE@1IFET0<C4a02l_;`0n?Sh0
<30`0492@P0m?Cd07AdM04Q8B00a<C40:2PX02l_;`0m?Cd0;Bd]024Q8@0k>c/0<C4a03/k>`0e=CD0
5ADE030`<01>CTh0<c<c02<S8`0M7Ad0>SXj03Lg=`0o?cl0=SHf03Ph>00l?3`203/k>`2F04E5A@17
AdL0Fe]K051@D00c<c<0E5AD07IfMP1iNGT0O7al075aL@1[Jf/0JVYZ08:2PP1fMWH0EUIF06=SH`1>
CTh0G5aL0492@P1WIfL0O7al08B4Q02WYjL0ZZZZ06][J`1bLW80J6QX07inOP1CDe<0HV9R07inOP1:
BTX0HF5Q08n?S`1jNWX0EEEE06m_K`1@D500ADE503Xj>P11@D40H61P06m_K`1QHF40EUIF0410@01R
HV80ATI605aLG011@D40<C4a04m?C`1CDe<0>c/k01DE5@24Q8@0/[:b06IVIP0j>SX0DU9B0492@P1d
M7@0B4Q805ADE00T92@0BDU902HV9P0k>c/0ATI603Lg=`0c<c<0C4a<04M7A`0V9RH0:RXZ02d];@0U
9BD0:RXZ05UIF@1GEeL0:b/[0410@00_;bl0<C4a02d];@0o?cl0ADE501TI6@1/K6`071`L010@401k
Ng/0>SXj051@D00j>SX0C4a<034a<@1/K6`0<C4a0451@@0i>CT0JFUY03De=@13@d<0CDe=01hN7P0o
?cl0EUIF038b<P1ADE40ATI605YJFP1jNWX0FUYJ04U9B@11@D40>CTi04i>CP0n?Sh0AdM705IFEP13
@d<0JFUY02LW9`0k>c/0F5QH02d];@2>SXh0=cLg079bLP1SHf<0;Rh^07emO@1]KFd0IVIV06UYJ@1?
Cdl0E5AD03hn?P2:RXX0E5AD03Hf=P1_Kfl0GemO01XJ6P1<C4`0>SXj02h^;P1/K6`0ADE50P1GEeL0
8018B4P0GEeM06m_K`1QHF40MgMg04e=C@0g=cL0E5AD03Xj>P1cLg<0?Shn01/K6`1DE5@0>CTi02d]
;@11@D408b<S05EEE@1<C4`0ADE503@d=01@D500HV9R06e]K@1DE5@0HF5Q06ATI01nOWh0GEeM05UI
F@28R8P0/K6a4Oooool000oooooo06D0SXj>051@D01RHV80B4Q806MWI`16ATH0GEeM05=CD`10@400
UYJF096AT@0`<300?3`l04=3@`1UIFD0UIFE02l_;`12@T80Cdm?04Q8B01FEUH0];Bd04I6AP0m?Cd0
CTi>05IFEP2][Jd0Lg=c03<c<`1@D500HF5Q05UIF@1GEeL0Ph>302HV9P17AdL0HF5Q03`l?01NGUh0
FEUI02/[:`0m?Cd0KVi^06ATI01`L700?Cdm038b<P0m?Cd0I6AT05=CD`1:BTX0Ogmo01hN7P0i>CT0
I6AT01`L700j>SX0BDU902DU9@13@d<0Kfm_05IFEP0Y:BT0@410059BDP1/K6`0OGem02XZ:P0G5aL0
<S8b05ADE01FEUH0L71`01`L700P8200C4a<08B4Q00l?3`0Fe]K04I6AP0S8b<0:b/[06=SH`11@D40
QhN703Xj>P0E5AD0<S8b065QH@1?Cdl0@D5104I6AP0O7al0>CTi06i^KP1PH600:RXZ04Y:BP0W9bL0
7alO05YJFP020451@@15055AD@11@D40EUIF09VIV@0l?3`061PH0451@@15ADD0AdM70;6a/@17AdL0
6a/K03Hf=P1WIfL0FUYJ06YZJP2[Zj/0:b/[04Q8B01iNGT0EEEE04=3@`1nOWh0=CDe020P8017AdL0
XZ:R05eMG@1TI6@0=SHf02@T901lO7`0Ti>C02h^;P0l?3`0LW9b02XZ:P1[Jf/0FUYJ01XJ6P0o?cl0
ATI604e=C@1UIFD0U9BD02<S8`0m?Cd0OGem05YJFP2BTY80@41001hN7P1CDe<0NGUi06QXJ01=CDd0
IVIV01lO7`0i>CT0NWYj071`L01ADE40QHF509>CT`0Q8B40Cdm?079bLP1=CDd0P82000809bLW0540
OGem092@T015ADD0>c/k03Ph>019BDT0VIVI08J6QP0m?Cd0B4Q804e=C@0k>c/0Cdm?09bLW00f=SH0
C4a<05]KF`1FEUH0WIfM05]KF`0T92@0?Cdm05eMG@1NGUh0Jf][02DU9@0^;Rh0MGEe05aLG01MGEd0
QHF502DU9@0];Bd0IfMW059BDP2>SXh09RHV0451@@18B4P0@d=306EUI@2<S8`0820P05ADE01`L700
AdM706e]K@0f=SH0C4a<07IfMP1OGel0@D5105EEE@1:BTX0@D5108B4Q00m?Cd0:b/[05iNGP17AdL0
>CTi06a/K017AdL0?3`l05aLG01HF5P0DE5A08B4Q01HF5P06QXJ02DU9@0m?Cd0C4a<08j>SP1FEUH0
7alO03`l?01CDe<0CTi>059BDP2o_kl00P1>CTh08@1PH600?Shn05IFEP29RHT07AdM02PX:01YJFT0
Lg=c04M7A`1QHF40E5AD01lO7`14A4@0PX:205=CD`1?Cdl0DE5A01LG5`0f=SH0IFEU02<S8`0/;2`0
HF5Q02h^;P0U9BD0FEUI0820P00/;2`0A4A402l_;`0R8R80M7Ad08Z:RP0Looooo`1g05=CD`1aLG40
QXJ606YZJP14A4@0Kfm_06=SH`1JFUX0RHV907IfMP2;Rh/0?clo04U9B@1cLg<0Ti>C065QH@1bLW80
EEEE03Ti>@1?Cdl0B4Q805iNGP1VIVH0Fe]K06ATI01aLG40G5aL05MGE`1QHF40?3`l05=CD`1IFET0
?clo065QH@1OGel0De=C069RHP1[Jf/0Rh^;06QXJ011@D40F5QH05ADE011@D40C4a<05EEE@1[Jf/0
=SHf04m?C`1@D500@41002/[:`12@T80@d=305iNGP10@400C4a<05YJFP1PH600O7al08Z:RP1[Jf/0
Fe]K05YJFP0m?Cd0EEEE04e=C@1QHF40Hf=S096AT@1eMGD0Hf=S06a/K01_Kfl0BTY:0492@P18B4P0
>c/k059BDP12@T80<S8b069RHP1;Bd/0@T9203@d=01=CDd0=CDe02<S8`1KFe/0BDU9055AD@0d=3@0
7alO04A4A01BDU80@D5103De=@0o?cl0De=C0410@01@D500Bd];05eMG@1QHF40BTY:065QH@1ADE40
EeMG030`<01GEeL0?3`l04=3@`1HF5P0FEUI065QH@1ZJVX0MWIf06UYJ@1TI6@00P1?Cdl08P0m?Cd0
;Rh^04U9B@1:BTX0AdM704U9B@1HF5P0XZ:R09JFUP1ZJVX0I6AT079bLP29RHT0DE5A08n?S`22PX80
ATI606ATI01RHV80@T9203Ph>010@400IFEU07alO01=CDd0ADE504e=C@0o?cl0GUiN075aL@1@D500
EeMG04I6AP1jNWX203lo?`1Z069RHP0l?3`0CDe=01lO7`1=CDd0Lg=c06IVIP0k>c/0J6QX03Ti>@1o
Ogl0A4A404e=C@0P8200E5AD05YJFP1BDU80EeMG028R8P0`<300C4a<05IFEP0e=CD0<30`03Ph>00b
<S80BDU903De=@1>CTh0;bl_0451@@0k>c/0Hf=S04E5A@1DE5@0FEUI01lO7`1DE5@0<C4a018B4P19
BDT0<c<c03Ph>00j>SX0De=C03dm?@1TI6@0<S8b06EUI@12@T80OGem02PX:01LG5`0Fe]K01`L7019
BDT0F5QH04m?C`1jNWX0CTi>055AD@1]KFd0B4Q803lo?`1;Bd/0>3Ph03dm?@1?Cdl0CTi>05eMG@1A
DE40Rh^;04Q8B01>CTh0J6QX020P801YJFT06ATI09>CT`1oOgl0C4a<07EeM@1OGel0M7Ad079bLP1D
E5@0J6QX04I6AP2;Rh/0Jf][051@D01EEED0Fe]K02d];@28R8P0HV9R03`l?01?Cdl0=CDe0451@@1F
EUH0D51@05UIF@1XJ6P0UYJF07inOP80Bd];0100H61P05MGE`1eMGD0GEeM02d];@18B4P0@D5103/k
>`1:BTX0>c/k05mOG`0k>c/0<c<c051@D01/K6`0De=C0P1aLG401@1gMgL0IVIV05QHF01[Jf/0Cdm?
0080PX:24Oooool000oooooo0:T0NWYj07QhN02b/[80A4A4065QH@1eMGD0`l?307]kN`10@400BDU9
07YjNP1aLG40[:b/06][J`0i>CT0LW9b07emO@1YJFT0JVYZ03De=@0l?3`0Ng]k07UiN@0l?3`0Fe]K
01/K6`1GEeL0J6QX02HV9P1DE5@0HV9R02/[:`0_;bl0KFe]02DU9@1>CTh0=CDe02d];@1_Kfl0Ng]k
01dM7@0O7al0?clo04i>CP24Q8@0?Cdm02HV9P0[:b/0?Shn04M7A`1HF5P0Xj>S02PX:00^;Rh0G5aL
04U9B@23Ph<0Ng]k02XZ:P0U9BD0?Shn06e]K@1FEUH0=3@d01XJ6P0Y:BT0KFe]06QXJ00l?3`0I6AT
038b<P0X:2P0CTi>05QHF011@D40EEEE02@T900[:b/0?Cdm05iNGP0^;Rh0>3Ph034a<@1FEUH0KVi^
06=SH`0Y:BT0=SHf04Y:BP0];Bd0KFe]07inOP0P8200<30`04A4A012@T80Fe]K09jNWP0T92@07alO
04=3@`1EEED0OGem0:JVYP0K6a/0?3`l04U9B@1UIFD0;Bd]05iNGP1=CDd0<C4a05ADE01oOgl092@T
05iNGP23Ph<0<c<c02TY:@1>CTh0=3@d04a<C01BDU80;2`/03`l?01iNGT0EEEE01lO7`0[:b/0DU9B
04E5A@2BTY80=CDe02LW9`0a<C40H61P069RHP1dM7@0WYjN02l_;`1DE5@0R8R805iNGP1bLW80G5aL
030`<010@400P82005ADE015ADD07alO04=3@`1]KFd0YJFU03Lg=`0l?3`0EEEE04=3@`0k>c/0MgMg
03<c<`0e=CD0BDU902l_;`0g=cL0NWYj06][J`0b<S80:2PX0080EeMG06@0Z:RX03Hf=P0J6QX0>c/k
04e=C@1?Cdl0OGem061PH00c<c<0E5AD05iNGP15ADD0SXj>08b<S00U9BD0B4Q806a/K01JFUX0MWIf
01/K6`10@400NGUi06YZJP1KFe/0QXJ604m?C`0_;bl0Fe]K02l_;`10@400R8R803De=@0^;Rh0MGEe
04E5A@18B4P0>3Ph05aLG021PH40@T9203@d=01HF5P0<30`07inOP2_[jl0=CDe04M7A`15ADD0N7Qh
0<30`01;Bd/0=3@d05EEE@1GEeL0EEEE08B4Q01GEeL0B4Q806IVIP1[Jf/0EEEE08Z:RP0d=3@0=CDe
0492@P1ADE40QhN707=cL`0a<C40Bd];04Y:BP2JVYX0GemO04M7A`1MGEd0=3@d061PH01mOGd0?Cdm
04Q8B01XJ6P08b<S030`<01LG5`0OWin04I6AP1LG5`08B4Q030`<027QhL0H61P02XZ:P16ATH0DE5A
04E5A@24Q8@0O7al02l_;`0[:b/0C4a<0P1DE5@04@2NWYh0<c<c03@d=01HF5P0Cdm?05IFEP2EUID0
>SXj01`L701=CDd0LW9b04Y:BP1EEED0820P01TI6@1=CDd0Lg=c01cooooo02H0IfMW069RHP1VIVH0
ATI605YJFP2<S8`0O7al06EUI@1oOgl0SHf=08n?S`1ADE40CTi>04e=C@1ZJVX0OGem08>3P`1dM7@0
A4A405EEE@1JFUX0Fe]K04=3@`1EEED0GemO04Q8B01;Bd/0@41005ADE00h>3P0G5aL061PH00l?3`0
BTY:05QHF01`L700QXJ607QhN080OGem01l0Bd];03dm?@1HF5P0EEEE0410@00P8200CDe=04a<C013
@d<0?Cdm03Lg=`16ATH0Ng]k0492@P1DE5@0;Bd]030`<01MGEd0LW9b04Y:BP11@D40A4A4079bLP1M
GEd0BTY:04m?C`1CDe<0BDU903/k>`1QHF40NGUi0080IfMW0=T0FEUI05ADE01?Cdl0@D5104e=C@0n
?Sh0BDU907UiN@1GEeL0?3`l05]KF`0/;2`0;Rh^03Lg=`0_;bl0=cLg02TY:@1BDU80;2`/01HF5P12
@T80De=C02l_;`0c<c<0BTY:05IFEP0[:b/0ATI604U9B@0[:b/0ATI605=CD`1ADE40C4a<05YJFP17
AdL0IFEU05mOG`1@D500KVi^08:2PP2DU9@0YJFU061PH01OGel0PH6105UIF@1ADE40E5AD03hn?P1K
Fe/0?Shn06EUI@1DE5@0M7Ad06e]K@1BDU80D51@05UIF@2JVYX0TI6A055AD@1QHF40GEeM03Xj>P1I
FET0IfMW051@D012@T80HF5Q0451@@0n?Sh0>CTi05aLG013@d<0BTY:08R8R01PH600@T9205ADE013
@d<0GEeM06ATI01OGel0K6a/051@D01/K6`0Fe]K065QH@27QhL0C4a<0410@01^KVh0Bd];0820P01H
F5P0De=C02d];@1?Cdl0Bd];03<c<`17AdL0=SHf03@d=01<C4`0CTi>03Lg=`0[:b/0@d=303hn?P0Z
:RX0ATI605QHF010@400DE5A051@D013@d<0ADE504A4A01RHV80FEUI06ATI00_;bl0@d=306i^KP1G
EeL0<S8b04i>CP0j>SX0DE5A05eMG@1DE5@0B4Q804a<C01TI6@0EEEE09JFUP2BTY80>SXj04M7A`1A
DE40ADE505]KF`0k>c/0G5aL06MWI`0g=cL0>SXj03dm?@0];Bd0@d=30451@@17AdL0Fe]K04Y:BP29
RHT0>SXj0492@P1KFe/0;Rh^07emO@12@T80K6a/07moO`1GEeL0RHV906ATI01<C4`0ZJVY04U9B@1R
HV80FEUI0;Rh^01FEUH0@T92051@D010@400ATI606e]K@1PH600ADE505]KF`14A4@0Cdm?0820P00l
?3`0De=C059BDP1?Cdl0L71`06=SH`1hN7P0JVYZ055AD@1IFET0ATI604E5A@21PH40HV9R03dm?@13
@d<0>SXj04Y:BP0j>SX0@41004I6AP1ADE40GUiN061PH01LG5`0RXZ:079bLP1TI6@0KVi^059BDP1[
Jf/0Z:RX017ooooo000?ooooo`0d069RHP1EEED0FUYJ05eMG@1FEUH0CTi>08V9R@2TY:@0GUiN069R
HP1<C4`0De=C05UIF@1TI6@0=CDe03/k>`1;Bd/0IVIV06a/K00_;bl0>3Ph05UIF@1PH600Fe]K096A
T@0O7al0BTY:04];B`1FEUH0Ph>30:n_[`0a<C40=3@d05EEE@1cLg<0^;Rh07emO@0J6QX0ATI605eM
G@18B4P0IVIV0:FUY@0f=SH0BDU9051@D015ADD0IFEU05iNGP0V9RH0:RXZ0410@080BTY:05<0:2PX
034a<@1@D500HF5Q030`<00e=CD0IfMW02TY:@0o?cl0EeMG01dM7@0a<C40>c/k02l_;`0j>SX0O7al
06e]K@0F5QH0<C4a05ADE01RHV80YZJV03dm?@0T92@0ATI605QHF013@d<0Ti>C059BDP0d=3@0BTY:
04A4A00h>3P0EUIF07moO`0O7al0<S8b05=CD`12@T80P82005iNGP0O7al09BDU04m?C`1eMGD0:2PX
071`L00b<S80ATI606i^KP1=CDd0<C4a05]KF`0h>3P0=CDe07YjNP20P8009bLW04E5A@1SHf<0Bd];
07YjNP2HV9P0:2PX0410@01DE5@0GemO08Z:RP2>SXh0:RXZ028R8P0e=CD0C4a<04i>CP1^KVh0K6a/
01lO7`0Z:RX0@D51034a<@1]KFd0BDU9018B4P0204M7A`2G03Ph>01>CTh0;bl_02DU9@1/K6`0NWYj
02LW9`0m?Cd0BDU904i>CP1UIFD0;Bd]02PX:013@d<0PX:2059BDP2?Shl0RHV902h^;P0X:2P0FUYJ
04i>CP23Ph<0QHF5030`<00P8200=cLg07IfMP1KFe/0P82006=SH`0c<c<0IfMW08:2PP0d=3@0RHV9
04M7A`0g=cL0A4A405YJFP0m?Cd0M7Ad02XZ:P0/;2`0>CTi05aLG015ADD0@d=30<?3``0j>SX0PH61
03`l?00o?cl0IVIV04m?C`1IFET0XJ6Q08J6QP0Z:RX0@D51055AD@1NGUh0alO704Y:BP11@D40FUYJ
059BDP1gMgL0BTY:03/k>`1EEED0EUIF06IVIP2NWYh0:BTY0451@@1VIVH0De=C06IVIP0T92@0>SXj
07]kN`1^KVh0?Cdm08:2PP0Y:BT08b<S05YJFP1iNGT0HV9R05ADE00R8R80B4Q80861P@24Q8@0>c/k
07UiN@0[:b/0E5AD07EeM@1:BTX08b<S04a<C017AdL0DE5A04a<C01_Kfl0>SXj05ADE01:BTX0<C4a
07YjNP2IVIT0:b/[03`l?018B4P0@T9208R8R02@T900:b/[03/k>`14A4@0CTi>05QHF02FUYH0SXj>
02HV9P11@D40DU9B04E5A@1mOGd0G5aL01LG5`13@d<0DE5A05ADE00m?Cd0:2PX01hN7P0[:b/0ADE5
06QXJ00^;Rh0@T9203<c<`0T92@0A4A40492@P0J6QX0>3Ph03De=@0Looooo`180:ZZZP2NWYh0QXJ6
04A4A01XJ6P0L71`06a/K01`L700AdM705iNGP1HF5P0DU9B06a/K01JFUX0Ogmo07inOP24Q8@0F5QH
05IFEP1UIFD0>SXj05eMG@1HF5P0DU9B04=3@`1;Bd/0CDe=04m?C`1@D500=CDe04M7A`1>CTh0>c/k
05]KF`1CDe<0?Shn055AD@1`L700/K6a0861P@18B4P0EEEE04i>CP11@D40>SXj03Ph>01;Bd/0@T92
03Xj>P1>CTh0@D5103lo?`1?Cdl0@D5104Y:BP16ATH0E5AD04i>CP19BDT0Cdm?06a/K01EEED0Bd];
0451@@0k>c/0AdM702`/;010@400Cdm?05iNGP1HF5P0CTi>0P1EEED204M7A`0L03/k>`0d=3@0?Cdm
03lo?`0J6QX0C4a<04=3@`0_;bl0:b/[04E5A@0V9RH0:RXZ04];B`0c<c<0@d=303Hf=P0Q8B4092@T
04Q8B010@400;Rh^01LG5`11@D40A4A403/k>`0_;bl0@d=304U9B@80>c/k09L0>3Ph04Y:BP1UIFD0
Cdm?03<c<`11@D40GEeM07AdM020P800Lg=c05iNGP1FEUH0JVYZ07=cL`0i>CT0@T9203Hf=P14A4@0
AdM704U9B@1JFUX0GEeM096AT@1/K6`0JFUY05iNGP0o?cl0?Shn04=3@`1<C4`0G5aL0451@@1jNWX0
KFe]04Q8B00f=SH0A4A40492@P19BDT0;Rh^02l_;`1IFET0EeMG04e=C@0m?Cd0ADE505YJFP1hN7P0
GUiN02<S8`0_;bl0HF5Q04m?C`1XJ6P0<c<c07IfMP2ZZZX0H61P0410@01IFET0HF5Q08V9R@1HF5P0
KFe]0451@@1_Kfl0ADE50451@@1<C4`0F5QH05ADE01CDe<0B4Q804M7A`15ADD0A4A403Lg=`0f=SH0
DU9B04m?C`0X:2P0Cdm?03Lg=`0o?cl0<c<c03/k>`1BDU807QhN05MGE`1IFET030`<065QH@13@d<0
9bLW03lo?`0l?3`0>CTi059BDP1WIfL0CTi>065QH@1kNg/0De=C04Q8B01?Cdl06a/K06YZJP1aLG40
>SXj06UYJ@1GEeL0GEeM06e]K@1CDe<0CDe=0492@P15ADD0FEUI04A4A01RHV80U9BD05eMG@2ATI40
8b<S04=3@`1OGel0<C4a08V9R@13@d<0Lg=c07]kN`0`<300XJ6Q07MgM`1cLg<0R8R806a/K01bLW80
@D5107EeM@1FEUH0@D5105ADE00c<c<0;Rh^03Ph>00d=3@0?clo05QHF00X:2P0BDU90080@d=301l0
JVYZ05=CD`1XJ6P0GEeM06QXJ02HV9P0GEeM06MWI`1NGUh0N7Qh03De=@0c<c<0BTY:03lo?`1=CDd0
EEEE03hn?P0i>CT0E5AD04m?C`1NGUh0T92@07moO`1OGel0[Jf]07AdM01ZJVX0/K6a05mOG`2>SXh0
[:b/017ooooo000?ooooo`0F09BDU01@D500F5QH06UYJ@2FUYH0<c<c075aL@2MWId0G5aL0:VYZ@1^
KVh0@D5104i>CP1[Jf/0D51@04e=C@0W9bL0K6a/08>3P`17AdL0LG5a09bLW080=3@d0?l0MgMg03hn
?P1QHF40CDe=01`L701GEeL0VYZJ069RHP16ATH0@D5102@T901EEED0WYjN055AD@1?Cdl0GemO01/K
6`0[:b/0J6QX04];B`1<C4`0?Cdm028R8P1QHF40OGem038b<P1:BTX0IfMW05UIF@1UIFD0?clo01HF
5P11@D40FEUI06ATI01QHF40]kNg04=3@`0j>SX0@T9205eMG@2_[jl0_Kfm024Q8@0f=SH0>CTi04I6
AP1DE5@0G5aL02PX:01<C4`0GemO06UYJ@0e=CD0ATI603De=@0T92@0;bl_05mOG`0e=CD0MWIf03dm
?@0X:2P0L71`09JFUP0b<S80:b/[03/k>`0i>CT0RXZ:08f=S@0Q8B40;bl_030`<01WIfL0C4a<09NG
U`0_;bl0=cLg05mOG`1_Kfl0O7al08R8R00n?Sh06a/K06QXJ01eMGD0CTi>08n?S`0c<c<06a/K05]K
F`1ZJVX0@D5105iNGP2UYJD0;2`/04M7A`1fMWH0?Shn03Hf=P16ATH0;Rh^01TI6@1kNg/0_;bl03Ti
>@1=CDd0:BTY02l_;`2GUiL0]KFe02HV9P0];Bd0ADE503Xj>P2EUID0GemO02LW9`0m?Cd0KVi^04M7
A`27QhL0QHF501LG5`1DE5@0C4a<04Q8B01mOGd0BTY:01lO7`1BDU80L71`04a<C00T92@0CDe=01TI
6@16ATH0KFe]04i>CP0g=cL0EUIF02l_;`0W9bL0KVi^07IfMP0Z:RX0=cLg03hn?P15ADD0T92@08>3
P`0P8200=cLg04];B`1IFET0Y:BT05EEE@0X:2P0B4Q8059BDP1IFET0NWYj0:NWY`0k>c/0RHV904m?
C`1XJ6P0[jn_02/[:`0g=cL0JFUY096AT@14A4@0G5aL02PX:00m?Cd0JVYZ07IfMP1:BTX0K6a/02HV
9P1MGEd0F5QH061PH01]KFd0:2PX03dm?@1mOGd0IFEU05IFEP1NGUh0;Rh^05eMG@1OGel0;Bd]05UI
F@17AdL0L71`0;Bd]00o?cl08B4Q03/k>`1ADE40UYJF08J6QP0U9BD0>c/k05UIF@1`L700Jf][0;Vi
^@14A4@0?clo05ADE01GEeL0K6a/0:j^[P1OGel0:BTY055AD@1?Cdl0Hf=S0<?3``0o?cl0>3Ph0451
@@1[Jf/0KVi^06ATI02DU9@0;Bd]03Ph>023Ph<0BDU904e=C@1LG5`0;Rh^030`<01CDe<0G5aL03@d
=01iNGT0;Bd]0451@@1IFET0IFEU03/k>`0W9bL0G5aL04U9B@1YJFT0FUYJ01<C4`0];Bd000/0BTY:
05ADE01<C4`0SHf=07]kN`0K6a/0@d=3069RHP0i>CT0MGEe04=3@`0Looooo`1304E5A@1KFe/0NGUi
05mOG`11@D40Cdm?05QHF01IFET0KFe]0;Jf]P1mOGd0@d=304E5A@1IFET0MGEe055AD@1VIVH0H61P
051@D01GEeL0BDU905MGE`1<C4`0De=C05MGE`1YJFT0I6AT03`l?01:BTX0>SXj0820P01VIVH0<C4a
05iNGP1[Jf/0E5AD05iNGP29RHT0Z:RX06IVIP10@400DE5A04a<C01:BTX0CDe=05UIF@1UIFD0@410
05ADE01VIVH0E5AD02@T900c<c<0Bd];05eMG@0R8R80<C4a04i>CP1?Cdl0CTi>0492@P0S8b<0@D51
04i>CP1?Cdl0>CTi03hn?P02059BDP0=04i>CP1GEeL0I6AT05QHF01:BTX0?Cdm03hn?P16ATH0CTi>
04=3@`15ADD0=CDe03Ph>00203Ti>@0O030`<00g=cL09bLW02PX:010@400ADE503Ti>@0/;2`0820P
03De=@0k>c/0<c<c02d];@0e=CD0?clo03Ti>@0l?3`0?clo0451@@0m?Cd0?Shn05mOG`1NGUh0GEeM
02l_;`1<C4`0Cdm?04U9B@1WIfL0N7Qh09FEU@0208f=S@0707QhN01LG5`0C4a<03Hf=P10@40092@T
0492@P0204U9B@1a04Y:BP1DE5@0?Shn05]KF`1EEED0ATI60820P01fMWH0Cdm?09^KV`1hN7P0<c<c
0410@01<C4`0Cdm?02/[:`0c<c<0MWIf07alO01;Bd/0DU9B04Q8B013@d<0PX:2071`L01YJFT0DU9B
02`/;00k>c/0DE5A04U9B@1:BTX0@D5109ZJVP0k>c/0C4a<08B4Q01KFe/0GUiN0820P018B4P0NGUi
06=SH`1cLg<07alO051@D019BDT0Fe]K06UYJ@0Z:RX0;Rh^04Q8B01GEeL06a/K02LW9`1:BTX0?Shn
05IFEP1XJ6P0L71`03lo?`1@D500ATI604];B`11@D40?3`l05IFEP0_;bl0IfMW04U9B@0n?Sh0GemO
03dm?@1<C4`0A4A404E5A@0j>SX0Fe]K05ADE01aLG40H61P07EeM@0^;Rh0Jf][06MWI`0I6AT0<30`
055AD@1cLg<0V9RH05EEE@1RHV80Rh^;038b<P0i>CT0HF5Q03Ph>013@d<0F5QH04I6AP1@D500CDe=
0:^[Z`13@d<0Ng]k07inOP0F5QH0JFUY01DE5@25QHD0MgMg04];B`1XJ6P00P1VIVH0<@1cLg<0?3`l
04];B`0c<c<0Jf][05UIF@16ATH0Shn?05aLG00^;Rh0Cdm?038b<P0i>CT0DU9B04M7A`1OGel0DU9B
03De=@0m?Cd0GUiN06YZJP2ATI40Hf=S07moO`28R8P0N7Qh08n?S`22PX80@d=304];B`1MGEd0JVYZ
07=cL`16ATH0?Shn03Lg=`1BDU80I6AT06=SH`1RHV80Ogmo079bLP1iNGT0Ph>308B4Q02BTY80Bd];
06=SH`2h^;P04Oooool000oooooo0280UiNG055AD@1mOGd0@410096AT@1QHF40FUYJ04U9B@0c<c<0
Fe]K07IfMP0h>3P0CDe=04];B`1=CDd0X:2P03Xj>P0e=CD0EUIF03hn?P1RHV80PH6102h^;P0J6QX0
D51@07UiN@1fMWH0EEEE01HF5P0U9BD0CTi>05eMG@1TI6@0MgMg0P0Y:BT0oP1ZJVX0GUiN08N7Q`1k
Ng/08R8R04A4A016ATH0BDU907]kN`0^;Rh04a<C03dm?@1aLG40F5QH07AdM03=cLd07AdM059BDP1[
Jf/0BDU906QXJ00m?Cd092@T0451@@1KFe/0C4a<0492@P0h>3P05ADE06ATI02PX:00EEEE01LG5`1@
D500ATI601`L701]KFd08B4Q02/[:`1:BTX0?Cdm04i>CP2GUiL0Bd];02DU9@0W9bL0BDU906=SH`2g
]kL0G5aL01DE5@0/;2`0Fe]K05YJFP1[Jf/0EEEE01LG5`0e=CD0IfMW055AD@1NGUh0NGUi01`L700T
92@0Cdm?055AD@1JFUX0KFe]010@400i>CT0SXj>05QHF00F5QH0GEeM03Ti>@11@D40Y:BT05ADE00D
51@0CTi>05MGE`0o?cl0KFe]0:FUY@0i>CT0De=C04Y:BP1PH600LW9b08n?S`0f=SH0;bl_04=3@`1Y
JFT0NWYj09^KV`0k>c/071`L034a<@1_Kfl0ADE507alO01]KFd09BDU04A4A02<S8`0=SHf07inOP0d
=3@07QhN03/k>`2CTi<0?Cdm03lo?`0b<S80@D51069RHP21PH40>c/k02`/;01DE5@0?Shn03De=@2?
Shl0;2`/03@d=01?Cdl0EEEE06ATI02@T900?Cdm01lO7`0X:2P0ADE506a/K02BTY806ATI02DU9@0_
;bl0Jf][0410@01LG5`0@41002d];@1;Bd/0GUiN02TY:@1=CDd0@D51028R8P17AdL0Kfm_0492@P1E
EED0:2PX05IFEP1PH600Bd];02d];@1TI6@0>3Ph04e=C@2BTY807AdM03<c<`1DE5@0?3`l071`L02>
SXh092@T03/k>`15ADD0]KFe09fMW@0X:2P0;Bd]069RHP1PH600Ti>C08j>SP0f=SH0Bd];05MGE`1h
N7P0[Zj^0451@@0f=SH0HF5Q06IVIP14A4@0J6QX02PX:00n?Sh0QXJ604Y:BP1GEeL0Kfm_02TY:@0U
9BD0CTi>05UIF@0h>3P0@D5102LW9`0[:b/0F5QH0:>SX`0l?3`0C4a<05MGE`0Y:BT0LW9b06UYJ@0U
9BD0Cdm?03lo?`0l?3`0BTY:08F5Q@19BDT0<S8b0410@01ADE40VIVI092@T00X:2P06QXJ055AD@1j
NWX0HV9R0=?Cd`0o?cl0<30`06IVIP1>CTh0CDe=04m?C`1nOWh0?clo03dm?@1^KVh0Cdm?05MGE`1n
OWh0;Bd]01dM7@11@D40DE5A03<c<`1EEED04a<C03@d=01eMGD0GEeM7?ooool0=`2<S8`0SXj>05QH
F019BDT0L71`06a/K01=CDd0BDU905UIF@1WIfL0R8R805QHF01>CTh0Ph>308j>SP2HV9P0UYJF08J6
QP1HF5P0JVYZ06e]K@1OGel0FEUI069RHP1fMWH0GemO06ATI01;Bd/0FUYJ0492@P19BDT0Kfm_038b
<P1HF5P0IVIV079bLP2:RXX0U9BD08b<S01iNGT0DU9B04Y:BP1/K6`0DE5A05MGE`0^;Rh0IVIV04A4
A01ADE40AdM705eMG@10@400A4A403lo?`1?Cdl00P0a<C402P1LG5`0Jf][04a<C012@T80?3`l06YZ
JP1;Bd/0;Rh^04i>CP1OGel204A4A00T05IFEP21PH40Shn?03/k>`0g=cL0DE5A04];B`0i>CT09BDU
03Ti>@1>CTh0IFEU05iNGP0o?cl0De=C02l_;`0b<S80>CTi02LW9`0c<c<0;Bd]04Y:BP0Z:RX07alO
0410@01EEED0>c/k04I6AP1CDe<0FEUI02DU9@10@400AdM702DU9@0f=SH0<S8b0P0i>CT0A00n?Sh0
ATI60492@P1>CTh0BDU904E5A@1UIFD0V9RH06QXJ00a<C40?clo05aLG01cLg<0:RXZ03Lg=`10@400
=cLg03@d=010@400L71`06EUI@1KFe/0GEeM07EeM@1BDU80@T9204M7A`16ATH0?3`l05IFEP0g=cL0
B4Q805YJFP1VIVH0De=C05UIF@0k>c/0=3@d02l_;`0e=CD0K6a/06MWI`1MGEd0@d=303lo?`1ADE40
Hf=S05]KF`1@D500NWYj09NGU`19BDT0ATI6020P801WIfL0^[Zj05IFEP0b<S80D51@04A4A01cLg<0
BTY:055AD@0R8R80C4a<03Ph>00X:2P0?Cdm0`1=CDd0;@0e=CD0>c/k03Ph>01<C4`0>c/k03<c<`1@
D500B4Q805QHF020P800HF5Q04];B`1JFUX0MWIf08R8R01<C4`0L71`03<c<`0^;Rh0QHF504E5A@0Q
8B40<c<c04e=C@10@400D51@04a<C018B4P0DE5A06i^KP10@400QXJ607moO`0c<c<0BTY:04a<C015
ADD0LW9b06UYJ@1HF5P0Fe]K04I6AP0i>CT0=SHf03Ti>@0204I6AP0G059BDP1SHf<0IVIV09:BTP0g
=cL0?clo04e=C@0h>3P0QhN7038b<P26QXH0RHV9061PH01^KVh0GUiN055AD@2CTi<0?clo05IFEP0Z
:RX0EEEE06EUI@1QHF400P19BDT0:012@T80LW9b055AD@12@T80=cLg02<S8`0g=cL0L71`05IFEP1P
H600M7Ad06MWI`23Ph<0IFEU0;:b/P20P800GemO05=CD`1UIFD0DE5A06QXJ01;Bd/0<S8b0492@P15
ADD0D51@03<c<`0m?Cd0GEeM075aL@1LG5`0RHV906EUI@22PX80Kfm_05mOG`2PX:00IfMW07inOP32
`/8Aooooo`003oooool0l`2=SHd0T92@0;:b/P11@D40Jf][06YZJP2WYjL0MGEe0410@017AdL0MGEe
05EEE@2^[Zh0FUYJ03`l?01>CTh0GEeM07emO@26QXH06a/K069RHP1PH600EUIF04m?C`1[Jf/0<c<c
07AdM01iNGT0D51@09BDU01@D500=SHf06m_K`1]KFd0De=C069RHP0F5QH09bLW04A4A01RHV80<c<c
0451@@1OGel0>SXj06IVIP1SHf<0;bl_03hn?P1:BTX0;Rh^05UIF@2SXj<0HF5Q04I6AP11@D40@410
0:f][@1aLG40820P02TY:@1BDU80FUYJ06m_K`0a<C40;Bd]01`L701@D500P82004U9B@1[Jf/0C4a<
01LG5`12@T80EeMG03dm?@2<S8`0820P02TY:@0b<S80NGUi05MGE`1_Kfl0@41001hN7P0m?Cd0JVYZ
038b<P13@d<0Bd];014A4@1BDU80Fe]K02<S8`0b<S80=cLg02d];@1SHf<0VYZJ02l_;`0E5AD0?clo
0410@01kNg/0Zj^[024Q8@0C4a<0<c<c059BDP0l?3`0/;2`06QXJ00W9bL0CTi>075aL@0l?3`0/;2`
05iNGP0N7Qh0=3@d04e=C@18B4P0K6a/08J6QP0G5aL0ATI606m_K`1XJ6P09RHV071`L01HF5P0;Bd]
08R8R01PH6007AdM04=3@`0f=SH0:b/[07AdM02:RXX092@T03<c<`1>CTh0C4a<0<S8b01CDe<061PH
02HV9P1bLW80?clo06m_K`0S8b<0:BTY03hn?P2GUiL0LW9b07MgM`2CTi<0:BTY03lo?`1ZJVX0A4A4
05IFEP1QHF404a<C038b<P1NGUh0KFe]03De=@1ADE40@d=303Xj>P24Q8@0Bd];02XZ:P15ADD0>CTi
02TY:@1CDe<0DE5A02DU9@1DE5@0?Cdm03hn?P24Q8@0J6QX02d];@1:BTX0J6QX04i>CP1oOgl0<C4a
030`<01PH600IFEU06ATI02YZJT0Cdm?018B4P1SHf<0IFEU055AD@1oOgl0<C4a02l_;`2EUID0@T92
069RHP0a<C40A4A4092@T00g=cL0?clo05QHF00W9bL0;2`/05mOG`1GEeL0De=C03<c<`0b<S80L71`
04e=C@0f=SH0F5QH02DU9@1DE5@0U9BD04=3@`0b<S80BTY:03/k>`2JVYX0PX:203lo?`0e=CD0Cdm?
04];B`1dM7@0Ogmo02DU9@0g=cL0>3Ph05eMG@0206QXJ00]09^KV`0W9bL0K6a/06i^KP0/;2`0Ogmo
04=3@`0Z:RX0=SHf06a/K01hN7P0E5AD0410@00b<S80>SXj07YjNP1MGEd0:2PX0451@@12@T80?Shn
05mOG`1VIVH0;bl_04Y:BP10@400BTY:07UiN@2DU9@0B4Q803<c<`0h>3P09BDU05=CD`2KVi/0>c/k
020P800/;2`0A4A404=3@`1gMgL0:RXZ01DE5@16ATH0NGUi01cooooo02P0G5aL06][J`1VIVH0A4A4
05iNGP1oOgl0O7al07AdM02UYJD0^;Rh0:j^[P20P800NGUi08f=S@2HV9P0RHV907QhN01]KFd0NGUi
07MgM`1:BTX0E5AD069RHP1GEeL0EUIF06e]K@1SHf<0EeMG07YjNP1PH600Fe]K07YjNP1BDU80MWIf
07MgM`1hN7P0TY:B08N7Q`3:b/X0UiNG0P1CDe<0A@1[Jf/0JFUY05mOG`10@400PX:204a<C01MGEd0
F5QH08>3P`1CDe<0GEeM04U9B@22PX80<30`03Xj>P1WIfL0DE5A07EeM@1FEUH0HV9R05ADE01>CTh0
<c<c05=CD`11@D40D51@04U9B@20P800De=C04Y:BP1DE5@0DE5A0410@01?Cdl0EeMG03De=@13@d<0
Cdm?02<S8`1?Cdl0?Cdm03@d=00S8b<0=SHf028R8P0M7Ad0@41002l_;`0k>c/0<30`01@D500^;Rh0
Cdm?03<c<`0X:2P0?clo04e=C@0o?cl0>3Ph0410@00i>CT0B4Q804M7A`12@T80?Shn04e=C@1IFET0
Bd];02DU9@0204];B`0Y04M7A`0l?3`0@d=304m?C`1LG5`0A4A403lo?`0a<C40<S8b02HV9P14A4@0
?3`l04Y:BP0g=cL0FEUI07EeM@1[Jf/0;Rh^03@d=01KFe/0IFEU04e=C@2=SHd0S8b<02`/;01;Bd/0
DU9B0451@@0i>CT0<30`05eMG@22PX80GEeM03De=@0h>3P0;Bd]05UIF@1YJFT0JVYZ06ATI00k>c/0
0P10@400H@0g=cL0Bd];04=3@`20P80071`L0861P@3;bl/0IFEU03<c<`1KFe/0?clo08V9R@1NGUh0
F5QH02XZ:P1_Kfl0?clo03hn?P1@D500?3`l05IFEP1EEED0?clo02/[:`0l?3`0:b/[03Xj>P10@400
EEEE05aLG00f=SH0?clo02d];@0k>c/0BTY:03`l?01BDU80?Cdm06UYJ@1QHF406ATI04Q8B00n?Sh0
;bl_04A4A010@400ADE5055AD@1@D500DU9B05]KF`1kNg/0>c/k05EEE@1QHF40>CTi04=3@`1>CTh0
DE5A07UiN@1VIVH0KFe]06ATI011@D40De=C04a<C01;Bd/0H61P04i>CP1:BTX0T92@079bLP2CTi<0
?Cdm05EEE@1LG5`0=CDe08N7Q`12@T80LW9b06MWI`18B4P0X:2P06IVIP1FEUH0Ph>304i>CP1]KFd0
EUIF0<30`01EEED0@d=305UIF@15ADD0E5AD07emO@1CDe<00P14A4@08`0U9BD0ADE506=SH`1UIFD0
GUiN06e]K@1<C4`0R8R805ADE033`l<0I6AT05iNGP1FEUH0N7Qh02HV9P0c<c<0B4Q80410@01=CDd0
:RXZ03Xj>P0`<3008b<S04I6AP1JFUX0MGEe07MgM`1YJFT0[:b/07inOP1lO7`0/[:b05QHF01cLg<0
cLg=017ooooo000?ooooo`0P06e]K@1GEeL0Lg=c06m_K`1iNGT0ADE5059BDP1dM7@0HF5Q08F5Q@1O
Gel0<S8b04=3@`1@D500HV9R0492@P0`<300Fe]K06a/K01=CDd0NGUi07]kN`0h>3P0BTY:06m_K`19
BDT0Ng]k04E5A@10@400IFEU07alO00c<c<204=3@`2k05EEE@2SXj<0NGUi03Ph>01GEeL0ADE50410
@01WIfL0OWin038b<P1NGUh0?Shn055AD@1WIfL0QHF502PX:018B4P0JVYZ04i>CP1UIFD0CTi>028R
8P0o?cl0KFe]04Q8B01ADE40S8b<03dm?@0e=CD0IVIV04Q8B01SHf<0Ph>302`/;00b<S80?3`l04m?
C`0h>3P0GEeM02XZ:P15ADD0Kfm_05=CD`0j>SX0IfMW04=3@`0/;2`0ADE504e=C@0V9RH0FUYJ0410
@00n?Sh0IVIV06ATI00N7Qh0820P04Y:BP0j>SX0KFe]055AD@0N7Qh0<30`04i>CP1KFe/0=cLg07mo
O`0R8R80=CDe06=SH`1UIFD0?clo079bLP0a<C4071`L04Q8B01LG5`0>c/k05iNGP0T92@0:RXZ07Ui
N@1fMWH0<c<c03lo?`1CDe<0>3Ph071`L02KVi/0ATI602@T9017AdL0<C4a03lo?`21PH40NGUi02l_
;`1NGUh0=3@d03Ti>@23Ph<0IFEU02@T9015ADD0GEeM05=CD`1/K6`0;bl_03@d=01DE5@0JVYZ04A4
A01FEUH0Fe]K02l_;`1BDU80Jf][04U9B@1hN7P0<C4a02l_;`1HF5P0QhN705=CD`16ATH0?clo03Ti
>@1KFe/0U9BD07]kN`0g=cL0NWYj03hn?P0o?cl0MWIf07emO@0k>c/0FUYJ03dm?@17AdL0NWYj05UI
F@0b<S80?Shn05IFEP1IFET0QhN704U9B@0/;2`0DE5A05eMG@0l?3`0Rh^;08f=S@0n?Sh0F5QH04U9
B@1LG5`0Ogmo038b<P0f=SH0NGUi09:BTP1;Bd/0IfMW03Xj>P1HF5P0UIFE05mOG`1UIFD0DE5A03`l
?020P800F5QH051@D01GEeL0?Cdm06QXJ02o_kl0EUIF04U9B@1GEeL0BTY:06ATI01IFET0@41005iN
GP02051@D00Q0:BTY01IFET0<S8b05iNGP1@D500HF5Q06UYJ@0W9bL0ATI606=SH`1JFUX0De=C08j>
SP0l?3`0BTY:06a/K01CDe<0GemO07MgM`0l?3`0=SHf051@D01CDe<0EeMG06i^KP0e=CD0>c/k04m?
C`1JFUX0;Rh^059BDP1dM7@0?Cdm0080GUiN0200;bl_04m?C`1SHf<0<C4a0451@@1UIFD0Hf=S03Hf
=P1PH600A4A403Ti>@1iNGT0IVIV02DU9@0g=cL0B4Q804U9B@1JFUX0E5AD024Q8@0Y:BT0De=C06AT
I01FEUH0MWIf03`l?00J6QX0>CTi05]KF`13@d<0LW9b04i>CQcooooo01L0RHV9092@T02=SHd0K6a/
06i^KP1gMgL0JFUY05mOG`2=SHd0[Zj^09>CT`1=CDd0AdM707]kN`1oOgl0S8b<08R8R02ATI40Fe]K
07QhN01QHF40ADE505MGE`0206m_K`1@05UIF@1]KFd0B4Q8051@D01FEUH0H61P08Z:RP0j>SX0LW9b
0861P@1iNGT0QHF50:b/[038b<P0QhN704M7A`1MGEd0J6QX0451@@1EEED0AdM706IVIP16ATH0G5aL
05UIF@1YJFT0>3Ph04=3@`1BDU80K6a/0492@P14A4@0L71`06QXJ01cLg<0GemO05MGE`1cLg<0Fe]K
04=3@`1NGUh0HF5Q05YJFP1BDU80JVYZ07QhN01nOWh0EeMG065QH@1WIfL0>c/k05UIF@1<C4`0@D51
05=CD`14A4@0EeMG0451@@1<C4`0<S8b03`l?00c<c<0:RXZ04A4A00i>CT0@D5103Lg=`0P8200?Cdm
055AD@0n?Sh0>CTi05QHF01GEeL0@d=304M7A`19BDT0?Cdm04i>CP16ATH2051@D01N05ADE012@T80
EeMG05UIF@1?Cdl0ADE5055AD@1BDU80GEeM04a<C01JFUX0IVIV05UIF@15ADD0Bd];030`<01IFET0
@d=305UIF@1>CTh0I6AT07=cL`21PH40KFe]05EEE@1VIVH0P8200410@011@D40CDe=02XZ:P1BDU80
F5QH04I6AP18B4P0CTi>0410@011@D40CTi>03`l?01HF5P0JFUY07IfMP1]KFd0?Cdm04E5A@1ADE40
GemO05]KF`1NGUh0MgMg03Hf=P1iNGT0;bl_07AdM02l_;`0GEeM03lo?`1KFe/0?Shn07MgM`1>CTh0
IfMW02/[:`1GEeL0=3@d02`/;015ADD0=cLg05IFEP16ATH0>c/k034a<@0n?Sh0?3`l0492@P0W9bL0
GUiN061PH014A4@0NGUi0492@P1KFe/0BDU904E5A@1LG5`0BDU906EUI@12@T809RHV06i^KP16ATH0
>3Ph0492@P80ADE500d0FEUI05=CD`1HF5P0FUYJ07EeM@1;Bd/0HF5Q06EUI@0_;bl0AdM705eMG@1K
Fe/0MgMg0080DE5A04P0L71`04A4A015ADD0EeMG04I6AP1ADE40GUiN05=CD`1HF5P0FUYJ09JFUP0j
>SX0Hf=S06ATI00M7Ad0JFUY02<S8`29RHT0Ph>305IFEP1bLW80O7al07AdM02@T900K6a/09FEU@1G
EeL0OGem05mOG`1GEeL0KVi^05QHF011@D40JFUY04E5A@1=CDd0IVIV0451@@1@D500Fe]K03hn?P1T
I6@0EEEE06EUI@1^KVh0ATI6096AT@1GEeL0FEUI05ADE02?Shl0;2`/04];B`1HF5P0BTY:065QH@0f
=SH0?Cdm04M7A`0h>3P0GEeM06EUI@1RHV80OWin05mOG`1dM7@0LG5a08V9R@26QXH0M7Ad07YjNP2h
^;PAooooo`003oooool0S024Q8@0S8b<0:6QX@16ATH0IVIV05]KF`1lO7`0=cLg03`l?01aLG40S8b<
05iNGP1eMGD0?3`l03Xj>P25QHD0?clo07AdM01RHV808R8R03hn?P1WIfL0@D51030`<00h>3P08b<S
06EUI@1TI6@07AdM03@d=00l?3`0@d=309>CT`1FEUH06QXJ04=3@`18B4P0H61P0:NWY`1>CTh061PH
030`<016ATH0BTY:09VIV@0W9bL06ATI04a<C01dM7@0@T9207emO@33`l<0820P03dm?@1WIfL0DE5A
06i^KP1PH60092@T051@D01gMgL0M7Ad06=SH`0a<C40=CDe0410@01KFe/0LW9b038b<P1lO7`0<S8b
02h^;P1MGEd0@d=303`l?01XJ6P09RHV03dm?@1CDe<0HV9R01hN7P18B4P0?3`l03Lg=`2ATI40OWin
01dM7@0o?cl0IfMW04E5A@1XJ6P0FEUI01lO7`1EEED0O7al0410@01JFUX0OGem014A4@0R8R80EUIF
05ADE01MGEd0EUIF014A4@0a<C40De=C05eMG@0l?3`0FUYJ03@d=00j>SX0O7al05QHF00[:b/0ATI6
04a<C00M7Ad0JVYZ09VIV@0_;bl0ADE504M7A`0`<300GEeM08B4Q00c<c<08B4Q05iNGP1WIfL0De=C
09jNWP0W9bL07AdM059BDP2NWYh0=cLg07IfMP16ATH09BDU0P1DE5@0AP1:BTX0OWin030`<00Q8B40
=SHf05aLG011@D40EeMG01PH600l?3`0DE5A03`l?00L71`0;bl_06=SH`0R8R80=SHf07emO@0M7Ad0
;bl_04E5A@0o?cl0DU9B0:ZZZP14A4@09BDU03Lg=`1NGUh0K6a/0:j^[P0/;2`0>SXj04=3@`1aLG40
CTi>0:FUY@1KFe/0ATI6065QH@1ZJVX0B4Q809^KV`1DE5@0CDe=06EUI@1nOWh0GemO05iNGP0L71`0
A4A408j>SP1XJ6P0=3@d05ADE00f=SH0>CTi07alO00/;2`0IVIV059BDP0j>SX0GemO08b<S00d=3@0
ADE503De=@1dM7@0Q8B401hN7P0j>SX205QHF00U07MgM`2KVi/0:BTY0492@P1LG5`0PX:20;no_`1Q
HF407QhN05mOG`1_Kfl0FEUI09BDU00o?cl0ADE505mOG`0m?Cd0LW9b08F5Q@0O7al0CTi>06=SH`1B
DU80GemO05=CD`0W9bL0AdM707AdM01VIVH0<30`0:^[Z`1CDe<0>3Ph07AdM01ZJVX0:2PX06][J`02
0410@00>04M7A`22PX80BDU90410@00n?Sh0:b/[06ATI02YZJT0BTY:02PX:01>CTh0C4a<06=SH`2T
Y:@202LW9`0E04e=C@1QHF40L71`07MgM`2EUID08R8R038b<P1^KVh0Bd];04E5A@2BTY80?3`l02DU
9@0o?cl0HV9R02PX:015ADD06QXJ01/K6`0k>c/0LW9b01cooooo03@0B4Q805QHF01aLG40HF5Q05MG
E`1dM7@0[:b/0:RXZ02i^KT0YJFU0;>c/`1FEUH0CDe=08b<S02LW9`0/;2`09VIV@1oOgl0DU9B0861
P@1WIfL0E5AD05EEE@1UIFD0BTY:04=3@`1UIFD0GUiN07emO@1VIVH0DU9B0:f][@1BDU80OWin07Mg
M`2OWil0[Zj^09fMW@33`l<0VYZJ05]KF`1NGUh0DU9B051@D01WIfL0@T9207YjNP11@D40K6a/04a<
C025QHD0AdM70P1ADE40@029RHT0;bl_03Hf=P1^KVh0EUIF07AdM010@400JVYZ05iNGP1FEUH0:2PX
05iNGP1BDU80KVi^04I6AP2FUYH0K6a/07=cL`1dM7@0Hf=S06IVIP12@T80Fe]K03Hf=P14A4@0GemO
03<c<`1PH600?3`l04];B`0/;2`0:b/[03Ph>00Z:RX0DU9B03Ph>01EEED0@41002TY:@11@D40KFe]
03Hf=P0a<C40A4A406QXJ00m?Cd0CTi>04Y:BP0l?3`0D51@04U9B@1>CTh0C4a<05IFEP1>CTh0Fe]K
0451@@1=CDd0Bd];0492@P0e=CD0?Cdm05QHF01hN7P206UYJ@2Z05EEE@1?Cdl0@d=305aLG01WIfL0
IVIV06][J`1_Kfl0VYZJ09JFUP2ATI40J6QX05MGE`1gMgL0N7Qh075aL@2>SXh0<S8b04Y:BP20P800
GemO04Y:BP18B4P0MGEe08>3P`1YJFT0DE5A06IVIP13@d<0HF5Q092@T02=SHd0IVIV0410@01_Kfl0
DE5A04Q8B01BDU80>3Ph09bLW00O7al0F5QH08j>SP1>CTh0<C4a05UIF@0h>3P0Cdm?0451@@1_Kfl0
3Ph>02h^;P0_;bl0ADE506IVIP0W9bL0;Rh^03De=@0j>SX06QXJ03<c<`0_;bl0?clo04M7A`2BTY80
Lg=c03@d=00i>CT0=cLg04A4A015ADD0E5AD07IfMP1FEUH0MGEe075aL@0`<300>CTi03`l?01:BTX0
C4a<02DU9@0f=SH0C4a<0451@@1MGEd0H61P06e]K@0g=cL0NWYj09nOW`1;Bd/0I6AT08F5Q@1<C4`0
CDe=07MgM`1XJ6P0IfMW061PH01CDe<0D51@059BDP1]KFd0B4Q804m?C`1QHF40KVi^0;Vi^@0S8b<0
Cdm?05iNGP1>CTh0Kfm_04I6AP1RHV80LG5a034a<@1eMGD0H61P07UiN@3Bd]80Ph>308b<S01TI6@0
YZJV08F5Q@1DE5@0JVYZ05mOG`1QHF40Kfm_03hn?P1CDe<0ATI602d];@0a<C40N7Qh03/k>`1_Kfl0
EeMG07=cL`2CTi<0GEeM0:ZZZP1PH600Fe]K055AD@2=SHd0EEEE092@T01WIfL0?3`l05=CD`1JFUX0
G5aL04Q8B00k>c/0ATI6069RHP24Q8@0SXj>07=cL`2n_[h0Vi^K08f=S@2ZZZX0D51@069RHP3:b/XA
ooooo`003oooool0o`1DE5@0EeMG09:BTP1ADE40IfMW07YjNP3<c<`0KFe]03Hf=P1EEED0D51@08:2
PP2l_;`0ADE503<c<`1:BTX0B4Q80;fm_@2<S8`0:RXZ03Ti>@10@400J6QX08^;R`1VIVH08B4Q05]K
F`1RHV80GEeM08N7Q`1_Kfl061PH038b<P18B4P0>CTi07IfMP0S8b<0:BTY03Ph>01]KFd0;bl_06IV
IP1XJ6P0=3@d07MgM`2ATI40?3`l03Xj>P1TI6@08R8R03Ti>@1RHV80BDU904A4A00k>c/09bLW05UI
F@1]KFd0820P02h^;P1QHF40?3`l05=CD`1?Cdl08R8R03/k>`11@D40H61P03dm?@1^KVh0HV9R01hN
7P11@D40KFe]05QHF02:RXX06QXJ02d];@1LG5`0QHF50451@@22PX80BTY:02DU9@1CDe<0MgMg034a
<@1HF5P0=cLg01TI6@0e=CD0B4Q801lO7`0f=SH0<c<c02TY:@1:BTX0EUIF02`/;00F5QH0=cLg01lO
7`2@T900VIVI01@D500X:2P0DE5A03Hf=P1=CDd0^;Rh0:NWY`0d=3@0EEEE055AD@13@d<0[jn_09BD
U00E5AD0=SHf03Ph>01<C4`0Ph>306a/K00J6QX0:b/[04];B`1KFe/0<C4a07EeM@1LG5`0;2`/06EU
I@1@D500;2`/05ADE00V9RH0?Cdm06=SH`1cLg<09BDU03Ph>00l?3`0CDe=08>3P`1@D5006ATI03/k
>`0o?cl0BDU907QhN00L71`0:b/[079bLP1SHf<0DU9B08>3P`1kNg/07QhN02XZ:P1hN7P0F5QH06i^
KP1eMGD0<C4a02TY:@1EEED0R8R803Hf=P1<C4`0DE5A03lo?`1dM7@0BDU902l_;`1dM7@0<30`01/K
6`14A4@0HF5Q02DU9@1YJFT09RHV0451@@1FEUH0I6AT02l_;`1EEED0DE5A05UIF@2DU9@0BTY:03/k
>`1=CDd0@d=3059BDP2g]kL0ADE501dM7@1EEED0Bd];0:NWY`1CDe<09BDU02`/;01QHF40Bd];08F5
Q@13@d<0Cdm?07moO`10@400SHf=08b<S00`<300EUIF08Z:RP1LG5`0HF5Q01PH6011@D40T92@08:2
PP1IFET0HF5Q01hN7P0[:b/0HF5Q06a/K00l?3`0;Bd]03Lg=`1;Bd/0MgMg05YJFP0a<C40GUiN04=3
@`1VIVH0M7Ad02HV9P0c<c<0DE5A04Y:BP13@d<0S8b<05aLG00S8b<0AdM705YJFP1CDe<0Jf][03Ph
>00];Bd0@d=305aLG0004`1DE5@0IVIV02h^;P0[:b/0=SHf05ADE01IFET0FUYJ069RHP19BDT0;2`/
06ATI01RHV80BTY:05=CD`0d=3@07AdM0410@01KFe/00P0n?Sh03P0_;bl0;Bd]03lo?`1]KFd0CDe=
024Q8@1>CTh0>CTi03De=@1PH6008B4Q01`L700^;Rh0DE5A7?ooool08`1EEED0PH610:JVYP1UIFD0
H61P06YZJP1OGel0D51@07emO@2ATI40QhN709^KV`2VYZH0YJFU09VIV@1HF5P0L71`07moO`1FEUH0
I6AT05]KF`13@d<0=cLg04];B`1HF5P0ADE504];B`15ADD0Fe]K04A4A01_Kfl0QXJ605YJFP1PH600
HV9R0080I6AT09d0KVi^0;^k^`1]KFd0>3Ph05YJFP0d=3@0?3`l0451@@13@d<0IVIV04Q8B01:BTX0
@d=305mOG`1QHF40IFEU04M7A`1cLg<0B4Q805eMG@1cLg<0CDe=07MgM`1:BTX0KVi^05]KF`1IFET0
<C4a06IVIP1?Cdl0M7Ad06MWI`1^KVh0JVYZ07QhN01iNGT0K6a/05YJFP0e=CD0L71`03/k>`0o?cl0
LW9b03Ti>@1NGUh0Cdm?04Q8B00o?cl0>3Ph03Hf=P0/;2`0EEEE034a<@1>CTh0=cLg02HV9P18B4P0
L71`03/k>`0b<S80CDe=05aLG01GEeL0C4a<059BDP15ADD0GEeM05=CD`1UIFD0BTY:06IVIP15ADD0
P82004I6AP1>CTh0@d=306MWI`10@400K6a/0451@@1:BTX0KVi^04M7A`0l?3`0AdM702PX:01CDe<0
A4A405=CD`14A4@0FUYJ06i^KP1OGel0Cdm?04=3@`1TI6@0QHF5061PH02d];@0^k^k04Q8B01TI6@0
TY:B06YZJP1BDU80IfMW05IFEP0o?cl0@T9202XZ:P1RHV80EEEE061PH02PX:00@d=304I6AP1?Cdl0
Lg=c06a/K01aLG40OWin03Lg=`14A4@07QhN07emO@3Hf=P0CDe=03<c<`1VIVH0=CDe071`L00c<c<0
CTi>014A4@1;Bd/0:BTY030`<017AdL0=cLg0492@P0l?3`0BDU901XJ6P0d=3@0?3`l04=3@`0C4a<0
BTY:05]KF`13@d<0JFUY04e=C@1gMgL0AdM703Hf=P19BDT0>3Ph0080Bd];03D07AdM05ADE00j>SX0
=SHf04E5A@0i>CT0?clo06IVIP1?Cdl09BDU03`l?02ATI40BDU903/k>`1<C4`0BDU905MGE`1QHF40
D51@05UIF@1ADE40BTY:075aL@0b<S80BTY:04a<C00l?3`0E5AD0492@P1IFET0SXj>06EUI@1XJ6P0
AdM7059BDP1RHV805QHF07EeM@0H61P0Jf][07IfMP22PX80[Zj^08f=S@1ZJVX0RXZ:04e=C@2;Rh/0
BTY:0:f][@1TI6@0C4a<07MgM`0206ATI00W08F5Q@1LG5`0Fe]K05EEE@0/;2`0ADE506i^KP1@D500
Q8B4061PH01oOgl0Shn?06m_K`2BTY80T92@08V9R@2FUYH0QhN705eMG@1JFUX0F5QH05YJFP1GEeL0
GEeM06QXJ01;Bd/0>3Ph0:VYZ@1dM7@0IfMW0<k>cP1CDe<0LG5a09fMW@2SXj<0UYJF08j>SP23Ph<0
VIVI017ooooo000?ooooo`0G05iNGP1WIfL0JFUY065QH@2EUID0B4Q806IVIP1mOGd0H61P079bLP17
AdL0>SXj06UYJ@1hN7P0FUYJ038b<P0/;2`0BDU907moO`11@D40CTi>04=3@`0K6a/00P1DE5@0^00c
<c<0KFe]03De=@0W9bL0QXJ609BDU00i>CT0A4A403lo?`16ATH0X:2P06YZJP0V9RH0GemO0451@@10
@400NGUi08F5Q@0Z:RX0Bd];07EeM@1[Jf/0IVIV06MWI`0V9RH0EeMG08V9R@1_Kfl0LG5a04Q8B00G
5aL0AdM707emO@1SHf<0DE5A096AT@0M7Ad0;bl_08J6QP1IFET0KFe]08b<S00Q8B40;bl_03/k>`1W
IfL0<30`05aLG00L71`0Bd];05YJFP0f=SH08B4Q03Lg=`0b<S809bLW06YZJP14A4@0;2`/03lo?`1J
FUX0A4A408N7Q`1;Bd/030`<02HV9P15ADD0>3Ph08B4Q01NGUh03`l?03De=@1EEED0FUYJ03Ti>@2E
UID0:2PX030`<01GEeL0FEUI03Xj>P1lO7`071`L01lO7`0h>3P0Jf][03hn?P1@D5007AdM03Ph>01:
BTX0Ng]k0410@00`<300FEUI03Xj>P2JVYX0YZJV04Q8B00_;bl0>CTi0492@P14A4@0RHV909nOW`0Y
:BT0BDU904A4A022PX80KFe]030`<00_;bl0EeMG06m_K`1DE5@0R8R800h>3P10@400EEEE05aLG01>
CTh0Ogmo0410@00T92@0CDe=06YZJP0g=cL0RXZ:03Hf=P0E5AD0ADE508n?S`1GEeL09bLW03lo?`0c
<c<0BTY:08F5Q@11@D40<S8b059BDP11@D40;2`/06=SH`1_Kfl0;bl_05=CD`13@d<0DU9B09BDU01S
Hf<07AdM034a<@1VIVH0HF5Q0<30`00a<C40>CTi05=CD`1EEED0>c/k071`L01[Jf/0:RXZ07MgM`1E
EED0ADE5059BDP0o?cl0>CTi08F5Q@2EUID0ADE504U9B@0l?3`0N7Qh08R8R011@D40AdM704];B`0]
;Bd0KVi^07AdM012@T8202XZ:P0U06a/K02IVIT0@D5103<c<`11@D40<c<c08^;R`0U9BD0:BTY051@
D01HF5P0G5aL092@T00[:b/0;2`/05ADE01/K6`0MGEe04i>CP0G5aL0De=C06EUI@1?Cdl0KVi^0;fm
_@0U9BD0FEUI05IFEP0k>c/0N7Qh09FEU@0/;2`06ATI05IFEP1kNg/0@T92092@T00202d];@0X04Y:
BP1ADE40:b/[05aLG01bLW809bLW05=CD`1_Kfl08B4Q03`l?01DE5@06a/K03Lg=`21PH40Ph>302l_
;`1HF5P0;Bd]04m?C`2][Jd0IfMW01XJ6P0X:2P0@D5103De=@1jNWX0D51@01/K6`0d=3@0De=C07=c
L`1YJFT0^[Zj04m?C`0S8b<0?Shn051@D00f=SH0B4Q802h^;Qcooooo01d0DE5A07emO@2XZ:P0FEUI
06IVIP1jNWX0OGem071`L02a/K40Rh^;0:>SX`1:BTX0ADE505IFEP1aLG40QhN708Z:RP1jNWX0>3Ph
07=cL`1TI6@0Cdm?04e=C@1ZJVX0P82004Y:BP1CDe<0IVIV09JFUP0204E5A@07069RHP1cLg<0LG5a
05ADE01kNg/0P82009:BTP0208Z:RP0a05MGE`0l?3`0Bd];04Q8B01FEUH0<C4a05EEE@17AdL0FUYJ
0451@@1>CTh0AdM704E5A@1>CTh0EUIF03<c<`0_;bl0Fe]K05YJFP1]KFd0M7Ad059BDP1NGUh0FEUI
04m?C`1DE5@0DU9B05MGE`10@400QhN708>3P`1_Kfl0KFe]05YJFP1<C4`0:RXZ069RHP1ZJVX0@T92
06IVIP0f=SH0BTY:03@d=00h>3P09BDU03dm?@0R8R805aLG03lo?`0204E5A@0D034a<@0R8R80>c/k
04U9B@12@T80>3Ph04A4A01EEED0>3Ph0410@017AdL0?Shn04I6AP18B4P0MWIf06m_K`1PH600ADE5
08V9R@1:BTX205=CD`1[07]kN`1BDU80O7al04e=C@1HF5P0Ogmo05UIF@13@d<0KVi^038b<P1cLg<0
ADE505]KF`14A4@0P8200::RXP2WYjL0OGem05aLG01mOGd0R8R8051@D01:BTX0ATI6069RHP2=SHd0
IFEU04A4A013@d<0>c/k06e]K@10@400MgMg03<c<`1hN7P0FUYJ04];B`21PH40CTi>05MGE`1EEED0
JVYZ0492@P0d=3@0GemO03/k>`1ZJVX0@41007moO`33`l<0EUIF02@T901GEeL0>SXj07EeM@0g=cL0
Lg=c014A4@1[Jf/0De=C04m?C`1]KFd0>c/k0451@@0_;bl0AdM704=3@`1BDU80<S8b02TY:@0:2PX0
JVYZ05mOG`0_;bl0FEUI03Ti>@11@D40>CTi05=CD`1@D500<C4a055AD@0n?Sh07AdM06UYJ@1?Cdl0
?3`l03De=@1>CTh0?3`l04M7A`16ATH0FUYJ06e]K@1BDU80820P07EeM@1_Kfl0=CDe04I6AP1JFUX0
H61P09>CT`1UIFD0F5QH07=cL`1?Cdl00P1KFe/03@1;Bd/0KFe]06=SH`1UIFD0HF5Q05UIF@2h^;P0
<S8b096AT@1dM7@0>c/k079bLP16ATH00P2?Shl0=@1IFET0D51@04U9B@1;Bd/0`L7107QhN02JVYX0
D51@0;^k^`1aLG40CTi>0:JVYP1RHV80F5QH06][J`0j>SX0D51@03dm?@0/;2`0Bd];07AdM011@D40
QhN7055AD@0j>SX0C4a<07YjNP2>SXh0OGem06ATI01BDU80Cdm?03Ti>@0m?Cd0Cdm?03Ph>016ATH0
@D5104e=C@1CDe<0GUiN05EEE@1[Jf/0SHf=08N7Q`24Q8@0a<C408:2PP2KVi/0_;bl0;Bd]02EUID0
^k^k017ooooo000?ooooo`330861P@1`L700QHF504I6AP1/K6`0@D51069RHP15ADD0C4a<09:BTP17
AdL0=SHf0451@@16ATH0GUiN0492@P0S8b<0>SXj05UIF@1DE5@0NGUi07emO@0I6AT0<C4a055AD@1d
M7@0YjNW030`<00T92@0>c/k05eMG@16ATH0PX:204E5A@0N7Qh0C4a<06MWI`1FEUH0Z:RX03hn?P0L
71`0De=C07AdM01?Cdl0VYZJ01LG5`0[:b/0HV9R075aL@17AdL0CTi>069RHP0j>SX0De=C06QXJ00^
;Rh0AdM704=3@`0b<S80BDU909FEU@1FEUH0;Bd]02<S8`0m?Cd0IFEU0;^k^`1LG5`09RHV05IFEP0_
;bl0>c/k09JFUP0U9BD0;Rh^055AD@1>CTh0E5AD07UiN@1KFe/06ATI03Ti>@14A4@0QHF50:NWY`0/
;2`08R8R05QHF026QXH0=3@d05ADE018B4P092@T0492@P1OGel0;Bd]02@T901FEUH08B4Q02`/;01m
OGd0>c/k03<c<`0g=cL0BTY:05iNGP2@T900;Rh^028R8P13@d<0ATI606a/K01nOWh07alO02HV9P1H
F5P0IFEU05ADE010@400UYJF01dM7@12@T80De=C06MWI`1QHF40GEeM02@T900V9RH0F5QH07alO01;
Bd/0KFe]02PX:010@400Z:RX075aL@0c<c<0LW9b05ADE00V9RH0S8b<07MgM`0];Bd0C4a<030`<00_
;bl0Ogmo09RHV00V9RH0>c/k04i>CP1=CDd0_;bl07YjNP0H61P0<30`04i>CP1VIVH0EEEE07QhN00N
7Qh0?Cdm05YJFP1HF5P0CDe=09BDU00W9bL0>3Ph030`<015ADD0C4a<09VIV@0G5aL0=3@d04M7A`1X
J6P0@d=307=cL`0i>CT0>3Ph06UYJ@1^KVh0A4A408V9R@0d=3@0;Rh^08j>SP2c/k<0D51@04U9B@0Z
:RX0GemO0;Zj^P19BDT0=cLg0080HV9R03X0TI6A07AdM00K6a/0J6QX07AdM01NGUh0RXZ:06ATI00O
7al0>3Ph05iNGP1mOGd0=3@d01TI6@0_;bl0N7Qh051@D01ADE40EUIF02DU9@1DE5@0?clo05MGE`29
RHT0<S8b04M7A`21PH40HV9R03Ti>@1nOWh0=CDe06IVIP1oOgl0:BTY03Xj>P1RHV80?clo04i>CP1g
MgL0BDU904];B`18B4P0:BTY03`l?028R8P0GUiN02l_;`0d=3@0?clo03Lg=`2;Rh/0?Shn02PX:011
@D40?Shn04A4A01^KVh0/k>c0P0j>SX0101/K6`0I6AT07]kN`2CTi<202PX:00K04m?C`21PH40EeMG
07inOP0X:2P08B4Q04Q8B02ATI40=cLg06i^KP1CDe<0820P03<c<`1UIFD0:RXZ038b<P1<C4`0:b/[
02LW9`1@D500GUiN01dM7@19BDT0;2`/06e]K@2UYJD0GUiN01cooooo01H0IfMW08B4Q02YZJT0HV9R
06a/K01hN7P0Ogmo07alO028R8P0UIFE08b<S01JFUX0L71`09FEU@1nOWh0SXj>08N7Q`2EUID0CTi>
065QH@1SHf<0Cdm?0P1<C4`0AP1CDe<0DU9B04m?C`0j>SX0BDU905=CD`11@D40LG5a04i>CP1MGEd0
JFUY07YjNP2FUYH0Ng]k0;Ng]`21PH40FEUI04E5A@0b<S80J6QX05YJFP0i>CT0Ogmo065QH@1iNGT0
ATI606][J`1dM7@0R8R804m?C`1hN7P0<c<c03dm?@1PH600<C4a04m?C`1;Bd/0CTi>0492@P0a<C40
>3Ph05EEE@12@T80FEUI05eMG@1jNWX0EEEE04i>CP1SHf<0HF5Q06MWI`0i>CT0Cdm?0492@P15ADD0
H61P04A4A01OGel0CDe=0451@@0k>c/0@41003Ph>00[:b/0BDU9038b<P14A4@0@D51034a<@0`<302
055AD@0403Xj>P12@T80F5QH04m?C`80B4Q80;D0BDU904i>CP0h>3P0EeMG04Q8B01@D500Cdm?06QX
J01WIfL0EEEE04m?C`23Ph<0SHf=08F5Q@16ATH0E5AD07AdM01IFET0A4A405IFEP1CDe<0GEeM03/k
>`1QHF40QXJ609bLW02][Jd0YJFU07YjNP1aLG40De=C06m_K`1QHF40DE5A06][J`0a<C40IfMW0:^[
Z`1UIFD0KFe]055AD@20P800@T9207moO`0g=cL0H61P07YjNP1^KVh0VYZJ05YJFP1dM7@0C4a<0:NW
Y`1NGUh0DU9B06ATI01WIfL0V9RH030`<01/K6`0X:2P071`L01?Cdl0JFUY04m?C`29RHT0Hf=S0820
P00E5AD0=cLg02`/;00c<c<0Bd];04=3@`0`<300:b/[055AD@0G5aL08R8R03Ti>@1:BTX05QHF09NG
U`1oOgl0=CDe05EEE@0l?3`0N7Qh0451@@0j>SX0@41003De=@26QXH0C4a<01@D5014A4@0>3Ph04U9
B@0n?Sh0=CDe03/k>`1WIfL0FEUI03`l?01=CDd0Kfm_03<c<`1?Cdl0IFEU02h^;P1XJ6P0Ti>C0451
@@1>CTh0Hf=S05YJFP1gMgL0@41004Q8B01TI6@0Cdm?04a<C01/K6`0Kfm_09nOW`1YJFT0HV9R02HV
9P16ATH0EEEE03Hf=P2>SXh0@D51071`L01GEeL0C4a<09NGU`26QXH0I6AT06YZJP1=CDd0N7Qh069R
HP2LW9`0CDe=03Ph>01cLg<0@d=306MWI`1YJFT0;2`/07UiN@1LG5`0?clo04=3@`1<C4`0;bl_0492
@P17AdL0>3Ph04a<C01^KVh0UYJF055AD@1jNWX0VIVI0:BTY01@D500ATI604m?C`1PH600K6a/04M7
A`0o?cl0FEUI03<c<`1HF5P0IVIV0820P02HV9P0KFe]0080UIFE00D0O7al09VIV@1OGel0LW9b0=KF
eP0Aooooo`003oooool0V`2RXZ80^k^k09^KV`15ADD0GUiN075aL@2>SXh0=CDe03dm?@1`L700F5QH
06i^KP1fMWH08R8R03Xj>P12@T80>c/k07IfMP14A4@08R8R05=CD`1WIfL0<c<c061PH015ADD0:RXZ
09nOW`1oOgl09BDU05UIF@0c<c<08B4Q05mOG`1TI6@0<S8b04M7A`0I6AT0>c/k09bLW01RHV80820P
02h^;P1>CTh0BDU90;Bd]00Z:RX071`L03lo?`1CDe<0=CDe09FEU@2m_Kd06ATI04a<C01eMGD0Cdm?
09fMW@2ATI406QXJ03Hf=P1[Jf/0EEEE06UYJ@0T92@0:BTY04E5A@1GEeL0OWin038b<P25QHD0C4a<
01<C4`1?Cdl0?Shn061PH01TI6@05aLG03Lg=`1ADE40ZZZZ059BDP1;Bd/0<S8b059BDP1fMWH0DE5A
03`l?013@d<0?clo04];B`1iNGT0E5AD02/[:`15ADD0D51@04Q8B01RHV80VIVI01`L700H61P0>SXj
05iNGP2<S8`0P82002TY:@14A4@0J6QX06UYJ@1BDU80Zj^[06e]K@0c<c<0KFe]05eMG@0X:2P0G5aL
04E5A@0b<S80E5AD08R8R00j>SX0CTi>05ADE016ATH0EUIF06e]K@0d=3@0:2PX05]KF`1<C4`0Hf=S
08>3P`0`<300;2`/07=cL`1dM7@0C4a<07AdM012@T80:RXZ069RHP1UIFD0O7al05mOG`0[:b/0820P
04i>CP2/[:`0Jf][06EUI@0E5AD0?Cdm06UYJ@1kNg/0EEEE0080GEeM07d0;Bd]030`<01_Kfl0;Bd]
04e=C@1ADE40;Bd]03lo?`1^KVh0OWin02PX:01@D500@41007MgM`2MWId0CTi>03<c<`1CDe<0GUiN
071`L02:RXX0F5QH02TY:@12@T80Bd];06ATI037alL0KFe]028R8P0[:b/0BDU906UYJ@2ATI40:b/[
0492@P1EEED0EUIF051@D02?Shl0HV9R04E5A@1]KFd0<S8b069RHP15ADD07AdM04Q8B01mOGd0ADE5
04I6AP0`<300Shn?07AdM00^;Rh0HF5Q04I6AP0d=3@0MgMg09:BTP11@D40Cdm?02l_;`1PH600^;Rh
05YJFP0_;bl0A4A406YZJP1JFUX0XZ:R03Ti>@1@D500FEUI061PH01jNWX0O7al01dM7@0l?3`0J6QX
05QHF02][Jd0OWin01/K6`0g=cL0ADE5051@D01]KFd0ZZZZ06EUI@0^;Rh0De=C07AdM01=CDd0QhN7
02TY:@0d=3@0Bd];04m?C`1VIVH0LG5a03<c<`0e=CD0DE5A05]KF`0m?Cd0;Bd]03Ti>@0h>3P0AdM7
06a/K00S8b<09bLW03De=@0l?3`0E5AD05mOG`1lO7`05aLG03hn?P1JFUX0@d=305aLG02;Rh/06a/K
01`L700205eMG@0603hn?P20P8009RHV01hN7P1JFUX0UYJF7?ooool0101nOWh0N7Qh08R8R01MGEd2
08:2PP80WIfM07D0IfMW08b<S01WIfL0GUiN08B4Q01JFUX0LW9b0:BTY02MWId0NGUi055AD@1[Jf/0
G5aL03hn?P1RHV80EeMG05EEE@1CDe<0HF5Q051@D01KFe/0K6a/06i^KP2IVIT0IVIV06YZJP1oOgl0
Lg=c06m_K`2BTY80X:2P07inOP13@d<0Bd];01PH600d=3@0Bd];051@D01QHF40@T9205]KF`1;Bd/0
GUiN0492@P15ADD0BTY:05aLG01DE5@0GEeM061PH011@D40LG5a0861P@1SHf<0CDe=04I6AP1CDe<0
C4a<04=3@`1EEED0Bd];05MGE`1=CDd0I6AT07AdM01jNWX0F5QH03Xj>P1[Jf/0ADE504M7A`1OGel0
<C4a0451@@1EEED0=cLg04I6AP1QHF40:b/[038b<P1JFUX0Cdm?04i>CP0n?Sh0;bl_03@d=019BDT0
>3Ph02HV9P0f=SH0ADE504I6AP0d=3@0@41006EUI@18B4P0;bl_05EEE@1<C4`0DU9B03dm?@1IFET0
ADE505ADE01KFe/0G5aL05ADE01RHV80Cdm?05=CD`1hN7P0DU9B03/k>`1<C4`0:b/[04U9B@0b<S80
0P1DE5@0<01`L700QhN708j>SP2PX:00JVYZ04i>CP26QXH0N7Qh04a<C021PH40I6AT06][J`2RXZ80
G5aL06i^KP1>CTh0Ph>306m_K`28R8P0>3Ph05]KF`1CDe<0BTY:07QhN022PX80PH6104Y:BP2DU9@0
GUiN04Y:BP1jNWX0?Shn04M7A`0Y:BT0FUYJ07MgM`1<C4`0?Cdm065QH@13@d<0F5QH04I6AP1VIVH0
9BDU04=3@`1;Bd/0?Shn05QHF080@D510740DU9B04Q8B00Z:RX0;bl_02LW9`0l?3`0820P04];B`1>
CTh0EEEE07QhN011@D40?Cdm04a<C01[Jf/0Lg=c0410@01=CDd0@D5102/[:`1`L700HF5Q02TY:@10
@400C4a<03hn?P0o?cl0C4a<04A4A01=CDd0Jf][02/[:`1XJ6P0Ogmo038b<P0c<c<0C4a<06YZJP1`
L700F5QH04I6AP1IFET0ADE504M7A`1CDe<0C4a<04I6AP14A4@0FUYJ05IFEP1/K6`0YZJV02PX:029
RHT0ATI601HF5P1BDU807alO08n?S`1oOgl0EEEE04I6AP19BDT0?3`l06a/K00o?cl0WinO04a<C02M
WId0I6AT04A4A01`L700?clo05=CD`1TI6@0;Rh^03Ti>@0];Bd08R8R03Hf=P1=CDd0B4Q804I6AP1R
HV80@4100820P01lO7`0TY:B05IFEP1nOWh0C4a<08F5Q@10@400AdM704I6AP0f=SH0Fe]K03/k>`0m
?Cd0A4A402`/;01VIVH0IfMW071`L01kNg/0Ogmo0:6QX@1bLW80NGUi09VIV@1aLG40Fe]K092@T00A
ooooo`003oooool0L01YJFT0Lg=c0:j^[P1LG5`0HV9R06IVIP2h^;P0LW9b04a<C01fMWH0?Shn0861
P@2?Shl0CDe=04=3@`18B4P0IfMW08:2PP1KFe/08B4Q03<c<`1GEeL0G5aL0:2PX01;Bd/0>3Ph05eM
G@1NGUh0EUIF0:n_[`0o?cl0;2`/02XZ:P1SHf<0Ng]k07inOP0T92@0820P02d];@1iNGT0B4Q807Mg
M`1KFe/0;bl_05aLG01PH600;2`/075aL@0n?Sh05aLG03De=@1MGEd0DE5A04e=C@0Q8B40:b/[055A
D@29RHT0>c/k04i>CP1`L7008B4Q07alO017AdL061PH03De=@19BDT0>CTi034a<@1/K6`0Lg=c018B
4P0j>SX0B4Q808J6QP1dM7@04a<C02@T9018B4P0IFEU05]KF`2<S8`0DU9B04e=C@1ZJVX0DU9B04Q8
B01NGUh0>3Ph01HF5P16ATH0H61P03Lg=`1nOWh0CTi>02/[:`1>CTh0O7al061PH00g=cL0GemO02HV
9P1@D500Hf=S03@d=00`<300DU9B02XZ:P1OGel0NWYj07AdM00X:2P204e=C@2`05QHF02g]kL0TY:B
01TI6@0`<300KFe]06IVIP2WYjL0X:2P01TI6@13@d<0Q8B4071`L01BDU80SHf=03hn?P1:BTX0MWIf
055AD@1QHF40JVYZ01`L701HF5P0LG5a09BDU01:BTX0FUYJ02l_;`1ADE40N7Qh04];B`0M7Ad0Kfm_
05EEE@0b<S80MgMg06UYJ@0];Bd0EeMG05]KF`0R8R80K6a/08R8R00`<3009BDU06MWI`0f=SH0WinO
09FEU@0G5aL09bLW05mOG`1HF5P0CDe=092@T019BDT0HF5Q06ATI01=CDd0EeMG08^;R`0h>3P0ADE5
05IFEP1fMWH0MgMg07emO@0P8200=CDe06YZJP2/[:`0;Bd]061PH00l?3`0=SHf09VIV@1HF5P0A4A4
05MGE`0h>3P0ADE5075aL@1VIVH0<C4a059BDP1HF5P0OGem05EEE@0W9bL0ATI604e=C@1<C4`0SHf=
03@d=019BDT0X:2P04a<C02JVYX0ADE50451@@16ATH0HV9R06][J`1]KFd0=cLg05=CD`1eMGD0BTY:
05EEE@1DE5@05aLG03/k>`1ZJVX0FUYJ075aL@0f=SH0820P069RHP28R8P0CTi>04Y:BP1WIfL0;2`/
06EUI@2=SHd0@T9204a<C01WIfL09BDU03Lg=`1dM7@0R8R802/[:`1FEUH0=SHf06a/K02=SHd0CDe=
01XJ6P1?Cdl0E5AD03Ph>02FUYH0IfMW01DE5@1?Cdl0Hf=S04U9B@1IFET0TI6A05UIF@0g=cL0JVYZ
04M7A`1MGEd0Lg=c02@T900c<c<0B4Q806YZJP17AdL0@d=302HV9P0S8b<0@d=3069RHP1eMGD0;bl_
04M7A`0W9bL0>c/k06][J`0m?Cd08b<S04];B`0j>SXLooooo`1<08N7Q`20P800P82008>3P`1SHf<0
IVIV04E5A@17AdL0I6AT051@D01PH600C4a<05ADE01kNg/0YJFU06m_K`2CTi<0T92@08B4Q01bLW80
IFEU05IFEP1BDU80FEUI06=SH`1KFe/0IVIV05YJFP1ADE40DU9B04I6AP24Q8@0I6AT06UYJ@1GEeL0
RXZ:08>3P`2BTY80KFe]07]kN`1LG5`0CDe=06QXJ013@d<0GEeM02PX:01LG5`0ADE5065QH@16ATH0
CTi>04Q8B01>CTh0F5QH06MWI`0i>CT0<S8b05mOG`1VIVH0GUiN03Lg=`1=CDd0M7Ad05]KF`0j>SX0
I6AT04U9B@1TI6@0Bd];07emO@1lO7`0UYJF07AdM01IFET0JVYZ04e=C@80GEeM0180ATI604a<C00k
>c/0CTi>03/k>`0e=CD07QhN0451@@0N7Qh05aLG03/k>`0[:b/0BTY:03<c<`0a<C40<30`06e]K@15
ADD204=3@`1>05eMG@16ATH0De=C04=3@`0^;Rh0?clo03Lg=`1RHV80IfMW05aLG00n?Sh0PH6105aL
G01DE5@0De=C07EeM@1UIFD0K6a/04E5A@0i>CT0J6QX05YJFP11@D40=SHf02/[:`1@D500>CTi05AD
E01FEUH0PH610::RXP2DU9@0EeMG05QHF017AdL0Q8B407YjNP19BDT0QhN705MGE`1WIfL0VYZJ09RH
V01BDU80A4A406IVIP1SHf<0IfMW04i>CP1HF5P0RXZ:07]kN`1mOGd0HV9R04U9B@14A4@0NGUi07=c
L`1ADE40N7Qh04];B`1LG5`0>3Ph051@D026QXH0UIFE04M7A`1LG5`0ATI605MGE`1gMgL0JVYZ01/K
6`13@d<0I6AT0492@P1CDe<0@4100P14A4@203/k>`0A03Ph>014A4@0AdM701TI6@1CDe<0GUiN02`/
;01=CDd0;bl_04A4A00j>SX0=3@d05=CD`0V9RH0Ogmo04Y:BP071`L00P0g=cL0F`0Y:BT0;bl_030`
<01:BTX0@T9205QHF01JFUX0GUiN06ATI00e=CD0CDe=05aLG00f=SH0<C4a04M7A`18B4P0IVIV06e]
K@1XJ6P0I6AT04A4A01ADE40FEUI04];B`0k>c/0C4a<05YJFP1EEED0E5AD06ATI01?Cdl0>3Ph05EE
E@11@D40S8b<030`<01@D500DE5A03Xj>P1>CTh0DE5A04i>CP2JVYX0GemO09RHV01aLG40KFe]05IF
EP0i>CT0I6AT04i>CP1aLG40KFe]02d];@16ATH0=SHf028R8P1=CDd0LG5a04E5A@1DE5@0D51@04=3
@`10@400FUYJ0:^[Z`1LG5`0R8R8055AD@2KVi/0C4a<04A4A01DE5@0@D5106ATI016ATH0?clo05=C
D`12@T80OGem07IfMP1`L700Vi^K08f=S@2YZJT0^KVi09FEU@2SXj<0IfMW05=CD`2c/k<04Oooool0
00oooooo04<0IFEU055AD@1RHV80MWIf07emO@1;Bd/0I6AT075aL@21PH40^;Rh04];B`0l?3`0MWIf
07=cL`27QhL0<30`02l_;`1DE5@0Hf=S055AD@22PX80B4Q803<c<`16ATH0Jf][061PH02EUID0;Rh^
02<S8`1RHV80PH6103Xj>P19BDT0:b/[04i>CP1iNGT0AdM7038b<P1EEED0;Rh^03/k>`1^KVh0N7Qh
038b<P0l?3`0K6a/03lo?`2ZZZX0Kfm_02d];@0g=cL0EeMG05UIF@1eMGD0;bl_020P8019BDT0@d=3
04U9B@1ZJVX0`<3001dM7@10@400YZJV04I6AP2IVIT0QHF50080:RXZ0=d0H61P07inOP0o?cl0Hf=S
01DE5@0[:b/0Bd];051@D00K6a/0Fe]K03Lg=`0Y:BT0>3Ph05UIF@0^;Rh0?clo03De=@0V9RH0HV9R
06MWI`0K6a/0:b/[0451@@0h>3P0JFUY03Ph>00M7Ad0;Bd]0492@P1DE5@0D51@0:>SX`0U9BD0;Rh^
05=CD`0l?3`0Lg=c0;Vi^@0Z:RX0;bl_051@D01gMgL0GUiN08Z:RP0U9BD0;2`/04];B`1]KFd0BDU9
04a<C01cLg<0;Rh^05MGE`2DU9@0AdM70451@@0n?Sh0<C4a038b<P1iNGT0OWin02`/;014A4@0>SXj
05mOG`2h^;P0GUiN01/K6`17AdL0F5QH05]KF`2CTi<0:2PX0410@01KFe/0BDU903lo?`36a/H0FUYJ
03Ph>01GEeL0De=C05QHF02UYJD0JFUY01/K6`1@D500G5aL05mOG`11@D40IVIV01XJ6P19BDT0Shn?
03Xj>P1<C4`0Ogmo02`/;00I6AT0GEeM04e=C@0g=cL0IfMW02HV9P0b<S80Rh^;07=cL`0O7al0EEEE
0451@@2:RXX0_Kfm034a<@0];Bd0CDe=08F5Q@17AdL0XZ:R06i^KP0^;Rh0P82004I6AP1WIfL0Ng]k
01`L700[:b/0F5QH05EEE@1?Cdl0GUiN030`<01SHf<0R8R8069RHP1cLg<0HF5Q03Hf=P1eMGD0DU9B
05ADE00d=3@0=CDe0861P@2KVi/0;Rh^04Q8B016ATH092@T05aLG00X:2P0FEUI06UYJ@0o?cl0TY:B
07IfMP0/;2`0=SHf065QH@1:BTX0X:2P07MgM`0M7Ad0C4a<05YJFP0o?cl0RHV90=7Ad@0/;2`0Fe]K
07MgM`1HF5P0HF5Q0:^[Z`0M7Ad05aLG04a<C01kNg/0Cdm?07]kN`0B4Q806a/K04];B`1]KFd0>SXj
07AdM01VIVH092@T0410@01kNg/0?Cdm04Q8B01BDU80<c<c03/k>`1QHF40RHV9038b<P1PH600=3@d
02TY:@1=CDd0Cdm?01XJ6P0i>CT0BTY:034a<@1MGEd0>SXj02DU9@0d=3@0@410079bLP1=CDd0QXJ6
03Ph>00E5AD0EUIF06=SH`0h>3P0Ti>C05MGE`0Looooo`2204U9B@1BDU80CTi>04E5A@1CDe<0GemO
065QH@1TI6@0YZJV08^;R`2OWil0EeMG05mOG`23Ph<0EUIF06e]K@1_Kfl0Lg=c04m?C`1WIfL0GUiN
051@D01FEUH0EeMG05UIF@1SHf<0K6a/04Y:BP1TI6@0MWIf04E5A@2;Rh/0LG5a079bLP1`L700Y:BT
0820P02MWId0TI6A09:BTP1EEED0D51@03`l?018B4P0J6QX03Xj>P27QhL0EEEE07MgM`1?Cdl0M7Ad
06=SH`18B4P0EEEE09:BTP12@T80>3Ph05MGE`0l?3`0IfMW04=3@`1=CDd0E5AD0492@P0a<C40GEeM
05EEE@1>CTh0BDU906a/K019BDT0ATI6069RHP1HF5P0E5AD04M7A`1VIVH0@T92038b<P1GEeL0@D51
04I6AP0l?3`0CTi>038b<P1<C4`0:BTY02d];@1<C4`0;Bd]03/k>`0m?Cd0;Rh^0451@@1EEED0@d=3
02`/;00b<S80@D5103lo?`0n?Sh0>c/k04A4A01GEeL0?clo05IFEP0o?cl0De=C05YJFP1BDU80@D51
04E5A@1=CDd0KVi^09^KV`2<S8`0BDU904];B`2BTY80KVi^03lo?`15ADD0?Cdm055AD@0/;2`0EeMG
05mOG`1WIfL0FEUI06i^KP80Lg=c04h0FUYJ075aL@1UIFD0Ogmo08n?S`1EEED0GUiN06][J`17AdL0
CTi>04Q8B01JFUX0LG5a05aLG00/;2`0?clo0410@018B4P0EUIF05YJFP1aLG40CTi>07AdM01?Cdl0
IFEU07QhN01CDe<0EUIF055AD@1GEeL0XJ6Q079bLP0];Bd0FUYJ055AD@1PH600FUYJ06e]K@0S8b<0
GEeM03lo?`0];Bd0Bd];059BDP0f=SH0BTY:038b<P0Z:RX0=cLg02`/;00j>SX04Q8B04Q8B01TI6@0
>3Ph05ADE013@d<0BTY:04e=C@15ADD0KVi^03Hf=P2k^k/0PX:201DE5@1FEUH0?Cdm03lo?`0i>CT0
>3Ph04E5A@19BDT0@T9204I6AP1FEUH0I6AT01dM7@1QHF4207=cL`1>02XZ:P14A4@0DE5A05UIF@1T
I6@0GEeM061PH01QHF40C4a<0451@@1;Bd/0GEeM04I6AP1=CDd0N7Qh05=CD`2ATI40@d=304Y:BP13
@d<0;2`/05MGE`0e=CD0DU9B05YJFP1DE5@0Ti>C05QHF014A4@0W9bL07emO@2PX:00WinO09fMW@1i
NGT0<c<c05MGE`12@T80Fe]K05MGE`0A4A40ADE503@d=00X:2P0?Cdm04=3@`1CDe<0H61P055AD@1l
O7`0F5QH06EUI@2=SHd0B4Q80820P01LG5`0S8b<07UiN@25QHD0D51@0492@P1IFET0EUIF06MWI`1@
D5008B4Q04m?C`1_Kfl0PH61096AT@2QXJ40alO709ZJVP2<S8`0/;2`0:2PX022PX80YZJV4Oooool0
00oooooo0<P0Ng]k0:f][@1lO7`0C4a<06YZJP1VIVH0NGUi03Lg=`17AdL0G5aL04M7A`0l?3`0D51@
034a<@1<C4`0IfMW030`<01<C4`0?Cdm02DU9@1@D500IfMW01dM7@12@T80=3@d05iNGP2XZ:P0@D51
02DU9@11@D40@41004m?C`1lO7`0:BTY02l_;`1<C4`0;bl_05mOG`2KVi/0;Rh^02/[:`1=CDd0CTi>
061PH02<S8`061PH03Ph>01IFET0SXj>08F5Q@2FUYH0/K6a03<c<`17AdL0FEUI03Lg=`2b/[80HF5Q
02HV9P1:BTX0M7Ad05MGE`0o?cl0;bl_03@d=01RHV80PH6103<c<`0[:b/0@D5102XZ:P0l?3`0Ogmo
02d];@17AdL0BTY:02LW9`13@d<0X:2P0492@P0T92@0?Cdm04m?C`1XJ6P0U9BD03Lg=`0S8b<0;bl_
06QXJ01IFET0I6AT04I6AP0i>CT0>SXj069RHP0c<c<0L71`06UYJ@0A4A40@D5107=cL`0n?Sh0C4a<
0410@00V9RH0;2`/05]KF`17AdL0:2PX05eMG@0f=SH0=cLg08V9R@0g=cL07alO0492@P0m?Cd0>3Ph
05YJFP2NWYh0;Bd]04=3@`1/K6`0EEEE079bLP2VYZH0<C4a02/[:`10@400IVIV07EeM@10@4006a/K
034a<@22PX80PH6103Lg=`1SHf<07alO02TY:@1ZJVX0J6QX04e=C@1VIVH09bLW01lO7`1DE5@0PH61
04Y:BP1JFUX07AdM03@d=028R8P0`L7106UYJ@16ATH0L71`02h^;P0Z:RX0R8R801lO7`0c<c<0FUYJ
04U9B@1JFUX0SXj>04=3@`0D51@0=CDe05EEE@1dM7@0Ng]k01dM7@0Y:BT0Hf=S0820P01>CTh0M7Ad
0492@P0f=SH0Kfm_06ATI01IFET0JFUY03De=@0U9BD0DE5A08j>SP1PH600GEeM02@T900g=cL0OGem
05EEE@0V9RH0IfMW04M7A`0g=cL0SHf=028R8P80BDU903D0Fe]K08Z:RP2@T900:RXZ05aLG01UIFD0
NWYj03De=@0Y:BT0<C4a07QhN01RHV80RXZ:075aL@0P8200GUiN03Hf=P29RHT0V9RH02/[:`18B4P0
Ph>305IFEP17AdL0N7Qh038b<P1RHV80Ti>C0410@01:BTX0BDU902d];@11@D40MWIf06][J`1ZJVX0
A4A402l_;`0g=cL0MWIf05]KF`16ATH0FUYJ0451@@0g=cL0XJ6Q02d];@0/;2`0@T9204M7A`16ATH0
UIFE0;Ng]`0202l_;`07069RHP1OGel0N7Qh0:FUY@0S8b<0;2`/04Y:BP0205UIF@0H08^;R`0M7Ad0
=CDe03<c<`0h>3P0;Rh^04Y:BP1RHV804A4A030`<01?Cdl0;Bd]05]KF`1HF5P04a<C030`<013@d<0
C4a<01`L700l?3`04a<C01lO7`1;Bd/0I6AT7?ooool0?01SHf<0Lg=c09JFUP1CDe<0Lg=c07AdM02:
RXX0MgMg09fMW@2:RXX0Ng]k0861P@2>SXh0NGUi08R8R02FUYH0SXj>07moO`1eMGD0L71`05UIF@0n
?Sh0A4A404E5A@0h>3P0De=C061PH00o?cl0CTi>03Ti>@1FEUH0Ti>C05ADE01JFUX0T92@07]kN`1o
Ogl0L71`0;2`/02DU9@0@D5104i>CP0L71`0?clo055AD@13@d<0JVYZ065QH@1OGel0C4a<06ATI01/
K6`0G5aL055AD@2<S8`0CTi>04I6AP1SHf<0BTY:07moO`80FUYJ01<0M7Ad06=SH`0d=3@0FEUI04Y:
BP1OGel0FEUI07inOP1SHf<0F5QH07MgM`24Q8@0NGUi059BDP2FUYH0FEUI03De=@1kNg/0;bl_0080
@d=302d0<c<c04Q8B018B4P0:b/[02d];@1PH600<30`04U9B@12@T80;bl_03Ti>@1DE5@0Bd];034a
<@0m?Cd0D51@05EEE@17AdL0BTY:05YJFP1ADE40;Bd]05aLG01<C4`0FEUI0410@01FEUH0?Shn059B
DP1MGEd0I6AT04e=C@1NGUh0C4a<04Q8B01FEUH0CTi>03@d=011@D40=SHf03Ti>@0a<C40CDe=06YZ
JP1TI6@00P2>SXh0E@2][Jd0S8b<0451@@1<C4`0D51@04I6AP1VIVH0@D5103hn?P1YJFT0LG5a03Ti
>@0V9RH0DU9B04E5A@1KFe/0A4A405UIF@1CDe<0Hf=S05=CD`1JFUX0HF5Q04E5A@1bLW80HV9R04E5
A@1TI6@0CDe=04U9B@0A4A40MgMg0<[:bP2=SHd0@D5105MGE`1=CDd0QhN705ADE01VIVH07alO04M7
A`1PH600<c<c04e=C@0k>c/0=CDe06YZJP0m?Cd0:b/[02l_;`0W9bL0BTY:03`l?01lO7`0MgMg0451
@@1=CDd0DU9B0861P@1EEED0AdM705ADE00Z:RX0@d=304];B`0k>c/0IFEU04M7A`0c<c<0CTi>03`l
?00m?Cd0KFe]065QH@1>CTh0HV9R061PH00W9bL0DU9B06=SH`18B4P0@D5107=cL`17AdL00P1ADE40
B@1=CDd0G5aL03dm?@0o?cl0=3@d0410@01:BTX0?3`l05MGE`1kNg/0KVi^08n?S`0S8b<0BTY:059B
DP0f=SH0GEeM04I6AP1UIFD0FUYJ02l_;`1UIFD0JVYZ06=SH`2=SHd0F5QH09fMW@1?Cdl0P82006=S
H`1ZJVX0VYZJ03/k>`1WIfL0I6AT02LW9`1fMWH0JVYZ04E5A@1@D500C4a<04i>CP1HF5P0ATI604E5
A@1;Bd/0GEeM08N7Q`2=SHd0PX:2061PH01LG5`0AdM70410@014A4@0BTY:05UIF@0[:b/0?3`l06QX
J00`<300SHf=06e]K@24Q8@0^KVi07MgM`1nOWh0_;bl09ZJVP1oOgl0L71`0820P02QXJ404Oooool0
00oooooo04<0Jf][09BDU02`/;00@D5105QHF02>SXh0_kno04Y:BP0o?cl0J6QX04i>CP1XJ6P0RXZ:
030`<01?Cdl0EeMG06QXJ02d];@0De=C02XZ:P0k>c/0G5aL04a<C02QXJ40CDe=02l_;`1QHF40HV9R
05mOG`2:RXX0GUiN02d];@0m?Cd0BDU905MGE`1RHV807AdM03Lg=`24Q8@0RHV903lo?`1RHV80GUiN
03Xj>P2NWYh0?clo03<c<`1^KVh0>c/k02HV9P1WIfL0`/;202d];@0c<c<0<S8b04M7A`2OWil0IfMW
02<S8`0i>CT0K6a/07=cL`1bLW8061PH02d];@11@D40F5QH0080QHF501<0TY:B028R8P0c<c<0A4A4
04Y:BP2FUYH0LG5a02TY:@0_;bl0L71`09jNWP1CDe<0KFe]0410@01EEED0J6QX079bLP0c<c<0EeMG
0080<c<c0580IVIV05aLG00L71`0CDe=04A4A00i>CT0UIFE0<o?c`1<C4`051@D03lo?`16ATH0S8b<
079bLP0T92@0?Cdm0410@018B4P0EeMG09ZJVP1EEED09RHV05=CD`1FEUH0>SXj07AdM00_;bl0;Rh^
03@d=01<C4`0A4A409nOW`1XJ6P08b<S03/k>`1@D500B4Q803lo?`1TI6@0>CTi04I6AP24Q8@0>CTi
03Hf=P0i>CT0EeMG05YJFP2JVYX0F5QH01dM7@1CDe<0HV9R06ATI01mOGd0:b/[02`/;01ADE40XZ:R
06m_K`2UYJD0:BTY02DU9@1?Cdl0SHf=07inOP1/K6`0Ng]k02PX:00S8b<0IfMW05eMG@17AdL0Kfm_
01PH6019BDT0MgMg06MWI`0c<c<0E5AD04E5A@0`<300KFe]0P10@400M01LG5`0?3`l04U9B@23Ph<0
De=C04A4A01/K6`0C4a<07QhN02FUYH0D51@02l_;`16ATH0GUiN06UYJ@2SXj<0:b/[02HV9P13@d<0
Kfm_05ADE02c/k<0IfMW02DU9@26QXH0EUIF07EeM@0g=cL08R8R04a<C026QXH0ADE508R8R00a<C40
L71`06e]K@16ATH0De=C04U9B@0Q8B40EeMG0861P@0];Bd0B4Q802PX:01VIVH0YjNW05iNGP11@D40
A4A404=3@`1OGel0Vi^K03<c<`16ATH0M7Ad075aL@2=SHd0Lg=c024Q8@0l?3`0@D51069RHP2XZ:P0
FUYJ02TY:@0m?Cd0Bd];05=CD`1JFUX0W9bL04M7A`1?Cdl0MgMg03lo?`10@400EUIF02<S8`0Z:RX0
Bd];09nOW`1HF5P0DE5A02XZ:P0c<c<0De=C07MgM`1>CTh0<c<c04];B`0b<S80>c/k06ATI00h>3P0
7alO06EUI@0m?Cd0?Shn05mOG`25QHD0>c/k030`<014A4@0=cLg07alO02/[:`0;2`/020P801BDU80
GUiN05MGE`1nOWh05ADE02`/;01=CDd0F5QH7?ooool00`2OWil0Rh^;0861P@0207emO@0Q07moO`1e
MGD0MgMg06EUI@2BTY80NGUi04i>CP1aLG40LW9b06][J`28R8P0[Zj^08Z:RP1EEED0Q8B407=cL`1D
E5@0EUIF05eMG@17AdL0EUIF05QHF01BDU80EEEE051@D00e=CD0Jf][05aLG01VIVH0J6QX07alO028
R8P0T92@0080Q8B40</0=CDe034a<@0^;Rh0=CDe05iNGP0g=cL0GemO04U9B@1JFUX0DE5A04m?C`12
@T80:b/[05=CD`1>CTh0<c<c03/k>`1PH600KFe]06=SH`1=CDd0AdM707EeM@1BDU80<30`04i>CP1d
M7@0@d=3034a<@0m?Cd0I6AT08Z:RP18B4P0@d=307=cL`1jNWX0MgMg079bLP1VIVH0JVYZ04=3@`1C
De<0HF5Q04I6AP1;Bd/0GUiN04I6AP0g=cL0ADE503/k>`1<C4`0?3`l05=CD`1?Cdl0N7Qh055AD@1O
Gel0Hf=S06ATI00j>SX0DE5A04U9B@11@D40BTY:03hn?P1^KVh0K6a/06IVIP14A4@0PX:2059BDP14
A4@0?3`l05IFEP1RHV80GUiN06EUI@1HF5P0J6QX05]KF`1FEUH0>SXj02l_;`1FEUH0CTi>051@D01>
CTh0JVYZ08j>SP1iNGT0Bd];069RHP1>CTh0IfMW07MgM`2GUiL0Vi^K05IFEP1<C4`0EeMG04I6AP0n
?Sh0?clo05EEE@0f=SH0@T9203lo?`1:BTX0E5AD07MgM`26QXH0Kfm_04e=C@0l?3`0CTi>07AdM028
R8P0PX:204e=C@1PH600?Shn071`L02SXj<0KFe]02TY:@1HF5P0<c<c06YZJP1CDe<0GUiN02PX:01`
L700CDe=01lO7`0`<300ATI604=3@`1CDe<0<C4a02TY:@10@400AdM704];B`0[:b/0ADE504i>CP0a
<C40C4a<03hn?P0e=CD0>c/k03dm?@1]KFd0;Rh^07QhN01@D5003@d=05iNGP18B4P0;bl_03dm?@0n
?Sh0CTi>04a<C01JFUX0CDe=05iNGP2GUiL0GUiN04E5A@1FEUH0FEUI06ATI01nOWh0ADE506QXJ01P
H600EUIF051@D019BDT0EUIF04I6AP1=CDd0EUIF06ATI01NGUh0FEUI061PH02>SXh0D51@092@T01b
LW809BDU061PH00T92@0QhN706e]K@1TI6@0F5QH05YJFP1[Jf/0WYjN06MWI`0206YZJP0]0:b/[01U
IFD0L71`06m_K`1IFET0Ph>3069RHP0l?3`0ADE505YJFP0o?cl0>CTi06ATI00d=3@0GUiN04Q8B01B
DU80CTi>07moO`2RXZ80Bd];06a/K01aLG40Ng]k04Q8B01IFET0D51@0410@01GEeL0HV9R059BDP1Q
HF40De=C0;Jf]P2?Shl0Ti>C0;2`/02/[:`0aLG508:2PP1dM7@0XJ6Q0:>SX`1gMgL0V9RH017ooooo
000?ooooo`0h05YJFP1ZJVX0R8R806YZJP1gMgL0De=C08n?S`1mOGd0Hf=S0:6QX@11@D40B4Q807]k
N`1^KVh0NGUi04a<C00j>SX0JFUY0861P@1IFET0NWYj0410@00`<300Bd];055AD@1GEeL0MWIf02LW
9`0m?Cd0LW9b06UYJ@1HF5P0QXJ603@d=01KFe/0GUiN03De=@1=CDd0Jf][03De=@0i>CT0Fe]K06YZ
JP0k>c/0DE5A05EEE@18B4P0Ph>305EEE@0R8R80CDe=06IVIP0k>c/0Ph>3034a<@0/;2`204=3@`3X
03Ph>026QXH0Fe]K01hN7P0k>c/0DU9B04a<C01_Kfl0=SHf01lO7`1:BTX0JFUY071`L013@d<0IFEU
02@T900h>3P0GUiN03@d=00o?cl0K6a/02d];@0j>SX0I6AT0492@P17AdL0OWin04Q8B01DE5@0KFe]
04];B`0K6a/0K6a/05QHF019BDT0Q8B406a/K00`<300AdM705IFEP1:BTX0FEUI08>3P`0h>3P0ATI6
07AdM011@D40MgMg06YZJP0O7al0>CTi05QHF02OWil0FEUI05YJFP1;Bd/0@41008j>SP2@T900=3@d
05mOG`1^KVh0BDU908>3P`2OWil0=CDe04a<C01PH600>3Ph05YJFP1kNg/0DU9B04Q8B01PH600=CDe
06][J`2:RXX0<S8b03Xj>P1QHF40LG5a05QHF025QHD0>3Ph04E5A@1bLW80C4a<03Lg=`1nOWh0CDe=
02d];@1NGUh0NGUi03dm?@21PH40A4A4030`<01ZJVX0NWYj04M7A`1IFET0L71`04i>CP1]KFd0Z:RX
06QXJ00n?Sh0GEeM04i>CP14A4@0LG5a04e=C@0m?Cd0I6AT030`<01?Cdl0Rh^;04a<C00^;Rh0H61P
04I6AP1aLG40TI6A03/k>`0l?3`0Jf][079bLP1GEeL0VIVI05mOG`0o?cl0I6AT06QXJ01PH600S8b<
02HV9P0o?cl0Hf=S08b<S01<C4`0Ng]k04=3@`2;Rh/0PX:205QHF02;Rh/0?Cdm02`/;01mOGd0EeMG
05UIF@0c<c<0@D5108B4Q02>SXh0@D5104Q8B016ATH0=CDe07moO`0o?cl0DU9B08n?S`1KFe/0K6a/
07AdM00l?3`0>3Ph04Y:BP1HF5P0SXj>04];B`0[:b/0De=C06IVIP1=CDd0L71`08R8R00`<300De=C
075aL@1<C4`0G5aL06YZJP0V9RH0<c<c05EEE@1eMGD0AdM706i^KP0f=SH0Bd];06IVIP18B4P0=3@d
04E5A@1BDU80@D5106YZJP1?Cdl08R8R05mOG`18B4P0?Cdm05aLG028R8P0EUIF038b<P1DE5@0@T92
03Ti>@1bLW80FUYJ02@T9012@T80FEUI0451@@1LG5`0BTY:02h^;P11@D40DU9B04E5A@1IFET0TI6A
02l_;`0T92@0BDU904A4A01;Bd/0YJFU03/k>acooooo01H0H61P069RHP1YJFT0Fe]K05UIF@1JFUX0
HF5Q06e]K@1oOgl0U9BD08>3P`1NGUh0Kfm_06EUI@1gMgL0Jf][079bLP20P800JVYZ07emO@1VIVH0
BDU90P1FEUH01@1BDU80DE5A04m?C`1<C4`0GEeM0080AdM701<0LG5a05YJFP1QHF40RXZ:0861P@1k
Ng/0P8200;:b/P2KVi/0AdM70492@P1CDe<0BDU9061PH00o?cl0KVi^05QHF01NGUh0BTY:0080IVIV
08L0BTY:05ADE026QXH0DE5A04i>CP1QHF40CDe=06QXJ01<C4`0BTY:05]KF`1IFET0;bl_05]KF`1=
CDd0Fe]K04a<C01dM7@0EEEE04i>CP1ZJVX0GUiN06UYJ@19BDT0GEeM055AD@0i>CT0IFEU04Y:BP1C
De<0=cLg04A4A00h>3P0>SXj01@D500_;bl0D51@02d];@1?Cdl0BTY:04I6AP11@D40Hf=S04];B`0d
=3@0@41005EEE@1ADE40BTY:04U9B@1SHf<0H61P04Y:BP1SHf<0CTi>05YJFP1>CTh0HV9R055AD@16
ATH0DE5A05mOG`1UIFD0I6AT0451@@1?Cdl0DU9B03Ti>@15ADD0?3`l03Hf=P0_;bl0=cLg04Y:BP1;
Bd/0EEEE05eMG@1^KVh0N7Qh09VIV@1TI6@0HV9R06ATI00m?Cd0Fe]K05QHF01LG5`0QHF505YJFP1B
DU80ATI606EUI@1ADE40HF5Q059BDP1FEUH0EEEE065QH@1KFe/0J6QX06EUI@1;Bd/0KVi^05ADE00o
?cl0GemO04I6AP1GEeL08b<S06i^KP33`l<0MWIf03Ph>01GEeL0ADE507YjNP18B4P0De=C01LG5`13
@d<0?3`l02XZ:P0n?Sh0=cLg02PX:01GEeL0G5aL02d];@0l?3`0:b/[02l_;`0M7Ad0MgMg05YJFP10
@4000P1<C4`0I@1WIfL0Cdm?03lo?`1SHf<0@D5108f=S@1hN7P0<C4a05EEE@16ATH0<c<c03lo?`0g
=cL0BDU905iNGP1_Kfl0Bd];05YJFP1aLG40=SHf03Ti>@13@d<0AdM704m?C`1ZJVX0@d=305=CD`1=
CDd0Hf=S05IFEP1=CDd0B4Q803/k>`1@D500EEEE03hn?P1BDU80O7al05aLG01kNg/0>CTi04e=C@1J
FUX0?clo06IVIP13@d<0Fe]K05iNGP1ZJVX0N7Qh05]KF`1@D500MWIf05MGE`28R8P0G5aL0::RXP1c
Lg<0I6AT06m_K`11@D40GemO06EUI@0d=3@0HF5Q05QHF00n?Sh0Bd];071`L012@T80IFEU03/k>`1]
KFd0EEEE071`L02=SHd0Q8B4092@T01ZJVX0NWYj05iNGP1XJ6P0EEEE04=3@`1RHV80Cdm?05UIF@1V
IVH0=cLg08b<S01`L700Ng]k0;2`/022PX80SHf=0:j^[P21PH40MGEe07YjNP1GEeL0WIfM017ooooo
000?ooooo`3o07AdM02UYJD0Vi^K04U9B@26QXH0Shn?0:RXZ00k>c/0Kfm_08j>SP1VIVH0Vi^K07mo
O`0j>SX0G5aL09RHV01;Bd/0IVIV038b<P0n?Sh0EeMG07MgM`0g=cL0Hf=S03Xj>P1CDe<0SXj>04M7
A`0^;Rh0De=C024Q8@0/;2`0I6AT059BDP1<C4`0=CDe02/[:`10@400YJFU05ADE00N7Qh0ADE504A4
A01YJFT0OWin01/K6`0X:2P0CDe=05eMG@16ATH0QXJ608b<S00U9BD0?3`l055AD@1SHf<0MGEe01hN
7P11@D40HV9R06MWI`1BDU80O7al01XJ6P0/;2`0BDU908b<S01;Bd/0KVi^06UYJ@0N7Qh0Cdm?069R
HP0/;2`0EUIF03Ph>00U9BD0DE5A05aLG01XJ6P0:BTY03Xj>P13@d<0J6QX08J6QP0Y:BT0;Bd]04e=
C@1EEED0@d=309:BTP1PH600=SHf055AD@1IFET0BDU908B4Q02JVYX030`<02XZ:P0`<300BTY:08>3
P`1/K6`071`L03hn?P1GEeL0;2`/02l_;`1<C4`0;Rh^03`l?01mOGd0Bd];02`/;01TI6@0=SHf02/[
:`18B4P0MWIf028R8P14A4@0AdM703hn?P1oOgl0VYZJ02/[:`0J6QX0HV9R07IfMP1cLg<0@T9202<S
8`0Y:BT0JFUY07QhN017AdL0XZ:R03<c<`0X:2P0LG5a09BDU01>CTh0P82002HV9P0P8200?Shn0:f]
[@1SHf<0IVIV01lO7`17AdL0B4Q807AdM00b<S80>SXj03dm?@0];Bd0ADE507alO00/;2`0>3Ph03`l
?01>CTh0DE5A09bLW010@4008R8R071`L01OGel0MWIf0;Jf]P0[:b/07AdM06YZJP1]KFd0DU9B0;Ng
]`0^;Rh0820P06e]K@1JFUX0LW9b07inOP0N7Qh0@D5103lo?`1NGUh0AdM706EUI@0M7Ad0EUIF05QH
F01BDU80@T9209ZJVP0`<300:BTY0861P@0S8b<0Cdm?034a<@13@d<0I6AT06QXJ00h>3P0Ng]k04M7
A`2VYZH0De=C02@T901<C4`0BTY:07inOP2OWil0EEEE01hN7P1>CTh0Cdm?0820P02DU9@0;Bd]03Lg
=`1kNg/0EEEE079bLP1DE5@0@D5106=SH`26QXH0H61P08V9R@0n?Sh0=cLg07IfMP1nOWh0GUiN0:NW
Y`0j>SX0>c/k06i^KP1lO7`0:RXZ03`l?01XJ6P0;bl_04I6AP2:RXX0?3`l030`<01:BTX0;2`/03`l
?01`L700WIfM000S02/[:`15ADD0BDU904e=C@1cLg<0HF5Q02<S8`0[:b/0KVi^06][J`1IFET0Vi^K
02/[:`0M7Ad0BTY:07MgM`16ATH0JFUY08F5Q@0H61P0=SHf05YJFP0^;Rh0EEEE06e]K@0L71`061PH
04e=C@1^KVh09BDU04];B`0G5aL07AdM04];B`1UIFD07?ooool0;`23Ph<0MgMg05iNGP1<C4`0Q8B4
08N7Q`1XJ6P0EeMG05iNGP1QHF40NGUi04a<C01FEUH0HV9R07moO`1VIVH0M7Ad075aL@1;Bd/0H61P
06QXJ01KFe/0C4a<06a/K01aLG40Bd];03Lg=`0n?Sh0@d=3055AD@0X:2P0GemO06=SH`1LG5`0H61P
07emO@1_Kfl0PH6107]kN`1mOGd0<S8b02<S8`0l?3`0>CTi06=SH`0l?3`0?Shn0080AdM700@0>CTi
03Xj>P0b<S80:b/[0P15ADD202PX:02T04];B`1HF5P0>c/k03dm?@0e=CD0De=C04E5A@0h>3P0@d=3
06=SH`0n?Sh0=3@d03/k>`1YJFT0Q8B404U9B@1<C4`0KVi^08j>SP1KFe/0CDe=05=CD`1IFET0Hf=S
079bLP1HF5P0@41003Xj>P1JFUX0;2`/02/[:`0g=cL0>CTi04m?C`13@d<0?clo05ADE01EEED0;bl_
03`l?01[Jf/0G5aL03/k>`12@T80@d=303lo?`1?Cdl0?Cdm06EUI@1YJFT0ADE504I6AP1[Jf/0Ng]k
05aLG01?Cdl0JVYZ06e]K@22PX80DU9B04E5A@1RHV80B4Q805MGE`1<C4`0<30`04M7A`0g=cL0ATI6
030`<01LG5`0WYjN0861P@20P800Ph>305mOG`1]KFd0KVi^06e]K@2=SHd0@D5105]KF`1WIfL0FUYJ
04A4A019BDT0G5aL038b<P1WIfL0Cdm?04];B`1?Cdl0HV9R04a<C01ADE40@d=3065QH@1UIFD0LG5a
05eMG@1/K6`0I6AT08J6QP1LG5`0EEEE09JFUP1oOgl0<S8b06YZJP1;Bd/0J6QX04Y:BP1HF5P0>c/k
05]KF`0d=3@09BDU03lo?`0d=3@0<c<c05EEE@19BDT0;Bd]02/[:`0T92@0DU9B01/K6`0h>3P0?clo
03dm?@1<C4`0=CDe03Xj>P1ADE40@41005]KF`16ATH0JFUY06IVIP0M7Ad0KFe]051@D00S8b<0ATI6
04U9B@1PH600@d=305=CD`0i>CT0ADE50492@P0_;bl0:RXZ04E5A@1OGel0=cLg055AD@1UIFD0P820
07=cL`1LG5`0Kfm_03@d=012@T82055AD@0D05QHF01FEUH0BTY:04A4A01=CDd0QhN706UYJ@2GUiL0
N7Qh02h^;P1>CTh0=CDe07]kN`1SHf<0>CTi04i>CP19BDT0Bd];075aL@0l?3`205UIF@0E07QhN01V
IVH0IfMW0861P@17AdL0De=C04];B`0e=CD0DE5A05=CD`0g=cL0>CTi04U9B@0M7Ad0CTi>04];B`1S
Hf<0EUIF09^KV`2UYJD0@D510080?clo00h0IVIV04E5A@1XJ6P0D51@03Lg=`1IFET0GEeM07IfMP1@
D5009BDU06m_K`27QhL0Shn?09jNWP80];Bd00H0TY:B07inOP2CTi<0LG5a04];B`27QhLAooooo`00
3oooool0o`1>CTh0M7Ad09BDU01:BTX0DU9B05EEE@2;Rh/0@T920410@01;Bd/0>CTi04a<C01nOWh0
AdM70492@P16ATH0De=C08n?S`0o?cl09bLW03hn?P17AdL0Fe]K08:2PP14A4@0;Rh^06YZJP1RHV80
GemO08N7Q`0U9BD08b<S05UIF@1[Jf/0WinO06YZJP0R8R80:RXZ05IFEP1^KVh0AdM708f=S@18B4P0
@D5105YJFP0k>c/0EEEE0;2`/00a<C40=SHf07=cL`1/K6`0?3`l06IVIP0N7Qh0DE5A09fMW@25QHD0
8R8R04U9B@16ATH0:BTY07]kN`1<C4`0:2PX04a<C011@D40CDe=06a/K029RHT0;2`/03Hf=P1<C4`0
N7Qh0;Rh^01bLW807alO02LW9`1GEeL0Jf][06QXJ02j^[X0=CDe03Xj>P1^KVh0M7Ad05eMG@37alL0
;2`/02HV9P11@D40I6AT030`<02JVYX0=3@d02l_;`1JFUX0RXZ:05YJFP0k>c/0Lg=c030`<01`L700
Lg=c01DE5@0d=3@0BTY:04E5A@1KFe/0W9bL03hn?P0j>SX0De=C06UYJ@1JFUX0_;bl04a<C00O7al0
AdM708>3P`1OGel0_[jn03/k>`0P8200D51@05aLG010@400@d=3096AT@0N7Qh0De=C05IFEP0Z:RX0
ATI6055AD@0Z:RX0FEUI06UYJ@1FEUH08b<S04E5A@13@d<0JFUY09jNWP0g=cL09bLW03Lg=`11@D40
DU9B08N7Q`0Q8B40>SXj06QXJ01HF5P0E5AD08f=S@27QhL06a/K04A4A01OGel0E5AD092@T02JVYX0
<S8b04e=C@14A4@0KFe]0410@02BTY80=SHf03@d=01FEUH0QHF504i>CP21PH40<S8b04a<C01oOgl0
E5AD03Ti>@1;Bd/0?Cdm061PH02LW9`0Bd];02TY:@1FEUH0C4a<069RHP2][Jd0B4Q803Hf=P1@D500
A4A406YZJP3?cll0Cdm?01TI6@1ZJVX0BTY:08N7Q`1ADE409RHV04m?C`1oOgl0Bd];0:f][@0b<S80
J6QX05aLG00j>SX0L71`034a<@0V9RH0JVYZ06i^KP0Q8B40@D5102TY:@1KFe/0Shn?04U9B@1?Cdl0
De=C02<S8`1lO7`0OWin02/[:`1>CTh0=CDe0492@P1oOgl0K6a/01DE5@0l?3`0D51@04];B`2@T900
N7Qh01dM7@0j>SX0GemO04Q8B01fMWH0Q8B402PX:00Q8B40NGUi04I6AP1/K6`0RHV902@T900V9RH0
BDU908j>SP008`1bLW80R8R804U9B@0e=CD0Q8B408^;R`0^;Rh0IfMW09jNWP18B4P0C4a<09^KV`1W
IfL0=SHf07QhN00h>3P0>CTi05ADE026QXH0@d=30492@P0];Bd0>SXj05eMG@1iNGT09BDU01hN7P0b
<S80@41003lo?`2;Rh/08R8R020P800`<300De=C01cooooo0680IVIV06UYJ@2<S8`0IVIV079bLP1_
Kfl0O7al06UYJ@2ZZZX0Ti>C0;Bd]01ADE40GUiN05EEE@1nOWh0SXj>08V9R@2FUYH0E5AD06ATI01N
GUh0DE5A051@D01LG5`0Fe]K04];B`16ATH0CTi>05EEE@1XJ6P0;2`/07=cL`28R8P0S8b<07IfMP2P
X:00S8b<0:6QX@3IfMT0`l?303lo?`13@d<0Lg=c0492@P1kNg/0@41006ATI01GEeL0IfMW04M7A`1B
DU80H61P03`l?01IFET0M7Ad04M7A`13@d<0H61P03@d=01TI6@0DE5A04A4A00i>CT0@d=302l_;`19
BDT0=CDe0492@P11@D40IVIV03Ti>@0O7al0DU9B05]KF`12@T8071`L03Xj>P12@T80=3@d05UIF@0Q
8B40<S8b02d];@10@400>SXj0492@P0O7al0:b/[03lo?`0b<S80>c/k04M7A`11@D40;bl_059BDP0h
>3P0;Bd]01lO7`80?3`l00h0?Cdm03De=@0l?3`0Cdm?04i>CP1?Cdl0C4a<05ADE01NGUh0DE5A02l_
;`0o?cl0GemO05]KF`80J6QX02D0B4Q805ADE01<C4`0ATI605]KF`1?Cdl0CTi>059BDP0o?cl0FEUI
0492@P1nOWh0F5QH079bLP1OGel0IVIV055AD@1GEeL0HV9R0451@@1?Cdl0E5AD059BDP1aLG40EUIF
05eMG@19BDT0Q8B406=SH`1]KFd0?clo04I6AP1FEUH0H61P05mOG`1ZJVX0IfMW0080BDU903H0@T92
04e=C@21PH40Bd];051@D00G5aL0G5aL0;fm_@2>SXh0:b/[04U9B@1]KFd0RXZ:06=SH`1VIVH09BDU
03<c<`0^;Rh0=3@d04=3@`1=CDd0;bl_04Y:BP1IFET0?clo04e=C@10@400=cLg018B4P1?Cdl0C4a<
03Hf=P1PH600@41004E5A@18B4P0?Cdm05EEE@0c<c<0Ng]k079bLP0Y:BT0BDU903Lg=`0k>c/0BTY:
02h^;P10@400DU9B065QH@1ADE40Hf=S05YJFP1IFET305QHF00=04M7A`1?Cdl0=SHf059BDP1JFUX0
C4a<05UIF@0k>c/0ADE503De=@1>CTh0I6AT03Xj>P0204a<C00[059BDP2>SXh0<c<c0410@01IFET0
AdM705UIF@17AdL0MGEe05=CD`1GEeL0O7al06a/K01PH600C4a<03Hf=P1/K6`0>3Ph07QhN01bLW80
E5AD05QHF016ATH0KFe]061PH00I6AT0Kfm_06QXJ00j>SX0=cLg05=CD`18B4P0MWIf03hn?P21PH40
ADE504Q8B01`L700F5QH06ATI01GEeL0I6AT04U9B@0205=CD`0B05IFEP1[Jf/0DE5A05=CD`1eMGD0
BDU907alO01bLW80R8R809bLW01TI6@0Lg=c0;bl_02DU9@0M7Ad0:f][@1_Kfl0W9bL4Oooool000oo
oooo02@0FUYJ059BDP1cLg<0I6AT07YjNP1EEED0K6a/092@T02NWYh0TY:B03Ti>@1;Bd/0CDe=05aL
G029RHT08B4Q03/k>`1BDU80Hf=S04E5A@1dM7@0?clo02LW9`0m?Cd0DE5A05eMG@1BDU80<c<c0451
@@21PH40Rh^;03Ti>@1>CTh0<C4a07YjNP2NWYh2030`<02903hn?P0/;2`0DE5A0<71`@1[Jf/09BDU
03lo?`0n?Sh0G5aL09VIV@1gMgL07AdM04Q8B01_Kfl0D51@07alO00_;bl0<c<c061PH02IVIT0C4a<
08:2PP0M7Ad0:b/[05]KF`2?Shl0DE5A09jNWP0R8R809RHV05EEE@1:BTX0=CDe04E5A@14A4@07AdM
05IFEP1XJ6P09RHV03Ti>@1GEeL092@T02`/;01HF5P0BTY:030`<01@D500=SHf03`l?01iNGT0FUYJ
01LG5`0[:b/0>3Ph05IFEP31`L40J6QX01LG5`0c<c<0Cdm?075aL@2;Rh/0YZJV038b<P1HF5P0IFEU
04a<C01cLg<0EeMG01hN7P15ADD0HV9R05QHF01YJFT0CDe=02l_;`1@D500K6a/06i^KP0U9BD0C4a<
05eMG@0i>CT0VYZJ09FEU@0e=CD0CDe=05ADE00c<c<0F5QH0;Zj^P1eMGD0>CTi05UIF@19BDT0Ph>3
0:b/[00X:2P0@41006IVIP1ZJVX0OWin0820P00V9RH0>SXj08b<S025QHD0Cdm?09RHV00c<c<06a/K
06QXJ01?Cdl0?3`l09^KV`0[:b/0=SHf07alO029RHT0PH6108Z:RP1FEUH0>c/k0820P02KVi/0EUIF
03Lg=`1OGel0<c<c051@D02<S8`0BDU903`l?00n?Sh0EEEE05IFEP2j^[X00P0g=cL0<@1?Cdl0HV9R
08n?S`1TI6@0;Rh^06IVIP2FUYH0L71`04Y:BP26QXH0BTY:04Q8B02a/K40Ogmo04m?C`1nOWh0;bl_
0451@@1KFe/0L71`04U9B@1UIFD0B4Q804i>CP1XJ6P0@D5106ATI00[:b/0?Shn09bLW01JFUX0Kfm_
04=3@`1PH600Zj^[0:BTY01dM7@0C4a<05UIF@1ADE40WYjN01PH6015ADD0JVYZ05iNGP1mOGd0M7Ad
020P8019BDT00P1PH6006P2d];@08b<S024Q8@20P800^KVi04E5A@1gMgL0L71`0451@@1;Bd/0RXZ:
03Ti>@1MGEd0JFUY02`/;01ADE40QXJ607inOP0g=cL0;2`/04Y:BP1MGEd0U9BD05MGE`0O7al0?Shn
0P0i>CT08P1<C4`0BDU902LW9`1BDU80B4Q804=3@`28R8P0[Jf]04Q8B00^;Rh0C4a<06e]K@1YJFT0
V9RH03`l?00d=3@0@d=305QHF01]KFd0PH6103hn?P0];Bd0BTY:05aLG01JFUX0DU9B07moO`0M7Ad0
=SHf055AD@19BDT0?Cdm05eMG@0P820Looooo`0Z07MgM`21PH40MWIf04i>CP1UIFD0MgMg09bLW022
PX80XZ:R09FEU@2a/K40TY:B09JFUP1eMGD0a<C408f=S@27QhL0TY:B08f=S@2CTi<0QXJ6059BDP1l
O7`0IFEU07UiN@1`L700I6AT051@D01PH600Fe]K04];B`2GUiL0Ng]k06e]K@21PH40U9BD08j>SP2/
[:`0gMgM0<c<c013@d<0>c/k0P18B4P01`20P800@d=306UYJ@1XJ6P0I6AT04M7A`1HF5P00P1MGEd0
7`1IFET0NWYj069RHP1GEeL0KVi^04M7A`25QHD0Fe]K05=CD`12@T80LW9b0451@@1RHV80F5QH051@
D019BDT0IfMW051@D01CDe<0JFUY059BDP1EEED0BTY:05aLG01RHV80@41007]kN`0j>SX0EEEE03dm
?@10@4000P17AdL03@0R8R80:RXZ05YJFP12@T80Hf=S04e=C@1FEUH0?clo05]KF`12@T80@d=305EE
E@1GEeL00P13@d<0_@0f=SH0<c<c04I6AP0[:b/0C4a<04Y:BP18B4P09BDU04];B`0a<C40>3Ph038b
<P14A4@0FEUI04M7A`0k>c/0@d=304U9B@0o?cl0CTi>03<c<`0T92@0>c/k05IFEP1<C4`0HV9R08J6
QP2VYZH0WIfM0;jn_P2ZZZX0Hf=S06YZJP1mOGd0EEEE08R8R01nOWh0DU9B08b<S01hN7P0IfMW06QX
J01?Cdl0;Rh^03lo?`17AdL0Lg=c030`<017AdL0Hf=S06MWI`1_Kfl0BTY:06][J`1UIFD0?clo055A
D@1MGEd0QHF5010@4016ATH0h^;R0;:b/P1;Bd/0K6a/03Xj>P1BDU80E5AD059BDP0H61P0D51@04Q8
B00V9RH0>c/k03Ti>@0Z:RX0DE5A03Xj>P0X:2P0;bl_02`/;01=CDd0@T9204e=C@1HF5P0>CTi04Y:
BP1DE5@0IFEU055AD@0k>c/0B4Q804Y:BP2<S8`0Ogmo02/[:`1RHV80ATI602TY:@17AdL0?3`l04U9
B@1TI6@0K6a/03De=@19BDT0CDe=05eMG@0];Bd0=CDe04a<C018B4P0LW9b03De=@1EEED0L71`0410
@01dM7@0CTi>05]KF`1HF5P0Fe]K05mOG`1GEeL0E5AD079bLP1DE5@0JFUY03Ti>@1?Cdl0G5aL03<c
<`1eMGD0;2`/065QH@1LG5`0=cLg04e=C@15ADD0C4a<05UIF@16ATH0DE5A0410@02GUiL0Ng]k08V9
R@2[Zj/0BDU904Y:BP0n?Sh06QXJ02d];@0f=SH0<30`059BDP1WIfL0B4Q80820P017AdL0Fe]K01lO
7`28R8P0Zj^[07AdM01aLG40HV9R09ZJVP1:BTX0Bd];05EEE@0o?cl0Hf=S05ADE01PH600Jf][03Lg
=`2f][H0S8b<07alO02e]KD0Shn?08J6QP2:RXX0RHV90820P01PH600Fe]K075aL@0Aooooo`003ooo
ool0B`2=SHd0SXj>061PH01FEUH0MGEe05UIF@1/K6`0A4A407EeM@2CTi<0FUYJ04I6AP1IFET0:RXZ
07UiN@1:BTX0?Shn04i>CP0n?Sh0ATI607moO`1CDe<0:RXZ03Ti>@14A4@0/K6a075aL@0Y:BT0:2PX
04m?C`2?Shl0Lg=c08f=S@0d=3@0?clo07inOP1FEUH0NWYj07UiN@0Z:RX09BDU06m_K`26QXH0GUiN
0861P@0@4100EeMG05]KF`1=CDd0=cLg06EUI@1FEUH07AdM06UYJ@15ADD0?clo04Y:BP0P8200BDU9
06=SH`1LG5`071`L03dm?@11@D40Bd];07=cL`1fMWH06a/K03De=@19BDT0CDe=07inOP1UIFD05aLG
03@d=00205EEE@2U09jNWP31`L407AdM01DE5@0l?3`0GUiN07]kN`2YZJT092@T020P801[Jf/0O7al
05]KF`2XZ:P0DE5A02<S8`1WIfL0QhN703dm?@1ADE40?Cdm01/K6`1;Bd/0@T9203Ph>01HF5P0<30`
0492@P1VIVH0Fe]K01dM7@0d=3@0DE5A03Ti>@1aLG40QXJ602DU9@18B4P0FUYJ06MWI`1<C4`0MWIf
07emO@0g=cL0H61P09BDU02PX:00Q8B408:2PP0c<c<0:BTY05IFEP2?Shl0P82003/k>`0Z:RX0De=C
08j>SP1eMGD0D51@07UiN@0g=cL0?clo08F5Q@0/;2`0De=C06EUI@14A4@0@41007UiN@1bLW8092@T
05QHF01OGel0KFe]0:JVYP1ZJVX08B4Q04e=C@1/K6`0HF5Q07alO02DU9@07AdM0492@P1dM7@0TY:B
06][J`2j^[X08b<S03<c<`1eMGD0Jf][08B4Q01[Jf/0:2PX04Q8B020P800EEEE04e=C@28R8P0=SHf
04Q8B01/K6`0?Shn03`l?01LG5`0?Cdm0410@01LG5`0P82003@d=010@400Jf][05=CD`1kNg/092@T
034a<@0n?Sh0>CTi04A4A02?Shl0;Bd]06ATI01>CTh0F5QH0820P00n?Sh09bLW061PH01_Kfl0NWYj
0451@@0Q8B40GEeM0;jn_P2m_Kd0ZZZZ07emO@1LG5`0IfMW04A4A01lO7`0CTi>03@d=01MGEd0RHV9
03`l?01DE5@0JVYZ03`l?027QhL0Fe]K03<c<`1UIFD0ATI605ADE01dM7@0XJ6Q03dm?@1RHV80ADE5
05=CD`1kNg/0WYjN0080:RXZ02h0GUiN0820P01cLg<0HV9R02XZ:P11@D40De=C07=cL`1VIVH0Ng]k
06IVIP0^;Rh0D51@05EEE@1]KFd0UiNG05]KF`0D51@0<c<c0820P01dM7@0Hf=S07UiN@0`<30092@T
06ATI01GEeL08b<S03@d=01BDU8030`<04];B`1ZJVX09RHV04M7A`0d=3@0:BTY04M7A`1RHV80=3@d
01XJ6P0n?Sh0:b/[04M7A`1jNWX09BDU7?ooool0<`2JVYX0TI6A06e]K@1GEeL0R8R806m_K`1fMWH0
JFUY08j>SP2f][H0W9bL05QHF01DE5@0ATI605mOG`1^KVh0QXJ607alO016ATH0EUIF06IVIP1SHf<0
?Shn04U9B@1iNGT0DE5A07UiN@1BDU80Fe]K04M7A`0V9RH0DE5A06MWI`1KFe/0A4A406i^KP2CTi<0
PH610:6QX@22PX80FEUI04U9B@0i>CT0ADE506YZJP1EEED0Jf][069RHP1CDe<0B4Q8055AD@0204I6
AP1805EEE@1WIfL0BTY:04m?C`1PH600C4a<071`L01bLW80JFUY055AD@1QHF40>3Ph05UIF@1LG5`0
Hf=S04];B`1aLG40N7Qh07UiN@1WIfL0F5QH06QXJ014A4@0De=C05ADE018B4P0Kfm_04I6AP1NGUh0
AdM704A4A013@d<0CTi>03Ti>@0W9bL0ATI60451@@1XJ6P0DU9B05QHF00l?3`0J6QX03`l?01EEED0
CTi>05IFEP16ATH0B4Q804=3@`16ATH0F5QH03`l?01_Kfl0DE5A06ATI010@400JVYZ03hn?P1ADE40
@D5105QHF016ATH0EEEE02<S8`0b<S80?Cdm03De=@13@d<0>c/k03Hf=P0l?3`0;2`/0P13@d<09`1H
F5P0>CTi04i>CP1<C4`0D51@05]KF`1lO7`0DE5A05eMG@1VIVH0K6a/07emO@1^KVh0A4A403/k>`0T
92@0AdM703Ti>@1DE5@0>3Ph0492@P0`<300C4a<0410@00m?Cd0?Shn05MGE`1NGUh0J6QX07moO`2<
S8`0N7Qh051@D00k>c/0BDU9096AT@1cLg<09RHV04E5A@0205]KF`0<06QXJ01OGel06a/K04I6AP0d
=3@09BDU04I6AP0];Bd0<30`04a<C012@T808b<S0P0g=cL0K00l?3`0<C4a075aL@1[Jf/0Fe]K069R
HP0e=CD0=SHf04A4A00o?cl0FUYJ04M7A`1[Jf/0H61P02`/;011@D40A4A402`/;015ADD0:2PX04E5
A@17AdL0N7Qh05MGE`1lO7`0IfMW06e]K@1:BTX0JFUY06YZJP15ADD0PH6104i>CP1aLG40H61P05iN
GP1JFUX0;2`/04];B`0g=cL0@D5104Y:BP11@D40BTY:051@D01CDe<0YJFU06MWI`29RHT0L71`02PX
:01DE5@0@d=307alO01DE5@0EEEE06=SH`1>CTh0@41007IfMP0b<S80FEUI03Hf=P28R8P0I6AT05]K
F`1DE5@0=cLg069RHP25QHD0DE5A04A4A01DE5@0@41003lo?`1gMgL0;Rh^05aLG01JFUX0Y:BT04Y:
BP1BDU80GemO051@D01QHF40<S8b05eMG@0o?cl0EEEE05=CD`17AdL0JFUY05aLG01gMgL0IVIV051@
D01/K6`0VIVI09FEU@28R8P0Shn?0;Jf]P2PX:00YZJV09fMW@1TI6@0GEeM09>CTa7ooooo000?oooo
o`0b08N7Q`2RXZ80VIVI04i>CP1hN7P0RXZ:0:JVYP0n?Sh0AdM706][J`23Ph<0O7al08^;R`12@T80
EEEE059BDP1VIVH0RHV9030`<00W9bL0B4Q806IVIP15ADD0QXJ603Hf=P0Y:BT0D51@04A4A01?Cdl0
DU9B01<C4`12@T80F5QH02`/;01BDU80?clo02HV9P1GEeL0S8b<02DU9@0N7Qh0D51@04I6AP1=CDd0
[jn_02`/;00a<C40GUiN04Y:BP0k>c/207UiN@3^01TI6@19BDT0@410075aL@1oOgl0820P02/[:`19
BDT0Ph>305aLG01_Kfl06a/K038b<P1kNg/0SHf=055AD@20P800FEUI02HV9P11@D40HF5Q04=3@`1m
OGd0>3Ph02<S8`1:BTX0RHV906UYJ@0f=SH0FUYJ01`L701:BTX0SXj>05EEE@0T92@0Cdm?034a<@0/
;2`0L71`05iNGP0Y:BT0@41003Ph>01RHV80TY:B08J6QP0E5AD0>CTi05UIF@1VIVH0Ti>C069RHP0K
6a/0?Cdm04I6AP1IFET0N7Qh0:b/[00Q8B40>3Ph06e]K@1BDU80EeMG09:BTP0K6a/0ADE504Y:BP1N
GUh0B4Q809fMW@0c<c<0<C4a075aL@1iNGT0?clo03/k>`1QHF40?3`l06e]K@1cLg<0:RXZ0492@P1F
EUH0D51@05aLG02NWYh0;Rh^03De=@1HF5P0G5aL08B4Q02DU9@0:BTY03`l?01DE5@0U9BD04U9B@27
QhL0=CDe03Ph>01bLW80KFe]03/k>`1^KVh0JFUY01XJ6P1=CDd0L71`03dm?@1TI6@0IFEU02@T901=
CDd0HV9R079bLP0c<c<0GUiN0410@02PX:00WIfM02LW9`0Y:BT0De=C03Hf=P1FEUH0[jn_05MGE`0]
;Bd0G5aL06=SH`1eMGD0Vi^K03<c<`0o?cl0BTY:06m_K`1hN7P0OGem01PH601MGEd0PH6105aLG01]
KFd0P82002DU9@0n?Sh0Y:BT04U9B@1HF5P0820P0410@01FEUH0DE5A03lo?`1kNg/0=CDe0:6QX@2B
TY80<S8b061PH00e=CD0>SXj07UiN@29RHT0;Rh^061PH00k>c/0Xj>S08f=S@0_;bl0G5aL071`L01Q
HF40QXJ605EEE@0_;bl0Ogmo05]KF`1QHF40][Jf05=CD`1<C4`0I6AT0:BTY01mOGd0`l?304a<C00c
<c<0IFEU092@T01GEeL0I6AT096AT@0M7Ad0?Shn06QXJ00`<300Cdm?05iNGP0P8200>c/k05=CD`1/
K6`0<S8b03lo?`0J6QX0DE5A08j>SP26QXH09bLW03<c<`1RHV80<30`059BDP2FUYH0;bl_02@T901;
Bd/0B4Q804I6AP1dM7@0WinO01TI6@0/;2`0FEUI07QhN02DU9@0Fe]K01XJ6P0O7al0A4A405eMG@0k
>c/0QhN701lO7`1:BTX0EUIF03dm?Acooooo08/0GUiN079bLP2HV9P0T92@08n?S`1oOgl0SHf=09:B
TP1KFe/0FUYJ06e]K@2HV9P0YjNW06YZJP2?Shl0/K6a0<C4a02ATI40DU9B065QH@1NGUh0D51@05YJ
FP1@D500IfMW05]KF`1PH600FUYJ04a<C01KFe/0DE5A08:2PP1UIFD0F5QH065QH@26QXH0GemO09FE
U@2LW9`0Jf][0492@P14A4@0D51@04M7A`1DE5@0=SHf04Q8B01OGel0Cdm?03De=@0i>CT0D51@04=3
@`0l?3`0?Cdm051@D01BDU80B4Q803Lg=`1FEUH0RHV905]KF`0m?Cd0CTi>05ADE018B4P0@d=3051@
D01[Jf/0FEUI03<c<`0Z:RX0B4Q804U9B@14A4@08b<S03/k>`13@d<0>CTi06QXJ01QHF40Fe]K051@
D013@d<0<c<c04U9B@0^;Rh0;bl_04M7A`13@d<0A4A4061PH012@T80=3@d04E5A@1[Jf/0BTY:03Hf
=P11@D40De=C055AD@0h>3P0=cLg04E5A@12@T80FEUI04a<C01GEeL0Cdm?065QH@1>CTh0D51@04];
B`1]KFd0C4a<06][J`0/;2`0Bd];04Q8B00[:b/0BDU90492@P11@D40EEEE03dm?@1EEED0IFEU09:B
TP1hN7P0UYJF07QhN028R8P0=SHf03/k>`1DE5@0F5QH075aL@18B4P09BDU0080E5AD05X0FUYJ03/k
>`1QHF40AdM705EEE@10@400EUIF02DU9@1:BTX0DU9B05MGE`14A4@0Cdm?04];B`14A4@0@D5105UI
F@1RHV80LW9b04e=C@1MGEd0cLg=09>CT`0N7Qh0ADE504e=C@1mOGd0H61P06UYJ@0E5AD0?3`l03De
=@18B4P0Jf][0451@@0R8R80D51@0492@P0e=CD0Bd];038b<P12@T805QHF03Ph>01FEUH0:b/[02h^
;P10@400D51@0492@P0`<300BTY:03hn?P2_[jl0W9bL04Q8B01HF5P0ATI603De=@18B4P0>3Ph04Y:
BP1TI6@0N7Qh04];B`1GEeL0Bd];055AD@0n?Sh0>3Ph05QHF01<C4`0EEEE03Lg=`1?Cdl0CDe=03Lg
=`1>CTh0<c<c04=3@`0c<c<0AdM705UIF@0f=SH0FUYJ08B4Q01TI6@0CTi>0410@00n?Sh204m?C`06
07AdM01=CDd0EEEE051@D00a<C40K6a/0P12@T80:P1NGUh0?3`l08N7Q`0n?Sh0Q8B4055AD@1QHF40
^;Rh075aL@1=CDd0C4a<02DU9@1RHV80Rh^;0451@@0j>SX0EUIF01LG5`1`L700Fe]K04];B`0c<c<0
M7Ad096AT@25QHD0ZZZZ08J6QP24Q8@0EUIF05ADE01GEeL0IFEU07inOP16ATH0EeMG09>CT`1XJ6P0
KFe]09ZJVP2WYjL0UiNG0820P080YJFU00D0PX:207UiN@1/K6`0MgMg0<71`@0Aooooo`003oooool0
F01EEED0HF5Q0:f][@23Ph<0Jf][04e=C@22PX80MgMg08N7Q`1dM7@0>CTi06m_K`29RHT0BTY:06UY
J@0S8b<0D51@092@T01XJ6P0@41005EEE@0b<S80@41006e]K@12@T80=CDe03`l?00[:b/0F5QH0:b/
[01CDe<09BDU05]KF`1TI6@0YZJV08F5Q@0X:2P09RHV04e=C@1eMGD0BTY:0:JVYP1>CTh0:b/[03lo
?`1:BTX0SXj>0;>c/`0j>SX0ADE504I6AP15ADD0AdM708Z:RP0O7al0C4a<08R8R00k>c/0:b/[05aL
G01:BTX0=SHf05aLG00b<S80:b/[06YZJP0i>CT0;bl_04Q8B01NGUh061PH03<c<`1BDU80AdM709ZJ
VP1^KVh0820P03lo?`1:BTX0HF5Q07MgM`2;Rh/0:RXZ02HV9P1<C4`0MGEe04];B`2HV9P202TY:@1B
04M7A`1GEeL0B4Q806=SH`0C4a<0=cLg08b<S020P800?clo05=CD`1XJ6P0?3`l08Z:RP2JVYX0@410
05YJFP12@T80:BTY05UIF@1aLG40FUYJ03dm?@0g=cL0FUYJ08^;R`2i^KT0Fe]K01dM7@14A4@0?clo
05ADE035aLD0?Cdm024Q8@16ATH0P82006YZJP26QXH0V9RH0492@P1<C4`0Kfm_04e=C@1WIfL0RHV9
020P801;Bd/0WIfM07EeM@1NGUh0JFUY02TY:@1SHf<0PX:203De=@11@D40Jf][0451@@0/;2`0O7al
03Hf=P0h>3P0GEeM059BDP1GEeL0a/K60;bl_01CDe<09bLW05QHF01:BTX0_kno0<71`@0h>3P0>SXj
05IFEP1ADE40Fe]K0;no_`0e=CD0<30`07MgM`80LG5a0780MGEe03Hf=P10@400I6AT07IfMP1?Cdl0
=SHf02LW9`1>CTh0QHF508>3P`0o?cl0BTY:038b<P1EEED0Ti>C05IFEP14A4@0EUIF04Q8B01GEeL0
U9BD0492@P0`<300@d=306m_K`2[Zj/0Bd];02LW9`1NGUh0G5aL04m?C`2GUiL0:b/[04M7A`1XJ6P0
O7al09fMW@1=CDd0>SXj05MGE`1^KVh0FUYJ06IVIP0V9RH0Fe]K075aL@1/K6`0^[Zj08V9R@0Z:RX0
JFUY0;Bd]01DE5@0JVYZ03@d=00^;Rh0IFEU07QhN013@d<0MWIf05ADE00^;Rh0MWIf06ATI00U9BD0
Fe]K03hn?P0o?cl0De=C08V9R@1SHf<0@T9203<c<`0l?3`0SHf=0<;2`P0n?Sh0:b/[04A4A01MGEd0
?clo09bLW00^;Rh0=cLg05mOG`1jNWX0ADE507AdM02FUYH0>c/k04A4A01:BTX0GEeM05MGE`2EUID0
7AdM03dm?@1@D500ADE502h^;P1LG5`08b<S02PX:01`L700HV9R038b<P1=CDd0@D5101/K6`0V9RH0
KFe]02`/;00V9RH204M7Aacooooo0340Kfm_07inOP1HF5P0AdM705iNGP1VIVH0LW9b05]KF`2:RXX0
Q8B40:VYZ@1QHF40IVIV06][J`1iNGT0HV9R04];B`2?Shl0FUYJ07QhN024Q8@0FEUI04I6AP1<C4`0
QHF507inOP1^KVh0IVIV05ADE02QXJ40@d=304e=C@1HF5P0GEeM08J6QP1jNWX0N7Qh09:BTP2<S8`0
MgMg03De=@1EEED0B4Q80451@@1jNWX0Cdm?06YZJP22PX80IVIV0080EEEE05d0HF5Q04=3@`1KFe/0
Ng]k0451@@0j>SX0F5QH04];B`1gMgL0Bd];04m?C`19BDT0IVIV02XZ:P1GEeL0BDU905iNGP0h>3P0
HV9R04Y:BP0k>c/0ADE505MGE`1BDU80>3Ph03Ti>@1JFUX0Kfm_069RHP0g=cL0<c<c06=SH`0U9BD0
:b/[06QXJ00c<c<07alO03lo?`19BDT0@41003Ti>@0f=SH0:BTY059BDP0m?Cd0Bd];03@d=00i>CT0
BTY:04];B`0_;bl0H61P03<c<`0V9RH0C4a<07]kN`15ADD09bLW04i>CP10@400Cdm?05IFEP18B4P0
@T9205iNGP0n?Sh0DU9B04M7A`0m?Cd0A4A404M7A`1;Bd/0CTi>03dm?@1RHV80S8b<08F5Q@23Ph<0
[Zj^0:FUY@24Q8@0=3@d065QH@1@D500Cdm?06a/K01^KVh0DE5A071`L01^KVh0JFUY05=CD`1JFUX0
0P10@400T00k>c/0EUIF03Lg=`1CDe<0FUYJ071`L01GEeL0FEUI06UYJ@1HF5P0B4Q8051@D016ATH0
MgMg02`/;01YJFT0/;2`08b<S01>CTh0L71`065QH@1CDe<0EUIF061PH00];Bd0De=C04m?C`0W9bL0
8B4Q03Lg=`0o?cl0C4a<04I6AP0i>CT0;Bd]03dm?@1EEED0@d=306a/K01hN7P0>SXj04I6AP19BDT0
JVYZ05=CD`0g=cL0Bd];03Hf=P1:BTX0CDe=01<C4`1KFe/0AdM701`L7017AdL0<C4a04Q8B00];Bd0
E5AD03De=@1GEeL0MGEe071`L00f=SH0BDU9059BDP0_;bl0De=C04=3@`1HF5P0IfMW03lo?`1TI6@0
@d=304Y:BP1<C4`0B4Q803lo?`1@D500EeMG03lo?`15ADD0IfMW05MGE`1]KFd0LW9b01`L7017AdL0
;Bd]07]kN`1CDe<0=3@d04i>CP1ADE40J6QX08V9R@0_;bl0FUYJ04E5A@2TY:@0MWIf04M7A`16ATH0
>SXj0410@01KFe/051@D02d];@1QHF40>CTi04E5A@1IFET0?Cdm06m_K`1KFe/0CTi>05YJFP23Ph<0
TI6A03hn?P1FEUH0=SHf051@D00a<C40BDU904A4A00/;2`0HF5Q04Y:BP1^KVh0MWIf03hn?P1kNg/0
QhN709:BTP2IVIT0I6AT08F5Q@2`/;00Y:BT08Z:RP1eMGD0H61P07YjNQ7ooooo000?ooooo`3o079b
LP1^KVh0DU9B05iNGP2;Rh/0BDU904a<C01OGel0PX:20<;2`P0o?cl0>c/k071`L02<S8`0MGEe03dm
?@0a<C40F5QH06i^KP1dM7@0W9bL02LW9`0c<c<0EUIF06][J`1kNg/0;bl_04E5A@11@D40QXJ60;Bd
]01mOGd0/k>c038b<P1XJ6P0LW9b02l_;`1GEeL0JVYZ01/K6`0^;Rh0JVYZ08V9R@17AdL0;bl_02DU
9@14A4@0UIFE07inOP0h>3P0F5QH03`l?016ATH0Vi^K0492@P0a<C40HF5Q06ATI01JFUX0WYjN03/k
>`0W9bL0?Cdm05IFEP2<S8`0clo?02/[:`0^;Rh0Cdm?04Y:BP0o?cl0UYJF06QXJ00a<C40HF5Q08b<
S01ADE40NWYj07MgM`0W9bL09RHV05IFEP11@D40ADE505]KF`0_;bl0?clo05=CD`0o?cl08b<S06a/
K00o?cl0QHF508R8R00g=cL07AdM04A4A01MGEd0GUiN07inOP1]KFd092@T05MGE`1FEUH0G5aL08V9
R@11@D4071`L04A4A01hN7P0QhN7071`L01?Cdl0;Rh^03lo?`2k^k/0^[Zj03Ph>01jNWX0DU9B03@d
=02UYJD0`L7103`l?01VIVH0=cLg01<C4`1CDe<0[jn_0:BTY01CDe<0<S8b03lo?`1HF5P0Xj>S04m?
C`0Y:BT0EEEE04];B`1ZJVX0Ph>301PH600_;bl0MGEe06MWI`1ZJVX0/k>c034a<@0Z:RX0KVi^09JF
UP1nOWh0Ti>C01XJ6P0i>CT0OWin09:BTP1NGUh0DE5A079bLP0o?cl0BDU907inOP1@D500FEUI09BD
U00Y:BT0@4100820P01_Kfl0Fe]K06=SH`0^;Rh0HV9R07IfMP15ADD0:b/[06m_K`1ADE40V9RH07mo
O`0[:b/0=SHf06IVIP1UIFD0Hf=S0:^[Z`15ADD0@d=305EEE@1KFe/0V9RH09>CT`0m?Cd0JFUY08Z:
RP11@D40BDU906IVIP0R8R80S8b<08n?S`12@T80GEeM04];B`0/;2`0GemO065QH@24Q8@0;Bd]04A4
A01HF5P0PH6103Xj>P1<C4`0Bd];03@d=01nOWh0=3@d04E5A@0f=SH0<c<c07emO@2LW9`0@T9203/k
>`15ADD0Q8B40:j^[P0e=CD0=SHf05]KF`18B4P0BDU90:j^[P2?Shl0>c/k04m?C`1hN7P0D51@0:NW
Y`1eMGD09RHV04A4A01ADE40I6AT07QhN01XJ6P092@T03dm?@1UIFD0EeMG04A4A01HF5P0E5AD000S
02/[:`1PH600Cdm?02XZ:P1CDe<0E5AD02LW9`1KFe/0YZJV05aLG00k>c/0<C4a020P801FEUH0Z:RX
05QHF00M7Ad0<C4a03hn?P16ATH0Ogmo04E5A@0B4Q80@T9206i^KP1=CDd0MGEe05mOG`0T92@0?3`l
03Lg=`0n?Sh0L71`079bLP0Q8B407?ooool0;@2QXJ40Rh^;05mOG`1?Cdl0RXZ:08:2PP2>SXh0H61P
0:>SX`2b/[80_Kfm06ATI02KVi/0P82008J6QP2SXj<0NGUi08b<S02:RXX0MGEe05QHF01KFe/0J6QX
06ATI01iNGT0M7Ad05mOG`1lO7`0D51@0;Fe]@1=CDd0FEUI07emO@1ZJVX0I6AT096AT@1[Jf/0T92@
079bLP1TI6@0=cLg04];B`0h>3P0?3`l061PH00204A4A00T04e=C@19BDT0DE5A05=CD`14A4@0?Shn
06EUI@1mOGd0ATI604E5A@1hN7P0De=C0:6QX@1UIFD0GEeM05MGE`1gMgL0<C4a06i^KP1cLg<0IFEU
0492@P1_Kfl0JVYZ071`L01MGEd0D51@071`L01SHf<0L71`05YJFP0_;bl0Bd];03dm?@1;Bd/0?clo
0P11@D40301@D500>SXj02<S8`19BDT0@d=306EUI@1CDe<0>c/k04U9B@1VIVH0C4a<05YJFP80CDe=
0680B4Q805EEE@1;Bd/0:BTY05QHF00m?Cd0FEUI03Ti>@1>CTh0=CDe04i>CP1DE5@0GEeM0410@01/
K6`0U9BD07AdM00^;Rh08B4Q04E5A@1OGel0?Cdm04];B`17AdL0C4a<04i>CP1FEUH0MWIf07]kN`2U
YJD0T92@06YZJP1dM7@0?3`l06ATI01/K6`0EeMG079bLP1iNGT0I6AT07emO@1EEED0>3Ph024Q8@1F
EUH0LG5a05eMG@0g=cL0?clo06IVIP1^KVh0CDe=05ADE01?Cdl0FUYJ06EUI@1KFe/0BTY:06IVIP1^
KVh0>c/k02LW9`0e=CD0WYjN08N7Q`0/;2`0;Bd]05UIF@1^KVh0JFUY06MWI`0I6AT0?3`l03Lg=`0P
8200=CDe02XZ:P0I6AT0@d=303/k>`0g=cL0>SXj04E5A@1;Bd/0;2`/03/k>`1?Cdl0BTY:05ADE01O
Gel0?Cdm0451@@1;Bd/0MgMg05MGE`1TI6@0EeMG020P8080CDe=05/08R8R04E5A@10@400EEEE03dm
?@1PH600@d=307QhN014A4@0=cLg03Xj>P23Ph<0N7Qh03dm?@1=CDd0@d=305YJFP1LG5`0EeMG038b
<P16ATH0C4a<030`<00l?3`0@T9204];B`1FEUH0D51@04i>CP2SXj<0Lg=c04I6AP1JFUX0>CTi05]K
F`0k>c/0GUiN051@D01DE5@0EEEE05=CD`17AdL0QHF505=CD`1WIfL0De=C0;Fe]@1FEUH0DU9B05IF
EP1CDe<0IfMW09ZJVP0W9bL09BDU05UIF@0m?Cd0JFUY075aL@13@d<0FUYJ07EeM@1;Bd/0K6a/06EU
I@2;Rh/0EeMG05iNGP10@400E5AD03@d=01@D500G5aL0451@@1aLG40DU9B07AdM02>SXh0DE5A07Yj
NP2OWil0/K6a0:RXZ01lO7`0VYZJ07inOP2KVi/0S8b<07=cL`1^KVh0RHV9017ooooo000?ooooo`1S
07MgM`3EeMD0GUiN05]KF`1dM7@0Ogmo07]kN`14A4@0HF5Q07=cL`1nOWh0IfMW04a<C00];Bd0Jf][
034a<@1:BTX0I6AT02/[:`0o?cl0Hf=S059BDP0Q8B40EeMG0492@P1HF5P0Cdm?01`L7012@T80Fe]K
069RHP1KFe/0ZJVY04I6AP18B4P0FEUI05eMG@21PH40NGUi01hN7P0`<300FEUI04i>CP21PH40IfMW
028R8P19BDT0N7Qh07EeM@1nOWh0K6a/03<c<`0m?Cd0LG5a06=SH`1oOgl0PH6102@T900i>CT0CDe=
06][J`10@400C4a<01TI6@0o?cl0TI6A06][J`0a<C40GEeM02`/;00L71`0C4a<061PH013@d<0EEEE
02`/;013@d<0T92@07emO@0P82007QhN04i>CP13@d<0WYjN09NGU`0J6QX0Bd];07UiN@1JFUX0E5AD
0<K6aP1CDe<0>3Ph07AdM01NGUh0KVi^08f=S@12@T80=cLg0080EUIF0:H0ATI60;Vi^@1CDe<0:b/[
06QXJ022PX80@T92051@D01/K6`0:b/[06ATI021PH40;Rh^030`<01HF5P0Hf=S05EEE@23Ph<0EeMG
01dM7@1?Cdl0SHf=07EeM@2JVYX0ATI601`L700o?cl0TY:B0:n_[`26QXH0@d=302l_;`1DE5@0SXj>
04e=C@0o?cl0D51@02XZ:P0b<S80W9bL0451@@1QHF40EeMG020P8014A4@0M7Ad06EUI@0Z:RX0Hf=S
03Ph>01`L700Zj^[06UYJ@0K6a/0?3`l04];B`1XJ6P0R8R808F5Q@0[:b/0DE5A07IfMP1]KFd0QhN7
0;fm_@0^;Rh05QHF05ADE01kNg/0SHf=09FEU@0^;Rh09RHV06i^KP1cLg<0A4A40:FUY@0k>c/0?Cdm
07AdM01LG5`0M7Ad07EeM@10@400=SHf0451@@1WIfL0F5QH05ADE00R8R80ADE504M7A`1>CTh0E5AD
09NGU`11@D40Kfm_09^KV`0a<C40DU9B055AD@18B4P0XZ:R059BDP0^;Rh0@D5105aLG02KVi/0Cdm?
02DU9@16ATH0Ti>C08R8R02HV9P0K6a/02l_;`1HF5P0Cdm?08:2PP1<C4`0>3Ph05]KF`2HV9P0UiNG
08j>SP1XJ6P0=3@d09fMW@1SHf<0CDe=0:BTY01<C4`0;2`/05IFEP2JVYX0BTY:06QXJ00Z:RX0>CTi
07UiN@2CTi<07AdM02`/;015ADD0>CTi071`L02NWYh0;bl_03De=@1ADE40@d=304U9B@28R8P0FEUI
02DU9@0n?Sh0FUYJ06YZJP21PH40@41001TI6@0a<C40M7Ad08^;R`2EUID0@d=30P0i>CT05@1PH600
OWin04Q8B01bLW8092@T02PX:00i>CT0Bd];02LW9`1:BTX0?Shn01PH6013@d<0LG5a03hn?P0P8200
=3@d01dM7@0e=CD0K6a/038b<P0Looooo`0Y069RHP1aLG40EUIF04M7A`1YJFT0KFe]05]KF`1EEED0
QhN706YZJP2@T900GEeM08b<S01QHF40RXZ:07inOP2?Shl0N7Qh06=SH`1`L700E5AD04e=C@1LG5`0
Cdm?071`L01XJ6P0EEEE079bLP1WIfL0/k>c0451@@1KFe/0OGem07=cL`1]KFd0WYjN06][J`2GUiL0
YJFU09>CT`0e=CD00P1HF5P0>P1>CTh0MWIf04];B`1BDU80Hf=S04m?C`1WIfL0GemO06QXJ00j>SX0
GUiN05mOG`0l?3`0?clo0820P021PH40N7Qh04a<C01BDU80FUYJ04Y:BP0W9bL0EUIF055AD@1HF5P0
?Cdm06IVIP1>CTh0@41005IFEP19BDT0GEeM03lo?`19BDT0Bd];03Ti>@1iNGT0BDU905=CD`1LG5`0
D51@04U9B@1CDe<0>3Ph03Xj>P14A4@0>CTi04I6AP0d=3@0:RXZ030`<01RHV80A4A405YJFP0i>CT0
AdM704A4A01;Bd/2034a<@0@051@D019BDT0EUIF04I6AP1ZJVX0D51@08R8R00j>SX0DU9B04];B`1J
FUX0@d=3061PH012@T80Cdm?0492@P80A4A40:T0AdM705IFEP1ADE40ADE505UIF@2TY:@0EEEE03Ph
>01WIfL0YJFU07QhN00^;Rh0CTi>06ATI022PX80U9BD03Ph>00/;2`0BTY:08:2PP16ATH08R8R04A4
A00a<C40EUIF02TY:@1<C4`0=3@d04U9B@17AdL0J6QX08R8R01PH600EUIF051@D01;Bd/0Jf][07Ee
M@1JFUX02`/;01hN7P2m_Kd0OWin01/K6`0o?cl0@41006ATI01DE5@0Bd];00`<3019BDT0ADE504A4
A01RHV80<c<c02PX:01>CTh0>CTi01lO7`0j>SX0;Bd]05YJFP1:BTX0@T92065QH@10@400=SHf04m?
C`18B4P0De=C03Xj>P12@T80B4Q807EeM@1bLW80DU9B051@D01?Cdl0>CTi04i>CP0k>c/0=SHf03Xj
>P1SHf<0>SXj02TY:@1LG5`0Cdm?03De=@0a<C40BDU902LW9`0n?Sh0D51@03/k>`1DE5@0CDe=0451
@@0T92@0@41003@d=014A4@0CTi>03@d=01BDU80H61P059BDP18B4P0@d=305MGE`1QHF40>CTi08B4
Q01MGEd0FEUI0451@@1CDe<0Ng]k055AD@1GEeL0QHF504M7A`1oOgl0Jf][0:JVYP1BDU80Bd];05]K
F`1SHf<0FEUI05YJFP14A4@0CDe=06=SH`15ADD0@d=307inOP0l?3`0CDe=06m_K`1/K6`0FEUI06MW
I`2>SXh0A4A404I6AP0n?Sh0DU9B03lo?`1VIVH0HF5Q06][J`1iNGT0LG5a09BDU01lO7`0OGem09ZJ
VP2SXj<0WYjN09>CT`2LW9`0^KVi09jNWP2CTi<0UIFE05]KF`1lO7`0]KFe017ooooo000?ooooo`0i
05MGE`26QXH0WIfM04m?C`1KFe/0Ng]k09JFUP0h>3P0@T9206=SH`1ZJVX0Ng]k09fMW@0Z:RX0DE5A
04];B`1gMgL0PH6102`/;00Y:BT0L71`07=cL`1OGel0]KFe038b<P1ZJVX0Hf=S03hn?P1QHF40Hf=S
01/K6`14A4@0L71`06UYJ@2PX:00IFEU01LG5`1DE5@0LW9b04];B`1QHF40`L7103lo?`10@400SHf=
034a<@1FEUH0?3`l03<c<`14A4@0Ogmo04Q8B00];Bd0CTi>03<c<`1_Kfl0SXj>0080<C4a02h0Cdm?
02l_;`1NGUh0R8R802d];@0d=3@0DU9B05=CD`1cLg<0Zj^[03@d=00K6a/0>c/k055AD@29RHT0fMWI
05aLG00Q8B40AdM706][J`0o?cl0CTi>09VIV@0^;Rh0Bd];0820P01DE5@0DU9B07QhN00f=SH08R8R
07moO`29RHT0MgMg05YJFP0U9BD0<C4a09>CT`1IFET071`L04=3@`1OGel0CDe=0;Bd]011@D407alO
0P0l?3`0]`1BDU80KVi^0:^[Z`0d=3@0@T9208Z:RP2QXJ40KFe]08Z:RP0M7Ad0EeMG08b<S021PH40
Bd];07MgM`0N7Qh0BDU905mOG`1NGUh0>CTi06YZJP0k>c/08R8R06a/K01[Jf/07alO06QXJ00n?Sh0
CDe=08:2PP1OGel08B4Q02h^;P18B4P0?3`l0;2`/020P8007AdM02@T901IFET0G5aL04A4A02BTY80
6QXJ02`/;01eMGD0`<3006EUI@25QHD0F5QH020P8012@T80[:b/06ATI01DE5@0B4Q801lO7`1_Kfl0
Q8B4065QH@13@d<0Ogmo03Ph>01DE5@0SHf=059BDP1JFUX0EeMG03lo?`1BDU80SHf=06e]K@1CDe<0
:2PX04Y:BP1`L700[Jf]05mOG`0/;2`0BTY:03Ph>01lO7`0X:2P02/[:`1:BTX0@D5105ADE029RHT0
`/;205QHF00[:b/0KVi^06e]K@1oOgl0?Cdm02`/;019BDT0OGem04m?C`1bLW80?Shn071`L01fMWH0
D51@05MGE`0c<c<0>c/k07UiN@1kNg/0>c/k04m?C`0W9bL0IFEU05eMG@0d=3@0GUiN038b<P19BDT0
/;2`096AT@0/;2`0ADE5051@D01?Cdl0[jn_069RHP0_;bl0?Cdm05YJFP1WIfL0XJ6Q03<c<`0S8b<0
Fe]K08n?S`1GEeL0IVIV09ZJVP0T92@0CDe=0820P00n?Sh0I6AT07=cL`0Z:RX0Cdm?065QH@1OGel0
:BTY05ADE00Q8B40E5AD07]kN`1lO7`0;Bd]03@d=01;Bd/08b<S07AdM01ZJVX092@T04I6AP0l?3`0
<S8b061PH01gMgL0Bd];02@T901:BTX0>3Ph065QH@1nOWh0JFUY01XJ6P0[:b/0>CTi05UIF@0m?Cd0
CTi>01PH600k>c/0@41003Hf=P0Looooo`0306ATI026QXH0PH610080Kfm_0380Ng]k09>CT`1RHV80
VIVI08n?S`2WYjL0QXJ60:BTY022PX80RHV9065QH@1IFET0GemO055AD@1FEUH0?clo055AD@1[Jf/0
FEUI05iNGP2EUID0KVi^06e]K@0m?Cd0Rh^;05mOG`1_Kfl0L71`05mOG`21PH40NGUi06i^KP2>SXh0
/[:b0<C4a016ATH0BDU90410@015ADD0J6QX04];B`1CDe<0Jf][04e=C@1[Jf/0HV9R07AdM01=CDd0
JVYZ0861P@80@T9204H0OGem04m?C`2?Shl0H61P07AdM01@D500Lg=c02LW9`1aLG40GemO07QhN01H
F5P0NGUi04m?C`1UIFD0I6AT05UIF@1]KFd0BTY:06m_K`1cLg<0=SHf075aL@1]KFd0IVIV04=3@`1@
D500FEUI04=3@`15ADD0?clo061PH00n?Sh0IVIV0451@@1;Bd/0BDU9071`L017AdL0H61P04A4A01;
Bd/0?Shn04m?C`18B4P0>SXj06IVIP14A4@0K6a/04A4A01KFe/0ADE506UYJ@0n?Sh0GemO06a/K01Y
JFT0Kfm_06e]K@0h>3P0De=C05ADE01MGEd0B4Q805ADE00k>c/0EUIF04A4A017AdL0F5QH0P1bLW80
G@1iNGT0De=C05ADE00j>SX0@41004i>CP13@d<0EUIF06UYJ@1>CTh0E5AD04a<C01BDU80<S8b06UY
J@0n?Sh0EeMG03lo?`1VIVH0?Shn05mOG`1RHV80NGUi03lo?`12@T80?clo07YjNP1KFe/0De=C06AT
I02@T9008B4Q01`L703MgMd0O7al01<C4`1cLg<0GUiN0820P01RHV80GUiN028R8P25QHD0BTY:02@T
900g=cL08B4Q059BDP1TI6@0@D5103Xj>P17AdL0<c<c06EUI@0g=cL0B4Q806m_K`0c<c<0AdM705iN
GP1RHV80Bd];02/[:`12@T80;2`/05QHF01JFUX06a/K051@D01DE5@08B4Q0451@@0^;Rh0BTY:059B
DP2BTY80=CDe04A4A01JFUX0L71`02TY:@0m?Cd0F5QH02/[:`1GEeL0D51@02d];@1=CDd0D51@05IF
EP0j>SX0BTY:04I6AP0204M7A`12030`<015ADD0?clo04E5A@1EEED0=SHf051@D01IFET0;bl_03Lg
=`0h>3P0GemO04A4A01GEeL0JVYZ05QHF010@400MWIf03<c<`1gMgL0ADE50=?Cd`2=SHd0KVi^07in
OP2ATI40@d=3075aL@11@D40?clo06i^KP0e=CD0BDU906QXJ00k>c/0?clo05iNGP1UIFD0J6QX065Q
H@2FUYH0KFe]05mOG`1KFe/0JVYZ03lo?`1JFUX0FEUI0410@01ZJVX0Shn?0820P01cLg<0J6QX09fM
W@2LW9`0[Jf]0;Ng]`1XJ6P0Lg=c0:JVYP2MWId0DE5A08>3P`1dM7@0KFe]4Oooool000oooooo0:40
KFe]08N7Q`28R8P0OWin07IfMP1PH600NGUi07alO01eMGD0Ogmo04A4A01CDe<0I6AT04a<C01ZJVX0
;2`/03Lg=`1OGel0GUiN06IVIP21PH40=SHf038b<P1;Bd/0E5AD06MWI`0i>CT0;Rh^0492@P1VIVH0
EeMG05YJFP2KVi/0<30`06a/K01iNGT0=cLg05IFEP1MGEd09bLW05MGE`2RXZ80IfMW05MGE`0l?3`0
>SXj07=cL`2NWYh0DE5A04e=C@1WIfL0EEEE0451@@1kNg/0@41003Ph>01SHf<0Bd];06][J`2WYjL0
@d=302PX:017AdL092@T08:2PP2[Zj/0<S8b02l_;`1<C4`0Bd];03Ti>@22PX80BTY:03<c<`1EEED0
EeMG03hn?P2EUID0M7Ad02XZ:P0j>SX0KFe]05IFEP1iNGT0OGem02d];@17AdL0H61P04M7A`0e=CD0
Fe]K03dm?@1hN7P0Y:BT04i>CP0o?cl0Jf][05mOG`11@D40N7Qh08F5Q@0h>3P0JVYZ05]KF`13@d<0
T92@04e=C@0Z:RX0>c/k04i>CP1LG5`0J6QX055AD@0c<c<0CDe=07]kN`1bLW80AdM707]kN`1UIFD0
AdM708F5Q@1OGel0=SHf05aLG018B4P0@D510820P02:RXX0Cdm?04i>CP1IFET0?Cdm09ZJVP25QHD0
@D5104i>CP1]KFd0=CDe05aLG01nOWh0:b/[05YJFP23Ph<0H61P06=SH`2>SXh0>3Ph02l_;`1DE5@0
ADE5071`L028R8P0:b/[055AD@1mOGd0HV9R030`<01FEUH0HV9R051@D00208^;R`1o04A4A01PH600
Shn?03lo?`1FEUH0`<3005mOG`1BDU80GEeM04=3@`25QHD0S8b<03`l?00/;2`0Jf][065QH@1XJ6P0
EEEE03<c<`1:BTX0MGEe05aLG01BDU80QHF503Lg=`0o?cl0KVi^0492@P1jNWX0CTi>01lO7`19BDT0
Lg=c079bLP1EEED0DE5A0492@P2;Rh/0PH6103lo?`1]KFd0=CDe038b<P2;Rh/0GEeM04i>CP0k>c/0
J6QX07QhN01jNWX0>c/k07EeM@1CDe<0DE5A07EeM@0`<300Bd];04E5A@17AdL0YjNW08b<S00h>3P0
ADE505EEE@1BDU80TI6A038b<P11@D40GemO055AD@19BDT0M7Ad09fMW@0g=cL0H61P05eMG@1<C4`0
SXj>06i^KP0Y:BT0E5AD06ATI01ADE40GUiN03@d=00g=cL0DE5A079bLP1>CTh0?clo07AdM01KFe/0
@d=305YJFP0g=cL0=SHf061PH01EEED0>c/k06MWI`28R8P0C4a<06ATI01KFe/0=3@d06i^KP1mOGd0
>c/k03@d=01GEeL0H61P03<c<`1iNGT0<30`028R8P16ATH0MWIf06ATI01<C4`0N7Qh02HV9P0d=3@0
B4Q802d];@1XJ6P0F5QH02LW9`0Looooo`3l06m_K`1kNg/0Fe]K04a<C01VIVH0KFe]06QXJ01>CTh0
J6QX07MgM`2DU9@0J6QX07]kN`1ZJVX0Lg=c07IfMP1hN7P0Shn?06=SH`1gMgL0KVi^05UIF@1UIFD0
Cdm?06a/K01TI6@0EUIF06UYJ@1FEUH0N7Qh059BDP1<C4`0N7Qh065QH@1>CTh0OWin08B4Q02GUiL0
TI6A07YjNP1HF5P0EeMG04];B`1>CTh0Hf=S04Q8B012@T80IfMW04];B`1LG5`0D51@05QHF00k>c/0
F5QH05iNGP0m?Cd0?Shn06MWI`1EEED0K6a/04m?C`1KFe/0CTi>05=CD`0^;Rh0GUiN05mOG`1DE5@0
?Shn065QH@1@D500EUIF05mOG`19BDT0LG5a05=CD`1OGel0G5aL0492@P1cLg<0De=C06EUI@1EEED0
Bd];0492@P0n?Sh0@d=303Lg=`0l?3`0>CTi03hn?P19BDT0?clo03Ph>01FEUH0AdM704];B`0n?Sh0
ATI603dm?@16ATH0@d=3055AD@1LG5`0De=C06IVIP1;Bd/0HV9R05UIF@23Ph<0D51@05EEE@1>CTh0
MgMg06m_K`2JVYX0DU9B05IFEP1^KVh0CTi>05ADE01_Kfl0Bd];05EEE@0d=3@0KFe]08n?S`2<S8`0
I6AT0;6a/@26QXH0N7Qh03Ph>01KFe/0J6QX03<c<`1IFET0Hf=S05YJFP1^KVh0HF5Q071`L013@d<0
EUIF03hn?P1JFUX0;Rh^06QXJ00k>c/0Fe]K051@D01^KVh0DU9B06i^KP1KFe/0IfMW04I6AP1MGEd0
E5AD03dm?@0S8b<09bLW0<W9b@2GUiL0:BTY05EEE@12@T80JVYZ05]KF`1:BTX04Q8B04=3@`0f=SH0
<C4a04a<C00];Bd08b<S0410@00e=CD0@410055AD@0j>SX0@D5103Xj>P1IFET0OGem03hn?P1;Bd/0
De=C05]KF`1:BTX0<30`03lo?`0k>c/0K6a/079bLP0V9RH0Cdm?059BDP0g=cL0EeMG034a<@10@400
ADE507EeM@0];Bd0@D5106UYJ@1[Jf/0?3`l069RHP1MGEd0=3@d0492@P14A4@0@T9205EEE@1@D500
?3`l02l_;`17AdL0<S8b03Lg=`17AdL0>c/k05MGE`17AdL0@D51061PH01UIFD0EeMG071`L00/;2`0
H61P04e=C@1/K6`0G5aL04];B`1QHF40CTi>04m?C`1MGEd0:BTY06YZJP18B4P0`/;207EeM@1HF5P0
IfMW07QhN01BDU80UIFE0P1HF5P0901mOGd0CTi>06EUI@29RHT0EEEE04];B`1LG5`0WYjN06YZJP1e
MGD0NGUi06IVIP1[Jf/0Cdm?065QH@1>CTh0GEeM051@D01DE5@0HV9R05YJFP1`L700NGUi07inOP2L
W9`0WinO09RHV02^[Zh0UIFE0:2PX01nOWh0Ogmo07UiN@2@T900O7al096ATA7ooooo000?ooooo`18
069RHP3AdM40PX:204M7A`1hN7P0YJFU096AT@16ATH0JFUY07YjNP1LG5`0b<S807QhN00^;Rh0PH61
03lo?`1MGEd0HF5Q02DU9@0m?Cd0Ogmo071`L01=CDd0Fe]K02HV9P0_;bl0FEUI02LW9`1bLW80D51@
02HV9P12@T80?Shn03<c<`16ATH0=CDe02d];@0e=CD0EEEE03De=@1HF5P0De=C03lo?`1ADE40D51@
02LW9`0d=3@0FUYJ0492@P1KFe/0Vi^K030`<00Z:RX0AdM706][J`1ZJVX0Q8B401DE5@0X:2P0MWIf
05UIF@1mOGd0Kfm_02TY:@0m?Cd0Rh^;071`L01cLg<0TI6A02DU9@0H61P0AdM70P1>CTh0P@29RHT0
7AdM01`L7018B4P0MGEe04=3@`0g=cL0I6AT02TY:@1TI6@0MWIf01`L700f=SH0AdM7059BDP1KFe/0
Ng]k034a<@0X:2P0Fe]K07YjNP1WIfL0YZJV03De=@0P8200ATI607YjNP1bLW80[:b/03Hf=P0O7al0
GUiN07QhN012@T80EUIF05aLG00L71`0Cdm?08F5Q@1DE5@0?clo06MWI`0O7al0@41006IVIP1bLW80
EUIF07UiN@0Q8B40B4Q80:j^[P1/K6`08B4Q030`<01HF5P0=CDe09jNWP10@4006a/K03lo?`1iNGT0
EUIF07QhN01iNGT09bLW02PX:01]KFd0CTi>0:VYZ@1nOWh0=SHf04Q8B02DU9@0P82003hn?P1`L700
9bLW03lo?`2h^;P0Rh^;0451@@1_Kfl0@D51024Q8@1CDe<0R8R802PX:01RHV80AdM704];B`1KFe/0
UiNG04M7A`0O7al0D51@07alO02SXj<0KFe]028R8P0n?Sh0Hf=S05EEE@28R8P0/K6a059BDP1GEeL0
Ng]k05ADE01lO7`0SXj>02XZ:P1;Bd/0Q8B406m_K`10@400ADE504e=C@19BDT0GEeM03Xj>P1<C4`0
GEeM04=3@`19BDT0LW9b03Ph>01UIFD0@T9204U9B@0206EUI@0V02h^;P18B4P0?Cdm0::RXP0o?cl0
:RXZ05MGE`15ADD0Bd];0:f][@1WIfL07alO0820P01FEUH0GemO02HV9P0`<300AdM708V9R@1/K6`0
KFe]04m?C`0c<c<0GUiN07EeM@1?Cdl0WYjN028R8P0m?Cd0C4a<06UYJ@14A4@0HF5Q024Q8@16ATH0
J6QX09NGU`16ATH205MGE`0]02h^;P1IFET0Fe]K02@T9017AdL0F5QH02<S8`10@400I6AT07inOP0g
=cL0C4a<02/[:`1^KVh0YZJV05aLG00J6QX0=SHf04e=C@19BDT0[Zj^06ATI00_;bl0<C4a04m?C`1K
Fe/0N7Qh092@T00o?cl0<C4a04e=C@1DE5@0KVi^07EeM@1IFET06a/K04Y:BP1IFET0C4a<04=3@`1@
D50071`L05UIF@2FUYH0G5aL01cooooo0:h0GEeM06i^KP28R8P0RHV905aLG01ZJVX0YjNW07AdM01Y
JFT0JVYZ0:>SX`2[Zj/0^k^k0:j^[P1oOgl0G5aL05ADE01cLg<0ADE506IVIP1:BTX0@d=305aLG01=
CDd0C4a<06=SH`1<C4`0Fe]K03Ti>@1OGel0DE5A05=CD`1XJ6P0BDU907EeM@1TI6@0E5AD05eMG@2@
T900ZJVY04e=C@1>CTh0BTY:0451@@1?Cdl0@D5104Q8B01_Kfl0I6AT05EEE@1IFET0P8200861P@1]
KFd0Ph>304E5A@0m?Cd0NGUi04=3@`27QhL0AdM707AdM016ATH0KFe]03lo?`24Q8@0DU9B061PH01i
NGT0LG5a04=3@`1LG5`0Jf][07inOP1jNWX0Bd];07MgM`1nOWh0=CDe06m_K`17AdL0?Cdm0451@@0/
;2`0DE5A03Xj>P1;Bd/0=CDe04a<C00j>SX0C4a<055AD@1>CTh0>SXj075aL@1FEUH0IFEU04I6AP1:
BTX0EEEE05YJFP1>CTh0?clo06=SH`0g=cL0GUiN04M7A`1BDU80;bl_05ADE016ATH0FUYJ07]kN`1f
MWH0GUiN07IfMP1GEeL0PH6108F5Q@1JFUX0De=C06YZJP17AdL0FUYJ03lo?`1QHF40LW9b08B4Q01A
DE40SHf=08b<S01kNg/0;Rh^05IFEP1VIVH0<30`04Q8B00n?Sh0DE5A06][J`1hN7P0Lg=c05ADE015
ADD08b<S0451@@0_;bl0FEUI02l_;`1:BTX0De=C07IfMP0o?cl0Kfm_04Q8B01?Cdl0?Shn055AD@1d
M7@0D51@02h^;P0;2`/0EUIF08J6QP0P8200Bd];05ADE01NGUh0DE5A06YZJP0J6QX0@T9203`l?00/
;2`20492@P0O01lO7`0m?Cd0?clo03<c<`0b<S80ADE5038b<P0f=SH09RHV04E5A@0m?Cd0CTi>0451
@@0X:2P0>CTi02@T900c<c<0;bl_05eMG@1XJ6P0<30`05=CD`1UIFD071`L03hn?P0S8b<0?Cdm030`
<01FEUH08b<S03Hf=P0207YjNP0A02XZ:P18B4P0BTY:02TY:@1[Jf/0BDU902PX:016ATH0>c/k038b
<P0k>c/0A4A402l_;`0j>SX0=CDe02@T9017AdL00P1DE5@0;@12@T80>SXj05QHF01mOGd0<C4a03@d
=00b<S80?clo05MGE`1OGel0G5aL04E5A@1:BTX0GemO02@T901jNWX0CDe=0=_Kf`1nOWh0G5aL07If
MP2RXZ80G5aL06a/K011@D40?Shn04a<C00/;2`0DE5A071`L01BDU80D51@07=cL`2HV9P0OGem0861
P@20P800?Shn04Q8B00_;bl0EEEE03Lg=`1KFe/0B4Q803Lg=`0204a<C00?06i^KP1>CTh0IfMW096A
T@2RXZ80WIfM0:VYZ@1nOWh0NWYj05UIF@1nOWh0IFEU07inOP1IFET0K6a/017ooooo000?ooooo`1k
059BDP2ATI40^[Zj08^;R`1PH600Hf=S09:BTP1ADE40M7Ad04U9B@0h>3P0DE5A06=SH`0e=CD0ATI6
04U9B@1CDe<0OGem02HV9P0S8b<0BTY:03@d=01iNGT0UIFE02<S8`0T92@0A4A404I6AP24Q8@0LG5a
01dM7@0l?3`0E5AD04e=C@2h^;P0LG5a01DE5@10@400De=C034a<@2IVIT0[:b/02@T901:BTX0HV9R
06m_K`2@T900?Shn04M7A`0g=cL0FUYJ061PH00_;bl0E5AD02TY:@1dM7@0MGEe04E5A@1?Cdl0Jf][
01DE5@17AdL0IFEU01/K6`0e=CD0ADE502<S8`1IFET0X:2P02d];@0G5aL0>3Ph055AD@2DU9@0XZ:R
02<S8`0M7Ad0820P051@D02<S8`0QHF50;bl_00T92@0JFUY05EEE@0l?3`0RXZ:07IfMP0G5aL0;bl_
06e]K@1OGel0EeMG065QH@0X:2P0IFEU092@T01bLW80:BTY06ATI00m?Cd0?clo096AT@15ADD09bLW
04E5A@0i>CT0JFUY08J6QP1aLG407alO03Ph>01kNg/0LG5a0:>SX`1YJFT09BDU02TY:@1ADE40TY:B
07AdM02`/;00?Shn0080>SXj00h0SHf=05=CD`1OGel0De=C02d];@1?Cdl0KVi^04U9B@1jNWX0=CDe
02LW9`0o?cl0MGEe03De=@80@41001D0:BTY05eMG@20P8007QhN02`/;01:BTX0ATI607moO`1SHf<0
:2PX02TY:@1oOgl0L71`09NGU`2WYjL0D51@03Ti>@19BDT0RHV906i^KP2IVIT00P0i>CT08P1GEeL0
MgMg08F5Q@1@D500XJ6Q030`<01SHf<0GEeM03dm?@1IFET0KVi^03Ti>@0n?Sh0GEeM04m?C`1LG5`0
<c<c03Lg=`1RHV80[jn_07AdM00K6a/0DE5A04M7A`1fMWH0Shn?02@T901CDe<0CDe=04Y:BP1WIfL0
T92@03Hf=P0`<30206a/K01>0:JVYP10@400>CTi05]KF`1SHf<0JVYZ09BDU00e=CD0Fe]K04i>CP1`
L700OGem03De=@0n?Sh0O7al06][J`15ADD0FUYJ06YZJP1^KVh0EeMG02@T901;Bd/0Hf=S07MgM`2=
SHd0KFe]030`<01?Cdl0<30`04M7A`2MWId0B4Q802LW9`1HF5P0Bd];06QXJ02TY:@0:2PX038b<P1?
Cdl0GUiN04I6AP2HV9P0UiNG01/K6`1=CDd0MWIf03/k>`27QhL0[Jf]02DU9@10@400EeMG05IFEP14
A4@0EeMG01/K6`0L71`0K6a/0:VYZ@0i>CT0MWIf065QH@0T92@0DU9B0861P@0W9bL0EEEE03@d=00R
8R80>3Ph06e]K@1YJFT0<30`02l_;`0f=SH0?Shn0P1jNWX02P0[:b/0<S8b02XZ:P0d=3@0IfMW06][
J`0G5aL0;2`/05QHF014A4@Looooo`0a08n?S`2IVIT0DU9B055AD@1/K6`0Jf][06=SH`0i>CT0Cdm?
07QhN01`L700Kfm_08V9R@2GUiL0TI6A07]kN`1JFUX0UIFE05UIF@25QHD0KVi^05EEE@1jNWX0F5QH
06=SH`1WIfL0NGUi0820P019BDT0Hf=S05QHF011@D40GUiN05QHF01>CTh0PH6107AdM028R8P0Ph>3
06i^KP1>CTh0G5aL0492@P0n?Sh0IfMW06EUI@1WIfL0Rh^;069RHP0205iNGP3_06EUI@0f=SH0Cdm?
06][J`1EEED0E5AD06EUI@1:BTX0IFEU04M7A`1UIFD0?3`l051@D00l?3`0FUYJ04a<C01IFET0?Shn
06IVIP1EEED0U9BD05mOG`11@D40JVYZ051@D01QHF40P8200492@P2DU9@0AdM705UIF@1DE5@0?Shn
04M7A`1=CDd0De=C02TY:@0n?Sh0CDe=04E5A@1EEED0A4A403dm?@1;Bd/0>3Ph055AD@1?Cdl0@d=3
0451@@15ADD0CTi>05mOG`1CDe<0?Shn06MWI`1MGEd0Lg=c04E5A@21PH40J6QX05=CD`0g=cL0E5AD
07alO01LG5`0@D5104m?C`1RHV80Cdm?0410@017AdL0@d=304A4A01IFET0GUiN08b<S02DU9@0V9RH
09jNWP1ZJVX0MWIf04];B`1EEED0HF5Q04m?C`1iNGT0MWIf07emO@20P800GUiN05]KF`1CDe<0CTi>
03De=@1CDe<0>SXj05IFEP19BDT0Cdm?07QhN01MGEd0CDe=05iNGP1WIfL0GUiN0451@@1<C4`0H61P
05iNGP1GEeL0<S8b071`L02<S8`092@T08>3P`1LG5`0DU9B04I6AP1OGel0<30`04];B`1LG5`0?3`l
04a<C00n?Sh0<S8b05=CD`0l?3`0>c/k02TY:@0d=3@0?Shn0492@P0n?Sh0HF5Q034a<@17AdL0E5AD
03dm?@0i>CT0>3Ph05=CD`0d=3@0HF5Q07=cL`0a<C40=SHf0492@P0U9BD0@d=302PX:00j>SX0<S8b
05MGE`0K6a/0?Shn04e=C@0i>CT06a/K04U9B@1=CDd05aLG02l_;`0g=cL0BDU905]KF`0c<c<0<C4a
0410@015ADD0>3Ph03Hf=P0e=CD0BTY:069RHP0i>CT0?3`l059BDP0h>3P0ATI607MgM`0e=CD0E5AD
034a<@0k>c/0=cLg03Ti>@1GEeL0C4a<06a/K020P800C4a<07IfMP1KFe/0ZJVY05QHF00c<c<0@T92
06MWI`14A4@0Ti>C04a<C014A4@0EUIF04Q8B01UIFD0MgMg05YJFP2a/K40RXZ:06=SH`17AdL0N7Qh
08N7Q`1GEeL0HF5Q04I6AP1<C4`0=3@d04Q8B017AdL0?clo05aLG01>CTh0OGem06MWI`1`L700WinO
09VIV@2CTi<0YZJV0:6QX@3;bl/0GUiN06ATI01NGUh0IVIV079bLP2=SHd04Oooool000oooooo0?l0
Cdm?06MWI`2=SHd0/[:b06e]K@1=CDd0KFe]06i^KP3<c<`0Jf][03Ti>@1?Cdl0DU9B04e=C@20P800
:b/[034a<@1^KVh0H61P04I6AP1YJFT0;Bd]04U9B@1[Jf/0HV9R04m?C`0E5AD0>SXj05iNGP1FEUH0
:b/[06EUI@1[Jf/0:BTY06e]K@1mOGd0Bd];05mOG`0l?3`07AdM04Y:BP2GUiL0CTi>04I6AP0g=cL0
JFUY079bLP16ATH09RHV03`l?01GEeL0Hf=S08J6QP1QHF405aLG05aLG01gMgL0E5AD08>3P`2CTi<0
8R8R020P801YJFT0ADE50;>c/`2SXj<07alO04=3@`1IFET0Fe]K04M7A`2YZJT0@T9203`l?01]KFd0
CDe=04Q8B01FEUH08R8R02/[:`11@D40LW9b02`/;01PH6009bLW028R8P26QXH0P82001lO7`0E5AD0
?3`l04m?C`2VYZH0EUIF028R8P0i>CT0GEeM06UYJ@1HF5P0Y:BT04I6AP0g=cL0[Jf]0:2PX00n?Sh0
MgMg02d];@0_;bl0Jf][09ZJVP1=CDd0DE5A02TY:@0e=CD0Ng]k092@T01WIfL0A4A406m_K`0j>SX0
CTi>0:2PX01GEeL0;bl_04i>CP0c<c<0AdM708b<S02@T900?Cdm055AD@1IFET0GemO0;^k^`2/[:`0
;Rh^04a<C01GEeL0;Rh^06a/K01NGUh0;bl_0451@@1^KVh0>c/k04E5A@1iNGT05aLG038b<P1VIVH0
@T9204E5A@1IFET0<c<c04M7A`1VIVH0FEUI03<c<`1FEUH0F5QH06EUI@2JVYX0Fe]K02d];@1LG5`0
Hf=S03@d=01IFET0a/K604=3@`1LG5`0EeMG05QHF01nOWh0YZJV02d];@0j>SX0JFUY07moO`2_[jl0
FEUI03/k>`1=CDd0K6a/07moO`2@T900a/K60410@01OGel0UiNG05eMG@20P800B4Q801dM7@1SHf<0
YZJV04i>CP18B4P0CDe=061PH02BTY80QhN704];B`2KVi/0>3Ph0492@P2RXZ80DU9B069RHP0/;2`0
A4A409JFUP1YJFT0<S8b06QXJ01@D500@d=308>3P`0c<c<0IVIV07=cL`1SHf<0Ti>C04U9B@0Q8B40
RHV9096AT@1[Jf/0TY:B034a<@0i>CT0FUYJ05]KF`1CDe<0WIfM06a/K00_;bl0N7Qh05YJFP13@d<0
Ogmo04U9B@0f=SH0@T920820P01@D500IfMW02<S8`0];Bd0@d=305aLG010@400;2`/05IFEP0Y:BT0
02<0@D5107EeM@0V9RH0;Rh^03/k>`19BDT0@d=308V9R@2MWId09bLW03<c<`1OGel0@D5108Z:RP1E
EED0;2`/02DU9@15ADD0K6a/08B4Q01@D5008R8R03lo?`19BDT0IFEU03Ph>01eMGD0=SHf02`/;00O
7al0IFEU03Ti>@1@D5006ATI02LW9`0Looooo`1W04Q8B01_Kfl0Kfm_06m_K`1]KFd0LW9b08b<S01@
D500FUYJ092@T02LW9`0Ng]k0:BTY01gMgL0LW9b07]kN`1XJ6P0SXj>05UIF@1nOWh0GEeM06a/K01S
Hf<0Cdm?06UYJ@1IFET0B4Q8059BDP1IFET0JVYZ04Q8B01:BTX0EUIF05UIF@1RHV80LG5a08J6QP2K
Vi/0UIFE0:^[Z`1IFET0Fe]K04U9B@1EEED0MWIf04E5A@0j>SX0Kfm_06=SH`1QHF40Bd];05aLG01E
EED0FUYJ05EEE@0a<C40?clo06QXJ01RHV80Q8B404M7A`1eMGD0EEEE05YJFP0_;bl0Fe]K05mOG`1D
E5@0ATI605eMG@16ATH0@d=305MGE`17AdL0Kfm_071`L01JFUX0EUIF06EUI@1^KVh0>c/k04M7A`15
ADD0?Shn02l_;`0X:2P0@T9203<c<`0R8R80<C4a0492@P1>CTh0:b/[030`<017AdL0>SXj04U9B@0k
>c/0?clo03hn?P1=CDd0C4a<030`<002055AD@1>05IFEP0i>CT0Hf=S05iNGP1nOWh0CTi>055AD@1=
CDd0Ogmo0::RXP29RHT0ADE504a<C01ZJVX0KFe]05UIF@1[Jf/0FUYJ06MWI`0b<S80EEEE0:VYZ@1i
NGT0AdM7069RHP1^KVh0Lg=c06QXJ026QXH0KVi^04U9B@1JFUX0L71`06i^KP1aLG40GemO051@D00g
=cL0KFe]03`l?01RHV80;Rh^06MWI`1;Bd/0JVYZ04M7A`1/K6`0AdM706][J`1mOGd0Fe]K05IFEP1R
HV80BTY:05QHF00e=CD0E5AD07MgM`1fMWH0=cLg04Y:BP1>CTh0EeMG05IFEP1DE5@04a<C04A4A01@
D500>CTi059BDP0b<S80;bl_04a<C011@D40@d=3030`<013@d<0A4A40P0g=cL06@1LG5`0;Rh^06a/
K01OGel0?Cdm02`/;00Q8B40>c/k02h^;P1OGel0IVIV030`<014A4@0DU9B01`L700f=SH07alO03lo
?`0d=3@0CTi>02d];@1<C4`0Cdm?04e=C@0R8R800P1`L7003@0Q8B40<c<c03<c<`0W9bL0ATI603Xj
>P0f=SH0>CTi04e=C@0e=CD0?3`l03@d=00e=CD00P0j>SX06P0m?Cd0IFEU03lo?`15ADD0Jf][03/k
>`28R8P0DE5A04A4A01BDU80A4A406MWI`1OGel0EeMG08Z:RP1ADE40LW9b03lo?`1[Jf/0HV9R02h^
;P1cLg<0Ng]k06e]K@2=SHd0CDe=0P1<C4`08`0];Bd0B4Q806i^KP1UIFD0HF5Q06IVIP1cLg<0@D51
06IVIP1XJ6P0?Shn07inOP29RHT0Lg=c03Ph>015ADD0BDU906][J`1hN7P0A4A4069RHP3Bd]80QHF5
07MgM`2ZZZX0Rh^;07inOP1PH600O7al05]KF`1YJFT0GemO06m_K`21PH40IVIV017ooooo000?oooo
o`0`08R8R02DU9@0CTi>05MGE`1LG5`0KVi^05=CD`14A4@0EEEE07UiN@0j>SX0JVYZ03Xj>P0X:2P0
HV9R03Hf=P19BDT0FEUI04U9B@1jNWX0Vi^K0451@@0f=SH0De=C04Y:BP2ATI40:BTY01dM7@1>CTh0
Jf][04];B`1iNGT0P82001/K6`1KFe/0K6a/04];B`29RHT0@d=302XZ:P0k>c/0U9BD075aL@1[Jf/0
6a/K03dm?@1HF5P0Q8B40P1^KVh0l02@T9006a/K05MGE`2BTY80>3Ph07=cL`1<C4`0=3@d04i>CP2H
V9P0AdM70492@P1FEUH08R8R04=3@`1jNWX0=cLg034a<@1EEED0?3`l04A4A01/K6`0AdM703hn?P0k
>c/0De=C06MWI`1nOWh0=cLg01PH600c<c<0Fe]K05IFEP2`/;008b<S02XZ:P14A4@0Hf=S04U9B@15
ADD0Lg=c02l_;`17AdL0F5QH03Xj>P1YJFT0CDe=01XJ6P0g=cL0?Cdm06MWI`0j>SX0ADE503<c<`14
A4@0JVYZ03lo?`0S8b<0>3Ph04Y:BP0[:b/0Ph>302/[:`0J6QX0=CDe05iNGP1PH600MWIf0<G5a@19
BDT0<c<c08J6QP1ZJVX0MgMg08V9R@0h>3P0:b/[05eMG@23Ph<0IVIV09FEU@0Y:BT0@D5105=CD`1e
MGD0OGem06m_K`1PH600<c<c04M7A`1CDe<09BDU05eMG@1:BTX0>c/k06m_K`2d];@0Cdm?01lO7`1F
EUH0?3`l0:6QX@23Ph<09RHV0451@@1CDe<0DE5A0410@02CTi<0LW9b03Ti>@18B4P0D51@0451@@2L
W9`0Ph>3034a<@11@D40D51@06=SH`2IVIT0:RXZ02HV9P10@400JFUY07AdM00o?cl0Fe]K03Xj>P1h
N7P0OWin03lo?`1IFET0EeMG02HV9P1TI6@0V9RH05YJFP15ADD0?Cdm03Xj>P2PX:00Shn?01`L700o
?cl0I6AT06a/K01QHF40E5AD02l_;`1ADE40CTi>05ADE02>SXh0?clo02l_;`1OGel0P82007YjNP0a
<C40<S8b04=3@`1oOgl0KFe]0;Jf]P14A4@0?Cdm05iNGP1>CTh0N7Qh02h^;P14A4@0FUYJ09RHV00m
?Cd0Fe]K05MGE`1PH600Xj>S04e=C@1ZJVX0M7Ad034a<@10@400G5aL08B4Q017AdL0?clo03Lg=`1A
DE40[jn_07QhN00f=SH0HV9R04U9B@1GEeL0Ng]k08:2PP0T92@0D51@04A4A01?Cdl0MGEe0;Rh^01[
Jf/08R8R08B4Q01JFUX0I6AT08R8R00l?3`0;Bd]05iNGP2@T900Ng]k06i^KP0_;bl0ADE504];B`1U
IFD0=3@d02<S8`11@D405aLG04e=C@1GEeL06QXJ02XZ:P1FEUH0:RXZ04i>CP2OWil0L71`01/K6`0W
9bL0>SXj04A4A02JVYX0?clo01LG5acooooo00@0GemO05ADE01;Bd/0ATI60P1?Cdl0M@1_Kfl0IVIV
04A4A01SHf<0GUiN09NGU`2IVIT0PX:207YjNP2EUID0WinO07MgM`1BDU80GUiN03Ph>00j>SX0GEeM
059BDP12@T80De=C08:2PP1DE5@0:2PX04E5A@1RHV80TY:B059BDP0b<S80JFUY05eMG@0a<C40CTi>
09:BTP2k^k/0@D5103lo?`13@d<0;Bd]03@d=00c<c<0AdM705UIF@13@d<0ATI604=3@`1HF5P0A4A4
03`l?01>CTh0BDU90451@@1<C4`0@D5104Y:BP1=CDd0EEEE03@d=01:BTX0@T9205EEE@1CDe<0B4Q8
05UIF@1BDU80@410069RHP1MGEd0Hf=S06ATI01BDU80DE5A05UIF@0o?cl0KVi^04m?C`1FEUH0DU9B
0451@@1>CTh0=cLg05QHF00a<C40?Shn04E5A@11@D40DE5A04M7A`0Y:BT0EEEE04a<C01IFET0Bd];
04E5A@1:BTX0Hf=S04U9B@13@d<0DE5A034a<@1BDU80C4a<06ATI019BDT0JFUY0451@@1DE5@0MGEe
07UiN@1mOGd0T92@05iNGP2>SXh0MGEe04];B`18B4P0DE5A0451@@0203Xj>P0;04a<C01HF5P0MGEe
06i^KP1nOWh0S8b<08N7Q`10@400=3@d05]KF`18B4P00`1UIFD08@1IFET0De=C07AdM017AdL0HF5Q
0492@P1;Bd/0?Cdm06MWI`0o?cl0De=C04M7A`1gMgL0GemO061PH00i>CT0@D5102TY:@0o?cl0GemO
04I6AP0G5aL010@407EeM@1nOWh08R8R055AD@1JFUX0KVi^065QH@1SHf<06QXJ04U9B@0204E5A@0?
05UIF@0i>CT0;2`/04Q8B00i>CT0EEEE03Lg=`1@D500@d=305mOG`13@d<0Cdm?02TY:@12@T80FUYJ
0080>3Ph01L0<S8b03Ti>@15ADD0FEUI06][J`0i>CT0@T9204e=C@0M7Ad0<c<c01LG5`0m?Cd08b<S
04Y:BP0I6AT0?Cdm055AD@1KFe/0:BTY02l_;`15ADD08B4Q02`/;002038b<P0i04M7A`0n?Sh0=CDe
04U9B@1>CTh0;Bd]03Ti>@0Y:BT0:RXZ05IFEP0g=cL0@d=304a<C01HF5P0DE5A06UYJ@10@400?Cdm
04];B`0g=cL0Jf][05]KF`1hN7P0De=C06YZJP1lO7`0F5QH0:RXZ01OGel0IfMW05mOG`18B4P0BTY:
06e]K@16ATH0IFEU05YJFP1<C4`0ATI603Ph>01DE5@0I6AT07MgM`1]KFd0OGem08>3P`21PH40UIFE
07MgM`1EEED0Ng]k04];B`1aLG40Fe]K061PH01?Cdl0=cLg0080CDe=00l0OGem055AD@1ZJVX0X:2P
07AdM02HV9P0/[:b0861P@20P800UYJF09RHV02QXJ40KVi^07=cL`1jNWX04Oooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {639, 0}} -> {-0.0500105, -0.0500105, \
0.00328642, 0.00328642}, {{15.1875, 305}, {623.75, 333.938}} -> {-16.7712, \
-16.8402, 1.10417, 1.10417}, {{333.938, 623.75}, {623.75, 333.938}} -> \
{-368.726, -16.8402, 1.10417, 1.10417}, {{15.1875, 305}, {305, 15.1875}} -> \
{-16.7712, -368.795, 1.10417, 1.10417}, {{333.938, 623.75}, {305, 15.1875}} -> \
{-368.726, -368.795, 1.10417, 1.10417}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Train histogram models", "Section"],

Cell[CellGroupData[{

Cell["Visualize training data", "Subsection"],

Cell[BoxData[{
    \(\(trainPos1 = {161, 1};\)\), "\[IndentingNewLine]", 
    \(\(trainPos2 = {320, 320};\)\), "\[IndentingNewLine]", 
    \(\(trainOffset = {4, 4};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(trainingVis = \[IndentingNewLine]BlockMatrix[
          Partition[\(TakeMatrix[#, trainPos1, trainPos2] &\)\  /@ \ 
              texImages, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[trainingVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C565693554447598659344C4F4F658D314144566CAC671E515B3687AF291F494971873A
244D7B58969D193056596383841E53508C70833E2C6FA54A57621B37566F454F321F6269
603E5E283C9691223440225BBC51263A32336BB73B2B4B613E92E0371C767F3BAB731F25
676F4F88521F265B525E5A162D636C2C3E503C355E642D3A3335538376325B4B495E9E5C
3257573D80A82B2C6D4959923F1B44615D76C22F27485C3B8BCB3F213C7158BDA53D3D4D
684C9D78204F8962779242245A89648188334252A273A36D4073833C56783B3799C45653
4B355CA35034514F6FA07D36574959AC66344C5B48A8812B3F80678C672528767972A42C
30617B65B967414F837D526F3A4253906642622840497A4A375B2D3E4C71686A6B2A2848
933E3B4A3F54684F1E464E39556A4919343A564B597B1D2F415C61786A2639545E5A4C44
6964543651543A675D594E4D776E5E565E49234E383C5B4D3C3B514B5952404040504C50
486655272E2E3541394348353D4A2E253A394A35354C61813C494E33344D3A4245577363
3D4D5B5D705363451C1F3D4C4F384255625249525355274C3F31334F4443334D4342543C
57454046254C245657685D324C2D4B543155443D5750532F3B423E6F6348A973325F3564
5F3C905F3185414A4B581D4C242C4B662EBF6E634D972D525D4B21552F20496938461B4B
3033461A47362F6845939B5968663A5D3467628F3751532A424B4A5D469C974D54532C53
14494B5E6243505E9C555E6715225F11562758364C3759555F5B4B6645816A4C64247353
466735775039464A504957613F4717682F29371F5B5D3F6859595339546565655D375153
2E3A118AC2786D433F562C364845653042607E8A7C6559584B66576C
B3514F6F719848467E8386BD413A6365617B71205F576E5A742B194A7C383734203E6248
866123293F7E782E6E232B82AD5925533456B37A244C7B3A848F2522455E5B7A5414375B
49819F21355793518474192A72865199411F3366946274321F4178825C7322417467434D
8638447D7C2B404F42778D43284761567976252C4A6B56A1572249647862A18433596586
63BD454549956E60652137738244704C2E479C9A48732D333E8159396C302C5C7B493D4D
2E365D82403A554447A07E3058442D78B44930555046B7BF374A8E59599C49214C925E80
7B31586B9A6FC039409C925B69492B739753733D494D73608A9039958D7D4B954B54AC6F
4E60463579A64E538557478458336F675491B03A3A5C846C829B393C4353429BB230313C
7C617D8822466157387A8E27225C713D5587332D4257324E6B33334A4B54498448622B34
38586B625C553D3A4F5F5966848775495C4B162C1B334E4E5D517A6762585362616E667C
716360362F483A553D405E353C4E3A323B1937221F33373D2C1C222D2F31333E4C4A5B4E
3B38383C4B1E2C52242A6348584F4A3D353C2F40272A233431283036242D222F372E423F
4B33434C1F301D66533A504E6B47574067925970645A792F57545F6E7757A39342685891
814D744E4D8433584A80564A478E5A913E7156533E4D4A505C4D355D42106A71395B3142
2C37542B554B3080557A8C2C4632436E43576198604B4842514A374E3274794A5831425A
465739724E375455A26E81892A306E1F4C4F5449544A59656055557F6594695D9C4E863D
384C2C783F40504F525743504A60324D3B5E6E3388644273152549354451504C774A6D4F
2446145BBB9E8B454353336D733943336057635A4255675C54558069
78745A6955817646713D366A80427055375E95352C4D373E8F4A19525B63834D202C5244
759C2236466E74599847472F505C89AC1C354D714B7D5A2A53523C4297253D4A623D4A54
23398D732340303F55582E2879333D96511926364452B44F1C3A49586ED85314609C688D
D2353A6A85716C791F67904B5F7E21395886446487153043753A51851E2755AD4C536B1E
3676922F594525418A3B2C553B417C8A2C346354419E622F4F574B5EB3512B716F5D8597
2A366A62449A8A223D64915BB8762547839258A2352C36755A5767274C5F6649723D375E
67354D5C394366642579448B9C6138433841B3853A554B427ABD3F38676564CD4C2B7167
598F582F458A8B84BE48514E6D5BBB94324A725E7FA945324585735B77443B609378476B
3E2D54A67D567345237DBA704456313A5F97492E5C473F588A302A55463D58A0578A3E46
534B4C3A65643949629790795B52676158562E33313647354156545A7355365D69703D4E
61705029313D55543B4662474753463A4E2955241C4B425442212E39394630443E555A5F
30436643753E456F4A505B524D65704F504B44463B4631322F303A403C51302C373E5D3D
434F47392C42313F473A512E332845462E3B3333466B64444E6061777A69B994515E397A
74456857405244372F885476644B628C5DA771513F5D2D61846041514E1564714B7C193E
413E4E214F3C3290636D8553654B404D32355DA3386956294A4354832D53603240272044
1551294F3B4B673B84469E974A318B2B59596B445D34555E504333682F5B5032672E4948
4A6F47684A4946433A352A3F2A46375B4E4835444B4A585E3C5A5E3F3D625F5DAC5D7943
2A6D305F89715F5E44562639412D4B2C5D4F665F3B3F5746435C4850
6C83B5734755675D873445506B81B84A3F445A48679D432A4B6049AB8D15447347675622
375887345D642D33916A39554F2663A37A397253449AA02546624253A63922426A43776E
2C2C5F81518E331D589257549541393B8A4B856C213165933C694B2D3975703C473B4743
81602C5522344C7340203931527D462031574C5BB62E2345423F85A52625435F3D9EC622
353A6D6AA4A62041556765B038285F93708B923C2355764189962C43639C477C6021495A
603651362151AB84344C5036657F42433F4B648F644160463F9CCD493C6C6554B07D3248
5A54977A224F82644FCB6C2B72794A882C334E6C568F3F3349866D625E254D717B7D9034
3563A7446F40314D99953C4C2B417C994741584A4287603739503969AE372E4160526FA9
94274F83909BAE3922437F6A75A7391A42517A69C54F2C334E4F548F701F374D60522536
526A6B4448633E57655F475945305249554832492C354C504448464044543F464559464F
3D4950343F3E37413C3F3D394B51464E513C50393E4B4050373E492D3F4B48474349755E
353F66506D39415A1F245957523B3E424753464F3D4822242B2932373336222E312B422E
422E3D38324C2D3C5857783B5639675037553B3A4E47542B3F2C335C5F4744522D5C256A
7645765B3F5C3D47353D1B4F304B35BB44B465494C953E2F464A33593733A78440583439
3C5D6E264A3D3145646283394D553E523D58576C5CA688313F413A475E656F554C544348
326249664A475344834C6B9F60479A72704D4A30583B4E45444E45673C6E56306E20632F
37551F5F2E28343636544C49565968504C434B4462617B784643563D616751465F50836B
6DAE4A5CAA856E63747B394B61435129424A7476494B564D4F5C6573
91555AB55A633F4A80743A543540705D2E6359303F6B4C3B532A3F76892C3A373789AF3D
2F513F42AD9D2C2945546DBD922024667371A35E1F45723F946D173F545960721E2C418B
565A742F426D78375C512F477B4E315B273760943530544A438B851B2437506084522742
475754A54E1D50535871751E224F88527962443C6D7C567F522553928342BA7D3B459D6B
4D83303974BA5E464B2845736F35443D355CA55B28404B4B76A740354B79599999263647
6D60B441224055866DB0543E506557837A1C3E4B68478D5F30317F615A60183948694854
5C1E4B7D615E782D2E75B04E5E365FAA5933563634777F275F5365AB86314667366CC06E
2D618378CC7A305D806F85BF473D66735A94A032396C9D8BA0892B3665814787A026319E
BD6F61421D43847233484C272E6D8A3E474A16328979263741282A58882D32544E53324B
6F506A564A5E36334D6E5E726452624D5F4C242D232A35333744655953583D726281595E
67555E20394A34563535563636434544452D3C2922385062371C2D40614730515E4F5963
6457603C6F4A59682B314C3D48554C4B45403D5C284239412B2C3A403547344044365A44
52404839364928344E41503A502D4C365457374D4A435838513D4C658A4D8A8539591B7E
69418340536C2C5D44544649477F436B2C5D524A4D484643574C3E772F0D455E45613D6F
526364397D3F325C5382A839542F224D51514A6744655F333C4C40523160725260654749
3B534A6351576F5582687D675191B59066514B5A89705D6A70555A745D6A5B4A76485E45
3F5C3F624F4C6B4A535B5D5F61693F683F45523B525C718A1C3D55385A55558A8A5C846B
5C684E8EA59BA1633E4B44748B3C4F4475584F4C505350616A5D9270
9E514D7869A3483D606661AF4D304C6E69A499274D5E6875B31F4A5787558C652A216A97
5C94302A448151718A192B4D84705F8A283280663D575D3940713A30773B7AAF4D293945
376BAD382243614C8D761D366B6C84C1322544826861A33625649D4D828B252E57783749
9A253C588A3D6C4A304F5A4E4779273B7D7C3F3B4D2D57776E254C553545759C2F46436F
779C5B2E4951507D932C3C6B5C5EAA6C2143639D659A27314D689068783A435693664F59
2E2B5B903E54662843677943633B49609B51374B52559F8B2A365156689A343054474DA8
A12C3646469CB83636455775B24F233E5856AC3A445C5852A8822058864D9A903A367A7C
54977F32579D4C8291434261894A63453E4A643E42722F3D5B90763E74583A55A0783854
5262B96923426560539B732F26345A45A3812F244970416E661E334E474D41A15D784C34
35524935595F3F3A5C918C9B77626A4C54582C373B2F3F313A596868605D516A59544557
584C4A3429333D4E2F42493F3C4937334927483230301C2B2732312D2F443F4C3641674A
1C24523E5C242F623C4F61524F5B5F4F595048473440241D2F262B373241232636274A26
3C434C58404C4E4B6C484F394A485F3A2D382D36485A50454D44527E924E857E54682176
6944773A2A371C3134624063583C669061AC7E5C5654356481743C4335155F6D36621A3C
376C91293E3569AB71587F4381494B60333433603662611B44453A602B77855693734361
246223785050632D98548F9E39C3A1836E525D456C45665C5B51356C3C9D6D3C7539866F
4D7A58855A5C583D3A5B332D42653C44335D5C2F67563F6D2E3845193861646B98656450
53794E565450404D40502F2A473F4521344971683240624148595559
86B1738651706B5B763E3B7582577C2E395F94474E7F22465861396A433A4F512C3A3D43
4979262537484573B64C1E4E70696DCB2D27606A58A5781942743F5AAA45296B793FAA4F
232D69686668232253742C5F731B3DAB82254F37393F8376395E413A4E8552264E466081
D353274348578C7F2B4B646961A9311C4593638A921F2D86AE3C7689223175AF4D7A7B1F
33657D48723E2844564430A129246581484F6E3940998B4360642D71866E515F494F689E
412C4A59437DA42C3049734A904B2D4A6B8B66A53E5D5C8C58835633678B8661AE5D4675
CC73664437468B88598A33496C87495D2C33678D48703C3482AB4E414F31749F48365054
466C833847565881BE3B53585A6EB16B29477A5F81CD513540909C788D692F3F6C905FAF
584453835775953932749445404B211F4F60453A4E1D313F7B7B3D57303B3D7D71682D43
465D55425B61434E575248589C828D5D5D4D274636344553394447596C4B3E5360645356
5957523A3C483E4F3A4E503B484B40394E25593D2E432F4B393138394552544C464C9C66
3C446941702F445E28265F5455514A4C454338503454372446413B3A3E4A2D303A354736
4841332C314B353F4F4F5E304C406D393B5037494C373A304A523F615F528C682B401255
5A4C8C5B3D412F521B322A5B303E54965FBE7D503E682337413D335634377C6A31462941
313B51374B4533444069974F6E4630454C41539A49A39D20554F5E7F4662733D3E453434
2A70354C43726F477731475F2B3B27815C353A306B2F4059583C33753745433B7F30513F
3A552F5C2E1E2C4D413142423E333F5541403E404D494D882F3C673D6D4D564A47606249
39B0816E9290667A4D753F4955435429404383834C4D6749534C525B
6F54A4B6514D495784382D446C88BA45222B605D90B1263A4B5963955A16447351745E19
2E725E63BE62253C788C4A75742A27728C6499222D4D7E436A4F173C673B3D4D2A3B5858
25354F2B5BA3471A3E673F7BA51A123B73648570213E675B609D871B5583645DA7452746
836E50702A405A7E4E7952203E8481384B403959704F2F404944669A3A2A485A4A749D31
283C5648AD9E26345A4A52D6561C3C674F83B0333F5D5766ADA12643768191BB9A2F4482
9076A4432B46526B648B52486B69396F76363D71584279554F587E473B52585C7A572338
584E7F68263F40538DC1402E6D5E679B2C2C50645698461F367459856D354D5962668A30
35566F4B92422F676E43497F3C326CB96A5D70263C6C734E956F324F71914C3E54304DB3
702B40413C629E79233C6055696B2813316142597C1F27344E373F702D253A5074642F3C
616D5B4C5B6C3F455A667F6D857D5D5D584D2546282C343F465B4646463F394D3B464050
474147221F31464B232632412C2B353F443854372A443363322F3C38594E45504748544F
4246443A503F3A532D3C565B525A56454B47366A253F334638353F4C34452A394B284937
473843363A423B415F4251355244625544513331473D5441534E487996647C6E425D1260
5E376E385A53293A344A2562327042833172516A5A3D2C587D6C38683E20677F49533256
3C54773B6E43446E5E6E8B4668303F575A52475B41485D33334536514B728E505B584141
294D365855445444884274851B40717A6C3C462D5A3F4A505645345B43664F2C5D1F664D
355A3773544E5A61544E5A5E43522B67353147437242656E3C3D40392B4C4D5D6B5B627F
589D5B71788D6E7B66603D4C5E3545194136556453484C52515D7C5F
B55252716E7B365351495B7D22316378396F5329478F56484F1A2D6B9E4168391F588B3E
385C29276B91283A5746367491262837419DA54B15455554B67B2746806389A9312F4F7E
73728D382344623D752F21428A715775262C7A9F43456234447891544656304984982737
4D3A55955C234C67668B7023294D7C4E83642B49684F65833A384A6F735BA9593C578070
6F863237638A537D822940708B7A773D2D36A0B8628A492B6CDE8D5576323467B8583F4A
2759AF6D2D4B60345EB4A9354D734D97A73549525E6FB07D385D736AB388223545805183
5D2761844C63832138B79247563E336E8237703B3D7F9F3F595532416F3B47522C427C68
27644954766F2D47623F85B159243F6E608E9236374B5C4198A13A3A49838091AC472E62
A68F955022386E99607F7622466C603B5F5E234776533455391D3B7E561D4B415A62463E
484C444C4A524F3F557E766A755957634D4A33473D434333333C4F6885573C474F5D424D
5F594B32212E29433B3C3C28383D432C47263E362D3325432E393F302C384D445C4E7167
384057586226314C29214F484442443D3E392B4C33462D26403E3F35323E2C202D373829
334C40493145305A624A5549585D965451554545484255283F4C354F6D42866440591E77
80516C3D4760315138573143223944B33AC66A454B553C2F444F313E2D1E7F63345F253D
2B53922B4C453B755A6180435A2B3E5A524C5F816055502D394B44544A9CA2515A4A5A5E
425430786448574A8F667F8A2D2B994C4C76603E744C615E5D504C68506262637F546268
536A438F50394E3B2F4831323F5C2B5056524D564E5C536538485132364C576473666983
56AE80507276606D46645E63794D502B5B46766B495061454D5B4F50
9C7280554F8A4E40705057BC85384C433EA86D25295035659725273F4565C83F2937625B
88B328453D7640A9DC212250A28C939A1349899A4980421C4774405936163945442C4E2C
1D718A5A345B2629826A1C314155738D4E1931546C5F983319386C5CA1971C264C8963A0
922D44649B71B8742C6C72666DB7293A63643862603D3879752C5B67284261632A535529
6C975C3763543397DB4B3F4F3244AC9529375C485BC0432F40998374AE333A457A858C70
1F2A4B814B6975302B54AC647B2F2D3D545E566020334977334C462554A15F4D653E3580
9F45333D43758F58315E387BB6492D444B55BC5B214A6E59A1A13B375246A2902046505C
4DBF542888A44B94873B3A7C885E7F433B3E846F5A68262C54625E4B604E2254645D5485
35339282383E5F42408B70272E47534179712A1F4A535D9D66152D3B703B95845F673034
4C5E4B3B758A374F5D5C5A7D765670483E4438463531394A3C44241E2F3C3633334B3D42
342F4B3B3E2C353F3D4434324A4D39384E3D5E38253E214A221E29384C33262E4A345257
5B63542C5E3E3D62252C65494C574F505141315F2537373B473C3D463E402C3344234A26
3E32422A3D422738424E523F3D46533C4648353039364A3C4B5542706E377A6944854048
553F804A494F4755317F3B513151517E566B5160556A3A425E5E2A72562A6C6E3B3A1A4E
38445D4462393368526B8A43550E3055504657924A60502C454B5D7344606E4778543335
28693E443B524B48905A7390683B895D4D4961335B31614A55433B61448C793B761D716B
4A772E6A421C29282642424B42404459555C53434B4D60623D655C2B345257648C687474
63B3703874796D714357283F594A5E2C41409FA35152764F51585561
6365A87C436A7B6595384E6B8F9CD12E413B7F8693842E424D4A5D8342308589344E3F27
3A90412D553D1F318B6C2E57372D557D2837495482A231203E443C839422285E525FAF6D
1D367F8D5D952D1F428B4F837017364D5646765B19305663286C58193A875132693C365D
884A3D5028315A8944646B2D49AD912D45624677942D30467644A6C0302D518C4B988E27
32738D40914A34437279688825363C876B486A2F4C656F3C4D4233596C61507E512980BC
69375146386B9D382B504E4EA7691A3F5B5D73B731275D67527F88203A596A68A9302D41
615D95861A57A5AB64A82D4A6A7B526E26236D7964763126407A5560452C6CBB5D4D6025
469168446542425E8F47404E4C60817336465A4A748846254E5B5C6A76AB31435B4E89D0
3C23596D6AA3A42A4C69735161781F293468424E4C1E2D4765403A61312C4C5D7048223E
7D675139403B32334D6660736C5273545A4317402030404E534753615E533C62657E504A
614C5D353844364D343E513339374C383D2C412C213C345527242C2B2D3B304C4D4A635B
262A5234553B55441E254D6250423B2C42362D3920352D3D2D3A333F393F203538314235
383D434E3F5130434D43513A50467A3F55532F3B3236492237493C5B742D5F625674255B
50355D38895F304D3644397A2D2A3EA334B14F6D544A2C3E636027533B05826730532E4B
3E4582294A362E6448415F376C3636586A4F416B3675661929222444339DA64445475D58
373E38726142474FA94976975E455D3D5358613F4E4057525F4F417E524E4D538342464E
385E3C6B5E3B46353E506085585C3A6D3C3F4E4A534C5F876A3F63305A5F7356685A917C
518D6244875B7C61637D445F7252683656397171593D524945475959
954E519558703F4A685C406D353B7862324932285B992D394A3E5882441E435F4F8E6127
2143424FAF732723436258C462305F633F6FC9312F957D64893E29509C5C63682B1D4B59
2F57542C567A5B316936324183393B6D29455D7D19295C57689499272C4A4063AE493149
514A6EA44127598D69968C41313E814B93742042536845693B2E4E715E4F874337617449
4D5A3145557C3561632F5CA5502E535E5D77A938405E5F547C812746878753AE5E402F74
7C5F8E2C3A3B68837A902A3A47694477743C4C7B754571584A51A24F5A453D4A81A13E62
4E35608A332E31385E8F642C5A3561C34826503360B966273B5E6EBA8430405950888F23
3B65705FAE7427587250705941496A9E798F98544D947F50AB8D3E37557A604D683339A7
B44D74413D579D6B36813D3B5AB16820484B34558F2C1F3360415EA339264A4F846B413A
3D545340585318364D7E6A5C4D4A685A4E533B443742454535414E69814B3453785C4F55
5E66543A38364152547253474A5C4D3155334E311F2D1D404F2C364A52462E564D62646A
3E4570366B2C292C2D3B4B4144524E495156474D313A3934543D4245403E332F4C2E4F37
4132382D31422C5B5542514756466935323335472A32322C37462F484F3FAA7B4583216B
774A5D3B5B6B2E4A35534751333E447141B8656C505521384C5F26614A20506B317B1C5F
2C2F4F2979482D563A60701957292748524654A73C434915483A465E364D5E4E504D4236
3B4F3449394E424078444F4B373E52494E536054563A5B4A524D4A63456871475F455561
4D66459286484A45565656613745445C3F4A4E4C83794F4C1E435E3C3F4A60506B52515E
74A85C67B25C734D375B2C394544623D3F34917E47476E4F4964615B
A361565C67BA5642515772AE47324C4D62BF68244B544D94711543596255B3212F61595F
4C631A282F5E3E7F69223B7E88294C561A59B062385D37378C3B1D3560335A912F143343
2B939B4828545E49BC5F2040455669D84523637D3859853C1B667341506934368EB4485B
4727457E78455D3E3362874143553E4A7995352E3B467FA35C163D7C557CDE8D1F3C674B
83CA443E54575A9AB43F537F834B7F4F3E5592817E862D5177B46D504D344979A157715C
46499E833858572450BD753C5F3A395C912A3D4747579166274B65527482213D676F81A5
6F1A5B693D65581D2D728150883D336275518722364E7C4253492F5A7B487670264D7A40
55702A395E86556180417DA863414C45434A725640553D37769F502C4660858CB34B3351
897FA36426567A8A5BE2571E4249B8608B632D464961404F2D2F2A4885355F5B81722631
57584232616F2E52545351745E4D695E453D205338313F404943565E554027514F6C4C53
5F475137464D314C404250364E61414354375D40344A286031534C49524A3C5465496E72
41457155694B4D2C1B1B4A5B613F3C524D373C493C463C5A5A443D4C49382552512C3B48
5A384F42444D35444543533F4A4B77507460383F293B303641443043493B56473E96477D
5C50814456532D4562932457304B578C3599565E58703F4A51611C956B0B645B2B4F1845
242D531B4E391B424E484F2D643938514B4035682D646C2A2A3C313A305D633F663D3F44
32492C67433728349F265270342D74474A5C674D713B554E5D433F6D478E764D894C7175
586D247A9935445B513C3D4A344D1F36262A34444E415B6E1B4680324D3E475B8A6B4F4A
39614B4E973B5645405F374348346A313E418A7A4A526B4A55545163
997E9E514A789F779C3C4F8E84596727305E7D3B50513C49903E2D4E3F569F4E243C3E42
568D461B3730419AC52E2C5D6551B06A2D2E5B6C50AE1D355B9F5C8E2A2D255E68466D20
2A3D705E5768192651642A524A1F3675882D344D473E6F3B1F4659535D732431586D6AAB
68213D56635E9F34203C857E85BA2433428951917F313083AB436C6C41437CD180685B2C
3D7F853E6D2E275299673E5E31425E70336758426D8E3A395C43369E872A2B57844FA4B0
3C424B6C548078303460B194B5353C4D7F5A817A1D324C7A475E3E2F617356335D203477
753A4A522261A537214B44448F5338623656904A284D4B67797136415D4988921D406350
7FC84F29678554B3854B3E6F7F76C16D3B3A646E96834940508388527B4E2F5DAFA76FA5
345D73885B76803952A0A22E305F34365A662D364C363E83742028475F3E89916A532F42
63664B3A5B44192D4E74696A60556549423E193626303D3A37526A666954396455786C6C
6D4F6125333739513F4C613C4A504A2E413A47271F34193E1A29333530392740383F6056
4D615B355324362E1F255E454C50433F4B3C434D24332928433733382B3B262743284834
40273F564C4A416D5E36403D49435F42523C293D3B5E58313D605D5A5E4C687561891556
62405D3B907A264A38523252333C289F2FC276684C4F333B4854244A5B0774733D622956
1E2753195755303F43496222627A3D3E5346649E4E4E472229342E442772773132354945
323E1A38393B3D3B632A51563057A65E53506E52514B62373C414553498379557D485960
324C32476539413C4B56325029411C5E4C394030392E434D25456C243047504C52546E66
779174447A40705848654C585E4D64367C4F927B594B735549625E5D
5F728B8643505E4C89353D466F8BB2292F4E5F69A49D214B6A5388943D2F5A8D628D5132
445D56528D48184D54705A87392E427B3D3E6A2F466348304C2E395D591E39413D5E994D
17353E366DB32E1645654C808A152441764F8769202F344B45AD4E3853464C3F8838394A
82463B6229254F812F4436253A7E4C273C463567A83521475B3A92B0263040766BA1AE1D
45625E7CB6352D5E66639D9A263367603BB6863B3C7C72519471334DA8866676442D4897
69577D1E2E7B95694C78324E6C562F4C552A659D4D256F67497892284B7755748A2E2640
6840917A364050606C871C434D5D5BB73536766458784331609F60824D496E91425F3724
4B9D9B49503741529A4348493345548D464B542159A54E28454F42429EA534375E6677A5
482B88724387B43B35628A7586782C2149744983931E1A5D755A579D431E427A72714838
5162564A57673A376290898864505E464C522E4530523D362E43494A6952536258584752
545052302B2F4E583D4B47354C504A42592A4F44444A274C274B4745485336564A6C6C6C
3D417A437C333D4A3A39414C4E59584E5E3F57593C3E3E375D364E464140333556284B33
532F464B394C2D48442E494251396F4A88622344293A1F2B3F3F3E47536F937883935A8B
8761603E5652314246643B612372427319C179514962304559632C5461105E69558B3358
2F37533A515E243A4C49671C56753E4A4E3835652C53461446604244294D744F35293C3E
37551E4F493E40518B5652574A354C3838404C414E264A3F443232512743583A71394F52
33512865A43B40553A31204F36503F5C5631332851506E923737643B554F5757725D704F
44876583DA7754453F533229364E5D27433E7F5F424F5A4243565C61
B95C6CBF7BA540555A677378293E71483E4C3241498E544E3B253D7566344A1A4A6F5C2F
32581D55B09C28334D225DBE7B2042524460BC373C564B54AA352458843F7C6F1F3C6F6F
366A6E242F60643E4F1C354784332F5A2A3C566E28313E393D86732130393A45A2581E3C
595D549830304173439F6D23504B5B5DAA68313F468E519D492A4475815F8C5337477353
478D2932B49D3B71602D4CB29C3C7055325A9B51374D3C45757631405A397CC26E313569
5B83DB3C2541805B64C148334B65589F862C3042734E915B4059694A457621318E7F4D77
3F2D4B953B515C244CAA6A3F513A529165495B2756B477284C5D3D9B8B2E5466609C4925
2D63666BC25139506D568C9229415D7561938F2A364C6959A7B0403640524784A1453A56
76449F502C446B64438D5925418F662C7C471D44945B2F383223378D5B25243769512439
7052432C4A4B2B5A514744597D4F5C473D3E31452C2E384D3649444A734E3F495A474551
59765B30332B2E3D323E37284551363B3D4549231F3921452C2329404A48444258548762
50657661704C56241A1F5E415A44433F4D4952513B4D353A4C4D4F4B4D553730433C4B31
534B3F3B414A3D51482F52455B46783C876A3D4F224B432B4C4B45565A537A636E7A2A61
535C8E47686936454159254229473D8919A0565D4E824028405E104C6610436F3346174A
463A513C474E35535B466122799D4C4E52372E87275E54172B372F4D1C657C4B5E393F44
36441F4C54616048824F53574048592E424C5E5B654D554D4B39305F2F5D643BA8515652
3065374E792D3F45424D3C5841571E61443045324C563C5628325C2F3730516383524F53
737F4E4C6823553D3E594546582F6D454B51655F4A39484449515D75
A4525F5955A457444C3D7DB43837504980B23F3C5A7454B39C28284A709FC33924417859
83A3383838786D4C8A38364E88498A5D1C365A533E56173B57693950253A4D6B362F493F
4B4C691D2044394FA82C1F24554E589121323E78546D75253556A5677A6F15485B604158
4625435850486D38304F6F3D5A6D1E384B622E39522A368C7521403B3A488C683F4A4560
66BA511B5879599F9B372E629C7DB67E394A9A7E80A03F2F4F7B687F84333A78A161657B
3F4B91AD4B62512E358C925054293859964A45402F2F536837593F6382792E1F444657AF
622B386F457E7A2349746460991D3F745280B63D215D9D58916D4D58734A65781A82BE67
768D593D78AB588659584C8F846797483E487B5A40562F3F6FA4A93C5C523266C7A14456
343DAA6C394558434DB35E233A504F49A9752734585F667E45122F2E63646E4566553234
3B536C5D5B542C2A48545F5F49404B403F512F321F33353847596351595258624F6D758F
644D4F211F28444F2E3455373D374B3E411C302D1E3B222E2A2A2F34272B332C2930604D
2F26443D43352F1F1F23343B634946454A3A483C1F291E383330323627371E373D213E2F
43353B444F5035524C5366425441593F844D39653250693B4F4A576355468A78AA9C2271
7D4A683C6D52455849643B4B2B4F478723A3799673593F3946532972681254872F5C2A45
3764782E523C1B3E4A5588253B5E40474F5242762C667B14242F4B7F2F636A3E484E4B42
384127554F372F388251787D5B404939464F564B502F4B353F31334A275555294F495C52
204B344E96374548404E30392F5E254C3455534F6E624D835E47644D4A444B4676765437
438662686C34615D40503B4359275846726F5D5E6B5052554D557A83
A57EA8734A848386A23D3D7F946C7E172C796634595F243666423F6A273275633978401A
54852D2A4B3D424D7C263364475194A82B3D494198AD3A27604D67B0381F3E613F62A948
313F5D45618635286E742E573E253C695B29564736407F39355226536A7C25254943377D
63203F5D3A418B591E4360406CC02C265D8B656AB22B2653924C8A751E33627E618F5629
455F7F4878292B46746553521B3D56A35C8560304F928D3E43393F566E463B5B53556492
383B5867707A782F435A8B5EB03E2E4F5A4C7DA7253B705B48AC571F498C6A536E282F76
90395A47233E7C4F345B2B3E70504659233D946D3D4E292F73943D5A5452A2A6333A5050
799C4C30406081A5963C5E635C78D2852F679B8083A23F26466A8E7DBB681D3E8DA69DBF
3B2B70BC617A7A3E5E75995961982F2C5F9E54437C3530675D38466C24308D83686A3133
5A4C412B606A2C384C91978D6B56724253423A3D3346393B2C414E589255385890583F4E
688C4A353E273444434B4A2C535F4D5058394E493D592443513733434D492D4D40496F70
333974568634533D27334F2950494D404B3B4233313A2522453A3B3A3D49122138253F20
343637322C3C37443A3D4E4744415D3C3F3D3241244E353F396A476B5B6CA769617D5E98
768BA357855C23414664445A464E348D318D7C52446A36496E78324B53172B723E682353
2556561B3B444B6E5B354C1A456037514F53427B305A5B2128422F4F415E8071685C4757
323918444765452E6E30433F34385422362F53435F2F4243472C2D552F6A641F824D6353
2872383362233C303137293B365224552E33444E3C414D8B594670384B4A6A537B49874A
506C583730208458415845495432764D452D835F4B55594E4F6A5C5E
8D4D749B4E504458A1553C483895B137203D4A409390212238376CB84628333E529E8315
3B6E664F9E6317474E40699A332B7C9961907C1F3FA4846D7A232D7B89334F4A15307E54
174F44235EAE292A413F396B72171C4B574A9A562D2D636560BD322B42735679A12E1D3F
70477170262657853F5D71293A5A59255A4F3332544D3D4A39454B5A2929463944897D19
444E465297482235535278972D25498058A4BB3727547B76783A2F6B756573A439374F5B
5F66AD294A547E7EA89D3E465F7241606825306B552F5B442B68A34E365034659D3A273F
64418F742535524B5FA1333B524B7AA62D26585C7DA52B1E448364915C2E489657754239
4E6A8F67842A447889506347353654AB605E72305A81672F5569264394A644485C4757A9
3E2245483C7199301E6773665D932E1F2D655D5096372A48553D66AA232163815349322E
3D4C4F3C443D4447463F394D6656695E443E2B4E46394266474A2F3138423D484B4B4C50
4C434A29373A304637364532393D3F36445054372C43335F50444844483F4240452E816D
34395A4E4D3E57524D4E4A4A5C4344413C453D392E4A2F3A4D41333A3C5921334236382E
4A4F434E4556344C2F3D4F28433F85305222354E1D3331362F2A3D4F402D493D82712B46
42475B495843344769992E42264F588544C99068488453223D5425494F1A388D4182324A
213E481D4B4E2F3B374F522B73764C505158507B4C626020445845564A747C6379673E39
364A2C494D3B5341683B7675383A4E1D3D33433F6839453744352A5C344D4F277C5B5247
154534315F2C452C3642274629562F5C50474C5D61638A8C433159373A223F4B915D5761
6C7E71494628563D466832445536714A49415C5F4B53514846796173
C75B5A7E90B03C4064787C9336394C5D767F314063A04F675820406F7F56711A3E658846
89592A404954303D4D194988431F3B3C39AFB4302D424288C04E1B477A588A702C2A4872
46855D2030814C5C722437467D577D7E1B1D3D8046617923265D7D32544E2237725B1F47
572B6090382C3C4D347B922E1D4E61479B7B2842424A69BB5E1A495C41559B571A54814A
8C8F32347D8C476E50214C896F4C63313C478F7855602E2B8C823650663640A98C303D53
4253B472244F493F8FDA4A33513E3E8FB22F3940474FAD54333549446A792435525E4E7B
3F3841783F65422143585465691D4B594B51602C40A886468B3C295E883A53583C878D34
4468655BB18E2C50726FB691363F567A77B7B53F455C914EB3AB3F424980728DB04C7B9A
6F70A0613D436A6D5284483245679145685C292C426033472F1B3C67572B463C58573130
40524C4F6C59213353655E5D54515B3E5645273732393A393F57595E60563C59646F5157
6A58541B2C382C4F3F44633C4449634458343E352038243A4A30213B1C2E28373A375255
535D453F4E32372C21273A344B362F44363D46461D291D3E383335402B39153A3A222E25
36242C34374130463A565932483E513C643728481E4E33564549568D733F765296762F5A
5E5C6F4987524E5D44593D48516A6189316F4BA45F453B4356671D5E6F1F5387495F3D74
2C62623572723E4A433F6018464D3C4B514A4F804F6965375B5F4967574E695359593D39
524B66565A4A76476A5F4D4149334E3133435F5A6A594941564337595F4E5E44736A484F
31545D3E842A433B4A46404446543F5249404A38526B45738141735D472A4948654B595C
60875557542E7D5455693F69562D614C5F35776D4B586549454A565C
9A5E72534E5F53535D3A636A503B5A2B62A96A523944467280212C3D4BB5931825346446
AE520E3B4853457E73184D8468448C3E1857A5565F4F2A2E6B735979183253683259672A
477F792D314E304B9844173F3C22429338243D36377798271D4A6760AEC4262D3D624F8C
7C374E5251689231293E5061617D192A3D854F3A912B2B517E3A5E5927404F5B234E3D21
6382332E52513E807D2137496167AA473143605C83BA462B43734A79813945647969775B
2731588E658947363E68885D7E2F2B4DA0776D5A254460742B513E3048854D354F294082
481F3A3453898D2A2E492E6DA32B3D734E898B3429705E53C95E3B59A35C948D28597951
606D323263914F7065315B7D5F6692563F418C7649863C313A76894A6B1E355493936182
3536769440584D534C8E6323353C5E4CA5962539466051966A143D67644F96575E6F4632
525E4C3B6C6847404B656761544C62665E4B30493237383D303D4C68815945597E5E575D
62715230342D3D4F434F5C2F4B505C4B663C4B2F1D4D383E75212047444F46493A4A6D66
2E31613D5620486437434C22544B493C41353E2F2F34291D4A4134313D431C1B372E331D
20303346244535552A41544C5039582C382C2E412A3C2031396A464E525E81376186428A
7669654F5A4C2337415D525E4949419445C16D57435434316B73423C4114346A39763847
2E62651F3033366D4C395B1556634D4E5A5D49604778811D414937513F6B8B4A423E4D50
57463F4E614C58539A6B5A5A5A48536A3E485F75684F5D494C4A5B5D41515D4575756A69
2C513D4A8333554E4945484D33503E634E4342384A433E9C7F63762A3D3F524471534D79
304D5851432A3A3742512D31474A773D3F64B4884E7E8A4A45606467
736B917643626C92B83D4E67747AAE3330376679897A294C464D7B7F242A6752527C472A
637E2F2E52201F3B783929612D4A6585393E5937948525223E3052C760144B8445698D28
154C9868778324313A595292362F4A4C4C3F904C1645895E4D50341F408C77576D252249
993B3A482C417F6A2A42474D7F873C204A536384C431384C554899A41B2E5E6C4A9D8A18
46976E7EA8333C5C8D56734726506B8D506B5A27538688495C3C2B417F4C316D43337C91
252E452D2F8B6C2A3A48544BA14A26405B3D767B2B38527457B265223D785D7C9D242D65
8F527335205EA45038512A2D6E6940641F3C8B664F5E272F5E632B47353D56A045414351
7483482D404775B2842F444A3B7BC772353D514D6AA56A353339728EBF351F55818D68AF
2E4D6A88427C5E3B527F954D677F1C2866A36C3D6D1B318C813B444A1930526C474B292D
3D4A49365C63244346444C75534C733B443E18392B37453C443E575B49423A4C574C494B
484A5037323A2E473C403F2C3C423E334D4D54323450384D622B3E44464B46535A466B6A
5B6171526328526028244E1E5A534537463F3B3923422A264033313C324A2439442D462C
443941393A43322F314146224A597D2A5D473B552133353A352E436759618C3C685B1D3C
48538037403939434A532F3D3F6547672A84455D60863838536C2F5257215D7D3D602E70
2B4C4A1C694A2032316E7C2F57514A49605C517B32575C336B67476B40597353605D3A2D
396662675D5D84475B4479746153784643577D5A71424D444D2C2A6144726C4F9575666E
39685246712B393F3E2C2658264D3C5A4D3D2F649F6F5F5131318323434C884E715A6F8F
4E55496F5C1D5F536775473D442E583939234F5649464845454C5259
A14F5690729A3D507C6B435C344866442C4C253D488340443E2A90AB3C223A2941915323
457642689F33163A3E635FC72E1C658F64817725316D6B8A592739486F5E8170332C4C65
359B4C2B4D7D4C4D8F2B295C871F235223256B8D1D2C433F5C5F3216323F3294C452214B
5C579A842023646D5C93722E3E725D4EA76C19334F7B46733625467354396B3E24567932
3F3E1E399D6F29493651766B3C23604A418D7F26244B5F639850233D5B7772BC36303B96
6E6C94292F68A553A893454B659069A58235438B7D57AB4B2841974B525D2A3768453A55
3E536B522B3C414E85883F36442F5A992D223E6464A537385D6779A34B2A5161739B6A1B
48828D6B9C362D4F995D6E63363D56AD5D5B4F223B54584872611F4186913842523C5486
5733455F4E72852724473F316D9F331B304E5E5F9727193A88525F89173449496D633C33
49544C3E565130454D5158678071764E60421D3523323F3F4853485E5C504C5D655C5E64
62565932333A384F363F604851485C35583F39292B3B30394B212D4145423F3B3B386566
322944404E556F80282B502E57453A41463343451A2F20393D30313E31471C3C38202435
332E334C2F5440532D585F3E473D5B2F7F26214F264E3140483A5A655A345340797A3168
7C5A662D59473D59243037424237479931D7617B4B4234485A5C3A6158214D543B5E3D62
2A555F2E3341284B4D38541B51455B532B3A455F3B64743240434954666F8D59344B5E5A
4431346B73335062A0462D3B4D424C3E4D5A56453D53583A4548375843494B2C394A584D
12403526943C402E334243524D62435D44333E373D432A664F346530603F435AA865677B
5860798D7E4D7243324D5D53684C5D4D56336764646F58544E4E7268
B0504E5064A84A3346666A96302355605DAB37213B69436856312F55834D6C1B2A3C886D
7E413D444E654B5B53164D6D613986463967924D47412068A24F335829298A8C3336543B
3AB788192B5F4E59B431272E4F6B44A11D2536564954631E29566A478769183B616B379B
2A2C4E764947732C224F7629374C3E4A83932C455A455BA16C1E485B5053B05921585C57
8E50232D59775D963E26395A496686452C4CAA5F64801D37475934536322497079334E48
45438354245B51305BA0442F4E322A6E9D3137513F54A27728485962898E2C2D3D496EA9
393465663877451F2F7064887526275E5649582246586841653D2F71783464573954692B
4065334B6F64325A534F9F9534435A5751B3912F2C61715AA2A6303248553F8B8B37505C
6C779D40465168605D9C3F30396A874E876324474F58495A361E63682D27562C564E3842
7B585548677028454E7D6E7960455B50625538433852452D2E3E6369634A2F5C6D5A4650
768B60373A36343F384957454B47583C554646332C44343A603C3D4D494C484B414F8580
403C724457243347212B3B204C4F473C4A38462E2230201D433331433B4E1934532C4225
2F2F3C2F2A47394D1E3D403E3C42642461372056344D22413047467F7F556459566C4E83
627270467F582B482E3D3C552344445F2B69416E4B8D3025605C2A40492963634D993A63
3A4C5D394C3C34755A4E6A28503B353641465A9A38495521475542513D7CA55859593136
2E5B3D40463F562D60305B6641384F3A3352725049445942483831534774723C5C636E6C
3154464F7260524C66645B503945366B4A47422F4B4F257556394D2743485C3A503B4A7A
6160515B4740775246502A2E4943523B465176584751544144535059
8569994A5956596B7428546554505E20434849276A4235526B303E4933847E36254D2D39
9F971C395546419C9A193370594AAC54293A775C78731F244F6F569B42283A8770646E30
2855987F5F8E1F35575B204E41293A5F354770333060912A1F3A3B4987811F2250404E98
461F34656B5FBD381F41805377791527699261B4A721376F954E6B4927425E843F803D29
6B7C442E5B2939877F425D372F48815D37634F3765B77C28534A3B72A234356E514C727E
213D50755496503D4A4A577276263741525167641C4C6056428D6A222E68525B631E2A5F
72394C383F4E6631324F1D63943B2D3C40567B332C53376FBF45234754479B8B3160734C
908B382F5B8688A67F414B645981AA473C4A92747987342E4C905E416830294777634C71
294978813C434C2548645C1F3D70283B60792837433A757C8421295A3C658D32524D2B2E
404245304C3C1B463C494E63644A523F463A213F2C3F3F5139443745443F34454939444C
4B505231333D2C3A35312D2932333A273E3C3F291C2C3F5B4B293148604F335468454E56
5254654A613C6168292B492A60474241413C4747333D35474D3D384C374A2C444C2F352A
3C4442473A5151533F575434454F7A1F736A3F73384D31382F54394E4B418A45686C3A7A
6E50664D57453E4545533246434D588C2AB85B896758262C574E2D4C381F6B624A54325D
34637B2F4741404541606E2A65273740555F3F5A39504D267273527C5256804731593A40
3F3530434751622F6427567455364E3B48624F4C6F4C4E4D5A382B4F4D3D4E386464575E
23503C32824D754F433B404A264A315A452D2A385A5246613C2F58354E43483E845E6275
63784F673718574D47612D4A5434603643377F7A505154484F4B525F
8A54996E4D4F7090A737454E4077711D2F4E5047A08B14448D4788711C4B574658944C19
56A24A5A6338215586496B73193141673B6C3C2E59934F564D27324D4C29765B3F7D641C
233E435D658B23314052577C622C39654B4CA648302E5A5C56701E292B7F634A6021355C
713C715525315062304F3F29426743366E362A81AD382A4A3B3D9C97272D383D3DA3911F
34505C5A9E3B2C547D6B92512836799D5FBE6935386EB4598A3B35696D544E8131245898
734C711E3A60564357582562B26A3B76543780A6523B72443B969E3047413C71AB302531
416B763E1F375A567E7D2D19524970821A276554416C2540634E3F6A3542647436693B29
4F805552572C3C819B4B4C553C5B958E386D474C55A06C2D3855496DB34F2040575371B6
3F265B745E90902E24646A4A71A71C235763437358162341735352762A237B7F585A3C41
5451634A7461204D4F6F6E757A58754755521E342734383734466764645F3B6A6F62534E
61575A1F2E3D26444143582A503D5C2B445846421C3D3D2D58303547404C373C2E425953
3C414D32443F33311A1F4B1934393526332C2B2A1F2529283F33383C2B40332D362F3B39
342F4555374F586C423C354B51505F3B563F476B424F433D2D394A5E47327962727B3790
6E567A46755436594C573F432F41407B33C1535A47732729665B3746441E7D53284F3871
3B334F205F412D6C5536401E43143E43222C3E6032575C2E2D3737455075AE4A4959464E
3032303D4424432A6B2D283D4541583A3F55574B414260353B3B3042414755456678505F
192E37368F4474393F51404C25623160332F443F7E743A535A3A7D466B4356466A334961
4A5252A55B1B6249506532685633523F5B2A626866585B4B464B4D4C
B94A84A5767448588753797D3F467B3A476D2E32769D4D602D2C406D453351303E7E552C
3840306273251635413689B02C2D595265B5821F346A5F7B852A353684499B722C317F57
5DAC752D537D5C687C382F595833537C1C2056733144653734695F1B443C4D56642B2F66
2B4AA77825354A5247A75F243861657FB42F385D767D57A131325F66415A852535446753
6F49234E6A553854393161694342693B3E608D3A405A344261732335544C6B8259203447
7279A62B277553489C9B162C807756C0812234754E62AF4F1D3C935DC1762B43648A5481
2D248B974164362350A87E48472B4988403D633B4E8E3F354E3F57955F1D545F5AA44E26
388D7F81AF471F43A16C888C303B73A854B281264A838A5E797B253D8E9C56A55F3449A0
7B4D5E41465962343257202549645031824A32868F262F474542829B331C334E5C775037
51484A45615F4F766E939F50413F555A4C473E42314D4044335451587D56455A64556765
5C635D3C32425458455056354C495130525E42531E45423974473D595260274C4D695C5D
3B437A456035427231376A10485147454F2A4746322E31315B393E563E561B3053283727
33323E33374D34352F3C4820233F603D333D3650414E1F302F454E705B50905D5F8051A2
68526D6FAE764255515D47522A484D753BB3756A65AA2F2140461F4E5625775256813456
2F5576273C3132515247462B573542403F4E3B682B1C2E143E4B367451568846354E3A3D
3858465A5B4358147426375456385642355260415E384D5057312439334C5F294E4F4C66
0C333221722D783A443840571547216A473E6058584A38624D1968215B495D45674E7F6B
51553D563B266737495521305744502B49338048486A634947535E4F
A9616A57689155535B48746B3B49543A5F7B2C20526C54A19A25404A438CAC1737445B74
90761D3D5D48368F52153F70694B5F2F2C577A4F685C1B41705A36631C284E612D3E5732
536D5C3775543B9DB42D24353F3989B03319495756927C3734445E78A6481B3E745565C2
3D1D59924351722B3679B64F5B3A2F4791772561632961866522476244769B4A30524B32
849C28428380857F3B2B47594A95B83C4758807B98C0572C8564466C882D526D673D575F
153C6169366A39214A9F4D5A4C28285E8848424E2C33797D314A39316D7F2B3449456076
3A2048585B96611B236E8B9E72193A515987B031497954808518406E5F4F9877246DAF54
715B396579B7655F5E4B6D8E5A5859474E59873C3C53483D86A8492B3D3B438D8827334C
85A2855825577C4C5AA03E333E656261B46D48426A546D8D3C1E457055566B205957272F
504B503F7A8E24383E4549476E51543D40432C3D354345693F4D425468413641493C4746
4253482F342A2E344145302B39504D1C3A4C414C364A3932523E3949554A3245513E8A8B
3E485E505E50615A35334F34464A483F45413B462446393551483B464056302E553C4936
403E4E4640524E5C3A382D353F3E610D556137622D432833303C38534156AF4C585E1F2B
4C8C6E1F343D3A5173753041445F51781F994A5F564C3736505F225D4E2B865B33473464
273E63244E43325550545C2D4D103448435B4D653E4F47173D3F2E49606A9E52406E4B47
332E464E42334B216D304569622F4E3745605A444D4451354C472C47453C4D356A705661
1739303366365E43465234493D54474E38233D356E6947735E286B30835158498E6B5762
523F497F46385F69606E4C53554B6742504C7D564C4C42424B5E4D50
867FCC4D4B7C7BAA5A49478E52A7703931604D49814231548C56846D1D5A7261437A273E
4A50302952323B5D763C3E57516D7028274F5D5291882426527961B8262B486B596B8F14
274F6A46BA921A29514861642D2E3658533A54241E2C5C673A814224797A3148651B4591
6A2D3B522B5499261E30503C9181194543495AB682193C694D4277701B4796684D603724
5A7A3E7A7915357F5F38563C1F4092722B562E24668284466C402958BC643856565188A3
2B3F494A7F8347243A453881A9332434565C95932B46456867764D1D48684A65871D486D
67516D3B39418451474A2058773D37581A35A4793D5D217DBE58315942339B7E21324E53
8089263C61819CAFA02538785D6DAE3940606551608C372A5489616A9C2F2C50854E7758
2537626A445A7B2E3B9288466D4F1923817C384A453143826426364E575B853E53534B5E
7B62584B4649274C4766727BAF957F4B5C574042465C41433D5E6F605C5D50614C615552
5A5059292641505C484251363F293828324642412339374E51363939483C2D404D31484E
435741404937394A272866295756474C4B4046422E2F38374F413449424F353849283F38
323543473F574D522F5A2D3C36585C2555656C7B354C353D3137554E472C475374723D5C
3D5A7A3E7B5632452B3A4747304354783AC673765E55373F655930684E206B4A2457305E
35396E315C41234849343E2D6A3F3A503C4B35653E263D25424D4B537575AC674C666D50
513A376078465D26703B36525A5C7A5C485262685748644C4F41453D4443524060725063
394544488A414D3C4D6C565E295C204E444A654A6C742D5653108951553A7F63704FB175
868770A86138855F7F6A36404A3C50487236634968734B584C516754
7856686C6C5434509A466D65335380313A3C35577B4E27413852B37123305E3973CF5314
41524173A238205B514A7CA92D3A7E714C6B3C273482684C591441746932874B33518949
4D63344367A538474748489E8117335A495894481A242B4B6497362A3B4D5078A3263C34
634C65602F465B5442683D162862335974373373925A597A382E9FA327405C386A7C3924
464F3D7F99401E5A655E60361A3465A072A6391F2B6A6045A9222C3253726788282E6A80
518F991E23856B386C4A393B7F753C601C1A3B9B50355219337AA84854412D72952C314D
344F995A243B49727876253C64375F892023798E628026436062709C3B3B76925C8D412B
4FB7834358223E6BAF6C6A53285F7F723748503D58A35B39483946498162295A4E5B8399
2E2F545E567B902B1F434C5786961F1F4462497C672047527445695F17417B70647E4A35
493F6C435A6A297864565D51554E6F6549442137313D35423B41545A5B4B2C4A4B444655
565A4749334427403F4D40323A3949464F563E4F3848352148443D344B53415047485E5C
2D355C455C33386C242B40233C463D2E34363030272F1F313A432A3F394D272D3A413D29
37464A592F4957581E46214C2A43503C3F32294133491E443A3950785B4E783A3A613876
4B69634399595579596D446728475A77207E58914F69427F724D2B564224785E3A7C333B
38467937523735715A4743428D3F4B51315A446F4D416416444B41594C4E8C587C7F423E
445B56494D3C5038AF773853552A483C36485A63553553464C35383C3448632A6155436A
145943395B1F5545492D4058263E1D502B192A2053522D90703D5A28605563627F5B4C4E
574E6C925741575944564A3F4C54643E44457F5C4A563B4242655155
BF537E5E9FAC463F50749F8733355E5582722032466488AA333953743E6753213C667442
445C283F706B32683C2958964E27572B71953A22304D308A9C2924512E48A87515406A6E
66BA50364B5A5694801F385A964B6F872D1E55A03666411B2A77A128841F2940855D5864
2544668B4439563B2F8D8C23373F3D7A993333395F6997AE383F568C5D719C3C24719A72
957E1F3BA2525E752F2E5988379E651E396C88334755273B6A7928364E3E47837A2E4C4A
2A8EA13C254A43559D561E28394C5A9F3A1B245F5F788824263E81569C4E305C70526B85
2525636840794621599E783D502C30785961432551744A3D5A204284701F6B4364865E27
305B73989E492868657FA1992B2E6E8378848534426F9472B5A724345F7D4D965B1A58A7
6F6E9D3F3F558B6E406B262F46703A295E253459773C3C593D2A5DA642223935504A3952
6C574D4453714A41467E79576E525D4543432342343F3F7340455C67885A38535A524544
506D59353A4C384C515C4D2E43504F2F3150743D153B424E59272B4F60442947613B7569
4D4E5035403A38634B4B5621414A503D332D27282D3E262848541B4443541A21442B3431
2B413B393D573F3739632B2C31795E203F3E3544362D1B3937463A4241439A4152512E4A
3A5C5F333B3D324F6F6E6D6A364964882DB15D6360843B426C693B6251267A5718452649
243063346939283535665C334C3332374C7150803595A335576054796E679256434D5C40
4C474250494D6A1F68535A796C394C46525C62526B56585354403A495B4251346D64374D
183D31477912403F4C3C3652304F3D59352F48347C904351472A76426A717065A0797975
648055706750656B4A5F54495E48584C4D3E5354565D4949547C5D60
7B9CBA51639F8B7249426D89435E5E2754A9544E641C337F832F6B4D50927426294B5069
776D18235D6F858C33223470748F94303270804D7E792C2E7B6647741D1E3C64466A5A1A
39425F29735C27619E35203E372A4591321731473B6D551D273C796FAE381B2B4A43829F
172A3B8C918AAF1B354D816C8869155284725282592850665232603830546F48354C2345
718F54614939548554223B404B94952C334B775288912A434B724F7F831E4F5D6C58B168
17487E68548C2C2942886B6D6A1E3A5F9C3E493E3D6E8B6F37593C3866823D3A5F393E7C
6237593E5081672C346152707824223F406B6B1D406945638D1D316A6A41973537758E53
787D1F57A1B953AA3248829176709834328BA75C55802F5A5E7059425C2E408CA1464F50
364E6755283E4F645F713B2246586169B941283B694B57AD4240487B65619C305A62423A
4A54534B64623455564646727657784C48401D37273B25323248564F4C5135604B54444D
696474452B4C304D4449593755505C49424D313F2133472D4335302F213B423D36313D44
414E493F547D7761181D5B2D4C4A4B4C4B314642332D3B644C403561414E313E582F413F
3A3141473F3942451C493A581F4435183B445A5F1B3A163B2A2E3C5231223E39675B447C
2D3F5C387748535A325039491B3B608138E46E81547033504F4A38595355906D2B583770
253A6C303F4F2B4E3A2E462F584348533542546A37484F3847473E3D6E6AB48A55645356
443A374E4F314E3CB65C2644604069533A3E5968563C604C4C2F433340404E3A5D5E3D6D
0B3D3233592E3D364A53435A2B79194E3A244A1D4346436E72455B818449752E6C437B8C
6F9A4E766D305C5D4B6347484A524641465674565299654C687B5980
797AB0554C5FA1CB633743776499833828696BA0B22745489860CE801B546D4B6D87451D
778948507724348B8B2F58711F3E7E4D355A352D528B3C38383C707E401D453F4D7E9C24
29394E3B99A31B1E57445EBB591831675F69992E19436142658516376B763C764F1A4D85
5E30633B2D4B7D40285A30265D821728423C4D9A7A1C235257698D43274A6A63696A1F39
51555C7684213165735D80432A6397804496372D47644A517C1E394A5837427725335D92
484853255CBE60273D2A3153AB472B5C3847A3A12B3656505A9D372B386457839035354F
535B9D3140495850756924435F3A424022476846476E3B497348274731408D7620393A53
73AE512D433E52AE5F1F6367326DD38123415E3E7FCD4A3065684A6CB3451E40694E9FB4
36354E6A5F95861F527E632B636E27458EAA3E5349353F6D7B293D3E2D49524F4C524241
63454B365569255C5651685375515C5946413D5D3D54415A38505B596553475E514F515D
739A632E363F45533F4B5B434F606A4F4D5B35592A3A6634523B3A494C57455444555D61
36305749512A2A3B2C344D30473C36243E2A3334382C282B505B33413D4722204549403C
463A49634252575F254B2F3D1C63543349553449213C2B4D1D343D6E433380353E49443C
39557045B3503251546139563D6561854B8D515D46603060585543655F337F854B4E4145
2C375D284748315A4C3651345F2D304843596C7D5C756E3B667368635D5D7E6166723E37
335246434F3D5228695B475F5B2B4D332E383A4B5C355344542E36393A486D2E55493B4B
2C3D39575F124D373A2E264A15391D5547507247525D496A69355831483D61468045756D
658E7CA18A4A81655065315A32494545655395526081504D44607058
7A5986778B6E4463C96E84613640783B38403A415A3F2444293359722E3D353B98A7381D
354747498840174152527D9B2A27788455AD4C1C34885B76651A414C554586372F557363
5071303F468759514C1E2A558B2330572335756A2C374142636E31213D435D89741A2B37
565CC27D225B634251CD54174F79468E972C3445904460731F3B75832B456025578B4524
553535577C302156384160401C3B4A4945AB4F1D24493985C62B28706E456088323F536A
47827A233B4F5C4275262B4A4B474A80422D5B7B4867592C34797340642A2D6971514F81
3033867C3948344060AE65375137878E1F3B53546099213F83555B7C2E1D5B6D618C2725
4DA26C906C234C5C9C62A35D2C3D65C253815C354762644256381B33457C4E684428527A
6D28692829626338214D3B38746F1E1B41686B81771F3145697073891734717D4B522F3E
5D3A472F535E134947817D576A4E5F56312A1736283429443440545E784E323F4B4C4046
49695D313137233A435C3920355651263B47504C37404B30404A444650514C4E4D48695F
433F5C4D614A6750302944323F383C4A40393D2A32403A455258445E45472F4E5F4C5046
574D4D4A445343593F5D574D428755324A4544443340213B284C2F3E2425582F524B3A58
4D59843F4C442D4E586B343F243C559849A844706483415C5C462D5242348D8147634D52
4B506A324F482F384155653A3F273B48415749736773654338455E696F64925F31525C43
4C424955644C713882604D787D254F35414C4554533E433C482D2E393B354C268A5C374F
0A5E334F60193A344240384B36632C5B3C404D6668644487A957924D5F51758BAF557A7E
688D6C5A5C477C3D50582941304330273E349A5C5F6D6258645E575B
A1545C5B78853C54696B917B2C474974626C27373E6074B321306D755FBB6B174CA3815E
9F9D1D325C5B4F561A2B58674564792B397D8C4362422C49584035531449646324424656
607F4F22434953978419203A73876B8B1D293C605B6B2E1B4E73679EA82F2B5C753B697B
193760824767802A4F88804A602E2D62955D3F5B47497F7B342551484A6A7B273761574C
96651B4B8F674C7F1C38534C2F87942C25487049555E2B2853632E5E491B30584F3D862E
325C682E38703457A9732940723A38874B2C6C4D4B8A802A2D70674FB372143D7A605D8E
311E5A6F486E23225B8989545121486F314F392A4991793E642A4E4F482361462887712E
414E2F6AB2653B634B398893343A4763728D8627304F385FC39827335D3F4CB0931D368A
8846BA42274D754F44622F304F7B544A733448629A553A76213E63803A4D46155E6A4D4E
686342456781483E45525149614E6959462E2C4728352B4325424B625752376171704E59
7954642432432D51474659304E58683444622E4723305D685E312446594C425157464C50
465869365D5443621A195D25323E2F3A3F21443C37353D4957462F563D4A213447314256
472C51563E5B615D3E5B477C4955424350445E59384A323E1F3D49663D445B4B78517287
525B806DA95D5073465C35591E3E5C8143AD636D41503A644F523F814C3091853C46355E
3A2D56356F5E365256426E4A6337454D3C4C4C6F3F575A1D41443B545C4CA766536E4850
3C3C3D5879375B529B5F4A4B563547333E4E495E594C45425332333239354C3251423757
1A3335546A163D2D563C374B41723857382D462C7270325C78485F58916E75395F4A5A8E
7EA56E88AB595E565F683A3F434E5B4A481E553C6954496753507868
B898874A639977A9403F48695D9E6A2842644D5353282E6066335E34267789262B453730
5B792C2149347A995614446C4F96B32C3557924BA6631754604A649F1F1C85AB5C7C7A25
4068694E9547384B8457437F232C5D5A3E465D253A8885384433144B8C57353D4B3E82A1
1F1747563B9EBD1B2554513F9A41172E5D6A6C71442862644D379B532361724B33682E37
5A914D423527436D662C5A322D4F763A3C573B45AA7C27354F2D4BB261192E4C4767D24B
1744843A6CAC372155843F7684464D5B7443A0563266834C5C6846505273334A502E4573
4A25562F35705519333B345284293552557150192D597A66AB23326A504785452B3B6252
70683D325A81569C385471683A578D1A4289723D666A4B2764AA6C4E65303A5192514F74
2E3B5B6A24634B1C56833F16445F3E489F3F2451634964B0391F505F346CB02C4E754D54
A05D713E5E8D278172786E639A5866533F5F2B52485A42553A603D6772585C527A4D7178
605543322B2F566443464C3A4652592957693F5C2F325E2F4225204D4B542853525E7655
36415A3F624D53763D327537424C385152234D41493A3D3B61455A6B5057294F6D3F5A5D
653368673F565C6939524E71526E5125505C363D4E4F2A482F3B405B45546A2557463E59
5B589F4C6950315459593F55254B668D6CC7386C595C30517F6937696121615D56714043
414E6744394E447A6C435E33712E314C5754557E3E5559314D524E77724970483E5F543A
394B344A5B4B6038A7603E6155216B4E464F5E8E5B4E68564C3C523E485F5953666F5260
364945556B203E3E58534F4C3B7D2B6852637747534158AD8C3C83485E4A587D92439380
70915A5D976DAF69455A466D5F4B435366536133505F3A4441515659
628BBC5068454366853B6538346485264B44607AA3323951525ACF641A446F659DCE3B23
365A856AA9351F4965356C2C1E45685250811F3F62752F3D3D415871431C433B4A77841E
27384648A6751D394A3B5FD16119375C48737E2A183669469C78133849425BA177144A73
604089471C30624822452B454F592D41312D677F6F233D4F4A67A06E1F3C5B57618A2F2A
4854659B462740617458B338304F88595E9F3B3E5C9844607434345FA944506126435E78
3A52562A437C4E5C5027244F9154465A36698B8C3B3C4B2960B337295B563E81B2262A69
585CAE3A36426A47925B254B6359775E22567E4D63721F3D797D476F383B647A3C572A32
629A48595131505A4F2F5D5F3B86C45C2F5151379C912B1F335150879A2D34665E5460A0
2E2D738145927B22248384465536424355553C6A6D30435A5136434D2D456D4348543C4C
8B49432D4E733A464D788B537D55576A3635284A2E34334A2E3E385D7C4F3E495F474049
5A70542C32403542434939253A5340294846504A444A5C4B4E4F484F4D58455150489B5B
35456470814F454831324934436B6D4C534A513849473D406234406547603547613E724E
633D67653A5E5E6F33625D9268676538666E3B523B511D422A5C4958324F7F2764414672
5453A7618C823D5A5C78485130416685359F4A6B6E745F5D4E493357492F9B903D482858
2B44792472601D434C42733B672C48541F2C4067312A402430382D305038824C3E574447
333441455D517F3A715B4E74682E4853616B4B6B63655C635C524E4B52465641685A4470
24762E39532A585253466574515443864937393956533D4F623D592C583C776091574763
536C438F83465D4E54563E463B52503E3D307862567E58575F6B6461
8850726794514372615ACF6B2D717D5E9856334E6D6C48842E325C8252774E2361897F2C
72453542613625472C65996E2A3F643578D6422B606142918812397B665F815336525F68
999C2F33478454884E1B3A7E87575C3F1A31534C24442C295C8C4125551B2174A8293549
444A9061192F4357739F2A26574E368176222E8399377478293D5F703862531956605E35
793F2052992F3154212D4C541D484646438C38243447566F7F232C475065668C3627585A
56878E153662525F9A31133D836854733226538A4A7378302172843E933A39446F6C667D
2A428C81306845386BA96C5B4E2962A64F3E4C3986A53E2A5F5764AD41365E4C80B65F1E
426C46A19B354B5D6164B285323E5C754F905B234D7F5E556F5C133F8F663663492A569C
823E5327425C68343A3F38446E7723375D494483AB3A3A69564C818D2925544165826D49
5A64856C5C7B5A706D53554D907A6449466346493F613B4D3283495D6655605569586B7C
6052482E222A3F45353539383B413F3A5B442F3B49464A3C412F2D4648472C415246664D
48585C304D5042772A2575433E4B3C403D3139313C24282F4838324840413033443B4F43
4758495450715C5A4E876B77678E6B3A5B6C4258445F244C29533B623B5A842A85536575
3C5CBD858B7935565673394E425762B144C53759465F4A5E6662505A541B56653B7C3052
3148651F3F472E5E5D4B593B824A2F413E373E9247514B3A475A395257478576444F3F39
2F373B68792D532A974D2D5A592649532B3941573E4258485C3C3F5559464637666B4346
213751565F34484E7B564A41406B2C463C354C38706F5577B95C7E4C6A547A47613A6C64
4F744557A05E8E543B49414A5246434C5341573B73754E69525D937A
6E717C4D786A6091443E8FA44C48412E7B843834485180A22A223B5650C97F171C3C644E
CD8D216460425A94371A60593B65671B378D7D4B7E321A3B8B574F6D153154692A5E3A24
4DAC58386E3A1F65771F2C554046637114375951579649274D625A6ABA251F44815C7973
13294F6C3B6D7C272F5F4D3254352254722C3049583784871D2A543351607C2C29646C4D
85451F2C6F4C60901B334375577D7A2B5A57886187552B5A594E4D772C2F75B58D386923
3B69AF5162562F42738C2D4D512B556851334F413C69843826383F62845F22454D4473BF
4A1A62764E6D3820558566766B14376E575F472A316CAE72A32738625E4E6A2D31496440
5745274C7C5944741D38757B3B4B57356398AA4553664656788A37255769698469243C69
7F8DB6302C4F4D4981B7393A4A694B80911E2A42743E6E8A292D4072362F361F456E5E48
5D40532D3C791C41524F5C5D504151433B453F5256433C49454B38605C594161656B4859
63586D4C2A494251444666345044591C39613D57292346373A40383E47434D43454BC176
2C3165637447455E464E673C4056504A463D4B384138332C4B343A514C56253C45364440
3B444253343953582E4A5781636141505F586955414E235C2657489B4D5D7F2699585D93
41546E87BB614D755D80304729483A5B65AE66804772395B65544C776F42838145474256
3B355D2A526948384C4F654556483A476464435E365A4F242F453D51492E715E4F714042
3045362C38234B3195583A695A22594F345938546F474D4362363840296156454A535574
354F3F5857295F3544333A5141492C5E557366614141256F91675D53A87E99426A2E6D5E
7FA84A75854184584D4F2E40504F1D2C333C67396675645D57605C73
8EA9BB465C6B86D85F3B5C7C76AD47292753556770283C77605E8A28374A67355B432439
5A9A3557592026796D283A2F4E94793331423757AF5A192A4F576EA8211E344969B17610
205C6E52C7581A2F654A5AA1282E519C54695A183962833E364422375D5C2A3C2D294C7F
2527393747797618364F4D4B993E244D4D506C98342C41713F70A257253D5D5569A93430
445B639C451D3769612B481E2C637C36355623435868233D4E3F588674202C6B737F9B35
1C473F3F87AC2A2F464D41A38724334C6B6DAD7D1F505D7157901F3C7065554B5921576C
664693434B92944E673223699554545629557A2539415072C945324E40598D43254F564D
88822148735D63B2363162B954999E243E5D72467B7C1E4C90A06F6CBB4D4D63936D6695
495FB58E427A3D3E3A655F2A572C244E915B1D3F54324372592A465A4D6F62254875383B
633F7D3A4B83215E4F4C4D4974556F68313B1D4F325248693E5545728C6447586C654D54
5A7F604B45514756576366494C4D542E465B555A474A733748564F59415A51504B505957
433C543146292E4F2F304D343F56553E39423D2A3C3734315521242D3845222E412F4030
384E3F4359703F3848644C424C93564D4C68574341491E40404A324C3D837B314D3D584C
3591AA5C4E503A3E6F7D4953305D589953A27A485E79417A6D501D475E2A70896F5B4A57
5961803A4C764E5C6E657C536B493C544338446C26625434394A48536C4C85684D655A46
35393F4851335847646E506C69173436334E39634B544C3F4835365B333A423A76582949
1A683744561F51344757605D46663994553D37357F884C8D935259345452465E8A447345
53735D82814E574A4D58464E4F4B463F3E57843E508F4A5A3E436553
62679F65725146728E5385452B5D8E3C613C30526E25434845558E421E60614A8A5F191B
6C864FAC8F1E2A62744C9B2E2E556F33717139304D935A703B1E4048494370333095B149
52512D2B8283316B5625489F5826334C2A598E38173339438A921233375A56A25D18565E
4968A33D144C4C3F4876253A5B5E2B626920355C5C307A791F266F60293C23323F6A4D36
4C394175601B364E6A5B7E2D1B2C57667E911A355B914A55621B38537C456D8B24257668
2C695421287062455E2020378E6A405E232C36613651552D7FAB512D5A5C3C9CA8253844
3D479A601E4E6253B45B1548724F7470294B5A45606916385E7765A12D3DA57653672B2F
689A50574E2A4A77612A513946648D472A6F52416B845B2957554C3E844A2549433069A3
54304446419A682544474244764B14417C89434F3D3F5F7168608D7E255E8750415A4853
794B7659609B3E57517295666441504D454133592E4A46521E4C1D534B573B73828C4C5A
7A766B2632463C5148445E3D564E6B4243703F4A3831695B55504D5D5169575A685B817B
595C6C476D3D3A913B2E85555857495252434A4B4F33425A553D45515751343C61425932
46474E42424B434C353B684E595D514E6152323C20402C511D434CA137586B35774A4F59
353B5F6D664D4F76515950512F30356144B05E7951564264915D306B6312A6A149645070
4E6B78357569265C4F3C552F634B59654C4E51734C7872343B483F6E8C5292734C664F43
3D484F4856415E2E82603B629239403D405456755E4C4F484E333648304748384D6B4B62
354F5679764F5A5D646A5F553F653A3A235D763C746B4F6CC1536734718E62659E80B060
70934E7C9142684F746241513B7F3D51332F66414957496152556962
6956868098783C446761C24A374B945C7D4A234C6C4869901C396C4F5490871B50BA5E36
695A284F90543B4D1D26626D2242503057863A2E5A3855B6651D2C4D3C739D332251733F
7D9D2C29585E41A0931C37697A5578463F4F5D98438F562728774E52591F273E7B373E38
272F8A8B2C4042324F9A6B214F443C72B34A254E43588FCE423341595D8D37192E545A6B
851E28598941487623385E732B4A342953834B215842435182374B6F4539466950264239
429F6E1F2E43325EAA4F233D4F5B80C94137515A44877E2126535E4A9752253F6A3D6C55
1F4552644E6A2B2B6785355F2D275B923B45473C9BBC5E5469415CA33B236B55548D4224
607168A18A2E326CA181C46333576F5D6AB74B3B7767805FC5713F524B815FA14E484550
69A8853B284B8C444F423A3963773345542841897518294E392E73973C2C492F57683B3D
9B555737426D347A5A7E6C51724B566D3B4A34683A604F6F35511A5F78684E66B1666063
6F9F64494D4C4E625C78624A615A662E5F705765382A5F414939385B51533B484E637EA3
50435E465A6B69892F2C63353D6A4D575C3C563E512F4441583B3F474A51342C4F3F4A49
544450664D62606C49676F53557C7A4C4760475530421B41174526443B58763F6D59616D
446786838670315D565B314627433D874994827361545A4A636443746A245458467E3C64
3268731F3C3C2A615B4A734E674F2F3F2752518916534E2D3C4A3C477258BC9A5A624F77
533D4579904A4A57CF914A446E39706F44534B85655A744F585157553E73764D5F625E92
63755E797D325C727E424D683B53237A31353F2F665ECFD2DEAE79A66FA890617140474E
7977478C6A528C3838403A4942413554474B7D314CA0514E54617562
AE7BA953577D58823E54899E435F39406185304247357390312A5F3730935B252E503C5C
BC532438574A75BB453237495A9286234C5061679D433349915C65602C41897448793F1A
42986C2857311F4D90532838242B446625262B373A8270263D3F2B739422364449358E7F
1B40455A4D914A243956695F903519473247447F362643535B4E75442B6C6D36555D1943
8F552D54493B79A03321513E60964A1F2E5340559E63274248406FAD562B475B7471C147
2C4D6A385E7024436D78357344282C8E98476F2C25439E53516B2022608E2E5E563C80AB
3726604C427940223D67609B6D1D3D6F4A7750284A7D779E853759776A4F8F3B52625C41
8E4336497157485D224F716F3A5C751E24969131454C39385D86355063264AAA6924444B
3D5DAA4B2B4A4D7DA49327435A5E468DA2363E62804A6E8C2E21494C44808520434A353E
4F425531407619473B7393515E3D54513D47374A3440405129421B5F545E3C646F5B4651
6A645C393F56344D4E4E4C35455B5C383D4F394C3B39595A58474563735744577A525782
5F505856673D32713E467F554C61535052474F444536434A582D5A5E4D482C41623E5F4D
5E4B646B606452525B59706375659767567446523D48295A32694E665185844F72515D6A
577A8A7A585E42676C8A445C3255498B3ACB9A7D72526D616E5A27514A2D838B444B4686
40484C2E625A3043405E76484B2B495737644957176B5516465E315D6228634D5574334A
2C3E33355D325A20614C317875193D4834583A5C5A3F503D4D2B2C451E3540206A68396E
2B4B3A575F19422F3B432F532F4D285627394C3653AEFFC690475495924546576C6FA033
718D43695F3C6544606A364A568153492D54904A3A524F4C4A505D6C
6666B44D56657B94463E554565B1462E4F766990612E3C6A597E7D362A436D73964F2B2D
477A3B7D61152D56673658253E6B7B5672551C44657932752F2564842A21534B4B985413
23456264AE521326746E637B1A1D275649536E1E325C714C6358191F65623C7B2C274A7A
3E3A5C282165862E33443C39854F294D612C48924A15374F3C5B8244264A3C426E6B2522
59763C64312853AC844C57331F88BA3E58723A1E769A45533F203043683D5B6925308572
2356424458AB542A4E3F3675762C29556C579440243550589BA02B3A3F6E559B9C1E5794
644B8E274B665938512829568D3D59743F525F28634C4173AC48406E394091A397803E4A
7455274B5B616FA6293B565F5D83AC37314E646A827E241D556F7098B0371D617F5B7A67
3B6571754C7A351C426A48405A351C32744E1E444B2C35735629664129355D434E634248
6E4C573F4E7A1B46415366578A5A78544652375421354150194C1F6F4F64466F84734C5E
856F652B35533F594B566E42604F663D436F405C4228683A473B335B465536494E734E86
3F416D3650535068272463343B5444555A3E504E442D3F454C3D4E4D4547323353344853
523B506D53586A805456738855417D4C616E5A5E40502950334F516544477A557958727F
455A7283987F45664E6748543D4653A0568F817B6268786A798A3F5B59178B783B573854
3C51681B41581F4459407063544037472D4574A32C515E22526931495B418F6A394D3163
383639515E313F2599772A474212545E254C2D55584851454333354D2663691C4C453360
2153214D5E1943505D5A4B723A59246A3A39404256A1DA565C4053A4894057575641504D
5C8B67C79B585E456455333838503B483A4C7A3D438C4D5E47555E57
63528E6AA74A486C8C61BA3F345792478D23276E8C4A4D59193066422256273E58612233
3F30445B7F1B21563B627829153373479490201F458C48B83A3C4D524C4B6D1A3238733F
5A4F1E2C5C7A2F37302D4D6249395F2F36718F3025422E2C7280201B294F51A54B212E39
3F5B92251B2C54437380272841653B85934B2D546839627B24276C6F45703E22487C5A4B
6121467F48264B58464C89341D3E684173832120416F576C69152E20493D74A9291F3F5D
508C34274877608BB3422C4B796766A4353B6B604E886C1B456C3D49723F1D56A348393B
3151945C1D4E425479411F364F696A751A3556499763193D70578A962F2B8799D888224E
8C7342735A2B4D906A3E7646404B6A5F3C7B35355D5E643B7C4A2357A459313E3F3E7598
252E563E4E98751538644A6C8E481D2560674977602A2D5B8744974F344B5E3C546E433B
A8626F4C4374446D4F4B6C4A876C5D4E444F4B753C45428C3145155365504B56634B505B
6E985F422E4F5E6343624C414A4C542462664E50563E733F4B50485D535C3F5554734787
4A497E40784C3FAC362B8A454160425B524766444D4842466C505C5652573C3B643F5E4E
6844655E50614F5047525F503D2F5040664F333B4A451D41254E3B5C2D6C623662626280
4A62696E554F3A6F6B84506A375543A26198726E5678605A75603F98691C8B8142804659
3A7C81264B682E6D6744806472723D5B2D4A4154244C461C233230455126746222432838
413436325B2F4C1D6048265252093849214F41855148584043313F51374449174C423362
264F3D748B1B5D4F54343A5428431D7738545D385985975035487DBD783E4B4C60556C20
5E6C3C5C54377D2B5347385839613D63375778304F89514A58518358
A068694C899D4869526FAD5736484769852F202B494992841E27416762C7621C38635693
A932293A55445666202A49522864462554853E375C24216F6B192F584151AF4F32553E44
8788211B2F514F806A174C725651893C20336A5D77A2234549897070851D3B536E38814E
2E46777C3F7146273B9556365021195282422B803D225E8F43195C523E936C2041595163
992A325D7C4BA7B71E3D7F5E59933A3455826753913D4E5E6D36524223275999522D542F
4271803141412C51B25F293738225FAE6E40583D519EA73234784F539F7A215444517C6A
174D4D526A9D3D286E6B568F3C1D659A4A5D5A2B47935383572F4B8F493874324093582D
6C4848817F2A3E4E6A82975D2958583C67C9482D49534C68D8702B39445648B94C354954
4951742A4A538142525B1F3C48664E60671D1F40782E363F1B37536D2A352F254157423F
4A395B484E83373B44515548785A81894D4B204F2A35404C2E502B4D6E5B4B51584B4B4F
5257543E373E3C4D5165533F50715D34334E655C402C573946514547474F474D5250586F
4D4E5E5677535C8F55416D4540594B4D43514D3B3A402E3D4B3946463D5024454D3B6049
54575D5B636E607A6563795A643F674A5775415035522558284636624C6F6F376170748E
8877699668733854687E4A4E2F3E3AB3738A6C72696E6E75915F20495E2480894D513A5C
3756621D5E5D1D3B4C345747525F3A5234615B781E4A522C334239415D438C743D5F4144
3A2E3B366F394B388F733D595B2445511F59417D5755564453393F3E21494F1A4E2F3F6D
2B64306675174A44474E38423A5E366B42453C43644B4B915D73C0BF924652858D53782C
5E8A5E8657416146545633384E713F3846576535387746594F4E575D
8B92A04E7D6F799B3F56816D79BB4852866C425D671D386E403E551D32568A2F5346364F
7C602B43415377A84C28475C46924D1839655963B32E27475E4E65733138645D75794025
5B726B5C943D39638343444F1E1D3B602232431E3F68461E4637375D70231F432E428D74
1731474969BC431C2C4D5769A32D2232536E56A53C2E39477845882B3F66743A51502136
646C2F4D2A1C4A6B403E6E242B658621365F242D7C632857434193662B155059545DB732
26658050956E232775B5468C642E2D72974F751F273F606048813433436A438C4A21707F
4E516B2C3C977D394038387B631F3D4F51696E274E3F46C0892347574273CD6B2F4F7294
CD30465566619BA1414672824B7A80352998703965672B3A497F435151303353692F635C
3C6677442A502D528186362E4945656DA0381B3E51649A6821214954458470134F74664B
6554763A375C18342D5F9B556D4F554D4F5B3E5A293F4B571A4C1F6061603B6E6D6D4961
7963692B2B4840573A3D50373233461D45563136362B40555B46395A6E5045536F5F3955
4A5051384C51515A2A245E59504F455B5D495951473B3B5F5E625C554755366254364F57
4F3847584E4E576B4C6B5E64482F6453575F5F5A3B55275D2E5B536D678C7C54A9747279
4180838B736F4079719151693747477C6F869197527C534F5B75447A64126588355E495B
546F871B414F35565E4C62545D714E61234A3D702F6571273341365B7334886D3952584D
333541396F5261198159377D6E28424535704D7264655649503D3D5631474B216F593758
2C613B78911C4C4E514C404C3D822E7631546161636855674C508C582F5453524E576A62
A49F5690725467284A4839474B5C534E353B4B4753694F605F5A896A
636CAD5858406EB05235613C4883443E505E5D938E2531503A719C212C3F5E8BB07D1C41
55716F8939263F759551721E2D7A93424C2F3948829F425E3A1F4D6C2E305B26455B4B2D
3C3D35487B771D344853859623232C4F66656B1B35477B5C93520F475E595C913726668D
4454701C18648023634E152F68651F4B3420217578233A4C3538867A314F4035818B3539
56405394401D4470425EA72919548249748D29267173428E781D2B706A34906645286C6A
45583B263B8148495F404B5289403C4442548B581E4846464D8936283B523FBC7A294754
488E9D31204D815D781D394F75498A2F2E667D436C54197DBA425240173089886B5B2253
96642F6F4A2E599B49406D415980832D3359565577A02E2C573E63A6B128294A4B5EB3A5
284D786A6BB443254770687C9E3F2F407F8C4390352341675A3F682E2D56753A6E553E58
A671582D3FA5556C5B635B5B6664567C5545496835344A7B3C5A1E64986D4B748E52626A
6EA65945343958513C49352E2B4F40264F4E48434C4A6541494037514855374E597F3F5D
3F467537684046A73924773F395C384F473E514342302F37564E4A4240522748612F5E48
5C475A55545A4F553A55646A3D2D5149774A3D40444E2748244134533C714B2B4B4A6186
415C67716D453F786B69425335524F92A6A6765B555E536C8A913553682C7B813C7A3C55
3559802A434E28495830493F75653A553D5A4A6F413F502B4257454A4F278B7A44554F5A
502F46367C3D502BA17652A68E274A4E255041856E6A5F5A51414D4937634E144D473784
33542F4C5D115A46474C444D3F533F5936444D617E657AAA515F7D3E1F4E517C65628A35
51726F85715D6E564F57475D5C5742555D4C5B3F405E4A5849525653
665E7A86B84A455A798FB83E4250627DB71C465F71575E662A50774C3759362F94C05467
4E2B267286291F38215E6F431D49435BA2661B29455A6EAB3C27215149748C28284E6F61
9775223D4D6F6595462C33725D455F3026436437469342307E7331344D304F6C461D3042
5065922D1B384B3C7CB83010475C51976C23185976627F80302855683C693A2659964553
6030404D7646595A22435B3F43554C183B7C2B2C3A2F467C772531422F44B0A3252D3D55
55A4672329516759B04C364D57608592245168524C6D6E243D556A4F7138365A932E4B37
273573582D57264A4C492854312A988E22494752826931455B47A77D1B2D626E8D951E3A
65754DA44A405F5E7075AD364287A64D5D923028578666459739244A967741692A284A67
34405335407780284936333F746C2D3F393F75BB54183B56375FC6731B456B3A4755483C
413B5238275525242A608F4345434F4C3F4F204640464F434146273E5A53334A5F46413E
4A774E333D34283E506355343767502B2D4565562D1B364B494D4E484E5856505F6B7F6C
4B477F386A4544A3605A704143624D56585765563D433C3C5B565854415E2C53673E6850
5C65685E5F655F70565A7E5960395842464A49433B482445424D38644B8B703B795F8298
4D758198B87C3F6C6F85446C47603D936371788A6B714E48485C405D4F26839F464F505F
4A578723474B1B4C5B344D415F623845305445631860581B2C472E56713D797A5F855C45
4D414B3D725168466245436F86375B54427A53767B755651664153614E4B5F3464443F60
466B4A7571354E516A575056485D29753C40486B8C52819B38705046384351575744575F
6375455E5E5E81336361434D3C6F393D2A4964464D5D4B52635E5A5A
837A86478C83577B383F9054404E464E7E3D234A524B577E2B2E6B4D5D983012305B4997
A92032455F52667409213F7647AC3D1D47643550541B2D37672A4D381F345A3C31502421
5B8C2D2C492F346E6E20362C37617737242E454087902832456147AC7E2E33615A51A17F
15415857468D4520426F6C4D4F27256CA0492D5D352D506A483B5534547784302E5C374E
7F2E20403C3381A02A2C584D6190722932675A4493241D516B365757191B5BA23B49731D
25618E4B625223435566304E56233F89633241424E75642225425C5881421A3447519B6D
1B343F6458AB403256494E6D381746844691252A534F3C86661D315A4754532644624341
713333647A31415F33598476404B5D3D7BA33F22364B42879E5A252D38618F9F3E24526B
4691792926518845AD7B28295C786F927D24377884303F5A2223426F373F2B254A56463A
603D5A3B2F6C24403A54653874587351496B2258313D4A581D473D5E655C3973796B496E
7B5E6C33273C3E58413A572F303A4E22344D30343B293D4F4C292D50654535476A5D3E51
575C575E6E5160742F1D4D4D4E41314B44364952362D2C514A3A454E2937255145264053
493D4F735964768E586A6E574842703D59617D5F425B245F2A4D3A633F5459345B425161
537A7569585C40505A894E4C374044CE8B7B818B4A9357636D965571704A60694856405C
53558B476E6C4249596379636366505F3954525C245A6329374830516B4C917648555172
593C5B2F80436341997351776E3354573C5652905D6271514F424F564355503471653F5F
26533870901551456D4F3C564C5045543C53554C3F4D65765DB875856E6460635F7C9F5F
6367619D7A63613F4341404D3247463C3D5A622F4FB75B59695C6075
7CB29148649B94CB3E494D5A8C88344A4E575D7C4C283C524C6A90272F6D925767692E2C
5C413A592D323B68592D402F33504C20354B4A60AE3D2E4C4C5A848A183B5D5859882D10
4D867B6A9C1E132F56355B59112E3A5B285768212456612F75461E396D1A2755321C5F8C
2F3A4925367F8B173B445C74BC461037656A62622B193D66527499282D4E5F5274742738
736C3B761A2E4C71455E5517415D88526677465688662C54424D5686291B53645864A132
194256397C971D345759488F9A25424C5861832621426A64727B1C25586C3B7449213F78
415A3D213273773C521B33967735532A5678673156433BB1C3323E593D82B43B2D615678
BF29235B8E576D813A637468437B7426329C6C486C4C392F7E833F5156364E977E4E6342
30347851514C292C43784837522A3242823B35344C7092732E294D3C479B8521576A5E43
524455414977382A2A4E6E574E415A4F4E5E4F4E48464E562F4F29415B544E616E646E6D
6E96663C3D4D57614E5B6541385B6B2C5D5F46534B2C5A48473F335B4B59374D5A844369
3435753C483C2D5E372B632F304F424E3D44553749362F2D544A4E43424C1D2F5D214D39
514A5247504E4A4C3B4C69774533535B77543E4A4153355A25534E9D4A976734834D90AB
50899AA4BC754C7C72925161315D597883908587534D445766795DAF7A147294535C6A67
65427C373E552945494550564C5E40452B4853713B655D2A475450555E30928052593D6D
6B484D3B673E5332865B35716315595A30533D70595558504639615F44756E26524E357E
35593B3F5A29483D726958734B6434673E3D326975383A50456562A1724443535740521B
4065486060538032493C3249365A394C4E797F4454B64B5B65588B68
754F7F5C973A4C5E64629A39307863607341435F703049443A49873729512A5D9D6C2738
5F394AA1871F31303C4F993234574D3D6D531534546B59832F25466F494D34284B696D26
5E442A457164245B333968771F23484049536B1D2E3B463F8F69223F503F52A7471C4D4B
337D9D2234335E3C71501B3B416D436A491D33755B2D48531F4B9B4A3D542B22508B3E2D
3C2E6A903C1F2F3E3390AB172733464781A41C44554F368768223D96785BB16342558188
427C4F3055966A4E7B313B678B5C5578294A5765324D3E36558A2F36494341A293264448
3492631C335942487C1F14565D3A7A1F3957664B7244236BBC50835F263D876F46422E48
715C34683B436E6D3A345C4650777E393C572F47715F1F2943545D76781D32405E4E9B41
2C544A5B8B932A3F6A675A558B37223F6644565E2B234C765C4A662B20448B45515F4B4A
5F475436347C214146619267754991714969225E3A46516444424A506C553B53665E3C4C
5C5B5C2F3434324648464C3636434C333140554B3A37504D4C524F5353564C4E587B6E7B
44456B506352416C55416F504454434142554B45474E4C304B504F484152313F593F5851
566061605D5E5B6A52447B474333604F43494A51484A203F4B522B4B41A0642E54394F5F
355D5455604933427B77455759592F7F4854656B467F4F768B7844495A1D708159AF5B5A
7D73AF5258733F5E583B705E3C564053275960793D6559433038414C6644827C638B3F50
5146602357477F31785C388D7B1244514D976DA86D796959544A5D4B363C48145B4D3464
2F5F2B6381256E51513B516455455A844B45453F3D305774333944712F4449757852752E
6A8E417D55799F3F4D364456314C233C37887B3A56A152575C4C5361
6D51585BA95C4F656D90CD4142484B7F89253E7A81497667203C7A6E5FAA21194364587F
A3321B3A7A5A5A51201F5776456136296A8C274446222E914D1B384B2C696F23384C7832
72801842517056AB521F43625662A22826374A365682142B33654B5D671A2844632F5144
27496248335B30505F792A3B4F2B4DA14D243C474A3F91702F2850575E983817345E6F65
761A224D6D2F6B6C31385A513D752F25398F673250271E55832C3442363B6C8C242F5537
69A568213B4B3F7BC1512136584B81B72B4C494C5763541C5664485782433B5790596B47
294A6C4264752D3F72413A82372E743A244C36398F72224141374D8A4342444F91602436
5F5663B65B1F587A5579CA402B5D753E6EA8362157924C809845456D9349686A2F338BA1
3968792D47839229493530408D5E232F4D2D5A5F3D25374D357289462731524257625138
443955332C5B295F70547856734F794F4B63244D3641565B1B432A575E5D3F7F6E776273
79666E2D262A3A6550537D4C5049662E5065424245284E4B40382B534B4B2C434D533451
4C4A7635515C45853C2361453C503B4D513B52404C302A2B535146463E3E19314B233E40
45404949484E57695C536E5C5A5C766C5A6479732D61375523513E7B507E7E3D895F70A4
6165737B6A7E385A4D5F546334493E9F74967766404E473C4B7E60828B218185394C4859
6740653E60693876716583498769385038724F836B87803A3E4839668D4C8E7B4847445B
515154445A3F4E507F69424F5C3F4B53424B548C46505D46453E496661505835827C4977
35714C708032545588917D6D71913B7B45644E5272444047334E597361654246554B711F
496055A44E50734F7545384A4978434E244651504A8C4A5A4C486073
9EA3644C547074833C60AE824A6D445265632C6554384F5135505E1B429A62217136266B
A24E274E386EA16D2E213C4755A935162E837387991F213B5E3A8E402B3962444A64193A
4B6D416C8A272E596D393C371E3A5549265035374E84412156384F7E941626455F57946A
154C485950933F283B475967741F1B2D764165621B2B3A775A5F4B23435972456240365B
5A4A3875334165691C36464A5D865223353D6880BA2C272F5743789E1A313F495469972C
1E4164417C4D21355B7E365834203D5E56355D1436625E2842641F539972296B413F9E95
2542683782BA3B36755D44AF3D2A55497E8F2C26668E829F4B274474549661215393713A
6421357277417C622D4898804364503C5D9B5E404A37344A904D2B49392250B75C364A56
4E729A38324A67719A442435639365875C415165634A69621C2C7A70415D4121627C6647
4C466561536F3D5D3E4D7658766F6D5350784F66535E5D64305531567063586F525D406C
877F6E432B2844653F4F824242494C1C404A3F41484A5C47434C43615A5C394D5287406F
47447F3C496B425D3E2B70433C66414240364A42443B2F2F4A495955485A2D315F3D5F4D
4F3E6753555155553D3953534739555B5A50414F2D4D3C55395D378965B27C56905C7491
5EB0AC746260526A555733463555457A70897C83544F5C6071674D907F2B5B7C4C965869
6450A5477170347F5C3D53505C6E5361265048754F4745364153413E5A28AF8E505C3B81
7441632C8D4161548F915A7E7B185A703A6248B4605C725E593A564C57525C234654357A
286230668525713C463B374C34392F5A2D35343844283150364540473D414A807879AA41
8A916BB073A3A841443F4C642D42264D3E524B33436F404E4C4B7C58
5E87744862627A8736395A776E86343F457379AF7918334B4CA1AB29433C6F70D24F3547
46555691281153663C5758171E5681375F29263E683D3C4F22276670273D3C4254734E1B
3C573857A650174C595F90671A2350674C9F6A18355B775FCB312236563D718C1F355E74
345D6214315B633A69492E606846294B383C90843A1B3F35438BA6273B565956A786213C
62455CBA341B5D95536856212B5C57365B730E1C5B6B204B37202F834A265D2F2948A66A
264F314361882829564376AB8124405A485AAE2C1B35534C648C1D1B47815ACD3E2F4292
5561472D67836F506A193271604F5B2C34895C3F4F345D9478244341357A942633495D62
A52F1F4D6753A3B3233269704BB6652131857398A34B30376673577A413238717C71A140
3C4B7861585B2B2D538439466339343960393345353D65802625274D487B701F7D665146
615C55424C90514847598C51664F6B6F59613E4B4146456B4949394D5F5541576358484C
516F5E4246443E45475B59494F515420364E595D48244F493C504A4E585146434D6E6F8C
4F4793385376416A4B5E673D3B5C41453D5057404F3A382A505A514A344F262F4A20484D
525C634D5C585A636043645D5A447F6F6D6B4B543250394A345241654E71684E74748C98
69464F6369743B5557673C4D42623F908A8A78584A5B5C54869150515C2D646B3B403245
5038712D5657273F4D355C3E4F5C32413D7F55894F7E7B363351406179375C595F9A5E64
51596039635E7B49CD8C398C91305266648C5C6C6F674E4A74454C6F7384813790894A8F
46714E525D1C40404B4F4A53496333632643543F5F314B645E474F71505B4A5663618A37
74815492614D655376562F30385C454533616343578F435260474D65
585781888A3F577D7B7B962F4E506793A71F37556653693F273E464B505915357DA53C34
45173FA5A82B2D462C5D822C17385853985F162A413C79921D2F65615B5C401D5274733B
7D381D35645B41592B153267242E4F1F21436416322C293B94631834321D5392371F3B33
389CBB231B2D51529C8F2132494F677730193B68824B8A392139745252512C3650645755
621D336A732F585234818F293750523580B7231D515A418F53254573488AA85219365879
5E9023283F606F62AF2A286781374C501F4D7462435A402D66844C325532457C72215D3C
4661612A4F59607D9D1C205B426E7322394E445D9D4B246B833B6F3940478762675C1E61
7E5944632A426B864B5C6F204B83863A3059243E7975263C5E3942999B2134583E61A365
234549536F943D274C52365E9C2B36434E4F5A651B2B4F72475F73192E6E6931565B5853
432F5F543A6C3B5C68646D497E73724E48792E57534E725C3E63445B59635A7359816977
7E6367361D1E4254403D6140553B4E1939533036402D4E5652463D5D77604F5567803956
454180827263324D53325D454B6B3A4040324538473D272B4244464A4B501D305C265440
52444F435C65525C505A64524B507D5864736A693A6B3F6C41613A7772BBA36689679798
495F5A5F6E6B44513C5E3B4F4949307781646E584B7C8E59525E5C5C5422738D4059445F
6442833A706221454C2F653842654C4F273C2D7641576530354E384C5920746232504049
4D3845215E3E4B398A6C4166531B44502E5B3D6C3D4F55464F2B463F404647173C623D59
234F3964881F44455746365048622264252F364F7F4F3F455646374A4A49475C608DAD2B
719C77B9666A7F303D3446302A4D3D422E445848496B465749495661
80866B57825D5A5D6AB0C25F355B38539E623052466AC6941F3C3A398AD0452F357A4E93
76162C2E83638941191D466C69831A1F4B7A4C6F82272C6F6E3C522A265F60232E58663E
8146202B533B40814F202E5A74678A2022345751746F1428435E63894314354C5C57B230
1F2D5C4B5566201951925950592541696E223233333A839422333A3158883C235654548B
6C161D426250995F29406B41678D3C41497D494D6B2A365CC03C5D4B1E3887752F3F6226
70AA72376A4F245AC5802A455B5993903B335F505FAE601F44675969922E1F548957A555
1D3F6E33825D193F9C5B4957303169524D621D37688F3E4C35467D5A23464832649D3729
6A5864832F265160537BC73A2069A26273AA3E294A8E6284A63E455D7A43597B2E474F58
5469592F5D84524F6E5D38396D6B30484D233B68562B39434048816024454D526B635349
5D606553509E734A4750746F5B3A694F4F623C51585E665B385B5258694C4269545F3255
67785A422E3147583A46573D38565A1E47543F44584F5F4241676053405350473B644860
6049593643563C573C284E363850402F3B39453B3F3E323A4863443C4A4C1A31383F493A
4D74595D585153544C4161564419854F63724D552D5F4A6C415745967CBA9E5D8C698BB7
59627C6D5E625A704F60466430523C5F755D8D815F415E7888833F5766255F6C3D795747
54348D323B4D1C5B511B47364F58505E2A532F8F5C565F273B6147454B2A7B6E3B563F5A
6D38521B7E2F47335E523F69681A636E3C65516E4C505A4E50354F4253796F1E50714668
345430425C114E3745463B40344C246C30463F3C52313B4E497E1F4E4648537997597C52
838C426E5462562F4B352F402C40394C3E5D463C50814D4D5F53676A
8DAC7E4565609067384BB89277853547718D596D3B18417C4D8B552025586B4557212C42
642F40432A2D535B293D3D2C3D864327504F42677A24304B3D64962643496F465C72332B
555E577BA62537394C55805E19282E5B3652391A54552A406B231D707E1C2B4F2A2B7C61
123A54305E9C3A212D52435E8A241D45816B826E18315190465A4612333545475F49145B
914854532431618028383E35368171253B5C574F94431F4A4F41828E20283A6F3D68A52C
304F73438D572F494781528133185066565F8A2F245F6C295550295B7E654D84392A8FB8
5862452D6E8832533A508C782A5359377699151C4C4C54A552296679406E4A2A37878E69
982143525D4D925E3669876C578E4A37577845414F28385E9C7A1C383447509F6B2D5728
4CA6BA4F375D4747826235255A79599B912A285F6A72713F253B646764813D33675F554C
66525F4E376F394E5A69966E6F506E6B745B32553E453A663B4535407A553C535E4A4052
4F4F513F2B2E32414B5B5441456C64263859646648224E524E472A4C5C4D4648516A5F76
463C6662733B1B43534B5C3E4654302B354E46303F3A2A25404042444449302E5820443E
4E353F39545A4B5160787268513D8353806C505F39613A533A523F505FA7956DAF7487C3
7BBBAA6B6990475E526C274533473267795964475236854A4E673D42644968753A4A5757
694469434C6839484A1D754B3F5E4C532F692B5E515C5B2B25382D53631967623C624A40
3F2B3E135632522D766135708C183D47427A5E8E4E62564B5738484D5542491252602F52
16683055620F3F3449493D4B444F38A33A484A4E58335474675531515155435768719231
82935991967D7B6380583A393A4A37451B5C54484F814E48534F5964
5479795D614C6E853B4A654168913E3342384FAC671C2949407F86232A3F4D69973C2254
6E407EA41E2A534D3D7A761333424E526B3435495E4557692A1B72722D4F212026556037
652E26466E581F4D2B31495D262B423343A05C15273A32669A29143A6052677B38352F60
566A651642547033774A1F3E745A56602943566E39334C32345887262D4430408C5A1426
524B66741C1F445C5E7D682235477B4F8077335C4A4F2F951F314A674B42701F25467946
365C1946697037567037737566293C574973AB772451684A8787132463646A9C38194F94
5568452E727C43A3722A4B933F44373043975442552E225F7B2542283B5C8E333A3D2968
CD5C30612E329AA5274774525FB29E2C356E5F83882F243867905D7E3E1C3E76817BA244
283673514CA26746555D485C592C48599C654A411945718F4A4A7C2F3578663555644F41
523B5B39277E2A353E4E6050705382594F7230574A4653533153364A565C3265616E4169
7B636531393139503F2F55473E3654353C4F36383A2D3D3F393E3D4B56434548636D405F
5F59612E3C455259361F4F50434A2C2F3E464747453020324B553C47453D1A5049264646
5555615C57494F543F3856483923692A404970472F404B533942448B43666E4C905597B6
776F8E6A6978716C5C6D505D4D523E74494A544F55548E5058713A4D553D8EA83750555D
8836975E75773150553648394768415C4F5A3C725B5D773934492A4B49259B743751523F
4735481A56435136534B2F7E7F29515A3D61608A485B584D4E3946445953613F577F3964
1F492A57652A4A394548425C444D3B57365D4E6478614B58417E5256627466759A7BB848
7AA098C66A8A773C494E42393A704C4E227E5142357D46475B4A575E
5C838D78853D629B71B3B53C57875E6B97374562A56B8F2F3256565B6A741C408E9C4450
2B25586E5D365D2C1F4C7440375B393A705D23633F334B842B2A4449616752162F505C74
8B3917435F4F5775192231614C57801725317A406F53182A4049284A1E1A33594E285E2B
389283403453333C825C182A583767853415376A4F81CA441E3C5C475B5E1B22598E5352
4B173F6B734BA33921587536356F29274BA02F355D343273531F535A5D56835525524F48
9ABB3219485253A3A430366F6B4A794E1343788B82976722598347406E2A42525A3B6427
46808D45463B41718E283E4F4D566A213156507BB1381F4C674CB449243F92688C842C24
729E6FAA374B566B667182254C758A5A5E842C4E907D2F537E3F4C7B91324A553143776F
24523A5B55917C2642425C8575213041605F999A2133405F4F70711D4168603E69875E3F
604D6F633662415265637D58796D65605F6E52744D43405B3D51365C7864507A676F6365
7A8D7546444643624D456C484B5264194F6A554E523C58573F5135565B55404D54764B64
4035793C48532B423C2A68403C683A473D44502A44403E2C4A4647555045243A5C2B4536
4E4D49494447616E4C517189571A7643667046522152414D3647374E31727C3CC55B6069
474959525C6A435243462E4229352B4067476978673B594A5A753B66743D52655A51514B
7F456C41567A3951562051513459516A41653C606B595C3A5178515440325E653345394C
54475F2F5A3A483990654673813A707B43556AAA565769654F395A4D4A505E29517D3E61
3051445C672947556252516252563B6D2C3635433E53495C4C475789715B6D74A8ADC855
8778487644797B384D3B4F49325848563A5D5E5E35724C545E405B76
8A9F645A974D8B4D436BB2784E583560954935493829617B2347422F538E3221575D4F99
44163458647799861B53636767A82F1A698B57AF55192B5C5353782531405F448477152C
69893E6687363B694B1E502C1A3D8B4124504A467876173653415185360C27453D647E37
0D30694D7461342B3C5C475F3B11465049385928294564643A4439293B88532C4E3242A8
7B262B3D3661B3761624454B75AE5921316B5076BD2E21447945985821493A5C317F812D
266172564D3928506F5E2E583D2C5E813F3F5B273894902D2E395B629A3A33524B548D37
1B4F6B54933E2160A94A6362274668525657284E614F406637245D6B32452A373C6D4C39
693242645C2F60422C82BE4624516A519EA42F2547666374B344264379468C9131435C8C
4E964F354D6E6E647B3626457B80446D492D356D4E373A342F316C43344D3B2B8065604A
7C6B4A312C8E382C3B4A7756515060854C502A43384244543F3B3B49644533524844313F
4F75603345333338445B4A433C5D4E1F3743645A3C3349454A5E4955625F5D57618A6180
5847846D776B425A4F426B484064554C4544473A463E37283F3C4847474E3D3E4E344A4A
57555F5D5F564D464C47514B443E6C3E494B4F472D473345384C4E68364D5842644C8F94
5C6065658F6A414D5366345152531F3F5F5F5E3F4E375651799E49424D3C6492385F635E
883F9E53668339595E36514258713B543B5656825C5256362B43304B4A1E78512B433D59
7F365B3E7E3C4840694F39767C294C5F4C7279815E6A53536742433F507E672F51783F93
404D32687A22533F5A4F4B513441407F37453750584976A3414B354C637D446679678B27
719259B56CA78967824B3D556F875B5A3C8B4F533F734D4E6F536B6F
55AB6A5861718B4F3344687C80822C3B606F69A537324B696595433856655B464C1D4378
7648728329366E9A555C421F487B7C4F6E31357CA23B55513966A0432F32304275AA3C1D
3539408CB72C31615341A24A0D404F5850AD302143563F546D191E4C6E2F6A6A1D205F5E
2C3B2B223367311B452A2A80941E24532F6088500B356665456D51292A4B564E774B2639
713C4B522637668C3B54432047656D305B452F537C4E385126485D8934395033616D6E3E
373D305295642140545363AF7B1E55725577B9211B47624873471732776946861F2A595B
456C432C68702C5E5C2247963A36442A569539317646398A651E3E5A4F8432285C586563
BF3129977B5C854D283BC59C608B364C51AF78587B2A35445D6640782A2A4FA077547127
3B5F672D3A4C33516A702A3D36474A998026323E4D6F72512A41425E60763D2F535B5539
5B384C34186C2F345255694E9670665740672B4A384039602D4537576255385A5A926154
636C683041382B54503D63433038562D2D4B463C34273C3C3F36234863422A3B674D2E43
575E56333A4F5F633A20424F3E3C2D3D393634423B2A24304F464B50483C25525F304B54
5B3A537B6158555D525A62584F34693C5E6B4F683E4A215C3A543985558B832D9C8E87B9
74556F605D7147542F4C344B1C35226545324F464F4D5C2F4C67444F60306B883B434A50
5A395B5055582C4C513568324157445C36732C555B4D5F3836424F6A4B3C7C5A2C34375D
80546D275A535C5097743173801C6B82383E4C803D455B433B2D4A394F50482A769B485F
31633D5C7D2B413F574A434A585A2F6229444D545758485044585C554C5A589A8F6FA137
94B2A5E9506768354E33394533583B46255B58794477655E6C607F86
5267767F7D347B865C9A9642797438497E414667692E6B3635697B232C4F6256944E1C49
5A337F782224445050A57E17254B5164C3341D305B4B917B164380715B883D3E4B786F5F
902D3C439E92356E194454772D4764191B596C195239364888462347232F93A62B254744
458F5D1D233E4760741E3232804A57742528708D3D4B7A2B2C4356284B4B2A2D55683559
4B4C5C6931213C556666491B27475C416E692628726249872D1450A35B6E6029324D664A
5A571935536D4B4A4B1B3E6A8347503E193C89733D5036296E732D2E494058B16A2C4D36
58A96E31535148A5B2372E513B5F67253F594C47963434517D5393572F6B7A3A6E4F2F53
9A8A3A7940356D8737364A524F8C5E265D5C5A66873B2F4E4058598644274B435558A237
27536A599289302751908F9B6F1D2E55874F595B18374B8C4F444C1C38919734596B6F3D
6D45574C347140404541715C4F4553574C5D4F4D4461374E344D3E4E5A52454B53523F4C
485A59574B405A665647694E414B601654644D52433252403E4E2D4E576134535B774672
503C8C49424C213A362C5A3433554941374D45324B4E3B2547503D3E53491B2E4B4B5336
3E4B4845474D5A67444755935D4A6D5F8566604951532754534F446235CEAA34A79885A7
858E9B5E6A5B50678F7C2F473C52362F526A574F5A3D47417D9A3C6C602B59823D616045
6545804053652C5C52154745848E5267254444795D38522B34593A34362778552D452534
4E304C1E6F2E492B9C7E3F7E8E283D5752775978555C444B4F324033426860142B503D7F
37352A3F551B41344C503A36333D43734C41295D64404A5F4D655F9971595C5A5897976A
648676916A74844550595868596047764F7A334C39674F4A684F5870
758161638541634F546FCA6A4C595869903431576D8C9733293C7F5C805B332D6E64599E
243E41746871AD3441695842625816324C4534792D1841552F444D314262531A2A464E55
581A20385A835E7B251E6481536CA3262B637C39826F1A3F5B635066251A4D9A693C5719
2F569C3C3D432B3B81762E792D2B6A6B40365034575B9A75234F564170A325264E5F48A1
771D536158689737386267356781301B5874274A753141715F3C5C313E547F2F254E4A45
739E541B555E65756F1D20447760876B21294463539730316A615065862B389AA9496420
4B81864D7132255398644A72293584424E622353B676304B3D4F888A3B613E4BA0492944
716056B6464E6594908E7F313D75A66A92633445777A66BF69194A777453AB5A1B4A7379
3C702D344C7553485D18338C99422D50484490972C313C507671592423345B6162675C4A
806F543B499E733345599D8268546D75656240543B444E6A574327548D54314B616A4641
59937E454A342E3F3F5D54432A51502C32504C5242333D333B614F4B5861565759775682
5D4A725C5F59395955564B36354F2E403A444E39432E34293B2F41433B41333A4C324240
4059404C5A6D5954454B49373A2E4E194143554A19381E492F53456A506B54355F739297
674A6867AD8A48433F562B412A2B355035373A345A465B2A3A4E3548514D8BAB3A384B58
79397548677B39413D286B5B464B3E4948654E535054684E393D474A5D445F4733554539
53536A24553F57426058364C573C494F42495C7541504F4A534742445D4745152A6E2A4D
216738455A294D3C3B463D484E4C5580348157464B3E6A5A38563147405F4067814F766D
7E8E91C6ADB07D48533D34474B5752583972545C314A513B53435C71
76D250708675B15D3F556D89AE772A355A506D852B317A5E41593C29559F3F3B40263086
762D3838293876491943463791B72B22593D4BBE760E3B5F4C8EAB20295D60425976292D
676B2A3646253856553261241D396049385B2E2E446C20202E3155725317333732638921
1A2B5F5D5C6A1B2E3A5846B14E1A3E613D5277351A2659AE576C2F253F62733377222053
8C323E6817398C792E3C372B45A350123C674356B041215873639C6F1C377D667083521F
458B7C5F7C26405E5C4E6E833C41686E3758663239646C1B4F5F23569E4B445C3849914C
1F605D509B5B2A4460546CA93420484B71A01A33836564982C2D668F508D3E285C7B3477
9A313B6F5A3F7A353D6898574D8D3C4E6580363A4838626F92542B58393E7EB754325251
49804523366E5B6EAB2C1935668E777C393A38594D64841B203933405A5B412D6C545A55
4F535240224E403147434F40726B513D424F41333B6748443D5F40414C666B5A4C625F44
363C583D372A48524A2D4A3E2433422339423D54352D38465242254152362B2C6144353E
5055482F3A515554262659524C5A2C4E4643464E4D3A343E4F4D5151514829435D395247
534A5F47493B48514A5F55545E527028574B41451B423659416056864EA27B4464608F93
6C5D653F4F616C804E69737A30334136454C41635D3B554B4A684A576D314A4F4A535C3E
4F33934C3A4B2E6D5B1F43355452535E323B335553364C253F3C3C32504556443B503746
6E3B5C186138544083683979721444533F634A64505443384C31453756473E163D573E5C
1E31434658264B3A45514C6078763B3E2F3B2853773D61776E587B82877F84987868AF7E
AEC1D9EF5056615E6B44496F536C4A6264776A653F68915A594E6D79
59917571546A76723970526177853344426477A5312B416D4F743F232C7D6C74681E4A3B
6C51745B1331465B3F7B4B212E52375068232D3C7D4A503C272F5A494C4D25435A6B2122
334B557D751D22274159A14E18413B517DCB40123A452C63912424415432865B20397159
467536294E7A4A364417335A5E2A39561F59AB88342F4E3151AF4E1A445A3A4CC35A124D
63518BA429256362528A641B424C68459A731A3154685060153B4B764245702531817D30
2D3B313878782336494F8F913E2946593177B933283F534BA17D243A636092BA2B414A72
58AD2F4A7F866F7C5B294EA58755401D45A663365D333D955D25403C42878E244F47426A
C24C3A79615DA086284997716CB6592757B25A557F2135558D7E5B9D35405C947C677721
5D5D483752401F6F9A64436549255360522B442D494A916B253A35337EA93E2A647F9147
5C3F5D65196C4C385D4F7468747E61503D43433F3538394E3C3F384E614B32545B4F4C5D
4150423C402D43493D3048502746481C6E684B4544304E3E2D46354E4353412B4061426A
4F3A724A454D1D43272E45211F3A283427422D243C3A2E21334B313143441E2B444E403A
47583E4847564F643A3D47794D354F5B764D3F5B2E5639393149578556BF90346A976570
809B745265563F5D515C2F452B41465A2F4B542D2F305932445A3C456B35606B3E57592D
5C4C895257594B323C304E6256543C55314350656649553A3B4C51445C556B39485F2648
643D5442835B55479075366B62194F7B4163487F5A6052524E3C513D58675A1B3F4C3E86
334446596426413B485E384B4547417D1D453F40496F4E474F8A3D515B4C4461548C9D39
464F437859777244566B725B35496A744D5D476F74654D4A54678363
507281A86641608B70A1774A60724A9C5B3246745F887434386A804D4A38314C793A3046
3A2D88882D397027337264224F392B4D9250284C354B6A782C4B463E8EB426274A5A3B70
951F214E7E647A8C162F6A6530BF70194A698135802F233C602E32581F2D8060262A4234
327D681D304D59677620214770547A6A192A76B7385C7C1F386B8D33755F24375F643FA6
2D31548552455C3B5167A4302E563B3285AE272B503D53A84B2E637C5A7DB52C364A6664
7168133B4370656F3B1638697647816721404C5C44672E1F567F3152532D3F997A375B31
368185335A6B6F8E6E373F604B87811F34566E5CA7422B8175557D23394F7B56B4412946
5765619D2E4147965D67432E3D526645786041474F5740563C2F39634F314E3A39616D32
3D613B4690842C2C716A658966222C4B54619E452B394983598B602139534D546A4F3F36
80664A31347165293F4679566A54636C4F584650484C4A6053573D6386633E5B53864B4D
59887A4E46444462573A5649213F4F122F415C533D4A4F37335858425D3B47314F47475F
433F5663604D3D5B4748432A2E37383126382D2C31322E2F2A3D3C3A3E3B302F40353947
3D463C4851604246457257474E3E592C48384149253C2D3E413B4B4F53AD882F7F737C88
52407470837549717B783E5C3E5A41712D656A39422D514C6F8A3C3E4C555F785C3D442C
5D2A64344860493F4D20475D4F42384F5C576156595C7F51383D459377322932778A3F41
51547C3060426465644C42827A4A404F3E7354525C69433E5A2E342E614037283E41364E
266A383C51335E423042524F533E2D4A34485F4C4A3E53565740325A615A4E7E53457C1F
655E3C46809E756D723C3D4C5460404F34894F514B5E56536254629D
81AA4E5F8B62A152406C834A714A376688386B64264A732E1E445C5B8252262A5C7E808E
262D3C68478EC62319545C4E886519286F746B7D13212C624E534618326A692D51432A5B
7D3D203E2F266992251A3035267168192C455747AF8D11436C5259903811458062686E12
343D6C4461531952675B47572532667D2F26372A32597D3A214A372E7C91312F6A3B31B7
881F295A4956AB4E275886776D883821408C89508E204369675E5C2B374E716939615232
6F8142335531296C79252B4E4048738527365D457B943D273E5245A083213A446A719222
3342765C5F4920485C3D6780264E79324F65254375723A724D3A85522346292C857A244F
5C3359944F3A5B3F7A956F2B56574D4D8EA93C53583D69AD6921545F3B60A5772158A63D
71BD2F3874B070545E3133496C3F576925425C693637521E384765232E4F3E415864544A
413951521A6C522D455A5E58887B573A3753363A26443D5F31484A504E523F4646576159
4F415939453D3C5050545F4929494D293F592D3A30203A54553C245377533F47565C3551
564D7A3A384A4252211F3D31324C2D383D4743364A414E3B49584D4E634E3E39623B5141
4B4C513A51464F4B3934445343527939564770561F464A59344489786C8362275252474B
4D6C66434E4F4341445346472E29387744544D444B4A643B3045314D5F45819B43475E50
743C8F51657341454E4874525351546A443D3359673A541D2F354A3B6C693231585F4643
79425E3E905666586E6B4A4A4B383E55485064674E58605B4B46554458704C345E684360
30455463682C4C59544C43445C4B65765656504A5F4E7488545A3D4D4F88626275538248
8C724A635B73643A4E4C47533D4750584A5D424C4E4E554E5F566069
88AE5C5A6C6FBE5F495E996ABD5A314D8B4A9783273C76676C692730625C3B55411D404C
4437663E32325E5C3C6539355853274749236391421B2F283087831A2A3A4B5AB57D113B
57425D9E4E184B4D4A5E911727454C4A95B01E2B435D3F4950152B4C4418412127475F35
1B44202149904F255E605C7F251F36514077981E22558D6B53B82C1850936763922E1D57
A24D565D3459736D495E3D22487F5B26623539638141223E2C5AAA49223158515C904431
3D4A397A9B2D342F654D908919313B5E557F99202A5F5A3E672D22497B384E60214F7464
3B7227458A731D3E553E78C14F395D506F7E19255E74568D3D355748417D2E1C4A5C337F
7D35535C63516E2D4BA5B1578F83253C7F8F565F5D304A6B87594C581D32679A5A5F5029
5783552A3E4A576C753D293D444CAABE23265B5545828E1E1E5E784954692A365B6D6D41
583F636A41968736354A816546444D6357513F574846456C4E443465995C406A8B6F534D
5B6755353C2E474D3F2F47492F42591D3F703F4F3F3A52432F4A344A3E4D56463944434D
4A385144454E41542A2D3A51514434403C402B363D45372E375D3D41484D32404D44494D
505E555D555569703E4A564F493861454E4528471B3A32342F3B49385BA4762A91825E74
7F91784D52485B625C646573413043513B7C7E7C732B453948532B455A324D553F555038
6539964449594B6358384D51545B2E432D473961495268424F5B595E58455A486062265F
83505B305D644B51A0734C6B5D4B5F935D51658B4E5155544A484749444E6B2C443F6B9E
485E48757F4840485953567567637AA6312947765C32514C6A9757885E493B544C7C9B50
52606C6E6789604E5838493E394A45634791507A794B7E535D678275
55B29AA1525A5DA85B744D698169576840374C914B5F572355A759314F4731919E403856
2E3DB1802E34584152AC3F1C3A6C376786261A5549547A251E3A873F44541F254C793F60
53252A506C294B4B363C5C3D165D3C22549D461F50482B658521133642618B4F222D5947
50843B1B4554595664172B49613779662B328C7C2A67582242974C1F2B452C539B401B3A
496D7D691E2E74546CAE711F1C597A54AB73174F5E574A6D211F5380486F653C2782A045
646633317E863B5D433B589C443351472A60AA3C2F4E484F9242383C3A4A5F832B2D6157
77B227306C9E605D4635538C667C3C305761384867243B88693654383F8F582C553F3066
A02E385B488B9E892E47593992BF51355D785388952728395C54849D291F3E71639C6D1F
30666B6983792D2C5D6E5874591F3D836A3D4B45343F9E7F244136233D77472485744A3C
7F6C4C4627563E2F425A735F5E4D6346425B37343C374D5A424E2B41565B32443D5D5652
5D72663B604D324A45595A382766511F2B46464D1D1B32555138344D7357694970523A46
57688057545E4068444134353449473B303D33302F2437353934474F443B37484C34463D
4455493450654548424A558F6A56945F57593B623F3842485253864E789C792C40476A91
694F6676975E335A746D36504F5C48523D5A5A35454252498696353B524C5B6D4E2E403F
5A2B4A3C52633F34392B56554B514D4F2A482B684050731D2A3930607035BE4961826A36
474F7A55744065476440288065192357194950675464564D623C434463504F5D976F3849
4D936F767239624B3C436D6440343B593D3331474B3F766F33371E3162AE78907950733F
7A587DAD3952527A8337273057562F4248B235457969514E69525084
5A645B8F664A596A67B86232746753954F25308080716B21206088506E3344414C3E546E
232C2F543D4F5C252F465D365C412B49674C4662232A794C1538393272B5281E3C47379D
A7132F364941906D1857734244965912466B6851B04838595C425557152F3B683F636A1B
445A6032481F2E5E583D325026248271242B4952339F92232C6B6539816F1538524B4486
321A56664A4088382354904674642931577325433A26689F36243C452F8574261E436955
6970154A5084518A751B4B834368934A284198825561262A4769657A2B243C5959626829
386949227B463E5E65234741448F911741595B66922529596B5F7D232D6E623D72392047
7E446477262F769865716255515D834DBC304247665B6577323C485B5C50693B2E7D8A4A
5061353455763138392256A45E1F41482E61913D2322365D4B8F50294C4D5B4F535D5942
43344F4B177A50274C65977183616B534C632C3D2B334F68374B42576867375C5E806083
76545C292920303D58384944384768302A643645281F4F443A372A513D45524437553E54
4A2556353559524E221F374D494529433E372C494135424246454C5A4B3934596039515A
554C53544646607C48464B51565F8369703651483832383C2A35453A49526344846D647D
686B553A5242414345513A47292D435E374C7343515253331B362735523C719A51475144
7220723C517E5C43473B8665436D4F672E393D80602B2C2547553E253F4AB386212F304C
8027412FA94A2833A17D364042303D6B2D555282444E7A483F474E364A98773445444FA2
213E3E797C33354E544A3F535B435E8F415A5854552A505739583F6A3937393C44798642
4A34303849606036474147432833304027445C7441619563536F7B8B
8F914F766A67794255848E5B613B4676B1556954405DA95F43402E548782395145465F7F
3F2F4D3D386492292D4D51548A7A13315D454F603A1D46783A85371E2865342B6723254C
842F346527144E7D2B1F351B155E601A3742295C4B541B4A513372A845163A45438A8F1C
2E3F4F54A031203062595C772B2549674437651B3E437D6A556C2C29488B5A3974313673
86293664414EAF5F3137484C9594311542803A7179221F4F5F5A7B2A2E3E7180467F3C35
5652343656213961903A3F4824496B89222C453C487748293F217EA180254E41556F9225
3A535D3FA75D20515B3B823E25438E4A825D2454724F388923557A5D2D44364B785E3655
3E475F9F4F36534C63A9AC4F675A51529F7D34454B4A75B3662F49554E75BB662C41654D
7D982F384E7D73846E2131568D6C938D3C2D5181436F5938275B7F2840422D375C724F2D
5E43504F1E6F653B626998757C6A5E544B58484843495A653554294F4C5A4F516D4F575B
56525E44422E324B654E5C48384B6B1A31663F402835454740362556505768655E72416C
6647824C4D69417A41384E383D553546423F3A404B36583B323F56555D4A463C5B31523E
5A485D414E4F504C554E5C7D5D49686E7438223D4043323C4C4D4D5787B7953150636E9A
7A4A73797D7E3B635C813B514244465C4A42684E57315049273D4E60843F393731494A2A
471D61251D342B47421A444E5852323D45493E444C54613045624A454F37865E545D3B38
503D514649433D2D5B56285D4E22487439474661484A3740482434444D354E566A4F2848
555C434857323A414866446075546A89333426333A2F8077556E2E522E59315443354729
543E3A696BAD784F5A333C394B4947734F812F5662614B49637A7364
64AF705C5E9E9C4E315E5B6CB7433A495D4B82732F4079636B8421426AB470A43F194176
4451C14E262D414E46621B39455C3F583C16306B3F44692741444218353543469A3C1925
464A549F351927405C697D1D2733783477751736394D24824125475C41336A2318526A3D
3A561F2F3F5233543D2842712B1B47394C4883231E2A3D466BB9271D2B473F77BE2E4463
6969867D1F445255729A591A456E573D72642C509648304F22404966214541313B9F7A2E
44524C6096331642705C7E621D29466D5A789E1D57755142862B2365884B54353766814E
6B7F233D697A4C4D5C2A608B5653373062922746623D5C9135296D665F9F3F1C5E6D4A9A
7C2F459181658333445CAD67A28B3B74918E5B785924407C95555F5C2046718E525B372A
6C7557396237236E7D5235673528769842305633316487292C4A573982A12A315F6F4B3C
664448613E6A732F474C946E4C464F60594E39462F2E415F544E354D724B315259556F65
5D6F5C353D465A5A674F5C544B4E61294D544D4D231F2930394D3957565946585E754368
694983665F574477554540323C604B4A414237474B435A41344E4F4D5A534D4263395851
6245605160525D5F6E4E535565517E4E7666375330624F4546574B50786A672952648790
665B564756505E4942654B47423D3A5E5846693C653C513937571F22425A565A4B404B3C
4B266634314F3E424F235A6D8D72344E455C45736251611A394939594E2F5372687C4235
5041673C71614F3D726D276F6B352C55386C51795A5C4F4268302F324456543AB4543C7A
4A614D80784B724B41545860573A5C813857384F4C325552535A736A4167418C4B56792D
5F6D627841695D4A5B38403E3B4B334A458D485072585D4F55575987
538180964F4A679B92B4534B726A4F784B38647C5E75892A56865A3D6D384998631E343C
2E498E7F293345506195402656494377721626433567B32A2D3F6344754F232B55594769
5419346A77375E2D1B45623A265D1E215D8539264E2A3C63672A2F4B3F49786516184546
54772B2C475D53857D1D1B4F4944B451413D5C87487D523B3B7A7A486C5F17366E5B2D6D
32195398312E74573E6F811F295B3A418E6426356F5D6F972D3946673D75781D3560785E
806C272F5F7344653B1D5E8B5931823F2D4774613073322E5F51354D334387671F515C40
6AB63628776392B2592232667C9F5E3153696581A42F5974674C68224391723B56312F5C
8629594D2A5D705734564B47566F49395D3E508D722A2E41617186802520405C4F725617
4B5F5B509C7C1A446369538D3317436B5563A449253961594385262D3F4E3726737B6F53
6E5B4D672348552E5081745385956246445B4F3930525D5D434E3B40415854423A4E5866
70555B3E2F2336384A545B42345E53384F4937362A4F4D544C33233F5355595652674E61
4C435C39384240823A384B41454A2E3F3B433F44413C46452A314A444B3542404B505953
5A5F534C5A5E5B5A534C545A784979678270404B4B665146495E474C8CA0872F4971879D
99A77F6A5B39395B4D4B2A3B2A37414B50645D445653563A45572C30424D537A5154583B
5225813429402C4243415E544E544A5954635C877965900F3A53417A633B927E48512F3E
6649533C7B3B883C80794A727F1F2A5E214649785A604C4B5D3A344B5D4B453E512F51A2
478944786E273F4B3B603F3F6A55455F2A3737474B3B6E583B66396D53805A48564B8368
835E6D9E47B472464729403D2E3E3F573050415E535D87544F6F6B79
6E7048707A49603D55A35B3D4F3D3C7F56243D56316CA5421F5371518E2A334665768E54
313850715E6A6C293A70664D603B293F905147571D39636D2B6943247E832E2E4C292977
8618203E3388953A132C3F2F4DAC381F484551568C2D206D82576F7B1D2F6AAD72743D1F
46747D4F671C31598F4F3769221B526A232E4E323560612B3C414A39A07B292D605E609C
421E3A88653D86422C486C44808D372576C53B5C602F305D6F3B7A312C4962463C7E1D44
6C742A2F3E54629E441D2E5C8663AA4F1C4F45765AAA2C2D6B605D803E194D6E2C685226
3D7A484A9E32296FAE4F5F2D3A7A7C3D59672163A7534273333F954E2B4D4E566E4A263E
4F49AC9E2D456F6569A1712C40695874B35C384D633E59652D31567A6852814054707231
4D67253C6EB46C606329388F64303D56273D5B5F1C32442759A73F194245375A635E6049
3F34524C305F693C7383B975615A5A6A55683838364A586137534C555C56354A4E738070
80626B553929536165425B52303553212D5E3A4513263D3A283830433B3D2C3640452F47
55486D4947616083473D3E3B3B3C343C30382C3C3B35462A2B4A40304C4139384A2D4436
413B4455473F5E6E53585A516A476365807159523658564646615860778C83524F628484
4F2D5E74559048714E683B48343353555A314A355C434C2E4A561A3D4F44304E47484D34
50195B2C2749293A442837535F6A314C405145726346592A3F584D71752354516C9A231B
4E2E61365B3F641C8E741D4E4F1A2A5E286A58623F5345394330292B4A51444A92632752
5D714C565A3E63402A37392B4731455736502C59603E6A5435653C462B55477F5F559342
56313C67435A66434C2C4238273A284636533545564C524053746170
9995554F6B8AAC3445796B73AE4B496F984F6B5C444361605D5F2D464D364F74352E5AA5
2F3756382E5550232D4B335068432D37415370631934423056A659143A49466A862C3735
64557BA71F2C4A663A67511A2E466F225B5E2E4456622E6229304A6B2719532F33855717
19304A44733516446167809C2717336C5673791737535B44527B1E2D67773F5876154A91
6B2C5023385272394145283E5EA7401D5796417CAB3543444567B14419536D4B68C25623
508F665A6C34415B7A49533B2B4C84944663562C4E846E354E2C548D8241444A338D7720
2D572B6DBE4927475A5994531C456E4573661D418947778D2021607E58A8242D48594C5E
463A397C4A46643B386FBF5B7B783A36789B4E524835896C63505B52214C893B315C563A
75B53129433A3795BA29394554677E8215202848354B671E1B565328555921245B6E4730
4E4B72511A6E7E3047535E4A6267513F4852352D2A4145554A4C4C3F42493E46584E695D
4758634937383E4B5A706D4F325D722B3C6960622228453D31423646444448443E4F495A
45335B6F6B392F4A404435303B424B452D4B392B474D492829443B39524D3E39514F5849
53694D435455443C403A376E666A7B56694642452F5B49333B47413451846F4268688190
875D646050934C794968434343514B473E5D645A663C515062775034405A4A654D3C4E40
551E623538721436411F494D3F57394B45544A724C4A58193446313448336E4D433E2337
78275420622A482957583B8C8A341B4E194253795052594D4D3F483E536F763C63765386
5A5E466E5F25353B19412A2B6253647449472841453F765362753751515A38524230615D
833F5875378170565630463C3F4E384A547D564C894F584E59645364
5A8E5F794947878A6A8C42536C4A3F663D60A55E2F41573A6E992A3E5031498F2D2C3257
4E618023223688546C7920385067585C3120445038496B2124446E2B4639203B51461E4D
261847A24B215129316B7E2A2250482E889B2733574945B77E1439754554A54A1C276C3B
626E112B514C22706B153360623162352170B550193F482A66A12F1B33664569B328226C
747B9A2E263C816871A92A3B586F53467D3B2657946E565F1B2F68973655692051426149
5B423153562A2F66404BB2751E3F54435DC5AA2035704D5E88251C495C5184351E46A460
797E29525657496C33486064355B4523649D3B5C423249905F444F2D328162234D337A76
5E2151585195A12E3546795EA29E343C346062A29029385B6055756D32265E764361463E
384F6542922A2742613B4865262281A253295330277BA0473446302F7A9A2E2E76774B26
535753501B58532F666E79678E8C61494D6B332B2132447331512E554852304E4B658763
725566432821384C65273F48393F43273E4A38461E313E4F4B2F20577764484B5A583C57
51496C4146544F6B343E4D6C5D4A354D2736253D3D2B3D3736464C4B513A39464B394C5C
533D48584F514B4F4D5E43353D464F4B584E7F5B224D46403637476A648A6D3B575A7BA3
8C5E765A49934B78677648452836364D6E5B5E37473F46353C67293F4A5A438C71484740
612A62292B451B3E483E5D59407F3D4F4A514C74654F6623364E495F7241928055611F2A
483D5E41742E5F34695F1D4A4830185D38485875544D403F43293C40444A4C3E99BB4687
7071436F5D3C524E3D513D5560497B80395023484D3E614B3C3E5252415A58604D248B36
592D4A71439554454E5455372E4A464B3B5B4B376552574C5A685D73
5565929153456F80A7B42F4A6C5682C065226A7A58906D322F748B658C273A5166477D38
3F42554F39592D38507E443A5633457C72233D404866993220353C578B621E374B445E92
35233374536890241B495B3E52B430224153574F601A2F437E463043211B547F383A4113
47954914343F3A6D8C321757673B9C6B2636599658845240486C573F603E294B73784F65
254696941B484D2D2A7C691D425E4864917925395B4E808F1B26407A557E9F1F4D574B51
AC9017477E574F85561D4E9F4A8D9639265CB34C7074382B7D724248253351732F513832
76763B576B2C4C9E7E2F45614D85691F474F479A84283F4D506C902A2D4C714864254872
503A81673164A28D4182334672AE5A677B3E4778AB502F56333A80C05D2D4C4359A5882D
394A3367C2752A2E4E4359AD302E2F706948B0333A5065463B5D22364C4D4B3F5E714E26
4344685F28618B3A3364AA8D6E49556E5955444C4741486A495F3F607A61484D64454F4F
5461704A3333575B643B5A673B405C445556323B12343B292031233D303B353822313F46
452F5143463A3054303C4D1D1B312D35282E2633342E3E29293C36333B443B26563F442D
4544423C364A484E464A5148525C69314A4C3C44254D3135404841384B7A6A374E525469
7788736B5B7B494F4359575C323B3F4E4466595249393A3B5B642F4A56513858535F5942
6B2E6623254C18534D2C5359445F3B4B3B4A5E9A7743853653835F676E4354655C833D29
4C346738503351449E9F2B5F591B2573273F4B674953443D4E372E384B55524696E98F7E
5A70458166344F4C5253514566485A6121332E5355404A5A5D57546C6B786A696D658C51
834D7A925A965F48412E42564D55496B62785A5A70537B5668876466
9E744E6E655C813B75B5735D85483B838C3C683D2744713545552F7FA0332D5C3F36844D
1C34343746803E2C407B56698433375C60558254244F67503D71461D2E5D333E4F223C59
771C4756292C81642C364038449377223D31395D9F4922493F60669321323F6157907225
2E3C653C611F27446A7440852520596528305E2A404A561D2F6F3040A989253C474A5DAA
2D253A5D38878A29354A764F9F9E2B376B7A5590533A46857F699C1B3245774F3459262F
5F9E424554303D5C632351561D57A0441F42434BB6C4392B434479B23529444F54A66918
46763E7C782522797E455A1E3550743A89321F4764493C4D25316B50336B2C659A403258
48316D8824306F7155C5443548816D92C83E39547F7C7A832F3448849C70821F3E7E7759
77791C498B754B7B6D313E7B50203E4827265D731B343536595C49213A4C226057836B44
70904D422F525E3439606F65735E4F49515C2D313A28485D4949384B5357314558675F53
53475C4C36363431414C53403A615729315B5148111D484837493844454A465A424A585B
51346A5D614D41755855523334524B45334E3A34464849223245494849393E3846454453
52665641594F443841483C705C607F4A71514B35273C313441373B58427B7347536E648F
72526745477D6A696956324534352C38347E5A3654405B2F3448262C4548419B65414B57
762E8444396B2C3F452746643758253E3A3F525461468520284453628E546D7353951D39
4F41744B5D38675544542963611E0E572B52688C3F455A4C3A3F453C4E7C6D85CA7F778B
767F485156344C6738535D35422F6A5F1C4C31575E60524D444A33402C4840706A2D9B59
7A4C5B5D4083615C613D412C635D28534C73464D8E535A526A685D8A
7EAC495E666BBC5F49695891B24445475762BF6A2244454B94B4252C7D6D67B9403D405A
3F695D233D3F474A5943193A6D474769332B7662233649444E6F52183641496896213153
68458C6E2332315C4E925F1927465C408E8F1B36829133743121547A7A4C6F241E447256
40612A49493D1A344146519B251F37555B88742D1F5470436A793D1765A9486256414E85
927199362762C859576A2E2A5F8C3D2C4C373478913C4262594395472554564667BA3E2F
4D4C5364A81E374D8B5A846F292F6767559B742A2E774C43702C2C65963F5A1C297A8240
4143294F804C306B5362AD3D23444B6ABF601E45483F64791B3F484D63A9272D6F695174
34436D775F519636528B8E3D464D2E3954743274892F4385592D5543216EB16C394D542E
7DA24C38474C47929E2D2B3A57449D9E1B2833724E7B7A182E473B2D5B5C2F3F69543727
3E4E7C5528676B313F728578836D76655F764D35373E4E6E4460396058592D526F667D6D
72656E4F3C41383E5D2D454A2B3B5E3D35622D5323233F3E383118494C42283B514F3643
534C552B2A4C535424324E574239273D442C2B483427372B2D2E3B473F2C34474E33444D
3E33394D4C53545E616F523E42515A2E4A457E67314B56473A445C7458817B4A5B65596F
5A5D5C4B7954394F46625061293430573B3D4537576A4B3B41601F375F4E2D5E414E483A
58249220254C28484D435C563F593C524F49556F8439871B324F41618332696B3F75193D
6A2355317B2C56386B6A2D657345317737354F5B3B473C45452D33334751504687C2DB91
6A4B4E85612D54754C445F5B53467E5F374D478C8C73866140505556317552775243825C
753A56765282464C5733453848552D604E704D485E4F695566716375
5CA16A824E559579AE7F3A406767505B293A6FA74C5934293A826C3B3F26365D58376045
2971A53C203D484C767A1F1F4E58689E4132364C495C81124261554E6F3D3038785A2C4E
271E5074523F691F31536E4939462C305C7C2B2142356889461D302C3C92AF251D434541
5FA12628674F32765E1A3673454E793E1956A2503A4B411F4E9C501F574E555B56283354
2849A7611A2E5B52609E4416447A514D8A312143716780682A52528A52AA6732494D5A49
673C22517064498A2A2B456C3A5D5F2E33567A3251484B5085412F4C576687321B504B58
9B8C2B3D9B6F598C6D2667743E6B3E2F7DAB3B7C5C2D599443535E3246907E2D5D304F7B
5B2D6C4C3D78983531495E7598A2333B3D6B7299953C3B44615B9B5F31576F494973502C
6B8431546133355686576B5D313652955841581D153B6F30305A2D2F5E8C655F54764530
495A79662F5F6C3C6F7A8D7087944C59545843383B3D3F503A5B48625562405A724D767B
5B666B53363E4949653752503D37664C5161294021364F41393A1C5643523A4145604354
6A367840403F2C64323D4A23384B2F49353C223A3D254F1F212A4351483E453257575A52
554052404F46464A462F3F5D686F764B6E4930485360393A4853504958706949627078A8
816878414A834E7B5D57555C394544213155544952426C677D7820254D4B2F673C4E523D
58225A1A1D4D154A671F3953374F32604232587D714775363B6050517055AE7E58B13531
4A2F722B582D63338D7F2B45441F145530385772556352576844474469595D1E54E0E489
63504A6D7B2632533B3F59727F519099505F6D50544A3B445E4D3B5735522A573B43915C
6329849D508063545E35424C53513C77627159536D68964F5C825579
695A7D914947554692AF383C515E5D7B2C25526D5E865514457D77718F1A18526E6B8F34
464C645751611B3255945F544C2E37515F455E3D364E7258333E2D488B432531373A61A5
2918414B575B962D13587A64829B2A1B3E64715F811B214D715B8F4516265C65347A3E27
2D5F47275E29266778292A493F3D8D4D171F5B835790541D2A53A345A9521C3D474B4B57
192D4F4D425C521B2F6C813B7C44234C6B6B364A222591B2402E532E4CA09E3636565150
874A1432666D7ED258184966579E902D33648D4AA27532554E543454192D8C5B32655631
71B17A705D2D2D86904859304D644734513249A189273E5361AF831D46575F65B4332452
6143A9542C376F5466B2203764A57955632043687B604E552541889B3C365C2D3E8EA14B
5C674978782F2646523C98AB2A2D2E485C74A13A3A454F3D5A831F2A3E6D45C151734846
4B5577753361894C41656B5D7987506665623F29413D495E3F4D3A506055324A67646A6A
5A5A6D6543423D3D3F4754423754543D3A58424317244E3C3750415449544A4F46605759
5B3C6E594D4938753042552E486248493F4B3D38413E5525264141534E4A3E384B2C3C50
55605E4C59536060614554465A4B68506D52485559433E3D414C4D4350587C3554757E9F
8070825A8D6B4F5C7068434E303E2B3C335B5B6454434C3D4A4A293B4B4A35865D415554
7B39741F2F640F3D4719364D3E672E4B374D595F6C3D7C44497B55898C386F5737828379
4F455F4F69567234586225545A312558527E72704E57514C454947465F535C3F53468B89
626F5F8778354A55484A5B2F463AA18F454F4794895A684F3B4A63674E915265594F7356
5B286B7D4A8348606E4C5443514F3F6D5B745A5973516356596A5B84
9A644F83819281584E8F7A8E9D434B6E72548C3E3B64973F68692C4D6382285C34394D4C
162B4F3B415E341035384B6876233753395879731A5A55565E7E1623547A517B40334850
7B367651113B4B4A226719264C5844205929364A83492C6B4146A594232D3F3247A9581D
41585C45983517366A4D6E97142432684551721E3561702F4D7224365D77274D393575AE
482D575A548A9D25184D6938888B213A5C90679E313343666B73AD1D35545C4C737F1E34
4D8B3A57491E3A6B66419D2E1F60A369396E33487D733641593276BD632F604845A76924
2B666479982E4342616198242C693B4E7D301F567F48633B15517D39726F1B317E6B4860
272E5D672E5B4A335E9A4C1F454E54678F272A53545C669036224B70767E9E253D4A6358
AB92276380605C8A5E183E826536613C204587672A4F5E2C36764D2A433E233A71846D42
51665D5B2778613B5F6C685F7288454D4A55504044515364495B46503B61445B59607EA1
755A72653D3A4249673150574040593D3E642B401720403D343C1F434F44464A4B56414F
6641573F3D45437647565943483F28363C37283F2C2B462E27333855453F435A64375148
503E464B5C6068625A585654734A81567966505D6661563B4B5367644F758B464C655374
695A544D4A7E4465526A4E5B273331563F5A52393A5761464E4E283D586649593D5C6636
4A376D352E4D204A4E3163643B682C42372D565F6627502A2C523C496D438A7643ABA0B5
8E4B7051656B5D706E703B869D403652343750684C4F49384C3A392F4E536C284C575C60
474F4D70643A524B403B3F3C7337474A485D3F40502D485349563D3D2742497A3053775A
732E628160A76F9F6C404538663E476B5473725873769C6764815F7E
64964B8F51559052585E3B52913841491E79C65E33304B4E82791F3B4C6A65AF35314560
4B768F1D3D615C6D8A4923509651505F28295B904F7B6E1D33594D2F4A2336516421234E
3B337789312851504FB15010264F4E50883E19284B5C53AC522B2B894D849117212A5C3A
5C4B0E282757274A342B485A31274933606C922B1E436177758E31284283647B79183655
64929E343D406F778E872F3C447741537027447D833177352547976A31693F3D50A9422B
4E3F2F85902627474640B35E19275B7A6AB34025518D67865A2D3068A465B44030336845
463F3241664D43532256595327502B4CBA712C414A38907A2321493891A11A404E4F5EB8
4F25646B55B3823034577960716D3443596E42856C384C765B466744285F6C6B376A5432
5A8C3337432E30859D413F3D4180795A151E334B559888213D473D4E8B6C1F414461352E
3F4B7686366A6A3C3E69716890923951467143263D2D455544614C4C4A543E565D5E575E
626671522A2E545B4E384C4B483B5D50415A2A44182F4F3C2F4B2F4A4544434B41646060
76367D473F443C5A33414D2D3844313E31473931344152232D50304349553B334A4C5139
545053404E47566748604C557A86B4728361746D3D6C61524B4D3937487C8F5961786AA1
83636A6D64936D8A6977756E373A3647428555493D3F714D4C5528233D6A2E7757435634
673A5F18254C244A52333646426B4E52463969607D224E30294F4366752BC1923F8D5367
8058743A91426C4A656813483C1F0D512631547C595D5A586D3B40435680811B512C1951
35504D656022485B4D454A3F52407C60204026435844614E444D374841595D735C97B082
8A41A39F4D603C4C584F6E49393B426457504F494B46625D5F8E5B65
60877CAC5242715FBA933F577366867B3D3968834C5F2F19565D3E51A7372A6771436226
232E6D41274C1A2781771C283A2C97B9552C334D6DA15B1C393C59539B3F144D8362718B
362653664844711A3059664154501A3A587D373E3D1C3165682F3A232D497D451F492031
A8AF2B263451428F7D17415B4D69B3441D3F62884181391D536C463D8E202C667F364745
13367565294F311F55A4622F573F3772963121396079AB6424405F5E64B3572430545A5E
8F323344593A788F2423628443804E263D68783F754A2D79A94E3D51323F9C4D27543C66
79872D474C4A86B73E3A5C5A6A913A3A4771579B392C4765557467194270385172374471
6946852B2B707D3A4E5B363D7FA3454B5343418EA43B3955585E96791F29406468874926
3F48478484242A7187356E60232D6F7E365D45281B52963A365B1D37476D394452877457
40484B472F7F6651406F7162968055564A724641463A3961446E485A4B723E6473717873
6E728E72554445506A4D5750453751493B4E36432536492E2F472934464C505E444C665D
613D864C4A44306549554831364C36343A3D3A3131334C203A31223F3B373E33592D4641
4E66454E62695C53564B504D585366788C616B662F4D55524546448555727D44717461A7
959383697A774B5E7A6E515F424846563F755C6B504262434B531F374C92487C5B4D5D3D
553A8933274B2C4549373B503F5732343947575B6D3A4B37346B5356662551492B8087AD
B69A7E3B694A9452847E1A5D62241371355A565F4D555F4A40384A36465C5A2C6A5B1D58
3F6C4D7B6E3E664B40455C4E5B327259367929555E385A314455484B346F2F683E555852
493D6C8A5AA546514C384C3D4B343F4D5E635A595154745448644D6A
7D4A5F7A7E5F74475B6D4D6F6529559A5736503C6FBC7A305B644672BA36272F4E457D4C
314A4E47738C2A251A5B46604E1232493C3D6B2F156F67263D3A1C3E495D2255632A3877
44214235323A692A1F3D2E2E61731D173874756B5F19254B5B74AC3C1439747445821B13
305F52525F191F487E40495712286061245760374A7949285D4A2D5FB775134168306280
193A505C5AA0571632586A40A9352234714C5A651825617E4C8B5A283673882A3B523951
78621555473157A34C204C3671C1932D2D50427DBA8A2C305A618A8E2836554843773637
5786596048336DB06B56683B526B4A36593336657826414026629F453657334F8C362D55
575FAF56295B6949659E292B69934E9176353B578A747379245349603D435E2139898E31
5E383C598F602F4C464D7D843A344444336E9329182959437B80222D534544644E783F27
304674612D896846416B7E67806D305D536E3E1F37293D594960375C6E6B344950686A73
8079805F484044454F3748544151654A366146632B224D434545295A5F5451484B4E4149
67535F5B3E3C314E2C385E494C5125333C3725293537591D3C4C22484F3E463B65315440
5D495534403E504D556658497258A88C8F5A3E6C27463C2E484C464D4578815053686982
604E5F6466703F614F6A6E6B25315A744C915546393F645C505F283A4D9847704D4C5649
65357B26305913474C323A50307C363B47365C4E64476C36273743727F32654428976781
AF8760455C435841595F19778A2B154B3B3D465E4F4D4F3F4833432D49536C273D341E5B
42434B5F51314B6B45394A386E3768471B3E2667646B834C50425C5D265033621F786D7D
72317F774D795778593C502B4518333F605C5E47517E946B517B5E6E
A0604C625E79963861875AB9873F3558606A9F393865723F786526569F6C5D74274F4C75
2A4B5E2F2D778427642C2D727D313D511F4F9D5F18474E35609B22305F5D3770542A2F54
4B46A365183B3A375B5B1B2B3A522F32450A2F5462336B58182C4261282F2F2156794319
312A225C9235122E43487A80181C365438899B1B1752822E8F712C1F3C79426547324E72
565F6D462B6490513B6935327E5F243D434E7CA334264A5A5392AE253B4B5E457F801522
477846BD4E1446816453994C17367F625A8026294D8A5063491A3C786C49631743A35739
404152918E313368646886253D726C8A8B2538514F5C846817367649687D1E355A474B57
193B4D643E5D5735625942335D4D395C78442E5C404C58673726614C557E751C2F4A6263
9E70295272556FA02C29648B595E7C39234B927156545521389B652A6250273D5B966430
3B47806841898649526470626B7A3E454A53572D3C2F2D52494B4454596750686558768D
7D9D97644C4E55586F4653584C384D3F4C602C4C182E544635432F4D393B4A453F4E474E
642C5344444D486C373E4B232B472F2D2C3F37393332493D334C364346453F485C3C4D4A
5A4951524D535C4F6040504B6E616B788F87A9F8473C513F3C3D595F4C7B7B5B5678788A
70588A7E586C65755F60345F2C3D4A42325458484E5962568177223C62835DB4695D533C
61536A17304833484F3A62643C6E3D38383B5A3D69235547324B4F4A5F2E6A4D22615242
6B8A632C6A375F4B5B6523524F30175146334C545556483B5640443E655C6E464C46216F
444E34695F2B494C4756484158457F5C354933694B292F213135464946604D90276C514A
4C2181665A9645524B5473394A2A4B4C8178647A5C515F4E4C875583
6C84528D4949745A5455385B8643344421387D6F1D3F45385772232B443383A228214B5A
5089732F3C4C4A5A9937305047356E8F1F2A585F4B77362E426449477E312E537A344A8A
3738596734404529436A3319323E25558643133B3B33A3A81A2C463A306F78172E4D5827
603D2537316B41723215414F223148281C5B86352C513C4064671E315A41459298313352
4B5E7946263D71846C9229385E6C5099713A44667E74B0383A53807355A95A3A4E743836
5329267D842C47443B39886C374540467394312E374F549852184C464A77BA1C1F4D4655
62383172804C585521506F663C71283F81773F71392D6F9A3834403C4D89254B4B3577A1
4038587059AC8E2643645A51AA79363F626F52B1553348544F4C9C5B235E603855A83A3D
8F983E49522C42736C2F444822398D6021384B403C6F681B243C4E497F7820365B73623D
5C687461394E5A483E547073696E3C5956673F385439385948503F4E725B374B655F6177
769F965A3D4B414044585F4E4656643834554562353454574F663F56444C51533E4B6564
663E7A5047543061524D553B3F572C353943263334395824534E304C5E444C4348424543
515E4F3A4B575E5D494748496A4F877096B5CCD64F465F4A474A6B6E75927F514A5E6992
848E8C5D675C32707578435F394949584B8C647D633D473E45481B32507747624B46514C
6930591C3F542B4D533333493160335343375D455C1A5B301F4A45556E3A5D4B215D3C41
A33D66386B577D625E6A2A5257483152524851594C54473A4A3A46397052604979713763
4957406866356C4C374A5D3E5E45914831512D627352563148315C55393F2C5F365F4372
653CA5737FB754765D3F503C4A4038415754514E586465634970516E
695D539D5D486270A097375D5A6889A72A4F566F609E33293159508491183E5F67757556
1E3B6A3F5D662F1B4F6D23523E2A727F36315D302684621C383F3E4F914A1939434A6792
522348373D75721C236464637D3C114052573B572B2046636D2F74262F2F503937662349
8D561524402F358E7A253A4D455F67221E455D3A6799362A4D6F4F56C1391D5B7A424C2E
293A6D69405D1E3169AE6B235A2E4156642F47513234825D1F5F432B6DC2672D4B50538B
9638145078569D802E2D45677196442D4B976D6B60362F5F9749715C2F4BB474485F453E
A28A23447F5C8E86292D4E4D6CA63B36494064B35C1C3F717B6A791C325C3F727E333A62
485E6D2C4355673F6A512A474B64434C47364673693B4F4E3B457A862E5A5E3362C4B537
446757726125364A5340715A251D4C8C316A60204D716E2148652C3D467624444C776C46
3E3B58593C64714B668061727F8E3F42457A5E25352B3E52485D42604C71434B845F7F72
ADAD94674251404774354F53484E54333A6338511927504F49461F3E4C554A4955563C44
524F71635A5D50703F3C623F4345313F393C35432D374538333C2F4B36414F496741534E
5A3D45565954524A57555A4979548A7886B2D0B46764694E3F465C7C5FA9927A6F90716A
495571707F703E4F3D5B4C51213B595B794B3B3A3E3A547E7A6B0B3458755EB865504A43
5B405B1B374D1843473A60593B60354932364A3A572C5051427B595A7C355D5647584752
3D30623E50485E5D5F681861645D28534F7A597B3F4455474A3F513258606D424A5E3A6A
69655664553A5E4F3B3E4C3E6443895336513F7E55638940412F414C425162A550784D95
752D7F5852875553665B6B4C4032404160755E6B53636B4F477F5571
B15D4D9A886E7339789B57837B324C8D834660365A706B395E4940569E4F43551D3E9262
33353E396B85372943525E834417225B3F6AA5411D2F513C838C1529346D47714E101C58
5F3B75361C246936364D10459660342A613A2D7A751734423D449040184956415A9F121B
485F3D455B253849674A69202B46674337845627284C4F315C3325487188394F4A518F54
182345535197422945507265972A44575D36677B353F44513D93732D2A5F6D5258772137
90802C56243B61724338541E39868E2944513398A74D27473A64CF99353051587B973925
58997772405553A47668651B3788705A6D21306F9F52694028687B434E42206FA93D3E4C
3148A25F2E5A51578BA02E37644B5D75A9273A59657C999B293C3F69438E5D26356A9173
84611E528F544468283751653C49622F2D3D7940235A5A444E6F2723392F375A6E725035
4D5571564877664541618CA69B593D544A68493138554D4C396D67644C6C6B6D89619AB9
A08D8E862642616B73435660565055254178355D192B645D4E5C2C5C3B40544D56544854
643368493F59356842417A3B4266334438442E2D2F345B2D2940244B3D3944364B3B4633
493C4B40494B4C524841464F696B875D7F94204A60624B3F495559687FA8885A63778CB5
7B637174656F4A724E5D5D6B343E4C645F84644956555E323F512A475E4E45605A525E55
7C5965383E533552583F374933413B422D2346566F1E4D352B5E50609242525C386E5346
401E5445967058566F7D2C5A603E20605A4F405840544344543F3D385A5D7B365374316A
4651455F5934456A3F4556385D457E56314A1B4F46445333535A4A4F3A403F573B6E7066
5B40D197889F53523E2F434D692A3F3C8C5B807B556E736658A2497D
746A4962565E8F3B41564CA99F34315E4C88B75028747372915B3A4C8F74A590221C4B90
7C924428314F6853AB191B5460275A541F38787349732537435F3A2959293A9795272C39
365CB0982227474758892C152754464F811F1B286A3B7A58142A585A28373F1A365B3327
49342B448B211E4E343A6E3C112A423E4DA0A11930344354B29A152C515E4AA28B1A525B
4667631D4B696A255472254677572143611E5DA04B314E272D96731C2B594B609674202C
5E6753A15A2A506E70645B2A17365D46748519314F60505F35195C7B4648581627967635
4F293E675520455048626C32395F455D962C203B46549E6E1C374A539A6D1C37424D7668
1B2E41686197423661774F5B8B4E2755724D67802F275F6A45386C44306A743B545C3243
99842B3A303D7F96422D4C474978BD49293C4A6551962D2B443D41546D272135507B8A5D
3C3C5C6743617D557D8A73608BB7414E5267552A46343C5E49444058575A415282534E57
568D7F3D3A453F46504F604E4B4F5C4E7F61446241677559577B5B5A465F6C71635E8470
5544746F5870467F5A497841466C37443A60523D4D6F68454460324546514A3E50645A46
52604B566C6155455347544161486D686F58364D4C55544138455F6980607C697D8CADC5
598D9B799F61596B53623E532A4B3B4B5F8349564B2A4C4248531B4B676F5B764F545A58
603850294A512A414A3F46634C5736403327422D4E1A302A1E57424367227A60223E3329
2C194F2A59435B5896A82E6064352E6366955566454C4B3B3C3B382E4F4E633E75824AA6
49523C817A3B5E472A2757395246895645523F5C465F71464E244D4A53484F5822553C83
7E5D704745765C885C404840483E394A565B587C4C5960685F5F5C8D
627F5F8545509B626C5E4E4D916D693A3D30648B3A681B2B556F305D671D5D8D62486938
2F566F2A2B3734538A5F2044523D70A42A3054635E8F5D174B4F5479A73D182765506E71
1739577940583D193752573C6319213B6D522C7624196B862925404C4D7669132052393E
80332944674D5E843B34385A2F59611E29575A3A4864172E5271382C52252860AD313342
1A3392661E3F5647627B2F1B475F51543C1D434F4C4E902123749F24335B2F275B8A3B35
6D3E3D4A664C545E25609C5A37624D32569A463A5B235EAB943A3855457EAF2E174B7144
7A403155566370681C4D704E597D1D3F7B47485A2120418834683738476D2A593B1B5FAD
4E36632875B57B344C493C64AF85424B534999B846243C4C5C7BB04C2257573980A23C3A
6392557A491B287B8C2B4A3721266382424C531B498D782640422746A59928375E624843
4C53684F35705C46435D7B80845F31463F5F481D3443594E4159584D44465B6F55458BA4
7F787866353962675D33464E4E4B56323E58424F1A2D3C4F5D381F3C5863535367755057
5E41614B45503D666F55544041573A362F3D2A2725264C36213F17474E384D3A632E4A46
5938474F4D434C4A5A72614978547D7161946897676F695F434C728C7D8B86668A98968C
636F4F617E563B624A6D434D2F3D43497873443943485B5F6081322938526B9E55434A55
605667263D4C1D3D503C4858324847494B213E3A4D2D3432164038435B2B816B1C513C29
5933654186596A5D5D6C256E6E372D51475A497C4A51614F4F4B4D3E5D6171344550264A
49764A5C4A29416D3D244323643B984E31492B664D6E733F47305B40394346532B66465B
571C7F5850704F525F46543E51203B3B6548605657615D5348664F69
6B4D4F9E5A4F66497B8D384A4E51A3662E24584C64C22D2431624A8E8F2B21435972C142
444A545F7E891A46656F57A850293B56546C9E252749733E783D1D2C795A284924184283
3A193850386C4C141C403462AC30172A635245BE402A1F5752549B122B2D78526485141B
375923727015145A42184F1D24437C351A554B357293311B4542426C7C17163B66577C73
18275D6F755E3D3349545A55642A3353561C3843365A966A274451336BA6451937523A63
7D3B245A4341ABA8272C5E5D4FA063264D7C4F74813B203E86505A6344425F695A684042
6D56305B372B6D9D653E5A33468C49374E39779D3E19364E3BAA61204E554B80561D4377
62628D25395C865C717547515C64576D612B3B586639523F224E7C63476D401F5B89542D
6337306A822F233D3E546A5120203E48528C7B1D1F53823D8669262F47734D705078562A
3635707C4A5D54545077A4A298693D5F5D694B2D453741573D5C4C814C5B424F713B6D5C
7EA894792E29333A563B4E514E4757395D653959286C73524970595B4552727E4B506A5A
5B516A4B476A566D46367455556030373A5036402D3B503D264A2052553D4B4C574A553F
505D4D5555525D4E5C3F4D41606A6E5E575C475B575C523A4248674C73867F79C3C4E5DA
70D08F80976854794A684C6531403E667D6D454B6D4450394F5C1951645852674A66635A
676886233F4C2F3A4B3249573A564A623D274D51513E3B261E56364B691E505A2D76201B
3E1B4A3656444A4F6F791C637B3A2F656A66515F5A5C423A563E33335A515F5773673283
363F335E5C2B4C524C574E5450457E31364C1E74707E893377344B4B7B687B7F3F8F4364
4D33B565517B54594B485132541D5053A15D6A6466766C535A744C5D
AC4E4D5C71748242637C52974D3A76954A4D77523D779861692D234B6F49625C232D5882
414A481C63A95D283835316E5E19322E21529F461C324C4B9C872A3554465691391F2257
6D53893828396C5E5E5D1A255363355B64242E5F602736391832793D2D4336354F9A271A
2F32257291231D274A6A803314265052558969153294735A613B233D7E662453251F6786
2D2F3B2537846F1F3E3A4B6BB65F2557552D597013317E7A69873D404966684B89422929
65714C894C2D469C5E455D1C255B80314B4C323898652B455331838A2B44463176D1802C
665646915A2831745C535C275359525E6C1B456B78406E431A527F3C4A372F5A79374A5E
41425F4747603A45998D354946374E83672346624757A1A8242964574CBC65223A6D8852
B66B205572444572292F56572F4478382E418652264719304B5E3622453731595381924C
373C4F44286C84534F5E626AA166554E4788471E39384351435149626B684755776C787E
738799894C3E3E4A66576A645F68722A3A5B5558212D506267492B4C4B5667584B554C4E
46395F67594A2C546A585E352755462F284D42243B5452342750273C4139372E453B3F3F
463C3A38485446475050574E6D487A70577E73A050546C6A49526468879FB2805F7DD2D2
5E4C46567B6246534856465E393E2A418476666D59445051465C23384557688B4A4A4750
623D622950573950583A3F5C4C6839414F2B412859223555335D462B48165D7925511F25
48335B49605A5C558791366B645A456F4C82576B525A56485349484269556D4452613F68
5168448581525E4E424860375741524449482F4C3B715535421C483E4D33484D43703B77
5B376F4D63A248594C4B5D5E914A4933605E5D876C635069555D597B
776E56793F56A756564D418E9A4E516B4D5B5E3D2F644D85A7361B3B593D4E8C34284D63
727539261D52577D6F141E4D7C4287601C1B475E4A9120295A5B4A428A292561542F313C
2724484E25542F227A7F231D37353166791E173D4E467576202C44826180472F3B57544D
5F1B222255402F60172E41521D314B2B315C671E33333C6E7E4B1226384C51A3550F275D
47726C31294A6457835B153E3C8859835F29494D374E6A2147656A294A944E38AA95263B
5A293DB063253149666BAC2C314676667B6D2332376D5D7F472F2F5D4D9995222052834C
6E3527346136443226435B383B4C2958A44E394B4434817C2E2F394E8A4925453A429DA2
2F59584581A85B3055624D7377353593AE4A796F372F4271655C8D382958862D4049273B
6B753F5651254B8F481F473E1E4A9F472F4445426DB12530315D422A842B4E4B4E85571C
36487A572A465F7247697F81AB8447594F8A69314F5644614D6D448754654B4E7A5D9189
9B967D74313A35436B36464D4A4262343E633D562D3B5844444C3652616B6664696C4D57
64545035335C606A4C25623A3F5430403F4A373B2E2A4745254C384B4E3F494D583D4A51
52494F5B4D444E485C6A513D4B597F4D406248704C4E543D3F3F63616B7D7185D2B2E9DD
758081729D5F5365505B6F61292D4A6B675B4A404B3E477D838C3C44553A7DC46D494439
50496C2E45432937472D5157467521452738492E5D464A3D2145394861523F6144726920
4128513E685A47576064296475462D434A6168844D4A664F4A5146385C808C5153513665
3E4C3C61583553955D554A3958548C2936461B53365E58354D2258404F4158596FA03780
723582435F7E779A714C4E27451A3D265E4A53564A614C6E64696069
5A7A689F434E8275AB75355AA37AB05A3942665D7CBE382266804E72752044644B4B6224
315C743457451B3F793F244B3F3E88913036314D56903C193F62526B9F411D50565169A4
262F33665784311924523E428E201E31584E3773191A33572D356F293754421131522153
8C2D1C333F385C7E221E41443B607D1F33556F496D9522385CA23B3A5E2639749B45493F
1E386C3C395F3A2D78A43E405E403083801E4761387F713E1F527D487AA8401E62A94B79
98232858B94E8A67194681842C9233366470393D4B2A3C7AA23F56362E89C4662F513D50
A7893A5C5068A4831D3956417F831F4E664B628F202E53774888311D55644D57241D4A8B
4A445E275A7163465856355D974225435B575E8F612559455D61B852363E4E4292A12E2E
646055B39E32366460487133224A49854246651E1D615F1F4E2B1C2C6A5225596D784E21
5D756C523C7C7A865A6695AA6951586B6461492F5C4B5F785877477F6E6D5C578E6890AE
A8B1AC8F3C43445377495A4F4E4F5D35556E4369303566554A682F653D4E48453D584B62
5D41714E44663D51433D605A65523A363D4033342B2D4C2C2E441D3B512D3D305A494B40
5645543E3D4F56635A4762567A4164715D9B60935A5F6C515345725891AB887961708979
57B8B25F753C4B482D4C294B2441283773765A69675043362B411D4E502336623C514F53
6A31672037492332411C354846543E6729272C4D732B5B39293E484D6346356A4F567147
6844505B838E5A4D6B802A5C603348875454345048484E3C4B4038354E46573549413C6F
4F55408E99464757474F702F6430563F3A413C935F505C2756233F4160456648445F527D
6764CF5F6B7042485B4E56425C3A4B3E9B827A90585F3E614F585F76
A35665835B6B603C6F844F623F4E698D3A3C48293E7F4D39553B45697B3139555399BC32
292C49539F6F1B16333960A95015354D4080711D296D983778531F427BA541653B2D424D
522F4F1D414E5F1E35462E58793419343B444F805B0E354D45569F251F5F694B71851E19
646C3A6B2A2932856B3A49311F3254391C6830284A67382B4A334557602B1D38524E6766
191D5164609D2D3645574778C5302E5464447A81263D6564486D481D506B5E2447432955
A835254A46449EBA2E1B3B4A58B576274F6E527E83263E58B080925C1A4B556970844C2F
3D776DB258227AB662516C2F3E8040393C1D587350225D335E6A5C2042395CB657283C5C
4CA7B02D2F656A52AEA0304A56695F8B3C395261663F9C6A2E3C6668478D64263C755D3B
75272D5599644065274293662632562F3E9B922F285254387B6D1D1D7165487D46795035
3F3C7E6A46779C543650666BB36E634E4B924B2934373A574C4844548C7A464F76735060
537E8164414B413D4D6063453F666B3136474E5B3841605852704161425158584E5F6882
684777503F834273724175333D5C482F315043353B375E452D4C2E455A3745446655534F
6A586052534A604D5C4B504E563D576B646D517A3F474D3E4D46545297CEBE7D98778D9F
625C6751704E406B486C41573C5B2F4D959472484F384778575F214758477BBE47404167
643F4C2A4F4C263C40184A5B39601F403333404B86224C4010532944581E2C6D306A7322
3A1C552443464F60B68C285A5B4E43574F66548752587151484C4D43567B94605949438E
434D4B8A5F3C5D7A5B45523F44398F4042432D412350511F5036493B5F4956464B794C8C
53395A4E78823A503D44514E7C3D41365D4755A05E7B6A7D68634F5D
6877486259A887334562799345353E7E75A5732C404D65639D2F2A53BA777D4A3C4E5666
4B74321F74BA5041581E25547F274E2625406F38344631375B682121404F507742253946
536D982B2657824359423429716B2B6F862529697D295749172E587D3C67332F48742D20
4F1D518350152637265F902A1425433F52A558233753576B993F1534717250721D294065
693D532D345B59253A3E20468079335C342B5F8323253D4D52925D1F2D48836DA570203E
718761AE363948775A6B5814375A7E3947421E505C422E5D3947B488343D4A1E48B76730
442C3DAB932B3E5A6F7B8223324767818C2128616556B7213D634C4057212568A0578465
374D6345434A2C335E93554E6C3773B8962C41683F31688D283F4443689497313E3E4376
922D394A61576CBB454860734E4E9A4A4963663D39581F2B605A433C5922355C6498873F
444A6145375D68763E5D737CB97A514E558E541F49503D5E3C5A3B795F674550866E9A84
95B2A895564E504888486252464B64473C643C5D3E26444C4C4429406563383E5F533642
5D726D6654674D6365484E556346282D413B2C4C373C495237473D4634313F60462A3D5B
51304D7B6257525A7553664667384E807199708752566C4A513B6A4A7D836D53847BB8C5
7075A34DB04F3F43575D424431462D455961504C5E5855374C60153F461A6C7B3A46464C
674157385754343238262C40354432572724226A6C436F322663453C552B7785406B6F37
4E2C3E3D575D544D535A256680523C513D4A2752393D464342494E3A464C57434A3F596B
3B4B4D7766313952483965374E548334383819572942593B5926423D594266546E992B5D
554479355B6E678A503A463D57374644714C587E578C58835D5B8B98
5C7786A0435165599B64316068627C67314591504C4A332E8F733441303B556B34476750
4E7C2F183762715D6D171B357255996914394C546486232D52955F539523424A502E4C33
1B3E5466464B233C7655272947312460842F1E41424164411820315A5792521B2B485467
951C11565F384A6F141F4A582C4C4A1928598C334D5119415876233342224F8F49145B4A
2C668D242651644B91671231586860C63F1F3862536E5F2D4C628F405267253D597D3658
48304266721C483B4160833D224B665783811E48506755A2572069A94B88812C293F634A
7626275F985F67412F69833B51551F61874D4659253585651F4D32367D491C30384A6F7A
273E4B4F6A762F3A485D5C859F3B40689637678D3539598F598199282D4A89305F652F48
78723668442B2A717C226635213D5D391E4459435D78461F443A38599A381D4357975644
6F7870583E726174596F86A5794656515C64452D524D4C5F4B6246795B65594A885A808E
92B2A06C413B5A54784552594B4E5F26436839694C2969544971307C444F56445C564760
4D315C433E564B5253355E3233563B393E432E35323849382A4A2438573A493A5F385147
58495A3F3B3D53745145514D61408493AB9D6D67476C58474C455D6880ACB47D6A5E9998
48767852613733644E7A4C6134503F6671696F415F4D54525075277764146F8334674E51
594074273F431B58671B3E4739542F4532263A3D4B243E2917663551551D738D393B4512
2C143F173D454042929D3E41412A50834050405B3E4E534D694F534D555E74504A26588F
474C34A8822F4264676166547640754132331B742F5B5D2C5A3E6F405A5964545E694970
563A8B395E764A53494052545F3C756C8155607B4F6B495C6A695C58
7F5A69C0685452449A9B40554C5D68852E30466871B432373C6769833238615F5D9B801C
293C5468AE54314878503E8232275781353C2D1B41543F5F72433D4D795722463C4F705F
1735455755A1391533515179BF3134275167548B2028466C5054791C415D763E567A1440
6E5A1F3D361E59782F2B362F376F7A171232704F8C94263E4A50437F6C274546733C5C38
1F55754528642A444F6D395A841544875C27424E2368942D3349463E87A94028476347A2
A3292B5D8B59AE81224373716B9A4E224A8E40423C21386A7E2F41342D4E783E31603D38
714F3552396C975925554B41987B1F39704F4E8C362E4855559A41416D76446B2E2A5584
617A73274E4F3E588B5A25545B5839705337376B552A8240404C834424494543817C283F
4F574CAC87303943524A94951D225A8D5370882038525443753E1D235A664F7A81A55F43
48406861457B735534466178955A76514C9F4F2B353E4261544E46504C6B555574845A61
6F677C6A4C3D424154565348394E4E25394D38625240624C47753D7F48505E545B625C76
5D4B7C554A823F5E755A633F3D504526365347454332604C4150374A643F49446150564F
67636B5C5443574F54514B65563F5459596B6F735143503C453C40505EA99854A4618FB4
64ACA5587C50576782643D43444D263A708C5A514B47425A746620567D1F5975333F4444
6F3D7F253B4012233A1C3E454C631C48303C3B6760244746263B463B4535436B364E542D
46306622515A442E4C511E4647253540509258525B52504348444D373E627B6199674C65
3E4F3B6570507554463C5B474B518E422C39406747655A3C5C3D3A46585F87566F8E4B68
585D824C5F6E4A5B666C655751355168654F5963565B556648495B69
9E68526586BB724157A490BE3B485E95939F75344B574848772A3C5A73477E39274F714C
30461532576426334E305D81471F444F327F4E21294C3345928928406C6F4E7E2928619D
54505E28385E733145371C2659592351462E3C734D123E4A31588719274F3A307DA71F31
46513E754B1B4149385E63163638553C3464251751543E2E6938155BAC422A511D2D7C9D
262E5145549623274A7B5B679F2B21433D2F5A4636376D5D5984243236646F52AD334844
68643A59353659792F374F2A36785B2234634E927E253053545FBD611E39645460A34539
53585F7F312C736A369A6917449F5C3C44253B505B4D5D2D37867739462453805A2E6338
3294AB30384D3464C9AA243F494D5EBD9727444D644AA38C2F584E58438856455567545F
5E1F4358794D549B2F2E5B73455872313B557E4D384F2F5C68722A4030484B874B617055
5C696654417166713C598070B7625D5648815D29405C696E425B447E4A5655467471948A
A8979888574754498141474C444B50353D5D407353255052525D46585956484B4F524352
4F485C55506649595B3351443C4637274144364636354B3D314633454938414E4E2D415C
534B516155596B5A67535F4F6A3A5F999296777A6C4F673D5B4266506689873D4C5AD4C6
5660655B9E363B4A4D6134532246243E676D58354E75754934552946511B5A7D35504954
7D3A83424B512339502F46433A511A3D2330225A574BA84B243645807F3F596A59847028
391D38274C5750405D713F546957303023521E4C4946614B4D505E4E5B657D515A2D5A72
53A3576E612E356A5E48512F634C834A663D3E7049979D45685E493C644E5D416A948987
716B86669EAE595F3234464152315A56756B556E54A250566A74657A
8069668B427795448947657C534253422E828F294148387BA63027355659935120388462
8F7F1513488753628B24294549316A2E3040441A2E421A3D69875B3A512022504D2E3C35
414677262235483776651E1B476745969B192E4E53588744132E61804B9B3E21397D5E3D
7120363A59313A4A1E4484531946474D59934313413A45698E4A21376B5C65942320406E
3863611044709D425E2E3A56754D3656311D86822137422A3AAB771E38634136A785284B
334D89BB41294C6B4C7A82292A677E4C777B1854A24A61B53E1F6DA7375F47413D60463A
612466C06A315F3E39A1A3373944496F78232C40487CB1292C6760519C33245D665BB361
1F387587746425425E634C7879253E5F8E40466D1F314556384C682138997B254B3E3D74
AB6C28504E3F71B1442948624461AE382B377E595F7E211D386F477B7B1B1E4B70A35D3C
5D576F5B2E7A7C77406A7A7A82655A5B54744924404044584F705A7D48515A4C738384A6
859A9E6A52445C55634C4F4F3F495434515A3B5E58255D51407640874038564B4A554260
5B3E6F483F715557613E563E3A5A3F1E394946343C485B402C5E383C4F524B3953585C3D
51505D464741525E5850624658407395B192566C6152573E505544445E9DA8666F767E6C
437B7837682F3D6E485F3764344E3249767D71304C3A44504A6F28977219436B2F6C5047
4C3A7D2B3F3B16435B2F3D4567793955363A2F544B25492C09302F38480C535C1E5E5623
41144F194E4B454C535A33605B1C23452D5D36635A504B576E42545B50538042763E4664
354A2E695A4040543C494C39774F713C404B286837444850735B7354583765354F6B1F4D
5368775B494A5C7941424A436B42825D553E405F34533B6467716CA0
68808FC642437172C24A495C586DA14A37386858AB80323251694E661930424B31527925
3D58422F5A38315E882C3149333B966E173F62423A5418123BA29D5C913E25444A669D58
182E556840781C1B266A463D882C1B3F5D4C4360141F2C6521493D114486411529373284
AF2B1525533E8D671A1D3B58448F471D3D4F5F3157701941664F234849274F4E4E277534
366D90291B3F5954AF4327415E615EA72F2C39774A8483253E408B4E638423273F67436A
4A232F6E99364634253E7E4D3C502C4E648F242C443262C64F2A2F4E2E766D234B785059
8D24264D8F47AF483058743F5E492769844359571D419A6245532B2E77793271273C9890
326F3C3299A54539573B3E6E9C4E2844496072A44C2B574868A077233B697F6CB1482C44
6A814B8E502844598B41772E2F2F7A9B2D534728326751414625375576392C375682592F
444B7A5D4D827F6D5969729F7A4C4A45514F442F363A51705B583955495A4C424E89526A
5B556E58544B45456B65664B3C636037223645735C415D5B4985469249425F4A4C55465D
5C41786046783A557351576272574924363F3D332F1A3E3D39442C4157344C3B57324148
566C5C47544C584253494F636C3D698A5C7A495C773D533C524161557A74744E707DC5C5
4887834383365772495C4C643F4F3E557F7E6E4552485D4A4F5F2F2D4A1A5C5B2F4A574E
8342692835360C2F471F3D3F354F163434573C6448304B43143635464511737048B1832D
473967365C5E72536A69114F56213D4D4C7842505A514D394842503F535D7F4EA72C7087
39594496825E50564B394E2C57496B343941507A545C5034584447377A37703140442169
3C68943D5F4C3A59457168474E3E4D68785A55684357344D4C5E565A
9D4E506A657049408B75334F3D4C94A9364F412C6A982D3C445B6C7D3B2F52484397C04B
2C50726EA95B1036594C8DAB3027526E47724A263A59293B43888E3E47794A6A221B4770
252C5247517E42193B444671872D1841505075A01E222C6C44877E19273756274F4F0B2E
6A594C471D1B3D7E472D2C1B2D4A71302E604C4563A12E1D525E3C8073282B4F345EBA99
1F4B856A5787241C55864386792942514128493535515F3C24532331519E4E2C473A5C7F
581F28376B559773234C51476FBA2830577F6080742C465EA9598A392E588E435569334E
7D81355832397380294B5441778E343B4A3B617D2D234C646990341B3C4B51BB381A265E
3DA36C1529745A67BC4B4845573F578353255E645E4C873E275A65332F674B386684394F
593943798E322F41494E955C1E36376C4A817A2F3F41446B84202D575A5042575DAC7136
43436F6B457C815B32413F448E6E595247914F313D4D4153334C42564356463A404C6C7F
7C91A56F50424740574043312F39352534482F3133213B526C59404B79614943554E4F5E
64607A7E616A44514B33373527473226464D363C3A31585832523C575D3F525160384F56
594A53474C4F4F4E5B4C544C54456AA08A757547714F5D515C426A5B6F77896B668FA8A8
5B8480457D46435847583C4D35423E856F6757315D4D5D54637B191F472A5B67344A5548
7E2B7B463B492D364B323B4B4565113A2B2E275B585A8B411F423D866624494F24605725
471C4B184D464B5E7D853F8E94453638435B27394D40593A554452504B618648682B595F
4F8939605543475842445B4D754972555D5132493A645B52725155395F3381375E4B2978
39507E2F8C6B596E3E403F355C42523E7353588A67704C616E755068
B56A4B5D628C71405C698D9B31316C9A68AD562C447C4D5B6E2545878952893231408771
6D5B163B57834D534D284E987E3D5250376D8D39475433243A2B554D4A3D63B13C1F3384
526EAB213A676355A7562032637D389B891C345C5E335A39355A6C292E83473A5B6E2D30
3B4C5E642218234B73625D19223B5B4F4BA23522569A7854641F22587E433D6827184991
423C4C1957B3752F413E4863732A254C4D5C928B1B455D6B5CB65D173C616965B147394F
665B58861F305B6131334E274497892C6A3E375D8D2C365B5750A18E2035514576B33133
4B6E67AD62235C6A5885543E4F6158935B1D5B584F5A782650AA7531622B2376863A5738
3289AA3A4747313A877D304A5C5378AA93213C4B4673A093284871615CA3413B4A63617F
7622596A624D809F2B5A4E4C2C5053213E51603E4F4E2624616E283539293B895EA2734B
483A52403647645B5865565B625162514A6650373F4D666B4A67446D375066477F7891B2
A4A69868464D614F7D4F5A36314C5C2F406328516D255F6045623E83452F40383335334B
5C3B4F412F574E4D52395C414563321B324A353D3B2F464D35402D33533A42294A404434
444A4F3C3E454E5C556B68496341879C896460565942503A5441513757778451869E99A5
6C8184587E34497541416D62283F474F7A657E76694D5B3A3E6B22494D176C7C2E514C41
604869324542264A5657524D4F6A484F3C3F456E8E3D5241132D31464C135E6032715D32
4736582C645E4F6264833E49534E373C2D5B2B426244583A573E4A434758703094466356
46572F6752393B685349483A5C487D4C423831575280652251393A3653558D49654A4660
4B808E618D5446594959554C5D57663A694E4A6546504C625A625D88
657D838240405853966F408E614F5437477774234B583868622D2851446D9F3424355C78
6D811C2560504E987E242A496C617C2C3A525C46796F1A1B304356696326385F5A3C7037
2149767C3C6C234552631F4653392E6E7F3124325945733F1A344D3672B73B1948694E73
8E26255B9955734E19326238195C34142C5B7A183845303A85331635614A6489411D2F79
5A776D1B3953715A893337695354656E1924627C51635C1E49708E3A5F79342E63751F59
425951935A1D575B3D645F2431597358B04C1C426D4E7597292751845490702347715D3B
501942746D434F312880942F4F3F3077A94D384653957B3A236A3D7A9C2A273D78849948
206B9B65AA8B2E3255626B9065252C7290466D73383C709350786F26318A7D3C6D4F2962
AE642F5D562D5C6167315638469481312E4647437B6C33413D52447460413A4A5E774538
645E59625059816536627F8E8D636A66576F4D434C4A4A6B4358565C414E524E5A796867
769D92674B584E40516B644B3B54512C474B394E5C4B66685575589B4F5A5B4B4C4B4262
60467360448941597150604649644F2E3A4C32404633535E46423C4B633B51475C4D5E4D
5A435F425446443143474C7E703D4859957B565B54404D385960554B5E929042636CAD8C
709C895A784F5E5B6F533A652E525873927A734850475D61667743735F174E672938463A
75307327384A132A3F204140364C1A3B39505968953A4855213A38464F22726A3883661D
38214A19534C5C6479963A5B5A224455365D4B5E48494E3D4C4A6053658181426C465367
3D4D3D8A6950505B494D5D305A5D8B5F664F386231667352733C6F495637402337364C75
3E75803D9B685E733B42462C463141416447556C504B4A6159717066
785A6B9F49505062AD65324F5680BC363B5674478E533F4292856E6B373966A25A75832F
507E5F3EA3442F35673B46552B38626019403C2E55481A1D2C4342786F14284B4E45A053
151F5646628F29174890578CB52D17448358595B0A20595626715A123268601F642A313F
6A362B3915334D7F392A542B45984B10235C7254995E1748544646942422334E6D407B37
226866334675153D555A253754256F9E351B524B358B952A1B313C5B9BC22842566B56A9
7C315D557C68C2692E5A9268758E2E357A904F405A2641AE64445A343860984A32633488
AB581D5F4E5DB1681A366D4D884D292F7D8D7E661A4065844B9A2A304D50657D19337A73
26673B2541723B2A461D346E7E2D3A5344577F943432434A547C8F252B4A6362A7602A3D
5A6E769863323D5369435D30164C6168427D3119446E344553351D4C924C294770734C38
3529474E45646D5C3956617B8EA8695F4E9D5A243B4451693541384F426C5A485A717D9A
7B64737C503E5F496551574C4D4C44344555353F4E2B3F5C6E6475675F5C624F665A565F
5E556974726E475D52323E42464D3A30494136473E484A583444334A473140574E364D5D
544E504D5B535F536444534D5D4554857B6A82636B5A68395F3D6D4F4D72755479BEBA85
56455966723124533C3A4466364E4E5999A27C5A74745F253762495A62407F9940424753
8240723E485524374C1F4840364F113C2A30322F9E4E4E66213B2D4E4F155158345C5534
65414F3B7F6140526488296D76294956424D3641453C53354B394C3C53637441754A4D55
3856236239413F8D5036343089406947525C3A61338760205237332B65395C323C1C2C76
49687A4774673E55555168474B453F3970524F84555B65696C696B76
C9505C9D7F96483F7C9B6E704A395368405F3D35526B364763184E7F4A33503F2D799934
2B5240668B661B3D574E7BA92C2D435445A154182A6449528530213061466E6623224A7B
374F4E232E62482B452829415C441E3D31405D661B194C4D5075771512415950A2451723
60425F80182E553B4C4D6F2323607430447C241F5F8F3A225425378A7822344A3157778B
2930542D95CD2E1B5562617A7C23316F5B4F8D64293576494D662D1C4F905F3C6D2A2340
87454747294085B055373D374E91592E53507A937C2230617166A937435D564560AF3B3E
9FC53E66313C5B884C664E2B4E6F3F5D27386C62333953204EB6642C57376BB131284453
487A4A194362727D77231F4A6B5177882C3A62848488AE39485A6C595370243B6771485D
53264B4E5F3E317A3B608C5C1C23473253BB94212C684C61803916337C815F8842625F50
5F595E6E50747067656D5C967755665F53624D4043515F61405D5F5F424D5A54577C5E77
847F94653E3D5C575B3E576140464A2D4947323F6153796B5164646D4D434E423540434D
513F433630403B4457356333367446212B3C2C3A372A39503348343852323E284E414C4B
4B384A4A43465773646570566B669692896E7976535252454A4B4D40487E9C536F9CAE91
5441584B743922734D3A434B39503536585F62415D456536425F26846C4250634B4F4938
624B5A3D3B52394B54445B5552573D603930413C7D384D4D1F3A3C5B4F2D89802F674D16
43274116444E4C5F8BAA395E572132492745314A4E4B5B48434753488665664972526771
3F5346704F462D664D514C2747468642683B2E55356C683852234B435E5760464D153658
4E6E6C4B836147585B83642D4E4B53376B6C7076797D56685D6E8784
7C69605857A15D364F7D79913736596961AE4B234C545C719F2A2E5F5D74AD3B2F2B4674
7D8D1629546456908B322F7768577A2C1D4A642A364119484663264133186EA335163A47
3B6B7E19204553538B39133C73793DA06517344D504D9C23182B4A30486E201945683551
491E336F7F276F2F1F4290451432523B5894330E4A6D47617B24234E72355E6B172F6668
416456284E8963415B343D7B92302E5C252975811F3737516384302534545E6BC849252D
57517EB92D3542625C81411F54596153C55215646F36546B3228746E2D443E484E8E342E
463662C463214A4C43937627335F6979531B6077458B6D2A37837A74933B34686B668925
37545E3957642456AE70486C502C5D7755254643425B8A762E4D3F4F65914B3855435B9D
972745646C547392412A538C474E6E2D2D5F81363746162B515B1E274024465074674939
44356057445F876D41558EBCBBAD7E6057774533493F315551533E69586A7B4281AA8F74
8B779D6E4F495A4371476D553B595E283D584E595C27415857666A6A4B4D715F4E4D7173
66495E604C893B5278645F353E6F46242F4C38323E484F573C5E3A3B543B4034524C594A
4E4F4F394E53483C4D393F665B434C5A93816C71565A52374A41543F51A69260A99E8FA5
564675547D522B71494E4F66364D3E4B898C6F457450723B3E673054802967632F514E3C
5E4D76383F4A3A50622337494852162E39554B6375414D4F1667394A380C3B5A40836325
423C532852523E5A506E34595C1342543F6C5049887A5B4E6738515E76586E5F728B4060
3F4C2A886441555E3E5A58495B4B7E5940402E4E20C0913555364A2F77566B2B52482F59
387D8A4B625C48593C4552324F2F4A416B4A525B4C554855755A7071
6867B4774C4C7461B74D69947371963149899059787127578E826B841B3D434F384D5518
669C443A572A1F708E28213E406189461C3F5D447873161F4378568A551E175E804C8025
4B3F5E464B701E2B415C284838352D5E67222D31324B85510E3835337CC2591641283E7E
851924374A44B34521373E564559291D444B742E6E342132643831372B36517A3526444D
5B7972165576466AA42F1C3E775158721F1E657F4F714822337D7C1B2B3C294D4E703552
34274866612D6C403A986F2743682D50A2A4273D614585A229294A7C5A835533494E4C5B
852F285281557737264D7E2949152F62903F435D2653872B5350364B874D2C3D2B6EBA5E
1F6756498F8B28235C64689F7033536276798D732836618967914927365E725985642A2F
6F59546A382529785E465F293341683F375348536074232636465E588927345C4D7B6E56
46496E4F40647E626C716267827A67594D8059383E43385443623A583C576D3E72839266
8C85AA785A54693E74465950454B5C393B65373B6231507C62614D66776C523E5A4E3D43
57644F6266563B4E623B5B42524B342D4A36273B3225344C27332E3D43203B4E51304052
4C2B413D4240493D5D71644B5B78A58F70597F996A445950483B66606574664D627997A9
574B7B4471474C6C403D525B304243838F8E776B6644723F456D3C6B852A727632444829
6E2C7C393E41183C4E3F434A43612437472B3A435D55785B232C404A4B1F4B52367A692E
3731524E55575B61566115515D3C433E525D38454A4A534A4445453F62505869996C4062
4E6065654D4666624A49884B6C57893E4C4038553053504282434B474C4D755270263F5A
4EAE8A3C5863586B3F4D5D46592B3E2277534773504F5671747F69A2
814C5A9F5A734B49957A42554B587A492349426D76503343555759964B2B3F568BA99720
26746B699F3226255D50708415273050388D5523496F3F2C45242B51782339362F337C42
17323D3C6B9615262E56569378234057563F725814235D6635684E1820656D3572331B25
6E56475C1F1F3E6A273F43285C6E50182F3F2453B071152B4A3D5E9F3721395F5B50742E
315F73334E8C1A365B6131565329424837325A2928718B292B315852866F1D446A74529C
3F2026818451A74E1D2D724A7D7031333D8465866C173980632F5F313B65632F4C4E2C5D
9C61356E2A57B9962251595C9D302D4B8E6392672E5B814779842B35746F7A65152F4F69
5395302545A2795F54253B45654A4D67194053583658502644637D38393A356193672737
334679A05220283C58648448254B433660812C265E523A3F5F1B2F4F51504557557A573E
6A927A6E4A748D6C486E8887BF8F86796C7D504858503657486A4F6E48577B4682A09293
9A8C95774850695C884363583A525927437E41427B395373576951774A415B4551514565
76495C5B46845A607A40543D3B7A41222F44272E383742592E3E3438522A413F5D474E3F
444B5542454C5A566637544D5856496A6F74726B6A45563347445B3351848376AF7A857C
665A6F596732315B50585556474A365175A75C445C6D575B78894158A74B857F564E533F
6A337A3F615A1244541B50474163124C3538574D5D383D461F314F7D65274F5739684B1B
4C163B375059384A5F5E4C6A83553D3B3E5347205F53613A4F43454964637B3865713E59
5B8C747354394D83706C6F7290587E5B4B4B2656267C4E4046335A2059587A47595A4460
3D776F49654F3349414C50323D4151334E524A557478565C886F836C
BF4754938ABA4B47687F9B7D2545506A6AA53323519959A3843047747A59581F296B9463
5453203E51632D4237374D8D4A2047253285933A436541408C4B1E494B39758B162B4057
537C621B33485D5A7527293D613A33793B183D582B2953201F7564171A3D39307F541627
3654808B3032204350818019334961445E7015274E82663C4F292843551534402D3A6545
1C37473464B12D2362564999B41C38443D72BE3B40365B506168235952774D4F70323A5F
653F4D43263D6E6C2E44322F608F5A2A44436786983134513A63A647164F7C41857B1D41
5B5763B1311D609D5370563B5C5B2E4E25276C8B3E4344333A7145595D2565984D4B543A
40836B2B4638536C8229343C434978B3322A575449918F4226576B5076713E3982A74F6A
482F42827A3863621948546D272F42264A787A2A4453365299532850543C5E8A818B6F44
5C5D63493E4B625B4C5C7C79757F835947804C483F3D3D5E69574E505069543F597F5B4B
607583634548453F5A4F5D4F3D5C5939475845496241546A64736D7B544D5F4C62575D73
8755575F45964549884E6C3C47836E4144513834424D4B5F4A4C2B415A37494F5C50544C
51555B49544A564359555A6580757F846B616C746346503F5046684B57929F5B4D607274
788A7549493B585C3146454F373C3C66515A6166603D565F7E624F62905EA182465E5E35
6A4B5D394443304355294F4D5161213A405951626B304C6420364545492B75723D644722
29345135543F364F5971404B4D2F595841603628674B484964434951523E5C6BAB814B69
4A6336817340525D4F5478514839564E5B515A7F5A7C63325545522D5F4F8F356929425B
387F6E4C6E64494D304F5E3348226E4B5655565D4A4E5B884C515CA6
A2617C4B4C706E58943D5E8C46455A26469B722E4E3D31779B2B31463D8A8B2B162D695E
95B11D2D466B4FA06E1D3B6B604680282C497B66656F20294A70547723253D5D5022711D
42435B2D3B3A33466E4C1D2A39384AA95F1F243B4E55BA351A2B554366A520212C5E435C
55193263503B612E273F432B29502C256F7E38223E3D315E731F36505138736726453767
6A77533540484E3B7A22314368394F66232F8C872B3D3B245CA14D3458553F75AF302645
584190B53D236374518E6A26568477719732207093757491301C6B8C3D44313042794043
3B1E43726C343F32537F5735563C4E9A2F1A4A5E3D7F6F2A3A475279B13642573C4D5322
34517E3D822E2F5A736247673A315C816A3F6B373355AA783F62543084A2513B6D4F6376
48203A6B5A526B93352B4D565A5EA0212F3C8B496E5B204A4F564C58432936535B69705B
63636D5041777B7D67827B67979F99635A735A584C3D277F4C69436C414D5F376C5B9563
899AA276604F7248714042513147463C3F4E3A39582E3F5E45475751695C52525A4C4F56
837B4E635C6165675832544F525B4B3145453042383B45532C4426414D3D405753414752
4038504D5752584D6E59575067708E9A62627F677B3F56475A46775C65737B5F82949294
4C364E434C522B65476B4153344146685785563D4F496232375A3F415F288D8446404933
5E3B7044625833414B2C5C534C612A3E45353E434C46655E1E573E53451E574B3775561A
2F253B2F40314F5A7B8A425B6D24303F304966435756743C4839513B3A6E6D3E51513E5E
528C70744C4A555F5A4D723F5E4880637E7E3D4E4B75803C603150298A44533F7D415E75
49796B47A56F4C453A6759424B2D471D744D3B715A4B567358638171
716FB358474F5888C1493E6E5875642525757C517B454848493C6FA21A397C6631464939
3A7D663D5F1F31495B3C466735335F49293D352F4561231B33323A77561A44497049B42E
1F2035488F790D213C535088601A2A3F6C405A481B364D501E52352A35643E2A5B283647
641A222E375E894224273D41568E3429403F504E6D361553573C4B7528313B6F464E731F
3F5F6220486840697E40224F3C4F6B7F291A4F7663A1611F4B4F595E9A5325296B7E3C61
342A32618B3D79292F394B3A3C4B1F3B7B7A2D32484D72A43F203F616E7F55153C4E4C9E
84194954495E93312579703D712A3B53642674322B566C374C4922537A7354741F5FAE5D
283931378684342D4353688B411B374F746CA1502E445A89607B441F308C9C659C384C7E
9249799E4E2E466E4C476640355756424758213547945537581D2259AD3A3A4151604F37
5F56866B517477603A5D8A72AF6A9D6B5299525351533D72417B48763D5563408A6A9283
93838D7A5748784F845145673F5552304B6236326B4C5672506B55664C415B3B3842515B
7B40465545753B456C34562F29644B232B402A2C323D3B4E313C15355A2F3E2B5B49503B
4247534247484F5A584858556979947D6A776E896D495048504F6B4A646B7F6B96948D9C
4E496E596B362C532B684D68403E31394B4E645A595D794B4863423E672461745E3E4E29
7B297B423F4931384527394A47572F42373452858C3B463E1F36427B5F295B592A54361E
5B243030552A2D3A5155364C4A3B5D61424B41305441423240223C3D2F4542266E4E3D5E
3F62446356454C7463537842572C7E55324A4254316A59376D3A6236494B7550A9695596
4A846D3E4E4953513E4F454B75304B3955696C6A6A727A966A5B5799
804C5E9F64743F4780894E582866793F2E50352F72A7323D45335EAF5E24423866A85519
25394A66BA421B58533B839F2F13516B3A7524283A726B3146182649752A49491C2F5867
36593F17509A3924501D2361861D1A4448627C68131C4668558C6215206853426F26233D
534B726B0F38275A3E53351B49696F4244451A5C71822E3742394793261F2B473577881F
2A44545E73A41E3765765C994D224D7266366A492663A242426428347883394653495977
63233B2E5A51B16226544A2C6E7A27363064396B5D323D4A9B5D8F3D25517428453B1750
89563A641E3C956D224F3A3380562F542F5BAC6A1B3F605B927E23324E57687C2F225678
537B263F508364725B175A58633056561A5572694D817323548A762C434C354A91983644
2F2F4B88622B413A405E8E352633562F6DA13413375E45878C34384C6E465C73528B6340
5B56694C35859F65404F659170698358475E5D4D424E445E51554D45586D55505F785A4D
5D717B54454A4F4159515C61455C58304271524E733244524D777D6D4F557D554F4B8793
9B574A6E489549528354503748674E2A3546363734524C672B40193F5E334543584B4F48
3A45505160646344674B4D4F57618B7663865B6256454C455247645B6279A650616B7095
62747A3F563645632B5E4D4B3C442F4B4579613E4D2B566D5E63413D5735797C56607841
7F42673F384F0F3F571140544A6715303F3254494D3A4B4D42744B515237807437523E13
20213D385756394A93B4444F4D292F2B305642426053523C444455393C69683A714F3269
387240A86353496A4A4A5A3F4C3B7E395E6A6F854C614B1552354F2A82537C4F81574967
4AC9AB5D6D586362354A3D374B354C2C67585979495B7D7754527E6D
90514E5A6D9E45377C7589853140775C617E2B35549B5773431931627E596A2520529751
5C5C182F677023672A173977603E5E2A3A5F673257434F5F5A2217334335826A1D182F62
49724D202027474F9423184164453D6F2B1B495836537D172E485416344C23395044173C
2F365F7A2F2C5433467A51101D3E5A598079191B449852AB6A0F246B5B3C663214379767
305E3818506B433F5725435A5F2448493E4C643C274353459BA0283440815FAAAD393F5E
7A647F85322D7AA3596D3A254994694A7B4B2E807C353B3C2D4279581D3E4C4762812636
4A5868AC452864864188333D584F348227259AAD3357393541682B52363A5C6B4E525D2F
495A4E325C2B4169883D4156435A76A753345038309BC15E296088617999363B6E81778D
2E265E70803E554818467450413845313B668C3151302346AA823742562867996D6D5843
6172715246595B7D5E728272968789624B8456644E594C63407244683F5063367D598555
928C9A7A5E3E5B396A3C3352404B45213F5E3E3855333A6D6655414F605F4B38554A4A4A
6B6F4F6E6B7A7D775830544D54633E385545384A343B3D582E3C223D3B232F4741303E45
3046545259355C6C645F63507099AC9E56687364724E563D5C4272526B627145678A98A8
6955605360332A3A2D5649683A464051477F6545593968404D6C384E601698A6403F5143
853F744B4C5028414C254F603F4D1C383F445758662E4F5329334A5156334D4A2A5F5825
3C24382E49444B4055644258531836454357585A574B693837314E363A535329543C505E
386D21644C3A4D834F3D672B51316935343B3351319473186034483A5A45607EA26D758A
4E6F5A5385334A4A32553E3B5016341D764847584949566349586B82
8686AE3D55566D788F475A76515A6A37435C442769464D5D5226363D41426F221D3E4E55
7D741C234A464CAB38151F476D5DA5343C4B6A3D90531A3B5541476A20293570374B5728
2E58692755472831726C283A3A3D469D5519502F465199331C4B48325C731D25425A3C76
35173C452D46661E2B5D83503B612542718F6B404C2B3C64671C21424946824C13185245
54A2410E2C62506A8A1B2E4060356B69293270AE508B7326358B53395F391F44695F325D
32317E7B3C3F4E2F449F712A4347637C9C3D2F564F5A87981C306B556586431D5C804F51
551D4B7B7B5E68342D696F345C3F4B794927635F5388722544463C725D1847554472A321
3E7B68549C3F294B814A6A70272F50755B4D53342944717346614034446673649238396A
8E30346E59429A83382143305B60681D3B436F53A3601A3152493E684936404D4E574542
5848917649777273496C8B82B36C9C724CA564664A734973516A43524A586C49885F7C7D
A182AC82593B61477A44406B415246224C6F4C41813644774C68525C4543563645414E5F
93474C5B446C33426139563B376F473F3C463529403A3E5141431D3B5D2C45305C38462F
3846582C52444F40523A41685F6382727D8C6B835C74654D655E6077618D9E6A767A7285
404B492D42312B6D436153763A41597157675342526062494A5650827A10627E3E686E35
6B2A8A3C516234545B36515A3D4D29422F32565D5C4963500E34467161307F7327584A22
43343E46825B3D3F5F6C38716B3963672A483550474B4C4135465B394B5B5B2C642F4775
447948B076513074525570407A2B673639536472375A52235F3D57626969696083654C77
4087653D652F6655203B365971202F33765D7A685562625F534B6885
7F5F9E5E4B583C6BB45454673F669235375D5A47AB922047634BA2A5203D76846193462E
4A733D6F7B21265B7E213F3B2E2D5E623A461A2F547E374A523337844E22343B5778831B
193F40416F9218343673557E851421509648BA44184C4E6E2C9B2D1643804A2953253D6D
6130354B285D6D331D353E318BAF212D395B3F699B231E3D73485E95232B4E654955592A
337682315867264A77462B53243756732D205852348C8A272B686465A9562537656C7180
3E1F2E654C51791F1C45A44055581F39595C2F5D4331417C4D38692832799B2936455874
993F2A494179CB47294C485795403152684DA65E2E626C677E43326B583F605D2E56816E
3D53224164743154373E5C6A472947402A5F8C4C232C4356578056222E324E6ACC453444
7863789A414264855278762929687D3E49541D31559C54383028354F73233937577F5B39
5E48655D51868DB557769281B3748F7C7C6E535F56564A535B5D4548687356435F6C626F
6C7D87684948554D624F5E5B404B461B3B574C486A46537252756A73576672514D466068
A7533373478447567358573D3C66502737493D343546425630462C4062394C40603F4C44
5944694560496B4C72455D474D4D5A71455F697062565941533E55464C7679416879A5AC
395B51305A2E46534656465F44473F453E78615E552B604F535937364C2170834E334C27
7628602D3750203543143A5443592431474A5262673F5254344F4B485631745E2D715F1F
3E3E4E265639343888B83B574F1E3D4643645E4456574C46554756435B6157317F52395B
2E57276A65473562486259354A386B482D3C3B564C676421573B63415F5779668E725878
6FB47E4158355F5A3D474C3F4E4D56417053535250603B435754727C
A84F5F7385974B4D879A8962323E71545F6B28304E8348573F2B385D80456B2539465322
6A5C39676C352E65344E9F862840583C5FA331284B5A418B8718424851549A45213C4E30
3D6A2A233D5451277C1F2D5368202D49243757691625433744808D0E1B5C5D476A2B1B52
8652655E2625555B2D612D25316A7B395D301F2B5B7531522D2022664E223F3917618E30
28554F62798E233189545FB1640D5E736C53A72B3D6986656771194168AC445A55184E5B
682F392E35757C42192D484D58661D374C4C4C975D234954426DA326255B8B5255481E41
76504E66242A7B8E3C7B381F5F6B30611740575F2C5A353E9783405B5B37979A3144534E
5798582B51535B93741B6C89865A8E971F3C5F8952828E22324E68485A5733456C984C71
2E32386C973C44592838777A3E353F4046903B283D587189741C47726B4A7683585B5F56
584B987357B2D2B6525F81AA83538668489B527749675B7B618243634169784177468182
8F89857658385B445E3A2D58434C3F30464D534751353C5C5A5651587268513E5345574E
6C6145715B6E5E6464425C47548953303A48422D223E3B441A41152B4F3040334E414D32
424159415A53614A764E624B54474F9864688A7B7866714363456357737F974365705F77
4966723B881D236B5F7D4048484E364746A06533535C5C3D5A6D453B5C378EA65B4B6245
8F367A30404F253D4B1E2F524B5E1F312E213C4953446D55213B4A7E63345B48214B5227
45333F3E63434C415F7856A18338483639473E393E404533432F4A2D3C504E3168333C5C
3E663C6F786B665A69678A626D426E4D61593855316E80535F4F543E616C664F855582A6
567651628F4F53523F693D48462A33327150617374685A596F847392
615571444B6A4E457D407C973537753368AA453A545F5A9174263B3E6D73951F39565649
9F971135644A518C581D498744516927305771476D333036654425602D4252611F305443
4191491B3A334E54B9351A2D694F5B8E291B507E3A597D2523526427467D223456543948
3D1D7DAD43414F3C367569182E4B395AAE771E2A474B5AA56E1D373B7F588F60191A5663
37792023556C4E426A33357DA92F3C523539857D1F515F3863AB372042734A7F9D25334F
824F755F134B7379439F3A1C5C7C3847732F3995933E624F2A329C561F383C29736D3A3C
382379BE362D495440B9511C4A52549B241B435947992E4464684D64462954894A7C7438
5E5D683F743447787A324A5521435D8E5D395B315461744F246B43475F87364A51525E98
7026445D96747F78212B44565C733B1C2F4E7A34735823436A402E56312A3876854D4551
89918B78645C6F744E5F6B53B388AF744C7547785A604376606E4D76625B924A9D569383
A1B3CB89724C8752805D4F795B5C4C2B566F51306B3E475D325A605D4B3E4B413C30454D
74484C504255373D4C454C45345761394A57373D3D36384A3F4C303A51333A3D4B45402B
474A504F443F506861475D5C3E59829E6A5C878E7C62684B543C4F4B6185985187937A9F
4F4B4D1B3E1B2B6A375744553F3D565D4F514E384D2F593E4047343F4A1D51683E5B622C
5F438A374D5C214049294F544B58364B322E436356253A4810292C404D24A15E226F551C
59313F3C6450403D6C7D324E4F1D7253294860524F57604652435A3D3F5D47346B2D2C4B
458948695A632F786E5770437143A06D37414B5B4A88824453355150814A735D8755465B
43783243542C9D6E394945515C5A562F50635851776B4647726F84B3
656BC84E536E7082925753916191B62A464F3661B2322F31724F6C73214C966E417E3B24
809F3C3336243F865019293B4692B730354B3C5CA24A22352C696A8C1D374648396B5A21
443E404C816F123F574A515A3C20465D4C4A622C3845732D29412F23388A3C193A345580
36191C483F5C821A4D4B7731709A192065AA49497523306383264A552A24557C1D2B3A33
3C804A173F4D42537A312151824D7C791846555945A041304A4F755A88412A3363665777
3F3B4D6C4A396C2C2A648031375438609B382042474775A63D3D5353617A1C1D2D81617A
5E2638516B535F29217283425A293D4E414169353D82531F473149806C1B45413B698F28
30574A53A75F2B5B563C8A9D3125578C68517B262D4499BA669E422C5C8E4E695E1A4555
73445C7616366268363758222F7D8926353558527D521F363C58518F462A3B4C4A5B5F34
423B635A51799E865E6E9076A1569D906B894467566C4A75707D425A51517348647F7363
7A8B94694C555A4759554664446A492B3957513D644952674C6F6769625E70405254535A
AF5F5E844A98444C6A48564F395E3F2D293C3E26294C444D2757233956393C3B4E434C39
4F535D324E3B483A613E454A3C4A45628076605C4F51443D5D505747629593656675698E
5EA27731542E2B7F4E575E683C3C4B4344615E5362407547475F29336C2170834E2E533B
65414D292F3C29504E3737545566272F42434B62743B4E57224E414C45214E2F36B4801F
323E7A477C4C5D3E7893338C7C223743465D45395955363855333F4A49524233965D4B75
44701F676C8E59775D6187598345644D44353850265E74527E4772424F5B795B8D52777A
4AC5686B94343B3A547156545A47553C5C505C615A564A4A5F506386
8052656F595B494C8F605963343E835645623E5E8B73253E5059856C22323E62699B372A
3B666E735419124F78437B421E1F70725E7C2D38336544705816426D492A5946215A9D32
335B313673961D285352588D581221645258BC421B3582696DAA291A37604742440C3341
562C544A2937524A2D4B4029548E42273342505E942D1D38662A78A91D14497241846F1A
4D5D8C3EB669305786602873393C72B6514787492F6B993F47573A3A9C8B33464F3852A1
5C22465D458F902924526664878326375B705DA146282D5B5755833F296D812B693D2D5E
8534443A4B5F954F324443558F37335F486D815629715F539B2E2A67654F887221619E72
3E7021306D8147833C3638808B524F462556746E30513E2E33787D26343C39709334284E
4C5C81C7571B3D7C83496F2C31447D5380701C2F596B35674B203250793C3A4858646D3A
5F63956B76A9A0A3494A98C0C27F92704989528B53734888528643553F738D429C74A48D
86C0C08E6D5596457C4B4576366D614F4360684A7E3342745F5F56506E5B59485F676C6D
816875866C77485B6A3D60402A604536474F3A3837383B5933482B4255394442522E4B3F
373C4E38564963436B4D634B5B6E62A65F60946D74505A3F5E3E6F688A8595578089879B
85496939693F356E424C3E5051535B56679B753C4A44715D676534317219697D5635683E
792A6E2A22472A363E242F52374E1C2C2C253347553F5A5F37413D5C5C2E5E47244D5324
473D43415A3640445067374E5727334A3D4D415B475D4A413C294B383A4D47386246395F
44B137897E78495F5E43663C3A39835477764274317F80455D3A413C74455C507A69514D
4C783A5056404A3C34423D3A492B3D2D59515856664F5B666B53848C
B04F5B6A747B494C789684A32F425E7367941F3F528A4F9441327F7538795F285395772B
863C236EAA4C36352D33899B323A3A334C6C352549395391621B1C3C3A61A5443624494C
709A38252B5D4F5F741838475230386019264C69253D3D274E5F4913373E355882291A3A
5C4B97722B2143404E9839263B7C9565923C265857542C5333373B555C31822E193E7226
1C4B2E2E859E2329574657A95A1B41805171CF41444D6C4B939B1F29687C3E746B303457
773A5736153F9E752C5D292856833C395738498A6229353C59789F302D453B4399572E4C
6B3E637A254A6E746268164577614F73213084664E702E446A6F2B4733365B843C444A3D
656B4230473D60C7631F3A3D485EB67F273B435B44785A1B3F4B6943765F25599873618E
26266E6B7952716A1F5D88553A5730194F7129224F3D38757325262F42667C7354646745
5F58A07F75ABB7B2717F77676D84916B506C45604A70526A546A57876B66A44C987E8A7F
B1BFC3986E5595568366417E4F775B3F446A5730752D3A6A4358485E614B553151524851
925C626743614C496740654C386F482A3C43343B3D432C5348501A39623843456B385554
5D3F553E4C3E4D4C53404D61637A97A9776EB98D694B6048543C624874899F80A5874D59
506F69456E473260466D4B4635334E6A518573556384863D3D643A296E2C718F5344583B
753060282B5A2239471A42643B521C3B21273755642A444D19333A3C513362383C88661E
5B3A4B398A6549596788465D5A33576B2F4C5659525F5C4441324537426941356B2A3856
3D6D3E5C60702F7863698147522E6750403B41443F8B784A6A2B602C5249625669587254
4E722F5063305037384B3E404A3D503F6E56645684624F479A4A6B99
735D9E444D5762706A3C4C77655E5E394675534A5C364D6D7F2B3D495580701529415C48
CA5A1D2D5142816E102E368E6C8B48164C6F422D82250E61885452603D21727A3B5C4A25
374F433045312D35583725413B4C6A762221385A61827D173143653694432531526C587D
16303B5D5859601B22526A2D375530607A521F2A4D1C4B944D0D3D4D554BC24B15427041
466A21205478644B7A3030718E3B46401925656322663F333C998B2F6A4534687F274543
4F6F86541C3B543F5BB34D1C57594765B1252272623F58411D429D5F555E29235B774047
4D43648C363F663870B85842602C4FB5441F575E51AA40334F6D6A7E4B2146584169741E
366661689041303D7C3C5F44212A3167534A491530516E423A5F2C3469932C4258385D94
602758836154978D20376C624790333827515F3A76362831594D3F6F271B3B656A837153
765F7C735C84A97E3F4E8372B56AA4A58892447A8176477B827F494A465B754371A58550
648DCA6947716843515F7E71566E7D54535F483E72484462506E6866674C644352516768
846A676E657342445157544A3C5A5C383B414437255840502852203C604032395F545545
594C5F32584762457241585253595988656E806F6C58583C6A57664784A096455E777793
758A89434C4E3F8D46484F5D413E61493F6861444D406349495B354D80256C834F5A6B34
703F81292148344F55162D53415E17292C27284D632843561F3F3B3E4828752C1BB37819
4142603A5634473A808731735D10344B3E6351585E70584346354F393F533A2D813A4267
35801E8E828148664B6187335D2D9E5C46413B54205D692B513951336E4F5D6859583C38
55986C74454880623F463A6E6A5E433E64586B4F4A567958624987AB
6E5681744E585E798B3A414F5B809F25404D4867A32B314B935D9157296168255C6E272B
869A3175592929726422352A2356813D355045569950194644406469241B3E4D5073431E
3B3442568D74253E445B79A2331F4E654C696D1F1D4F72435B731A2B485B2931431D5277
3E243D362D8BB92B1D24414077801B23476E4D819D383F4861415766221D455726314F32
2B533A2547462F439F4E2240455A70811F223A564AA64D2C4A51626DBD3A225874418492
45276A944647632F38457C3E80502A30614F416036388590262E4F2C5A9B2631544A488B
6F194B7B474B9936427C4D5E6A242F795749794545574C38784045645533823E32879E3C
3B3E443D88692C4E335178A247324C414075B24C275446545DAD2B345F7A4C786E374177
A349A07E2D3755965D535E21336A702A4E31374666421C3036434C845319444451586E4F
546A9E6E4FA4DAA84B4D84977DA3924538484F4D30504767484E3A432F6B683E4E485D62
737A6D674D416A49633E2F51424D403939464D3D402327587448393A636E3F2E52603F33
577E7E5F426B7C694D334754755F422F543D39473B3635552B4222494427375C5A314B4F
413D4C465A5763456D63695B7A7B7B9C616C83665E565B36603E6D579DAFB4657193B4A1
6E7776296F8A9A78444E58515451654D77905F385A6A784D5B7F63225D4B838853335B46
733154282F4F313F46194E5B2E431B3F1C352E4551284D4C29583D4F55205821104D5617
4E394C3C6B4455404B642A817E214A4B394F434C4C615C36332948363963402D6D20355E
247F3263666D3A6C4956704D84216B4F3C44464A1FA7863752264C46545966585878674F
558C5B86643641404855434A3C2F4D526A52585E83654D6CA9577982
9C6068817D833E638F6F9083364D696351652E3C5E843C87392D3F562F42553C4D733721
48413D6D7D1F223473639E492A3954485E7F23263E62428E61153054486389372C476E27
2F5D1F26568432223C263B7A8B1D3742253D883E233D3C3A5A872A133E60306B76192060
714F7F3F1C455390547019233F67583864362C528E491D4232314E89342848472E83A71B
203B4463A6741D4457604B6F282F49864B585920357EAB3B5F3E2D5692552B3948339599
2D263A4E496C72272F4B4E47B2772448403D68A5442555733B497D263D8C695396301D58
813F43422743916E345725738F403D653A4DA4613E6948537F452A6E6050713621598143
6857304F689461AA3123749A4A5A5F3F274977893C67391C39687C38693026376E204054
295E967130244E4F449C98242B445B5BA55C1841545A4F98621F494A814A8F6F61596443
6C91817E7140566564867E56503A6B8159753C6349666670597D47533A3F5F4C705B6F84
B4A5AE8C5D507461684F42765155514B4F6A5C3177202D61535E47535935472948414746
7F594B5F4A59312F3E30423D1D483A27282F3D2D213B313B2A4015304E33231D3A373F30
3B383C3B3B45475B50334B5D76797C716B6A82764E5E634E5C42677C84A7AA468F72687E
53627E4A618FA74C556F50453A41606F6260564062465C41314F532D481584B2663A5242
744864432449263B4637334C3A53262A2D252A59572B404617312D3F45196C1C107B660D
503A4C316C314139617035434D1E3F563251465F547A5A4941394E3E47564E3769273B58
2D8E377261652E7D6D66694F543E8A7236366F5F1A4C3A2E6C45595557485D6F61774D37
36713A733E1B54392D41235F4B4C453450626D546164A15A5D5988B1
8E5062486A64465D53409691303C433B8E952F424F4856B4463D4D4E56AD733350615957
B1552647613C5E592B3D6E7750703D323D64534A7F1E264C641C3A4925436F561E344052
6C7D2A17325456617F1C204C843C5B46232B4B7A41873A1532614F415C301F396E602A4A
271F5A631F41514156993C1841453559B1471B36675A6AAB3A1B487955437E352047A26D
4C6436247C932E3C722A60755A1A3F464D65942327527D5A92401E5379684D8D3F1F397A
70518593214F8A594D8027277D90453B521D4999863D484D3B4F9C44274C5B569D5B243D
5D5E577E252E755C5D85252D5B72528E26414843658C203D6A70476D364C765F41556133
41843D2B5E47396C65293C5C585184581A253D55438E561F3C534E52BF4E3F5D603E5689
1D286973593561541F4482534F51171A5265232C612E2559802C32562F22748A5371866A
3D4A6F635A89768B3F49739A8B617255394F485E665B5275715C57613C53593F536F5F53
626B8B68415854324F4C556B364F50402B42463F5E404C5A607C8A6B674F5A3D554D6163
9175638B4C6F4A42483B524232625E3842344D35235B49511A4E1F445241353F53405047
4E5D614A61515730573C3A4C5859616A7669644F49543D2E494A474958A2964B88647289
518F82466462354F3840657C4D454D3F506B715057467A3F3F623C504A1F4D73663B6839
7F446C2E20545A525722304C4B613530383249354E2F414B2A634554591F543112495312
383A533D643265426C8E285C5B1C49584F7A4E524F6D483F4B383D4F4E5D475A8B484E68
2069199375884C755F74725468468B6A6C50555B2D88623C4F35542D56505968967E4B4B
318F57755D2D48413B4A3B615D3B33506C5371717766604F6B4F8282
7A78B244566C75C37B40497A71AC6B3939727D696A353C7B793C793D1B57682654622B2F
6A6F254E352D6F7B1D1F3F4458843D262B3E4758A32828335C49837B2A253E6D4368341A
296D683C6432283962584155242B3D5E2E383B27566E6329364A2D6DB14B203044425B9E
241F436B3E7DA61B3C49652D5E4D2C36547F245E8333294E4F194C522C3C79551F2B524E
3C923527316062749E2F3B6D885E725C3040805439501F436DA5373C55433B7B73333549
2F377A6B3228585657A8361A3B4D4F7D8B3533545E458E8C25486C585C761B40796A5B86
4F2F53622F4088352E7545483D335C81423458307EAF3527674578C04B34555755847637
48666B558A3435425C458773314B4A9A5F475D3434607D3D486823305C7E34585C213087
602A46514C3E847C2F2B4C54549E331B4D584F56953A1C4D724A426720194D7367626646
5B588C7C657F8D8F514E4D43907D837444555A5B43555E60484B4054385C603C4B495870
86787D7D4B3D58505940204D4C433D37467B493A542D305D724A414463805D4A4F53493B
617967666859544F414D3E49795738405B2C2E372F3729521E391642532F334A562B4659
392B4653514C5A47655F5A466E8294A5605F81595948543E5B3E6554746D523E61599A91
51615D3A59674D534261413E395C434A51BE604254435D645F6C50696E5B61874C406E4B
80586C3A2D4F4B334736344C4854372B433E2A465840515D424345446259642F436E6C42
324E3A515D54484C5C6C5596923A4751455B3B6B4D67373A3D2D4341475B5440893A425B
2E7D426C6D905789644CA9496259B86448425040466D60455B445C41803C53524F706378
4A895159464581623D433A464D3A4046515E605C8A7261666E526BA8
62555A5D5E4E4E89A45E624C53596433363B4B666C2F3859605B968B1F4A4B5683AF3134
545673B87D1A465D4866A53536495045655E262A404A365D2831506130356729334B571D
313B2F3A7C6D1629385462A63D24465843937B28344A4438567F1F32376E42805E1F254F
752870471D466E4D315B38357A80202E45634B7A98284054803D8A8E2A22354C4E6E6C18
262A41316D491247473829732F256C7A273D494E55742D284382528F892E283E754E8385
302037765B809134336782348947374473403D742A2C395C4543C3373C813C3F664F59A1
862A4140515EC74A415A52777A193B5556669E294166535E6D243A7B6E3D8229235AA34E
6254224881843B79352154754A234C47514C6F4232544A317A992B3C484257B9902B3B44
4E58968E1A324152457D5C174351543445281E2B45682E4233244543421A3835AA9E8644
5D73706C70475E58526C5A6D907E845856653A5D5852384D4B4D4F5035474E3B575E533E
5170B18148554E433E3A384B423A4E413F4F48394A46544E494F6C554F46413B472C404F
5E584E55545547473B343D3F1A4C54312F2B45262A4B33432C40212448402E1741443B23
3A43493B3B384A654F33364C5D7480735E566A733C3642364447495A5D916C4B875E3F3E
434C5C417A6D2E62364442492E2F595754463D455A785E232F614F705F3376AA60405961
89587069416F45414C5854533A554745443736524F284F57163F333B521E57590C617115
273F3C3952674E61738253484F1B6A713A69576F4B6D534D4245594462946F4A9123435F
318943737B7B30A17773886C72417567444154332E38343F58285B3643436A53685D6898
4674675E7835334A3F4D553A4139544F5E907F5FAD74676CB15F8EAC
94505869AD7F33719D5CA96E414E6B4A554D276C8347719C3434727B3E614D1C579A6246
532F24559E514F5F1B2B68672F4C3D22617D324A67593A8F3F1641596461B7432A49425D
AFBD21363946547D3A284C5F69354635242F605D35763D287096322B4530398A8D212F30
674C974915375F6F7C883E1B6875405C8F331B5B6A415EA52B2D47763E36462E197BBC50
224D292F97B5262D453A5BCE5F273D6E4787851748604C487D4A1F52704C24613819466D
4E37562F276EA4472A373E45908320374C4A59A455284852597AA7274F894F68AF2B3769
91446B4D283D6A764A6C265D733C606D283D7D65565E2E49715F2D594770B43F213B5151
9686253B59706BB9681F3F54576CAE5F29514F596CC33F38416B6E64942D2C4383494D5C
2E30535C3334792D4159653B275C495B765A132D4A544C8D7B1B3D4962397543455B795F
3F424F58596DB67D4345598862516660505749574C534F5E69643C4A3A8066314C706B54
5E89A86640514C3F554D5965405466542433484D5D22314E4F4E4223354C4E4F393E5252
4E576460504A3D3E464E434535383B363930372728404539253220353B332D353F393C43
3B413D3E5F5E5D2F4C4F48496778958D8D785C4C3D2F40244249494A543E5B5059468076
4F9B7833404C4E502B33767C4B52484350B37069522C3B51494A4194A03B4C845B5E8048
7963AD391F50495B692A2E484A631B274A3E5668703F505B304B413C562F67493E5F5B1E
4C44453A5B5471606D7C2E6B671930517398555E658B32396138435846504D4DAB437B7E
1669158579754B686666733C4B336B6849468F5C2E4F323952477A4352353D5E6A91637F
927E788F82434B5D6A73463D3E37526463627F727983AD5B924B63B8
97517D406DB4615A49335B76384D4B4555A03A35563E62812E1A3F6079765516254E5D64
AE3F29296A5E877B22444648497B2E133D715874CD1D31726B49683D24415B4C2E563815
64A0551750461C5882212B4A3D4E974B25273C5563B75C152C5B5A6B7733173567515E79
1C244F68395A6D10398E58165D392E53A454144E573F6DA54C25534A60728F362F436986
6D9B3B1C316F457C6D2524648C367E341E3B933D3549324162813B2C543E35829C2C344F
5564903D1F283F4A6C9219252F6B405C5B242D4B5E294D4122476F4341552856604B2D64
384DAA791D33543C708E243B4940B59D282D6260938E363B5A5778AE4136616644682927
3E864A576F29254E783A3841272B58A33C4C571C367269254F3F3C4A85491F4540519990
281A517A4A79D33F30664E4D4F7E3F27526E4F577E2D1D4151333A6F1334755D8C8E5849
5A866C4D49596788584E836BB0989686586A6D5F5962707C5F644B5A42496F325A556672
8A948C79524A6C465B572E664451475D404444394F31315C6B4C423C61734B2E4E5F4444
56818F522337514B3925394E655E3D40532F323927332D4A262D1F40553B465359254055
3825363239393E46424E444D45659868313F5C73371C374037344070655B5D4B9F524247
463C5637485A5F6C53593B342F356C675D5D433F51635B507A9749404C2067BA56325044
734A574B224C38283D4D4D4D2D3C3B384C3B3350485880734E4B5A76884C70332E856F1B
21334D40504C4851677440867F334A4C4572696C445B46393639464652636A6292373F4D
388732867B97606E5E51933F562A5548826149494272514237233D3170566074678365B2
7B845F536551684B3242455A46333D5D715C8965826F5D61A0677EC2
8D90B2414B8A6AA77540477555AE5A393F4E5D7D861B6260564FA432337479509450366F
677353621627446233415F334166632F3E4A2E59A3612D5F4140AD712029525A6D71312D
1C5080496B4C173153573D8C20293279576F58271E3D6A32434B115280362332372D639A
2F153F4B347BAB211333523CB06827274E713CB05E1E344D5F306C8617466F6826705818
4288601D43362B748A2426404E4CC8531826723F6C7223293E97727793293F458E445661
13325E6D3551681E3A844B2A453929537E2425543D3E84682D4A6835677F3130606564A9
4F124F7765517F312F9542623F234490373F58272C5F573D693332704D3658255494661F
324A3B9A823F354F5342747F2537385D68689B232B6C6E2C7F432A366C78337440323A7A
5D2841423A425F662F4A404A7994482E373825539B3B202C44435C922A1546795C6B6644
5F5D7F7C74A5B8AE80798D949C89786D79774A54625747656D63577A605B7A526A817778
9287CA9753536B62705F40824C5D5883535D553C82303A67517556625D4B4E3353415049
80534A644451404F5735434F234F4A30342336221D402F3B1C43142E4F33283F4D3F3838
47394847423E4D594B2532644B473C434F5C443F31303226443C4A3759756B2E2D345B65
4D8D8C2C4B52473A39305D825D35382D456C696A643B4040374B43867A1C81CB65335B3F
895E77392A6F3F3E503C565534492B3C2B3A40555C363F3A1F3B4A3C523D696119485625
2F4440455150525B668F3B556139434E51796690496441534C4B604E4A909153933D555C
358742725F6F48A06656834E6D56C06941435945547D534444253E4C63655E6D4C8854C3
6B5D5E5678263348404D2A2E453023465A757769AC7E8176B25873CD
545C818D99644B597F4B6A47323F6531492D334D7A4843543C4494662D4A44546E702037
3F4778B44A24424B647686184A6A51746682164D8D744E9431224A9E4D458C2E27608B45
515F263E3F60253E373D4A93542547473C516A271B37554C7E74211348694776391B375B
7132752811426F5626542525455A2C415E2142A568232F4A3451A9AD2A1B3E4646B7931F
2B4D535096432F457777668025385E793F495837437D6A2E5F2D3869783C1A2E374A72B1
452052524B87AB2F235D504A92373A3A6E5E5774233B57713F8162214D583B3C66254593
884556573E619D4D384D4C67622C43585A6FBF3F354D6A44A1412E576158B737215A7259
77551A465F563E8C3B46568F41375C3D41436C792B4E3540535A172D4840618B55183352
3C487F50183F615C458E590D31485E4E703B1F285D92474E261A274D5D324E47738BA77D
777375686469B18043416457888D92925B89563C58704D805C643E4B4B6F762D5184866D
7F9FC074455F4E333B4C5553445260502B3950645E4B537F758E846F725B6C546B566D6E
78797D715B6A52416268505541555948534852342B57444033491F384F3E2C51534D3C3C
45474234535F503A604C474D433E52524B5B5A573C43432E4E4B55536F97955B785F5D77
3E25342A354A385944423843514F60506F9E772D30415A73596A40ADAA35598B575A7337
524B9C371C3831273D3542443240252B3440397C753B5E53344F3F3F5C57753C2552551D
434C3F4265615F607C8D475E683B66795862486038703D3D4D394F46425158539227705C
1A6D1D7C73754C70777A8E74925C624D564A7A3F3462355A823D4A4A5C4E745D5F7341B9
5B59554783254B59465D2C323A512C505C6980617780CA988F9190B4
855264517F663F4B6877A07632473B63A8572D685E51AEA2334F655B64AC462C5C88454E
63203192A74C6C3E1C57764321512A2E67873A43462728876B21343C425C8B4C1D2F404B
75A73125393E4A7B8217404B524F863F1B394D52307D2A2F4D531A2D482C2C6469202840
453B883A1528577458903C134B5D314A5D26114C83424F5C31263789622D501B374A5E2F
426E152170871845422F4087382F495A49635E2725616B63913525479569726E29284377
B14DA22A3265948253562944627B29424B3E5B996F1D4B493994B7484058577B983F265F
9C508F5F354E8D7191552B988C465D551F60BF6D5D602A3C6E7151653F47917A42614331
4B7D3446665D678F4B213D496486923A2A5C3A585D8D35354A594576A03A305A66466B73
26394B763D435E2C2D63733D3C4734495F6C23294936649E521A2646595396559E95735A
5873786959B0AAA5574C926DAF8B7D8F5A666B4E556D78755675515561509E466A867C85
8AB9D099495A8144515E397947665182454C5A38793835615B573A3E78844932516C4636
5B777F5A32577B34502F315047583927451B253129302D42253B2142523D455E5B395156
4A3259574C4158494E66564E466452684D59725A4E465331643B5C48594E6D617D4B6F88
415D66296E663A4A4C59483E4A2950816E59624C5960634362832B4643298EED63234244
9C5177513A7636304C396A4732463D504444143F4B4D94493566534A5C3A554726898A1B
2C374B474C4550545A6F4F64622328405D8B5A6546704B4D61525275635E65559A4D556C
20642996A47F5F74806D92649851976C6A6462714D7055404A4469425A2E544C6A684A68
53555D609B334B564D643F3B4C3D44696D5A7C5D716269557D5663BB
848CA14652795B7C373C718C5E753C3044853F7462223E6741304A262365641D343C4393
7C2F1A434860A74E183046375C9927194C74427DC320265367516E602450777444823135
405B72327C322E4A70433C68263D53621E483A3D37917E1D3F6745688D241F557C405A7D
1122566F395D561131535D3C5A342A497C582B464C1D6A993C214547305D8433215E6731
759E271D529E377646255454544A7E3021365C41515C183C513C1C2F6322369B5E1D2F45
3F52AA4425375F5D6CAE2C3A43714EA5932346616A489B544D657E57675E1C448E683454
3639797F2C66523A5F8C34453F2B74841E3A5858779B293F455C82BF611E5F6F59944D31
455F3D72851F4E636E355F532747746630AB53353A746A286B40404782492F513E2B64A9
4A284E4C4A7CA427274D61707795221D476E4B45923C253F622848411A1B3B7248587161
515D74ACA8B9A5B3564D8C88B0B0997F528167545565464D43655E7D6652AD52728A779F
AE9DC39A5B5E52465A67427A416C4C854751653D892F366E5674406A655756285E526E46
966C739D4A6366425B36445F33603C3C4B2C2B382A5238553A4629416D363144683D4E47
4D3C50494E4C564E5B4149504B42353D587869694B5F4F435C67666B6F9A9677AB685777
78718E324A80546A4A487583695166436859908D66406F514852389F981F588E4E315938
4F4198450E2E2F4566272E352F451A332F3F479273343944294445547656757130395126
4A4C25364C415D606575377A9F4B64854C4D77943C67605350526D484F616973B9234F5E
4E6F4662766C31756079D2838C64A66E9C546A5F616F3E53462D3F23783B6F5773935DAA
605F5B518D5590673C535A6850483B4662848E73BE9B9782AA5062CA
54579251725B7ACC6D36555082BC45362F4A48BD8C2A3940688BA229215B625D876F1832
424E39762329386D2F66682F3877913C3A64223962492B5C3B27596D202E613C386E4F22
3B41603D6E621E2B566D588A1A2D5C854182761E255377315837193547491F3633294A56
2C1637201E9099142851364DB8A71F49555143AF941536385146836C1A2B4B5B31755C16
4165502C54263D637325313E3C4D8350193B3F4976791C2B726352837B1E2A549B586E75
31295588364C722F3F74492F74301B447D442569264156642F55513082944A3B4D4352B7
451D42684BA753252C614B856D184F7F408D8C30568A5C50711841908259611E2B619A3E
3C2D374B775A315E3F4666742633514A438C5C172F475A536B382D435C54606B2E2B3654
595A62491A3E64624A53341D405B3E2B512F2D3F6D4D214E39354B75211C2E515581A665
734D6A5F507D91879BA6A5929F58707F56645B43374B5858454B455B446F865A5F616264
646EBB6D385A343345414366484A435F6165503E73485D734D774A6E684E5931664F7467
6E6A78777B6C5A35703B3F72395E524C483F38362C55314E2B432648703B324D5C574C50
54455D53654A664580464E4E4367406C414A6E472F484728534453445A6E5F4856436485
60B4BB4864926A6A5267563F422A6255714EA043464F736C717E3740471E7DD84D336635
70335E3E114B29304737423C41501A343C43134A5B43695C3E77473649384B4B1D545420
3645393F664F253C879B493B4C495761505951652F71324A4C3C5442598E755468475262
1675186B767582AE8D6A8A4D8B4AAD71574C776464855C5B552C59316E5084607F8F6F92
839C8996875D5A585A575D87494B38A97467CE53719DD075968E8399
5E676961AD7D48667D6072473A69784D67322C497F414E431B545850336D352786943944
443946A06A265F414079851C374B756B66672657896F469B4817477D6351911D1E408659
6D8C212F3B673062561C4B5A36213732276A70172C3F5A44874B0C263A5038845E0F3555
5A399539163057593A7C1C1F386B3943501D384A7B40305921529AA6482F394244899F1B
374944826D302F576F548B840E40555C4E7F402435646A378A3615458F57274835334A85
413252412C6399452F53435294631D314D7F61C0313953553B706B1A3A775545523F3985
95455A383C788841474B2D6E9D4B422A2A6C994133413373A2252950585C902B2C546374
754E1753654F6EBD2D1C59563B78952C19567B3053902D2D4A512B5C722726806F213C54
1B3781832B33582D4FAD671A2841354CA7501B34537369BA4F233D3F5036482E517DA859
7D4E7A7D70B18BA34A45565989878A7A3873644F4D6A8A764A536696454562737C66547B
80928A8A573C4B424E563155475A414E4745584356332F5B5A6D7452625A594F54525740
87836F92485A4C2A626A4266364A343338253D22173F4545253D223B4942384455384045
493E4648766F6045894A5056537B527C4D587F593C4A6E3273455B4480A2A77D7C5C7D88
504A46628D654146433B6D407733785A6036814E57556A42345F3B6073407FC35624573A
7537885E116B534F6D3B412F3B52435232290A6A5F2F5951214139535031513E1D697429
3C354E3C47465A6D4A5920756F35465A6093657E31734F5B5B4B6D6365616250B8329174
3B72468F8C915950494BC1789A50BB5F824EA662586B3A503D2C4C4A744187513A4C7A8E
728764524F393D4F3846413D5D535E556B8D8784C482A095BCB495BB
8170854665724162454C9247364146407C42233A5954797D1931495874A730243B5D4682
6B1F1E4C6756A83E1C537446579A172B6271474E623A4E58682E4743324995562238233D
65BB5C26562F3B8F9C252E514E54795B19394B3D85A72C2258863454682724425F2D2456
212C7D5D1833374A5E902E224346587F7E1F2658655440961921425367615D2426587C30
666D2840A871337254265FB9772D4C302F7F982634414E4DBC7A18304E6655AD431E3D5A
584D9427383045444C99173447684373521F38696E4489342E8EB34F50492A5FBA493762
6291A3441B68745E8A641F38615B7D34192F78505156254A5E3F578932478162397E3E2B
667F293A623F4E77662B4B48293C885E2F343F2C428B3E28413E446EB33A363E6C647B93
28284F8158567E28214891376E53202A3B652A324C2B27505E1D385A2C6DA55E6784A962
8156787F7C88958C5A70955BA08E87954E61634F4C4C4165524F3A495341714E4E6B697A
967BB7815945325B755A397F6179466B7488663778333D60314F4B4E513231385542595D
7A554E695C6167394F424560445F4D4D413B40382B4932443F42313051513A42584F4842
4E494E385748504F68675E4C4F838D8546547459434556535D3B61869CADA5757F71536F
61516B3167AB62676D5180427F37607A87559A5A744CA75E526467A18E306CA0704F694F
8963A95715372C334B43302B3B661722394A16977F3555413778413A4035864C14445718
493E353B67593C4D627B334F652E6893414E637C38774048644F4C6C6F9F8A4862264655
368E41705D514C9786646A4D78629C455438734367692C795C3F5C2A4C2F4247384C6E96
534F7A99A450464F606C473E3F5933586680986D95959266995F72D6
A2BB9B455666718E353D70586E7622373C423B7644225367336062282A9F7F255933215F
85433247193B9C62202E4E3D55B42A1C3F533595BD193662754F9D911A366B555C752429
45577E32854C13326C3E6064173751AA524B3A295276513C433F4B7987202B4550486299
1C183A6D4F8C802944686952AB6D1C496D5D285C45325488571D4E5446566D34285B4C35
9083302C73744C74422A3F85657C5F2B204EAC6B6465153D697B555D5D2D30528C2D4D51
2D3F6E7E2850423D779D4E33535E708A951B29424B64C76D222B49547D912B425556508F
62456D6C3262451D487D4546342C8F742E61463477924146572F60B85A2F446A5AA24F23
5059607A7C1D3C684F60AD7E1B3745506DAA65273553744D8729344B4F665B873335515B
3D2D39383D506C2327353C545F7C172D4E5A435C8B1B1C5D5D3E728E261E5A967E78885D
887B829D9D678C675E845A5C88A49D79516B5C3E625747625361505B6C6E9966557F7F73
6F92A07E434B1827404B5061425B4B5E424550445C545D6041718163544546534C43554B
574D646C7C7A583A6B45475F31415C4E3746612B325A4F4E3B402F344938263645463432
4D65482F554C523D594552555B5C54624F537852373E4C2B4932545470878E91AF6A4E86
784C81646BA25A5E6E4E836F88385B5352427882814A945E4A7A3E414C295A774C3D6143
58465B7025434B3E584141523B542A2F273C204B4E557860223D4C6B73404D412B708B36
29404C3E3F4C444D53832B687F32334C6A70586428594547534C46445A565C7CA6288946
16521F8F7B835546493C6C3F9F4C9D537544703F53642E392D22402B4D48466240807C92
55567E4C85404746365B3B4534442C6667707B7FA172797899715B90
6973AE5C744F66B8724C763E818F4D33524867825B2133575CA07125385D5E56AF3F2C2A
62647B7E24202D7948775B28365C602C713E17355D513565212B51893B4E70215E994718
354939316C73122C48488674132448655B8C92114D6A52485E381646734C377E4E2B4E7C
60375F262550633430522A5F7A74232D4D4D58B79219306D7B50A7A019438470528D3E42
517651616A1C5871944A565D2F51784B1D6F55325698692D575B226C8830255B72369F95
17275F584D906E2361644D578B3845568F5D777D20356AAC2D603C274599584457384571
66314C58587D5527464D4C8D462249A04C9A454146626B72683753754A5554173B6A793A
71362062884E4A672E29658D424C6725377488233256366C8D4D1A4F54386AC267154F63
495991591F4F6A475D732433486A47325326234362752F47273B54823D234B3A87808083
5B6A6645476450604C547BAB9E6F9390847265565259477E5B665A5152468464537E578A
83926D7B5C4D683D495D285C4561464E484E60506739325F665E374D7F695B3A6449644B
7D7C969B4D596A4D5D5D464C3B4E4134351E411E173B2B4A224431306D4543435D465344
412E3F3762675C3E815C51575375656C4539685A4240362B5039545681A2945658584784
7A498757679A9E9152446663674E588A9A5B7D624944797351784B576138508695475C46
5777686C1B4364425340444432433B38444719535E2C4D4419443A3453267F4A07375518
292F304A42585A5E4A7E354D5C36314748666D735C644451594B3B4C5A556246644F3855
418C30504F533A4E514E9A5F98716D4B6139644E716D2D46362244567145545043405AAB
694F88519B4C4454416446413C53427D76709B8DA9B9B772A36753B3
65516276AE4C4B647181B84B3C76736DA1302F54635182483346865060952E2362813A49
292C4E794732552E3B6E78273D3C6C3FAA6F2D37575965852F204943496AC01D1E62A646
99852A2A607E3F893D152B4B501B5B372938733E2E3F352662671B2B453D3869381D2D42
5450A32F1A2E533C73B92A2F507758648A252C4B6D494C732A32579447413E3132797E1E
39443A5FB85E1B47585BA67F28405B493FC65A384C615358A5691B505C5F418E3E1A498F
3A4C7F2C195D6931376726328B731F554A388ABD312D4D8547A26E27348046677B1C2B58
554F774530638862736136757331543435819B2E4846245F582859693F92762C3661474C
A0771D4C5A3F89D131275B775861AB1D174C7B47577B121B4B6D3A746624314F7B3D4852
333B6189283B6034294D4F1A394A313A803A253440724D8638153F6C6338935749524E45
60465F6164A68B9F575F8355576D6F734F675E5056575161636C4A6476458B715C8870A4
809D919255503C3E51683A8755774F7463487138924238573C67434D624542315D554E49
6C4946764D5854476642325741463D3A4E324C292D4C2D3B36432E4155432C32413F3E37
3F44573F563F535A52414E3B4D6E9B8C494B926E4439453D512C575F67596E7075735A71
657F8F555E6B4A444E485A715C2C3F404848565A714E744F657853505B5157A1722D5A51
605A6476235D3F2D4B52364A24402A372C3A1248643854572F4A4D456E36BB8215566316
3F39384549424656596F1D6173732A44515964734660614C414B5D464D78663F91434A43
2C573552486B549358449C7DA09F9D866B3357425B57114534284337435360517C58658D
454B805C8C798550425956676650214F6F8191A1C79AAD6BB0A082A6
7BAD7C4C6A6A667937475C473C50313D5A67304C3D2550671D4237305EA8412541404F7C
3C162F4C2F5F9B2E2B4D4E3C848C1838598E8596B13324695937B261264A74572A542F34
6281332B412A3C7F7E2D474A2743A042243D415C689437232F6859646625393A62337069
11417356254C40262C5B47285D361E4F89371F423D385A9E3D1D436C5572A6312B40665F
8B401B31828137631F294390684D66271F54814A4F641D3488C16946702E2A90801F335A
495A8E4314356446747B1D2963804E74661D366F6459693525518E59665D24377D552667
473784952249495B8A902A5C65647A35293178628A712056663689982B48835647783033
6293404A492D4176973F6A442F37765B465A412A44A12D2C42474695B72F2737625F78A5
232C4A594C668B1D3533382E4A62112F314F2D5B581330434C1C2C4B131F4B6463739653
8F57748A779D8A7B818E7968A7968E7F7570593E4445373853603F4E395693544E66907B
7F70B094414E1C304D51436A615F4C646C5C61408C4E46634A7F5A5A7F696334594A5F59
7E63587E6F8479529659357B2F43483D3348482B2D603049364E2F39544B313D50554740
535A512D5C4C5940563E4A5A5D644D5E4C48564E3631413639314D6A648E8E9EBC8C414C
504666413E69776A392652455B445953794D535A6145726245644D49491177CA8D41574D
8754616A1F4760334D3B356A3A402B2F274A3C7C77414D574C815547542A434B3B655935
334E3C3D6D614E62526D2752634841734751516D2C5C3D3F34404A3C577B815B8F234A52
365D46655E562F656A638D589D4F8065606A9A3B676427766A45465A4C4E5846454B5D87
75A582605C4740444A592B364168308D6D84B9777EBCBB787F7080A1
6B94B04160508EBF4A3F684E688A3046575768B4532A3B5C4CA17B1F2F61625F8A5E2D3D
652D57621D3784893F625E1E569E3F336E3B2667C22D2D3932479F6723396C736182182D
4158858592223336514A9671292F709E536D5926556872335733336680381C4D443995CF
4C143F4D3E8C72243D4048579A55153653563A742F2E344C4F399F68233B50483F643921
6A84393639575A9A581D446162647D2B2C51A26F8CBD29254F8D7E6C7B28234B835D476F
1849776733546920306D40405C3C4983772E446C4C7896502F465E4092A32B26436F54B3
672565A7567537224C864588372B706D4653492157812D444C2866A75E4144435F9B3C29
4674718D73213C41754FA85A293D4B535A9C47405D773F4056232A4B9F583E642A335377
4E334B32334264381F653D3E5F853B1E4244377CAC2C20525E576893152C4D589F8B817D
71887F75776592794E71726E6788AE8A55847354565D3F4F5658525550356B5C4D7F687C
8890848435312E27425E375F495A514F422B52534E333B606D634D47599052304E744331
3D648A5A3543737A7772666A43536260464B5E4637453B4C3A3D534F78515F63643A514A
48414A3E6E6C6644825252353C56625E6558685B59523A2F564E504E6A8E794551624E67
77979B564C574B413E3F5536423F4A54816D866F4D3C4E7488824D5F603E70A36D295833
6A534B7028704D1F304643532B372940474B2B454E314C502C353B3D6D2E78500D5E6C23
2F3D3E4E4C5A4D5E929B5E455659647E4568606D3E504956464D56645E5968578E509072
256024877B5E64585A6B9E676A6AAC6960706F5983623C455A3F4B2764345E48524E7FA2
51446C717B4859504057625B496153B68F93B0ACC5828B5DA1A37798
5178AF8591485DBF9368A94465A985589F594890993F6F3437566C313449303C905E3752
412D756C1E2C594D428A7E33254B8757B14A263A5D54928212284256368A431E2F535134
5528277D93672A77321B4C7A242D513A5D7766173B604A7A913C21558E6364A351294259
73809A4A2358A43B4F5A21476CAF424446664BAB911B405350738FA2273A4B497A743C25
3D6243676B1D4F66B077873A2A5F854E2D6E3930529973254B3047667539376057748DA7
342749645A8063282B5149598F2A2868664C81803B4291B4649E383E4A765D4C6F264578
A135795660BE894A633E359A6636403165A9692B3D4E45AF90264E89757A702D26526065
942B2E588A576D7E242E5D723A44482538646D1C384E4F53854421274566648C42204154
456B8D3E213D4D64448A4F2D476B5654822E35415B5855621D2C4474493A782A5055655A
66485D738A877C78717F574F655365695B615F5151505757535356765D4864656A786E84
9A94B3A54747675262723784576E52746737704092413B614B60373B5952472253494D3A
69504972484C5E4450402D56584F2F2C4937361733492642454A3A3B5D4635324D454946
46535D4E57485262635A56354C6379733A47583D3E3835372D283F3D444A636981987570
6A395B61518C655150445B4978574E64724B4B57575683552F5641395A336CBE6E395D5C
A5504D54214041253C30265C4A543B45282B105C514A624B314B4A4A7741B39A2E50692C
3C3D38505857516D525F273952503553434E4C905E5451483B5B6041545E6646993F4653
3E6340545768616859548E55835ABA9484575D35575E4553463A53486C3A473E927B7583
4E697B506E778664557A607666753D6D6F87BF717EAC934D61775394
625B614F9968495F665D983D2B4C5742AA3F2C416973854B28404F5479A31E3E537378B9
342D414F4C6E7D1C2F2C55365C57233955601D606E22599C502F44303A81721E30365264
894416173E785BBF292D24424451862017515B2F529C452D495A15824C222D6586374C53
21326C49263344469E791C2B448E5A836E3034708E4C7E88322F779B435D74273A82683F
7E5D276FA946255C31399EB3462A5F4A408D602A37527E54B658196D7F557AD632274CA9
9B5470372D6177304F771744866E3458343160A13A3544304994862D43527373A926384E
7762A37726577B65B23C2360685572341C5FB256533E24407C575594415E784A4A413960
876B284D42427391363648705E738C262D457D497B8E1D42474B47635E1C55615C247C3C
354D836E26415B1F2D5A641A3C472B2F6866264149315CBF401B303B3E5BD24B706F6D5B
6056564F5077AC8E4A5E727EA6827E9678996C405A5B43564F4A424430467E4F3F5FA67D
5B6CB090473D3F313B4E4658584D4258655D5E427A6061614E6F61595B656A3B6350685D
7F5953846A70734E696145743B5649353E393D112A56335B44515247684F334D5D5D4A44
547363456F53613A61474845555A505548574B35415B423530455458667078648E995353
5E415A4F677D585954476E59494C5D455F646B78733F59534F684B6A5D1270C87D36502E
4F4046640C46362F3F3D2A515F6F1E322D3229916336365A578353334E40665634595D24
29403641638644477C964439343D698143574E56455849483B454A3B5099863E5D335360
3F694562664F72885C4B5E598C5D89555C71804D666B236F69425B36734A8337472F6A96
A2B6A58385454946314A3E54345630AA706EA0929BB0BA69897C5AA5
74A59B497E8D8FA83B6F8E669B7F3A4770984B66323E57773763581B538E472E53212C64
7F254C352B40A5541E4544577B7E1B284D5D46868C2531475163751E416267527E791A2C
498C4B6E691E4F5E652C563825515C68293A3C4A6886292D4D554392A31C36515949849A
0C2A303D57836C1C3E572C2F4C2E2F497D4B2C64362B4876291B44473E7F9A2B1A62764E
97422329697847A233283BA7944E8026203EAD635E6D1F474874323A3D2D4571872C383C
4E519C4022706C5276B62B1D6A6D52B74418206D5A727E1E413F5E3855651D565852429A
30297889234F31436468387B335BA653244C4A7E9F551E4C504F80942D377B5572542F52
638660893E37767E6656A73A3B6E7C2A3C682F33588A3C304A2C3C709D2B2366494D7361
232B6E6B456D9B2B1D4A774669851823495A2E556D1C184D6E254F47171D4B6583775E4C
8E798768575E61794C566277866674714B60685B4C6C657D4B373E4351285F634D6B607D
6F817B7D32233C2B47633C3E4747393A322B4C3D4528284B583B3D354D59453843633E34
3B6984553C4C6E8E5B4D53596372644C403A5A2C2B37394F46403F54552F3C6B5C3B424A
3C3F4F3D656945466B7B6E4A4F6A6D8252456248604D4C30473746305C9E815CA4835F6D
6E6D8D415B67625244495C32674F4B4F675D4C51436165715D6C6486855C55967F326A4B
684A456B3B5B34253F3433553C552D2B24521B383F3D4C3F2B3A51405B4669661D6D7E22
23464960435339453C472F2A455F37516580735D5B6F3442515158564A44524787699778
2E4E357B7253394E494B713C5959785774678147534B355153373E33491D4E4B63569BA5
3D443F3F6645685037595D965550256F878F9EB4B4928B7093714B87
4E74944A6440558B42404B394C7E473B4846538F3F273E475B826D1A2E6A625F87252359
8D489F6A222A566E478D48334E5A3B55B03136736C3C5F6D1E519D852249462955A04C28
4C414D6C892C364B4D78B8721F27576B68BA57123A6E745DC72C26416266309A342F5A8A
5A3B73312F707315344A455B9C3E294A53695ABC4C1F47836E4FBE3B20505C4043911E48
5E562A46512A59695623553443699E37273741527E90213A6858548D871B44596454909A
324D446D409237353456854E81324C7F7632394B3D609C4B29564C4A7AAD483650446ACF
4F195E754A8751264F7F4BAD2D36685C3A7031266A6E215031295B8F494F53237C7E2531
4E35427F6C153C50484D90781D3A5F487684280C3579466C892426498E72838D4935848B
2E679E4836629B673678383954864323612D3A5D79251E32403F85902220305366698C66
984C6F7C69AA93B4515E556A918E899654645E51505C5B5B4B464E55682C7388799F76A0
8CA1D9C33F437341427B406457674752603C7C367447436034645144432F432F49354241
66391F52525B421C3A4234592132302A403A421F2B3F323B434A412F52382D1F3C3C3D33
373C4F4E4F4C545E512F403D5F5B686848544C465F564F4E523F59427E58725568665157
62414F5452715B505D4984636D3F465668575F6A674949424D814B4758175CBD8E2B496D
8A635F6D25332E34434D2F4A545E3F4D4037124F4C3660522D45483D55337B7229495419
3B4A2E4052615163545F59585858474F36525A6731593B45354E643A4C4C5C478E334059
475947755452577C6C604C366C387872725458466D60196F683A4F1E5348763E81454870
446B645764495353566B51555075497C72889C6473BCC85F74AD6F9C
5A527364AB48556C909E92394B4D5C7999213B526345743F273D673B5D523341818B394E
39297A9E30303E2C51C16B15353F3E5C99771D486F5070882F3360994C821D2B52638F51
9E2226554A35455B2C1D5668263957242C587D173050363C795A172B363A56C16817334F
718BA6253E58654C73571E456258379A4D2F506C6E254C5D3E349A95354D543358BA7523
4E594983AC2840666A7EB649263A8C854F98331B60704F3C9B2B367C89818A73393B809B
56375F33508C6A283C3E5556BA37374F6D578F642E6696704A864A2E62B17F4F7E2F415B
70499832484E6841642B3E9C6F446F4360ABA4744C5951AE8E18456A5E7D74204960447C
B4232180B945777031504B8A395D692C51867E1C522C4A5D94571F3E3939395E49275248
4388AD4827354C6D69983C3443586D4AB73E2D4A5C5A527F1D363C66493D5D207781764E
7554779C82A295B1929675C0C78D87928D9386527C656D85706450605B4B977B54858194
8EACDDCC433B48325E804369686447585D5D7B377A62576E47855B534241724162585049
675053854C52554A5C62407B3A554633404747222A5A42634852563F5B42435557434335
3633462B4C4A48254B31412F324459473B43493F4A5233243B564C6286A69D9FDDAA636A
7D55887E528C886867684F2E3F4773303F4F63676F4A6B653F515D808A1046E2B24B6C3A
52544C58185048263B392A512E46282F2C4D424D58394A664165513B484A8C7F2B626A22
29473C49646C354942585D2D354C48723555704D32744E5B585B5F5754727E2A69394F5C
33752C615760374D454C5946514097649289AB494A3E1A2D36305F45674880475B1F88AB
608871629A4A4B553F635459666B37B68C7CB58F868A937E80605B71
8D8E60568069596C4475935A46592A5D954A3E4E3E467F532A393D4AB17129284F8F738D
43243F7E567A792A256F864B708110575B4D3765561D636E453F4A2049635C1C3841414B
73761B35494D7E8A3F173455559EC11D153C73497BA924206B7C5BA8851D2367873D513D
1B4B423D32583042665B1D3451395D858625485A674C767D2C426094A084823329568F69
963B2A538E755079373F83862C536544407972244F615F6DA66A214D6C617CC2651D4274
926BBA2333757264846B284880554D88303C486C3E3C5C3D405C803335406B537B24313E
3944C05D2D644E58803E2760617D7A41215DBEBDAA7D5C6C61447C4E345D893C546A294E
875B3365465474A13D3D6245537B9E2A2A5E805195622A415373667B662E4B55556D975B
143380745D6979302464572334520C296D6A264734294762341A4A312B477A259A916D57
AE616F76698EB69C5854464C726E867C465666633E49737F5179525B472651676650446E
9381A1825949393B4E6A556B6253485146465A50674A4F604C7072694E546138595C634B
7178797F4F5868445354486F465E4D4144434E39274641684B59583C683C554E5646483F
4746583C6F5164406A3E5A484158465523323D354C393B363C2C434358394E3F59505B7C
515D666C7D6E45423B24473954384230494F403D3E575E687F8C78425E3B49917326455B
5B6864591B463425462D304C30532337373C31716B5B62472336443F5A476B602C416522
2C4528454778577C56786D4A696A45814E716075475A2C4B37414A414A505451A5678970
2854437C565255634E40763259368868605B5437628551445440433A772E5C5AA44A525F
4E5261325D3F555347695C915D66506C9995888FB6A0A6A59D645D93
87A2994E757B8AA63E476B837C8B425158526689302748664586402C2950444F52134258
391F523F26578C251E50462A70AF2C315E4A3B797919434F40717F202B49835C75691B32
7B8D5180592641774B437D38234A8969365A20174A8E55244F312C709725294038629286
1539595B7093621B3D465978AC21313F6D5257921B454A5E4C439D333171793F3B613C43
97732A4256505C9E2E35446B5C8494293C549449937B3538726D3B6E691A4D647C3D6465
244D6272335E403FA09D2729533656AF8A232D5C63759B333F4A6F6B847D185D815C6D80
253E9EAA4958204056513F7B2743A1923260353A79892E615E3BA38D2F5C706186552836
7F5B61B6534C64A45B9EC34C3365905764911D304C68304F5E203B536C3228551A518E86
273362302C78962F244B4846749F1917415978945B1A1F445D3BA06D1F4A563D5E729890
95887F8D925B5A6D98A76A6DB0B1C49152615E505A50606E5B605A4C5B518265357A6186
5F959C6B424450503D5436485F4F3539504350273D5052483756895B43374E544843506B
59332A434D4944233B433968615B5C434333492E2F4743445A664234456B4A364153513F
31374542594C574F614E58484B6D4C6B2C4B482B52404241553D55659278966B8588363B
545871482554594E5A3B61475540562542525257444F4B4441596260834D5DCD931E454D
7D605F73153C35486B412250354F354B32421638562B2E532D5042304A3EAF9C48585E2E
3548384A64784B574B4A513E38584C55374F4D3A334E3343334759365A8486424E403E4F
4F744D55554A316C42425E3C873E84445D61B8714D4C25628B41482B5617705B4B337491
709AAA8684565457657E464F5F93686D9AA79780A5A5966D796C77C1
5561AD8392434D82778774396F894A5B7623509068405532406D6321353C2B58AC53255B
7552A68528264D754AA64E371E3F4A8EB33A45464547977D1F4C883B2B5C4A365860322B
6A392F485E1833544F479A6E203F4A61778B2D26264C754B982929476D40486313378C80
3F53682E4A8A9A405A422959715A2A4F375A8BB95B1D443F495FC53D2146806A86984247
516F4D6789204B9D755E933E29638235416B412C698E36385D5257C6BC5327634C4ABFC1
383A56515BBF4A203077717175364064A04B4F36274E85833F4A32496093564456485794
4230493C6FAB4B275E5C4F97312447687C9D4D3A576E5A814B265B716CBA892A69B44562
6A342E6578437654312B7664255B3E3F538963295A333C8DC23E2B445D3F8DAB2E375F7A
4574963B41474A5D57951D3D50452E4B6D23287062324D411B2656832C2647476F7E5847
714B66725B8A84A961666B658C624B8F5A788459464C66A47E6E6654A1434D584476867A
78928C77355548423F7A4F6A82665555614383327B413A584B774B4F4F42662A57495E38
624A3B4A3F575238395A6F6237336561252B68331F3F4940353D3629523D4B34394A4B22
3C6033264C7B45274E4058455648425E3E52473D4543474B4E3D628C8583AE95B5843461
504F6C6E5170796369535A40403B5637495C5A7057596958485046638B2C69B08C4E7061
53565F612D534F2721373F4C3B50392D3D55436C783A46543D6A53374B364A4D135B6628
1C4731482D54355749A0703649522F53435867374764434A4C483F50573F593067576D72
1C472D7B564F344E5168892F5A45A4608C47463A405B142D61396129593D6F5B4E5A8391
3E3E5636503149442C614A5E7D763E7B8792996485B0C4838A75607A
726E525EAD68494C5F82C23F3B708C79713D31586E749C27335684517B2F454186B47DB3
273D68722F576A1B2E6A89414D2F2544957E38583C468BAA423161645A9E3B273347568C
CF2B2E4F4A3F969C3431618C517A772726565B27455B2F3F533F236C44398588371D445D
5E7E6D212657565C89411C447887469A4F2E3FBBBA387A522246A5C13C66371353AFA42D
78323F58A34F29554B6A9B6A182F75676AB3312A4696967E931A397E925E51A2423F497E
505994294080A23B5B632E6276452B6F4E53987F2B36666563AB453650555B98933D698A
41499438228C8F425D4B2C5F6C55842D4458813A4C4B348D6F344536337D9C423B456B9C
AE35365B4849AE8F35404F7850A7752644516443AC68243D65574458542B3A864F2A5354
275BA65C1F57312056A8581D313E4658A54512426E4D755F243C3A343E707221A18B5F4F
A173828E60A3B2BD649B806AA2A3798C8A75585B6864678B745F7C50B54D597D3D976491
6B907264374B383C3B6044444D495153443E72577D46457853A1655D5B5277316E736542
6F6A706E4B507063705A2F4B3D4B3F3F4141503A2349436554523B49664C5A4D4D48555C
3A29583D59394E354E547346406C94742E21455F3F3A4B474C4E56767BA590775C743C64
6C577279647D6346382156715D373F6686554D544F5A655B4A666E354127359E872C2D59
6E696766193C3720352A19432B4A373A454B2C3B4F4A5477463D414B77576457204D6E2B
224540553D6043783750373A83783D4D435A5C505D32464C303C424B56505A41A373465A
395B3B5E38685455534785536753B55C50525653679A2725593D805271435A754B6C658B
644A5E405434505C41715264838E517A9FB1A87C9A7E90A68C736E89
77D55E5B5C8B7F7B4461737E674C2D7660314A642B3F635221572F55584F1C425B625BA9
5E2D48595D81791E30594E649E67224978757E6C333D538F637F8124394D6B405444193F
916B315D2C1C4C843C43552C43907D201E4E3D489E971A4B795A54C6921438745E6E8D42
3756563853B9532B688242506C2B5770812E30586355835719214F8D759A461C3F92AF57
B5432F548E4D3F502A328FA8416157204474652A6E573870AB691B3C4B6888B9512B5176
6D87BD2E16549E588D952E266E7344A53F373D745C7475403641674F61542245474E5497
416FCF6631525148A2522E4152669B4F25469388986C2F505F4F824C385B98978E681D4B
9D634DA44C2C569A4F45682A3979931D2C4539568A9E2F35514349885925215B5A6A8140
1931748B67C2433939607E487224282D454B274A3E1843713E2045231D356C3262715647
72606D5B55876A905D8C61878C7E8F786370544D5C4F6D7268557267B3415B7D479E6D9E
6B97A5933558586437764B52634F675F683A84385F3C3F8081784C525F554A275651583D
664E406348495D3F494B397949535562504953383A44394630382A3062445A3947444B39
2931504956466A50883A574D4B5A4360424F42444A3D4756514559A4553867A0AA782E4E
648294382C4A7F844622443156294C3442504768886056504B6B754C680B1EBD7E1B3F40
645445500C4945446233284E274A1F3A2D5A4A426140366E3048533A424875725250603D
394E3B363A633A2941774F353149273E503B54514941244034444E345260634048435761
39845D593D44537B515785477F6BA6465E4B5B63595A444D634551347E3C4D6F6C59678E
3D4A463E523F66616B79718D9A7C7D9AA39E939CB99EA581955B7CB5
57869D4F5E587B963842636A7B9D2A4C564B77812C2970735FB52C386A633E61631B4470
646DA0651754724B61C13F255B8D31563C33447F482D5546336F8E31314F2F5EB55A2D34
525373AB341B3B693889D95C21476B3F4E994D0F4B8054527836227FA76B775A25319359
1C435F3F5BB4411F3C3C526EAB34255E8AA16D8A1D578C813F57771E495F5E396A3B2248
906B1F683E4D825F212E47483CB0801D24595C44B1721A2C75C06585582042A0B8645448
1F6F8461437F353B548D525A573F528D954453284A70AD5F2C4A3857A0A02B4A415489C2
582B73686D7F3D2C497D4F72285370765057333B797B3B5A4427655D345E3249B0912236
45504FAF622F3D5A4C81A133235B8F57669A244159803E64732A4F615F29466221547B7C
2D344B235B8D6A24463C3260774B244B4938617E691A2B39593D712A183B40366486816F
8C527B9362998FA786A4827D9461595F51563F516B595567956E6D3D8B5F6F7045788179
6E8EB2C44649403F4B684B536B4D6B62744D8D478142427D4F8F6074524D7327715F7858
794F656E5A596D4A6F7336716D665035505943453F603E664B364B49704760444B3E4F4D
433A66446C445B45693E605E6C696F6D3853545D4E42543B564447587272795C49543A40
4E4356694E5453445232693E573F663E5B6362793F423F7A5B536480A0211CDD7C13735E
8062576422854A243721526438493A47336537486F33477349624B2B422C585A1B50792F
21412E4A52923544397B70293D582B57502D4D425E563A4A46474730453F4F3A55365059
2F37385F2B5D576A584076337745D388926E7E914371413F6E355C35683B3F5E65686196
5F7B5F5B6A3F5A59406A8F857B73689D9CADB76873A6E5555183746D
5F68B29298426088A3897741528154754A30447B643D74283D5A6320493133497B57405F
2F4085692635363078C34A2B474A449A952A2C53745CB14C262C727579AC29203754287F
9028355D66316A64212E5C6B247454404387771F4A612F50773E32424F50A7AD283C6D86
609A781B455D7A59AD362F44635D35744340708B7228485A516699562A555D56957F3019
626657BC5825527B40829F5C1960BA5151863B2F4F7449425D2D6B5E53222E6C4250BA9F
2D397B5367D3581D3B7249A7A6312D7BAF487C312740837C48591C48497A416547275F69
8352702350A675274F2F3FA662253E5B718D4E26536B5893493A4F5359D061203D6B3A75
8E234F515A476881323F716C3775442E4D6A46244322455189421D565C626A64252D5A59
4F93892A215164477D6F202B698E488B61271E57AD7E3F6821404B521E3B312B83955245
84677E6F4F7E9DA96A6F5458716A6A98537278505C414D5357646348533B41603C5A426B
6D8A8E794E523E444355463D4B4A52403E36545C6B43466F738C5F5B5B6B652F6477573E
616A79794A4A7B697371518A47656B4C4349454B324641494F474345594A4D605A3F4954
4F58654C7451634B8F4352554C6F67A1425B70516A4A6D4655376E707667AA8373724464
673D686C6B776E4C6E495A3A56275647426E4E605A674E5F477B542538252CCF82306E50
9462463D0E3C322544261F3B2739497443453439533757713A4E403C5347979528669032
51723948396A30544F9772558874363A455B735F5842375B473D434A69454F2164625A84
2C4D42665D605779694E55327E52E66F81604F5F3C985B426C599067B86A566287758981
454B614157637357445F556C6E657FC5AFA6B18D927978696CB181A0
7AA65D69A5586069556086465347447771272A43578F8D43273C6D5D8541293A515773D6
292852884776841E3680834B9E2E304CA6786D7A35264F9F594353215DA25D2F553B1F84
C63B283A3041996E35384D4357B5941431526D54A8992B3D485038733221499A73416837
225591502D773C2C73632432385B5D9A5E252A6B7166AD702D3871674162332B6A956E51
6C4C2378B25D4A5F2A36817B3D534B6F7495342F4545409EB329379B703D7E9940505B76
5A86A32A44ACC83E68473C6371472A5B434953783F53673B5BB151254361428F5517327D
61588C2333708D568A3B24708A635D1B5F62A650963A497D7B264636347EB7504D3E2D68
9341326D484B80B931384E4D61A697235B5D5C6DA04628515B5A609159244A4F493E6551
263B866E8A9052205F8A553D44321D5E973925343E4A59872B274D363C947E235A616452
66455C604C51517F65867F6997818685727B63626E5D7E9071486F649D685690519B5A90
9AA4947A625B576E43714947824B655F723F75395136355F374C3E5B3D34412D5747503D
613632655148673C4B46335C5F65623A533B373A3B323033404C3B2A5344491B323B432E
3B4A535957456066775D5A534F7E779361516B4A5645705055316BAEA160B79C847D2B51
68294A5A4965774F713D52425E357A2E4079527C4A75686E443F54484B2121C2AC223C33
4053534E1549393C533327452C44362D303C3F79A6443E51506853242A2E404E2437651D
1C3B28375180292D368463223C4532494228373C493626321D304A2C44494D465C68545C
2B735772555D3F4933506520563E9D68794F7F916892556E8D434E4D5A403F56B45F6070
7292745D6B38474863655E61828D7D738F89AB9DAD839387866E7681
62D18247816FA59146697A5CC8782E7E843F5D61253D7F704D5B1B312F5927725026423E
323446352D35553558533F3A685027345A425B9B302A3B536B6A84152876597D9F3E293D
8B7073912518476A324E891D1C48754337642C2664761C3647525B7B441E285B7A67A635
20467A875DAC361F5E7842565C1C336B85543F671F4066724963792148AE6C213058358C
B0401B3F7956787927285E7B4EA97E364894803E6A75273FB88B416F412153B25E286247
4B5B97471F506493A36D223E635588B14F54577B547C8E2A4B846F314F454D495D3A4C5D
4349766D3865424965652E483149A23F2A57454BAD671F768A565F263047896C6D4F283D
5E754F9E223D4C69335561214668974657572E5D555B2447582340647E374C4B2B6EA65C
1A364D4992C9642F314F5B78903F313268546E75591B4A594C43633D1C59965C5D6E8889
68506AA774696AA3ABBBAE7B835C547345664A435C4D4E49634C5B395F51536838597564
545D90A94D4E4A443D4F41486F6455598081914883453D79438747744C406D3F84526079
71435C62747E7A4B777E356F473D4E332C513A4B354C3A4C52504E3A715665464A555A4D
4F3F63375E47522F544650637B765E765781855A5A4B6A475A3F617284518D7F997B2E56
6630483E516B905F73544523412F592F2D6653763F6F484F3E51744D532E0B5686204B54
5E5161721A423C2C42421F3D2E50333245323626453D4E572B283924332F5D683053A228
1C3E233D3056233650A37A2A484A296B4928463441323B442F3A352447548225423A587D
3134323F47675F5C454A5F247A4DDB76865C76A25C6C413E4C2C5A4870525073987D8180
4636482F55375B48374C4C63794E6791A29DA97E7A59916A657E596C
5291BA8B744C639251744938516335454649537D26234A347995271E24444684711D3C54
2E6BB8711540533199AC243460626F903E47375A602F8424297475454F6B15478B3E1B35
452359A02D1738604294A2231D20508C85BC1C2B69553C8A76172F6D8A33576128659072
29643D255891452745396986711F20507B71A369252951925D8BB03E3A3A8D535F532D4D
516E497A35273F7535404C33295D801E2C4A467F685E28297F7097A750394981916E9939
3957778550A1233C635D3D596E393E5D7A245C333762AF741B51474BA18F24534D4A6790
3630686F6CA640395B636A9431395B4E707D353E7C6B457C376A6E57244B63778D6D203F
4F30479D4827584B428EA428324F5E4698971B3466763B87AD2540575644535A1B1C6CA9
397661243E668127553422386D69303B23363E7A7A2B322A34679045172C58448F995251
7A5E6B63394F78706F8997978B7B5A9559856E557A586C5A677980496358415E416E4E81
7488836E4E5C42403C6765678B625E5E65365B426B5554654A6547653F38503C5A4C593E
6655947B42416A5061804294475968403E474D53293E4D455455443D4B38514F43414551
4B5F533E675D73458168614537547C5C414F624F3F41474344595E8C94989E884B764B55
614F79767D806B505B534E35533A56493C61785D4D5E675E414C6054685732708C24835C
5246536B304B5C3C4C3E3253393E3B29343E423E61314767413D39385334617331365B28
2543283A32571B3E4456391B494D172F37495B31353140453836354A62394B2D52384677
3554313B2B4339574C6C804C765BA95C5433426744934C4456487C4D775AB18A63477887
535B61464C3448473F5C4E7D7C67709F9993A6A1CB5E67615E66728D
4F678DB293474D6D6ECC6B394F524D97682B316E6046692D496B764D4F153A5E562B656B
1D346D7D4B5F3C1D4A974E375537697246263C5763869F22175C775483932220636E45B3
A31F43595B47A953313C6D4D4856222B41723E1960272286801F153C435BA65622395D69
58A4461F4FADA03E772D2F6B9A4D525029357B9067446F3A3F5DA0572F4E33478C903D47
5A595FBBAC2E4C572E6C912A2F416E3B457917325774424559334766593356832D659A5B
2D5C633459C65D285C57587EA62D3A69817DAF593B4D6C7F90C6404677975D80481D63A6
4E4873276092874B9B3842A27C27622C44966932685043976E336673639349218991498D
9231395A5B539D6C1945785A437F49364280506766232D435C402C5629417178262E3B49
43899D271D485F418A552C25456C84762A223F49653875362C1F517939501927486F6F6F
7762728C505A909C7BA477568E7B688E597E5D6C634F666B594852596A484A564A676271
869B95AB595B49525876453A6F63614B5C556C4855313F686284477553575A2F5B5F5446
5D46436449476F705A56656E3B474B3E3E2F28423322314255462B30473A493B3F3E4D53
443051515639635E7E4E5C464D7FA289454C6A6D634F6B5A673255A97947626874736886
6E495A706E716C5150376D3C622E674B6074476C476B7D5B56624A466A35547776374A4E
575658501344503952322F4C344D4330434437375C2E6C7C423D2C213B2E5F6630447C28
1C361F3F344E2D4C37674D22707021333327462D4736394D353C34353A3A4831653F456B
3B8851444F5444675F578A51723F6B5F642E737B6D8D4D4C4C2D4D426E65616673416668
35477E89733845496B78444B78D28577AA8B7E607C5B646E5F6F8166
88944E5766516E534455793A6A3A285371364959497A9B413653405391291D4E6B4B7980
171E5B6C4B89432A3B9471597C1B3D58846E6E901B57949038734C344E984742723A2243
7A3731553C446C6B223E3B53677E3718335B4368B0232A4463494573223C47583A694D1A
373D67294A4533446A3F23384A2B798C2B1A355E6076C549293C866A7789382B5D83668F
9B294153757D6F6033475B4B255D4A3B6FB44F1F604B3CA183264153514093B132394850
419C83314150794C992A264069743F5B1E56787E3F59572664985A3B4F3D3AA08F1C3F64
6C617A2E2F514E548E3F2F5F8B757A3132437F6DB6443D64584E782E445A983D5B57407F
A34D6A7431405C8439543F3751AF7836624957589D822450444F75B86B2273945A64883C
2D5E907B5F7C2F454B65342341174D614D1A2A562A4E9F701B273A3A449A3F175F544B46
4F4E4F6F6644635E9799826C87959F77525E383A5D5244405382542845629252194B695D
314E92BB413F43372234334759434643584443354E49414C414A4D5535324A4255534859
5240625A5F63645251593F6E4F565E45414E3758313E4541534F4729554C594B454A6347
4B435131524C64496941505875797D905E8E754B3E5151413A3A4C58756E7E70A7874034
5B48656565595452744761424B3D673F456047775F603941293F5F404B1704757E22515A
6E615C6A1A49454559392C48284A553750435F434F2942654F3838323945596B39427326
1D33173D234A193D435E5B292F45212C3232472D4E35494E2D39292A5637483D4C585169
403D4B37795C5B78536A7C58A85F675866484A6D46655A4C46385B4C64776D7D83819577
45647B4B715B604F374D4D7F7B516AA07498B2818096A08FA16E737A
63A24E543D824845984E526B8D5344723835292D5C406D5725624D2153745735432F2F5E
3E495142385C6729775248655B5A206D713A5C482750644B81677E402F88592970574357
6D4253885A54516949797239B07B349A4C41929E6323BF62368E79603E95422489974F4D
53A443259483548E5B3D6F5077553F76774467865CB371756A4A7D8C5864764A628256B2
3A627C41763F54654760C7322065803C84821C50996F3E87A7393A6178478446687A8758
7F865992ADA581A6C57D5C7FAB3C4C6FA05488C06B29779A3F5E49568E45569B4D7FA159
74A74150C28834874A5084895357CE8469C1A66148AB90AE554D8B785558362C5B916840
5B7741216B6E7C445A6B5149A17F3D4C57393D724D95B97539676C78223B635734899C50
3B55964C2E6487783C855E3C55733FAE7D42987B51BBBC684C4E638B382566985BA3BF63
60686976A97E7B2B1515100E0E2B453B7684802D2F2E2E2B251F1C2139A67A4E49331323
88321515151F162F62865E2E24272D39389DD051281C1D2F4652B0BD9B3A2E3740353747
4960A4B55B343E41332E32334A91AF63574B2C4BCE666825120E0E0F235C9DAA70B7934B
3F39385544578AD6CD7B41377794456B3C353F49767A53394EC56E87ADB9AFDADA877F9E
C15EA786574C524F2F1A1D4C3D3A7C785332992917181716151D3B6A93D0D3D285638684
84818C81B4B2AA5C736ED1813D35261C21354D6885939C899C8424A5DDDAC882866B6B6F
727C838497D2B3562525355269201F1D28486D5E58348144341E2049CCB7CACCD6D24B58
1C1A2C7D837326337534181D29886A65878988ABAAA4CFABA9A89B87806A442E324FC7B4
A6AE5D50506A8898928AA6817AA577442F63473F6546475865844448
609A4F4A4485434F852D4F7B8750476439424D468B4C696E2D764E30687D6446442F337A
4B4E492C4577702B85503D4E4A462D826E3F513D1B537145956F3A2B4CA46B2C65353A84
86455499545281784B88781A99533FAD53246C9D6821C02E379B986F35C23C187244132E
3E7449207836317260364C37825E29574C4E876F1F955C7D7D334A5A558EA052455456A3
5F55483463705F812D65B245386F703CA38F3B579A57224F966645695C3D7B5E3A5B9158
A5885878995E4B89A1567673984C5B86994C82C6844688A846553E328247598433768557
8C6A366FBD673484645B5F845B61CF8B5274848854AC90A97A47788B7460704576AC7D4A
588E80306F85844E5F6A6E5AB589405F54423F7A4B8AC3775877787D213B654C37989139
3965964425476F713CA58334525939A486479276337C8C4343595A80362D85A5B1AA7652
2A2021329093732119120E0E0D0D39405896A14A41393A393A3D4E68AD9647403C2A132D
761B1115151D1611131F4A6952322A2E2F95B75D1A1C1F27324393D5C4551F1F20282522
34286CAC3B2A2A1F2A4760583623368465565F6DB4A4885A2A132E585D476D5B7DB9994D
495577956A654BA48084241C206A8F5EA57669698EA8624598D586A3CBC2BECFC9C2CAD2
A7965E301C1B2D4A4B1F171D529D988E644A78181A1715151515151553D2B072BF522120
28374B77C3BB6C5D3848DC7B1C32361C211C1D24394C74AADBC092B6DEBDB3B8886B4F3D
3430292A2C96BD5348222C673F3B42574732305E6947765C563E4687AFAB835E6BB96119
15151C428F5B502F6E611C234974837E99A6A9C3AE9FAB829492A4C18E75816993BEDFDA
DBA66659595D57617394B9ADC8BF685163321D232662797794825B1D
5688514A374D2C536D30365D674A553B174F494C552C8C772D651B2F5E87765252292662
4B65451418456523861736324607206164386D731C33563B9B9C401C2F78474F7F3C1F38
553879B65A2B5B4C387F813BAD55257C5B2F74883B4AC2522775863434A64B1C804C242A
3779411D71442B5E284A512E776542604E31598A5E895355724C556B536D766B49625599
5B596A505A75717F516AC44231706F3C9C8D3D558D7B3050A26B4266824380795E704A44
91987390958B6B8996466C729E575990854698D693518AAE5074613A70455C7B39828B63
A8643C9DAB3C2D9863686457316ECC9372A1886142C4A58A944E7C956E557B4973A68848
5F8C7B2676967D4F7B706F4C9B89495B6452427B6386C2705973677E213F79553492933F
31A6A2672345742F2D948B30486C3C9C7C4992705E71A94A49946B6B1F379799ADA7627B
5B4762AA845AA64D472715120D0D0F6F69405A120D0E0E0E0E10131F8C683C2D3C2A1D66
4F171013111A1D13110E1324587B66342E7F82921D162127294A76D4D5C2814E34231E1F
333F83956831374755451F161715172864576C4E968B5C2B8588552D1E1D282050B4A56E
686E90C8C167527027495725193891BDB6935E5A5E6A7193CECE8F8A95B2AF80615B83A4
B8CB3117141919294C451D153AB699957682381615151313151515154A7B6787AD7C6E51
3746373781B55F3248ACDE98171D3428261D1D26384D5087CEBFD8EAE998AB75686B766E
72728894BCD9DE8A4F5665312345767226282B677B7E4F4E7C8991AE8C493F675A4C8A28
1515182A9254763F47C18B8A8173B46B50427BB04C7E523E4B52403437504D7BDFD4A3BA
DBD5C49A4A211B2023316E68C2A6A6571F1F1E23202772B2CAD0AF57
665F525541703B467631647E3F327A732F32406055135A6236872A2D5A51415E75553551
2856614136683E19664B2F1B4F34237338253B49292E462F555C653B3C8525295E523955
5E2F4E8B5C4C6F6E4B7286559179339C4D3B8B7D591D8E45278F73312FA51F15869F292E
337052216F4F33703E4955447B6947626F4868936B8B6B74773F4A7D5A797C6F416F57A2
68576E5A607767A16465C24A39789259AF8C3C598985334E996C46768A477E6F65717A50
768C6E91998D6C8DAE6B7B99BF785B8890426BC78454949D478557387B5BA29847837433
A081569CB150296F49545A4F3A5AB67868A5754941D0C98A6B447B8B6C6B544471996A55
A5A46B1E68722E25918A6C3C738A5675966E4E726A8AD49E5B7E646F2570A85D268A8436
347C99542E556C81359E80304D7739984C30887955788346266A938534268896745266BB
C581829097A996935733251F18110E74A6877C11100F0E0D0D0C0F1365534527573D49A7
3716141413131E0E10101013141B4B7D668980CE3D1B313B48A3B4C26D729CA577544D4C
505AB993885A5027131515192324262237594C428C7C904B734F211B2E52798C8BB2571D
284374AABB6884642C1B6C483E4992B6CA95534D71A3A482566DBACA979FB096765B8BAE
AA9E3C17131514152D534D427EC890A297B41D1513141516191E3553784962A97C3A4763
92795A4C66C9998BD9E6E1C04E1F3243493C4A5652567DBCBA5CA1E9E3DAC6B9AA92796C
62646265607BAE8E8D9866201E24663B372C4C4E699AAF706884A8D37C8177462623337B
25151A1C8C65537279D9D8A2475E523E35449CA85C8220292219172124295A8DCFC793A9
D9CA94688FB3803B262E6F81C3A09D2D232C252D243B69B4D3B2735C
6A994C3A407D40496D2829727D473A5E32291E456B3D522F256C3D396B5F4441593A3369
434D564046766A28816D3D32402A2672764151583135624B795D6B4169BD5A3861443C55
694770A35E4C668643918A53737935894461B4915E27BD51278F884D39AA2D1666743F31
306A3E40934B306D3A49664D92774F6D6E4B66926E846D727852647156756C704A6E518C
666B83538D78577A5650B85237748F5AA18B365F927530498E3A68B39E49745E6C748A5D
8691869D9A926A8ABE5B6B8FAB664F849F638CD37955A9A0405B5533614C758F4F785143
A46B517E965F348355486E604B6ECE7661A9764A2F86A3987C44755A597F523E628E3631
64724A1E6E49664A5C635A345E653482A5614464546EBA8147777478293C613725846628
2F69762825627B663CA05F225357317A7338989252C46C4930516B794A39A592975B5FB7
86412A32618C5C6C706B635C564168ADA7C69B4F473C2D2A2E30394A9A9A92656366C0CB
2C13140E10152A1010130E111511102771C2B6D3B074676B8BD8D8D4503628477C9A7349
387AC28E7E4F131511121B37292819121321684E9AA5BEAF6B68656D654440382F385F32
161C2C48785AB8834A353FA367627FB1CBB0938880796D64404392B3C9DAA96A506D5B44
6B7F762315131415166F8F4C4182A3BED2C92D353C393F3D3B362F3A796683C5CA98788B
8D6D623B42A49AD0C9A43547A276393976B2B6B4B0A18F92C26DB8E9D08DA5B88E573425
242526282D37417781A6662D1E1E3E373B646883AFC0AD586365A89D94AC643429252963
86171A229DC2B3C9D7E2893D4C4F3A30344CADAAAA3815151516171620222394B38F4C9E
62477798939EC1C9B28BA4C1BD60667E45414548727D94AD757D8867
619D4E5046934348926C315D6A44404E2F494A498A4658553174363E75795E545F39437D
454C4814459676358F5F3B35412A2E786240505D34447A3F7B5F4C272D72563E60253396
8B427BAF604C86873B91843C4E863280463481836328C05734AC9E6D3CA93E2376583A28
2F644326695F398535456548884C577A644363824675595E665482794A6E6F6066744D8E
58597E537F796B8D554FC0563D938051A98A3F8FC1823245995341708D417A416685885A
827D68B9C7A36A7AAE7B727EB6656CA8B3588ED552318DB5497E5843724D6A864D806657
A56D2E60915C358A574287885979CD8460B3875F41A896A46E4073515669543F64956E41
6E8F4B2C9A586F4F707E564066773849613549656297C6534D97A78C366088572993601F
365972232B4C714C5DAC7424466D37836D34887459CD8F3C334F65772D3582914BA9B65E
5F79596E927E86846F564A41465F7BC2B8D5CE815D57575A5D647488CBD3C4B5BBC9D2C6
3613141410154715110E0F111615110E1B7889CDDDBFA9A5D1CCCEC9C5B38F7D67646E97
B1DCB35A46492A1711201D1D1814151515152C8281AECBCD916849382C23161713153256
2B191D344E7B8439618C8367313F5284B9BFA26070949B9F9989959E8BC276381C324126
4965717D21131313165FAC81648AC5D5D7D23A1A1715141516161555524CA9AB4B919781
929BA797B0C4C3E5BC2B1716257A9A89C68D5F382D27304B99A0C9D2CBAE9A916F54302A
2D29272931332F4C8FB34A562720375A4A919D837D95BF92829AB44D584A71312E313B40
7A6D3B6CCECCA5BBE7E1986267403D5F8EBFD2D99D1A15171516171719213FA2825A6C81
1C181A20336B90B8B5CCDFCDA5AA55A79663738C83A0967D6EAA586E
5E974D5B477D3D579B6D2F7690463D331439365C632E8A593E801E53927A60636E4F4170
434B643D33706D3090203A2B43194B935F394E4112386A427D888544459B523B5C35243F
5B286FB450578A883287805E397C2C6D4E45AAA05028AE3E3F9598605DBB54307C522D3C
55776C3A7B6638832C4C5541A06C546B683D5985597E5C4E6750607740587E6E5561478D
5085774A8B6E5E8A3C47A04359A37D5094992F6AA47C385AA66A497A90447F6D5C657A56
7C71557A868A627FAD79818C91304B7F89468BB272589897618C373A8E4E6564346C765F
909C5480B55338955B3D48575288D09157A2B6845CBFA8B983468A666E8B1F284D945A48
808B31207052283490893834627B3F7A7F173A66707FD3703A605A4E25486C672D8E5D1F
37547C392F54625D376860214967318B6341A96964D091313E6A9175282B8E9B3D91966B
567DA9BB6E2D2543739D805F546E82B48395CCA43C31302E2F3131489CAB7E6F9454658F
6C1915130E1E9725120F0E13160E1111206B3D8EA9322D3AB8B0CBAF735D5A656869698B
A4D78E2C263B274D441C1415111313111315144BD5B2C6B97F4D34191513131218161742
572B1B366294622D545A52587458484F8692965D22243F8FBFC5833E39738553191A3B1F
264F45627B2516152F42A4D18774B4B4A6BF7A2715141516171530653668AF5C286A8449
401B253E73C1E1EA8942473E42517FB45B5E6A3D383B4A4E62CBD3D5BC7577586350352C
3029292B31394B5471985F5F501F38676B838899ABB8BAA361718241525C814932354055
9DC99A5B499D6856A9DECCAC9FA0B99D727AC8DA871715151616171A1B1F757E63589128
151717171517192E55B6D6C58590AFC0C5A0704956A1887B927C8562
6A684F534571324178582966383F6A7C3A3941605C2462654D791C2B676C52808F584C6D
2D5D7C41439B4B21773733244F1921683C376761353C583987A48446498E3A588E524E55
622953A96B627F7B3FB69D6C323D236F7A60B8B4122896622A929E1E2B815B2D83A86324
27616359A567327560687229886D687233316A895F6E445D8357706E446FA3725F50328E
698451266C935FB63226A9733F8B642D919A467DB853253670445B9D802F735C61736551
8F8D718C7C65548CC29194B2B0644A81924994C3686A8D923D63522356456975414C5C46
836C619EB6743C894F42594E396DA8834E807F785DCCCEC26E32777865885A3D60A06A4C
7A78412F7B475D4D647B693750662E6876474F586A50C7604B806A6C2E496764388D6634
3A4F87432F5E687240755C2E83862E7A3325727365CE6B17172D4B6C2D27887C456A4151
77ACC2BEA4775E505D93B08DBE8F5FB3542E925912120F0F10110E1647A353455117153C
B23A17110D349A4B49453028100E2316519A897E873434669342B4C29B7C352A36424741
48BCAD3C223A172E380E0F131110131315131320CBB0B0AF8833201411110F1016191819
445F293F62797567422E201D2830372A67903E67511E1D2973973D2E3056845B281C3E25
1D305A3C5F77443143889B4C26298BCDB27E807529131515151F5D36559D572628445430
431B25263D66A2DC843E463A393342912859AE8F644229191998D4CBD79AA97442431B1E
2B2121232217171E4C7C9E4E8E7EAB949E8FA27F725B73C351314157555F522B243178C2
B6B9421B1C2E8C7493C6D3C7B6805255A0C28B6FA632141515191E203265B06B689C4115
151617191716151721A0B1D2AA90B8BCC48A4A48ACAB83895A646B4E
6F744B52477940436F402F697031264C2C2C1B475B425C2846672C3787393247635E5F77
2A4A50274E955D2681533F1E4D35297F562F44563B3447274960673D559C2C3057355E86
60215194697C8E4F2F6D824C426D22625271CBAC4D1C985028928D3E39A15B368873542E
356E783E71773B71533F80628A647C866434587A5A732838624A7C6D23426C5665783376
5065774E487E5F84543E834D4194734376904992B07D37388256446B7F3D5E4B808D4344
9F9C7586C5663F73B1506A92A15B68A7844B99BB587EABA6436D4C204B5487713C475E53
6E564E74AB6F398A5E426F6F5590BB6A50A37E5534948F9C8A3C6379687F543C54875E41
6493713E945C6F475E75754B6884496B6673648C9486C7955388B893354C642A367D6742
3146802A478F95633E6C4E1D576C348865319B7478D3604331567272372A757C5C5A322C
2D79CDD3B7754C403B528E7CB1858B9B5A34715A17151923160E0E131D9561653511111B
9B8D1F141F6626141528776F1B121F45A4D1DDC2CC8C85C3585F661F294A6B5A331C2A25
286AB186403F131545160E0E141917151415151E92A785734A23170E0E0E0E1111141C19
1D4F7480B65C5E3C261915161C2023318560594B68331E1C69903D2A2843959E69414538
1D266E282B41759D62767D22314B66CAA680686E93661C16196C4C527B8B1E1D50585737
704551373858B0B8983733312F302C9D2D3851726715151325B9CBD4DA4A323D222A3F1C
191415151515152F577FCC8393BD8D61A76F38241F252F6990362C5B58644842859E705F
A87A2D2E2A2251B592BBB292554E8FC07830192563882B273B5B7A909DCEB79E86BF1D15
1515171715171619618C41B2B6A2A3BCA7A9B3ABC7734E59716F6657
6A9A5144438846459E7C25646C352C5F3B4846597943694A4A78293C8C6E5A566135466C
435457322C5F4A2D98484B3D4B32317A52354F503B485035646A5F33468A51386845344A
5E2F217E566C94853D9A76573A6F295F544CB1966D23C15C68BAA15E42A266297E73324C
678A873A7D58448B5E3A6C4BA172695F6543827752725B4D614A577E3F3F666D61754A7A
56748157506663904F4C623C5AB9AF8572A94078B37E3E579F5D487593457D5E52657351
81705982957160A0B37681998B2A3F7C763F92AB45555C894E7F404B733F585B3A704D4D
69772B599B7136873E4C867D4B8FB87268CDC06A4CACA4AD873A6F767083673258906E4C
6185272E96826F445A85283A7276446D5C275F91937EC4A8528A98962F48638353B47247
2D38974127588066526D5E27614F1F6B6635A56F49B68060396A7A7F322C8096886A362E
2C5A9ECD7D1D1514110F105DB29B575D7A3E62631715131B171031231B696F8F31110E13
52B344247B30101310171D3E5F749588BBD8CFBDC7C6CE9B4A69120A0D0D10284F5F3E23
2337A77E9255131429350E0E0E1011121712132A7DA2876B3C20100E1411131515131B1D
172D86CCE2DED08B241C1C281A1A1E532D16496A4C63221D3D6D2C24214ECAC4573E5C3E
3963B5682F2F47919686393C51716C729971515D6095956C8D5B5C598E281B1E45A96238
702D4A26403891A2CA47282931393785607353474A15152696C6D9A898AD672B1E194E50
2D2B221C1D1C245760A78FA5D9D5B7CC792B262520252E3F5F6E34507385A2BB855B4A68
D03D171F5D7C5877CEB4A88571C99E3319171B1E2891CDBEAF9C8A8690D4C79C7B8F5529
261F151515151A4E7E2A72C29C97B4B2A4B1B4D79E3A434B5C9FA1A6
6091505B476B4A69B1842E74884A4D5A28403B5C5D3E72455670283F664F4F6D693D6380
5154703A3A5F4E329C3F3A34411E3E7D4C3956382A464A2E706B6B3F4D813D386A50564C
673D24676F72867F389F7B61484338745A4EAFA6283BC7723EA08E3138A56A357F873325
2F615F276A3F20574E3B5F2377676D6737366A7E586831617E5366673E6A8C6866644897
637C5B38757152962D558B4037928A5F68854A84B54E3956795A446964468D675E6B5A66
B8955D9B9D383E769A587EA292564890604FA0B35C8E606864805421553F60512D53686B
534C357CA24E50A2494859413F9BAD544665898062D7DBBD8243908670943327568B6359
8E8E5C28855F344490747841647C486471596D5D8775B5A03C7A8B6E2F72AF8649A18827
3F83A6562F5B7A3B67A9772F5F5926705350C2815ED19557467F7B6B3149ABA0BF8A4837
33837EB33D1511120E0D0D13988477549177596E1819141515152C67223D94C55F1B100E
2F9BBE95824A5E627479867E64483C3CC1DA8B3D8BBFD39570350D0D0D0D0E0D0D163E61
58448584918D5B241737160D0E0E0E0D1315153A63ADC1A6372D1719191713120E10131D
1552C9DCCAA0A96E474F4A524F506F5A1C171F4D5969451D37592924205764AFAC485E7F
9DAF998A745161AC81B4556378464041334F685A525683DECD4A609B491A181C3FC7BEA4
A6231B273E2D58A5D46C2F3548657C9F786F693F601E4580525BC18A45609E6B241B425F
35272A272D3749837CB0D0BCC1DBC7D478321D212B2B232B42757D60C9BE97774A4D73D7
E190365D89AB9843D4C4CEB6C85D26181515171A2364B957312620202EBA6F5D66669362
3D2D2724192A627D4C529D8DB875C98270A97CB6AF4E789B9F9C846D
636F515648743A3978602C662F2F475929322C605C33552E657030418033366C7041645B
335B6C3436631B247D44352D5A332C7C2C3D7B563549312B6F836C444B7B29578E5A6141
4F325AA07A716D4E42897A4D4B28154C5A4AC47C27177651349D9E1A208166367A87383B
407A64276545296E3E3C6D48845E5B5A6F45768D627152467D4D61853C416B65625E4779
507D7E549282588D4A4366503D8B762B548E428CA777485F8D5D3B62853F5C375D684C45
77885DA2967077989C5B8CC1AA634FA1403979A65B9569963F624F2D6B499A7C3E5B4B28
4F866296AA502B6E594B5C392379A45D5FA9824C216B818B5B2A66486EB46B2D5D83322B
475B3C2B64384C303B50533E71543D979B6E85687675D4B86B8C95651F4076925261692D
222F71562A5C863F3E56482B8C7531784C36965F78D68027409EBC6F281E5383BA4E4672
9396739927151313100F0D107838204374CC8677341C1513101415539A959B957A6E716D
7D9CDCD5CDBAA88D7D6C6649363D5BA4D0C135658078C6C07F10100F0E0E100E0E0E0E11
3D97A88FA8526376473F44190E0D100E0E105B8E91D5D9A57B5032433E3B312318140E13
30A5B6C574C4AD8B89816C6B6C3B2F4D2615192A5D6E59263E4B30313A684257DADCC4A4
8A5F4D4B5F8EA5A48588824E2F3D3928171737565F453FA2BF847A691C1C182060534A6E
C254212D34273B7DC4B75754413032457D24514361718645471E718A3C3E529B721F303D
6E2D222B343029457AA29889C1B48F6AAD682921201D212B3460A4CB997498A08894A6D3
695782CC96B6AC34B3C7D7BB631716161919171D288E691715181B1D379553544C845E6E
396C7B89715C4C5E4957503E8B5CC06E497DA0A4B1A65C30333BA658
626A494F43954C43A78A29778F3E2F612B3334385D56532347612F3B7264434F5C2F5F6D
354955353A5045317B2D44314B2D2B7B433C4A342E4138265F5365414E8C3B2D68547344
4C262560515D636A348A905B57422063453CA8654324B14A47A7912C2D9D5D2F728B4343
448571326E5F356E46426A51935B4E66824E88936B736852864853864A4E6F6A5C5C4F91
4A777F4F6361608F4F5D663F348A7539357F499DAD6A4C6C9C513D7A9046603866677A66
818368B29F8897A8A53D53848A5671B66047A79C407E8F8E4965642F6027527B3C655E4B
395F4B97956D39925A4C68644A6B895F55B3754236A0A26B4E2C6B3E445E563E698A4E31
53522649934D6D37485A5A578C5B2745524677643C4179875B96AC7D2F4A86714E5C6D3D
293D894C2C7DA05F475F41227E4C2E8E6741AA42339B9256375E5B6A3B276A92A2969AA1
B77AA6931F1615140E101013623217183FD1BE8473631B1F313B6D8089817F6856484941
97CFD8BD894C43322C213E636B8C6B2C53BF4ABC975AACBB3E0D110F0E0F0E0E0F0E0E0E
101757898E5C856E7C948A441E1A1715171549AECFC0E9D3C7C5A8795D57555051503436
71593176AFA57E423F3C393E3F5F522D491F171A326C545863756750969E3E69D27D5577
403C3E4F5A7ED9BCA4A5AB3E4533251B18151B26465C6D74C28F84291A1A2D4B57664E39
4B465728363C538691CE2B1C1A1A1F255F2E3D557D99482917173DB34D4D5F9782943F2E
481C1715161A19297FA26D77BB5A7B7288B86829231F1D20305AB46660C7B99C697ED052
21272E4492C9A766D5DDDDC2531516171719191C30933F171B191B275C7D554B51736040
5450B6796B256042303130305C5B7D7042693C3D827A241C292E732E
699A5157439C4D49A58B2E79904030682739445A754D644670773B4179775367643B5F7F
495D5B354B5E503B8F3D413D512F2D754F3E5B382E332B327152673852964E41765E7A44
5D4E317D554E697F419F86597D67336C413EB3705221A63D4D9C844B3DA4713F80AB3C49
4F7F49318A753C7249648F548C635E7987517B906E8063687A4C769E4F50775173715690
45948F506565477D507465324A9C6E3F347B2F558C6E42648F325A9C99447828405C6A64
8F794D97A07980BAB27469A1873B5797734DB98B315F557542724F52793B6E7138845F4E
3F69276B915A338A485F91603F70A2705CD4CE6446AFB89E5F45946A6172403A7F906537
516727265D55643E42692B468B6B395957378A7A5768899156B2D395304C843D3447492D
2739772B1E5B7B4755AB8C2D7D47174E63409F453FB2684E3E87816A254E98A08B585959
6AB5D09A3956302D323223226A4255759599BDC93630B9BDB78E544381AF6F80312A315B
5C91B89A8D40281A1D30888F6228192C58A9A4ADA088A0AF590E0D0D0E0D0D0D0E0E0E12
111528802840A2B5A79A9C956C552C1F29477CACA9C1CE816CCA49151517120E10163171
8221166191B4944F3A2E25303C5B7C53283E211A1C429EC198A7A987BF9F58C0791C2020
18161D1E202385C5AA52C18B31201A1B1A1C1D1C1C2D4D7AD7BB9E501D385C83491A1515
174427575A6D563CA6BE621E1C191E1D355A37859C6A2715152690D6D69B6D5A749FA744
3E1E171617192171A9985D7E8A4D61B375A97C612A1E1F233268A15D6C9581AFA1C1751E
1E252A2E4D77BBD6A9E0DAB78524151C1A151C1B3B8A301C1B1D30488F795E516565645E
49694934293F7D353C32253183755B695871382A4D85371E2D54AA3A
689C4E4F4D84484774242F767E382C6A273A4B686E3B6D43777333567F6F557462356573
45624522465C543EAB224C3C482340764D41482F25524235675044336AAF46456F356582
784E2E7D49426C7740B5682B4D4F23747D52BC774E24B55B3783763744C8701D586C4D50
81925E2D6B4A38803A39634DAB4649675661B47C3F654E938F35455F407B9E4748504D9A
50625127897C4D772F5FA0443072603C597D3E6A9C5A477FA65C33686F4B845E515D6F5E
B0735EB2873139ACB97763A4A56866955451C08A3F8169874470603880486C5C2E887455
41562E797E5525703F4755382D70A3653E9B918959BFA8B478265E6663815A3569976E3B
4C5E492973736D333C7E5E44856A3F604F255E757561A59E348C7D802E48896E546B3D27
3D75A570255669113A575426754D25686742A96041BA603B3C7A74621A23427C924B5970
6AC6B6B5A650241D2F394F4A938B6A493D427D778D85AF6C5358462C21352A9D79705E52
596FA0CAA6998847444881674A4F5C584685BC5CAA953C7D74130D0E0D0D0D0E0E130E11
13101D721F15205499CAB49BACBD944A404351C2D3948BA3818C835527151211100E1028
761A195A768F5A70695533282E4F635D5D2D432717308AA3A3886E327481BB9F46191715
1615151A1C255EA3604B9B4F1E1C1A1C1B1B1C1B1A17234FA0938D8A717875351C151515
1521443D7E522339B6D9CE85614C3F3535BC94B5737A1915308F784D82A07749455E95AF
602817181A278A7D9597442B4B6C84BDB49DAD73674B5F474D818C5FA87A6E5592B04429
20232C487373A2C97A7FD3BC9A8F4B1B18191D1D498C201D28404F6FA8A68770481A194D
4E4F613B3085393124232B46704A5B7A7276382F3B736A334941516B
5E835755406E4C64A96723625C3A3C452C5442563A2B67396F3E1B41546C4F7353244D56
43733F24475D4A369B3841395827235B483B5433232F372B60563E273E6E39456F40436D
5C43347E4747574432926D3C5D372B856C40968826449550369A861D1D7B5E2E5D7B204F
6C8068307A40225E34364F3D875D4C60533965795550385972494D7038496258654B3F77
3C65734A8E5A5262426B7A41397C652835763979905B36487A57337B54286C615A6B425D
AD9266BB846E69A9A86D66AAB16E6A966668D2A44E8476696B89632F5A3E6C783C7E7A4E
4A6254928E6235964E5B5B41386B97594AB77E6941C6A06B583467425D79644174885D48
6D654B2E8790645A5F825C468E6C3F706D395959537FD2AC5E95626A217CCA88636E4419
2B41855E2251534E4058512373582C7A3C39896C3FAE691B42A9AB5C31365087854C4B4A
816E4080802F1A171413132463624D392E2847235B9CAC8B351F2F20170F1A7A7D4F342C
283E79C4B4A0BE57292D80826C4D3A231B2E9F6EBC4F1C527F290E0D0D0D0D0D0D100E0E
1011457F4719151620569EBCAEB0A798463170C2B3834F999F7E8D47615E553E261A1417
93324470866D1C16182A585937325D57485C36445E8188A5767F4F392B6E64864D241515
151515171A2360A77743514F19181C18171C1A1916181C2D79929892CA662F2115151315
1515313848392747C6B0B23D425667839EE2DD9F71751E59844829413D3050624E424C87
AE7B2B214A926058A0AB9F6E727C8088857C8C99608BA8B1A8A0AF9294625880C24C3A50
4D445D908A5E77AE2F3D7EC5C7989D55313B474864912B4D6F8178AFCA7A69241715171F
6D3D5264578C3D2D1A23373A252F375D748155343263918663291D2B
656D4A5441734145896122603A2B545D24343566481D5930A160273B64494486703E5A41
2855532E4A612F2B7C3C2E2F603134672C48705234332D297E7A632A4A8C36678D5C3D91
53273A8565494C4B459C592B584F217460327C5B3C22A1382F969F3226A5672F679C3B3D
5E7771347354326A2B3753458A54495F754B7C81576460738045528151536B5A5B59507B
497C8E4E7A71688D58737044387A6E404980459DAD804151883C53B99B475C2C69747E63
B28C77C4A68B7F88AC8098CDB46B6C954A5AB57742A0A3843D5752286352808C4A826747
596D4D8F9F5961C061516041498FB56F53C3876643C6BB7F58345E45669F614376761D33
50544B4DA08E4A314876553B903E3571773F68442754888A69916848134D854E507F5123
3444694520545C5C4B5459328F62287052348C6C3CB16B4A3259687935395181874C485B
6D357E955C6F301B151712113B3F333E283C341283878DB891411F292B42689D4E181E1C
23214CC9C4C5CDE4DDE2D98C5C6A78809687B268344F1E427459110D0D0C0D0D0D0E0E0F
122E3B12494D13101517467EBBA2B7D0C2A972352560A4909D7C964B442A303856676767
B2A5BD947A7746291A19151A4A563B484442615B8CC086C04F586E581E6B93463D462415
151516171518348B7C43498120181719151C191919171B1A45C4D1AEA139291915131615
171517614745346D92954E1C1A1D202655CBDBC9AE9FA17A2B253B2D1E20222B3E4E4859
5FA2A1AEB35D4461A341384F6C7D82867F95B1CCB4B5B7BFC0D7D5BC94817CB972201D1D
213372BD4D327E7920373BA4BB767B8473536B70A29E7E7F8F976B7DAC79301A15151517
4C583F63D0624228202A2A1F2827355A6C7B6A84807DB3CC913E372C
67AB4D63439855599A6D2477832C2551262A214F583E631F6D5F2B486A40397A65355463
3F5852355564323F954742435B2F375C233B41492F2E522F5E484C2F4C852D356B5931A2
572A287647385E6745A0622C74692A754D297D5E432CA74662B8995B32AE6C2D658F453E
638D472F8A703C772F49623E8945658373596D734F8B626E714C768D4B506D54747E558E
3D5B714D3D453B705E797B4649A67B436071385C93743B508F51315E7440742D7982756A
B67065BBA6857EA0905056B5AE6787A3636ECF83356BA0824371563C764483914A80713B
75724680A75B4AA65162A5422D599D8851BF767F2E94BFB27F3B6729387A7F47A39C6341
575F26237E7C652F3C77454E976844626E4F6A4D566D96835B84798336527B21367B7854
3F467036348F98585A52471F6B4E2B835B3181492EB4A6743E736560386F7C88BE4E4668
3D937E4844446539191615194F4626353F4F1D454630315CB7C8A79B9AD9D27C1B1D1915
21207B892350ABDADDDBBC967763463A2C26288C2B303A376D75140E0D0C0D0D0D0D0D0E
216A2B0F148460493C53A389A87372A5D1822B29193974885C66756C5B493C302927292D
93B09FA6D3391E3042351E1718215059476065BFB9BBCEDD8B4E7F926C90B7596C3D2F2A
17151517151519545D546DB4635B3933211B1A171516192665DEDAD7D6A2582318151515
15171529684E5FB15FA7271A181D204F8D3A7C8B98C3B52328411D191B1F212320314867
4B6EC3B19B808AC09A5D4B516B5642608D524880CDBB8DAEA4BABDC2B4B0D6D635232221
1D1E38775A3EB33F2346539255446F91BCD78F50CB995435232835396C35261715171515
3B3E5943A379321B2B2825151B19285F81755CADBB90A5CCB9A19A89
6DAB4D4743744D49733C3E8D822E2C6E29433A573433732F913A2D646E66529B63387582
5958482761805C45A51846424F1E51893A41403A305463436A514A3C6FA74954802A3188
70332C8445416F7B3C8E55204967317F593B46645231A9352B6A735728A56F4051874141
7C8A793B745E328B3F3569488D4E395F654C79513D6C57897439507D424E6E51525A5688
557478506F5452764C86AC402F7D8447638D4471BC84414E935D3F788941794E5A666369
BE7866C59F8E89B27B676DCE8D4F8BA85C98D97941648D564C956031693B795F45C19250
897619629F5A689742466A583F71B8825BCBB36F3887757E763D7C576881413992925C3D
623D412F83765330457A2D2F81704C6B75499A827874A4977CA298793177AA394D5B554B
525586391D4D5754689C6E317241266F51296E5021878F61347063521A3A5979D9886870
A25C3F3E283C3D683F1A1517504C2D28442C3F4C2F1F1D1E36B3C7C4D0D3BF50171C2116
1B17752C111020BC993C2015120E0C0C0D080D6C96303E3E636A350F080D0D0A0D0C0C10
758E303743311C32487EC7454F1B2557A031304657471E29506052873E4F4E47392F293B
9EB68A8CBA3A13151925383F2917153687A9C2BBE2D5CA9D96828863619BBA634129342F
392419191815153E6066633A202126343B433E341F171A3296C4C3B4B0AEBFBB76301715
151515167089BECF5EA21C1C1E294A842D236EA8ACC4C991481E192229282D3842444432
3D5FC1C5949CC5ABBB8694A754334C53525C4B538E95B1A39DB9A7885B476FB735221D1C
1D20356A795E9C262E5F8EC38C3C2E2940A64D31A43716192C3F581A543C281515151515
2C2D4B568992372E272A1D151A2C5A96C79A7CCBB8AF9BA45D679091
627B506340714662A25626666A25283E2E54334D322D582097612842544B56A876245A70
4B6C462C4C713F3AA048483B64252A564447565C36385838776231224686404E8A684880
5542408E5D4B5E55409574395551387D6D627F6D402AAD6829907B3721B87E4663901C49
6C7F7C3C9341278D643C5B329F634A502440868C4C5A387D8E4F674930638C636D5A649F
6473703E9265587F41538C6141908B50879A4684B8804B5B9B5668AC7142806377763252
B09C7ACB9A3A89CFB0698DD881417D843077C56C4B769D4F4F8371244A368F7B3D756638
9E825087AC3551A16052651D2168B96B459F817249BCC9B762366A6978A1673D8B813349
7F6E593777763653858C332F696B4D6E72387061435ABAB9B07D6331195881735F5E4F20
5189A46E264851174B68692F67622887542E89642994933C286A63612F4C4A71CDD4CDA4
5A322B3D2520354065562316533D1D45403F482F1C1E1E1D4697493133ACC288201E1B15
112E5112101010934E1D1415130D060D0C0A0D2D5B7E7EBFB665721D0F0E0E0D0D0D0F57
71382F23211B171715358B777F1B1C539F51594A1F131917192F5166511F3F4F689D8651
91B1AF443C791D151515192027372D232BC8CCD7DDD8C09C8E989F8A7FC7B9473129352D
343C332018171D38688481201B1D1A1A191D25324D48336E7E718BA0D5AC514579B19C4F
1F15151755B4C5C1B0B75A3C47598B292A425D9D8EBEBCAE5C2928445F5C5E432B252F37
3F599079525682A7A455485C2B1931371C2B4B50567390C8AEC0898D4227559B5C1E2522
21213F7C8A9D7533394D6C9D37476E6B455E75607B33151F3A581C193262251515151515
282F4C4193A6874C523E42667E8785AD8FC4D392A39C8A632E303D4F
6A7C4B613F69374E8D5E27776133496E2B4635616039420E8A5F2F4E5C1A2F638F395639
366459305A7E16308145382352262E5C1539686C503937256278673A47852C609473477E
4226439C584D5D452F787E3C4F672B474B696077492DAE642B91983737C781407DAB4E34
4F6F5B39A0773A745155774591594B6B69426483607C5D6F654D8B8D4348664E8D605387
458491419256387E647A9E464BA97C30727C519AC57533477B343F677638652A68784C47
9F647AD1AD597AB46C4085C499568AA05D8CCF524A86A6853F636B275234877C3D70663D
857F4A75B46C4F603E525D35284E896A48AD7261278FA89D7A3B6136428B72357B781D2F
4E6758376D7E432D3F77462974302D648049936D263B76998FB0C88A2D4F72535360613C
3D45705E1C4053514D615E328058237A382A6952207E9F253BA9AA7835504B72D5DAD170
4339353524201E3C3E5F7C509661444C53411E1B25223749904C251B1642BB9261211213
184821110F1012814A1A15150E0A0C0D060C15105D7AAD8274999C5E260F0C0C0F0F4354
221915151715151F4D889989795E66BAB390271A13121B1715161D4A7F21172337696923
9CCE992A27854D201517141519191F386CB5DEAEC3D6AA808F8E9895BDCB8881452B2B31
383A434D2B225352918293261B1C1A1C1A1A171C1D3CB976656FB6B3D3AD90805B476BA0
AF652E264F8AD2BEAA814D3B407F474F524E3B3D8FCF9DAEBA6C6851321C23364552493F
5E939A65788DA3ABC9783F3B232546291515175C6D9F7A9B9A9075395431566C8E1F1A2A
514E47559BB1724454429564201C233E6168A1BE92804B4C812A151A1E813C1715151515
453B4F3AA2C0CAC29AABA9B7C7CCCDA34398BC7B8B9B873127264567
71A850633B834F4F91642A673427485A2A26154A5C376A30926032647A745A766037556C
5266322B5B6A31418D3A3F3A4E22365B2337405747442A27636D573A548D215D8B70467F
4C25298D4A4D5F7B34776F416B7335886968717C5D2FAA323E7A7A4C3EB25F3655854F35
526B693785763A7139356E4B882D3D685B415D4F3B785C7B5C3159824C44604554656899
5667894E4E4F3F6D4B87A233337D6D3A82773764B07138568A494C7C8B35503A67623D4C
93705FA498699FC99F6186D5965EA9B66A95D06C62C2C8804A65802A51398B7C4BA97745
A78F568AB0814855557994463258A4744CA4605D338879897835664D6A775E3A83934C3E
4D5B5469A484473E4F723523735747546847BE99715D91963D719279284C6347679B9254
554560361B427448465F3F4B9678267C58215C4927668D53203F63773B5D4F5FB0BEC76E
352E29261D211F2453494196CDCC72713C261B1F485A5750852B1D171641C5925E703715
293D19130E0E13823A17140E0F0C0C0D0D0D0E0E59D8BFA6A27788825C33110C1673661D
171511151013152D5071907F6598B09E8C1D141213131517151717219FA1755D5E6B909C
E0DFB33325546E343021151516181C5D97A5AA94859D8584707C765F8AA4609C5D484A3A
33323B3B56444B6DC0A8A4491C18191719181C191B4B8E90AD7678B2C8713B33577C7346
4D91CBA78ACBB9A2C0AD454D8E49362B1D17161D60D39DB6B08F28213432352F1D191C1D
207CB3724E659D569D6D3B34353418171618174A666730465D4B623535534E548D6D2F32
45475546A87DBC854657925C261E1C1C203195DCBCD9B8D5991A16161979472515161523
677C8EAAB4D4C6BA9E71647064537F8790BC95AEB6C96927283E6164
72A7516741904E5287533C80651F2C612C3E2C615B307838A3653F8A8C715A8857418785
59643132898244439332492F4222537A394146403E6259455F4C2F3970993B4A814E3EA2
73352D852D4B7E742D6D4425446F3885312F4E8A5A34AD65238C91393CC288496A98643D
5263793D956F3D81614D73478D5B47675F3D5C7F427C5B78624C778F4943665D69566394
5B788B465144465E4690A92E43996E3884895167B67337669947546C7E5977577C715F6B
AF8E96C99B75A8D1AF658ACE5266A8A64985C0523C6E90694C716A4E8F498656335F6647
A460389BA372325D394264573B4F9F6F59BDC78E50B8B1BC724BB87E7D7350419897553D
444B252B6B794E43456A251F775B54554A236B594E598E855C828378274A63262B558856
52464D312E4F89473F5D3331735C286D62286C713169973D234F7255385F4F6B41AAC395
4B2F281F1C1D1C1D264A3D82C2C47A914751504937484A7F883237516385A4CC66426881
8B201F1B0F0F19862D1710130F130E0A090D0E1BA09A896D90B986A2363E3D4F76BF3412
110E110E151E314750341B504585A3656D2F110D0E0E151815171853AE775A688C89958A
D8D3B135243B3614172A37241E171C6994A4BA936F8E5144645C3D3739865B5C53252E49
423D39383C7690B1D1C0A4B446191C171917191A2571695F7E5F4FBABC9246392F374E63
675888D2E0E782AEAD514F842F1918191A16172B41A0939D788E474336231D191A17171D
2C4CB1797A426C4D4F2C413A2C1616151515203952503937523E83695D4B648ABBCF9587
9498A7BCCD6F7F9A52947D4B221E1C1D2663B198ADC697C995823A1A194F875E373D628A
A79BA28E9AC9CEABAC4F2E3A526E898B9FB8CED0DAC9953B416A7557
64894E463C7949527B412562561F2C3D3C5C34603A356F3099372B555F5A4E8A4F28606A
67672122506F44469E3043383D1E345A37454C5E494252415F4A37284C68334F74333074
56342D923D465A6B25777B3E4B5D367E4F55748B4B33B97825877F1B63AA803F6B97506B
A098773B7C5C4D8E5F526F53AB6B49635270A383456B49927A4F8359598D9063665983B1
647D734C9D6B4D62347ABB4D489B75438A7E595CBA705C9C9F4B5C675B34725E7561477E
BA8FA0C08B3E8BA78C4697C87451BEAC5487C657557CB6814C6A6644663C8084417A8E51
A976407D9F6C1C2D3C4F62432B638662418360814CC9ADB4732B6476726A58286D996642
446354406A7E494547651F459F7553595B427E4A48637C795FA2A17D2B5D82425E567864
4C4C5F4F22456D593D744F3E763321724327646B2B4C8D4932577667337A687D3588D3C6
B95A38221B1B20201D2B69A2AB9BC5A15D484642282B7CB9917765432E262C6BA8623D4C
971E10130D0D1D6B26100F0D0F0D0D0D080D158A671F2D5E6589B2B9795F95B5BAAA9546
2A29363D453F2F2F15131121695A818963521F100E0E11171523719C6E35302E36556438
8BBF8E6E1E34321010111731624F767A4478867877871F18253B5E40416C5C6264523B2F
3E4A3F484996D393679498A26C59271A1C1A181D60778C5358588F4329674F211C335C4F
6FC4B9CCE0E193D6AC3238613B24191717161C3A277C768F8A923326191A1C1A1B191D2C
5065346D7B68595D4428343D211C1515151522425A44434D78685B283C75AEC4BECC5D75
90717B7094CEA3AFBCC97E352223233E68A9674386AD6C64524C6F5D5355CEC19D7E6270
8A7C676A56C5B69E9E766D82613F36342C5A95A9C8C3B3B99A9E481F
7A9C4A6E3E774C51A3793C807521345C214A2C623E296E3780664957756F48A164347F85
627A3C30566D243F9555654B452A3F663C56856E4D424F49A1763D2A64672E4E7F644087
4B2E33A5546353502B76763F45597C8C3A5182904440BD8227887C2139B27F3C7388472E
46657234725E36744848543E795143542F37626D416C497B6E426E7D404A70505E465E97
6469714B8D6F4C675F8195554B956759A2974E5AB84E3B5CA24C5D687D39684974614C5A
888DA8C47469BDC595679FC7835DB8AB598FD38A719DBF744C686B2F50337F8044757045
AA7A54AA9D6C1E243757654C35598A71549D786839B690A07D396F84767F66296BA8683F
5D885743697D4B5672794421855D4F55724C7D625461AA8873C6C8661D517D5967717A44
505D76792F4D6F3E408B6144936A2D6C5B1D4C62353C9A3D327AA07C215057763788D8D4
B7B5A28A6D51382E3257B1C296BCC49F7C7B89714158675C333E3B2F292D221A54883E17
58611512110D175F1E0D0A080F040C0C10206C4E1B2026174559B3C7C8C7BD9054264C98
7D3825191615151D151412183D8898AC5D3844180E100F1D42946E5B271A1B17191F5823
319DB473482F370E171E20296CC8D184A4938657773416153E24445544667457795F2A2D
374A53317EB588652791BC9335507148201B193A997C7B50688C38171519675929323044
A0D2BEB9C8DEB9D9C63E411E1D3051312D385E5D1A4C62A598903A18191C1D1C1F314258
4D25283D8B9177AD4E2B313D2D2C2C192633448A8949487B837E6536313790AFCFCDBF94
7E58556BA6DBAAB98CB1A55C2C40524F7163234C7B639D7B574A3D46407AD8B540364A69
C8BCA76B69B94A384B56812419192121273A7F88B0BFA08CB5471F1F
7C8150703D6B4E74AC703C7E572F576B2749427159366133766658546F3857977F347248
3A6E5433597C1C367E5153314A22365D1A345950404533325550432760672A7F94783F81
422E578C515A4B6331627E3D45472F6B47507E972733A1712584803144C17D387FA6664E
617C8739776645935846745C965F3A6153447E763B6F578D713B6C8A4E56875556786E9C
64628153764E476865A3A936429D804480873F51AF714974A34356757D3F5F40745C4163
8291A6B4887EC4C59F6FC6C68269BC913A7FC55D6B99A34C4D6E57344D348B794A705130
945E51C1AD472B3D3B676B292D569586519F6B793BADB9B589386D776A9F7A4789A53C3B
58683F578F7C4F3A5C62412F9B423D5960459181563868784FB8A1782947753680AF9A3A
3B6388643A6E8647347A3F377E883671641C4A6F50379A4F2851717D3A6047664DA8D6A5
4C445B87B8CCCBBFAFC2D3D5D9D8B4554439332B3356502B1713110E0E0E0D0E104B6E43
2D5F4312170D1461260C0B090C130E0D155C4B17182517141519A6CDCBC3B58E62472B2B
719143171515151515171A19519A7D806D3B383F0F0D1386984E5A1C1A191A16191B4631
1D67CC6D8A6367403530313965669DA7BF868B8463441917452D214E4D4F8C5467562E16
1719377B548499777A92CD965A233766865B2A8684966586A03415151515284955342D23
6C6D5BBFD4E9D5696730371B1C327853363435541F31767D988336181C1F28343E3E4C3F
3733252D64909EAA6F837EA6B7A4685154557EC0AC7C65436C72724C354D92A8AA5EB4B6
C4BAA1B1C1C8B3BEBFA286A28B7A5C7C6F2640593343547A9B625E5965B3BF6A58698B89
A971BE86B9A3302F4F3D2D1A16181519202F658C73B0AF9092221C1F
7B494F6A3C54263B7355346014131D3F251C142937274E255D5C4F46524B46977D2E6779
4A5F452E587E4A558947473C3A1C2C482E4C55613F3C4E5B7D6746245E5F243A6E5C3E7E
4929369244524A6A3D6E73395066457E3750939E4334A45A2982883E61B3753275874555
6A805C328D5D56A45B55816DA6694C69554D8564487A61AB65427F72596C77455F686495
54738B4D8D583E5F4598BC2B46A67D448A714167BA77569E93396888655F8941866C4F6E
957893BF756EBDC35E48BB97456AA57F3F89C9528099AB5E4B605751683A8B744D886142
9A3C2FAA894335261E6877432B3C75724BAE71683B9D7CA181408C5D4F7E5836728D4437
4D513B3E57745F4B59623A49986549575C4365696B55908C69BD927929497D5E59568864
40577B4027455352337F40397582387970214B5E3252B35C345F70793E6E427997586ABA
67352724314F8DAAB5CEDAD6D0CF762F2A435E49614C100E0E0E0D0D0E0E0E0D0D0F5965
46266A380E0D136B2D0C090C0D100D16604114171D1E1213192EC6B384A27D8681656961
404E8D762A1715171F2C28463D9AC053586334411F14335A5D421F1A1A181718171E3143
2368CCC7CED5CAA7867873747F8E9CB6D1D6C7AA658243478E2C1E2B5F477A695B394517
1515173BCFB0BD952A195F99832A1F235897B3AD958A928D302E1517171516174C583C3E
88574940A4E7B553756164494D4A2B1D191B192B341F8C5DB48B7129292E303242552B1D
3C26232132B0C2A2475C86756978A4BC997F6EA590BD88535B6B4E4D81A3A6A43A36533A
5B958ECCABBF7DC7A0AF9DA0BDC2A78741546F2F1D274F73CDD8D1BEC6D0AE60727C4E47
4E7D9ABADFA94D474C542B1F1C191C1A244F588E606DBCA2A82C2731
7E69404F3E763E507339356E4F1D3A6229502F776422623C80684B544A585196672F7478
5A5F2B2D727540686F414C5553193866395C7D5E3754524EA6833D2A736D354E7D624598
4F283D86364F616B459568305D548379234287933C3B9B4F20868D3347B0874586A15C49
4972883A8361407C4B42556093493D4B334F9252406D497E5941686A45596D4F504F7186
5E7C694B7F4C4B635977A25341A1745EA28D4354B65A547C8E44576F61478A4965594288
A57A8D9C5053C7BD9151BFA16C5BA26D398DD1679DA6A9665665652A5A499052446F5C44
93524AB7914A483523615B3325406E603E8D8E6E4CC09FAE4B2D6B5C6F9376397F9A5237
505E444064705D465B69215CA76C455778506A63635688866AC0A4782A5A9F6F594F6E22
5299A15A334F5F52349F50396D5D2F857522577F591C7348306361542E8E6492544236AE
7F4A2F251F2121334D9BD6D6D5AF39182D2F3C5F44260F0D0E0D0D0C0D0D0D0C0D0D135E
614334712F0D1A70330F0D0C0E0D155D3E1B1715271316193AA4A92310537F3B8F76655A
2C1E2767AE704037484049214EBDB3533F6F6746442C343A1A1F1D1C1E1A17191A1A2A56
2A6DA78BC2E0601C1515293F3F457EB9C9AB8F58403D37397F511D1F39545F7E54344236
1516162C6C5C604521161D97C23C201F1D32C8C7D0CF9E25231D15151515151518508259
D06C4645BAE4DEB1689C30323B2E1E1C1C181A1B311C9D72B3A0683535435F5B461F1927
2D211E4A8FD3B6C7D4B5A2B398AFA9AA9D9B95B1B0AFA1B3712F20298CC1CB663247482B
325EAA7FA9B86D7076887099CBCAD968448840201F275A8ADBD7AE78A9BEA14E636F676C
767A97B391A9697B57463D1D1F1C202D3E7FB2ADBE9AC4C1C6574B64
85864955396F4663985E367A5439563B2D5B295C312264337B353A4F5B4E6B9F64265D45
487C262556622B626E3946376017285A2636504F333E2D3F7E62331F5B442C707854407A
572D4F8B3543495A3D787C3A4D456163415D86753A40A86B21889D5254B585428AA65650
50697F349267457E4F4A6A6D966341524337856A4B815F995C486080555674544D385183
5D7A7D5697555168659FA74F3FA472488B853D5AA263647D8D445B6F66618B476D553776
8B91B2AA5560CBBA8F4EC69F835B996B3E94BE748FAAB25960605C334C4188644C655643
9C5161BF8F5180612F616A3E3C5C7659487D5D5243C5A493693669567595613B92913357
917A473E64764E66817B487AAE5F4D5477526A595A80BC8D6FA8AC5E468EA458514A7538
334C675C275264304EA16E38784424884A1742615119892E3178665D1D556A85433E365C
AD53301D1F1D2C535E569ECFD58E36223D3A5E3B1715120E0E0D0D0D0D0D0D0D0D0D0D11
7E61734D9E261D9C6F100A0E0D1768371A19151B1A17254E496234090D30836B4C2B1F48
5A2E1C20484C354349401E133758679759387D919A6B32171315151721271E1A1B1A3C4C
788068C190D254553D4C3D211B1C1D728FC68E572E222826253D3D1E1B524F825A38365A
25151759384527542D1619B3DA962C2A399BBDC3D2BB3323321F151515151515161849BE
D76F8BBCAAD6BAC5DAAF2B282A211D1A1917191C3035B08FA8BD6C405B56421F1819193B
26203E59B89CC2E4E7CEC8C399512F232024335CA3A4B9C5952B1D2577B3A0814C73743B
5D797D808F8E694A403A6FA2C4B5A2731D5C24272B3697D1BDC7BC8FA192B173562D1915
181B4D6271A484686F4E4A271C244B5F77A1B5B2BEC2C6C6C7C16B2B
94954C763C6736508E583D7F4D2B4148204F3C84572649297154384A563A518E6E2D515F
495540305A6A1D42543E5155491C28593E4745533F484B4E944A2E20613F2647786F4384
4C273B6D3A5239663A8A70393F549D6433669977374B865B1E88B54E56BD884487A95B4F
507D6841A665427345575D678E5E44584537946A537E6A96724F6485595178554F546389
648284517B3F547463AD97233FA9774F93843579A256717C8C476A92686982467F644B7B
8F91A8AC6372C6B189507BAA7251A2693388B7569F9FA441859854304F408264495E4044
A36E5C9D8F30896A2E59621F2D7BA6664A987C654EC5A7A36E35665977B66C41A6A2222B
525E31517680234784743E85B83859866C445B552052846B66B8B55C285B8D564E4F8642
3B737659275E6E512C92483576512E876A1E495D311D8A1F225D7E5C3B60357B5D3F322E
966942211C1D1F3A3E487ACACC60333D436E3E151111111512150E0D0D07090D0C060D0C
2187747579A598DDB338141533772C191B171A1B143058291573130D0E252B784D231A1B
2E5D44262A4A472E14100E15171B33368B689BD3D680151113131015151516171B205083
9760377BA6BA552A7D5820191B1D1E6F9DBF8C58311C1C2525293F391B4E5B7C684E3337
601D3B5646321C4E2E1B2E61CAD3BDC7C7E2CFD2CF923C3E5C411F191515151516191B7B
8BAAC0939A7F4D6185B63C2A221C181C1B1B1B191D3A9DB6A7A0BD622B33512A17182150
2D4D353A8B3759D8BA8A5D464F211C1D1F1C1D3191678FBA7C7C6766967D4775A8BFBD8F
9275846D666072734A4A598E6357599950561F2362AFB5936D8155363E6C84341A161515
171A37584B7F8D737C877247324B7B91755C63ADA5C5C2BFA78C5D21
806950763881515F8F56479B6B233F5F2C3F26604D2860329C5922525F4E6192732B5A68
795E4F366B7937595D3F515148235078374A405149694A4C8C503E2D8468345A816E429E
582E3B652752435A4F84603A455EC45D2858A9A04043734B1D89A24D54A852257DA66166
6881412276633C8135716563925171835937AB376F7E6B8B4F769A8B6054654C7B5E5D78
48A3934A6E3F5588569C9B2562C0894C8A5952B0AA5B6B7D56366E785C4F84265C716673
803C99B38C83CE91383D5D9B58519E834583B26F9BA4B0545558362B4B3E9082565C5548
A06647AA9E4F955D2972782D3D4B6948486E546B3DAFD6B67C286E4A568B4832BDA24937
5A73323C658442495B6F228ABB3B3D53483A5D444359965E43828861548CA435666D7B3C
4DA09565446066403AAB632E664F1D69682548605D197046204B4C5938723D7A73573D32
4EA94B25225E2D2A313E9EC5BD7F494B6636151013111014110F0F151D100C0D0C0A1013
134199A8B5C9D7C4C8A5A399A92F21201713181B34511C0D2D6720263B64356859281715
17216CA16A5319110E0E10171515332F2EBACEADC66C1A12111314151514151725557770
754E1C256ABB8C254A582A1C1B1C2983CE9D3131544C261C20282748263875B3A0B75336
66917C35511D1B4372574B92D7D4DD8168BAB8AAC0A06E2E1F1D36531B1D201F211A1C85
A9C6C1BFB5401F1C49599B391D191B1B1D1C212F5072B3D2D0AC581514151A7B5C58ADB3
8033164C45214E99211C4876696B3F2B221F1F47859F667E6B6690D29D2C31459BE0E2CB
7A8762504951743F263B4041524B5883A54F3F8BA8837B606E85371515173E422C171515
151921453859938597B5C9B6867C60493C39458A9BB889A89E88724E
7C954A713A8D52626425497656264149517335754B357B389B39388F87494E925C3FA682
70622228919A586184255D4E400B3A6034463C271B4F5C3F8E440F1E88913963602331AF
7C2E3A721B5B7553407951335E4EA956274586733A496636418F954B60B35C347993384D
4E7570359153428A65635D628436384B3D34A74F5470646E4D3D626E5457623A4944487E
565E7E415F4B4968559FAA4134956D4F976D319D9352757087485871673C9357666F6873
876D79795775C59C733DA5924E58A979447BB75D7F9D8B477B7C41394C37805B56845C51
AD3E3A9A964DB27A255A653F4858A655348852602A7F879149367B717D905F40BAA1445D
93893F4E667D3B69927C30628B485168403757565488B38553908B4728586D3A4B4B7525
2C7C987B36505C3425814D2F5C5F27786624466C7F2A923E20444C4F23727E9891997658
3EC5A39C819A7D717CB1AABFBEBF8E703F1514111E17131F1111135D621C11151312171B
2C387EB1B9C79C8C7359A5CFA33322151B2025524C1E313246333B2E151B3B2E8F291C15
191A3B86211B1B110E0E1519151523411A99584699863C17131513131E1C345870542D34
403A1B1A3987C56E565C53381A1D2CA9E4A33D1C2B4544493A3027304B329FB394B58B5A
4ACD7B59432927606A95815686CBA8AE45A4794A76908270251D1E22262819181C2572AB
B8A5BDA433211D1C2960B861252F363E544E575D5960DCB9C6BD521515151571AE96B3C1
6B192859241D53571514172CB8AF8D7C798584AB643A96B9B0C7CDDD3A1D1F46AFCEDBC1
D2B98E79616F6A28442C1317334E5C85A3D5B16F65495C413B651C151513264F35171515
15191C3B31345FC0B6AD9868553736363438418A9C69659E4B79857F
88944A6544994B62602E487C4D2541162A51274D102D582B741C1C5977404382531F5C6C
555E231B5A69405B5C334E2B501C39682F4D3E5E424C4643AA6F3D1D6A6232685B332B7C
64273A7F2A3C3C3D4395702F3E3D8F70546298793B4E685B1B6574385BA1784A7794494F
447282399848397D576B518299594C53503DA157586A6EA068587174535F8D5F5C595998
667562378253515C4283AB5745B0514282763DA19F4A4E657F425A6F64429D6475825C7D
8381A88E4886C0AB7858C27A4267A87051A9BF70A0A4753391853D34644272364C763F47
9775579B8B349075315A604B4658A96B3E7D61714BC6B2AE6621618A88B37E47C6993C39
5B7D3E546E73303D69792F497F41476B5E48644C2B5A856F418C9E79326D8E4D4F559A68
53AE76762950666F2E8B592B668736775D2A597A733BBA3A1E3C52593F60387B58627E79
76CF9F7855646759413D8AA5C1BEA05C191513101315131011131C78402B344452535667
6A67568F8DB9915E5C32AC98B29C5D6557587A483F422C294B120F110E10161E74472216
15173D6817171E190E0E1A1515161743319E4148ACD1896F4E3D38364564644128161B31
343F19172F4ECF97AD9160562F2B84C5D8CC9E3B262F15214C5737344C392D6D905D5D8C
ADD2C09D58566990937D451E4397356FC9DA905791864A9793291B1C1B1C1D192370685C
C591C3541D1C1C1D2F339CC296705B4C4C4740353895D3C3C3D8BA631F21515C2D2D4544
5F1F693F213752351514193549191D21273A8D74261C6FDACB9FC1AD481D2781A969C094
CBBDB1A5B1D597432F151513152F547E9BCF9F4E3234542F3452151415151C4B4B191515
151921492C3347D0B2AC6D686030323330353EA1A36598923256979C
6B7A4D363C733F628F4A61864132544D2354286031225D326E4C2059794D499D6D2F6B59
48814F3577612D646F4549315622407221373F533C4A353A7B6D4B2C84543C80746C419C
5F2E51883C4A4030358364373B5176724A88A46C3D618C63308F824962AC7B54748B4A4A
49676F41B5613B714372576182464D52353DA24F54585B88615F6E5A48647C5A64414D7F
6799864D914F73896090A75145B889498A784B90A4525661715178844339764C8E7A4688
8E83B58B3E7FBB9C638BC3913D529335396EBB71B1C19B4D5E773D274334905D4B7F563D
916763A38B4C9B6B3156532B4F7BAF66396F5D6B47D4C5BD8324644C5683874ACAA96E45
708A425A63865E4D7785423B61484F5D6B49614D5576A2913F8AAD793A738F494C537E5F
51A29E5B1C4C6B773085593198872F7E662A437E925188492459956C5A80427B859F744E
5899C2603425402D271C6C89B1BACB98481E17192132405A6565778B876953433E394143
483F2C2E997FCE6787A7B85C99D2968779A369181917103A3B10100E0D0E1417337F2517
15174D3714151921131214151515152B46A54144789C735E3A34415780B02D1B16172132
325A3548697D87476360AAA295B3D49D5E69A4A69E84291D171F54554B4B3EB4AE5F5648
A8E1D6B4ACA984585BA6824F4D90352D90B79FB095753240669B391C17171C1C1D26459D
CEC9C39025181C1F282AD2DCA24E3825202120235B7E98E7D9C7D3CAAAA15E46343D281E
797F923E7BB39F41151930481613111115152D451B207488826055B8A59B7693475098A7
928197A9AF9C9675151514131517264F6EA36F1D24313F283B5815151515183D7A4C1E17
151B359B533C6EB87A49785679432D2E2F3561A78B8EC3BA878CB9D0
698850533A7338538648608F58253D4C233531765334673B76562049582F397369296249
2D5458348566294675404F3E5F1E4162374035563746404C9B814C2A85622A61605F3EA1
412B477732423B483F875B34447C65755189A9623552645A379D97446BB375488D964F61
7677543384563A793F725D5C5A3A6D6953348F36726F6B7F3D5F806F4048544561564F70
4768804A7431496E519FA83054B478458C545D9B95485559543A53835A366F32546C4072
7668B8A4638CBE6E3C56B38C4A76B76D367AA35BA2B58D4175763E313E267C43518A4E42
7B2E4CA17D4FB45B357C683E4761985350A399752DA48FA0492261867193654BD0A25848
748D428091956E5078823D548066576671537B424279958A3A7EB473366F8B433E447C37
51B86744226FA876347D382D707F3370893943848F4AA24426295066568A40786E7C6A4C
4854BCD08F5556484439A07BADC7B096A5979EA19A887A5E4C4567986F494F4A4238281B
151617172CBADADED2DED8C8C5D5D9D7DCD93711100E195B22110E0E0E0E120F1DB03622
1718502B15151C252F2617151516151A578D515AA93D40511A15234734315B25191B5A66
867E3A55536873467A57437AD0DEC1421F253649615B322E28311D347980CFD8AC3F374B
8AD9E7E9DE5F6A51355F3F5073A0684A7E6E629ACCAA583E345886521E1C15182E5886C7
D9D6CCA54A341F2629889AC4E15A251F24232862793AA5DFDAB88F9199B2B98947201E27
78C181A397A8C8604F215E151015131415151C2E174A64212EC47B75C56DBAB79467A68D
A38185A285426C521915151515171F466D545729233C3F2849441415151516276672292C
3D72747E84A1A66E3E314F7A6D6C2F2F446D655E61977E5069A1B9CC
6665516E3D8D474F84426D92692749642D5629644C4250206A541D4053432E7A64255B60
4A514F389666324C73424F4B5C205763354B444F3A5D4B467F6B4339A8782E6B636940A8
66304B6F2D50504441923E35677044773B718B7D375F6E4F4C99844287C0603166893A44
516B6B3D83405084608856817F4A4A6255438F41626280995A53705F5669845D5A3A6689
67746B4170516C5F43A2B25142B34B499C6048B6733F5C65724562805E567E4B6875446D
635EA162428FCD82568EBB4037789F5D418D734E84BC77397D78416D673F8C3761975844
773841845F4781372956412E4C6CA3372C53616149BC95A851246C7970715B43D3984B4D
795D2F514E765250656E283E7B585761413944494F6D9787446A926F2969844031658D40
4A8574401F4B6C6F3778482E758536727D3C43857654B7532F314C685D7D3F845E4A3F33
2E4C8BD5D4B4B6ACA3B8C9BDD9BF4D1F91C2713A322B2E34323275A06E3C2A1914111414
141513111399D9E1CAC1B4B3B3B19A8591BCAB351510355017150E0E0E100F101DCDAA50
4A37741B15151B1E2B433D17171515178575728F6B42443E1515251F271B1E3A3631449E
A82F1D37384970162E396A71D0D9522021251D1C2720352A2930363548D8E0CACDA77574
C8C0C68AA0914231511F191F59887D86AB3A373FAE829171414F4D8776343B506991A4B7
DCCA63376B4D4F4D938F3366DEDC9E81645286A83F72C2999EBE94ABBBC1B497A087444A
C0A18B9890D1D64E749D691314151311151519311F6F2B1B67938AA8CAC5745CA1D4C3C0
959F753C2D2C40603513151215151D3C774461512A5A38286D3216151515151E5C9C8690
9056546369C3C597312428659C97846A664433448B8E5049648FBA87
66715C4A3A63385769354A6845395D3544642C542C40723A6F3D2D5973452E874D32775D
415518286D4F2871742D4F54481A4568396466352C432D378D65283180543A7946383C98
62365A763041493751A06B375A372C6250ABA153497B994E368940316F897B48728F654F
4A707A3C745B3C694287476B75424A5B3850803B504E718658576C5E3B4F715F57395177
626C6E425A45676D4B7A9C5446A961398E6744C07B4949566E435E5D39556646665D3574
7571BE5A2C72B28458ACBF893E7E915077D58F4D87BC7F458D8937375236A447509A6443
7F5F4F94734974413C754E2B4A648638305F593D33BAA194312D876C5D673C31CA6F4553
76834A5A4D7E4B466883333E7F69546461525149487AA7903C65906C226D7F416287AB79
2B906E6D26557B793D9959376A4F3085813F5E9D3E51AD5D3429486F5C7B619153434347
50443C858B453B4875ABD1B9D5BA381986A1371C1917191A171A31442C18150E11131110
1313151317B6B990D3D6D09889CC8C5A4A59AEBD8045802B15161010151411348ED3D8B1
85ADB95B1D1713151A2B7B2E1919151C865974B3654642311515252F32293226454C4F84
711C15252D446E1719294173D7C13E1F492A1C191615152A363031459CB1CE8C525F80CE
CDA2B0934C94A98133181A195E5F577578422B3A9F962D65927E6676AFB8A97B98B0AFA0
A0C96F202B5A70AF772B2528BFD7C6C5CDE0DA969DBB52305C7FAD936FA7B9D1A89FA1AA
D89E5495C8B4A57276753013131313141115193C4D3E1D545F29222FAEC7A87E91CEDABD
842B1F1D21232C48591F151315151F34913E53C1759B3B358D27141315151F64A2B98674
574E2B399BBDA46A7C773B34C3DBD06750626D793F2B5178A2A2ABA2
5D5E4F68357643538752596E392A483B25383763392845246538172B4D30558C62255032
2D4F35286E43175673363A35461C38511B333B462944302F6A6E40377C2D345C4E523384
333E7475414C452B4F8B663755601D5C54A8704D3058593D378352376D9A73446D825D59
49586A3A784E4A7F51846377743D4787725E85314E67988153526F6F4E577161564C677C
60737D46713E6B7954929A4B50A97045986353C781494F486343638B546754425C653572
8374BF674E9EC15E4BCBC8994AB1841B4DBC9F4F8FC75431B18934404933A34954884346
8B4E628B714EA1443774543E49417F56326553443BB49B8D2C1F696A4C61583BCA5F3762
8B7B4758527A584E89853A4D916D58797A5F54533684847E2D58854F4AAB9A3E66749688
2FBE9C67244E722750915E418A501D7156263D7E7064CD442A405E6F19579F9B67455046
3B322E3D712F1617244CC48DAEB33D267A7D441B1715151314152D371511111515151015
1014141333BE8CA1D6DEC5524069A358382D41729ED2BA29151311131F48808F814C4F94
C9C67060674C2B19171B2CA0561C1525924598899264822C19151A5F5A4050484B3E4C35
36171523283D7C1916233755D6B2A153521F1815151515132D5F888081607CBF7F444CC4
B9AC495EB8515F808459372475434A73615E41708D82692A3190B68BB1CDD7CAC9A87663
675A946A2324A3B15021252F7B674F6E85CFDDDEAF3B1F2C235EA2C3A96B60649BC9CEE1
E0CCCDD8CC6F5BAB40403B211A18181717171B5D7A3551662D211D2878D8C79F9CC9B67A
311D1D1F1F24262B534A1513151C4565B36993D5D3BE8999C52310131332796C65B67F57
3525273D879E8E5F5B657F94D4AEB2BC7C753B1D1C2034775D96A9BB
5F915379357747538D52609A62344E672C4C2F6F5046632C785618236C474867621F4C58
425752315F3D1B446B2F3D5A481B354F2C4D4D4C2E4C3C32717E47408F5433595157338F
502E60793A4C3B2E83A15835575A224D4BA5A56D3B795B363784583C7E85503F796C4E5E
46435850883946725077649174426787685682357C65916E50758D6B4F585F677D587969
6BA5774194227F7F589E862D71AA734890213893B15A55623E69A0A65A7362438A733E75
657DCB84689EC03639C1A68162C5943E60C87666A8C36025596B263D5944AE5F5E8F2D35
94926B776035854C386A433164819254426950684CBB809E5C2963635B9C6B43C08A3880
A7924583738927609F945571A7366A87716B5F482551825543738F41156279457E979044
2991916B39618F3E256B362D69772C6D8A3E3C826594D677391D4C6343233E6A4C404439
322A26224B1B1614152990929DCB6A6582586F1B1411151414275D681A13110E10141518
232B314AAFCACEE0E2BF8F762E287B7830333E63A2D0CCA02F2240687C694129201F3739
6FC2BA8A4754684E362F204386783F70989256434E449B593B3341B57B3E2E2C3433373F
2B1716373E57B22616183883C9B384525525171515151315155CCEA692867362ADC5B3B2
B6A5494FAB50874E36405770B8414D6452AC874A2922335E52759F549DC5C4DC7E8F8C54
2E1D3C8CA095939041372953321616161A29B8D8432B2D191921509B9F643D2F3557C4EA
9063AFCFAF6C2DC9CDBDB7A795877973758597C1568D6C3B282221349A56882D1F49B08C
3A1C1C1C1E20212F396C534D678094BECBC0BF98C2BCC8DADA5B192C6C774F4F5D99A155
423A2F5D8A843C293738497BAF4E819C1E19191E21234067769C998D
6691567A3372454B8A4E619B6034506739583D835F3D732F7F4E121D6045596E5E1C515B
6253432C663A21545E2D48664B1A4756304F4139354A2626687A4948944A36605B573B90
58345280394A4030898B54426C56285A1637897438815332509E4A336D7D3542B18C545E
4B67183D9561425428885F903F2659794F516E1661548B6827526947485A2525504A7746
3155613D7F254A6465BF9D22559B635F985122597843687D2F31497457844620598F467F
292D886F5E9CB63B6BA4A64A5CAF95486FCB65507CA97E4C628F384252338A5373B14C2C
603248916F3E6D27379D491A225E755C35784C5241C6C1B27B275F3D498E69459BAC4152
6D43325F677A433B5F635B768A433B59276A7660467E7B4E2B4974561A685B274F5D6F56
27AF894D203E6D75337247346B67316E81393C8A5275A57435213C5857294D94503C3930
2C261E1B4B2E151312187FCCC9D9B4BCAA8EB2864B46443E382F1D3448343C47576A6B5E
69636297CDB684717AA88A7A5A243F82512A1A2C3865A4CAB49E653D251E1E2029293B8C
B7AE5071A8874C59664D3D435989B2DBC9A14347333F3E1514131554766044322C2D3F45
301F163A8DD0D1AD7B4C4FC8B5D38B54271E1A151415151316684034578F8B847ADCCF6B
6EBF5155B8ADA7302A253033827E48628B7C4F211B1E212450C1AAD5D0B7C0C591593321
1715192C73D1692B53858B7C1F1515171621A0CD46391D203E2B437C9A5B28467C97C4D2
A59E8A5D779D7BC6B9B096653A2E2B32334A8FCDBF7142342723214E7330535E1C336BBC
6A1E1C1C202024293689D18C716FA5976384A2ACC8CFD79D9ACEA6B3664550575C749297
856F5694C3982A2C32472C4AB98FC4971B19191D1E30566696954E8A
888F58763F89444A7A4D7A98533553585C713B795A508A3D8D524A7779414E684C337454
6156285CA34B2D566A333E632D24725F30504E1D43624328643E3E85914A3660312D4D8A
603D5D654066675B818D2F215354334D51988F503885571328596E326391302967704577
677644386B2E575B2F7045945725444D315C6E2A4A3B926A4048514251665F4947346F78
527654326C426369578A813C559553427B63216A72424B55593D5745418C40294F583666
4D5D933F2D90B0679596A87573BFA25089CC926B6FA8925C736C3F6D58458F31498D724A
8B6B5B8678448D37445D492C395F803D319979612159668B562D5D494D69351F6470485E
8F614468687352526E805C558E6B48845A71583F3D977D5B33547A52238E7A305F7A773D
35A3826223385E55518A5B326766335C833F41AB6A75BE522B22335B45298AA149373529
2B28221D34581713152DA2D7DAC8B5CF65768883371D2915213964768983715D504B392A
29251B4BA632211E1E2D899389654195C68D5D3F3B2B7AC0A5413739404C5A63655F6B6A
84A36C303A659F94665F725A3E5C68D9DA6C363A31491A1214151922514B1D1D1C1C1F2E
27321F80CDA87B5176ADD4E0DDB8968A2B191C1A171917172971221F4B44474869C0D061
448D8258A05D61502925242A5DAB77886A5A5F29181922272689C5D49F7A9C812B272923
1719171C64D1A97F408AC4792E1716161C416FCC4D22202E17173E44B2C0BB6D92B8D1A5
BF4E1D20477DB0D7865E7B9663383A39425CB8768AC0C8946F453B8B392C4971324651D2
552E1F1B202827306C99AF7C7F8D62518D9B9CBF9EC3849099B3E097A3A3A16A51273025
427593756675533D3835355FC3D4DED45D1A1D1A1F4B5B96714F7372
5A5661463A603E654F25495E374647213943264E1B32572F7D23283A55385688541B473B
586425215B2F276C4D351C492C173C411D43422C34381D1D78542F3F643937553026315B
4C395B6C2B22392A6D8F4A2D452B35584F968A32477C6B2E2E5F463C7A9B5934847A335C
47655A4A7A3D4660456D40745E294E634F517F3652648A755150875740617261544F7976
50707938432B697986B07B3A5C9A5D4E8F672F4F52435260603F55774C8D31495D59345D
7176A5555289B26D94839C718BBE8452A9B6796770A761839A783A5051338145538E5B58
AD8D6F7B63438A4F466E594654659052245158564EBD91AD561E46475D72552B4D693B6A
986B3D64666739699F8041508F644F9D6E735C3234A0A3622E546F3D43948D365A678B7F
2BB982471D4460542E584D318472355D65233E975572A7552A506863331557865D4A3028
2824211D22871F215DA5AABBD9CDCDC9AD967544877C7590907C565C6E594A3225191916
18181557471D1B1A171A2F7DABC0C3C6CFC8B398825A77D0933F4958545C614834275740
483A6D542027355789A295879893CDE7D16874918F80191B1715151D2947221B1C1B1C25
466783A5806B44403840B4DBDEB5774C68542D191C1C1D25674036495F4A25242E56943E
2B71B8615B503348472D232942A89E66252461491F1A1B281F3A7FA86D664F561F262C21
1617181B84613362C6D5AD6F582E1D2151253FCB351C1815151744415CD8E1CB9B778295
561D1C1E54617B8082AB969CC37A594F5D9F9D59AD878B90A2B3CBC3242C45609E926FBA
BD7C622F1F243182D1B9AF92542A325884D69D6DAB5F6D5F5AA7D49C8D949BB946465058
60567BA3968FAC6A49526D84AFB58A8CB478291E3A6199583E4B6E30
635F546A356334486A367264232A464C3721256D40323C257A493E4933223B6A551D4F3E
3E4D4326652E27595A292C42261A3C4D34473F4642564C266A6D3E5A752E3A6551413764
2B3768793F374C3383825E54644C514A46A47D3736765838438A432E53864238A7935269
4C6A596887464C7C5171547871324E78595F863E546084554A6680534357646856468D67
5171793E4E2965718FAA813F6AA95C589C6D3855614A4D5C64435B853E894C525B804E60
7373974E4792954F8FA5AC6C9FC16D439EAE698992A789764E513360543D7E5D6FB04C49
8E66748C5C4D782E408D4E234B86A56430594F656BD0C3B2882962465F8C773A4385434F
8879396F748E5F578685405B9A3947A773735B2C377D796230506F46207C81367DA29375
2DC1742517465B55314A3C2A62702B617440338B4B688E6E34182B504D173E76644B3E2E
29221D1D2193ADA78261776879C8DCC2978079392AB6D4936B796247564D291A191B181A
1B173165281C1C1A1616182F5EBBE1C6CD90584B526CA6C79E4A3828271F1C1C1D3F3027
1F19266E4D192227334871A0C7CDDED3E7C7B995975A331E1713161D22232F1B191B2120
4589999D4919313F4476A0B3CFC86A332F3C5A6340241F3672425A804D31252734397D3B
2C46A4BF9E9944303F443F4059A89E3C1C1F3553351618171B393E51775B4A572129311D
1517181D702F1D24B9D2703F588C8563301B3593291715151521483E52CE722D1E1F3261
241A1C2635165D514738747665716F657FB388A8B6C290673D3342A123294380CB5433A3
4D2D43836873A9D3DBCF9F431619282E78864F9AC2844D50547D98797B7A6EBC90371E19
171A4373417CBBAC8BB4CDBAB15D1D285CA6A5566BAA4F2F404D8D60
6A8B5E783B7F4247652B58793C3D48514B5F2B7B664568297E5F41454B3D486E4C245F69
5657412D834739786C2F49524028576F3A51402E566949235E4A3C7A854D2D6770593A7C
61316A6D424C5F449082413D52475258527972423B815A3D4791543A5691393277784079
857549557F455E724A764D7A69436A65496C7142695885523B59774A51664D676745976A
67826C4F782972658ABA7E367E98616C9234417A7C49537340567D653E91406F89634A67
5870A85753B1A6406778883F7FA47D54B0AD59635D8D7A825F58306958306F2F5A976955
893E458E584B6B1A3DAF5730455593542B5E4E64449385AF8026706B638868484A934657
8E302C6E797F5E6376422F6C945B3FA13C767860559C6936456E784D1E7B3D2043648678
2DCC8D721C4C5A6137404C37626F3B7882403178497694673317234B501B438AA88F7445
3C3A262041B36A42614F1C24689DC4C5C3BC8A6EA5D3C8CF873E291E1D22535E4A4F3432
30368E341F201F2020201C1C6292D254966C40444D43907DAC6232312D2C213147392C1D
1515151B7C641F191C1E253764B6D0CCE7E7CA6F578248413C3237271F1C1F4D592B291F
3E9AD75F3219151734864A7E8DC75B41303A31414D6473B74A46866D2923282539468046
313E6EBA9E9E746A5351678347839A512129293B4F25171A1C4638529D815359222B1F19
181918266B2B2B7D7642586A4A73AE46241C3A491A15151515335A94D7DA521D1C192357
18191B31171569415E2A3D9AAE7E757089BB9DD1BF8F40221D1C2584354F94A19A4E499E
253B3A1E90E0C4A5BC624419151F27458B3721368E3A213B4E4B7AAE4F47465645151315
1314142A573957C9DBD2A6CA966E55544E4B65C4BD532E424D86573D
808067583B6D3E459042749A4543513A4260306C4B4D772A8D3B535D4F3A49653D2B605A
51561C3C963C3373543C48582F1A3F4D2B5938213E4F33225A272B846133356849376374
51306A5A282F4E2E798457444A2C4F6C5D90852E48907B365B8E483F6594562E7C61305A
4D594A63842E5671496639836C324F45387D7D3B4E3770764A5B6044455E60545B3D6E5C
5F5C55775C3B6A496D9C6F36677648618B5B466060333265523F4A413E94394D5D434A74
4F587E3C3D98964E786C945A98B2895EC4A8727C6C876BA59985275B5928694151734D59
81587BB2624B7E2738B743384A5393292772877956BEA1AB41337F5B5F723624538A415F
8B5B44656F7F60759878374D736547A675786E7F5B9C7F6647557049218E914A4D6E9191
36B39784264E4C713A5F5E41552F1D607C36318258A8A75D36131E4E581B4C876C5F6A90
87504154A5705F7A2E1A1D526C973F66AF9A8FBBDAD1C2676B1B1B1D17153A7137342729
2D6D4D405157564844453F4F6F61C476491B15151616376D644B603C2D29283C434E2E1C
191A151525985C492A1B1D1F2D89D3B2C89ACBBDBBC273525087958B7C77798B92755C5D
7BBFD34D3B1616215E343F9D7A85424D564D4339373857C890858E332220331D21638D3E
31297B6A506434404D67B053717CA063221E20213B371C1C1C483C558D8B71722B441E1A
1A1B193E8246865F351C203058696A37391D3B331A15182568ABA2A4A1ACAA1919182551
181B1F28151959303A48408ABC8F7D7188945677B2B78467754865ACAC90454B59685B87
19193A5A88C9503E5A503C18253574BE7B1E1F264B28181C29518E901D252727481D1314
14111216697F5BB9D19467959941454955686C92BC606E7F8954211E
61535A5B3A63334D84407C7D3C5679543B62286B3135561F873434454D425C6B50234F25
4E58282E952B346C4636224F311D3E3D1E463C35504D291F66492F8E431E3A724A2A4A47
292E51613C2F3E39997E556258365359579B6B243E7064354C7F2A32507E3E33716C4375
4C483A6B763F625D51695872743950855B83823E63647453496B85474B525B515E4E7254
6677719D50387E658DA35F34747B5C7C86485D86743F2F6855444D673F8A3A6E6566457A
646A79464EA5A762776C87528FB28176D6A46F81666F54ADCC57266A64276E41586B445C
81528296445D9E4B3BB94A496267853C274F4F5A4ECAA7AC7331674B6B80573E6A733E8E
B35F3A6E73363D92BE8E3F556D68418471856C6B62D2BE6F4C547E3F41CF97475566897D
2F8789511F4E50455F9E6A485F752748733C377E3968AC5C26121A526D216099534E4641
4F84B2C7A5826837171B344E81502138BEB44F3BB5A49324201313111113362817171515
15324B3B36393D3D33323D4A7A7DCEB22F1513151513314B531C3D2328221D1F292B2D1D
1D1C1715184A151C464923335983DEE5D1743F4376CCD4B55E9D8B7168787A8A82AAAFBA
C6D4BC81442D258135364E8C325762211C292E3439404C899ED74027231F291D207F8C48
3020764C59682728383F815568B3994F211A1B1A1D3B361C2932364C9BC1998A4F47201A
1B1B1B56BE9A5E371C1C1C1D235B8966391D3D3024467E825E49687C7767AD451D1E535B
1719262215234722294675AA5440372E2C475B338FB42D2234BFAA8579302242535C3F8B
19171E31899230443E543732645C336A401D2320373316191D2F5780311D231F2F451512
14121322665C489FAB5D2F697F1F212932353C5D99386B9E8343351F
7185687040873E45883E7D652B334B3B3C21266E4C323619794332505D34496A4A245C53
50513128822B424C3C2C3F58221A3B3A364A312D3F5C4A256E622E9777422D6958325754
4E2E305D3831493C98752C445E3E522F50A875354C8C582F4F702E35547C3536808B3B78
4B4F428683406B557187538E65426C693A7F7476967F823269A380454E515A626B526F4A
6F7A6A9D3D388B5F95B06A4AB08C5D88803176A37D4C2572547A82563A8B40756E704A94
7470724B4D9AA5506F779353898D3144C09F6E8A6A6E4B898F4E27694126753F4C80546B
7F648989452961462BC23D2967AE8E31325A4B453CCEA9A56B3581508ABA65407A6E2C8B
AC613A776E6B4E546B6F3A52962D359B68796D3128838B5F4953772513999241566B7D2C
1F7B8A59264C5E2434433E5582792C51503065A75D6B6A502B11164E271F82A15D524C3F
5A6BC7D2D3C32B19192D345E864D666C68A0893C818C816A591E1B231D1E4D351E1A1513
151A3B332A282320242F342E7DC0DEB47C481E1515153F474F1B191517211D19232C2E1A
1C1C1619173C1713153B8F959DB5CFD8AC823A332D3667504449351C1D1C26867D5565AA
E3E4D0C796779F7C3F3A70531B1C75491F1B1A1A21292D563C8C3C232522232D42816E45
252D7E3F48612927352F4C957C80C46B351F1C1E1C1F4332453A3B50B7BDD3C689361E1E
1F1F26B0A451391B1A1D1C1D1E423D706F3F6A907F6D41405FA4BB641F5F58A424224460
16193D151537351D20348C7B312B1F1B1626571F4BB1551D5393385D712529334359368F
19151822937B7D7C779EB07C2E151745301E252328421C171B2658622A271F221E353015
101515404B8D859990454060751D1F1E27303E3F7435516F6C2F505A
80846B6B659E4658913B83A245486A554D6731855A3A6B2E904C2C55714757685921655E
504F332C7E354D4E4E32486125193C2A375333334168532B725B2DAE7B3F35705024645B
5B3A3769404C73338E6B3E4A5634514E3E645E3D5183542D54792D3550722F607B783582
4853287173376C4352754A82432D546E43804C3C6B756443365473404D583D617A486837
787D5C9C44297B61ACA363245F795D925E2F4E90553623593067945A3B7D307E68733F86
6A7A844E4BA28E5690AF9B4C8CAE746BDA8C749D747C7574704C3669362786394B7A738A
9F6A6E915C4B7C3A28974B352F40614E336357333DD0CC91593486157D9C5C439E70235E
7D3C2C7D6678515A856E344C64382768526E4F3F5A8F5A4E3C5E7C4225AC873C5678894C
273E714B3968884F374232406B882C5F762F407B51888E40382A1E40541C4B6F8694A489
9CB8D2BEB776845F49367C8B86723F1A161B58957AA9B0BCDBC483534B4D84774B211C19
15152B3128201F2E3C3F729BC3969D6B89936F3B23154D4F5A20171515171F213326361F
1B1C1C18152919131218946C46A8CBD79C35393A342C2B2830394B3D1F2B4753564F5D97
D8D35B55504893A07DAA9A2219172D7A5023171519202547344468201D1F202F415D6E49
25437C46362524222A2530824E31A0CA63372B1D1C191E48724B4481AA96627FA07D573B
41367480863A211F19191B1C1C513B2C5ABFB96F515A6A8B93ACCC662B574A70721D3B5A
171D4215153F2D1C2741632B15151515151B561F256C9B728B3C355497352D363B5E499B
2215193DAF85B295A1BDAD5915151645241E211F1F49291C1A2750A85C2C2D1F231F3533
13153A524C9799AF8F54598CAE3B2021252A2F4180676F4E69292E3C
7B6E65454B78425582418DA73E4C372B684F35622F556230944C6E8E704146665B2B7868
51472555A44154563F3F49562E3E7D43355444336E724F25641F40A17A3939754E358365
5A3A605B2F4D4D2B895D424E473154496397592053803D469C914137515D304A51643492
5E4E337262386D6A6B694B76592C4B5933737956896D685C52627138485D69536747595B
65796D7A50427D5C9FA2613B89696EB74C31629B54392C624144554D389645A1A77A3378
68A7B67B51A46825517A3E3E94A76E6AD8863F9CB5B28B7E79384577772B813557896E8F
8E398BB6504D6642288456564A455B4835615F3550CDC7A67F347F3D59644350A575386A
7B3431A392895C587F6D4A787F5B42544A7043207B9E4D4B5A8B7B4C29A16B4D8CB2814C
34486719193961523D484B405040428A8239569C49798E4B1B3049685B1D4B814B51454B
86D4B49E984E5480B2B988594C3A241D19151947BEBFC7C8CE827A67605F6A6863574C4D
38212A40433D3636363A719B5E964E2C213955716A649D66733216151518191A2B282F1E
1B1A1D15151A241514305B3B46C7B1C9D18E6C3D292F333426293E5676513B4E57564F78
D8B12E467061846394C6AC3A1815156F732F20181C1C205551417A3B202122315C67633B
3D6783541F1A19212B242F946C66BADDA46167625447446D6E8DA1BF7DB790A26D4C5B6D
7C7A847DA354442C2E291E1D255E332B62CEA39D6452433A253360668A73524385494963
2952691517452C1E29584C191515151517185021215BBA9E443A56B9D4B25F3B396171CD
7D2726A1ADA18E9EA650455B451715441D1C1B1D1E2C421D1D2E53622F522F252625253E
3B3D504859624B856B80BF8739645D2F232B2A2F7F9E84727B2E2621
787B7A6D498D3D4C4F2467843949543D3D572A7144284D256F2B36595B36426E352F5C47
4E5024266533475F4034374F211E493B32522D18444E291E7337249C5C32346427238162
462B6E5C2856432293734C473F34705B689C5B227DAF4D2A53693D5283814C5F505B287B
61522D744331885A634C499766355C4F3A8985585072804C595F3C4B8270566160465E55
6F6C606F494C71428B9C78468C57469B644084B547404B883C50573654872C555D612B59
4266563E5EB8824C92A9633F7AAA7072D9906A9885828C768730448B6C2D7F3957724C89
7D4C6890464969221B744C5D4F515B364E897B4842B38A9C783599676456466FBE7F3F85
A53234666B5F4C89A551253B86534457296D63447EC06A213E5A6A4043BD712F4466582B
386C5C2B23406F37564B464A4F6523597B365E983F89BE3B21121A5466286A9031597454
8FC3B4A68F3B5C9D8E845435211D241B1E1C256ABED6BEC9C74D2A24272E60523430383B
64766C6A39181515151536447D2A48593623212537527C94913D151415151416304B4F39
353B251A171731151741364884C476B8683146626B613D3E33214096B38C4C2E18181526
3C6B621E59C098A17C8E3053471F173F9D5232211F222574614243572D2C328D87945346
858880711D1C1B191E3465D08FBFBE7C47383646476775B0B8C2CBB6B5D7A87B565A5050
5A7F8891985C6556645D6B76ADA1286189AE77622B211E1F1D30394477B5663959A65BAA
817B8B2E3D86313B4762331515131515171C672020448D84455DA7B74B6FC79B6890C4A8
A9C8C8DFAC8B88B4762D2D3B516248321A1C1C1D1E22482A1F39542213274B38242A2A2D
6E7733617C374E77478A7F59251A3A6F4133466A62B2627B9B897B69
6B4C695D495D37628833789F425177554F5A3C904F363F3087443063413C548A57264722
556638367D21437A5B3D2A5232284E2434632B22555A3A1D855925A868312D6E512E7327
222F694A335E21206660403E3A1F4B5668B06F2B4B68612F627622394E7C4554516E3481
45442D746A357457676E537765385B4A27686752666255475F693D2C4759566A6D3E7C5F
927139626B537F4C899C5951A77D55A7452D7EA76C312A67317E733D3D7A3278603A6286
54949136419B7233527468407E923973CDA77AC9AE8665775828387263428D384956328A
915594A74B4C672E195024726C57501C3556896152CE9FA16046A05E686B2B4CAA54338B
A86B327F646039496E682D539B54575A4A64593B74CC764B425D6C311D837E41506C5F40
2C4E644E3C6288493C463F68806E255D523D91A2536F964F341A2354301A467A3B747652
6AC4BCADCACC7A6679582C1713110E111C3C4A5F9381919EB79964422C43413B443B251E
1D1D2C3F2D1516151516484536182A6D4D25232622273B7C7799311D151515152584A24E
282F2419181741175D424D8ED4BA617D1913151A283E66696C939F8E6A621B1515161518
19368825654F4E7F47391B1C35442F1E769A414C5E626BA4B7927D8581595258AFC2786D
A2A7B4A86C5653504F5CAF90CFD7B7391F23272B354568B0C6CFB3C6DACA4023242D333B
3F567C609E28412F2D2428353F8B9983B08B5E50261E201C1D3127518690AB574A6FC7CD
C2C5C1BACCD2A3BDAB87311513141518182A8E582529748C9594B95833324FC1CFD18451
376AC4E09581BAAE6C3A2D32384575341B1D1C20262F3C412871842915151D4A371F2D39
5959335487446A567A6419276D3916298B8E8C5E5791867D925B6A76
747C75644C8333456E397D492D5861484B2E2B794B4445197F433759351F26705A31684B
465B32376E334063623E334A342D58292B5F553851532F298B4F28A64D2F4E7E58439E2E
19249543398440267C4E353F4A335836488266345E8C543B8D7E313C566C385B6C7D3B8A
49642A6E5F2D743F5E735E81584E705D357A66636B826A443F504E39514E374B5947602A
5B70475547427A5EBB9B4440888156A7473B6A816E3928521E3C4E53518B36A0786B3855
2C634C4C50A67C447D9E483F8C9D5264B98364CCDA8F68606423688B444A924362442C7E
7745779D354D71461C581E515671693643686C4047D0958C2E346543717D5071A7663973
96633DA48E8759568D55298293434154489F774983DB604184AE6E3C268D7D538FB88B72
464F5B272D878952514C3B485E6227626A2E627A4FA28D45364C5B7C5A1F4A7F5C463328
2AA46465A5A8B68EAD7B4723171313181B1F1B1E75554E8892B3925B4721100E12224436
2524326E52321718152A4364191F2D5C69554F3E31251C3174AC7770371A171F50AA8866
4D3B372F31407781AEB0B3D7E0BA8857131313101524413B8C893E34415A2C1515151718
1A2A60565D211C563B2D1518191E363E42D4B6AEC0BFB9BFBDC4C6CA9054849B6C6E947F
AABD9F4F332A2724293673B7D4CD975A2A1D212040786587CDD9CE88648A301A1C1C211C
1F2946B7BB8C323B2726231C257AC4B8CC9B6E5F3B2927242B231F45425A965B6894C7A2
6B948E9FC9E1D2C1C0602912131315161F706EA4642B75A7849CA448423F3691DAA67E29
2A3F61D0B2BE6852762F25302F3148651A1D1E1F1D2B3C7C97C5BC3E151515184A312125
5A5D2A589C6B7D736E161312226B3F33519A6D4955A3A23B58C18D8D
7E7072495C7E3D518E3883953D4F7660556E3D91503C5932954C44706529346C3A376C47
4F411750782D58644B44525D353B6A4138492C245E4B211D633426A2321A234D344C7740
353F982F2D7B3B36AA542E4B4C486353569C54296F9D512A596A35456A6025385182389B
796B37824D3F98617257539F523764553F8F694B397A7F5054582B476260515E5E3B7054
6359447A5F476D4E94985B50925569AE425F877F733829582C4B5255628B296F75664562
4F8F504059B2704187992C306D8F5971C275408FAAA269675E273F856D2D713C71583975
6E1D9EC34D4D6120235D2568524A411E6193853D5ED0C17F5B3E652852664082B9753F82
96253C76737D575D7F45216C88534F3D2A575F5478D9564543546A30278340334C5F7753
3E527D7D3D6C8D6C594F515A677B276E6C2C778245947A4525192357404190A0473D2F2C
2CA658526E7F9AA8B36E40472610131515130E0E5D41466FA1AF8D6C411B0E0E100E1029
51403B3E6E82491D235A614C18334165413F534452423123639F4E718E847B58545C6176
617C99A09A989D7A64667FD3D7D0C97F191513101313173F4B5E46283349521F1D1E1A1D
18236F7D4C191939412F1615151617223BBE64453F37344A8CA5A5BDDBC9856E8D6A9CC8
CC86725A422D2726284794CE9B599088A26B6687756A734786BD95281F406E3018181A1B
203475B965687E53322D27212C80A6B2A999706F4D43443F24192C452D2C778975B8AD85
4A6D8590AAB6D9D79763211D1515151C746017299A69537963C8711F181E55A997C29269
454A60BCDA822C533C4E272A391F3080311D1C1D335886A3928B8766181515151D55302E
4C572C7CB49E829B211014121519ADB96B6EA35A7391C565655A5664
6F6C86604C763E55674292A241517F5F6F6B3B8D4F3E5A27732F265F7134526948266449
5E461B35681F64792B383A5B23244C31436E341A5C583D33811F3CA059293D6C52547622
165D7C3B3991152B5E462E432F34544D67A050218E9054376F772554867830435A61246C
4E58369B6B317F606B6D5995613B6E4C2B7067525175755A5351522D3E61586774416854
64582D8064434E3B5D5E5462A553458F3A64BB924052636E2D4C4C326F82478F70425F6B
48854B1537985A40A89C5B3859964C77AF7166B5B3976B6758303B786F37722C435D3F77
724ABDB44F676F1D195C306351574F104B708C4D4AB77977255074455A5B2950A56C3D7B
955C368170865A53837246728D515546446B53495CD15360555879312B7C4845615E7239
426C98853B86754189A8595C5D6C3C976A32837D47ABA655381D2C512120699A86634535
3D9F47664075615F9485271B200E0D1112100D0E5D362C5D6B9E594C401C170F100E0E10
1949593D49629A79747B9C25213F6B481B171515172A505059B04247729D7A472B1F1E2C
5759443E2D2E7A6BA466686A8DC7B38A251615151515151F7438A99370648A8A4C484957
566F7F574E1D1A23483A1717171517194E564959431E1B1C2A56B4A9DC99425B46255AC3
C6A7463945554C434065BE5E343E5C9DB9DA9C61525C712F79AF8C4A1F255672231A1C1C
327B723952414B62836F3F36578195A19C604659362E373B3D4C6C3E2B39693062B45929
192D555E789BA39DBE803F1B191519596718151A31C59A8BA3BF2D172E69853B1B499EC0
A67FAEDAD9803C65173A5B30422B2B76743F6168746D8A9A7158559134151515151B704C
4B6943A3C5A5AD261114101015197D70623846CEBAB3D4B588969393
664D694A4F6740697332685D3D838851975753853C44433C9D4720583F44637D41284127
6B652D3A7A1C404C2F241F472524581F313C302B5745252C794B2192322F5A6E4955721B
163F3F1D38841936662D3C764241644B699C4C1D7D823B337F771E3450662E46817C3693
4F363EAB87377D4A6A7B6DA0603E676C48956E5D6B96794C658861353F5C2A7BA651953D
986E418154505263A5812F58B37452AF3676D55B4D373C49234C4625675B30876641465F
40A165455ABB404D9DB962353B734B5992825AB5AC8E6C6B662F44827534823B4880567E
7853C5AF3C79855723592A9694947129626C744258D09251303C524453414065BE533D6D
8E5B3F896E86585A8D5C3C7489515750476762534BCB6B6658638138389A584A647B694B
7FBCA27835B73F155C664F604F1947AE7933786027C4B26B3821334B5C264689A4C6BEA8
B0A94D562B707F55764C5D140E0D0C11100E0D0E6131172A31549464503B19130F0E0D0E
162E5C505D6973C7C6D2BF31425F732D25251F1B231B194D75C3546E978D8379491A191E
214D72878E8D7A6E91A8877C545D95734C1915151414132564376A3F353D626E201D1B24
2C40735844342E44483A1A1816191B46562A2930494F3A2A1D35C3CEBCB86B63244289A9
7F639963283C5D6A99B04E25252370CFCFD4573C333C49877FA9928833242F5364241B3E
7645261C33582E2D37528BA3BECCD4905236505C3A1C22202021474530424A367D961D1D
201D1C353C51429C7EA3942D1D26568C17173F668E8AE0D6E1BD2E319F78221515194297
DBC99F7D98B6969B291C56815A7487BBB17D624D7883A357444E331E3B3917151D172694
72A883ABBDBE7F4F49443F3F4368AA5B211B25D1CAA1B6CD52392C36
756D7C49507C394B6D38944D253F64578935396E4B44272A7A452150352E4F6844265F59
5D502C3E893E574C482D3B4F2226583764472D2C58643F2C89592263601F34754F577634
2844472144853743652F1C504C465F2356975D248A8242318C88273A554C2A5171792E9E
493336866D34771B74786F982D59897D4DA54F8C798B6D294C664E36434B255665478424
5C69428E255F7E7B9D962345926653AA2445D15158524B4B2B5650377D55328E7D655F5C
3286806172B55C486F7C5432426F3F3F68916197A99389B0943C45877333843D5287507F
936EC8A033979F5D263D1953536B7F4660626C5056CB9B684E386846524A406AC34E3F71
8D593D8C6A7255A3AA6F378782458A6C4267593C3C8F56776156453C6FBA8E55616E3426
437099613CC863365D4F4A655B60368A72346577297C8B4A39282E454F294D944B526B95
BEC64F443C29344C523A544F150E0D0D0E0D1020A043191A2024456C7771362A2B1E2A2A
3C5B636673A6C1BBC59DB59C61918B2C232124202128417AA2B4937D544934497D68424F
3A3479C4AA69526EACCCCA6517196C60622616141312153C3F3F442A22292F3715151719
1B2843594351222F7D733E2B222959593D28221C1C214B6F79758C9FB9AE9F4B57995838
2B3445729D8E8480BAA72828283360BAD0D9BCAEB4AAC23B1C80C5C39D56443E625F4867
371B171A1940432C252A4A97BBBBBC856E5E4B21363E1C1D1B1C2C4232552D618F441715
1A252F2226361753A05F92AE788FD5774C5982A7CDD0D5DBD2B997C4581A1515152C5653
9A4922273F8D8340743236CCC49B7A7CBC9E9999A7BE4E171D252D151959472F1B151A3C
C7D3957ABB9B37323B413C363A5FB2641D1E3FB7642E57AB2222262B
777980496390405D402589723243543B8B7860956553484792532B49553E556B46275C54
664A2358A550624F4E4E3F5434638A425B4932298A5D38308D402B694D1F3B6D465F873C
3042712F33682A47562F2E604344533B759A5C2A8D86404EBCA33A3F5C442B445F672B99
464543955B345F27645A72821B5378694395426A5683653D485857374339326D4C417339
6E4C3A852D3A736BA6884B4F956A53912E44857A6F62595635787746817A4AAF82626C59
1B725B5178BD557388A166373E511853B8A54E7FAE8E548D7B2D4B806D42763849875AA3
986AC29C19768D4F2C5B356147475C3C68515C1B59C5CF83572F6C4F6D63476CC64F4EA8
AC623F8C6A1D3079AF73388B782B55603E635C273A7C706F5C5D2D1938796D4E6B5E632E
497D6F4874C86939625545938A753CAA6C3D829F44988D563925334E552B588A51493D3F
5ACC813E241B15151A28455F3628151118315F88A9AF5B30292127609AA88B598B484A50
55577F898A828A6A8BA885ABABAE89623625201B27667F54407F427474506191B36A757C
6E6E8457595D7088B1C9B049251529805263181315172B41265F35202322313615151515
151C3A4B4E674558A0793C3860765B391A191916171A224FA5716F5573A1AAC4B3692D1C
1C1D1F29BC67556784974F4E5C589DD0A3BC754F5A84A04F22AFB0A2B0868A908FB1C442
191717171A2045524041588FA6BED9C24C2A201C1E3B441E1B1D23423D9782AA711D1411
151B241C222D1317625A85C7CF96606F867563719883AFADA0B9C94915151616223B6369
932F3865815FBB6A4491A9AB8FAEA48E90A1BFC9C5C73D151B2062454366794C5F3A232F
D8D8D4B8AF622B2F2B2C28253D5497571D20648E451F2CBE4D313740
A172793B647C426235277073323C4A226B60547551745155945A45656B37526839386B54
643F105B914753492C4035421A275740603D2617585038348215689A52224042257E9868
3740832C36591B4C5A24315D3D4D4E426E755324907D222462732D3E666A395B6E692A9F
5741428E683A63485A49735A38466E623D896B71527B573D54685C42513A448D504D904A
80603B736F5176779E915257A5626292437AA15B5D5C7245309B993F7E5B2DA69A577754
4A9A5B4E87BE44807D8858375A6C2937776E427EBD95827A5B1F43723F925A3649702E68
924EC194225F6A3B34613487524E4F236A4D542548728F8F6226493ABA9F456EBE2E3A84
A1663CA17E5C4C649D67369A8D4E5251385B62232B8B916668636E272E766D4E87A26C3E
55B0413BA98C7B34554E2D626E603C9F39398C9D469D8A31465B867D3D305F774F484D5D
59D0C9641B19151314131A42857079756F623C29263B7D91563D31408CB9DACECB897565
6B5338553B5A88826466AE8A7C903F2D4747427181381515462F201C88D2C79167363DB2
816F7E819C7B675850A175894D1B1A446B6E2815112C4E3135AC341E1C1D243716151515
151622A3C2BDBBC9D7BD7C82916F69453624191816151C3D699F9952434A8BCCA5401B1B
1C1D1C2188313B83808371415885ABA7C5BB432D2738326EA7794749782D24314979A73C
151917161A1C2E4F565BAAC8CFB29C9F3426211C1D243B4825335288B5D8E1C68C1B1514
151B331E312E11151A9497B28C4362606A78A3CED0A481A84C76981715131519264E7A82
9C4F5C3E222748C98EB5C48E2AA8C9B3B69F71404143873323483B1C263C775E3B84779C
B2D9DED2A4431A1A1F221A1B202D645D2D2B9E6D312A4FA24B455366
7666773B597540617B46908E333976606D59413522734A4D7A2E758A793951651E356959
664A12478B30514836483134273E79385135151F5E3E2032813A2F66512350441959753C
254E8C1D394F19506021375D385753479F7F49278C6A4934998823426E68405F7352348A
774D3E9E5359984C5D507D52345075774089737B5EA17C4A54713B3F5D6251794A579D4F
875A4D9A7C69596BB6954D59A130788E4496AA404B9397402056502F744E3992785D804C
498C50429CCB508887752B407587376288422393BD939488551F4696444056336B6D3585
7549C6932B6D60413C713B7D524F5423674B5D4C8B868B79483B3E2F936B3988C54A476E
7E3144717173695A893329A385494C4646927B5229968A89A4A17A2C2D6D2C4651738B56
6EBA8673B2697F3D5B5E3C5E6E6A429664307E904CAF862D26303D623F306298505D6B63
8DC5D59B2C191516151313199DAB6E57543B1E1A1B1C23437884819870D3D3D6963F231A
172966451C171C60B97E9BB375557F4C447C8E4A1C15173F43271C2941A1656643557FD1
C78F6336231C191A1971BB77834527266F5F8F695E737F98C3D29A3E2F2C2B4815151515
15182D6A7CACB2BB8A7AB4CA938D68493F41443B251D325284523922262843BE722C301D
1C1C1D1F534234494375797D90866A94A57E7F6542251D36864D2D4B7734211D2D496866
2919171B1B1F4F4B264F78A8B68462A4352723211E1F1D32A1A188A1B8C1C9CF98511515
151F1E1E2D251115176A66AE8F879083888387A4D7787D2948838A1F191515192D66907A
B34927211D242D7BD6C7AF82598160391E37584D34353D83525917151C2277C2A48DA8AE
BCC0DBD3CE5B1A1B18191A171E297A8974A7D25C3255B14E1715171D
7A6E8948677B3D697E479085354482616D614F814051432B7A38395A4D2F444F362A5B4E
634D224F993A4F624648283B3249682E45361C2F675136328C38336B462357671F4B6B45
2F51862D3B571D69823B345D2E6268499077542A8570483D967624577F653C5C716A2D9D
615A378C713A7B3C604379734052805448A376844386824F4E7A653F5B5F406C714D7B45
6127447C655E473D767E4056A34D748143A1984349545E4B3568411F775B4EA5564EA06A
4A865344A9BA558B8D965D2C5C8F40679277336BB78C98B473387FA768384F3069634E9E
642FB383255C413A8580406E514A582E819D805D959F92601A58654EB34B2765AC3F5173
775440766C7B6E538F701B8C924A4D543849635A328C555A8177762E3A7E72515269894C
8FC1895FBA5767459E8B40645E5850BD6C38927A4ACBA25F4A2839655D39789FB7789590
5E396FC5642529151513143A67332121354C4E40271C1B1F2A5492A0C4BFB6B74E3B3735
32282A535622153E998B454E7B99B3BED6942D3C3A395F71432E2539457C66611B191C8D
491C1A16181A1A1C1E6180AE4667474546ABB4875B586A5D576DC0AF916D686927171516
171E2F49568B5637505A75BD6132334363626F55687F96A347562C201C1D43C25C1E3329
1D1B1C1D34684B3427614672434B4E732F605A738B2D1E274E53233B5F32262F315A3F57
5F2D29292E355939557C52AF97693F91853321201F213053CAA17BABCAD881805B704714
151A191D2527111329605AB7B7724F5C5A7A4F68AFAD2E1C259FA931385C3C3841567096
D63A25222525254FD5709A9EC39C7815151517305B3A326995832838433F7AC4D3CC7D99
C7BDCAD9DB8B2F1C1C2D415F768BABBBC6DAD69F6B6FB14F1B171317
7263B54465744886784589843754955B6A5D5A8A51544D2F994F486859456D7840314326
6A691E5C962348612F342A562F446C254C563B3B5F3219427E2B3772253B755E184D6148
2575863E32531870602A3058333E4949917F3C4B9B8F543B9B5C1C4181603B6C7B7D34AA
633539907F49753C84678D7741728455397C609D589273436F825846643A3A6C575B6F50
6F3D526E45737B6E8D863169B45A7D69458F8E52506A6D4C417F7237715B4BB16D4D8966
52AD684AA6AD3891B394523368553569A2693586CA616C8C521E4464376358337340459A
643C9F782C7956294746338F817A5C1A5A534D5299C2AD6A3C466052C46C3C6DA74062AD
9D5744947E54649F94702494884D7C6F465B583F498B6479AD9B4F426C7D6B50738B7149
B2C37856C0804C245A5C4492845D388A6550AF73388F9B6D4755A8AD3D296B77AFBC753E
2E2A2269A0461E19171418623915191B1D191F3266634E748AA7C3C8D9D7CA6D24171A15
151517172E64666195251B1B1D4BD0C0CF3115151822876B5855713C5C765D4319151A6F
22171815171C1F29329C9C9953295C636AB9A689AE96755B677EA2A489846D49536E3629
2F45395E725E321C1B1E409237211F1D1C1F2E5C96CED67158501E1C1C1D70C4491C1D34
2D1C1C1D3C723D2C25624E5737305C351925413B3B1F1D2D3C5E343544312B3A568A8143
87835F4A44352F41384244999C8D5177328651343B597796B0799BC0CFAF653C70455E48
1E2B221E2E2D0E1A556A646B3F373133352F2F2B3C82301E29BEDEC8B9C7C3AFB4C6CFD5
D8862D2520231F44D26576ABBE9C6015141915163089739E6C8970232851A2CED9D9A8B0
CECAD3D3CE914B8F9EB3B7A9A1ADB1AE916B92C08E3A738D3C231516
82547D487253427B613F824A3B68833F55274E7549522236854A58814027445A24385D43
5042157A97454435194B2536254D75463D331A307A4526426B285C891E255A5327627926
22575119344C1F836F1C3D66465C3D34766E3D2775592456AC682A4A8A373F52676953C2
9A402D60646A8D30644A9C7421385E5249862C734E975F293D6149709D673650447F8E3C
503E7B8A464E5E69C59E4151A13A8B75486B6D42569E8B434F897135754352A681549848
567D6145AAA03497AD7C53649E873955852D19AACDA98D984243869E54345250A6564A83
5845C3882958543871562A4D3F3746216F5F45296E6C845C364842279B5D3B89B1363F66
6C254F8A9C6059585F24469E8237402D4FA98943257D5A61BDC06D203568377191926C33
8DA33756888876275F4D255973673D8F314F9D9942B4B5674DA2A79C4F2D6B5ACB6E3B32
29291E22878233191B1A2F523115191523212A4E828DB590898299A2B7D6CFA7561D1A12
15151515172E92B8A81F12111218864894481515151966353033323873766B3819181F70
1C1A191B32305068767619182A432762B9B5433B4F53706D746C51445266766AAC717083
674058512E2A40221F1F2F8D664136292523201D2E6AA26A73291D1D1F4AC5D27F261C1D
302B1F4046794C222978524E423F5C1717162A39302D1F1F366D542177471E263854665D
69785E3C373640436A507AB3C8C8B56F3B9CC1AF99665D938B8C6D3C355D634E30555065
5A31534B4936174C5877682313151315131013161A794A3278D9AC4C5464636074728DB8
9FB06F3E2024204BCE8A7DA47B5F7F2E222F221F215DCC916A65ADA1807597C3C3B874A8
994A365CA6AD7B729D86816E613F50788C7B7173805A6C9A47676C75
7F5D9841635E3F76694C8F783145893B6D4A43634572492B64263D57673B5353212C574F
4E45154E7E3C493C1943312D153361464D45202365533F5468134A673A1F6624285B694E
4A977E1D2B5C2886893F2B4D31736758848B2967C092353B9443367FAB5C355E69372C5F
6C583D60354876456E3F746B31516132577D638C34887B3D515C2C325660476245496F46
571D4888606C392E4F5F4D4DAB1C55664589732736796A4B40594A31795A4FC24D5C9F57
4C5B4B63CABC5EB2BE773044657337537D4D368A9C7B887D39195676474B434784747B93
4A2C7961346F2F2C806F355C5647482187956A56919B8E351C453B3B8C3219659C474E77
642C3F6865707B698659247A78414E452D4B735227955A5A807A6B233E725451475C7344
AC95493C60577E3C8061395669634E9F673B776D3ECEC240253D3A554E277891A041352E
27241A1A36B1542914195C3B1E151C1D6D9AA28B7066483F2529419C4589C1718A711E15
1415172C3F7292ACAA5D161413156A225F8A282E3741916A3E25252880785A251A1B3F5D
1C27394A514C3B2E5D1F0E1515214747B4AB71937E394C5250484F63646258789092C594
80804C231A1C3C332F454D4C724B455C3B3333303E629CB5761926436A9EE0D27859351C
1C35894E365D914376CEB695538C4C161617192D2C3B3A1B2B68623FADB77452493C3647
4D83A986675D5E68718A7D94B9C0C6C49FA0AFACBFB9B4A14D1E1718245569827EC67F81
8F7D85767E4740514E71431513131415151515151D5A808193CC6B2F3A89D570494D6CB3
9467944C1B1D225BAE74814B2D3969764739393A4397BCA0938987C62F238A9C9431173B
4A291D216CD1BFA864422F2533495B6F745633676E77497C4B232B38
7D508841705056A53D2D6E6334544E32733C4C3326424A308D4C345F743A4B6C4134554F
757C1B4C8036726836254E552338753D6770373A51311C7D6726524F2449904C29507515
1A4048313153237C60422C52294D4E688D432A2A67503842B44C1741755233604F733295
6B483E576056653E8454866B3B4A7353565C65944A91793F4F724643614D466365655146
50324B8E5F7F3C75927F344B90457C6E33875D3A3E7546394154391C625246C55F346958
3B433E358E944195AE6649488091375989543C94A576868F502656944F5073387F737A9C
6470C4582968542C6D632F54574E4B1F5E504E599E9681492E333F3D6E483466942F4E71
5A364681686688A89966246B755B8E5E4F584C402B98608399735F1D4164715E5A647443
CCA84C467C764339887F468F72375FA15D45A461238EB58D4B95526956398C9FB4423832
25211C1B155EA14C182B682D1B354A7E9EB47F352174AE774B3F5B8A1921899B3B6D8335
242F4F65744C397A667258191312672948C4B27857373C606B653221AC6964221A194544
273A2E2E2A292C412815151515161B54A1719899BB8042251F1B1A1A1C253A8C767576B4
C06D1E1C18182C745047464D934E41472F323B414A8CAEAF948C83749AAA653F936A4F4B
211D863D2546B5B5A6ADCFCAC0D031151516151E3C32621F2A6E4F98D8A7C35D1B1A201F
3D7CA595727A746568899E87BEB997D5B8734735394FAB5417151517205F6AA5B2CAC188
9798946754747C47676E1D131313131517171515173E9E6B549B482B2E46A7735A4953A7
904E539E3D171C71AB85342E272244CC9F7C808EC8D6B95D21252C7D446D92716B191725
4E2D1E2139ACB3C298584F674B2F2254676161577D8C704873212726
A5619E437D643F55573F86464DAD9B366D455A8B424C31418647345E4F3D707D3C2F342A
50511A46743E413E2541464F1C3F7935343E4647512C224B5C275A5F2B266443305A6431
2F593F234E5522895D2A39623C675477943C2C317E523440BB52314F98523169566B3495
6340484772666B44874C87583A4B6F5E71535F935876653E495E424760404364616D4A44
4F39539E5F72518783853553A0497665296E6D46417A4D404F594E26766553D57A4B8858
41443E3FA09035688182544D99994166B87335999461A2CF6C32598D4E525D3B856775AE
725FC455337D643873593A637F69642C56445550AAA38D473C473E35685B3B6F932A61A1
7C3F46956A3D635E603B5D9E4E335F5F5C8B6F2E4FAF6E7DB185573A807166685C75602D
AE8D455B8B99762F544E29667A4953882153B37140B3C55F52CEBC9B1F206B76D6693C32
27271C1C1623AE862471645E7EA79D835F592115153A3A130F0E10522C153A8C6C2BAAC0
898C5F37251718245B3454621D14735C5C8F2C33426B726F5A4F535DB866521D171C732E
1D1D23241F253139151517151515181E604EA19654481F1C1D1A1B1C1B191E4530295592
79452E17171932321D1F2327816E3321272832432F34ABDAC0905EA67B2D1E2332927347
552445364C63414378B37BA6CABC611A1517151753585E393DA09E84726DAF781C19191F
2B808C5138617E43353B8F7AAC9BBAB2984947352D337668281915172833238AD7BD977A
8D878C9FB1B75E55946619141010131515151515183E525D5796392929458F3D3C40743C
2361414E812C1C8DA74E1F241D215594281F212B5BC8C350221E2357C3A5698D2716181E
50232222377D547F348B6921151A22313E506E646379926D7545323A
7B55783A725C496836369046274D76325C225469364C23348845336444315B64383B6E4C
7352206A7F515347344C49432652904F504931496C644B74592F857F3830633E60A77F5C
385C41135E6328895A1F548F447139438B6F43357C4E306FB0503453A22F326E837B3591
71314B717862735F7F4B9350587E7B5B745F54A16179624B77733E486B394F7C74675D64
7540517B3D8F5B8293822673933D5F4B2B849B4040783A3654674520705641C8674C694A
4A414F42A7883B66758B4F4EA44D2C477B84398E9859879954345F6E4762463D743D69AA
6D45C351358D703C77372844526B6E3041373D33959CA165474F371964733D709A283B64
581F4B757E7367784B302E6A693B561E275C7E51389B3047A6AC411E506D375483A78343
B36F2D335C678A3C62693D5C6D3B5B6F3C3670612BC6C639294E57833E256973A5B45E34
2D241D1B181870B09FC6C0B584523A291F1915151543150E0E0E0E294813102E913174CB
AF341715181C151733472C416C46B2B8AE91181514152349788163ABA6976F332755C866
34201F1D2126441C151515151515171D361F937E4836181F211C1715151516171A1F2946
69384F1D191C401C1D1D1B25318F5D2C262B28324786BDB99F88C658251D1E1D21377F87
4B6B5466995F4F85C7D3B297BD9C6E4F211715284554A79CA8D8774C644D286C4C1B191E
3677A87C6590B29184848EAFAECCB49890404A4B433559B2793B1A24371E1D436D292527
374578B2DBB07A8B87731B1411111110151113151548377176A42D24398A923532565C15
1721514C5CA56CD4C0411C231E47492E1E1D1C1E26807E6523222A767E6E833F1519161C
48222225356C47702655251517171B242F3E589E6C6483A49C9E7176
8662AD3C74684D7642266F513C733F235B344F29234243447E2235806E40726D1733566A
9C4211538C516740213C4E1912327035584F102448422E803F16556833325D1C325D644D
4E955F324D6326896E3E275F41654C5B7B4B3042955A263C6A403156A72720385F663FAC
8A3B3E585C66593875499C5E3146635189593F905B8C642D42664862886149614D7A5244
562D60914F6A3A62A686314A863F524E263E9055407B6F4486B75E206D564BB36F4F6C4F
524B534DB4884D7297B44C52A3883F51566146B4A17A8AAC3D529F893D332D4979596595
3A4CC653356E493B94643045564D4F25413D5E4A926A8B52495C4337544B409DA14E4D7D
53294A765D726F745D42336C5E3A58413A4873633FA75A47808E6021534C383E346D6C43
C99B433A66585E589E833E5F66307FA1483B883F1F95B87741904758212B708955829C50
2F231C1A1715606BB2C27D361C16171B1D181E181655100E0D0E0E1454150E136D983A9F
611715181824272322485E4A41976F54AD7D5B51392E211D2E5CCFD2D7CCC8C29EAD9C93
574D3A22222F3616161515151517173D351B8873482C1617171515161818151717242F3D
6F3B3F481D263F151A191D282577894D4843372F679BB4C2CCAFA12B1C1A1C1C1D1E328E
A86CCC999FA5874D3E67D1D233254E6045322B484585B6C6D8D78D745F702929833E1A23
677D79726D95A7644447ABC19FC2B55F644B4C4630201A496A2628453D1C1C623D151315
13161C418D966C9A7D812C13130E101314151515174D2C82AEC77F92ACC5C89A66812215
171B1D5795ACE7E7CE6226393A3953171C171A1D1F5C4D66322A3B903C7A5E1716191D1F
45202423335F2E7024451E1317191C262B364847315079A4ADBBA9AF
85508443794F6DAA6038952B375F81254F2B6B6125352A41793429624F37809935322F2B
6C611F67552458602E2958461D3C5C1C5C564547594E3A81612478552E467A4D427D501C
274E4F3163571D5A744B345B26775A75874C164370612A54A7463758A14231575A343A5D
865B5B572A7784486941A477404F34196C6A5375319F7F3E6A51304C6B655158196F7559
48145B8E5085423F55803955832F7C893741A3384A86673847534228653A38AF68608140
6C867554BF8F314C6B8B4A5B8F744165953C1F87826094AC2F236B8439592E3B6E4B6C9D
5A599E5E378326389F6C32475E523E297284705AA483B52D3055563E592C2E63824268AE
7135476D5A4C88C1684A35736950794B3849746057BF6E55A186602A74525B5840724F33
AF9E51518156553F4A66466D5945637A48397F733A93C8743C83565A30204080468762B8
802F1D1817167B5B67884720181D1C18162057282458110E0E0E0E10491F121032B25B7C
3A191C1B1514151516152A55739F8476481A2845657A7E8CACBAA6AACBBCACB7D9B72B39
73555E5859651C16151715181515195F2418808F48281717161515171B1B1A1715253236
65442C4D4031431516192A252049231921436EB4C3C1BFCA756D844E1D1C171A1C1D2040
A0D8B3CBC2823B37579FDE9B3E1B161A1C509A87BAC6BDC39D829F8D90AD893A3C695554
8A7262262E4E642D1D225A6C4079A394746925221D221A27734F46542B1F237233151517
151515194D733D6283A16416131313111512141529423296CEE2E7DB9EA0B4B2B7841715
171B191665B2E4D9D188413C46433F1515151515184630585A334B743D6B1F151B1C171C
421D21263659296326402816171C1E282E3A431D17215090A5BDA5BD
9E5AA645814A42824D3BB16C334F8D2A4B1D4D70395238419459305E32244F6F333A5744
66532562683E5142282A544C1D3F66293B3D2B3C4B1A1791561F7A341B41654548895743
3766381D676B2970622F3E712E4C46796B4425334E4F2264AB2A347C8C452F6163634282
85536E7A4C5966556C347A755764615F7B5552935977694E978052506B676C8E72716C84
7F3A428F5E8F586B7E793382982A554D2863A9563E6C533C6E8D461C64613DA1355D8852
5E525462D3944E536A752644904B316BA27435817D5B58723F2462843E6052307D494D81
595C9E38428852367A42447F8E704022524E6B57BD95AB3F3D5565476D6B4C678E254069
7D3949657258669B523B3274494E835F2D4F5A3F79C582619A76343C8D6E744F50AC7D48
AEA82056A09F6D5B533C45B98C49737749408C6B3BAAC76F3A6B596D41253A7F77BACACE
B9582119172EB078689B3617302621131532722A4154110F100E100E39381310157BAE72
3219171515151716150E10131B517F853715111219252B35385B99AF9FB4BFA481C25A24
2D67584749651F1515151516161750882C1C6BC56A451C1917171B1516171A1C1B2C2E34
5C5F333B538D4B151722211D1D3F171515162AD181579D89ABB9497D2F1C191A1A1C1F25
82ABD1D1CB8A95B8986C4E8C6447291C346CB9D6CBAE98A75C5B667F97898374627E78C2
9488251C1F3852261C1F723A324F718686682B1D262B372E779892623625277D21151515
1515181719433061A59FA5695D15141113151315442E337BB19197969389B3503751591A
1C1C191942BCD790463C528060771E1415151515153E3054653D754C612015171B19181B
4A2B21243751245B2C3B3117171C1F27343E2D1B191C223C7EA9C9B7
AE5AAC499B6950845A45AF6E37539033733D67853A4F2A1F79522B587133556C335A7749
64382F786E394D37363A56252A73743A4C321549744C27663B29A44D293A693467956238
4062341568632B856E1E4A7337773278793F2842583E3993A0403A44912F3C62675A4383
8A454B61476F604A65429C564658666289683D8A70995B386774505B6D52436955754F5E
5930575D4374506F8F691F4A8A3E834C253D804263A05C2F77986C216343457E584B5A44
8B825C4AC17F314F78593D66BA8C3C6C93603B928F665D8758276F553A774B3F7A7D5B91
585176323D7C4F387F38284A4D64482862583F44A1919553585E4224797E4475934D4C71
8C424E736E6981AC61422D7C734E61531D44675F7EC6635FAC9659235F4B2D2F3E8C5F3A
B2B25F3964775A644F57345A6C3E6D711A6AC25D3F86C3494A88948440263368D0D8E7E5
D3C4703432A5CAC5D0CC8C4F41423E2B1B1415156E4F0E0D0E101113517D1F112558BE9C
2615141515131515120E11101C4B845E62301410131413151523756E8D97C1A04E569A43
352F4F5F2A262C171515171929566A676275BDCCB0A97C70371E19191C1B1E1C1F386D41
597847405AA25B1617211F1E2D5C151517162490489AA1454BCE9866AF76634337322F5C
8A75CBD5DEC27930191515195A66547B7FAA9DDF847F89566673656D6D7781896C99A0A5
CD811B1D2028381F1D27AB372C305D5353652E3D4C79524D92B98A7D746779941D151515
1415191E193F276F605F5C4D4E5A38191311151D4737698B4A1717162875BD4C2A335060
2B191B1E54D2B349312349547C94371715111215153B2536615981582E15151B1915151A
483523273E582A5C2F3930171B1C27353E371C1C1A1B1C2142859BCF
7A618643794E55833137875E344C3A4B84335D5B3E6A612B7A454E7C702F516720415743
6A5B1E5C5D39723D44314F361648612B534019386661317D301F80592F4F72473D675A33
5E794028674420826F3A34572C6E46736E3227638D4E296C943453739B462A5040475A92
905A5A622C837B614C34856E4F5B363C806B4D663F786447864B3B52726155592B716164
4D1D5B7C4461344774782F4F6F306F532C4E772A3B704E356352342D78533C83496F7935
57433E67D0723B3A6D583273A483396EA56A2D99764C65933E3A847A345524697C6E6295
3F4797525089575CAF653E564959323B94765353B87C75366F7F372D87664A8588554F5A
703366A16B6088B0483257AE82506735235C604D82C9466DAF984B25643C53463B853E39
C9C6794D7D7864875B6C466670476E614035726B4775C027244162844A2A3567A4D4E6EA
EAE7DCC8C3E2D8CCC4AE46557B706D5B503C1C15926D1814162035678EB48C5C7F48B4CA
1E14151515151515130E1112434E5B283F5F321515111315152F1E48CDB79E9565575A74
1F151724584E272C2636454E3A1E1A8BD1B0BCB4A3895E6479643F414A484E4F3A285970
76C4B391989D9E4A202B3A499D8D3940464F8CADBADCD3C0CFD5C2BEC080658B885A7399
75BF8E77DB491717151515151F5A8FD1DEB2C5D15B6155444636211C1B1F2F5DAAB9D1CC
CFB66953586563684B45B56D28312C4F3B6A4D338A58354E8594CFB3AAABB4A42D151515
15191C201F61476142814828292C3F52401515304691AE7035131313289AC56B34363840
7B60292799B198512F385C377437554E41251518153925285073A95118151516191B181C
555631244075395D3A382D151B23343A42251C191C1B1D20396DA0D1
9C5894437C414C7C49418A464B7F7F365A335D421C3D2F40602C28423538627A38553E32
78612C764722474C4324573F1D444C1D5055393D563C359A4D21963E244C6B4F3D574C1D
2A57482A5E52368785483767296958A46F472C47525F25728C263E63823F2C54463F4870
9460586B3F7669547956866D4F516F5C7B5D5196759764427C7551487464506A5E815B66
623D6E8E537138668B691F5B6B36843F2753792E3E6F3C3566502A1D685034454E555F3C
71615D69D35C413B7B613D61A28F4171B58A35B77F507C8C35248F8A37512A35565A827E
4D4C6D41537E463E855D41554A604E2C5068675BC58B76324B582A257B2D3F73884E4F52
62294E69695AA5CC592F38967A4B614F2A3C4B4781C96764A1935522605168454E974638
8CA871589F72287967694E7F5B317D8E3C3C86815781A84630545E893E2E417DC0B8C8E2
E9E6CB8FA8DBD75DA1B6AA584045536B908E807CC8BB80766C675230203A5E5B9D6FB9CF
575D4A342D211C19141317364B4229191935672B1514131523281A28AC8C715B86452C4D
511715151938877C7F65301B1615289660A8B1BCA9A2937B594B4A3C2E191D293F474879
77A5837E99A5C1D1857D8D84CEC287767373A6BFCFDDA67380B5A9492319224C53618181
C2C6854CC6271715151515151A1D77E1DFE7B7C778492A1E1C23351E1D1B191E529CC791
7454493D39344336201F58BD4927253D5590A4AD51474D686789B25C5642337C66191515
271F1A1D43798A6047637F37212A2E304767384A8DC881551D1D15142F96E3CFC4B38141
3D6B9A9AC4AAC5B0BBCFD3A99E15151B395E5E5E3D3A683E89AF6B4637161615171A1F28
82A86E445A93386E463B3E21233340422A1B1C1C1C1A2344769FAFD1
AA609B43995E578D4A41A058314E7D3F64276172293B39307E563C485128465526515838
5D5E3364703553463B4A8B3F1C416B39443A2438605B2F9D37258B622F48774B38665E32
4667461F6A63338C7E4A3973396C44877340294E57622B8A943D4A51AC4D28574F55547C
995C757E41785E5D8261765854575C597F4651927C9E564F6E694F4D7565577459804D6B
5D36758C686E4376886522697838833E397796473C665D49685E3D20704F3953586A7149
81626D81D95757379A8E3A4CAA774884B07436BF51327783382BB490437C393D5A475D7A
4E607220597A4A417D503C524B715C3C5A5C5870C4B5915A8682472B986C458BAA574A69
84365E7F53457BA84D2545934950814623493F2F66C5506CB17144348759694560834D37
8AB25461AD7B386C41254D7F7039716B345FA55B2F848533356868702C354C6473D4D2E9
E6B4AC618AD1D5B4407CBE9352423B454F6FCBCB8D2319141517171F2123312E677AD5DA
908E898A8A70675E5C658C87595C1A1717192C5F2915131B2A191D33907C41212C455833
4A4B1B1C3346766838251515152570583071B9C0B686757A893F3C3A47524A37241F1D7E
B5945F9F989678968FA8ACC0CA5C5552555D76C2A0C4A44860C0D23A161515171A235B5B
A1BF9059A4271817171816191B1C51C6C8DD979E3A22251D161A1D291F1D1C1C2E4C92BA
AA8D291C272C3C1B1619207FB0462C2B678A9E845E4532281B2D5A544144413390491D14
211D1C315A4348367584B2763729263A50458FB5C6A35D2A1C1F15246DC4D6E4EAE7E59B
805F93DAC3D96E7373ABCAC5B71D141515141B325479A6B1B57233414C1717171B1A365D
8397A0A0B7BE63807252624B404F5B301D1D1C3C30486C7454607F98
B8659942985D5E82494AAB67416D8B417A347F7D29475E39915B374D7149615C25536445
595331636636503F3B4C9A3D193A6B334C351D34657D379B36257E552F4A7142336B5B32
4E61271768693489653D6C6C416933987A3B22505448258A913C555CB04133636B5D5B87
90536B7E3E8756736D547446645D4949773B3F6F839F4D3F75764A516D466478588B4885
65357E73688E586E886A2C897E378851385E6246396E5F3F8991591D796F505562777148
80748589D45A5358A88D4458936A346A9D793DC25646838F4934BA663F6D2A4970616C97
508188237A8E5048863A416D708B425488743C498B63713399AB454BAC75589E9A385587
5827616C815970A032166AA26034623C276841225DB1396BC27F361F5D4368467E8F4F3A
80AB3E5492633684484E4351743B82771855A6915589983C368692803630295644B8D7E4
DD5B647CC5CFD0C8965E95C0713B4D5B595F85C2A93C1714171B1A161A1F35414AB6D091
A99C758CAE74807360666D7BC8511816171517376A31233D201F38557D963B2317152C6B
5D7F70422317153D4D3C6956554C69468AAD9CA3A07D5D4A515E483F312A2E374951735F
D4784568ADBBBF799ECF95C9B9534A3C38312DAF6782B07198B4AF6F1615191B191D327B
7EABA5859F44251F1D191C1E1E5487A8BBB57982201E221E181B1A192A241A1C274199A1
61BD57181D293C1B1A1B1D346A9A52374C726F9737161315161C275823434B407CA96934
281923627C402E1E266DCA8165747872869ACDCADEAE631B1B25437868494FB2DBEAEAE4
CEC4D0C3D0ACBA60438FC25F74521615151415151A66447BA2741F3851301B1F2F4D5648
4A69BD9297C6A3A5AA88A99F848B4D28232A286175622F264C71987B
C06987458C576074324591553E787F3F7F2F7F7722534B3B905039495B456B5429755F41
504447896A3652383545822F1F486035592F15356E75318E253A8D562E4E614252875A2F
597238255D5B3997723E5761468134887032225B585D1F8B86316A94AC38234F573B71A4
9C7B648136A275705057A2644E5C322F7552484344916E356945456995624F512696655E
4C36987B506D266AAA7E266A523A9A683B835E2B3D7B603D574D441D743753565D7B5E29
6B676B64CF4C38739F863C4A908E406DA85034C97F458C8F1D35A97542762E7096657FA0
3F6C98475F65286CA95539494A6B2D5281815C68A6816E2670762F317A2E67B1A14F3E77
5F284E4B876374A67E2F4E9162326E321D5557314FAE1E3E8186471D5C54462E89A27846
92B27373A98149AD8C4E435676427C85303E7A8A5483B4212D51697E3B373168438E7AB2
D09EBBCDB473B7C3B7775E8DB25019141315257F873C4535241A1716152B331856D3AD81
772818212F3339373330302E77874E20171615193E9A5C31283A58858E663F3B23151525
774F5B15111311153A686D2B2C468453747A9EA27972484955676562513A2F2928307870
DC822F3962CBD4A6939EAD9277856F402F212EA8645B63C58D758D95361B1B1E2940549D
8782455E8C4460573A3B3720215CA0ADA29475771D1D1B18171915152030201C284EA468
35A8A1211D2C32231D1B16192B74A292AEBE4E5B21121115151928A0664C59667DB39268
7E75869C3A2F313E2D4A8B66534246485DACC9DCE4C8641D33725D241218253AABDFE2C8
8A5CA8C2AD283795705A9848477B3F17181F364D56739F959D771944578D59655B3F3C31
2C3F5661ABBA87A698A9B8BDCEAC34384B5F59462721274B67896E88
AC78864161395B843F4B79334F9356608D2E7371216849498B4A305155426B3B275D374E
7C2F31753B376E2F452F802529684B327449194D69612B8839358937357466342E564A1E
52634836714A336E6C36684448654B93883D2F6C635F1F8F561C566C963C24545446767D
84876F6A317657655A589A554D677547744A4D947594723B54573F5876645869538D595C
6234778C5D6833758F67217C4E317C5256AA5C1B58784E3A6952241D924B5344597B4D2A
6C535C56B14653949F864174B5843760A74D30A750429C884A3BAE817E8B2C365948AD77
637E734177873B528556364951694590C08B5E9DBFB1653670742E3E80313E587A4D4195
4F26505051379ACE7528639A6D4371874561592F5CB16665775C3B1D604D353B767B7243
C5D16276B0692285814F474E443997A537497778549C96472B4E606F354C676C5F7A79BC
DDC69C80A4455DBBA84A50628BA73E120E1013496E451D253333323A332A2F49B9CCB9A1
353A1816161717130E0E111323637758201B151C517595696471B7B67129192739201714
372534151313173B757F673B43B0AC9595A84930374B8EB0A182735850574C3E3136C3C1
D6AB3C489DADC39EC5D9666364534C5A696B77D0783F3C916E6E77868E4D355D5E45215B
767A3D3C8115172B5E60589688904CB984735076191A1617161516171725331D3B74A95E
2E7ACE4A45561E15171D1F1F2539B79B9AC0874B151315151519345334636C85A7ADBB73
9191D07C25482E444271412919202C3E5C91BBC5CDAAAA677440281914151A2741BCA848
45519E999160625B8B783C56404FA56F7472573B2E387BBAD6A42F4DABB5854D32221C1F
1F2D6670395EC7BBAEC35F6D94A2766F5A402825242440687360734D
88728544774A607D3A54A2582F5D5D3A5631643C39763C4B5E45436148447D6521533040
5E452E7A4330472A2C2D6335174F50223C3D2C3F403139853638711F29505F2F2D565C36
736C402373604E896E2F6E5065634C9491313461554F298E6333766480342A57513E6467
7F8683703B76475E616A873F48685C4C632A5685828256394B4F4B667D5B577057734E64
623F828761683CAA974847A9792E66295093633741636B4369631E27934A66596A916138
7663683D8B4B41A28C704083B4803C71BA8039BE5247B6944F42BA5C507227306C415970
609580227076505A815D6393A6904D765F606E9AD5AE563F74642B728846485E89334BB7
6234514D59516B8D622151802B619270424C393088924A6085633620755D894C805E382A
A6B13770C29F3A8E54546570602C7B882A55823A1F8A8F532D546D431F62675448784C8B
C38069642F1B20BAD7864436409AB13F211C233F7599808078747278867F8CC3DAB2B766
2E2F4420283726131717131515433C6B663236635460AAA7A7B5C3C4611B15172138281A
322131101938523E2D23A087607AA296BBB2221C3321428A363D51617C787EB7BCC0CAB4
5E93BCA9D3A5C2C5B79D2325344B4D4640354785BDB2515B844D51677EB395391F191635
6F6A3E407515151516265BD6AF2D2F795E665CA82D1A1C1615161715191C5F5784BA9D8C
6A81D7BAA29F741D1517393D5492B155396B887619111515181D4A1C15177B9CABB7D9C4
C3D5DD8B867B2E44525A27171015181F2939659BA49DA67A281D1E20151515172B7A6855
4C559382711714151975958D91BFCDA96F8E677D7DB1816793CEB46F84815D2C221C1D1F
3F6138282C6B7FBABFB966475A6D8C483E3C373D4C39797C5E714E4D
B5748D4DA853687C446EB565376B6942682A6D5B21523D6C783F29462D37596028685544
543D5EA562334D323041633E1C59543E452F1B4B6953376F294073332D5B512D36624634
66622D1A605C3C9B4B288350645549AE853D27544E5538AC7C3772627F2C4F7D7B504C58
7757CB863A7749856E636A3571795A486B206D7F728A54606D654C697C5E928F4F6950B0
6D377E5D81905FA8964F217D73316D533B7C664A42684E4396A63B1B865B69694CA8693E
7A664F5DA4584DA4AD4F35589D5A5991A56337C37A4B9A8F3257B17C536B2427603E6C73
457B7E276E5F3F5D774B4545396741615D526379A390573D825D247E794E4A5B9C393D9E
5831647A825384B13D1E779A5C3B6947426C342D9181456CA96F2033885968418E7C492E
84A83178C592379B5730557676377A6F215582874574A53638748A792C3B465C5B584148
90856440374E8CBFDDD1AD60334DA6BEC8B9A99BA6AF5F4B434039352E313167B8AA4744
553042792F1A1A1B29343226171D503A6C91A876749D986C554B9ABA4F2216181A243824
3C414236583B201716405A9B604D977F757F331A332526561C1E1D2F4AD1B08F737FB572
343579DD8551C5C95F901A1717191B352525333E648CBBBF7A4327395E9B23161C191A24
5E585F3F6115151516151583661D1F695D79B4A5B396703C2B1C19151C243E25499A8353
54B48D39768EA68A6A231E50A5723F824385706C601A1115183B2B15141549506ECCD8BF
A4CFD0B5707A4B5377331D1515161818171A23789FD2844B1A1B1E21191416151D72A445
3D896C66531513131335D2C5B5B8B67C6E5B42301F2F2763B190CA91A5B3552922223854
51363C588A97A5DBAC7C9EABB2C2C0A16D6464779FAF85637B52531C
B17A55507F476D602D58804C3B583D7393397B593B72366B714D5986613A482E387B5343
47212766472D541F423E561C2F6456333D2F1269684338541668753C286238345F7F5439
7768131E61573F9A4D1B66455D5C2E608852285C48223C996C335C678C31214053485F70
6F5CBC5F368A4E62615F8538406B5C5362405D7D6F8442285652445B7245566E49775458
642D73726E7D50A5AF72338E6946A1633C986A45506C945455524C24702D7A795A6D5B4F
A4873F40B87170C69E8C4785A569375CA43E319A5854B882473B8459626435797B477E6D
4F897C2B77703D7D8D3D2B394C4525676F726D8497A34D2B807E3B7C822F61989B524487
63284442745199BB7224598E603E7757334050257A8D29537467351B535639248D906D4B
BFB6477ABB9339A8525B4C5275316D73274E70825278983D223E5B7F33444E6B78453D45
5FD0B1AAC384453A57AAB89E953773B27E4A43678AB44135302B272B1F151F5F9E741B17
375558631E1C3A503A282534493A5F487DB0C4B9A49985766C6A70844D31181916171E4D
61585B461D1817153B5037846A58836C504161202D3021531C1C1C359C8A5A503E2D9660
2E3558D049B5DCBA5877161817171819171718192A414E836D2D2B41766A1B171B17171B
503D553E621515151515156435191D6F7BB57A5D2F3C566D7A7578747C674B4F7EAE9858
88A74C4A451E2959A5987E9F5D4D6587788FA0A2949C40263A3F12130F15322A32B9C6AC
8EB8BEA6C3B3A5985B1D1D1013151615151721408EB5BC691C1E242C311D191A28607E3E
5F60456743121215176A8E75595879291514131515364F7D3F4E5C866A8077887B45678A
838A85827C88A4D7B14052829BA3AAA389808C9DCAA68FA27B431919
9C9A764D7B3E728C40618A50436C3D3362294818336E307825313E53413E4B342C554561
773F35893A4D725152364A351E4D4F365639226C431C54602957691248816730294A4238
7771451A6F31388D693884495F5A5B8D8D293C866A462D9B4E388BAD80302B4553386E62
685CC752319358683964904E426744495537615057896537573C6AA1915E65503D8F6E61
3B3B847A72631B698E59379245378054388153277A928149565A49479D4C666C5EB26735
544F5874B44D30AB8951447DAA764986B27538A36252BB6E424DAD636E67233A57409E76
368D7C397B6E2B58723D3E4D55692B544F57538DB2B34C375576357C7248495691505497
50254D3E67497E826922547C465C9B7049415B297F995C737C643720637F8E2A8F6E4343
9A8B4881A4833AC28B4C54455D2281792652624A497E7639293F59612763615C7C403946
8F746583592D1F1C1C2564A9A18BC468363D4737525B1C1C1F232B37331C398F77231F14
474C5B453D7D622A222320272D59846FB1C4C5BBC178535F26191834684820171519184C
717F795C45321D465B3F385B1C15483866404F4B2134236F455186985C3E3C5A9C6DA28A
47408FCF87A9BDB65F70171915171A1A19181517182F434B852A3649953A171818191F53
AF7860506F15151519151567281B24A3936B6E75291D1D1F253149505A769FA0C99C83A0
B648273C6E27181A3571D251272F53A4DCA6AEB3A2ABB4998C230E110E16322841858C53
8F89BE6E91B8D3BE391A1B1715161715161822326DA3D6C2676D8691A378655B63A3BFB8
AE453E7039151515396A265A73407412131513151E675A41153F57998A5F29316EBB6D2B
1B17151A2B7A52DADDD0BE984B3A7F9A5F627085C0BCCDD181231B1A
788A735199485D83508C792D4C7D544B55579D5A3B7A39825D283D45304E765235441C38
6832377C2827513E421C5341274C31223F4C39714B32593E1B70641D1F5650272F4C2A2B
52582D1F65464B76432C7D3A3D4B5CA46A1D2250533B35993B24426D5522354C583B7C45
5655BB4B2F7F43715C6088464584686C5738687A6E71513750374C799067656148825B5D
563B75746C4A399D994141AA6136744C3D95532E475A573C564F272789477354506F5149
A050354BA4552EA26674497EA55E3C74A27B3F946151B35D365EAD6F6772284A4B46BC6B
4F8C632982793D697D334E676C793C6658465562687B4239687B3894714E596180334A7F
3F2657477B59868D6B236383513E68585A4345368E895052874A242E818A8C27926E6440
96822792B76432AB944B6F5942267D772758663D5AAB593C2F49595518493F3F5C3D428B
9C3E696338271E1B19181C2C79B1A89C4D303754838744312E231F1C1A205DA8301B2214
1B1C2D73BA8040342A23292F313CC08C8871B9809E4B412A151515196E61462319243D58
544B49474D58846D34294F60292E6E4648583A57272D1E78B98C5C442A201C1D308A96B0
B77E6A73704572C77167181916161719181A16161519453AA63240509B251C1B22476A61
5CA3BED090181515151517631E285CB77E4B56A3AE3F372F4C8088A2A6A6A4958BB74CB7
9B191722374919191F31B1371D3958ACAB7997A493B0C5D7963F3A35365346255C573B1B
4623798C53889BBC6B321D1E1917151716171B2E598DC9E6C6A19A9ED0D8C8AB8CC6E0D7
AD96437E3315152B64241C4B9E577A1314151516428161191B35665DB071366B70564615
1415151D7C46AFD7DBA7819097444B975D87A8B4C8ADC0C26F191A1A
AE8D6C56AE4D6A694F80AC58406F4B6F61327C4C444F2C7C61313B4827375B3D366A6557
5D2846923D394A3539366238264258344B523F606F446941207A702E2A5C502E3A54504C
5F56221C664F4C764C2879454F43479470372854513339974C293684541A263B644A8048
5B4598472F703A7C66627C455B7A5B755425646E787E58475C485CA79A6B757A4B7F5E6D
5F4D7E66846D539F95423A9B5E438434439E532F405456405F62253293307B62637B3F4A
BE5C5A76A74037A984844891AF7A4390A44241B68B68CB8D166EA46A7B67316047399B76
599B652FA3824078792A48555C894C67596368837574483B6869246B5842828390495078
393363576F4C7D7C3A1F7896554871405E513D36896D3C6DB76C252955393040BA9E8559
C09C177CB675359961116A9574287D3B226FA55F63754820416687831D61432B474552A9
774DAF993C271E1C171A171B1B549AB9BA9897A9A9B6A2864D2C21212E7DBC5F1E16251D
15161D5D8A725F7452483D332F4D94907693C79C923C3521171516172F8B5776576A6570
96533B1E1A444A4648556033312F4D67334C49464A25324F261F21211B1C181A1A397EAC
6329263F633F58AB836F171515151916171515171615344B88907B81914437706642322F
2E7393CB895125161517366B3A83C6B59E534490DDD1C19D8C6B76B3734D34231F64BFC4
B32C171B244D30171C208A583F607EB8639792887B5B72BFA0353131355F702F69581B1A
2744699A464A728E7E442B1D1C1A161516152B40735785D57D5B8ED2B946383237778470
92A5A4A330153D571D1A1C329B6F79151515151E68821F151B3C2D549AC39C6C1E1D6919
1517184681B2A56FD7C67E5781BC786020283758A4D6A1815F21191A
B194685BAF4E6A695683B6584A6F49476A449B544376377466362F723F3A5C353A757054
7E2F3076403E533546335F3825455D4547563D5E7B4B8451288B71342A644E314A67544C
57633C267C593E6E532B704A54445B7F6F3F2C575F2E52A15F2D33856526333F72438A66
72557B5B3C71365B6A668C4750795E704E31617E7D7E493E5D4E60967C638661437C5071
4D5A815E704F42B19E463EAB5555A74E3AA16048476B593D5D5A2F34923A75736B7B4F49
785F727DB75A2D9D8D3F3687B67949AAC6443AAB3058A48F3F3D8246A47941A58550B774
457D693796642B86833F525E5E7B2F6F8A746F8E708C452F8A82386C5613698F8F3E5B81
262A626B564B9D97291D77854947631958655E3A845B13467E68302A6346301E7E7F3264
DABF3692C37B319B623C4F586A2673601E4F8A636C595C261C275571225F4560496096A6
7EA4ADB0915B2A211C1A1717151E4C42A85F221B3A4A3A586C707479B2B9B4511C1C233E
17191F4D4F506A33251D1C1F52526C7C87635E75723D373E463F1E162C999E8968925D84
7983715869593E3A3C515C3D261718294C2D6E5C5257633D1B1D1C1C1C1619181C367785
2D1C1C2A5B34548B8F732919151819171916151615162D6566CD99686EAB8E3A2D2C282D
3980D68E1B26565C425A928D8FC0BB5C4D8C3DA3C385653A2E2B4B4C2B1E1C1D1E6BC659
4C984E18202D4B24384177974F6483AA57A7A92D32484E769F742E252F4387818D40161A
2933267A773E447293563E2F2024222C1A19346673475DC5983F33352F1C1517215E794E
9391CEC748414E1E161B1D2CA198A51F171C21459E5313171E451E766CB9A425181A4D3F
1515175AA0925B968D3A6B9CA9A0C8AD405D9BBA98BE568B6C391D1F
A6986379A14B748D608CBB534C704A4B7A3F77345D813B7C66525A7847485A3D2E5B5476
8B333A81285768303525652E326A4E41484F3064763B87411D766A2D2C6A6B233458494D
6D743E26763B5E8958315A3A575E82A0703F3B70633D3798472D5692631F353D52228280
723E8A4D36914B764E709B4F5C5A40656D4C6A223F8B6539501B638F816F703827945E5E
135D9E689A6131758F6342BE384EA35343AA462E7F896C3A534C2039903C775870B96754
9C534775B7773BA09F3D3186AA6C6BBDC37247A86F58B07A434998349094273B4B43B64F
224C5E41C47C22666F4A9B9F9B8F214C69745F938F8C40244B723A6A6B455756683583C2
872D435B28139BC56B21657A4546664950414D4089452C5B78513068B59D7824897D614E
9A9442A3D18E33B36D486C5B601F8C7B2555845A825E573223335A72225D427392B3B79C
8B5D8F4F888C6B3A1E1B161515164F1D5C381010262B1810111936A8782A3A79311E2531
2A191B39433022131515151742716B57321E237E52242615182C5A6C5964777E9B635738
545F514F9087747A61252537534423182742438F8BA65642211F1C1D1B1B1C1C1C477F69
1E1C1D275D5B364B9B6E523A161515151516141815172F666F93DBB999835A453C406EA3
B6B4D04E3734366D93805B50495E9F3D285498AA3B242625324A441F191A1D2131AAAB62
1B47A84122294F7E384554C173837280618F975219183752B6996B4B3C448CBC9D351A1B
371D1B439F6451568995584A47312F54304183A365387E9B511815181717131A21597C5C
9FA97198C881191B191D1E5DB9A6B8272A2658909020171C25481E6D3281752F171A238D
191833A5854760A325171B214B9BB9C3D6BD5E282183B0A6BBB68B92
86AB6484593774836D964D35678B3E5E3C498941514F2E9142414D2A2240623C333E2546
6A32739A233246303212582E236516274B5728422D1F9C50247E441055845F1D38531427
475435478A223A5F4D25592C6E5B8C9887152D667A494B98311A205D4A1A3943622D6843
5F3D79442C7B455D3B54824A6C50364B684A6F3D365F52425B3C415C6F76775E3A6B5966
4250795F9276487F943A7ECE7748813265C34C26415648365D5619388A39763B437E7B5C
9D471B3C7D5D25A18C7F3B96842046A9A5794994725BB05F3A5BAD6B82752A634077CE62
86A04534797F3976512F3D51BDAC4C64557F3E9CD8BE5B536458358D5546628B4014529B
612B45495E3D758C672A73642E8AB76D6A46534AA15142686F491742638F74238892856A
D3B03FABCE8A4CDAB64666596127A77D235483629A684C31282A5155187A6E7BDDD5B580
64745E6E4E61835D4D321D1B191743293357110E2F472113121417873C2427956E4D3C33
4A272A3F4E302014131417315B3F5A2B19191A5D8628281B1C293F91B3896B67B34E351E
3847342646494C61541815151F3A4C463330457EC695844C2320202425201C1D1E618276
1F20222538704156B87D594B381D17151515151515193CA07BABD88651544F79BC986033
1F27A0B17866506ACE5937453779C16E6162CBA05E717B646D6D62645B5E5847988AAA8F
251F54A03940634A517182BD823A6D2D19345A573535384BAF9A873C405EA2C6A7572C21
26181E34574666545F9D7B3846524136668689695D3D9D6B571515171515141A1D409189
7B7A504EAC6C181B191D396761BBC34935374F9F5B2C2E5F875627601F439B621B1A1E73
5335A690475FB746171B1B212946392D697F181722BBD1B4C69C7A6D
768C588C7C4164797087783C436B3E6C4F3C763A5650246C583C496C333A4E2A55885250
501A447F40454F204A2B5B404C7E3645414725533F2280391F83480E275B473E778B464F
633616277A4564713C1B4432422F8E99562126416746488C5E2F2887432A5C5E673B7646
4D4574523E7847896B69716EAC886A7A7D4A8C785D66436F6D58537D6A7BA473496F6881
5168603DBBBB5F8C8C2849B2665384214CB998524760395AB09740428B3D927E6692635B
9D58418A8F3B45B493893BA28C5257C2948641787461B1473759AF75A273275E4C3F8594
8F974A388B60347965382916827E39875660367F878E704254451A80855461A575375E98
4232514F614CB2955C34957327355E3F60443F7EAF854B616F69213268855C4093947455
D7AA38C9D874229EAC4B6A583D3DC49726519860B9C269342326572926939582BABC644F
41392A3D7F585F6F51513E3029337A522860271E487F5E613C2E38A2573564B6C4B2A79D
7B524E597874532D1A183B5B31502E19171A1B39CF62434B637A7F5436659A7E70291615
224F2F21174B343F4824151515191D1E4B6363B26492848F50211A1D20211D1C306A8386
2F252C28266F8EAFCAA62F344C422013151515171920688F7BA7E2BEB1B7D4DD81291715
27468B2A263D638DC2B2766D6EC8D09F95B5D19477553A2F253E291A17172340BA4266D8
8A2A1C51A6808A69372A277E67356A191921353351603D3E828AC1814C61B8CAB97D6438
1B1C1D2F631A1D5964709F70394B69ADB79F6A756669B8576B1715171515141723589090
383D6C4B85971B1C1F393D5272C0AC5B6360ABCF51252D438E69433C1A237F9A7A5C53A3
BCC2815F71C8D121181C1D1E21662215175242217F956DAEB9C07674
A5B25BBC9E4B70647AA1B44C4C482D9076506D2C8A933D945B4D6990393954153B62544D
8A3343A03F3F47364729471C357C3C52443A2F69673999221F9172273971273246532F60
7E4B293475365E742A256A3C56347E984024323D4E33499B6432298F351E3F5D853D6548
3532965B3E602A9961615E355F715E706C2B7E6747793144745C52723A41AB8F44615786
49676729808C5F969D4D56C06769A54D3DB175465E6648375570514C6C2862955B8F3B33
947D5A8DA121407F84703A9D9C7469C7A28E5C928D63B0634D6BAC729A59295B5545A15C
7F955F43BB813C7C70322A17536A309D645F67998F6C48419167377E5D4998C27E3F5B81
2F3C676B7052BA9221219481393D5F30795E3D378E483089C08B31306633182160724735
D3A1368FBF6224855E36A4853617816F2653A4467F8B5231232E6A4B1757613087A55A35
2626272C423C3B7B816C6B68704E366A665F774E3E504740373458709CA2CA8252475F7C
9E8B8D8577898A5951776E334B30191725191A8EA1B6D2B6833C1B1D1D333C54322D1413
17543221152141484E391A15181A1A1C1F4AC48667689299573F3432271F1D1F675A788C
3B3333304081969BC38C85512130433A2E1F23325066717C5F95CC959881879D7D3E483D
4A5A3416151517206466338D3864A9453B459E361E16151528321110131113136E404DB2
8C9668217C9556291B1D175E92835C1515151F312E2115163687B9C97E699A6D8EB9AD92
25191C214716181D567B8BB89577829EBDB78D8D96C1A95493231717191C19274BA1BF5B
771F664D83C8605357727E95B0C6C991513739538C4027305A5F79231D237CD4C0ADB28A
9AB686BFCCA1A1551B171B203A861B15151E66928B3A64C9CFCBDBCD
99B75482864A724943779C494A6C387C715B7A2A507046A73A8F977C2F2E623631696D4E
822F4AA04039483E53276635337B404E532848817B3BB01231967B284575533144653E67
945E333376416F8F552350404E3C8ACD4B313E3A472584B063405884491B3846594C9378
54426129646041734D89774E6F61648F874C7E5D436B485C5D396E946C6D9D3148695356
34886F5E7A59439C9B455E9B369096413FC43F2C7D7E55344E592D6F8F3E5C5A68A6393C
674D4D99A5373391827245B8AF7266BDA83C63A38C59B23C18709E538F514FA0524DB148
618B413CB9793D7F7C3E342854602FACAC8C69988A905A2D53603B7A3B1F49616D405A7A
53263A657650BB8D5726658145425B1C415362499F5D20526A7E2C356778432774774940
A7D864C1D5712BB0792C747D5F239F2D1D71B36386A640132C4C7C531A657F6891B87D31
25252326254150504C4F55503E3D3D477C7E9057635E323249673A2A3CAFD17A7B6D655D
262129548F8D7D7E8BB58A774D463C36222E7A5C154783422A1B1C1D22272D5D353F1D15
154D372615154F535D4828181A181C1D26337E96565644A1C38373716C627A72B357ACB3
51454A575A6B9191C56E5D796C35265E987758709A725373A7AB9438313F494C5F764B79
8E891A1514151517374582CA5423A2573C3671371F171A2148151310131213144B4B5A72
1C2C6D654B584A2119192B7DB76F78141015193A20251515348EA08419192F79509B945A
583B1D2545171B1C218BC2BDB2827979AEC8B4B4CFDDAD7DBE532B3343505B758DB8AB71
7C4A4C466CCE8C6E5C4E517397CAD0674C61696F6DA28C8771BA92171B55B1DED4955B7B
BDD1CAC059223A755A191C1E39951813171A40AB3349A498A1BEBAC2
88C75F875F518D677094795B8B94418865609F446E8944A24241755044627E37353B446C
6E27456F254B53363C20722B27671D567D3F3133183D912B1D87402A7C6D3C3448562994
A75830376B2B67824E2762366E394390824380826B284D88432524733C1C3F4559315E3D
613B5C3C54523D55486F47486E5C5067733C66614F4D3D5B49395664676C8F456E4D5255
3561464E78505A938A325A93477B9D3A43984D346E60453951461F6589386C574D945C51
8253338CA34533517A4037A79F6D6CCBAC7F529C87509537246F9D547E5A215E524FB552
84BB4038B43F2F8D624347527F6C2367555366947B69444173643F684A3E47716C3A4F63
502F406A6658B3844B276279453E62456735433F9D3F3E6F6F862B3C777E3B2A75856667
9BD564C1CA5F2A9284337A77462A96471B447F5076C4401920295D27258083749AB78535
29262930423F5346372D2D292D2D55494B7D7F974F60485F4D3B393A3793A7B36AAD9E45
1812161E1E528767B2C1A39B9698949D9EBF78130E494B2D2D1A1F1E2B204E81687E892C
246577441715429792695F2B232121272B3B5BBB4D5A6DBBB1898487959FB5C8DCCF5CBB
D4A8724E526AA7A999959B6D5A7C877A94924B94695C8166384870394C3C37474A52B9C6
C75C151515172F4A67603C4A7B39776446406E361B191A4F2F1311101413131535548043
16171A6A603D2C2C3E516D4A8F403E4115111736282E15193981AAAD493A4ECB8D6E858B
5459402B60251D171C66B8D5D4C8C2D1DFD8CDD9DAE7BABBDBD4C5B3957C735F4C445D93
5276304692C67C8E69556678B4DDBB17171527569367ADC1B4BFC2382FB6B3CED6A7A0BF
D3C270795924293C5A6A32202D731715152154685F98A87B5F9AA955
81BF56887B568A6C73866A3D54703977296C9044623B55A7644EAA4222286C3131603D4A
6F234C762C2C3D21371F581E2A5129454F3B3F595F4F88301E91571A465123343F4F2365
8745253668376C7945265F346134849E4D1D4D4743384A945A2C2091521C3F3F4334773C
5E3162335A6A486F558C4D3F726D5F75723D5B73576D436D6F556A687A62945E7C595E5F
4372595A70658BA2923A65A45087A24846C1624C5B69573A525A346F9236758B53924858
87715B888C22246F656239C09E7171CBAD7D4C8A7A559343357F9F53654C2C5F5257B064
656C5237923D2B664140567B806E317633395A965C552744645C326479474B8C7B415083
5D3046714E7FC790492E5765417D864B763449489C3E43795F832A449B7A3B2A6B40302C
6BC25EA7B5772D755B4082632B2999661E4A823F76B85223252B5F4C1D506C60B4D5AA49
423E4F57525D3B1B1A1515161D4F4F4C365872A5AC9C7132261B161635727582B1AE735F
2E27271F36777C6B8FB06A453130374569A85310116C34285933262C293541243D1F4249
3B3B596B57477BAFB4AB8B5F5A443D424E352CA46080CCA876554D443F374684D0D762C1
6C51598E8C8C4930424F65798995A5B3BFB3B67289602115131532361E3F545653597E9B
AB71181D3D6C7C4B20571814267A80907C5A87431C1B2D3F1711151111131213345E982C
1C18173E76A16E76352C1C154A61256E52111529382617372F78946C535F718BBD9A5B5A
7F48557785665E312B929ED3D9CBABB1A39B9398C4C3C4CBBBB85D2E2721201D2D243C5D
ACA16B7DB6D2A7A0675E6EADCDDDC41D141515175AD2DACACBC3C5BDB6869CBD64221F28
438234224D5A3C293743746B366A1915192E814691B0733B2858B657
ACCA5F9E8F5293698B8E80435B7C35966071893461583BA4577DBD873A2B722B4687574C
6D2159934839431F4630521C345F3A5A50354D6B6B83802324B06A22505D373C597B4289
7F4925406F3363764127623F803D8A8F3D2A605E3F2E6EA05C2A1C9D47336D7655407B43
5555872C517851884C9A4E5D8C846A6778536B684D9C4E978A546868695F95506A658A78
447B625DA8628EAB932D96954387A24E5DCA65455D816F4C696D387B8E3369765689214F
936457968E23267E57633BC38E6994DAB87D49AF8380B35A38868945644C2F6C497CA358
8E876843834932653D426D8BA46D315934374EA79C702F43543F2E956F3E4A90372768A1
4E2C396037677254582C4E5427446B4F6C474280CA77447460532D6CAF722F2861673F43
ACDE8790C97B35785448AD957E2E8C3D2A8A804370A8632A4D5B805C1F526E28E2E5D9B0
AAA49A8FAC451A1515131919183F3E53341E76C3C4625C1D191C17186940488EC09D7A9A
BC6A588194281213185782623E2118171B378E18197827361F2C535062481C207449363E
5E431E1D335C9C8796693F232D456B6C493C228EC89888736B4A46494A5D8A9DA2ADD9B2
51413D67732C1C192130272F396BBBC8D5E0C3AA401515151515153B1C161A295093968B
6DB07F69452B1A1A164C1D15152965B2579BB28B2A2D661715111111131515155794A021
17191932685D3A351715151318543F24874815173B253E3E4BA47F46413A475452709877
50848BA1553B6293AD9F77ACCCB18A796EA6B68E78959E839EB4663E24241D203A1F224B
73CDAAD3CBD1A9A78B9FD1BCA085AC631C15151545D6E4DFE0C8ACD7C5C5BC77271E1E25
2E604E25284B775D412D3D5788964C262C4DA05479623B25293E9EC3
A6A244A680558443848C964351533FBE79824A358A73448A3598BE8433376D1D6C925043
393A9DA44D48422C622943387186395557308099698F6B144DC37B2651534060A18C4E8E
7C5A34646C36677342476F458D4693C65C3A6D743D2D83A258231C833E1A375E513A844F
413A702D4A4E3E593C8D3237717566605F43494A53843B765B3D5A5F3C37623C7B49554E
33703D3D7D4E74B7802D6F75348D783371B85B39617D3B66A077377D564388754F932B6C
C27A6990894348B08F7E3AC5644160BB954C62C8815FA66842A18836534B3368387C9C70
6F88573CB3573269394580AAB37F4355415A2E756B6742455B3A1C75553C659F5B334382
2D3C47444764614B4B274A66313F664C63352A43A7713E726D7E25448F58252260661B1C
95D969A5D0933169341B748962279728134587685D83771A202655231B486663D8DCA45D
53557E4C414B45321B15151919281C2E224C6A7BA371462E151513415A313A6C67294F94
BEAE897A88362819151547816340333B352A6B5C4C84442317161E4375432D3EA27C3B2A
2B344225548E6AB6B48A351C1B1C2035535686B3BD604523233856596AA8BFB46F68BBBA
805D48482C221915151C192B2E60A2C2D0DCB35D1A171515151515312E1C1815193F6191
9D99491A17161615153A3411131528A24552AFB6A9BD71151313131510151E3543B9C036
151815406647361A1315151517444E182C905B1750846047946570667F78603D383A5274
999DA1B16B5E6E68D0BF99784B1E15152147282C3143559F95AA8F7A6441313941302640
84C9E2C8C4948193B9AFAE462129458C5B151531A5B6AD6685A6B9BBCBDEC24E191F272B
2551492425333C707A6F60487B5C757E73B1968E883A372A2B3CB384
A4BD5B7F7B528A35324B7740515E2387516F55225A6343802C488A6A333F7B1831614554
4A184F75393F4323413052183C4527594E27686C67AC6C1D258250265E3D19273051308E
82291B4A65325F7F372F5D466B2C719E582D777D58395896572822934D1A3A4E3264C083
733E6F2C5B624E5140A13344746F5D687052373F577E5E9F5139617665475641915E7D41
32844953783D74CA97467F7239B2A3416DB54740708C5D476C5A338A7A32585469AA4755
635F6D9FA43A2B838A534BB8B15663BC902A3494665AAF2A1B829754554255A1556B7544
688A432E54512E73403D718B8A803E7B816D607A6A91344897703A8751197CAB79364176
113350614F656D3E37469E76333B442F7F683C4EA3403CA1B095283668343C768069191F
96B2297E926D2B7142256574562F8D3A1C5162505D7D6425282C572420455855A2ABAA4B
322F4F59312B3B3947504A4230241D2C21402D47A6903845151314663C3F6370311D4F50
A8A16723161C2A313139373F6561424B484F429A8F8E5519171C2053424B896C801B140E
14132371824B2F56705C76663E2E3E342F3FA897AEA38D471A171C2D448FAE80554A98B3
B560332F241C191A1717171B454669677CBC4F4C171415151515151B41252016161C409A
9B74331515151517172F3815151515676D38799AB7D63713101015151317432F5CC2C661
1B191E415B5230161513141317215D1D173185876E9466948F4D17222D3C675D56392A3E
8F9DACB33922388AD7D88C5B1E151616452A341B13172697A5AEBDA9A09065676E59374D
BBCFD6C5B276A8ADB7AA775A381F2B529E836B935E3D312A63B5D3D5CFDAAB2523252822
22454D2625312E2E59939EA2AB83484D81D0B5B65C414A35386CA71D
ACCA64907076BE5F837F6477B9A83C9D5EA39A42564A81BC58887D56859DB12F383640A5
7A2B7562346D73372A4E7425455523818A51745B38CCA84032A33C5E9C5935505A4F259F
9B671F64480F5791683C5E26774F879A5441B5C5583F6785374B589E771B3B50313C626F
673768167B83564634B55D4B5D3779A88F5343356FAB5C9531307D939546601C90688A2E
2B98914F75152C669A49926B17869B437DC210255299694F7F3A0C807A3B50152BAB7E6D
7D4B1A689C522F876F5124B07D5E6BBD976E46705D77933638A3905637331A5F5E7DA032
52835738582D38A144489CAE9867215E667E5D4A1F75392F4F5E3F77623A5C936E384585
32333852535A5E423121525C283B4B293A363146A2452C675A71243E642E13356B632237
B292549CB15E2F9F79395E5D533D9A592255574F757B65302F305D362871925F5B47AA71
43352A4B4A4349595243435C67615A563F3B2B46CCA03565291C2BAB8FA3C5882F41311F
7765210E0D0D0D0E0E1B1B191E3259432C3F3E4CD056362A171D4E2F272568743F111011
111517817D3A2033772F295D96681A15153793B22E1F37838B5F4E58759DBD9F8D6AB8C8
92362524181516161619182A653E436B4AAC524A211515151515151549281C1C1C1C3DC3
7A424315151515171C1D4915151113379C3B50795FC13113111311111330281FB4D7DDB3
35254D7D5F852313101410111316573C1D152698CD9FB6C25B1E1A243C443422314E6651
3F7E7194BA634C63CDCF80461518171D44181A15151516504E6976B7B775514C454B7499
8EC8BBC387738E61373546696A432D316BCFBE5E272E3E3E62C6D0DBD6C19633342B2520
1F324E3236543C37405CADC0BEC98BADE1CCB07F4B4F6377ABC6BE5A
60C861AA54479356AB84513C56783F7130757C4A4E3B4F884C856632283F82253836275D
642C7D6B283147283C2F5A1F3F44213F48335147248D5F4838A52A255B64415665531845
53471B654D153C5C4C3A5E173F4B92A7671C597A7D346A7A201517765F1A3B5042457655
633D6C245C64565235814E596942515E6E54392D5F814EA1552C52544657753C6D46965D
36773D649C6E8AA7613A9F833D86583A96AE63365386597FA86B2766683C615640B04979
AE6E5196763F4D96626933BE78658BCEB15F5AA5324E7A4F408F66404C442F7947A7BD66
51833C2C7C41255D3B3D83C2BA7131564C4F3F7D80864C4061634AAE9D536AA5361E5B93
4F323B77407C9D705C2B5863375F8350572F2E58B762467E6D781D4189601A3C66353B73
BB944DADB0531C4F6037614B1B21845321545D205A958A33403D64171C4962608D49529D
7568527072768581868F7678615F5E79828A96C6D9BF609F8B5767CEA44836557577827E
A756160E0D0D0D0E0D131515141519415E4A4248CB503C3E1A453519594354631A100E0E
101344575A5C1855A2331D1E4E5D1515195EBA503615152B8A261819216B79848798C87C
76281D1B15151517191A1D2662302B6253AA5E4F3D171515131415153C471D20212C739A
6E387617151515171717551515121527C43946723CA8561113131112156031473A55A2C8
B06D829A91B34A131013131110156472504A69C0CCD8C79F365764625E34251B1C1A2338
1A3BA9919CCCAAC4E0D3B73817151D401D1315151412151C17504C9BA884685C687497CE
D0C4B7AD3320331E1B1A1C2B4272764446AB923E7B9CB19089A6D0D2D8BBB967513B2621
1F2B5F575296A38A7D8AB5CEA1AA574BB1B7C06988AEAE8861353890
A2964F8F6E648D669AB485465D6957B34F97855570695D9F618F9F753D4A6725585D4256
2E23846E3C4B3A2A4B3335305A5A3B5A55425E7D5CA5635455AA54346B534A7FA46C4074
6047316563245E6452437538564B8788582F7384663AAF9D58201A85402858734855A25B
2F6873347830616D4A712D59735E9E70395950497A582C875E3C75823C4D673A81546549
377E46426E7595C387428C653D9D7743809C5C38686D1B51846C2D624053765E3FAC223A
5C6169AB782D438C786733B73F3061A18D585C786365AB71416D884E3A40347A4078905E
69A455224349308125265F7180853C594E6B346D54755A456843226A843C5CA365393789
4D3444732D3754644A2E56421A3A644C773F2775BD8C43786B582356A664193F642D203A
B94C86C2B46E2A554B2E76612425A041225353505B875E3893AE7E3E2545742BC6A487CA
783F352D413329303A405A7B8E978AAEA996B5AF9CBBD0CEB5693C4294562D242F71AABA
D189190F110E0D0D0D0D111515151314194A6FB4D2B86851604F333FA888763E19151011
173371351F444A403145411F2150261525B37A47441B2215151815151742992F4423747E
984B403C2F31343F4A494B6D7D49427E56BC7B555D1D1E1B1815191525693B2C1E348233
533B7F291515151516155D2213151638DB7237813E8A9615101111103BC1642327319BC8
9DB5BD8D76636F4D101312111433717C7853539CC3D3C5CC92719CA64E35251917171C25
1B2E96CCB8A6B8E6CFD5DE7C563E3866191517151513111717484B8250677E683E539492
999B50485548371D1D1C1B1A1D335FB49094ADB9884922213C83B1D2C49BB4BEAC978C46
476E98A69F94A0C6D8C3AD7475977F6ABBA1D8C4B59966311C1C267E
B2C25D9D7A82A74C69695072AB58338A4298373875596D861D8A96655A876E1A36653E5C
66228777384C53355E40481C2D4B2B5D462163674C9D58194A8A4239712E284665544A82
7121194D5E236A6020386737652A6FA46231809C38269F99574766A44C152D5328669E80
4E3C492896635A4947A13D436C4D8F936A5C312B8B7A4A93314373816C7342309F586439
4394546B6B3177AF9C478F4D459F7B4B97A44461B28C47666E553C994C3C615573B15C6F
6F7D5ABA874443946D5A3DC28F5672B9923B8FB07473A4563489966A51385BB46F809B38
84C261324E3E34944B4466856A7A34605577689B747942486A4836816A4271A9633A389B
3138545B4B524F3C442F5E6F363666698E68444AB07E41939873213E7B5630689B7F324C
BB6741977060358A5136B396452D9E32418A9460828A5E212D3D582F32587944858BAEBC
5E4D332821373E242427373E2E345695C98E462C2A7BD1B23F15110E1F8D642E2636805A
ABA55E150E0D0E0D0D0D0E141717171C2B55A3DFD5D9B5C3B0807A6B90907B605C5D615C
6586B3673F56686B73586D764D3C512162D991625518141310151D17196ECE4EAF88A0CC
C899897D6A5E5B57493C2F3E6499B1AB6AB395749D332A1E23242221459149533D685F1D
2A54646115141412151652793F4D76B4E0E3A6BE377ACF20101016456847584D5D9DC6CE
6C5AA38E4A666661240F0E15275641131F5398ACC8D3BC7F6A658C885E2B1E1C1B191D31
2F45656699BDB4DCCBD69FA52D50B8631917151515141D221945407B4C3A73C4DADBC99D
75955955573945282024201A1D1F245EC1C9A031151A2F60724D498A9A8886705BC4C1B8
B0977C979B95B2D1D7BB4921285FC8C3C0AFBE985D4337251F21256B
98C1598B456FAB5E8D6B354469653F682295704051206D8742944526488890243B2B5393
5827893E38746943446A56233F3F2B817F4362485FC99C355B963D64A2684050683249B0
72501F694731A69A473E503C7D3C7DAA3B46B1C16834A17B1B22357F65192D5141597A61
51403F226754564A3A7342476F4769595F5933256D704B8C68445874697C7E5578575A6B
478A5257696594B991438B6F3B9B734F94844036567B49686A2D269951474E1F52AB6475
67454AA5A33D439855412BAB936473AF93396A885E7B9F1B2DB8955E62292F936A828A3B
4C774B2766295DA95A3D476876622988A9A86AA15B8F315FC47947886A46BEC8873C3C93
17408C685D536948244D9E713136522B87823E5EC13946989A792F58931E28635C282D6D
B07350C49929206D61275E51272D9F4620544D317EA2582E37475512378081586D646564
793A2E2A261F3F5F4E727D473222313B95442B28227EC18A1915130F101967713C316955
A8735B4B190D0C0E0D0D0D0D5F82889FBCB7AFCDCBC1C4DCC6888F9EA4A69896785A3F2A
2F72795E58503A323855425274808388B77B5F45621313151115152F5CBBCECBE7E0BFD9
CB94423F41424D5648403C5560484D69A9BC6A9ACFA4766541342A292884544378A7361C
163A4F9119151514151B8F86665075769FBDCFDA736ADEA6645A7B531C13153792664F9A
AE53498B6473653E5F2D1527484D10101317435BC59DA3231923384C3F271C16171D2943
4F4E2D27367A9DC762556E947129525F1A161B17161518241A4346714B2646AAD3CD703E
5B83573F657651573A3731232025222B66B364252742644A372E3556849E5C59546B3F31
28272F4B20192432565D1C1D222DC5BFB38891853633363121243568
7EAF53A26974AD5E99837E4B8C7D45A33B997B42624D7197619090572A648A2A3A45396D
502481603243483438453627404430494B3B5A395D4F53297187242E6C553C47672A4385
423821693D1E636A3A4A4F365F3782AF2A2152685630B36C3A33298B58172D53326B926B
533E54347D60555E527D464980709A67735D3C327A795294694F6668626B7C5981584E60
568F52537681AAB07943955C43A8584F87725E4B90874D7675682B793C4743346FA64C85
5F6F4E9A68274A986E7638BD80677EA7A2418572519F91351F98735E5225477752898458
8481512B4D222574393B3D30495119444D7D54A46A8F26325463449F6E2C5BB05833549E
39264B622D5B7C652E2A5445234E5F2F65552A6B9E61398D783C1B4584521B54754B1A42
AC5156C1AC68244E5A4587541E269D39378049384F87582B46645E282A4F50329B634F4C
506933241F1E225562497D39282F42437C65253066B3A9991D19110E1113145B885B6C71
9F922433521B0E0D0E0D0D1348445A524450985844B5CDDBCFAC594C5E9C9B7E837E6C5D
48507D8B552B17130E2562272D549FD39D4E6571AA3F2E2F343C5093C9D46DD2DED4CDCC
A89E686B585457513C352F251D1D1F46C1CF42A28D544B527DA0B0884F906BB0AC6B3917
1617488B291213131562911915151515174ECBCC8A58BC2F4C954913132443674E43331B
3C848C8E96946D523B5D665B581B10121323387AC85DAC5E151921473E3F20171C21405C
4A352E28334C5B72321C38548F45336822191A19171819413A685B5E3D2645625B9F5C78
9CB157306B423A393C4E525040353D3E5892868561462F2B312C25468B98446E6B481819
161C1D361D1A1A1C224B1F1C203B87A9798689A84B402D2324255948
BAB851A97184AD5899868451857B3A9D46A573406953709A6087956A4767832240565564
4A258C6930504D2F4058392642453B563A264E46894E542D7C8B44467E553F5B884062AB
473E34635A378978465363457E3F9FBC40316F92513DC57A3C40347A32354E60344BA473
3A705C328A3D6C5B5C7A445C846FA16F4A6B573B834E58895C5F79692760765698476E52
4B8027567D66C8B63E489E5644972D4D84805A5EAA683792B1692C702A654D378C842485
8D6E67A5524A849861622FBD533657719137868A3B73884735B7412F4933496A4CA5B267
84983F3669462A82253E63648E63345E476527728572404A6041276C713F98B652313C86
2A366968444659493C4D805C292A4F4B776C2F54A65A45ADB16D1E438734227D6D3A1D51
A97C71C8AB712E515C365A582E2891552F6552394E8D5425476A744F355F664447677156
495B5229211F1C33BE95AC997A8B4A19699A718CB2C9B9AB8C6034201817131555A297B2
D3C46726275D2F0F100E130F1715161B2D783A111039C8B98F5D6590B87D1712182B3164
6B79AB5E191B191B17136F8D6863A065BEAAB3BAB77E838C919452A36176D2C4483659B5
AAC2372315151515151415131D354869C2C7647B7B5F563C37394E75C6D18074973D361C
15152E5C631615152FAE281413151411142B6EDEA9A5AE85B07A776C7374756132151311
111C568AA3BBB07B474EAF7918100E15173046718EA4488426151A3C454B3D20243F5540
424C313B3A2D1DAC331724395C9C57995F45404D54685FBD87B3A4845A5872686E9EA485
7FAEA88C5B1E1E302F1E1C2E426999A4BF9F925B351E192421252A61B9B93271603F1919
191C1D371E191A1E389F78694D819D74407496DB9C5E392C29355549
B38D58B968878661BEC179507A6C4AA748946F4170496B965D8C99673E703A305B544A70
26308D5737523941435A2929623F376141195D4E7D533C197377384B6D232F5271316797
4B1F2E604239A1741C4F57467B2068A342326C923D31AC74354D4B6B2E111F4634307970
31483F2F8E45543D59853C35584B9771505431399052507242587A613D515C4C984C3F31
5C722E446346B4C273459036508D4351677D4B73AF723E5C665B3A792E49373C996A3570
546462A85B28489868763DBD8D5F61656F3A979D6C8E903C27AC785035325E8E4B79783B
8B9E3B2F5D29349737304E5554562E75747E5792507A314F84503B7C472F849F6C393F95
35264F44474A545F4D3565672E2F593659794062B0763F80966F1E4B84431B77795B2556
96767BC6AC7330616E3F59461B256C483370583A51775F1E3E6D774F3450795935353C4E
5D5C635B40335896D0D1BCC4B6AD866A7EC5BC825075B46846485863615F45362161AECC
CBB9D08C392B4F2B100F171B16171D2F8533090A0C34A3536C4C23577E54151317131510
1623535D1E131A15172B85585B73B78BBC83726E805B555C54648AC2989670A32B175CDB
A99E3C2E2323292C393B3D4258BBC3D1E2B6C298391C1B1C1C1D201F48B6D16469574223
1715193DBE441D2AA6541413101113111F8B6D9E3B669E9F3F2680D4B595843B1F121515
14111C9E71A873859587B54E1313151B33482B5D30503F497619162D644F5C39554E2A34
3C342E37291A32C676171F26727AC774376D8D8A80796487D2D3C3C6BC7986665693A777
7EA89FAB771E1F242A3C281C1C2857B7BFC0882B17161B1F202547AE76535F6271312617
191C1D33311F2F68A6C3937E93C3CD713786D0E7DDAA473A415D4553
BE954D976697804267646150772C4C8844802947723F905A1F78594254754F1C3D384278
321F7134294F37271F511D153A302F5656284B316177521D744D2651614A2A4B69235870
2A2E2C5A432A69682D4941375D419F992F42909D5535C35B2E4F4C695312264F4F29685C
3C5041318A565F5D5E7C463C846A945F635C3A3989666A865E5E675D4E4E795D8E57455C
5977486A765EB4AB6E44904E4997415B677C585B7F7C4F738030468B4B5B4846BD864895
5A666DA9733152A6413F2EA783585D6462358A876291862E34A67E4C3A30427A5E8B8C6A
8B904142451C2366363E5E59605A2351526B5E974C7C475465624273524C8EB57332438A
2A2F492D454B6B7E4C365F6B3930493A53722C5EA58751A29B72225894651D8279544398
C18160B1844F3FC4A24357452844AA56358381587D8E6832417169413B94A0674138352F
31748D59A5C6AC8668ABBDA17CA97C88C1B892301B4175381818191D212A3C6188BFB3A1
957270AB7F67326247313431343A42A3390D0B090C468D4D6F6689ADA8711D18150E0E0F
15133E7F271713153153412923226E3F8B8E58852D1C1C1C1B1B1D296DBC9B855B78C0DD
C3D4AD978F5A5758584B3E312E2A5A7CB1D5DFC3581F1C1C1C1D265288CEC2BCB19F7E28
1B15142FD4CFA9B8CB19100E0E1521466568969725568C8815216FB1C9A3633828191211
0E152DDB7E7C5D3165BC77461215182F54271D3B1719652C705317215358789A61282F30
342D39311E3876DCCD6E331E6378CAB2AF72597576848895DCB8B0D5C4A18564704A5D77
6287AB7C802A1F2023283C3B37525C618EC9A154302A331D1D2F89561738764981484D1B
1C21335785535647598C5462A8AF879376CACE7C7584ADAC95946F43
B5A2519453908D519780496D9B66506539A262475B2B84916D7C845B427671225267556D
3E409E58354C432D3246231D505741534C2E5E525B556525805B364B6A4D2950642F6B67
3D39306B583B686D344A51487348AE8229345B715834C44C2F4E59654734475D5A2A6C50
384F2B34874A5C4E637F4740866DA46C6655323E8E767A6B5F6E6B60495F7D5F7858455A
5A763F5A7D75C3A75F409B384A84376666655D649476568DA85E4873445C372C9B7042A6
6F3F669D72254EA5516339A595647B9368348DA071BB954A61927953473840866B8C9396
AD825A61612D266F484971676C5224554C55568D5E622A6282553D786C3B7ABE864E5291
443C47415593927E3C3D53573843534E4461337694744E988D553C92C371208F54042C88
BB7B508A8256226776395548252D9962367E59295CAD832F467B621D45967D53813E332C
2C66D2D4C3996C6C86AEB8B666242039957772321E5252251313141614140E1536C38478
8D764F5571685853B97F6D7090A5D4A7130D080D095D7C618F8A6295B78643210C0D0E0D
10131E766720143E4D2B1F21242F5F6889967E71211C1A1C191B1C1C237F82758B673AC8
D2D1833015151415151514151315153157C8E0AA9C582A2B437BA1B3AD91C3CCB5B0C9B2
65201F89DDC8A6E4DD682D2F3D515439322B979D4F73899923577E7367467E8D975D2D1E
1B4FAEE4B5468656589C90561417255E49193E2415152D572581431C30AEB38A4B302D48
494735244181B79896BD97595D86CED7A47A5C5868887D4C42AAC6C3C3AC99702B1E2363
8891B8927F762E1F1D252433602F273C5D76CEA34D405B382B7A8C171D35526F6E8F7D6D
4D4E4B45752F2F3768B796ABA95E6CAECFA156823E31335294CBB089
B59B61BB71928569C4C05B4D6762919947A16D5F813C8F936D7E9A6449814C4D8C6D6A5E
15328F633C4C25563F5F2339845D4D523B327746635F54218052324C6655387C76467775
5C3A368A5F396261454F5C517353B58B403B62845C35CB5B3B5663522360668663287F71
5298343A88437A405B5F445B6B61A05C5951263F8E5983585B62685D3B6C7E648D7C8E40
555E339E9A70BB9B487BB3404C6E388D92835561985066CCD157495F5E963D44A76C4CC9
AD6B6A9B5E5992C4656F41C255588B9D5D2A8EA03FB4B47A85805269953B498B4CC3BC7D
A18B5D937A4C2873615C9C96915F305E45525D897A78375889474AB160377DA94A2A86B4
6F38394A217084853D415E351F6C9F6039792A9EB79450908B351B4788511E8F64242151
9C65365E5B6933717D324E544234875D32694C48609B6822437974462E847558A66E3740
72B5A9775E925D28202A47A089847461998495866B9C571C18291715151413132B807366
C2772B22285670B6BD808F9A8D64316F681F0D0E1186776E7197A3A3CE98532E0F0D0C0D
0E1219399E5E5C3F262E30372C3F584B8DAAA65A643D28251E1C1C191D3B8433863842AC
7D971D150E131515151515151515194564ADB9A049CBB3CAC3A3716B563B67CB8B8D6AA1
C9B4B3DFADAC9DB287B9BE8D583D281F1D37CFC78AA8CFCA84934A29131317244D7EC3CA
AF8666A8DD886FADAAB98A5E2A32544817153C1613131539363592312FB88C655F434060
604C31517A9B60191A46A9AA9DC8D8B3472F3F877A4C494C4B997D91C1C3C07E1A15194B
A68D988C9DB24E483D3028264E21243F627B793F677172B9B3CC44191924377D90929AAF
5A443F3E7446313150657EC59A9DB7D2C59CA1C19A76665A74698C9F
B6695E9A62985A3657884E52562056823F6530728A4094532F8691593E852D184E57615C
28237F4C3E45272725681D1A42434150332A6E41545E2F359169334D3C2D578A753E6A81
312D5C8365315F633F7467518E218CB8623E60853648C49F394B66502B14295F5B2B8459
2255453E803F89474C4E38506654815629555D37821D636552646E5B2773815E7D38533E
546615496C55AE94292C70405169344B5F78535D98432A54713E55435289594CA0461966
726271B339284077665652C4682E50783D23969B448A7631839C552D4D3A3966246A7E4C
808E245B7A4B22712748838894854966455E2C75A8965E608D2C33826644759542175D7B
372A372C425853632A43562E092F60452E661652957650878D671A467C2E19828A663572
94304C876C623C796232723C22336D313775664A5B715D23457C5B3D34908056AD9FAEC3
B26A514D47496F531B19197FB4B288618A8A5E9269BFA2594D4C453E3329271F6A6F8650
B6C5867693C4A5B4BB95562C120E1114487D533F6CBA81866E656273DDAE3116090C0C0D
0D0E0E0F7BC357443A403D444463603D82CF311B1C2D3F4D4F403136253F9F825CA2A46C
719D1D1411130E0E13151716264751437D9773C76FBFD4AD7E724C2F393D338FBE6D3B4E
5DABE1E9A8BECD71515A5F94C5D4AB958DB5DCDBE0DFE3E6D35B2F10100E150E0E198EC9
7D1A141B7CC78A8CCCD0D8AF9F62591615194115101112174C265F9E93A3A18D9EA297A8
6A7569918F4518171C1C3D8E535BDCE4D6BDBE512237517092C778A3D3CFC68619152F4F
4382524D8ABD65564745444D6A494C7485964D17172C9BA3433557371C213173B9A2B4AA
785D56619FAD868075529C94ACBED7A58ACB68232E4371AEAE6E4138
C29B509F639E9E5988AC555174586476398D523B622E9E6B2F6191624D9E723157576676
2C339739425C3C2C1655291B55253F654B2D6A42607B4419604E28564E402B735133765C
251D1F514A2A594619375036592D6A80343C60742235B4592F5781644A1E3F63372F9263
33534C528E3F6350606E313B62528C824D4E2E409365775A416F936F3B61455D9557582E
637D475050368795514294255672405A6D483B5D94706F7872327464447A524FB87E3298
66407AA266314692322B4FC9934C6D845A2DA4956DBE91395E505C4D5A292E4936867347
6D9B38547A1F1C69253A5D4F6F58395E4752424772744B4B774D3975523A769C6F377884
2832564B516E6A5E2F4C5343243B3D2C2B483181B1744A8C8F63214A782C1D7E8E663A80
B95A1C2B6B5A3E9A482C6F583A39752567A47746599443448DA74D2F3A94692484D0DFCF
BB9984745C5F5B5C4220216D5F3F2A3555996897C5B75F3F3A36383D494F5D70B5B25E6B
592A1516476F716D616D37303123131010278AB392D58A4745433B69D1B38A270C09070C
0D0D0D117EA5AF99837369676278809FCDB62E1A1A161717192233485B91A5AB39AA8C37
60981F1210130E11111A425144291F37A87182B4E0975956768D8D5849393668B0922D28
3E65DFE6D8D3CC9B989592807490D0E6E4B7DFDEDCA6B5DDCA2E110E0F100E1111189272
1D1313141773B860C9D2E1D7CF881715155F5C151211141325402898AF4598C6C9C9C3B8
ABC1AE78311917171B192A372D3F9F5991BBA21A15151B43808B95CBE5E7D9A8533A4B3E
401A4A544F8BAA6A676B647192838CABCBA15F1F1D358969111417514E28375DA4D5C8A9
9398A1B7D4DBC8C1C5CAC36AC2D3B076A69322222C334483929B553B
AF8B527F5DAA935E909E6872AC697D564AA058505033A08C376F4245528E5F364A325576
263F9B473A4C3531265A2A255E413A443F225A314A5353206E2E265D513C378A3F287E68
442E3A7246338B68444D584666509C7325427C805735C5342A3F7A563226496C5D229B52
2B61364A824B692558603D41473D527162533A317C67765C59655D6549787C5163616244
697146597E739E90385999374E4C449F91634944795C7FA6943958464F822D308D5B42C7
9758779C634574A2454D70D48665A6B4582FA37F5ACCA96872544C5D541D3A613F897923
5A85485E981C2376454077517B40246865615251918D2C3C9E573D734021478B74458375
40254E5854AE8D51234C79523142372D34513C8889537ACCB46A214B7511177B917052A9
BD6C2242671850C8842B47423965A44B377B4874A28E591F3862553A419D6E3448C8BC4D
33292B324A72A58EA13A32705F2A272C344D90CCDACF56352E272119191A282D617A7880
21111011101C283654684D272937442C15275186A8D68E343B232A8284274473290C0C03
0D0D0F2258291E201D1D212847A5A7A8ABB19E552D1D1A1B1715151517328E8C634D6A36
649123110E1514234650322723242181833456C1DB923817151E467D8061578494D05D21
1E29D1DBE0CB6F41474D484F4D4D6F8DCEB5CB694FC0D8CBAC6E100D100E101013469734
15101513121DBDBEBECBD7D5C32814152ECE73161514130E1345287C58495AC1865D59AC
DBC8492616161A1A1C182D2D364B7A41254BBB2F1515151D63406A71B3E4DDC3B2764529
15151A4655838C302E26242C5C364684B7BA5F5A4D4D8463151316274B6F5A77A69195A1
6B60624749595F95C9D0D3B6CEBBC0C1CF982D2B363A527F3D3D7384
C592529452997C657A5F3F588872875E3E975A53702C9498346F945A4995635885627E4D
25719F4B3949282D1B57211E5A433F49442152407C786220795A3552372A60A985476765
4A2D3F78372C5364474E2D4C8051A1922753796F4B42B94F353F83503963768A6C1EBD51
498A3C537D4E7C3B63573B44554B56635657413F7D2E6C67555E555D2D6B6A525C797C35
68583E91855B7380226C922C3F322B406E733E3D752A7CA8A23A612B5DA0553A9D744D8A
716887C54D2F83A261528CD63C3D6988582AA49A8FDAAB698853432C64291F5536B3A271
7C7F2C92A6561B5D3171C5A8B25A2E52415C3983B6903E3C74313997572E479E392CA3A3
612F525135677967434E6E423A6F67282F4E36887034334D724E20557B291A7B68283A61
B67A25374A3E2C7D582D60381B387B335D90393B7E756A284B7E4F2B56A37E46449E7F3D
3B4145433E3B4696BCA24A96A7A1312C5789C1BDD6BCCF855D52615D555A46556B779E64
1C120D0E0E0F0E191A3D744A36323266AA876C583FC5AA4140286FB2260C0F397A30130A
0D131466503E405E5449505450827533213ABF607457251C151515131517738E762A7744
7DB12514102747412A211E1E211D369942293688CD478D581F1E211D3483975661C5C470
3639C1C8D9811D1515151515151515187DD99E1D3C5E80A483AC310D0E0E0E0E25834723
14151113195EA190AEA9CACE9F1615328D34591E1514151114246C8459558D7D8F98BBD6
A6981B131219191917173C272F747034191B6B7D1715171B56212933428F3E78BE8A2415
15171C354AA2836B53342D2C6639549385A2777A9E9E87771513191921B5D2D8C1A5813C
222028191515175CA9AAD0DFB7627394C3BA8A3C394D995B30363759
C69452AA59AC8671A8A45156694E8C71519D656D8734A796306990564C712B3A6B725754
1947934937521D542E6B193F774D3B4C432B4E36487A463C886E3557331D356960407765
2D5370795438535F43484F3D785199843D4464662462B85D3B428D4A23243F7D6F24B965
355F434D6F5E913E644B5D75594E584F335834357B5C545E565B536633666E4F825B522D
6B512C5A85527587305B922A374534496A6A2F3783667C629236533D44904D3792897297
876F7FB7842762BC60599CCC785485A1712C98A2B2C5AC637957623E55341F562F938F5B
807E3E458C3D1A53233C635B715F34574B5B1B527C8F5750741D27796B384B9120187649
2932564E5C6153523A4A5A3215587033373946B890626094AC3F3D80853B35A58C664773
BB7D2548564D3D87383F9E602D3A481F4071533E5B6C2E5A9C9C41232D87602B79BEBB8E
5B3B3C2B2831373864CCCAB4698690928885BACDD5979A60161314141721808634385254
310E0E100E0F0E0F121B3BA25A474B82AF813B262395BB6D3F46B27B190D0E137BD5AF86
7F7B9F989F9864595147332E3541511E1525A83D175F87341B15171519185BBCCE75B8A9
CDDC5D4D5C3F201E1B1B1F252A2D996720243167C241709E964A343136477FB199BEDFD5
CEB3D1B3D1341F1A15141516151515154CBF591D522A3982AF8980130E0E0F157D582629
141317336D7131599E934188981A299328143E3C15151514171953D3B2BE9285915B569E
3732571717151514152A44212F974219171623924A1C2F78A629192934401935A2561513
151D37566E6F495283524063B59EA65B51691C2A5B8EBEA31C171E3F7D9D9BC6A9B3C6A0
826A2C1716191F6D6FA2D0DD943D6E769A8796BC959CDD7F473A3E4B
C17488B756AB606884A1495E765D7C69635D4D997835AE77478789523C985344624A6366
2350A15039522D3A20601717514B35502B1B5C454B55311C635731594749396F5A45785F
44225C6E503B573F356249435C3696A55443636B3341AD3F4664926A2E37597B3847CA78
37603D567C5B7632704B2C5269365164526239338160647352555E78477E6A5894706738
70774D62845E80A33D64A03239573A40665D4B6B9B6A7F59862C6A4A4B9468369F8E9287
6A6694BB812B57AA705DBAB182528DAA5A33B4A280BBA250755A6147582B1D824A897A40
A8A55539953C1F6B605E894F72522B57445757636587276EBF642B69513394A87538805F
124395855B5B683A246B6930226568374833267B6D216C9CB04F1D4663141C8195634F73
B66535615C634372392C652D1A3E4C1E5C6B4D4C6C57292F4F7A5F3D39975B33B2BCAD47
474A3425211C1D304F9887B1DBD8BE92865C394E69B270965B1A131519176D4F19273F58
4A120E0E100E0E0E10172584B04F61A1948548271E54C0C4A0BB9D899175748FCDDBCFAA
A4B8D8C7665E6E5D5D5B3B1A1423383519166B901112389A5C3137495865ABCDD18BD1AA
E0E6DEAA5C2F1F1F20263C4B3A6A99352E294380C3564A61781D181413151A4AC6DBA481
91D0D1AF6F21211915141613151515172F913219491A267C96878868130E1556622B2913
19394644353637797B9D4277BA93C4641712346A2115151415194295992F38732F1C434D
181F4F48151515131540311E3BBB2D1917151645C46C523B6B2E2125232731338E7A1515
1D375A91401523515B8685A9A37D503C58661F1C293D82D294818AA96D7EB49D9C8D3719
273317171A244E7048334AC4B5416794A38B60BED593B4CBAB706C7F
BE72509153AF81647B9C4B699C768D625D9F59515C329B46256F8753599A454B473B8867
1F4D892B5376432F1F622D1F50394E754228543F4A6C5C27815B2F604A453C543E4EAB62
4131445B493C704A293C4E5B6D2853813E70AD9A4C4CBD1F3038885B2E3E5659431F7371
2A5D3E706F5F532B8756375D594C8E894B594168B1616650478FA9824375417C7C70633B
857553634B44A39239608D36716F323C6838253579556B4536268D6648844B4DC3958188
602E75A97C406BA65645CAB476538C8F452484975AB8763DB6B66248542534A36B93763E
526A412F8C2B54B0605C964F7D4D3883938A6486759D3B48775E316D571C4B8479398478
3F2C6B7259555E4F164B82583D633A18774E338A7050416C9B4C21517044176F98594478
9B20177B8D68358853396F3A366A6D255C5E4864A083632A4571353747B68A64699BA66B
554C5D5A606464697E5F6D9EB7D9852C1715133D2B3DA7727089361515236D3B221A4055
5F21111014141111171F2778558FCAC1BBA37B56393BC8D6C25D30222E2D313437486E83
7289BC9772643538351A1010151A29303E192C9F29101057D7BFA47A6C769FAC7381D5E0
DCE2B1CECCA57F5C8898998B8BC35B494042557C8B61382A582D1D1A1313176479D3D5CB
C4DABB869A2F222022151515151815192778261C3E17177779A45E964E13507F321F1F3B
482D201C1B21349256C5A2BAB14C60A0906E7AB84815151315246F8F61246E3A161A4F26
15151F63511515132052343A70D02A191615161D982015154834204434304853AF911D2A
3B50843B15151838B78D699677909082788A3834384156C7DBCA94707095B9BDBC6B191C
1C28291E253D51944A32398AC78A5C729B8F468A95282F4989A1AEC4
C884527760B7847081694F8CA0627F24759C655A6339A68E2D59182D488F3942402A5173
21488C4133552F2B1F5D311F521525575E2E4B3F809366247745489C6D4141573A2E6961
512955720E3685653B47153B69466F843440676A3D569B33423F8C4B234B5C4F4C319550
3472226B825E4D176F59385A372A48623F612840814D57433D534C4E3D8059455088661B
6F786297555C6D7331958B284D3F345A5F5A2F2D684B7D56601E654B3F802A4E908B947E
7E6C759E702F62B74434A5A67C67B4A77433877350CEA041556A4A53571C275D4AA98D64
6B854C2D8D241F604D58A2548444244F4D73617B74A25C696D6032676E4A629F8043896F
532B817F55788D893443704B406859276934389271634A5E80503A81802C1957885B67C5
B78C197A832B37946F4BAA431E4B803F51692E438D95632F4786361538807D4EACBAAC6E
453531201E1B19232A386456339B3C1615151031381E3D9B7A5893814A84513C3C204A6E
7D4C1D1B191818151F3F3D18111A6233392D192D529FD6D9CAB0A1826C3C1E1D1F2C4C90
836594CA6534200F0E0E0E0E111424363B42174D83161054A279788998C0CDCFC8C1DDDC
CEDADCB18BB0D5DA87291E1F297E786751373441665F351F30391817151B464B3B76376E
3F957175C26A2A272A2018151716181825611A2F3B181B4A9CAF7343A77EA24340473B21
1C1B1719172679A67F6429596D6A161D2F415474AB4D1513234561CA9F5A77191A1D4C17
151517245A4C17174E5E6C69B7DE301C1A18151B81171515206F272E46527EB0DECA6C40
4C8A4F151D28516D59B0C2A68E744B353C9F92A3A294A0B45571C1B5C1CACED8C162231A
1D2D4A3F36251C5150362F6AB68FB68E90A9487F7F2227282D3A87BA
B7715E9C4D946D85A572416D8D6C884467905558354797762F624E373D9633465B536274
2145985A4552282438612C214B2C383E3D294A1C3561582476142A61583E4A645F4B8F63
5528465A3F3B5657424A434A674A906D404871733F53952E454394352D5E6B785F55A835
2C89456E4E697C3B782A4E7969424042277A483F77285D594753594B2C705B46544A6B31
77553A62687F817E2469973C54492942766F33377A2B6A96902B6B3A60AA7144876185B4
8E6F62B75F3A88C87A4887772437749489328F793DACA15263691C4E85411E503CB8AA70
7993273E8A4526662E57AE98A46433584F724180A19F566C61583E70755060AB51399C8A
643A98832646777438519A332974792A772637A099695464672426577E4B215C732A326A
772D227B75432875382D7C4C31535A296E8E605C7B5E503553804C373A836B3C4E868437
231D1D1A191616191C56567147436B171513102942341749CC9E57749FC545483E22478C
8292471B1517254442170E0D0D134E293823111427BFD2D6D09F8355586F65493A484070
5D54B2AB3D0F0E0E0D0D0D0E0E0E1433343D281EBA676D6A281C1B1C19247D709DDCE5D9
B8A9DD59614856A9992C23364458A1361D1A1819514F37251C3D12162F3D282C511B1737
37236B94C89E3B2D381D1E1D191517152B7519598A403956BCADBF89ACD0A986391B171A
171620395A7CBDC0962A23435E871C16191C1E2278BB59316859B487B575471A1B284E17
151615171D498188CFB2B0D1DFE26B28241515237D19151515325C28605BD4D8D4E3B268
8B77191D434C271715539D9B5B4E683B3E621B214286D0944A916F495C92AAC9A2576335
2C442C1919171B525A443A52B1403AA0BFC45C96903F3734447893D8
C254628B509D475C6F82529B89498F50938268873F4680654E86883B3B6829716D4E6441
2B6D8D51464B1B3335421D385E2F414B2B335F3D47492F398141345A3D4D7D915F439252
41264F544B596A4959594754573A98934C517A6E235B9B3F464590542646544E28637353
32885178686B663C815036627B3E4250438B4752825064454889927A48845D6E7E687844
8989545D5B74AF822D7B9340797C403A6D53558197677E61772D6A4734876C4582655472
5A3F56AF3E2E5CB7633E7487504A909B6A3DBB9049B07157B8AD3E3A603C1D46299DA565
77891E2C7E4223601D3A65668172414F527413375FA56E80A93931755B388CBE50269460
292A7D7F514E71411A6A904D275057349E49318B753B90B1A14623535A292B5F8C4E3971
A7631A697D552C6C66376D282252502C3D6A597C9477407EB89E463543854E1B4D9AB649
2D1F1D1C1A17193E32918A9C4B2F6E1F1514133C8C6C2F3CAA7B959A778A8656576F92B3
C1A9984956684D19100D0D0D133F6C436467596F97CFB0BB9C2D2E3B5A7F727B858B81A5
BAC6C65F3E130D0D0D0D0D0D0D101319322B401E9EDE7B26151918151546701B1FA1CE9E
5A58D49D4A42484778976D87142D8D2619151925588E333320285D3D291B2B5030111519
3E175EB883BA683F26271D1B1615171B2B6220727380A0B3D5CCB8BDC2AFAD3B16171C32
53706A53555D57796B201E325BA0311B1715181834A5C58640A44F31839C4A1721716E22
1F232B334261A4C7C9B08C7A62CA9C2F2619152980181514131D5B6C7CA7CFA8E2DED7C3
D52C2C542915131516538D84435DA76565732F1B2331A5B493785E133471428FA9416E99
6B2C211C1C1C22555746362F933421328EDAD4BAAC90A0B0C0BCAF9B
CC775B6458B88070773A428A94536F3A8B7F4364415A81422E573941657D2351413D9365
254B663B77813927334E211C4C2452854D3D5C4467623F2A7C4A30623F2C485C573E984A
2822445E415C632D2B543C704F306D853E79A17D3C508C295B6D885E2455525A434E7758
347D2A6A5B64426999543E6B5550765C4379345974407C4539515F5E386F33584E6C5D2B
6C76505F2C4F866533785F357A5B3B39602D354867438853412F85523C875C749983869A
4A4A60B1814072C34443AEA56A3A7E906033BF874FBA804459704148602E5A823D7E8769
9798512A7B2B4C7D435A77517B402C77827B5270668E2C46614D326040296097672FAF72
51338F85564C546C2D5C7E46436338196A302D7972504D5C774222546A341A4C90503874
A96F2489806A32636839613C335455315058478792863A2D4B764B333B70613C6FD1CFA1
675936221D234C7BABD3CED06543536A373E504D9B9C74A44C15154597D0C5AF664E4879
88B6D1B656150C11150E0D12195BA1A2967C41367DA34E3775180A0D0F26212A3B5668B7
AF3C24592C310E0D0D0D0E0E0E111318283D3137BAB72E17191B151639A9382328975F92
3D34A72C634C2130649FB3882C34992A2C637473A19B8248323441161924434713131315
273A47753C74D29D4237292B2B1C1D204D51413731393F476BD1CAAAB49795A45B807D75
5D544A39201C1D63911F1E2152877F1B1C1515151B48D1C1C1801F5885C07C6BA9E7DEBE
B1B4A0908982664B74A7955D2263B462271C1D3978151B13153083AB789CBBD4A292A9E2
DE58661F1517151517536E64477B583346973D435A818AAFA4A6A48D98783F7EC965535C
6D47211A171D4444563E2E287261242D5AB56061641A1E51B7574249
995B5A6A469072627D73407498567937738046451E5B8564405928233767204A37337065
275356303F5136213B58291E4C29273E4C33442D676D523488316994683B4F4D3A5DBE67
5822584A307788513948286E5C567B7B2F697E7B364B8E1E3B3C91571D5A564D4852623D
39892E6B526035397F4840575E494A5837763C56724A64454A6063573E6D4F77426D5E2F
727154543F7B88512A6E56378D4D3D3E4E393F4C5A43854B591F7832336D3F526A70877C
3F3864A7893466C253405D90643A7C897A42A7884BB69B53799C464444152F6B3876663F
766540277C222C684949675379512F4B46865C8461813D7161512F544F4493B87C43C069
573782875C4C5E69265F88644E68482A7E38267B8060656D77421B5763221F4C92635BB1
B170319867582E6D773D614F3B706E2F50453382C069533F598C47393D637F4DB5CECAA3
71605E5B5A5E4E6ABBD18FBAC8B2A7CA795246393355A7CD5A382F1C1D8AC98973556590
A99DD78F4744362B160E0E152B80A97C6873414B874D3B1D534E120E0D0D101D251E1F51
783F153C255211100E0E0D0E0D0D101721365563C5AB60282227558EB7B63E2E42A74AC2
7F416A13143C4C2C2D757E5493BACAA6A4533736657854907A82351D26345D130E111413
153B3F7B4B41B2DBA16557819B4047876B4E4B1C172333455EB7A09CB28996D8B8797C8A
7C5D4847473733599A4D20214760BD301E1B1C2B4F47A0C2D13F4E713E71DAC6D5D2D96B
49494643444969BFE4E3912A212DBE892E1F30467A1D2D14151E2B50D6C8C4BE95A6D1DC
B29555431B151315165A556253603C317E85494C4740468D84907E7561B16D71C69D5949
57665629193B3E4B554B2A26589A303D78D3625D672C1F78662A4749
C36D55915399845D7BB14C739F588C3E758B39564455986F3B738638347D1D39515C8277
285689554E54301E4C5220224A27374E452D46404A7450329041336659344D514137764D
3623474D38676E414540387543697D845054757432449237544796591B5C666E6452603A
3D9036735C5C4E5A9346425C67514E412D6F34606B4559474C5860664276588852686837
84825E52577E9061286F64379A673B4A5E5D464F75567E54742A75402E7A6172837B7C81
695B4D9A633857C86F4B77945C387091684C9F8351BB8B537CA9443F3E1A316134785F3E
A766342E78243364243E555E6B583A5A496B638C5D92527D6957284F374376B17E50C463
463A897E5E929574265C8E44406F4C2D944C2C7D9260936D743B2C85814E21496027558F
965D39A23E13318A685D9F4A29767A3E6A742874BE74595780AD703E62A87F38864C569F
CB8B684D4E98C3482673C3A6C9CDB1CCA85D504F7B8E96A87393C4CDACC9DDC4B1B0B0B5
C1CDD6BE601B1A2616112151849EB4BD8E7F2F0D24473B1C2E6319100D0E0E0E222B2759
40783A1E6D522F1C13111111100E0E0D102F5EB4D49F82867CABAA7353A3A992788077C9
CA9A7D2B1F1C214845534E342A77E1CE7C6B6E89A0BF788D98B27E483960281314131515
152B4B57555252DBDCC1C1D2B47A99C356634D1915191922518C5F61A998D1CEC5937051
331D17191B2029275EA51E243A6E999D252A656A313457C7B09B79412E88DDE17642A9B0
514F49526286B6E5E4DA7622202386AF5D283A53841B1C1932232778B3E6C564C3C4C15A
7EA87F52452D171518704F7751522F5C802B1A222B386995869C8C5B4D8FBFADC8857474
4E554A5263401E30455C5272C8C5926CB38493545A6653A7434E6574
CC66558E58A3827FA2B34C70A25C9240828E34603C7AA25F42838F433D791945685D8873
28668B50555335225553252A492F3F4B4D2A52445874523293483C6D5B2F475D563C8033
2720495243786A3151423A7837638B6C41597D5E2D47882B574A7F35294E556D414E761D
6E93386845A45A62864455766F554D4C3B7E435F643779664C596A4E529B538444918935
826D58856A8886502C988C41A0383868A08046516C2993B78D2887413B8F62747D678690
4679568E4D4647CF6251748D2D45B69E784DA2415DC99E72BBBB3D665C2E33643DAE8155
A87F214B7F353771176390A0814A2F654E493C93978C3F736760377F694F70AD2242A572
623EA4723258846B275AA83433886E2AA61C359B9B5B869A791D246B805249899247548C
5A1B4F7A774C2E5C13377364346651174E74507ECF5A1F3C6A876A213169391787AC8A52
5FA98E5A6C6D95732F3DCED5D3D39EC6C69E84734033293283BBCEE9DF9BABC599977B94
A6C1BE7F8F7847396B8E836266A68A7F883C2F121755402B283348100D0D0E0D0E1C2477
436A7B75D4C6A47A6C6D6C6D6C5743322F7EC8AFDCACA4CA7F311D1C202E6664AD7AB852
275A67749B5F392546605A4F2869CEAD8D868E89A5939C98C4BD9BB7BC8B171310101215
17526A3A6C6158CA9D7089C9A2C7DBC0547A4819171C1E1F33763C327E436F6338181515
15151315151515162E915424377785D6AEAA68353A68623AE0D79196C0E7E0A26C437EC0
776E7386B1E0C692CF6AB78D211E4DB3BD4B4280671D1C1F572867AB67DFE0B8D8D56784
CB2C39726042442A227E5E9965414C903A1C1C1E2222326F9178AE6E5F6491CC83537CA1
8446424C7A553C578AA4C19CACD4DAD0B344719E8577A87D7A7C615D
C85F7E804E864B698195455B5D63A33E9485396B3C847041628A79474C432382705E7442
408F8C565F452F3E5F3129506E3C474C27495E395848375B9A4A386B4C4A85875B409339
1D4F7A5E40746C30625A407D385D936D3D5E7B5638848E315347882C19534B4135575541
6D7E2C54276A605B7D296D7B5F53583531813E6349216D6347556D433D7A497529576B3C
94423B715185A0312A8D7C47AE2F2E3C6E485B8B46174B786D2891165EA1657077137693
6A575395374B7FCD94559AA1282D6C794D47BC753B9742328EB2313D70474A6334978A4F
B48B26336B294D78213A5075705336604A49195B6F87446A732B22615B3F6AA9746C817B
7056C18B5E5E5D4828879F4D3D683F3CAA3D3578693B9DC3A9481A6668152459784469B3
7330347A746430545A3B704A3874502F4D6B4475CC77403C5076523A409F6B2CDCBD9869
564366A17E614F84B5B9BABBBD777EB8BF7063542F20211B299BD9DBCDB8ACCAAD6E786C
6065784B4287BBDABB8E617DB7965753744A22312F82453B2421492B0E0E0E0E0E184F89
594BC8B3597E9B4C3522353E47507B9BA59BD8DFE299AA8347453827241F2C5796AAB372
2130351329688F8A5B587F7C4E96876E3E42477672677D8782A2A4A96553491311111311
30756C5A8CA4AD9B495E7959505AAE9E6877451A1B1D1F3735822D283F536D5419151515
1314131415151518214DBA393F83CDD8D57062777D502E54E0DD7447338CABB3C8AB6BA2
261618193394396C901F5CB06A2A2E7CD08F5AAE4D1D26619695CD8972CAD1D9BE456636
59261A1D4F7F45437C9B8F9B684C84541E1B1C1D1D222752A6719583404DA6A67E394878
D9D8CEC5C6BA9E929C9F76669CD3E4DBD6868BDAD0DBC15640405581
D455597F69BB85748BAB4776864E75388E6F6C92358A7340408D7C537151174B5274903B
225E3A49816C3518525A222544185B773D2F3F3D9A5C2E33783B4E782E27495E4A43A441
2B1E4D643A877022384F366F332D677D3C5E7E5021497E35515975521D5D57242F816643
82793668417D516D813759545764835C4375327C763E73274275737153733F8048603042
9E7861601E64915C2F80464596573E486C1D335C6E4160543F3FA13E397941888F4C6D6A
3C7192A95B3A44B64149809B57346F783B1C917D4E896443567C36505B226F7B558E7523
6E85403E76195F8B4C4D555A644D4987664148825A771D6B6E402D60403E95A690886946
1A66C2916568691C1B6492623C84283DA8583A985E194C5C74371B6565371D5C6B487DC3
843D3D91735E3E87725389453FAE6731717A3376D08453576A9256423CB37A3E804F4B31
2826232F6D979184C3D995A8C1A95DA7422D344856614E2F42A0D9DCE3BA9A95D4B7A3A5
6D38263D5066AACCB37F5FAB9E7D27150F1E4247708D553A332026561214111010385D80
7451B7944E506C171010101E262F393F5194D0C6C8B88F5C3C392E12131C177F8799605B
223536111315193C8AA09393A5A3A47D433A704B2E303854765A6C5B6B2F2D4421151521
4383634F4A72B2A295662B223A44619D7377411D1E231D385B514E1F365B815D1B151515
17141315151515162439C9AA55979AAE7A94AF876C7D81A6BCD46F8D9CDABF52C38E1741
4E1A18205B40339F471A2550A6A14B47D2D2C4D95A89ABBFA4D7BF7CA3623A8675151739
2C561D1719379C78BAC0C7A957747C29191C1D1C1E1E22427371967C457E9970817A3B55
CFA588958FB0726F6B80ACC3D9E3E4D6B69ED0E4B4D1943D5D81978D
BF5C8B635DA18B9CA9515FAB9F657250AD543E513995833A556024384F611A40223D695D
2D785634404C2B205E6424284E333A42373131224051343A771B476B4C2751561E4A8750
48336052327D8E554B413885456C917F5290BA782B518822405167561C5A52442B454D47
7C6F246E4D642D5A8C3E547E2E3248544279274D603C6F55404C5F765A81457353627134
78705862529C8D4A317E5C359A5752687C5C2F686E529C9A551C7D5240752B477A679571
3E3E408A723945B85F4A707F42366C705D2AAB6263A36D5593AA4860602C28544A9F745F
82682D3D692D5475385361676B1A387F785750915E80258DA943326B3845AEA177887554
3C4CBD6B52BBA9571E4F8845377E533582513F9E9F4C828283331B6B613E2567503399BC
5A2B51914A27345F2A4A823F206045287E822866C495655C7AB06B3561C07E416B4E412E
2826211E1D2145AD97A36255616B537C1A14110F10132558B099A891C9756566BD6D6B82
A0B6925A3A90A088924EA9908772130E0E0F1025829B783B4A251B35271513132F45483F
3C6E95AF856C411A151725374941393C498DD5DE978FB6825E565051627699B1A9524657
2E373D151415151324476194BFC19E893B6768302015151532586C67763E202151393848
4B8F6C63659AA3555A401D1C283C4A7C787C422A2A25285028154249405E726F32151517
161311121313101B202F98D5BBD4DCA0B5B37DA26E5B5E3FC6CF91887CA9DF4B608B1919
671D1D43371B2189201C1C2046B0DA9095E6CEDCCF936B8581C2B7B18D381A707A181517
2131451715192EACD3BFBFC1918A451A1C1D1C1C1D2021415D707A8D5C9C33576C99888C
85392B4AADBEC382A9CACFD8B297DED5B06E82A4CCE4BCA09485685E
BD516D756388578793734566657E7833855B4B59236F7D355592762E4369256E6E776D5C
4F947E4A434B321D675B203248334D4E3F374B294D55363E923A3668572A53733C4D8E39
283955613853614056382852367A8671293F56581F5A7E293955593B376966644272723A
60782C654698715D8443647F5E5E52654A8B3B695D45927E435179716A864D7F5D958D3A
84576F9158C28B364C926C3C98314D66927126635B2A52776B2A9753607D4A608C75AD7C
4E6158B3954D5DCB6B61818D3C426E7C4433B6764D7D3E58927C2D717236436747AC8B5E
A8812C577943887D24618A9A7C52426644474DA18A921A4662573A7E291C547D56839175
4C83D1753C53624E21629B3238854E3D8F4B66BC9C489AAC9A312F82573947805D3684CE
613239706263335B443F774A3775331B5E643046B87D4773B1B05620288944219750352E
2A251F1D201C1A6F40445F394B6D9B411715111111100E195D9D6133561B2443755F210F
11203B779FA0AE699ED6C775244D2D100E101110268C7B60643E1B1F4F130E2C44442913
176485B7888D566175798A95A9A19B918E8BACCA5D71CAD8B2908C82757DAED7571D4552
3E374515131413151516483AABBDC4B3562121151515171515273A7DB68A414247796360
7B6681525A82825E56562D1D1D22376A94A76C3F1F1E4F26131517736C636160471F1817
1011150E0E111018203CAC9843B4E7AE581B1B1C19181637CD71573324349FB54E792115
605645351F1E2756201D1C1C1F379DDFB8DFDDE37A3E335B4CB0CEAEA61B17718F151114
1C274544191D1B4B9FC0C3CACE7625191B1B1C1C1E1F23406C6B809CA9301F2D7AA4BC63
5F33374B6199E0D8D6C3A58288BDB0A6E0DFD7A1CADFCC8579665039
C956887A8CB15C638472659F60567B39885B6B8233856744788C673651351F524F6F562C
3C6D634B4D4131266D2D234851284B561C425126543E306E9B3C386945355D8C4859863A
373C566946655E3F6A49386C3977AB683C696F563F8E81364560673C1B52655B41948364
447436642E7D5C576A357368527686504F7A42823C2D77464577973D5A6E597D3E557359
9A54416141A798452D84585BAD4B394F793F24706D4567604B4291385B784A796B2C7569
4B579DB5593766AC5E82B9A5473360875731B4774F7B5D456E522E4240386D743D9F7445
A86B2A284D36A6663A3B52536431479589542C65798130849A3831744D40968F4F77506B
5C69C77E69AD9B4E246A8437216C41537A2F338B572E7A8A8238195E4B33215B3B3DA0C6
5C26378E303176733741753E38B23F225A702D3FB7945C616688372A62AE783C9A7A3B2D
26221F1F1D1C1C56403F47445590D2301D1515141515111A804D3A333A19193E5C1F1910
0E0F0E1149C2C2D0DED5A21A191C5568372A181313864344706A38266C312E584E170F0D
3A324097DBBCA274503C30241F1B17131215409BC1C5B8BA97493C312A54A0D657413F4B
503546121315121513151E50667B8A5F161217151314151515174B4964A695597DC28247
322C2E225B5C212460415E53413A366E7ED9B24A263F7C130E15176F86CBA85356391715
111011101115141D2B5CD5CC98BBDC53151615191F1A197B81263B271D27608FA75F3C1A
5A413D5B5B5566906761443B45465797DBE0E9E48F33283889BFC37894181B86B1251514
1929273C40282E736D8BC3D4D13B1A1A191C1C1D201E1F3E7861A6C790251E2584D8D7CA
8056594A4880CD9AA38FA19BBAD28288C6E0BF9889A8A92723262322
C356866D67AD5A678360527F716D78619E385675348B38365E85736B83621D50387B8B4A
3E8849526D603A145F4E1D2B381A5D682D383849824C25427B2F396027365F6E39628033
26516153366C642C4E442781355391623A65614B1F5A5E3145715C421E5E6547238C714E
386434713F67427681345A453056606B446D2D5F49357463364C62617F5B4D8754524563
A46D54532D8D8F4739824E3B8F4D404D672C1454563D7F74482D8243475A386855449A45
2635726052365CB7435D8B95453F8FA35D38BD7958A675518A522D475230366F50947A4C
AD662F27453EAE48434D746365524582714B5172537E296772442B7F5639808673858D93
7D3EC85B398B8B662E61824D3C77533E45473CA18B3E747E7A392C9360412E5033226CC6
4724366D4A2F22544242622C36AD542351691723A68E558081883E1D447D6735718B5632
2A222324201C1C46493D3C92BCDADB66301916151515144E81444341251C1A52611B2913
0E0E0E0E1379625BC2987C1B27133541151E2D30288B5436325B89AF8D9FAD672D100E1F
3F333583557A661E19181215291E191715197E94DAA3626BC46647423A6CADA052484E4F
5A454015131515131314153B705993702713171515141515171545915B64639BD2C24D16
161719344837171B224412284A7593A0BFBC84829A836C4C494D5C8BA4BCC06D51411714
0F11101414151835468FD2E7B48CBA662715171F191725A4311D3D402321525388997038
4F1E361E151729461B1D263347709EC9D8E4E7F0E4DFD0BFD4DE7F4B801D53C1B4A44215
151E3031505F6F6F625F4C8EA24322221C1C1E273422213A7E519DAC755F2C359AB9DAB7
B5B9A49BA5BCB8A58C5A51518BCAB4C4C9C1555A334FB56021212226
C155977E9ABD5A789A955A9F8A69764383446459429E54435F533D3B505B1E443D5F763F
3C8656463C3B40246659182B4531404A212E2D345B441E547A285F6940274A5A3A7F933E
37394E32358467385A39275B33798855449B8A4B2267442A5A7451352569745323945C37
3B702B5F3B54435D6D2D513E3D5354664D77345426327257384C4F587654767E5A5F6E69
98544F3B29C686323D7D4345903F465C6A3833696D3C8E8C4F388C4059593F6C4949AB47
46599956493D67BA68708AA65469CBBA7437CB5287B26866885C2E45633D4D6A43945C5C
AA473032504DBE413785C4CF7B46487E71405076578432805B41288E5A5178702E6F6B88
803DB5705973705C2C596E2133785B3D75366BC28A45677B7E33367A603C2F41313E7BCE
6726354F5A452B6D64425331218E2A194F5C3B38918F48807A794C3261927B34C8827B36
291D201F1D1B1C3F633F89C5A8C494B9A76D3B211515229152573D491E1E1E212E2F3415
150E0E0E116A48239D717C363A11342B0E1319345AC892777594877690ADB677270D0D49
292F467A27578B524F3F2723534C41412E653031A79C423D5B20212623192743A34C4D78
7D5A501A1513151515141521A69D67A44E201C17151515151A1F7953525F26648D8F2B17
17182D4E4E19151715422D1310132971DFBDD1BC5C1B191D1D242F3069BABD597B66501C
0E1312172933334F82BFD2AB665A6D5B47171615171837731A152D523626506C91699379
30341715151752211D1B181C191E524DD0E7DBE6B1ACC7DCE4D0343B6E68C25921579B74
2F1B323C51809835615E4F67A7C9A48C6C392A416F525B5FA398CE66383C859B8776A457
3E4C4D4A5CB9B98E96A5AAADCD9194BDBCA03B6254408EC14D232525
BC60B76E8D95518BAF8B619987718054A5425A603A965E4565916942555B1D4D536F6938
3A94694941314723635A1B2F472A444E2B313B31493B225A963535603D234A4A26617B59
3E414E4A4E78613C5B353260277D85622B545E59236C4A3643744928264E644823A64A2B
4A6B2E63496947627A2D51444A4F59585E80355923416D4F35495648795B8D655B776C80
944C6F5635C98C3C428C533C8C3B47596E362F72695067744A388F468D8647744D51CB7B
516996473A4094C35C7491953769C78F4C37C45E5888666179505D526243586A44A45F6F
B74E24565249A12C2C3D596270564B7178484AAAB382379C5D344EA25341628250475189
8045854D6586816F2B585D522F62633456323B9F803C5A5F853B1D6E704129444D418DD0
761F347C77473064463E48252F99342250746D3E8B8B458B766F382188B08231BCC37459
3725221F1C1B1B349B989053253D4448648CAC9F8066AC884D53483D2224210E14315317
100F100E1370481B94B4A7B45E4F687E564A3C434E8D989F8C9D9A94A3A4773C240F2349
2C39744327671311182B394455717ACABB3D192955A5997C4226221E231D26458B696065
889C851D1313151415151927C9BE8FBE9C8469573A353437415AA25D7197699D7C721715
1517554225141415152246140E10133FD9A3A47F3F1E2228342F2B346ADE6F8350767353
303D3A31263367737497D7898085518B58231517161946261515162C4B364D8893B57CB6
2E1715151B33711C19181A17191D2D4496D093CF714C85CBB1D54973B9CA411015151F64
83633424273860245E3C5596C2644E7D98B2B297B3B1B6A5D8CCB43B204196936C987038
4E4A4B5F92A638415054516896734864957B225B6B4F5BD5C8823E3A
B252A37896AD5466A47E617346898053924E8C764F9D46628A8E603F5E581F5F53636A32
3EA35F47402C5736712D2C5A66313D5025484432463E28859A3336664121515F306E7C53
3F4A67634F8452365D443C681E72A4582D6F773E2D8C533943733D2B254D7B5326945732
3C6A2B5B356736616128533B3353465A59673150373E6645314969667943736E6F5C737B
6B4B504E3ECC8D415D9D5E3A864C47516020237F634B6A803E387C44617140732932A177
5B739B622151AEBA678E8694548AD18E5344C4707998645D785439776F45538078D5A86B
BC7B26463A458D2A3B4D7079593943605C2F315B657E378C54392E7B3247566E52484E55
5640573D6C9074672C546667337566284F595AC58536474F8C46257E65372544424F8ECB
6A1B338B80503B6A4A3942313982573E417F8238808C41938D86402A98B47931959BC994
592D231E1D1C2365D06F2D282E1D1C434928313F70AEDE6E474E4D2E2D161314181E3B2C
10100E0F179C581C8DE0DEBC825F424E282321312233536A729CAC95839571312D297668
42559825592F0E0D0E0E0E12212E3775831B173743717E6448393A3C313A323F717F6A98
8F84C46937232021252D5C6BCFAE75B2A0A35F87A79262545A6AABA58B9E7AADBA771715
1544393F131215151417344015234572C9D2A4A56E476045393F496B6377B293885A7DA7
632D2E565B4F3721538CE29B7A8390CA5134171A191A52151515151A374B4D8D92B35074
1D171722507C561D1D181B1B1B223855B6821F85921E297778CEC1D29978221114151517
25689587603F53565D3E7483D789666F7579A2BBC5B77059C0CEB22B1E254298C7A06252
324C6B9D9F3D4A4028262A33478C4A629783212E5F7253B5A296A45E
C657B875B5B9597CBA816D97787F7771873B65666B9746366A885241622F3E90435E5622
4B92503E434259234E5218353B2B41461D36273B49351A63732435602E347667327C7B43
2D4653553D76594164474E65407CA45828726B672471403A4078512B2C4C7F584D8E4C37
476F326749502D696D293B262E5B5B586A5A30593C405336426B7461783985806F503F6A
614C572B37D37A34477E41367E4750475D1F21956B4C6570393F8546767E3F70484BAF61
5C689D6956439EAF5F8D73994894D0914F6BBC6F878F4F5472483444532A40414CAC765A
A95F335254528C46485875846841465A553F407D816B278145444092454C5D863C4E4A4D
555A48446EA87F5E234354472D6A44245B605BC29D4032318445277A63342948445085C9
7024478D83574A726B43545947855C3B4F91743A83763882857F6B4AA7B63F289360B3B1
914833252C4A70709E792B252D261B1A533B2723213DC1A24B545935211515151F272D17
2B1514185ECEA14EC5DAAF451214192913100A0D0D0D4751A28153819954437F6F7492C0
A7C7C382AF26100E100E0E0E1531222C7D271646383B1C210E0E0E131111111344823F43
8BBEC8994B474A5956545558B19275A0C2BB9F7F799259424148AFB285A47B5DAE886123
2A48461B1513141515151F4C73442F32C1E793A577494983846C54354B64CE7F6A7E7E9F
957D69341B15151879B6E7BFC0D3E0E4B750171517323513151615191E657078AFAD6B73
31344F4D342134251C191C1C1C41458882531E37C133295D9EE0E06E325C351311131515
1921306098AC8FBC7955609D78CADBCDB390827F63635A97BAD9D29688858AC4D7B2982F
3548798F423432272A2E30303D744462AA832D3F6F6B84AC8A3F71B4
AE67C45281A3618C934470995E7E5679A44A6B5E66A76546707C4F587F51244D30775C25
3A913B4B5041491B4C541C3C4A2947461D3B2535542D196B68233551421D5C642F80763F
283D445040784E416C373367337899612E7467522678463C537D3E253A5583464367513F
53674A8049554784832A4B3D2E4D634C7053305449435C39344365527A48577661596D3E
734F553D4AD1813D4C7F4F31895D50436F3F32CA6B574E63395F8F447D5A41815E4BA861
3780C86B5046A2A260899D8155A0CF993964B5317EB147538641405551212C5F51AA594D
A041234C48407D333A6C707A544F485B5A484E92716831744D494987393D568939494E55
41603F366BB8794E255E564D30552D2A3D4C55C89B45422970392585512C3C5D2E3E73BD
4E19415B4D395E755E7D885241924F3678AA7D439B8F3F7B7091745DB9BD823971678DDB
A4BD897E674924171F676E2F252E1717374736332E2986CB8B5B7B1E15150E0E1525463D
87764852547A99B9BF9D7112111219481F110D0E0D0F312D5CB269595D3C3C9A72514745
A299AEB056553C160E0E0D0E13402C2B723B175E492B19240D0D0E100E0E0D0C1E318243
58BDCAB87C696970617961753D353C7C6C637C9BA6AEA588674F5B815A8DB145AB93AEB4
8255250E110E10101413155952242A32CFE2DACDBEA89174524E58402E3ED3B43755C3A9
D12D16151517192472D5BB488AA8819BA1B838181D6D1E15151715152931846CC0B2927E
6E593A261E1C1F45221A1C1F2D4B7E5F80281E247AA150BEE0DACA1E214E4F1515131515
171D1F203568A2D4B796BDDAADD1D0905C3F4076BFD2C7C5B6BBE4E0B5819DCBD5C96226
3C719F321C1D2B322E272F303C58586AB476373791A4B8B2C98088B6
9B56B062856368A4B56570754A976C6D725A81527BA16E457A65363A67493E61274F522B
53A22D344633471B513F31645C245A5D2A5935426A451F786426515D3E1D5F492D948C34
26393B3D3A8653455927396C38709C483B987B2F23852E334669221D3F5E95536C9F3C35
806C365F3F7C3B695A2C4F494D59453D7D60275D2251714F3138354291556861525B6B2B
6841534347D370394E875458A151584E792B31CC6D498B8E3641753D8956367B3041B770
3B456D4E3257BABA4D61743E3983C38A407AB8655F7F5A4B6E384E7D552546675DC1664C
AB58216245295A2D356E7A8D4F224576643F4A8B707B36A587554394513687913860773E
233D313556C48A3833846B64306A3F3C3E4055C78838897A632A298F3B1B27581C2F84BA
6B375A6F28224F6B3D4553253C984D24747F3147C19D458E77875935C6BC873A5C72548B
DDDED978281C1615151B5C603228261517452B2727284AB7CEA36B151515151D1B1F3C1D
3086B375422468CBBC846235393F3F655B4836251A473123269EABAF242A58793B7C738E
968B8088752A354D36181011151A433C84551A72571C21260E10100E100E0D0E2A46B57B
75C9D1C2A2869DB65C60623A242D6F8525445257828F5A6E6A2E47A190C4D28CB9A4AED1
B96213101415131413142C3444243F6AD9D6B585CE8A4C7F8744395A606E3B428E6E9496
6075251D1C1B2C5A99BDDBB160686850618FA93F7EBF2315161D18152B284062A296404D
4F241D171A181D825E3A425C578B5F445B1B1C1C3FD3DBA79773962C1941621614151515
13171D24253C759BC18897C375553F62865438435ED3DA89448DBAA2C69BC8CCD8C1C17F
629E381C1C212E3025242B2B4259876EA866593067B0A5C9E0D9CAD3
B95EC4608B945559A45982692B6F657D443D7041775F5C6F9E954443601C437E41614219
558B344A50254926552417364228414D164B3C2F3F1F196E732634563B2B754B184C6954
353E4D3D3360483B6B3F3B622E8BA549275A4F212D884B3F417D2B1B354C60459CC76841
74633C4C336C4075421B4F4054543D2F63522E4E1C3F593F27302F387042584B38676727
5E216B5443D3732D81A245376A1E50677D4944D4572E5A853B44602F79603D81343D7452
4A61A65531397DA76482788B508EC98239A2BE5A58875A9BAA5D2B3C65193B4157B47A4D
AE5D19544D2F422E1F59839B583A434D4A1F4DAD9E50215B553F55A94227667A1E536658
3F5624355495815B294C63292C6638345E4461D0882F5052491E369D58305384513B63BC
3D206660543C63543A42592134792A2BA187494AC1835BD2BD8724179CAC7A375D786266
D1DCC43A20191615151518516A3D311C19294A17181929918FB45519151515224A3B6B45
3D375BB0BA8FC661A3C0783925242215121A2A3F697D36171D7DDFCC562839583CAAB796
5013255763792D203455361913152360B5924DAB972D2413100E0E1313150E0F445EABBC
647793858C2B4693A7736E8A90B8DC751413213A4E57723A5E8E93BEC8D5C399A688B8CA
C178131011131413112540392D466E676E9D81928FAF9F686E764821171A15152CA5C1BD
78846E2B394C81BA9FC98EA7C58F73696257B3DDA5BA9533191D211E1D213A6EA0452537
2A342118171F2F4F38334152927553615A1C1D2046BB643D4E7E9056172E632115131513
13181D22253DBDAB935A8A691D2F2E293890925A9FC8CA474A9845436678B3D5E2B0C2CD
CE6C1C1C1D2B2D2924252729436E676F8969344A61928FD3DAA77A70
C560B27DC2A6685AA46DB2C3667C607D8E557A40866640387C8A3E37704E3F784B5D381F
457F295A5B3F46194A481F314729454B23473A2D54431773651745361A33776D2B868435
294C6D683F70401F444E3F75274F9B6430796F41246E404C6B82792F4246644160744F48
63627E60435D3C7E511F4136545B524F6B4F355233536C45364942507646A57D4A625A43
58314E363DD46F2750904A3C843A6F506C277AB5795747774872814471684A935E5A857D
655BB8776C528CA770A09F9A5591B9894CADB2655989475C945C42545B1B3C57599E7E4F
AB6F2D644E2D30443257586D57384F494A2A395B84643D61521E4B86543869883B4F5162
4662366A69938C434BBD79441D60582F811546AC8E4A6B90793829903E184473313160B9
5F223E5E4F36724C1D6D7F4A3B761C1C7B7A5269CD642A7FA08A3F17759D82365D8A5DB4
DEDDD399431B1A171C232F254969422B1E1C5A31181529873BB38D2D313B4269919AAC95
54483D365DD5BD4E6AA3936C271A191612121815185F361C42BDE4D38B58599E9390CB3E
281A150D2F5D893F1F2B586E381F4CAECBBDCED9C27D37100E101010375816131C97AADC
C0918EA0B47FA9AEC2B6B28F6766D2751F1A13152043647F5D63A7C2E0B341161A2C86A9
C5A2411311111312163D2B4B5669301A184E676DBCD3BEBAAF38231E1C1C191D1E7DADBD
A979C56C6B6F8FA2CAA3511F4199CCAFABB9CCE0CC5159896D32233D2E273C7C97401E34
214C1E171722452721274C83795A918A6D1C1E254F9D2944618872931B20603615131514
161B1F222B4AA77F9871B347242E434138267BC6C2A1938895473B44527A94D5BC79ACD3
D3411C1D202725272B262828416B61367D7F2EAFA4B1CDC58F656950
905A8B5274855352554283884C626AB585527047A2925C43825A4D66824842604E914C21
467248847734342D5D3E243433348D7D2147385C854019874E2687533B244A5F2281844A
30474C51429B6837402B45794575AD3E4B93895F2A792732404E471F46426D518296593C
4D365761414841BC7D2658334F927152704F6475414B65354D64584179457F7040714442
7A3654333DD082475FA16668B55E705D753477647C5B48582D6C7F42793A6CA2716A7C78
486AB690675A7C925FB1A58E5185A59546D8AF5E56845F806C364B464D1A43656AA46457
B87E2D574540505C33645B704D398DAA635A538185653D97623457894D3F72863B505637
162223336194662E1F59574C25643C3D9055429351309391713E288C552646642B2F67C3
7B2C5385634B6E4C31424C383E742F2896915B6DCF9F459468604D40A2C3782996C17EC1
CD9DA9C0963A221D1C1D1923245B784C2E2F818D353252AF8BD4D3B39D81655F5F544A97
413F332D2BB6B1455D422F5A70271717111115151F4B4760B9B38B8299A8C6C1833B3B54
2D2D23150E133E93632F304385A86D7EADC9B7D3C48F69492D151542532A17162E445087
BAD5D6D2DBD6BAAFC0BA4D2D17257474451B1A1A13133588D8CCCDBDC3903F2117215564
A1A352431713141540344E524220161513198170C7BEDDB579322D1F23273D6E73919C81
CEB8A4382F4881AFD2B9271C1B2D5FA0DAE0D3C1AB593E415D8E958C89799AC69C5B1C1F
30393019192B402026487A8C4E4A80B773421F3D607D343E4A708BA62B1F575314111417
1C212122326E5543AD77504D56304C60592F47AEAB4E6DBB503D42455095AA62495D57A3
A3591E21232527282D272E3B536B4433A2C78EC7D0D5C567494F86A7
AC58C2748F994E539D5D8F9E4B643D6B62584C2F66664C3A8464292B6237395630714C1A
4268233D3F2C2A1C452D1C282E2247522E3C2937594D198453185254271B2D4044AF994E
326248252D58472D23274578416783462461563B2A6F2239436E2B134D4777587C7B4A3F
514A7A5B403D2C695D1C5240475E4B395F47455B3040615A41575C325B4F8F7B49505370
7C3A565235B57F45688F376EA15667587D45786F7F664669387B533A696053954B6C786E
42347B4C3353777E5FA79A7F4C84AA883CDFA557687663A875394C39454E6967649F5E69
C583275A2D1C33392D5B60534A305F494C4F5682876432978A484E98425387973F645A34
29291A1B49926D5928926040244E32264F4343C17C487272745E2A9667224F6332307ACE
84346190665D7563654D4C463F8D2F2A9F9B5A97DBA549BCB27E382381D0AE6AD3D3C5BF
7C477286AB9053281C1B1C1B1A2B768E5F6AABCC8790BAD39CC5CEA7462D252443AFA1B3
4A311C2157D6CCAAAE231016507A2C19151515172474A7AA72552519294DC48D8E1E1528
4C363921131010339695576DA2C6ABA2A9AFA0CEB9668174726DB05C1D1E1A3168521727
C5DDDEDBC8CED9AE55821B1716151A4B5C2A1B1C1B131325BC923A4F958855391D404E48
81B4535F511D15325F5438432215151517156CA2B05BC44A506861407E75663F23194F7C
C3D1BF4C3DBFDAE5AF434D1B1617344775C797A680843E4843454E777C9AB1D3C0953B33
4A797430344149264C727039313FAFAB606A76465258674D8196A4845721516717141516
242220213C86354BA4661613317B8DA37C76A06863996D8A3532414E75BF5E1D3C407D84
A577321E1C232C3132323C47A0656983BEDABCADC4D7DC8074A79160
AD69C68C95956074B15790AF4D834A93775D83458C9A4C35909239488A3A41704F955C1C
4F783E63563D2D2A60391C3442405360313B3F485F611D8B6C1E5C711F172E5820566559
355C45593C4648293147417F4C6889452F695A382F6B1A3D466E22377E867B4C7F7A5777
8E57885A4D53397D5C234E4182774B3F5C385954314A5743546164556641887A70534A74
5354824E34CB8A5EA8A96258A5436F7265307A887862618336804B396265589738687C72
5868A046434C849284AB974C6CA5B08A4DE1AD36999A6AB19C5747443D5CBA97569B453F
A76523682C2C4420326676633F3B7F4A35325B7E87563F71684144845742827F3D535A4F
4B2C283655AF936B3FA16A432B4C4439433C37B68A3F7D7A6E4D259F442A52551B47A1C3
6F3A80A9446487684B505921338A4C2FAC812E7FC36B38A8AC81492D55B5C578C7CCD3C8
8D74454D515E7687422C24211C2136CEC2A2B0C9B28F4C9B836EC29EBB98859BC8D5D9AC
585577868A99A2417D75220E17387A2F19151A215CC9A46B411A191D21458C5243511815
334A5358272E1B1532B2D9C0AFA4AD815989C5D27A65725D447FB26931204D551B1D2861
CFE0CFA6697DA472233D1B15151514195853391C1C1015177835272A9169863F1C527F4A
5AA29C4684815144463E39491A191517161533D7B6698F4C2E218589361D17151515266A
969FDDDCC2BEBD9FD2A05E3F19171C4968715A62BAAE7D5158697E97A49197D0D4AFBBC2
CAC2B999A68E665A6B6F382A3F7132205D51A8585118391D34A6C084A15C5D94321B245F
5D5D41334CA9386CB8581013153EC3DDC5A854261B2FA49563374B80B6911E1D34534383
A36E61291D353338393B507DB59B627FC6CE6E9ACEC8A7BFC7603640
9488C4709D5F7191994B736C52B34B7B5F9E9A43AC9747429C8F3F547D357D8657934628
796E3B6352314A2B43253F784D2C51581C4F3849623232A4691B4F5B31346C6938887D67
3787806B353B3C2E624B3C643792AD634157512A5296443A568733174E484D4A8CA94E48
784BA0647C79428F46397153849153326C397646387C65437F9838627248A06A605E3698
4832563538C786396C945388AE294D896B3A9EAF44549B883A8F5869988F529E478AC59F
6970A3483870999F8EB7AD69528C9B4058B6903A628259BFAD4E7B785C244D7F5B967C73
B66C3AA4533F5724588EA9925A408C4732257AC1B1404E604335567E4E61A0744475825F
5B35362A39AD9B7961B390433B6255394E3C40BC8B367E836C4237A65237728B392E6FBD
2C1A527E49483447183F824D3677172184874B8DD33F2375806330253555A53ECAD4E1C1
A7A6714F4F4F50607786674E3D416DD1A68C92C65B331B2377C0C6B0A7C7A078606FA19D
AB7059442122893B3745611F14155A863731439AB2917354303229263B23255754404A1B
244C554C201F302A185FC698A1B6C8C1B88C3B265F73546778B79FA3A89E67153C558C5B
3FB0515F2F223679451F2C17151213151E715E222219151D7C3721227D51339C3347AE88
4D98D49791945A564C3B3B331616151715172ED9D984769538215E331715151515173F51
7F7DE1E7B7865A4F807B868255281C336E57544092DAD7C1B3BABABCC6B8B2DBE7D8A67A
6C828A7187B4C3CD8A4A364655261B192A587A6C30161B1D1D369690AD8171B06A334728
244177A6BCB598A8C72F141517166CC6973E1A1A1A1E37999D79B0ADA761251B29604F62
7FA6854A348D78555F659D9354476FA56AD08BB99D735868A4393B43
A66D8C71B9896B67794EACAA5AA1417D42757F43BA5E5560735F40626F28545B458E3F20
6957478F59332B313831224428317F5C223F28697E30197D441854422535546631898324
1F5C4E504162363632234A5A356CAD4D628D6C2B276D253C5D7F58196353493550675459
64266A60654A208C631F561549676B4C61234D703F54422337585E5653396C6E6A431C9B
6E415931299594476E8F283F804E5C64722E655C5E415D35278E4D3D633D6AA746667654
3578A28B4A4F8F4243678B6A5C9B938B7FA384447569236F925C355D59297A49639C6776
B4412A815E5B995330566F665D49AF84423A4655855B58754C226080486CAC6822466145
5B7C6E5B61A97F3173C98E4724656B3D7F2468B77F4BB3C5853D1D8F3217425C3A3986CC
6321497B565F36573C2B554C3866291F85915B90DA7A3F9E937B392E6E7C8749DDD0C1C7
AFB8B3867C7A5F524E638DA98CA7D2C179499EDA763F70734A9FC9C4C6C2C2A6998496A8
9A5E3B2D251E4AA3714C436D271762D2A1B9D0A486597455596566751D1716455A254566
2E28605E3C1A1E3651637F31596A88CD500C0A0A11396D6155B3C6B9C1D58291D894311D
1B7A1B444E23244A74292F1D15151515152A7F4021271D385C301E21914B16A5B6714CB6
92A1CCD5687AB89F4B427D1B17151615234CA3E7E9B8A4BC5144502A19151415151C2442
30B7D9D58E353F3D4265503F5F7666418A5D5B4D5CC7C68A7F695F546F5373D7D6AE7F63
484A4042687CB5D59C4C635D191A191918436C634A151F1D1C26358682AD82C1DC8F6B6D
75819298917296BFAB171313151E7756331516151A1B2D48A871361F34522E1C2E859FA7
819786764F95B67B748777547087B17E62D8A58DA88D707292462A3F
9B8E974E8782726340337B895F69399155704D368E77432F4C2B2F47772E622E245B4629
744A254A4D3326324425226424173A51363C1735574820A724126170282E42311C576643
1D683910357845423E104269416CA1172D3E4B32286E152C376F1C186555615458625460
584585457163357D521F614E72523335713A60633D547F4742596A67774F85686D523BA4
633B6F7A3D90863F72A15353905874598547716C64425B4F28754A457246396E5B867B6C
3C5C8256344C895B7F8B9D6E44BE9E8090B1904067765967814B454B2D4AA74B558F375C
9D522B952B355F3035557F5F34326270576051769B374B957A3B597A19428D7B434F591D
38334935669F7B5245B56B503667274A8F5B38B24F19507172581D924323505B1A398BCF
7A284387555D3B60632E52603C713121857B4294D97740987F5A2E1F9B774755D4D4C699
91B8A26C3D3635446C8C78ADC3D7CBDAD2D5917BAEA8D1C6A2C1CEBBD0C0C1B4896F838C
7F594C3729293A392F4156679C9B9D694393A79C8376664F2F333B4F341D153753423466
8344429B3B1E1E345DA364837A7A418E190D0D0E0D0E1A6087B5BDDBD3CAB2A1D0390E10
19541D1C3B39242B69522938161517151316368238272C604D251F2F9042184F1A2F414D
C4CBBEDA9F6F83B35D7A622A1D1F284593B891BCE1C8BABB8C7E30202315181617263333
2197C0E5A13B29353D4E5F644F363E8A9A66697C9CCB5123394347579DB4AEAAD1BB8C89
9E897D9BB8825FB3C68D5C1A15171715171744485C151B261F22284086BCCAD6D3996B56
47435675797DAAD1BE2A15172565C9932F171B1B1B1F2F505F191C1F2A5427204A487781
9085AB9FA2BC8477778697A0AEB5B757AEC5BA91BB9AB6CCAE6E3574
8C729B6699899577924A8B9A669C3AA04B578540928C4C31997A31508F2E61884D804125
8065435D50322D2641261F4C3D334A5129462E49524621A54C1649582830285E376B5930
1A593C503C4A35382D20474F476C782D44403D192B611A313A6C1B2689725C46615A4E8E
5744912F715E2F834526574260511F37763B6C424B73653D3C4C377D674B774869432A8F
395B86542D9678539F99455A88418B8777465E6A58729657276C3C466E4C5198558F7774
537FB549324A8769848EA3604DA2A97694A88349A16B606E9F60415D4318525A6DA9424E
984B329D353F581A3E56895432357749213449819751507370426296585E9E8C454F5E43
53475D455FB093543EC45C4C43573F34484F38BE93475F707B741D7D42284C5F223C8ACF
6E334274506240655B3558483672241F756D4494CF7941926541421570747449C5B6986E
425DB1B2856E65695A55678DD2D3D38CAFCA401C4BBE79403F486699BAC8C3954E35282C
6667534E4B483534311E1C2182BD894F43874B78392C604F2320193B3A3115175B4D504C
64AB8FBB78373392BDAC71C0CF434170120F0D0D0E0E0E1253D5DBCBAF979F286D381111
15481D1A185C2C2141884E322E1516131519176F6A3E3C8E3A2D323A93372F1A0E13273B
89E4B85380B68FA7BB6D72523F427BAC81371A546AC9B6C6DB922A1D291F181919203C1B
1D8FA9DAC98D37212B304B6365645A6C79B4C5C2ACBC4945535F80AFD3B95B92C1D0A78F
8B7B8787B2B386C0BEA7281E1A131515171216585125193024262934ACC4DCC7B1664E55
5655443746ADD5D096925363848CB7BF4A161C1B1D202740511B1D1D276C31363F474D78
757296C585BDBFB59C8B7D5D9CC8BA98BE846B98BA3748415CCAA36E
A084BB62875176908049878E73A3368D48739A4894825B578D6E385552317877417E303A
94584F5C4F3A442C362C41773831474D28483158735A22AA52194F582722225F39615843
1D5747574548373A352F4D6055919A3B4A3F421E4A7F26303C85192A4F56504B6256335F
553C912C8C663583353E6A495F4A2E396E326B463857683A3C504B64503F66665F482880
3A474E2E1D845D397F8A45738925626C49338E863649705327884C728F675E8E61AA9885
6B70B26E3D4FA37A8AACA7497BAA8843A3C97A328A5E5766A564446146296D6E6D986685
BF5C34A83F40662B5482B48640377C441A355781943E6C734F3657955C7CA67D4F65735F
6B496B3D70CB9D523EC65D5D484E41543A4236C59139626C72611C75412849711F49A4BA
613B5A89345D686E572C4B1C39823A25894B3AA4C06D3D816A585F1C4E8CD150C0AC9669
44386ED2C7958C877D8579678AD2CB8038697F4E339B40231C1C2F4168B9C4934C2D221E
2D69764735304E5E3D20224E65792410123E325C572B4E57472A2544253F4131465B545F
6B7FBCA6767DA9BC4288A16597334A5F0D0E0D101013130E378F675138406C1A3846110E
13432421103C461D236579468043271C1715152C7C8F63832A323D3F98392C0E0E1B1515
54B2AF403852ABD5DED0A996CADE9738151515433E70BCC4CBC8421F254719151D2C2F17
45CEC69A8EA295683E344376979993C0BEC3A5643F741B151B2F63B5786242ABA7AAC57B
636D4F4C7FCBA7D0C9784E1E170F1515191513325C571A282637627A9AD4E2B38971524E
444C5569B8DBBBA7556CC284361F31A16925191C1D212E404F1C1E20296C473C464B5845
576E7BD2D9B5C0BCAA809995CCB2C4BF5A5E667FBA50403967BC2D22
A384B080B485514E744A8B546F812E6842A37D3E883E3B396C5D346185206D83486E351C
674A66803C252E352313284B2B475E4F244B2C5875333DAE471952403A44625E37665F35
2F7C63504750273F403766573561923D473F4219355C2D2D3C7B2D195B60495C8E8A4E65
573B9A5074583E94442E6C4F6C52494F773E876846654741678956594A519B69795D2D9F
4E6755422387793D74782287A64886734D33457551536F2627AF3F4B7440769248A19D7D
538FCC6A2B4A6F3F6BA198505ABD88369E60733087313F9DAB4F7569352D6A5D72865078
BF4137A1493D75253F5065735034814E253F9AB1B544615F482F7D71407AAE4F4C846F4F
525C8B3A578B6B453DC3503C6E7854514F483BC58135617259372A83382E6C78213274BF
34489B823A3D2F4C1C276C54337012269C804394A83A3B846F42602F46368A37C8CBB853
3D398CBAB65534281D19161617A466806939476EA1B45320181A4247246A979D985D3429
21339291797083806C547C9B5658151919374E557D3B39153077737465455D695F794957
5A4D4D641B2067A93A9F3F204F52673F0D0E0E0F0E10101238603D25313D79473C591714
155447301841A23F1E339D9576624C433E3B353C55BE918B65644433AD741B1517303242
95BE9416213C8B78D24D4526AA701B171B272F626F894DC6CACF8B331E262C192D36203A
6FDA75347F919B94AF9BA69A68434B73B4B489323A621515151D416E626E47B89894AAC6
979A837A81B3E5C2A57C70391E10131A130F111763733D29244B99A9C8C3E5E0C4B0A79B
9C969BD0E4E3B0A7BCAE79A3A8532C7E697F291C1C222C4A491C21293E885D4B47482B1D
266091CADCCEB9968A7A74BBDDC8B3882C283148708A3F3D638C1F28
9C8A6E5CAC724B473C5FB48E805F4EA646776F57A775423B5B4053738D236A3232713E28
86263558503A20454F1E3254182D55612B33255F893D1D84243474401D1C37532F6F5E22
1B4934374963343C26297A5F547570365D50411B3D6C203D4D73281F61611F486A6C4163
4D3F71316C30218E49335F1B5259524A5426786142634030476F4654443570686C283DA7
556D612B3CA9925078752D697D3975716C564B5A5C4E632D1C984E4B611573915B936C37
1674A469323B633F6781766164C2A96CCA537C3C8438294C843E3152353F7C62949D517A
C346318E2A5EA0333B538E683F3AA167212C616B9156546C5D2C4B5D3E81AD66465B591E
5677996D7A7D5B1B5FBD6A4A3F683E4E633245A773427D9D6D401B6633254C70343F83CA
4835787D464540542F245B4D377C2322767A4AA2B81E228098773A1D575A6733B8B2B85B
46757FB350271F202322211E19536850616C382F81C6562C1A1F371B154D612D75B2BB6F
4D5A8F958382809B879CB3B96F7B1B1F1D225B56806D4631392D2B2F405A5D5D2A4E674C
665D4E461C1C4CB1CEB97D3D508D9A40140E0D0D100E0E135662512A384B875970863635
387B6D5441445E9B5455A2C18C47392B262C2D50669EC59DCA5E80A5C7A8786263625D67
C6D89B1D0E12264E9D462A6DAA49383330262F839CB66D5BCCD088794C3A4E34411E426D
CBB34A293DA79455406AAC543E332C5D9E92612D4148141515152E636A504DC19C8A4E54
A9352F345383C79C537B8493331A152813111113239996314C4F91C6D1A7D9AD6D403321
1C191A87D7884F7797923F4481B2A3696A4661391E1D2D58411F27434B7A6E454F321C1F
2749C3C0CC987C3D293269CDCF9798842C2F354350965F4578502329
8597A059A17769674D48657C835426954D652F47956D3D3C59342D56862B6A7C48622F21
8854444F442E2E43311C36502F343F5A2945314B653D24A84423495231315331368C713A
1C5429215A883E46321A6B7162917A225F6A5629426C1A3D4973332D7A774C585D5D408E
52496C21945F3F762D344F2C5B441A455C35765B497C643C43583E7857447E5B8F442D88
427456221E8B715291874069682D868669654E594F7E9A48258D43405F3D748652956C61
507FB8703A40595185837A64A3CBAC69CF5E5A45AE4540508A4B44521E46864D70861A62
A75B309D2336632B4467B07E26226F843C508680AD2F67AA703753712559A9804D595120
40567B638178722D489963494A571F4E655C36AE3D1D6C898C77216C582A4A8B314682CA
5A2E6B9D5B6260735D2762463DAA3B29995145BABD5B2646576C6639514E2215C3B0AB68
967E8D7F2C261D1C1D1C1C1D1D2A6B403A5A633A43A27347212A37171554491B37747E39
362F2B4565514A4456948688AD8D692E2D2949739490663E211C1C181B3B3F64382B5171
6EB0A469789BD0B5BDC9A6B28E6CB57C6159433427171827AE76A74F5168713E507D211D
18558B35322E253EA2A78BA6AB5B2920202421274987DBDCC9DB8A7D9F4B3E46322D45B8
EAE9B17014101549846E6CCC4F1D222329221D748436294C7AE0AE6C7B7A7D421E4A7996
819C592B3C4D21713320368967555B91C6965B425121151514174B5188A3D1B35B494231
6F1B171515156AC37C5456815E19172F232D16191F5EC9B3D0D3C5D9CB8ED64914131213
151524B1AA3840977E876F45385E78AFA46E3F574A293B803927423E42598B4F461E1F20
387F5DA6C9B8733E6DA3A4D6C33B60612633393C47788F487A36385C
8B809E5E74508BA46C4E6C7895872B8E43757957A66D3A44906A416B8232618C5A693038
9E534A5149453B473025506A2F403F532B553041582C39A2582A54302B3D6A4D1F4E6633
33854E2F414D295C3E2F616071A27B375340421A536D1A314366152850694D5D795A345C
4B406D2487603E7E254E613A5C4D195669397A3743775E453B4A295357416A4D5652368B
326B763F308C405199893D6F632263656B6545503E47733C218C2B65825982844EACB580
68A2BB694766685E8F7F623E70BE9B6AD2806936985640548C4171712E2E65579B795C96
B5313BA043345E193E749F80422E694A25528E84A7293D69552B5C5D1F59935B678F8E59
707CB05776BB94534CAF5A53514524483E493AC16B324F707E60307B3F3E697A143F8CA6
3E2C62811D455A6966347D363681293495623799A13C43878F77413F9DA8712AC6946FD6
8D9EA9452D29211F201D1E1B1B1D583E42437354327C8A5B774D191917716F313F63441C
232A24242F604E426F868EADC292B19C707187BE8B8C5A2C1D1C1C21332B3162823145D6
CBC1B6C8C5A8678DB0BE969594CBC05B202235425E616AAEC07D7E9B9AAA5945918B6761
488DAF43452F292D76C04A51CEC98161565153588784D6CCCBC88FB96788BA8C919FD9D1
CECEA3AB4B13154E73E3E171291C1C2229251D7843181D316BCCD991A0B6993E61A86C24
5F9B523B4F231919603B395D95914CA18089A080761F1615172C7A6D3B367977313B4950
5D2B171716329DA3A28A604D641A191C2651201D3784B9D5D8A3BAE9CE72CF2B13141213
15174DC967343A5E2B757F5648343F83878B968C78888B9E3A4B46424F567A612E1E213D
7F474BABDDD5D6D494271B71B3354A4E2332363F435A9B747E417374
958FA77BB57880856350654E97752A7648AC7C63985968718E62425B4645817457522021
7F3E45422B32352F201742512F3A42412251283A593B26A74F264A492C3A59632F6B5D33
25504C3A4E541A3D3D3564474384822E604C491E5A6C22445D6D362A6161498ABA72476A
436081438A6457863C395D3D5D4D3A5E663678503476683A3C59355C4A366B6B614E2D95
505A5E3D30786B3F8C913F7578509277786A575157447438218C3937764B7A744581827F
6194B742276C7457B0BC915895C16D5BAE906746AE454F718F3D35632D4076549C9165B9
AB443BA44036632B3E57986046397F632133A7BBA94550564528796C3F5BA047445C6C2D
688FA7626566722A41AB59255F73488869354AC17D5399A6542A1D682A295D66254579AB
284378623A4847512B2B71584CA83C278A6348B9AB4523445342563D548C692ED3C5CCD1
AFBF794543271E21232521211E1A4648432D3E7529586D5357461F27464B5793B8B99561
56463C3326304C6690B9C1AFC0CAB4C6BA7C67B39E8570602F25362B1915153CC4B9CAD3
D6CBB2A161524B6CC3C5B5A8847A7586501415111519252F79C6AC9DB6D399B64D232635
3D62A15F623F3949807AAA75C6D5A07B543B342A4A8DD2B97C9C758C10246E64A7D47A37
3AAB6389B93A175098DB9F37231C191F1C1D1F8A371A181F33D5EAD7D1D5D4A3C0621B1E
63973042481615151E675A4A5177C9D34054A09297623D221A667D3429314C5F26343B77
4D4A1B1E417A454A888CB08DA22C1F262A4B271E3D77DBD3C8DDADC6CDC5CA2014131513
151C8CA12C1E41522E387B64394C539E6C456488ADCAD2D5A27A51566958636B2C307885
2E3990BADAC8BBB8B2472352BA3748412032293645517E7CAD814A50
94957690A77F99A0645A8E7FA687378741786E63983F46417F5F535A5237696A655C3227
993F635F35322F3F301D4A4F2B4557552B612E4F543027A54A2D4B3D2D33545E32805938
245340304E542B4F2A246850709F8435736E61224F621C37476A32306461424A806F4375
463E73486B45457C413C5C346D5F426E514E884E44834A5B606A40762B4F8C6C69303CA8
5B69594569AC6A479070459E8052AF9A4D6165575973A3363A893C3B762F7B9A53A89E59
3CA7B9743D796C4B79697C5099CB825C79643B5B904F386C8346477627548B49A5864185
94544ABE32496B295F90BD99473981681F2F88B1A444847342246145296FA176757A7C36
435E873E7FC19D5549AC654B4B472F75753E3BBB5030575C73651A583523475D2A59A1BA
3A1F3E572C5C8480622B50153A9136217E1B2794A556243F59413757C2CE37209FB1CED2
D6D887332E221D1F1D1C19191516393C2E21349B9E8B7B8677859351201D181A67BA96A3
87675855504537658BC3B3B8D0BCACC0B7948491A2C3B49A906B3725191B1D35CEB77F5F
688EBEC5ACB9C6D6E6C6AE473E313341725C150E1515152683B7DBD2B9B9CF985B433532
2C2740A865485482873994B3CDA77D758892917E5248BB649BCACC5010132959754E1815
1529A05ABCB12B4CCAAD6A3B211D2122294B75C68F392B2231D9DDD2D8DCE3EAC32A191E
80562548371815151D3E6D6552539CC1453BC4837E394E6389A7392B2E376E9036233345
467155735C2E2229506D67AFB7692E44376535344BA3CB95ADD8E0C5ABE4D05614131515
1845C05019184E601E1A195A563132649B3A3662A8ADCAD3CAA6ACC1A85E3F614EA45B25
3378B3B3617D692E67B4BACCD5585837212D2950636556A6D0D9B7C6
8397895F8981BAA3478DB37AAB4D5C914B602E5E9B505B57453C4A55345A7F32345E292F
9527394D5134263F3D1D4D52173D535F3253263D5330349E374F7451283152533A9F7839
28573321626E324B2436935A64B86E235B4C4D205A5417244C692F426866594C8A553483
5B49683D89673B78334F5730454B1C695F346D304676502B29432764512D573B7B432973
337C652F3F9A3F57AD73327846347A7E626A4A47474B743F2272245D7E31627C4AA4B76F
386DAC604799865EAE73454094B584788B626B4891563E575D3D7F7F29396038AF94699D
A22958AF4D2D55164252746456328651111296D29F303E675439755E2F447944598C783D
364E844B5F64824B57C9542A706F3A73423062CB8E50656C745E21552F2B446F14376CA4
35253957262B405968276B443D7C3A25876D3DA1B057244264633A3E627E681E99D1D79F
854183A450261F1C1919151515151F522E3051AA9499C6B7C8BB7619151515162A772B24
375C8792866355846CA1E2D4B8A48FB2B661515C7AB6839EA385786D636F6D96D458534C
4337947F53464959B4A97F271A151D262E4E5A2B181D4C6C5FA69CC4D5E0D69864524D52
5F71766CA4311C1D3F3F768993291C1013152A5DAFBEAF6BB1CAE0453246372C4C221715
1515569E84CCB187D597AE80645241729AB36A3775AC7A719C817A8E9BCBDAE5DF973724
962B245B3318171822201B58837FA3B18D3ECF95681E263B6A4952364565A9DE88222831
568E8845352322282C7C8097B2B18A9269ACA69ABEE5E5A19BBDDFE0DDE3C9A42015151B
2BA99921161B347C151A171A6454303173853D7297BBD1D0B7C59C8FBEB5772323481E25
58A5B0862F6E59292D354974D3AD6D261E242C444B546F8FD1DBD6D7
738F94758255638A4B525048AB61587757826E5C96486771785848472B4474583C4C222B
784A48502B443D322327564A39564A292B592536461C3A8C3E345124334E7B421E4C643B
345D5632474E3056472B654F66BE72336753401B755B172051491F34424D554C83534364
494C6B4674653865274E5D3B42512D635536694C3F7C592A3765405F5139677271493279
324D6C404BA5423B8C78388D5C5D9677668A64484559723E2975313B874E6756297E9677
4C88B43338BA87539C7E7A509AB67D75BD78695D89674B6D7E484B7D253F84568D7A5DAB
8D3B48A83E2F572B6366966D52398855353F6DB0A34E41562F30706A3A537F5D6B636C3B
3755725F86789B614FCC5A32514E3A7939193DB782446B7932173A76542D436A264D76AA
3329436340484E585F38854C47803928876A41A4AC4A21404F49575298947C2465A18974
763C3D4D8B732E1D191615161A374F818D9F66383C5D8763806E54201915161B206B292E
25201E26386383A6C6E4E2CA584D4C6B904934313ABBB67CB191829282736F92C17F4C28
234774231515133958AE7C201C1D182224243D6C767462476082B1B9CB916B819A867062
64585C206C742B1E414173B93E161C14121111101C75CDBBB1ABC9CA3D19141526442416
19151763A6C6DCDFD5C3BB918E937D804722151515327185A526787298C977D2889BBFA2
B01F36B65B4B2D2131342A2F4A9377B0BBB8E1CC4D1D263B42255075688C91CCC2653234
6D9B5C4A372E40482F76A1B9567EC3CBD4D4CFCFD7D9CA7F97959ED4E6E9E9C36F4A4B50
68CA43354D7FB6BE1B16151719685D2F3AA6A5A3B4AEC6C9CAB5CC84C1BD7D837975414D
AA9FB934446F54272C313A3D72C8A7292B3139454C6B907ABA5F3A36
8F98708CA4877F74549B9B54A27A763D47875F6D7D3F4C729474646F4455695367733722
7D307461263F32351B1C4133294C5E3B2C5D294B512A37893A35502D1B33565B2A5B692B
33494B34767223353F3FAC4746947D438C894C1B584C21335B4736473F59585693644A5C
33728157722E5C703E59474083623471535F904D4260466B7D77456C2F607C7678315397
436E6C4977BB64419D7C42A160838D7825718E6B496E7333609237426F3E7B9E419C7E74
4A8CAD7275CE945AAD8E814EA0BB456FB9A675657751689264495C7B255A9E5B9E5A4EC9
913F4FA3405F6F30746E946D5153A7A325568AC8973D4957593F6F664552897270666D28
2F546E49897F866040D6683B6B573A6E4A4A6CC9773B738D5B2E285E1F2A4B5F225673A2
2C4E876938475452174975453F71244D7A5F3EA7A63C22434C4C5C567D566A473A578783
7D3F414545487556251D3343403631403C3F584F5050757A4B5A6B421D1A17191F653425
2B30331F1C1D2D7389CFCCB453393F487A47624044B7A681B7BA5E466198B6A58CBE671F
296E39152A1F2C542A80D1411C1D1D1B27363956C568638F929CB3508325303D3F547083
767D6E4E41BC6B476050B69D3A1A1A151412141116794230637179961E1515162D2F4533
1A1A1B1FB2D5D9E1E1DBC9906E38221713151515181925968989CED3C7CE36AF4A2A315F
B75C986D5E7C6561716A655E555B9C9CD6DCE7D88223365C4D526E7E814A3552B9939165
866B4860454D48587046689C7D6386C0E7C7A090B39AA8B0AA84613ED5E0EAE0D0958D8A
C9955156424A81704E191517161E69533EA4BA6F617DDAD4A482B3DBD1A26E5D6371B2BC
9FB44F314D773C26252D3C484974CF64273237444C80938D88221C23
8E9761699B7E7469404F6B5E8D4D93774772468E9C6050783339576636644E173F512F26
6F1333554F4F1E5C431D4239226E785131443B856E2D3D80376F6C341F39555B2B687141
353C2E103E573541232873576CAF6C1946635E1D643D153B79482B483E46377F936D4153
3B4B685066383D633A5B451E3E5F417441387F4540744F32465E3D5A3C41716C6523377D
4C68561D66B25E3CA74E4AB57C81906C4A715E473C7C6A273A7C3341602144793C8A7133
4BA2AB648DD37D55CCBA8350AAB34839597C606E6022639A5B4A694A275B9A52AA4A428D
7B414E92255B7133686685703634848D506D86D2943882704B4575613A4D8F7E6D667434
3484985D856C71345ADA4F2F6D524B9D5A5272C47754BCC95D352E7E1C41A6782857769C
1B47734F30434C4E5B36734E446734255F5335A3B2343075907B5D426A484B3B3D43966E
89402F2D3837395687573423241D1D231A151D4562589399734D57832E1B17181E7D4F23
2320242C262F595159D58C666D5C423F6E6E5D423862A2AD654481BC6E342B2D4A7CA57F
8186150E15245B2F2F44DABE56211F1F1B1B2B4EBC9D88493774485C7D25241E191B1D35
5273869AA1E1CCC1B4C6B06F381A1C191512151C61B6231C1E6BAC806417131629213795
8D615C53B4DFE1DEDBB68D4F65858675442A1915172877292631865CA9C937847C383448
9BBD8574724E3D33312622211E1F266ADDEAEAE6A753A58C8082725936372D2F65C28EB9
CC4C3D704D57675E548672342F629CD4CAD1B1BFB9C6BB704239465AB4C1C6D7DAAC7B8A
AE762627334C6A495F4B171515161CA3A5B58581ACD7E2DDD38D62DBA8AA954D568ADDD4
C990274E767B3521252835484D5CCBC582463D4356A09DA49C394770
8AA48C84B1715A7B546E996C84529C7A57582167864B497C5747415C3469764A87873725
733F4F5C4C452C483B1C403F263557552C4E2A45592C3D7E23355F461B3C562813317042
3230242253592C40193A7D4E6AB753216E57411E663111184E47214C3C401D696D643D50
44635B5D77543F36335F43394452235C533E703F406F564A4C7349512859796352274076
3E6970445DB94C3F9C4230A64A8B974A61A76D253192633B4A593353854F5C86438D674A
3A69995A9ADA3A2F858C5C5BB1BC6D7C56826F7571565885544F6C672849934EA57B70BF
964F4F932B404D1F625A6A4C4126826823527ED893284E765641744E3A759C66655B7E21
344F73647774703643BC6333524030684F4462C25B3260756043349C2B26445C314E7F9A
314D935C243F445060405C38568835326D272899A7401F3A45403F355F4A56353A3DA871
B553362D2A303F4A974A261B15141315171515152866A2ACA3648496852E1B1C21A38F37
261F1D22212C515984B84B73225A7E778C56596F7770619D7C3E36364C12100E101931A3
DD6D121017213D1D26687A46796D2F1A1B17152CBE3D343544672F9A7B2625301919191C
2D333736366D8F8DD3E7855B4D1819191C1D2C44AC991E243C4A949F9E69513C43505B5B
5A61674580ABCED6D6BD6A3B34373D40566D796033612D15151530807ACEA86AC29780AD
A87A7D897E82747D633E2A2D2F231F34D1E7E9E9E9E7C28B433B1725673F31314487BCA1
C5AE6A8F876C787584B33C1C1C1C429785C7D5B2B2702F241F1F374880AEBFE7CF6F3A34
3FA4343333574E3930555C28191C1A4EDFD5D2C8AC8EA4D1C3C7D4CD4D73AB976470CCD9
DCA98362A9B63A25292530384D96D7D3D7B16E5784C5B5C7CF906C47
789E7F80A6646096536DA1639E86BC7C4F785B709C5B4D909171526A34688C559B90382C
6C354A5D3D3F322B201D403B385163593654415875343E87463E583919335B5A27366339
333C392E6F63323C31407B5B63A0532376573F21642E151E7E35255E5848377F7960527D
3F6F496E96544941376C3F3A495128624D3B6A4D6D746271654859653A7D82516B3A4A6E
337D673D70BA3A53B44C5EC33F607550589E8A532E945D45724F2D5876556A864BA3826F
6B95AC57AACD865BA1924D5EBFB86599A392497E9E6073A87559747F36569F579F6E70C1
9346539F454B632F5851775B4C297E642B526BD8802B554F3E3676411F587968554C692F
3657725D7B878F6C36B888374A5F437A6C485FC58F5297BC8F594890332F57722F49759F
395F9169364C677F654F6F3C53823B48724C2585A74A2B4C5C3421418B8E62373C4BD0B1
D49D4236292525245426191515151519171515151528AFD1C9ABBC6DAD5E45435DB08681
49271E203B59493B6CD08C8B2D1F7FCFAC9779331F15217A38294539503D151315152E65
ACB2281924475C312C86210E125880351919152DA4452535725765B78F4B2D2017191517
1A232B2D2E247E5678C3A987781D1B22387D5C98D89B2B4051393CBECBC761272E3D4339
30364D629CBACDD493BA8F5A453F3C3E36443F5DB15A151615151D87ACBEDBBFDCCEB9AB
A95B4B3D6756393B658B7D5133272077CDD8C15C97DE421D43191722865C4A4C60819EB1
77B5D19FB59E633D237D291D1D1A2B556EABB0D36B1715151517151838CAE2CDB2571F21
339D61293F683F39302E375C4C3027A5D6C1904C3744A194C5BDBAD145377FBDB7C4D4D5
DAB7CFCBD6CA583638343C489E9D6FA4D3CCD7C7CBD5BDBE8C37487E
7A9D64A77E6D899C4F73AB63A58AC07457965B8E7439678B807F8C64246F854E964B2C4A
6D366155294C2F3B1D345A4E4B827E3A50513B697C2D4B733D434F2B183C5D6731386843
776D331F61794B4D38498F5D8DB9712771644C4293481E2F88491F453A473BA1AB683F4E
388A4E467652605A36854C446E6B286A4F587037534C4B59686E445F305E6B4152347078
2F5E5947ACB5384198452F945594746969745C473398532C766D325141338270417A8C72
9EB89651C7BE8753BAAD725BC3B0396D59644A6E72489DB5565D956D3D72815BAB4E46B1
82215E883C5161256D7EAB71613268583F6C63DD78377067462D5C3428547F6151496036
405D785A87A58D552B7C58224E47447D493563BB8B54AAB98F5C7CA855355D6D323E77A6
304FA773243F45663E8083465C9122357356238497273D7173543B295D724B4774B7D5D7
AD6E618F614B3F37592C2D2032201B1819181A1A181BB3C1DDCC9281924235448B30172D
84633E515E766158469AA79C82446AAE3A1F15171A19276C25131526415A2E15191F7171
ADD8BB8B75838D8697B2150E101265A9452E243DAF733A678889A7282867521D1A1B1818
191E272A22224F9F57ABCCB5CC7D5B4D3B2D439FCC6D5E98537450957399D48267756F68
5F666D82C0CCCBA68A34B24A312922231F231D1D5151151515172151A58FE1C0E8CCC7A1
B95168A83C201E1F27253A7279444D8BCF98994F4ECA3B4592452F3E71C1B6BCBC904C5C
A6D1DCC19A833E1E29562731262254465768366435151515171B16183BCFBEA8B0903E23
2B5798385059272C34342F323770B09C5D5F2C364F534A3260ACC2D7AD3E5AB3D6DCD7CB
99C8D1D4DBE0C18A47302E85782F5F70A2CEC5DCDBC2BDB7AD87B185
7797557889505A4F6E978A679196C54355703C7C7C3D48703F444E6A224754376760293A
51305F6232371E42221A3E2932535F50393B45875E32786C3D465C322B627F6038566A2D
4B401F2978603C4E2046844168B45F389E8E3C35643215216F281C4F3440298366664A4B
346351446A39684B3372454D4451275E4434603859745E405C734D693A6A744C4D3E7681
475D6F4180AE373F924B41A859BF665179885B3D368744427B54306D78495C7B526E7F54
58A77E41C8A0444AAF9C545FD0A9529751514F6E613568863A4570323D818C64AB472DB7
954566882D7E641B474479684C2E525C3E5C5FDB7141747960335F3A39607C465F84843D
3E64783C706B8474366B63246F65497B4337639F8659B1B5935695B571375A75193E7B8B
3565CA8632384260415C745368A532316546237B9B3B2C4747644829566D422F8565A7D8
C76E4B5C6E5F596F836FADB6C1703B333A3C3D4B4D5FD7D7DCE1CDB2A78F88C593342B23
2695CAACAB9B9E995B55BBB4C8A6DAC74A28222C32383E743215151529436E3E4889A98A
B4D687596A8297919EA7381310112CDAD4AF9EACC6C4B6CFDCBA301D1F1C4D531F1C1C19
1C1D211D211D2095CDDBEAE3E6DFD4988190B6DC9261517FB4CEA682272D6768272F2C1E
1D191724778ACEC3663537B1331D1B1C1D1C2522265B15151A3D4A333CCCDCD1E4D1D595
C3B65C3D40211E1E201E2624389CB4B2657B935686C1C48553517CBC6A5B84C5C05F422B
2885A0AB7C661D1E452D334E454C7E5C56582C4025171516181618192F9D7986AEA57D35
3445A56C6943282D37423E394FB691888C493753634A433B323563D2DFAFC2CBB6DCC876
9AB6C3D0DDD9B78F9B9B898E3E4A797672C1DBD9D5DBD8C59CC9D57D
7BB67399924E5A884F5190667774BA7262885E829E4B478E8D594D742248784A638F333E
50394C482944251F201E47343F5C694E403E2F55492365392A5E702C1B43664926475730
41422228655E3C411A4184487D9A541F5B563134662F1420781A1A50364233A866634345
3A6C4243713F58332E6A457A4F3B1B5643394D2F615F5D435958575F315C5E4F46217886
4D5A644196983142792D479C3EB45A3C837B5E29448D313F89382A74804F5E7A5B6B8B75
71A9804BCA975860A78F4B67D9AE5995536E5F776B54829347578267396C91709B5460A6
812E5B8B274F5F3245457757452E4F61232F4FD06F3D7077473F746C567397514B5E5C2C
518A7A567852675948936C27506045793F2971AC8F59AC9B3D2E99B36D4F918B34346F79
1B349E772F324A6155587A4C5CAA34326048217EA54136505B6C5026546C6B339E7E7C82
6787895B54606D42663A46689A8A6C55493E413F2A69ADD1DBE0D4D9C6BA8A8B8E714B39
2E7E77444B698CB5A960B7D3E1D3E3D6B4764F566AA2A0AE61342D23222A5FA44932654B
6ACB66251F2C975D36459629133997BB9986828ABA9D9AC7D9A131181313174852261D17
1A1D1A20232D339B94BFDAC1A54D545E5D7DBBE7CB9839346DA7C2872B37456613151A1B
1815181E628FCFC69973265B74221C1D1D182429316428203D3723202CAB9998DC9583C3
B67E331B473422201E1D1F242E66D3782B8FA673BDBAD083664D89B3A9A864312A436567
5291BA9C6D892F334A284689A0C65972635E3B522A19161A191C191D5660489395BEA286
616B81BBB953393A332D3D73B9949F49537D6D5F4B5A49393D32278BD7D97B363BBBA8AE
D2CCC9CFC38E9FAD96696293A1B4CBCEC3D5C2E2D7C9C49A7BB7BFC3
6C9C6B9565769A984E54A26EB687C974567760A09F4853949260598024548440668D354D
533A4C4C33512930311D4B4442606D57413E2A5E542F75462B3D572A1B4C61653956512E
575339407B684448324B7258969B5A286B5D3637763D1925792239755A5135B66B467271
37654D4B76364D4838714F7D543E1F5B41424D2C616A4E4A524A5E65285B685653286E6F
4461553F8E9431468830479033B9564A85745D364C9A4440844430857C54778E5C709D73
8DB29D57CAB9847BAFA24170CBAD5379546F53AC9B588BAB50538862446E8678BD6D6FA7
75346F8035664D223A47765D2C297E91356449CA5531706947306D6F53ABA472515E6326
4560665E79667C46297A5C2B56474884322858986E5EBFB37B48C1982938627C2A3E7494
26337B75343E57695167764345B03434755722748136365A463435275865632650454043
3E4551757C524F839EA28D61527977766350575B988C59BDAAD6C6B9C3A5534445474D58
B7B05D51515A8B5A629EC5E1C7ADCEB4AABFBC85746C714D15151B253A48766E37394F47
4BB56C172D54414B573857C8A2C4692E20231D2EC1593583A28C751C1310151AA3845A4A
413936343E568A544295C68BDB91503A2B222E90E3CC434B6F7EAB803F2C478017141317
15161A3094B79F7485944C175E7428201F1B1C2134527F3E221C1E1E58616C9F62A893A2
9FB0871D32883A281F201D202B69953B39C1DFBBB6B6CBB06A9DC6D0AC32221C19151733
93BF88AEB86154542A2F599C5F8A66665D513151321B1B1A17191C1D5C2638909DA2A18E
A1B6BFD2D9A9653F3966AEAD86A24E5884C38F66533A3F2E32332E55D5DFA84D5A9197E2
DAC8CDDDA46A6B557193ADBA9292A8ACB5A053C1BFC5C6C9CFA74E6F
7BA972A88D4C536647567A8AA96CBD6B889851A55C428880674D55734090845D663E3A72
5D3A4A48365A31372E43814F3D5F68516E482B6265429E5D3B3E5A393E806F652F755A23
6C7A3A41616B5F653A4E7960A5A672296C6250619C591C3188201E49383A38B558563B50
2F6531736F30494055925B65514C3784444A47518E784744522D7F802A5A4A757F33726B
5886663B879039729E4B4D8635B9966D7170612B8BA85C3F825457AD7E5A7F8A82A9A277
89B38C64B4A17A84A5AF6957D8A4537A544D2E7C7F4C8E9B44588F6047753D619A7469A7
86217E8E415A4D255C89C07F472A3958305D44B357457A66523371282E725C5B66608640
4050752E659C8F693FA76C32673E39815A3E70A42C4D7F708D55CC856A34527C24489D98
222669552F73A5774C6C693F5EB5362C791B237A87383A6A3F2232407D5A5A2C504B4841
372E313949748FA8AF9C7342373C414754709AB79485B890C9C66763C59A6F555C60606E
BBC49F82B86E4D402F51BACAD1B47EA190A98EA6C6AB6B1E15141615151D53766048425E
67A5842F7B321526725851DFDB7E281A1817182AAE4641707D475F541512142EC5B4A58F
7B7E7B717B7876635B9FE1DDE2E7CE7A5D504A4D94CD40151725555F522940802D10191C
19194F7384AE5D586D6F7F1F175A783A272119223F7D63391A1F204B5662AA612049C09C
7F818F8C6E888E8D6D4A352A347D5D719DE1DED1C39ED8D4B5D1CE6240502D1D16151515
298553A89C5D388A867A5C2E2B685E516F4133583D1C1A1B191C1C2D2D1C3A95928FA24D
4F548EBAD4C6C4A3A8BC909BB052629292624959514A433D35444584D7AFA2CED98588D6
DFA997CA371C3B636B503E76A5C3C1B5C67598CBB2A35249AC933F3F
739659B68E4F587F476E626580648B30578A45A2783A568367576F602561797089742563
4D37584630523A3F26224D393A7162315A3831602C38795532465120215B60583A815529
48442242593547622D596D387CA368317E7133427946265C72331E52473D39BE675E5050
2D61354E60264C463276494D7C49306C3C5A4D2A695B525966465D5C2D665C5C4E298444
457B5F4CA46B3B797E436C8042A25D3F7F947242587C344E9C37407E5C6D83456D686563
90B56B4782804C8BC7B75859D27D368D9253418C65519D8635629052437F687992565DB0
6C2D725D3A5A4C212C395D6957364456233C41B27F498E7747568A6A6B8863356A827232
455E6964625F667345B959459E6D46574D40999A637477586263D8B16F3C5A7E2331767B
1D55B8783333513D228F7923409D25579A561F6D7B2552BA7B3B25478360562D50473B2E
2824212121285CCCB1C4A85D5082847267554B5CB1DDAF81959A4581828C7136261F2C41
84A6613B6174271D36AA9C4C4067AABFB3B7B29C9EAEA374512C1C19191A4C7A411E1B40
4A9476467D1715152A88AFD7B53F1A1617161E44902B2768624836633C225D7035202128
24262D3A737385B8BEDADBAFDFE37B251917131118366D2118173D60513D31626E1C2027
435C4C40969A5D55576A7667241E4F8055393F4D4241517527274354715A815A42278AC9
ACAC8A975C2828438193645F7F8BADBDD17353B4B8C5E1DDDFDD5C252239441817171619
2679876097AA262435453B28315059546533395131191C1A1A1C1F4D1F25629A5A909540
4553888E59A58EC4D4A7B2B4707790906622292D4551474B4A4B61C2A154356AB0A38EBF
B855839517171818244C847963718FBEB8ACD793C65F4F4F8D93452E
6BA1537C775E583E5E867B6F4E6D9E466A4B4498723A6B4330687667286129476D5B2473
304278644742434E342A51112D6C7B406319458C6D338B252B7980322458371742A27D34
4F43155F89645141145587609CB62D2E5F86413E75101254663F215A5A1520978E5F5353
2E915754332A6F733B7A14367674424E186778367014345679465E3A237B7A57471F9077
595C2156BBA3418D671F5C7B4FA55C22574B533681721C378A57497D1B439579936A331E
419B9754877C235C877C4B89DB9B49504963429A495AAD86494587514D88749A994C6CC4
70347E47418A582F40326365494A4C6C3348267966426F5A283978635E6F5E4C52605D2B
5A8A5E6E6562535161B74D23554A6C832A1A7C7D5B8CBC8A3F5DAB5A425883A34E418376
133F9A7A333B55421C5F82404A95153E9252197C671031676B70462A54361A384C3D3533
2E2726201D1B3ECD4A79BAD4B0484255658CCAC490A86A919BBD8A37172746712B1F1C19
297F98392F6D2D5C988F7136373A7F6A8EB6C2A69088473658756F5736283A8C2A1D1B2C
4B9676154327151729C1C890A83915151A2E57B2C862346A69693B59B4A14E1D16151315
151B1A171B3F3D474CA7DB8CBDCEB82D19151A15131665521B15285547513146B8775D59
402E4F55D28D5D6F4AAC96AE6F3D2C4CA1753B211B27397686626A7038451A18564D8879
698EAE6B6D7138243B9778649FAFC6C771345E97604CBFCBCFCE4E362D1F4C1719202D27
3D7CA4397CAA474136303A283C4F656A5133304D321F1F1C1C1D37562D3B839C4C5D774C
4A4E5CAFAC63D1DAC4C6DAB8A6A79C6E331C222827315A424751A9C4725F3C5096CB94D3
D7AAC37D15171816181C553D232737676082AE4A863748629B816D5A
71B15CA55C8C93733E617F786D519F457C7F3D978E426E8562545C702E85755A6A702581
68364955384B393D2E2646302B427E436F332E5C593884311C3F582524553D303C885D27
4C3819325B4C4A3E1B437A63A19B50244D66384494421B6A55291D5C4D4E449A6A525059
306C445560294551347A4E545B61326E2B585A39766232446C4A69632F61655347298A62
5F513744A6782B785E31535C37A76F617F5743399183443B85404F9761488C72967A8764
58B38C628E8D658EA37F2367CB8E495D686C4EA273446D8B45415635628C6FA48D3B539F
65318B56265165423E3A6D701F2D6285476A30575945817A4A3E867277915A5656694C1A
405C73668198432946A15C3673242E4D472C896B214950687B7BAA58453148955C5192A9
203CAC7744779B7A3F5E7B3D59A73D2FA7401F84873A31744C373D70A04C312646403536
332E29201F2C98D288857FC3381B1514174FBBAFAFA0C4B2847D691511131325463F382B
1B427587337D58958478281C1D1F4A686F7B93A8BCC8A04F3E3E51665A5B84AF6D5A3D44
A1BE80171641291D849D798B94943941456D713B55A3786A8D5C3651CE661E19152B1615
181516171D2D4C668DBCD9C9C8A8D0A668482D1816142D8335171B64414C5B57D2534845
4D65869CE0C0B49259A4C88A7065859696987E5558535B72CDB55D2E441F121417588A57
608A5C968F6B745235A6916EA4BCC162637F834E25235AADBE8C6B3737204A362A405347
3D39945B5DA6767499324A395964747D423C39653621221F1F224A312A5EA07D4E50311D
2F445E8EBF9A92D5BEC7C2A5C7CEAD381C1E2128332B375F4C879AA8B14C475190C3C99D
AECADB791719191E27385A2C2C293460587B623B5F282C2F8746445B
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000301/K6`0EUIF05IFEP2CTi<0EEEE04A4A017AdL0FEUI08J6QP1IFET0=3@d04a<
C080Cdm?0140IFEU08f=S@0a<C40@D5104A4A01FEUH0K6a/0:b/[01WIfL07QhN055AD@1KFe/0=SHf
08N7Q`2_[jl0:BTY01lO7`0204U9B@1`075aL@27QhL0>SXj02@T901=CDd0Ng]k05QHF02FUYH0WIfM
01TI6@0`<300EUIF05UIF@1SHf<0Ph>308B4Q00N7Qh0De=C051@D02<S8`0L71`08>3P`0n?Sh0;2`/
06m_K`2UYJD0BTY:05MGE`1RHV806a/K03Lg=`1FEUH0Kfm_04E5A@1?Cdl0<S8b01lO7`1RHV80JFUY
061PH00n?Sh0GUiN02PX:00l?3`0UYJF096AT@0R8R80=3@d0410@00R8R80Fe]K0;bl_01ADE409RHV
03Xj>P0b<S80<c<c06][J`2g]kL0>c/k02/[:`1;Bd/0HF5Q03hn?P2BTY80h>3P03Lg=`0L71`0MWIf
07moO`0k>c/0Zj^[07=cL`0O7al09BDU06MWI`1_Kfl0Cdm?08R8R01BDU807alO02HV9P1KFe/0DU9B
05iNGP1JFUX05QHF02d];@1SHf<0K6a/02`/;00n?Sh0D51@03`l?00e=CD0GUiN06ATI00];Bd0>SXj
03<c<`0e=CD0De=C08>3P`1fMWH0<S8b05]KF`1;Bd/0BDU905iNGP2NWYh0G5aL038b<P80EeMG01d0
?Cdm0820P02XZ:P0:b/[02`/;01]KFd0BDU905UIF@2BTY80?clo01/K6`14A4@0GemO07IfMP32`/80
;bl_02LW9`18B4P0G5aL03/k>`2;Rh/0bl_;03lo?`0Q8B40?3`l075aL@1HF5P0_Kfm0:FUY@0203dm
?@2_04e=C@1XJ6P0C4a<09fMW@1hN7P0820P04m?C`29RHT0HV9R07MgM`2BTY80@T9202@T901JFUX0
RHV906ATI021PH40R8R803<c<`12@T80DU9B0::RXP1cLg<0Xj>S06e]K@10@400Lg=c08>3P`0l?3`0
EUIF07QhN00k>c/0=cLg09VIV@34a<@0EUIF05=CD`1;Bd/0=CDe05aLG02SXj<0D51@03@d=01ADE40
Cdm?06m_K`2PX:00OGem03Hf=P1GEeL0BDU905UIF@2/[:`0IVIV03@d=01<C4`0Fe]K04Q8B02XZ:P0
PH6102/[:`0o?cl0P82006MWI`2<S8`0IfMW02DU9@0X:2P0MWIf07UiN@1bLW80Y:BT02`/;00`<300
HF5Q07]kN`1UIFD0^KVi06MWI`11@D40Cdm?08>3P`1mOGd0DU9B06m_K`0j>SX0@T9205=CD`2@T900
IVIV0492@P1RHV80:2PX0410@019BDT0NWYj04Y:BP0g=cL0Fe]K02d];@0n?Sh0C4a<075aL@1XJ6P0
JVYZ06][J`0Z:RX0:2PX04Q8B02CTi<0?Shn03/k>`1:BTX0?clo05ADE01XJ6P0Cdm?01hN7P16ATH0
CTi>03Ti>@1EEED0JVYZ04U9B@0I6AT0=3@d03Xj>P1FEUH0Bd];05UIF@1kNg/07AdM02l_;`11@D40
G5aL065QH@1hN7P0JVYZ02HV9P0i>CT0E5AD05iNGP1JFUX0C4a<04A4A01YJFT0I6AT05ADE00f=SH0
DE5A05ADE00j>SX0IfMW05eMG@1IFET0CTi>04e=C@1gMgL0KVi^05iNGP1FEUH0GUiN04U9B@0S8b<0
CTi>03Ph>00l?3`0Fe]K04e=C@0l?3`0>c/k055AD@1;Bd/0FEUI059BDP030410@007051@D01<C4`0
D51@04Q8B01VIVH0EEEE02LW9`0202h^;P0=03De=@11@D40>CTi04=3@`18B4P0=CDe03dm?@1:BTX0
;Rh^02DU9@0j>SX0>CTi04Y:BP0203De=@3J04a<C01QHF40PH6103`l?019BDT0CTi>03<c<`0d=3@0
CDe=03Xj>P12@T80ADE505MGE`1cLg<0Hf=S03dm?@1=CDd0Fe]K05eMG@1`L700De=C06=SH`15ADD0
71`L01lO7`0m?Cd0C4a<04m?C`0h>3P0@T9205EEE@1RHV80DU9B04U9B@1BDU80De=C05EEE@0W9bL0
C4a<03lo?`0a<C40<c<c04m?C`14A4@0@d=303<c<`1=CDd0@d=30492@P1DE5@0?3`l05MGE`15ADD0
@41004I6AP0U9BD0C4a<02@T901FEUH0EeMG06QXJ01MGEd0<S8b04a<C00];Bd0Bd];05ADE00a<C40
EEEE04A4A00m?Cd0EeMG051@D01CDe<0;bl_03/k>`12@T80?Shn06m_K`1SHf<0B4Q80:VYZ@1cLg<0
<S8b05mOG`0e=CD0I6AT05mOG`0l?3`0T92@05mOG`0a<C40QHF50451@@1:BTX0Bd];05QHF00M7Ad0
>3Ph02`/;01;Bd/0IVIV02h^;P2o_kl0KVi^06=SH`1=CDd0UiNG02d];@1BDU80GEeM04];B`0Q8B40
EEEE02l_;`0P8200BDU906UYJ@0h>3P0ATI601/K6`1;Bd/0<30`03<c<`16ATH06QXJ04M7A`0f=SH0
;bl_06QXJ015ADD0Ti>C09^KV`1IFET0J6QX06IVIP0j>SX0GEeM03@d=01WIfL0HV9R08n?S`0g=cL0
DE5A05=CD`0Z:RX0@T9204];B`1:BTX0GEeM04I6AP2LW9`0UiNG04e=C@1DE5@0De=C02`/;01CDe<0
51@D04U9B@1;Bd/0GUiN069RHP13@d<0D51@05iNGP2LW9`0EEEE05iNGP1WIfL05ADE028R8P1OGel0
4A4A05IFEP0W9bL0F5QH03Hf=P1<C4`0=cLg05UIF@1EEED0GemO05]KF`1;Bd/0IVIV04E5A@21PH40
JVYZ04a<C01TI6@092@T07=cL`1CDe<0ATI606MWI`0e=CD0MgMg051@D00i>CT0ATI604Y:BP1@D500
BDU905MGE`1QHF40?clo04M7A`0G5aL0J6QX02l_;`0Y:BT0=cLg01lO7`1KFe/0GEeM03lo?`1XJ6P2
05UIF@0305=CD`0i>CT0E5AD00<0IFEU0200GEeM03Lg=`1ADE40De=C02h^;P0j>SX04A4A08Z:RP32
`/80N7Qh06e]K@13@d<0?clo05IFEP0/;2`0=SHf04Q8B015ADD0IFEU030`<012@T80H61P07inOP2:
RXX0O7al06EUI@1IFET0F5QH04];B`1VIVH0EeMG06a/K0;ooooo0000TP2c/k<0DE5A04m?C`1_Kfl0
LG5a09RHV018B4P0ATI607inOP23Ph<0QXJ60;fm_@11@D40>SXj06=SH`1UIFD0HF5Q07]kN`1aLG40
820P05mOG`1GEeL0KVi^05YJFP1dM7@0:b/[01TI6@1:BTX0O7al03Ph>00g=cL0=3@d020P800n?Sh0
HV9R04Q8B026QXH0HF5Q02<S8`0Y:BT0?clo07inOP1hN7P0;Rh^06i^KP0S8b<0:b/[08:2PP2][Jd0
FEUI02DU9@1CDe<0=3@d05IFEP2c/k<0NWYj02@T901<C4`0Ng]k03Xj>P24Q8@0Shn?02DU9@0R8R80
ADE505iNGP1KFe/0NWYj05ADE00D51@0=cLg05]KF`19BDT0PH6109nOW`0Q8B40=CDe05MGE`2CTi<0
DE5A08B4Q01dM7@06ATI02XZ:P1bLW80QXJ6055AD@2IVIT0@D5101lO7`0c<c<0IVIV09BDU01RHV80
M7Ad038b<P0O7al0@D5107QhN022PX80G5aL07=cL`0R8R80@D5107AdM01WIfL0@d=304e=C@26QXH0
>3Ph04A4A01mOGd0O7al02/[:`10@400Cdm?0492@P1gMgL0SHf=04=3@`0X:2P0AdM7065QH@1FEUH0
NGUi07IfMP0U9BD0;2`/04Y:BP1[Jf/0EUIF0:6QX@1GEeL08R8R04U9B@1TI6@0N7Qh069RHP2QXJ40
Q8B403<c<`1IFET0IFEU08J6QP1SHf<0_Kfm0P15ADD0>P19BDT0UIFE06i^KP1PH600IFEU024Q8@0g
=cL0Lg=c08:2PP14A4@0L71`03dm?@17AdL0W9bL09ZJVP18B4P0Lg=c02d];@0c<c<0?Shn0861P@1I
FET0>CTi06a/K00`<300;2`/05aLG01kNg/0BDU903dm?@1=CDd0;Rh^03Hf=P1MGEd0PX:20410@00j
>SX0EEEE04A4A017AdL0X:2P07inOP0`<300F5QH04A4A00];Bd0N7Qh0;Bd]019BDT0<30`05EEE@1@
D500ATI60;Ng]`2o_kl0=cLg04Y:BP2>SXh205UIF@0n09bLW019BDT08B4Q04a<C02BTY80GUiN0820
P01kNg/0<C4a05QHF01[Jf/0VYZJ06m_K`30`<00>CTi0410@02LW9`0TY:B05]KF`1YJFT0BDU902/[
:`1cLg<0UiNG05=CD`1cLg<0?Cdm04U9B@1=CDd0Lg=c061PH02:RXX0T92@03Ti>@2EUID0SHf=07em
O@1;Bd/0UIFE04];B`1DE5@0[:b/06m_K`1>CTh0H61P04I6AP0e=CD0NGUi0:JVYP1>CTh0De=C08F5
Q@1GEeL0AdM708B4Q01HF5P0<c<c06m_K`1WIfL0E5AD096AT@2`/;0203Xj>P0X05aLG024Q8@0K6a/
08:2PP2KVi/0>CTi03`l?013@d<0De=C0492@P2KVi/0/[:b030`<00a<C40?3`l07alO01QHF40OGem
08R8R00R8R80ATI6065QH@1GEeL0>3Ph07YjNP2>SXh09bLW028R8P1LG5`0LG5a03dm?@1EEED0QhN7
03<c<`0];Bd0@T9205MGE`0b<S80CTi>06][J`80<c<c01l0BTY:04];B`1DE5@0BDU908B4Q018B4P0
HV9R02/[:`0d=3@0>3Ph05QHF01[Jf/0HV9R05aLG01EEED0?Cdm03Xj>P1?Cdl0GemO05UIF@1VIVH0
Q8B408N7Q`1eMGD0BDU905aLG01;Bd/05QHF02`/;00K6a/0<c<c0080CTi>0340GEeM055AD@1jNWX0
IfMW069RHP1HF5P0De=C069RHP1QHF40KVi^06IVIP1lO7`0LG5a06=SH`1PH600=SHf02l_;`18B4P0
>SXj05EEE@0m?Cd0@41005iNGP0e=CD0?3`l04i>CP0j>SX0<S8b03/k>`0I6AT0=cLg028R8P0O7al0
<c<c03Lg=`0m?Cd0;2`/01`L700R8R80;Bd]02l_;`0a<C40<c<c03hn?P1<C4`0BTY:05]KF`1>CTh0
>c/k0080>3Ph0:D0?3`l04];B`0N7Qh0;2`/059BDP0T92@0:RXZ06=SH`18B4P0F5QH04m?C`1:BTX0
?Cdm03De=@0l?3`0;bl_0410@00W9bL0:RXZ02<S8`0d=3@0<C4a02PX:00`<300=SHf02@T900];Bd0
8R8R02l_;`0g=cL0;Rh^0492@P0o?cl0Bd];03<c<`13@d<0C4a<01lO7`0`<3007AdM06IVIP1CDe<0
>SXj051@D01>CTh0Jf][04M7A`1GEeL0@41006MWI`2BTY80FEUI071`L01TI6@0FUYJ07UiN@0_;bl0
EeMG05ADE01OGel0KVi^07MgM`1GEeL0Xj>S09>CT`12@T80J6QX05QHF02ATI40PH6104e=C@1dM7@0
CTi>04e=C@24Q8@0<c<c05QHF01:BTX0P82005IFEP19BDT0SXj>05YJFP2ATI40?Shn075aL@1FEUH0
De=C03hn?P1=CDd0BTY:051@D01LG5`0CDe=03De=@1MGEd0@T92010@401ZJVX0LG5a03Ti>@1KFe/0
<C4a0492@P0/;2`0=cLg05ADE00[:b/0EEEE04];B`0`<300P82005EEE@1jNWX0S8b<02`/;016ATH0
<S8b04=3@`1^KVh0@d=305MGE`1QHF40V9RH061PH01;Bd/0B4Q80492@P1ADE40BTY:03Lg=`1>CTh0
<S8b07AdM01iNGT0BTY:05QHF00a<C40@T9205YJFP16ATH0EeMG03Ti>@1bLW80CTi>03Lg=`1DE5@0
EEEE0::RXP1^KVh0PH6108V9R@0Z:RX0<30`06i^KP0O7al0C4a<04m?C`1DE5@0BDU905ADE01:BTX0
FEUI06EUI@1PH6000P1EEED0B@1oOgl0IFEU09BDU01YJFT0GEeM09bLW01>CTh0QXJ603dm?@0h>3P0
C4a<02`/;01hN7P0?clo0410@01@D500Cdm?059BDP1GEeL0@d=3051@D01:BTX0H61P038b<P1=CDd0
>c/k05iNGP1^KVh0<c<c08R8R01TI6@0@T9207=cL`0E5AD09BDU04U9B@0e=CD0A4A4055AD@1@D500
C4a<07MgM`1:BTX0KFe]04m?C`0T92@0ATI601@D501KFe/0^k^k09jNWP2;Rh/0ADE504=3@`1CDe<0
<c<c06e]K@1cLg<0>CTi04=3@`0c<c<0H61P05MGE`1SHf<0FUYJ0492@P1EEED0IfMW05aLG01DE5@0
EEEE0820P01YJFT00_ooool0000]07QhN01dM7@0FUYJ06UYJ@1EEED0PH6107IfMP16ATH0LG5a03dm
?@0f=SH0JVYZ0820P012@T80L71`05EEE@0g=cL0GUiN09FEU@0e=CD0;2`/04e=C@0g=cL0?Shn08n?
S`1:BTX06ATI059BDP1KFe/0Hf=S08>3P`1=CDd0820P02`/;01BDU80A4A407EeM@2LW9`08R8R03Hf
=P16ATH0KVi^07AdM01IFET0V9RH0080AdM70?l0;bl_051@D01LG5`0RHV90:b/[00L71`0=CDe04e=
C@1aLG40Bd];07emO@1JFUX0:RXZ05=CD`1BDU80?3`l0492@P2GUiL09BDU03dm?@1:BTX0HV9R03dm
?@1:BTX0E5AD02<S8`0i>CT0SHf=07=cL`0S8b<0@410030`<00o?cl0EEEE05QHF00^;Rh0:2PX07Ui
N@0c<c<0?Cdm09JFUP1ADE406ATI02HV9P0f=SH0A4A4059BDP2d];@0Cdm?01`L700j>SX0BDU905QH
F01^KVh0f=SH05=CD`0D51@0H61P09bLW01XJ6P0SHf=0=;BdP0e=CD0>SXj06YZJP25QHD0LG5a06a/
K01iNGT07alO06MWI`2@T900Bd];05mOG`1nOWh08B4Q03Ti>@1HF5P0QXJ604A4A01TI6@0QhN701DE
5@0`<300@d=307EeM@0j>SX0DE5A08F5Q@0N7Qh09bLW05EEE@2][Jd0C4a<05=CD`1[Jf/07QhN03Hf
=P1fMWH0TY:B02l_;`1IFET0ADE502DU9@11@D40RXZ:03/k>`0/;2`0EEEE03/k>`11@D40O7al05]K
F`0d=3@0Hf=S05ADE011@D40WYjN069RHP0_;bl0Cdm?05MGE`1;Bd/0GUiN0;>c/`1ADE40:b/[075a
L@1_Kfl0GEeM08F5Q@2GUiL0:RXZ03Hf=P1ZJVX0HV9R04A4A02JVYX0RXZ:028R8P0m?Cd0I6AT096A
T@1KFe/0^;Rh07IfMP0U9BD0AdM708>3P`2BTY80F5QH0::RXP0e=CD0;2`/03Hf=P1eMGD0FUYJ05MG
E`1WIfL09bLW04a<C01OGel0IVIV04U9B@1bLW80?Cdm03Lg=`1NGUh0IfMW03De=@1=CDd0G5aL03Ti
>@13@d<0IVIV06ATI00U9BD0NGUi04A4A02;Rh/0W9bL065QH@0h>3P0@d=303Ph>011@D40/k>c08F5
Q@0j>SX0EEEE04];B`12@T80NWYj0;fm_@0o?cl0>3Ph06MWI`1UIFD0I6AT0<g=c@1<C4`0:b/[075a
L@1WIfL0FEUI08n?S`1HF5P0;bl_04E5A@2:RXX0Rh^;08B4Q02n_[h0B4Q8055AD@1>CTh0KFe]05]K
F`2k^k/0U9BD038b<P1:BTX0LW9b05iNGP1oOgl0ZJVY04E5A@0b<S80ADE508F5Q@1cLg<0Fe]K07Mg
M`14A4@0>c/k061PH02CTi<0N7Qh04M7A`1[Jf/0?Shn02d];@1DE5@0YZJV07emO@1FEUH0Lg=c04E5
A@0S8b<0OGem0;Zj^P1`L700A4A405IFEP0a<C4004@0>SXj05mOG`2GUiL0BDU902h^;P1LG5`0AdM7
03lo?`1HF5P0RXZ:030`<00Z:RX0EEEE04I6AP0m?Cd0F5QH0:2PX01GEeL0RXZ:03hn?P16ATH0De=C
04];B`1<C4`0>SXj06EUI@1TI6@0>CTi04U9B@1RHV80UiNG092@T01iNGT0Fe]K059BDP1WIfL0HF5Q
05QHF01FEUH0;Rh^03<c<`0a<C40=SHf04M7A`0e=CD0@D5105IFEP1DE5@0FUYJ07=cL`1EEED0=SHf
05eMG@1YJFT0L71`03dm?@1>CTh0HF5Q071`L01@D500:BTY034a<@0m?Cd0EEEE05ADE00k>c/0ATI6
069RHP80AdM700h0De=C04I6AP0j>SX0CTi>02TY:@1EEED092@T01`L701;Bd/0@T9205ADE012@T80
8B4Q02h^;P80>CTi03d0ATI6030`<014A4@0?Shn05EEE@1JFUX0GemO030`<013@d<0IVIV04=3@`1e
MGD0?Shn04E5A@1_Kfl0BTY:051@D01KFe/0DU9B04e=C@1UIFD0L71`04m?C`1@D500Bd];04A4A016
ATH0>c/k04I6AP0a<C40<S8b02l_;`0`<300>SXj0410@00l?3`0DE5A030`<00/;2`0=cLg03hn?P1M
GEd0?Cdm04=3@`1?Cdl0AdM703Ti>@0/;2`0@T92034a<@0o?cl0AdM703Xj>P1ADE40;Rh^03<c<`0X
:2P0ADE504I6AP0^;Rh0>c/k0080<c<c06L0ATI606][J`1TI6@0A4A404i>CP1PH600HF5Q07MgM`1j
NWX0JFUY0;Vi^@2DU9@0DE5A05iNGP0i>CT0NWYj07AdM015ADD0J6QX05MGE`10@400DU9B04A4A00g
=cL0;bl_08R8R01DE5@0KFe]04];B`1RHV80S8b<05eMG@2WYjL0LG5a055AD@0o?cl0GEeM02d];@1Q
HF40Q8B4061PH011@D40DE5A04i>CP0E5AD0I6AT075aL@1;Bd/0O7al01TI6@0n?Sh0@D5103hn?P1>
CTh08B4Q04m?C`0l?3`0<S8b092@T01SHf<0KFe]08F5Q@1CDe<0IFEU04];B`10@400CDe=038b<P0e
=CD0GEeM0:>SX`0h>3P0JFUY05IFEP0Y:BT0BTY:04=3@`1DE5@0Ph>302d];@1CDe<0H61P038b<P10
@4009bLW020P8014A4@05ADE055AD@0Y:BT0Cdm?03/k>`1;Bd/0IfMW03/k>`24Q8@0ATI609jNWP2G
UiL0BTY:034a<@2;Rh/0:b/[0080FEUI0580Jf][04A4A01MGEd0=3@d05EEE@1NGUh0D51@04=3@`0c
<c<0J6QX02l_;`1KFe/0D51@038b<P1WIfL0;Rh^04U9B@18B4P0BTY:06m_K`17AdL0J6QX04Y:BP19
BDT0ATI604=3@`0j>SX0=CDe02XZ:P0o?cl0:RXZ04I6AP0g=cL0Fe]K04i>CP18B4P0=CDe04A4A01;
Bd/0BTY:05QHF01NGUh0?3`l05YJFP1NGUh0?clo03dm?@1RHV80GemO05eMG@2/[:`0GEeM07UiN@13
@d<0:RXZ06e]K@0`<300GemO08V9R@1aLG40GemO05iNGP14A4@0EUIF02HV9P0i>CT0@D5102d];@1;
Bd/0;2`/05eMG@1?Cdl0IVIV05mOG`0k>c/0?clo05MGE`16ATH0@d=305aLG018B4P0D51@0_ooool0
001806a/K023Ph<0]KFe07=cL`17AdL0EEEE06MWI`1MGEd0QhN703@d=015ADD0D51@06][J`21PH40
^;Rh04Y:BP0o?cl0A4A405YJFP18B4P0IfMW09fMW@13@d<0:RXZ04];B`1PH600BDU90:^[Z`2=SHd0
5ADE04A4A01cLg<0AdM706MWI`1FEUH08R8R03Lg=`1HF5P0QhN703@d=01MGEd0I6AT02d];@0c<c<0
TI6A06YZJP0i>CT0EEEE04m?C`0V9RH0Hf=S0:>SX`1jNWX0>CTi079bLP1CDe<0A4A409ZJVP2PX:00
9BDU04I6AP1RHV80@T9205=CD`2VYZH0>CTi028R8P12@T80JVYZ04=3@`1gMgL0KVi^0P0/;2`0o`1O
Gel0PH61055AD@2>SXh0<c<c01dM7@1HF5P0TY:B05MGE`1DE5@0UIFE0451@@0i>CT0>c/k08Z:RP1;
Bd/0QHF506a/K00Q8B40<C4a06EUI@2CTi<0?3`l06UYJ@1;Bd/0;Bd]03Ti>@1eMGD0L71`03`l?017
AdL0>c/k04M7A`13@d<0PH61061PH00/;2`0EEEE028R8P0d=3@0C4a<07=cL`10@400820P03Ti>@0a
<C40DU9B07emO@16ATH0820P034a<@1GEeL0C4a<05]KF`2f][H0;Rh^02<S8`15ADD0@T9203lo?`25
QHD0YJFU02HV9P0U9BD0@d=305mOG`0m?Cd0WYjN0<K6aP0R8R80=CDe03Xj>P1]KFd0JVYZ0:BTY02V
YZH0820P0451@@1EEED0IfMW06EUI@2`/;00>3Ph02PX:01OGel0PX:208^;R`2BTY80?3`l02<S8`1E
EED0MWIf0451@@29RHT0UYJF02`/;013@d<0Hf=S09bLW017AdL0O7al061PH00Q8B40BDU905YJFP1P
H600=SHf055AD@0f=SH08B4Q055AD@2[Zj/0Q8B403@d=01<C4`0D51@03Hf=P1UIFD0Ogmo0492@P13
@d<0?clo04];B`1TI6@0Shn?06ATI011@D40H61P04I6AP0o?cl0W9bL0<g=c@19BDT0?3`l06a/K01U
IFD0E5AD0;2`/01mOGd0<S8b04Q8B01JFUX0E5AD09NGU`1jNWX08R8R04m?C`22PX80I6AT04m?C`3;
bl/0K6a/02/[:`1bLW80NGUi04Y:BP28R8P0;2`/03<c<`1>CTh0K6a/05IFEP2?Shl0?clo03<c<`19
BDT0QXJ606e]K@1RHV80GUiN02DU9@1=CDd0LG5a07]kN`1mOGd0T92@03@d=00e=CD0Hf=S0:NWY`14
A4@0Kfm_0410@00a<C40CDe=09VIV@2EUID0?3`l04a<C00[:b/0@D5107alO02IVIT0AdM70451@@1H
F5P0BTY:0492@P27QhL0H61P03Lg=`0i>CT0D51@03Ti>@1YJFT0[Zj^03Lg=`0^;Rh0@D51061PH01B
DU80Kfm_0:VYZ@2DU9@09bLW04m?C`23Ph<0T92@09^KV`2^[Zh0>CTi028R8P13@d<0Ogmo06YZJP1e
MGD0YjNW03Ti>@0J6QX0@T92055AD@1jNWX0JFUY0<G5a@1?Cdl0;2`/03<c<`1>CTh0Cdm?05ADE02?
Shl0L71`01lO7`0g=cL0CDe=061PH01BDU809BDU03Hf=P1BDU80JVYZ06][J`14A4@0B4Q806=SH`00
o00n?Sh0EeMG06EUI@1OGel0AdM705UIF@15ADD0<30`059BDP19BDT0EEEE04Q8B00b<S80BDU902`/
;00e=CD0C4a<051@D014A4@0B4Q804I6AP10@400A4A405ADE00o?cl0ATI604E5A@1IFET0ATI604m?
C`0m?Cd0BDU9051@D00d=3@0?clo03hn?P0g=cL0@D5103`l?00o?cl0?Cdm03Ti>@1;Bd/0DE5A04I6
AP1>CTh0DE5A03`l?01@D500>CTi03hn?P1;Bd/0@410051@D00g=cL0?Shn04U9B@0];Bd0?clo04];
B`18B4P0AdM704=3@`19BDT0MGEe05iNGP0e=CD0?clo06IVIP1@D500KFe]03Ti>@11@D40FUYJ01lO
7`0T92@0FEUI05MGE`1BDU80>c/k03hn?P12@T80AdM705=CD`16ATH0Cdm?03dm?@18B4P08R8R02@T
900[:b/0:BTY038b<P0g=cL0<c<c03Hf=P0R8R80;Rh^034a<@0[:b/0@T9202h^;P12@T80;Rh^03dm
?@0h>3P0<S8b04a<C00];Bd0?3`l05QHF01GEeL0N7Qh03/k>`1FEUH0>CTi06MWI`1@D500=cLg05EE
E@0k>c/0>SXj04i>CP17AdL0E5AD02/[:`0o?cl0;2`/03<c<`1LG5`0GemO04M7A`14A4@0DU9B02d]
;@1LG5`09BDU06YZJP1fMWH0ADE507IfMP1KFe/0?clo05aLG00m?Cd0AdM703De=@0m?Cd06a/K0410
@01;Bd/0=CDe0;^k^`14A4@0];Bd06EUI@19BDT0C4a<09FEU@0n?Sh0;bl_04I6AP1:BTX0<c<c05UI
F@0g=cL0<c<c0:NWY`24Q8@0@41005QHF00d=3@0>CTi03`l?01MGEd0KVi^02HV9P1:BTX0?Cdm034a
<@15ADD0I6AT069RHP23Ph<0>CTi04e=C@1EEED0?Shn059BDP0m?Cd0F5QH05MGE`1/K6`0G5aL0:JV
YP28R8P0<C4a03lo?`11@D40>SXj04M7A`1NGUh0IFEU06m_K`1EEED0C4a<05ADE013@d<0B4Q8038b
<P1RHV80BDU906IVIP1:BTX0AdM705=CD`14A4@0Ph>304a<C01[Jf/0WinO061PH017AdL0VYZJ079b
LP1`L700CDe=04Y:BP0`<300F5QH03/k>`1>CTh0ADE504A4A01>CTh0ADE506MWI`0l?3`0KVi^05IF
EP0`<300KVi^020P801SHf<0;bl_03Lg=`1EEED07alO05mOG`0^;Rh0:2PX03@d=080=SHf03L0E5AD
04a<C019BDT0EUIF05UIF@1XJ6P0D51@04a<C013@d<0Bd];04A4A01RHV80HF5Q07]kN`1hN7P0ATI6
04=3@`1FEUH0?Cdm065QH@1WIfL0DE5A04I6AP1OGel0D51@08>3P`1[Jf/0KFe]0:j^[P1:BTX0G5aL
0:ZZZP25QHD0KVi^06=SH`1dM7@0Ng]k03Ti>@1;Bd/0HF5Q04=3@`1ADE40:BTY0492@P1:BTX0M7Ad
07IfMP19BDT0Bd];05IFEP1=CDd0Cdm?05aLG01UIFD0Lg=c00;ooooo00007`2ATI40EEEE05YJFP2e
]KD0FUYJ06=SH`0o?cl0BTY:0820P01dM7@0>SXj05ADE00e=CD0@410071`L01MGEd0;Rh^06=SH`1I
FET0<30`03lo?`1[Jf/0C4a<03/k>`1CDe<0:RXZ03lo?`1fMWH0RHV902`/;00j>SX00P0g=cL0Q029
RHT0[jn_03dm?@0_;bl0DE5A03lo?`12@T80[Jf]09fMW@0/;2`0:BTY04E5A@1DE5@0KFe]0;fm_@2B
TY80820P02@T901VIVH0Lg=c075aL@2SXj<0GUiN01lO7`15ADD0LW9b03lo?`2DU9@0KFe]01LG5`0o
?cl0E5AD05UIF@1PH600LW9b01hN7P0/;2`0@D5108^;R`1FEUH0FUYJ07AdM00_;bl0@T9206e]K@1h
N7P0=cLg05aLG01ADE40;bl_04M7A`1kNg/0CTi>034a<@1KFe/09bLW03Lg=`1PH600U9BD03De=@0`
<300E5AD04Y:BP13@d<0Rh^;08F5Q@0K6a/092@T03Lg=`1@D500H61P08B4Q01BDU809bLW0492@P17
AdL0EeMG05ADE02UYJD0CTi>01dM7@1@D500De=C05QHF01aLG40MGEe01hN7P0R8R80Cdm?08R8R01B
DU80NGUi069RHP14A4@0?3`l06e]K@1lO7`0EUIF07moO`1BDU809BDU05=CD`2BTY80Ph>30492@P2j
^[X0OGem03/k>`15ADD0WIfM06][J`1=CDd0Ph>3030`<00i>CT0M7Ad0;Zj^P1NGUh0ATI604];B`0X
:2P0ADE507=cL`1_Kfl0=CDe04A4A00i>CT0G5aL0:FUY@1KFe/0:2PX0410@080Bd];00L0MWIf0:NW
Y`10@400=CDe04];B`1iNGT0FEUI0080VIVI0;l09RHV03Hf=P17AdL0KFe]061PH02d];@0@D51028R
8P10@400EEEE08J6QP1]KFd0/;2`05ADE00n?Sh0D51@06EUI@1GEeL0Ph>307YjNP0L71`0?Shn04];
B`1XJ6P0AdM708f=S@1OGel0<30`034a<@1oOgl0HF5Q05YJFP1PH60061PH03Ti>@18B4P0JFUY04Q8
B01DE5@0G5aL01hN7P1;Bd/0OGem065QH@1NGUh0N7Qh02d];@0^;Rh0MGEe0;2`/01>CTh0GUiN03Hf
=P1OGel0ZZZZ05UIF@0c<c<0EUIF03Hf=P0d=3@0MgMg07moO`0W9bL0GemO05=CD`1UIFD0Zj^[08J6
QP0a<C40ATI606MWI`0f=SH0K6a/0<30`01^KVh0;Bd]065QH@23Ph<0N7Qh0<c<c01jNWX0<30`05eM
G@20P800Kfm_08F5Q@2o_kl0AdM703dm?@1VIVH0Lg=c05YJFP2DU9@0X:2P038b<P0i>CT0K6a/09fM
W@2;Rh/0X:2P08V9R@0[:b/0=SHf06EUI@21PH40AdM708N7Q`2PX:009RHV034a<@2NWYh0_Kfm06m_
K`1QHF40@T9201dM7@13@d<0Q8B4079bLP0c<c<0B4Q804a<C00W9bL0;Rh^06e]K@2:RXX0?Shn04M7
A`1:BTX05QHF038b<P29RHT0NGUi02HV9P0g=cL0@D5102PX:00Z:RX0F5QH08R8R00];Bd0<S8b05AD
E01>CTh0De=C038b<P1;Bd/0Kfm_051@D01ZJVX0EUIF04Y:BP1NGUh0=SHf03<c<`1=CDd0KVi^05iN
GP1bLW80I6AT059BDP1RHV80CDe=05mOG`1<C4`092@T02d];@0S8b<0:RXZ03De=@0c<c<0=cLg04A4
A01UIFD0FEUI05=CD`1HF5P0?Cdm079bLP1RHV80PH6105UIF@1NGUh0IfMW05EEE@1NGUh0820P03Ti
>@1:BTX0=3@d05IFEP0203De=@2E05IFEP0f=SH0=SHf04=3@`15ADD0A4A404E5A@0];Bd0?3`l02TY
:@0R8R80>3Ph051@D01RHV80=cLg01`L700];Bd0@410065QH@17AdL0<30`055AD@1NGUh0Cdm?05UI
F@1SHf<0I6AT05MGE`1PH600?3`l06m_K`1:BTX0FEUI06QXJ00[:b/0<C4a04a<C00m?Cd0B4Q805EE
E@1<C4`0Bd];04E5A@10@400?Cdm05aLG00X:2P0@T9203Ti>@11@D40:b/[02`/;00j>SX0@41003De
=@17AdL0=3@d0410@014A4@0=SHf05YJFP14A4@0DU9B0410@018B4P0>CTi03Hf=P19BDT0:2PX03@d
=01>CTh0@D51051@D00j>SX0D51@02d];@1<C4`0=SHf05ADE01GEeL0=cLg04e=C@1:BTX0@d=305QH
F00h>3P0DE5A03dm?@1<C4`0IFEU08Z:RP1=CDd0RXZ:08F5Q@0i>CT0FEUI01/K6`1nOWh0JFUY0451
@@23Ph<0@41005=CD`1/K6`0;2`/05eMG@14A4@0E5AD04I6AP18B4P0Ogmo04=3@`1[Jf/0;2`/05eM
G@1BDU80BTY:04e=C@18B4P0ATI604=3@`1GEeL0C4a<03hn?P1gMgL0;bl_00d=3@15ADD0GUiN04E5
A@1QHF40?Cdm06m_K`1BDU80Hf=S06ATI00i>CT0OGem03lo?`0b<S80G5aL05=CD`22PX80Z:RX03Ti
>@1DE5@0;bl_028R8P1=CDd00P1ADE40D`1:BTX0IfMW04A4A01UIFD0GemO03<c<`0l?3`0C4a<0410
@01BDU80<C4a061PH01bLW80DU9B061PH01UIFD0AdM704U9B@0k>c/0De=C04Y:BP1SHf<0DE5A05MG
E`1_Kfl0EEEE08:2PP1XJ6P0OGem06MWI`1ADE40TI6A0;Fe]@2@T900IVIV055AD@1;Bd/0FUYJ08V9
R@1`L700GEeM06YZJP1`L700EEEE05YJFP1dM7@0GEeM06YZJP1KFe/0BTY:07IfMP18B4P0GUiN04E5
A@0o?cl0G5aL03lo?`1RHV80Cdm?04a<C01[Jf/0BTY:05=CD`1KFe/0GEeM05mOG`1QHF40JFUY03lo
?`1XJ6P0?clo04E5A@1BDU80>c/k059BDP1LG5`0LG5a08Z:RP0L71`0?Cdm05EEE@0h>3P0FUYJ0080
EEEE0P2:RXX07`1LG5`0Q8B406][J`1LG5`0J6QX04i>CP2>SXh0YJFU09^KV`2QXJ40Hf=S03hn?P1;
Bd/0A4A407AdM02;Rh/0?3`l04m?C`14A4@0MGEe05QHF01?Cdl0C4a<051@D01CDe<0D51@065QH@1Z
JVX0GEeM09:BTP1`L7000_ooool0003J09jNWP1ADE40CDe=07QhN01YJFT0Xj>S04Q8B00m?Cd0H61P
06IVIP1QHF40[jn_04e=C@0`<300C4a<06i^KP1YJFT0Y:BT09VIV@0W9bL0CDe=05iNGP1XJ6P0MGEe
0;>c/`0O7al0BTY:05MGE`27QhL0EEEE08b<S01UIFD0:RXZ024Q8@1ZJVX0UiNG05aLG02DU9@0<30`
02XZ:P14A4@0PH61055AD@1aLG40RXZ:01TI6@0[:b/0CDe=08B4Q01`L700GemO08Z:RP0X:2P0<S8b
0820P01VIVH0?Cdm05MGE`1MGEd0>CTi0410@01aLG40>SXj030`<01gMgL0>c/k07YjNP2_[jl0CDe=
02TY:@0i>CT0ADE503Lg=`1[Jf/0[Jf]03Ph>00R8R80@d=3065QH@1<C4`0SHf=07IfMP0M7Ad0=SHf
06][J`1/K6`0Q8B40<71`@0b<S809BDU04A4A022PX80J6QX065QH@2SXj<0=SHf02DU9@1TI6@0WIfM
04e=C@22PX80Rh^;02DU9@0^;Rh0EeMG07QhN00g=cL0BDU909ZJVP0U9BD0?3`l05QHF02:RXX0?Cdm
06a/K01:BTX0<30`04m?C`1JFUX0CTi>04M7A`1iNGT09bLW03/k>`1mOGd0O7al03lo?`0k>c/0CDe=
02d];@1GEeL0MgMg06i^KP0U9BD0C4a<05EEE@0e=CD0ADE507EeM@2LW9`0;bl_04I6AP13@d<0Kfm_
07MgM`2LW9`0Fe]K02h^;P19BDT0DE5A051@D01mOGd0Ti>C02`/;00l?3`0Jf][05aLG01NGUh0ZZZZ
04M7A`13@d<0Hf=S09fMW@1UIFD0VYZJ02LW9`0a<C40CDe=06QXJ02@T900J6QX07QhN00j>SX0@d=3
05IFEP2CTi<0IVIV04m?C`1IFET0;Rh^02/[:`1KFe/0T92@03hn?P1DE5@0IVIV02PX:013@d<0IfMW
07UiN@13@d<0Hf=S03/k>`19BDT0H61P09^KV`1ADE40=cLg04];B`1BDU80EEEE09nOW`2;Rh/0:RXZ
03Hf=P1ADE40EUIF06QXJ02JVYX0=3@d030`<01DE5@0AdM704e=C@2XZ:P0XJ6Q02`/;00f=SH204I6
AP2109bLW02h^;P0=SHf03Hf=P15ADD0EeMG07EeM@2b/[80Cdm?02<S8`0n?Sh0F5QH05IFEP2/[:`0
>SXj04A4A01LG5`0F5QH059BDP2XZ:P0PX:2020P801HF5P0QXJ604e=C@2JVYX0T92@03Xj>P0f=SH0
NWYj07alO01DE5@0UiNG07moO`0b<S80EeMG09fMW@1<C4`0PX:2096AT@13@d<0@T92065QH@29RHT0
BTY:06=SH`15ADD0?Shn04Y:BP1TI6@0?Shn0492@P1bLW80;bl_03dm?@1KFe/0T92@07IfMP0n?Sh0
M7Ad05QHF00j>SX0EEEE0:2PX01hN7P0>3Ph05ADE01BDU80HV9R0;Vi^@1YJFT08b<S0492@P1UIFD0
H61P05=CD`2KVi/0Lg=c02l_;`0V9RH0=3@d05YJFP15ADD0Xj>S0861P@0_;bl092@T04U9B@1`L700
@D5106i^KP1VIVH07QhN03<c<`1>CTh0AdM704e=C@11@D40XJ6Q05eMG@1hN7P0C4a<03@d=00e=CD0
DU9B04U9B@0e=CD0FEUI05mOG`0o?cl0>SXj05aLG02ATI40S8b<09^KV`1gMgL0HV9R06YZJP1<C4`0
E5AD05QHF00/;2`0=cLg03/k>`0_;bl0?clo034a<@0j>SX0FEUI0080J6QX01`0H61P05eMG@1ADE40
JVYZ05UIF@1DE5@0ADE505MGE`1HF5P0C4a<04Y:BP0d=3@0:BTY03<c<`0m?Cd0CTi>02l_;`12@T80
BDU903lo?`0l?3`0BDU903Lg=`0c<c<0BDU902LW9`18B4P0<S8b0P0`<300X@0L71`0:b/[02LW9`0b
<S80<C4a02d];@0_;bl0A4A403lo?`1<C4`0=SHf0451@@1WIfL0BTY:01`L700T92@0DU9B03hn?P1L
G5`092@T02l_;`1RHV80?3`l04m?C`1QHF40DU9B04m?C`1KFe/0GemO04m?C`1IFET0D51@04Q8B017
AdL0=3@d0410@00T92@07AdM02l_;`0V9RH0:b/[03Lg=`0b<S80@D5102<S8`0V9RH0=SHf02LW9`1:
BTX09RHV03`l?013@d<0C4a<05QHF010@400C4a<04i>CP1;Bd/0K6a/04Q8B01?Cdl0>CTi04Y:BP18
B4P0GemO03Xj>P0];Bd0>3Ph02d];@0f=SH0B4Q805YJFP1@D500ADE504e=C@14A4@0DU9B07inOP2B
TY80CTi>08F5Q@1nOWh0E5AD06QXJ00Q8B40MWIf06UYJ@14A4@0MgMg03Xj>P0Z:RX0=cLg01`L700a
<C40=3@d069RHP10@400GUiN03`l?01VIVH0T92@065QH@2/[:`0OWin05aLG01FEUH0E5AD03De=@1T
I6@0PH6107AdM00l?3`0@d=303De=@0E5AD0GemO06e]K@0f=SH0HV9R01XJ6P0l?3`0=cLg06a/K02A
TI40:BTY03hn?P0e=CD0JFUY0:^[Z`1aLG40F5QH07moO`13@d<0PH6104U9B@1;Bd/0H61P03<c<`0d
=3@0<c<c061PH00f=SH0HV9R065QH@0K6a/0A4A404E5A@0j>SX0H61P02/[:`1gMgL0QHF505IFEP2C
Ti<0Lg=c04=3@`1QHF4092@T069RHP0S8b<0N7Qh0080D51@05h0Hf=S02d];@2HV9P0E5AD08n?S`2N
WYh0>CTi0<?3``2QXJ40Ph>306i^KP1BDU80GEeM04E5A@1/K6`0ADE506IVIP1LG5`0Fe]K055AD@0e
=CD0K6a/03`l?02MWId0KFe]03`l?01eMGD0>CTi08J6QP1_Kfl0CDe=07YjNP1HF5P0QHF505YJFP1L
G5`0F5QH03dm?@0j>SX0Fe]K03<c<`0];Bd0@T9206EUI@0l?3`0A4A403<c<`1MGEd0G5aL02l_;`1W
IfL0EUIF03lo?`1]KFd0;Rh^03Ph>015ADD06ATI03Ph>01QHF40I6AT06][J`2HV9P0IFEU06ATI01@
D500De=C07UiN@1>CTh0EUIF05ADE01@D500@41004e=C@10@400D51@02l_;`0Z:RX0AdM703lo?`15
ADD08B4Q03@d=019BDT0LG5a06QXJ00b<S80@410069RHP11@D40B4Q805UIF@1EEED0FEUI0_ooool0
002N08J6QP2a/K40Lg=c08J6QP1ADE40L71`06][J`1KFe/0MWIf03hn?P0k>c/0MGEe08:2PP1GEeL0
O7al02h^;P0i>CT0GemO09BDU017AdL0CTi>07moO`0R8R80ATI605QHF01QHF40>CTi06YZJP13@d<0
>SXj04m?C`1ADE40;2`/03Xj>P0m?Cd0@d=304U9B@1iNGT09RHV02DU9@0g=cL0B4Q804E5A@1cLg<0
][Jf04a<C00N7Qh0CTi>071`L01YJFT0KFe]0<_;b`0];Bd09bLW061PH01ZJVX0F5QH0:FUY@1hN7P0
6ATI0492@P1dM7@0?clo05YJFP2ZZZX0ADE502TY:@1[Jf/0NGUi03lo?`2ZZZX0Cdm?02<S8`0];Bd0
JFUY06QXJ01VIVH0J6QX02<S8`0R8R80De=C07AdM00/;2`0GemO07=cL`0K6a/0?Cdm0:^[Z`22PX80
9BDU04m?C`0g=cL0>CTi03lo?`23Ph<0MWIf03Ti>@1NGUh0@D5103Xj>P1>CTh0QHF5059BDP0V9RH0
CTi>04I6AP1PH600PH610=?Cd`1CDe<09bLW04=3@`18B4P0EeMG08b<S01oOgl0:b/[04];B`1TI6@0
JFUY065QH@2YZJT0<C4a01`L7015ADD0Ti>C06=SH`2:RXX0TY:B01lO7`0];Bd0QXJ60:j^[P0l?3`0
MWIf08V9R@0R8R80<C4a07EeM@2_[jl0CDe=07YjNP1kNg/07alO03<c<`1UIFD0OGem04Q8B01bLW80
?Shn02PX:014A4@0EUIF04A4A00`<300XJ6Q02TY:@0T92@206EUI@2G04m?C`1^KVh0>CTi0410@02I
VIT0Rh^;04=3@`1PH600I6AT02d];@1aLG40QXJ606i^KP1ADE40GemO04U9B@1?Cdl0J6QX09jNWP11
@D40;2`/04Y:BP1IFET0@d=307emO@2TY:@0;2`/030`<019BDT0Lg=c04Y:BP2@T900Bd];02d];@1:
BTX0Jf][08^;R`1VIVH0YJFU03hn?P1MGEd0G5aL08b<S01HF5P0Ph>305IFEP0c<c<0IfMW08^;R`26
QXH0HF5Q0:j^[P1MGEd0ATI607EeM@3<c<`0Lg=c06IVIP14A4@0=cLg04I6AP2;Rh/0R8R805UIF@2:
RXX0<c<c04U9B@1/K6`0QhN704U9B@1MGEd0;2`/03<c<`1WIfL0SHf=04Q8B01`L700?3`l03@d=022
PX80Zj^[04i>CP11@D40Cdm?034a<@1dM7@0WinO04Q8B00f=SH0D51@05ADE016ATH0K6a/08>3P`0h
>3P0AdM705IFEP1HF5P0PH610;jn_P0k>c/0De=C05QHF01JFUX0KVi^0;6a/@1[Jf/0:BTY04M7A`1j
NWX0GemO0861P@3=cLd0DE5A03De=@10@400T92@09bLW01hN7P0SHf=06UYJ@0_;bl0?clo06a/K02@
T900GemO0:n_[`1HF5P0A4A405=CD`23Ph<0EeMG07EeM@2EUID0>CTi038b<P1dM7@0U9BD04E5A@10
@400Bd];024Q8@0O7al0Cdm?061PH015ADD0>SXj04i>CP0M7Ad0<C4a03lo?`0207]kN`0I03dm?@1G
EeL0<30`03/k>`0m?Cd0OGem075aL@1XJ6P0;Bd]04=3@`16ATH0GEeM05EEE@12@T80Fe]K065QH@13
@d<0CTi>05MGE`1BDU80B4Q805QHF02LW9`0PX:208f=S@0205eMG@1S04e=C@0W9bL0ATI603Hf=P0d
=3@0ADE505=CD`0i>CT0A4A404M7A`1IFET0K6a/04];B`0n?Sh0De=C061PH01TI6@0De=C05IFEP1I
FET0EeMG059BDP0j>SX0?3`l04Q8B00n?Sh0Cdm?03Xj>P1>CTh0D51@03/k>`18B4P0Bd];0410@00i
>CT0CTi>02DU9@1IFET0?Cdm02h^;P13@d<0;bl_04];B`0i>CT0<C4a03Ph>00i>CT0ADE5059BDP1D
E5@0C4a<04I6AP1<C4`0W9bL06IVIP0l?3`0A4A406UYJ@11@D40L71`02l_;`14A4@0GUiN02PX:00V
9RH0GemO05ADE01EEED0DE5A04Y:BP1<C4`0ADE504=3@`0h>3P0D51@03@d=01DE5@0=cLg02@T9016
ATH0@D5103/k>`0j>SX0?Shn04Y:BP0];Bd0<30`03Xj>P0e=CD0AdM703Hf=P18B4P0@D5103<c<`0/
;2`0<C4a04];B`0e=CD0?clo0080Cdm?05l0GUiN030`<01<C4`0@41006e]K@0i>CT0>c/k051@D00g
=cL0BDU904a<C00g=cL0>SXj030`<01:BTX0DU9B03lo?`1QHF40GemO059BDP2<S8`0J6QX02/[:`10
@4004Q8B05EEE@1JFUX0C4a<08b<S01KFe/0?Cdm0451@@0_;bl0DU9B01/K6`0b<S80:RXZ04I6AP0n
?Sh0E5AD09JFUP1OGel0_[jn07emO@1@D500?Shn06QXJ00S8b<0=cLg0451@@0m?Cd0<c<c05IFEP0d
=3@0=cLg07alO01ZJVX0<C4a04I6AP0Y:BT0@D51034a<@0k>c/0DE5A03Lg=`1;Bd/0ADE503<c<`14
A4@0@41006UYJ@2GUiL0Cdm?06i^KP16ATH0<30`04E5A@1<C4`0@D5105=CD`2JVYX0BDU90:>SX`2M
WId0820P05EEE@1?Cdl0GUiN07moO`16ATH0HV9R07=cL`0m?Cd0?Shn04E5A@0203@d=00^02XZ:P1`
L700=CDe04a<C013@d<0LW9b06m_K`17AdL0MgMg034a<@17AdL0GemO02/[:`0k>c/09bLW0861P@1L
G5`0=CDe03Xj>P0`<300Jf][02l_;`10@400FEUI05QHF00l?3`0<c<c07EeM@0g=cL0ADE504=3@`0k
>c/0Ogmo030`<01ADE40?clo03Xj>P1EEED0;bl_05aLG00^;Rh07QhN02`/;01=CDd0@D51034a<@80
@T9202X0?Shn03<c<`0o?cl0EEEE0451@@10@400?Shn0410@01=CDd0BDU904e=C@28R8P0;bl_03`l
?01WIfL0?Cdm06e]K@1=CDd0EUIF04Y:BP17AdL0H61P069RHP19BDT0>CTi0;2`/021PH40KVi^09:B
TP2@T900IVIV07YjNP1=CDd0MGEe03lo?`19BDT0EEEE04=3@`1DE5@0:BTY0410@013@d<208>3P`08
04a<C01=CDd0IfMW04U9B@1CDe<0C4a<059BDP1KFe/2ooooo`0004H0Kfm_05ADE02TY:@0][Jf055A
D@1=CDd0BDU905MGE`24Q8@0>3Ph02d];@14A4@0K6a/08R8R02j^[X0ADE5028R8P0[:b/0H61P05eM
G@2@T900/K6a02HV9P0j>SX0Bd];05UIF@1SHf<0UIFE05YJFP0F5QH0A4A407=cL`1ADE40M7Ad05iN
GP0I6AT0;Rh^079bLP1NGUh0Hf=S0;jn_P1RHV809BDU03`l?01hN7P0S8b<04Y:BP1eMGD0M7Ad02XZ
:P0W9bL0LW9b08b<S01TI6@0VIVI028R8P0];Bd0CDe=07inOP13@d<0JVYZ04m?C`0G5aL0?3`l06MW
I`0k>c/0?Cdm04e=C@0Z:RX0>c/k0P1HF5P0W`0U9BD0=CDe04m?C`0[:b/0Fe]K0:>SX`17AdL06QXJ
03hn?P1WIfL0?clo07]kN`2UYJD06QXJ018B4P0k>c/0Lg=c06ATI025QHD0L71`024Q8@0n?Sh0IfMW
05]KF`1PH600WIfM08N7Q`0K6a/0EEEE08>3P`1TI6@0GEeM0:NWY`15ADD09bLW04I6AP23Ph<0KVi^
051@D01`L700:RXZ0410@01JFUX0OWin04i>CP1iNGT0DU9B020P800n?Sh0Q8B40861P@0h>3P0Bd];
0410@00i>CT0FEUI071`L01?Cdl0;bl_0410@019BDT0A4A406IVIP2JVYX0>SXj02XZ:P18B4P0FUYJ
04Y:BP1dM7@0WIfM034a<@0X:2P0?3`l05IFEP18B4P0[Jf]09jNWP0V9RH0=3@d05YJFP1:BTX0DU9B
0=KFeP1FEUH071`L03`l?01KFe/0Ph>30;2`/00c<c<0?clo05eMG@1GEeL0IVIV0:f][@2QXJ409RHV
04=3@`1fMWH0PH61096AT@2k^k/0VYZJ02l_;`14A4@0PX:2092@T01fMWH0Y:BT04=3@`0[:b/0ATI6
059BDP1[Jf/0I6AT08^;R`1BDU80B4Q806][J`1YJFT0>CTi06m_K`1fMWH0=SHf03dm?@1aLG40F5QH
0492@P1iNGT0EEEE04m?C`1HF5P0OWin04M7A`0k>c/0DU9B05QHF01LG5`0NWYj05MGE`0S8b<0>3Ph
05QHF01>CTh0Ogmo06QXJ00V9RH0?clo0410@01CDe<0SHf=0<71`@10@400;Rh^06e]K@1NGUh0IfMW
09^KV`0202`/;01X051@D01TI6@0EUIF09RHV016ATH07alO03Hf=P1dM7@0FEUI08F5Q@1]KFd0=CDe
04e=C@1IFET0HV9R06IVIP2:RXX0<30`03De=@1FEUH0Kfm_04];B`2BTY80@T9202l_;`1WIfL0KVi^
04=3@`19BDT0Ogmo03`l?00b<S80K6a/0;Vi^@1ZJVX0GEeM071`L00V9RH0?3`l06a/K01cLg<0CTi>
09FEU@1_Kfl0<S8b04m?C`1aLG40TI6A04a<C00n?Sh0E5AD030`<01=CDd0/k>c071`L00[:b/0@410
0451@@0l?3`0HV9R09jNWP1iNGT08b<S03`l?01PH600EEEE06UYJ@1[Jf/0:2PX01<C4`0a<C40HF5Q
0492@P1IFET0O7al01lO7`0W9bL0=3@d04i>CP0g=cL0?clo071`L00];Bd09BDU03Xj>P1@D500M7Ad
06ATI00_;bl0?3`l065QH@1]KFd0Fe]K04a<C01KFe/0K6a/03lo?`15ADD0FUYJ06IVIP1oOgl0KFe]
08F5Q@1mOGd205eMG@0:05QHF01=CDd09BDU04I6AP0X:2P0;2`/03@d=00o?cl0ATI605]KF`<0ATI6
0:d0?clo03Ti>@1=CDd0>c/k04I6AP10@400D51@04M7A`11@D40AdM7028R8P0O7al0<C4a04I6AP1;
Bd/08b<S02HV9P0b<S80@D5102`/;00[:b/0=CDe03lo?`14A4@0>3Ph05ADE00g=cL0:RXZ04A4A00c
<c<0Hf=S038b<P0_;bl0?3`l03Ph>01IFET0CTi>04E5A@1@D500AdM704Q8B01DE5@0Cdm?0492@P16
ATH0A4A403Xj>P1@D500?clo03Xj>P1CDe<0;Bd]03`l?01FEUH0Fe]K059BDP1JFUX0EUIF04E5A@1;
Bd/0AdM703Hf=P1ZJVX09BDU03lo?`0c<c<0ATI603Ph>00e=CD0?clo04a<C00d=3@0ADE502XZ:P0i
>CT0Bd];02PX:019BDT0=cLg04M7A`0h>3P0@d=303Hf=P0j>SX0@T9203/k>`11@D40GemO0492@P1A
DE40=CDe059BDP14A4@0HV9R05EEE@14A4@0DE5A03<c<`0a<C40AdM703dm?@1DE5@0@D5105=CD`1>
CTh0B4Q807UiN@2FUYH0I6AT07alO01^KVh0@T9205eMG@0B4Q80H61P05iNGP0g=cL0KVi^03Ph>01J
FUX0De=C02TY:@0j>SX0=3@d04Y:BP0U9BD0BTY:071`L012@T80Ph>3034a<@1bLW80DE5A06YZJP1J
FUX0?Cdm02`/;01HF5P0OGem06a/K00h>3P0J6QX03hn?P0P8200IfMW07moO`19BDT0De=C038b<P1F
EUH0?3`l05ADE01gMgL0>c/k06i^KP13@d<0A4A406i^KP1NGUh0KVi^08^;R`16ATH0J6QX030`<00o
?cl0EeMG05YJFP1BDU80AdM705]KF`11@D40B4Q805eMG@0203<c<`0904E5A@0f=SH0DE5A04];B`1b
LW80SXj>051@D01KFe/0F5QH0080@D5106@0:BTY04e=C@0f=SH0F5QH05EEE@14A4@0E5AD04A4A028
R8P0@T9207AdM025QHD06a/K0410@01aLG40NWYj06a/K00l?3`0ATI602d];@1JFUX0?clo04Y:BP1@
D500EUIF04E5A@0d=3@0Fe]K04=3@`1VIVH0Cdm?02`/;01MGEd07alO06IVIP1=CDd0=CDe05YJFP0g
=cL0Lg=c05ADE01>CTh0FUYJ065QH@1DE5@0CTi>05YJFP1NGUh0@d=3059BDP0[:b/0IfMW03De=@0a
<C40AdM704=3@`1bLW80@T9206EUI@1^KVh0?3`l03dm?@10@400>CTi02/[:`1<C4`0CDe=05eMG@1[
Jf/0Fe]K069RHP1oOgl0F5QH09fMW@1KFe/0LG5a07QhN02=SHd0KVi^07]kN`1VIVH0H61P03dm?@1<
C4`0GUiN03De=@15ADD06ATI0451@@0f=SH0EEEE06ATI01CDe<0B4Q804a<C01BDU80DE5A05eMG@1l
O7`0GemO0_ooool0003o0;Fe]@1BDU80DU9B075aL@1^KVh0Ng]k03Hf=P1CDe<0DE5A04U9B@1KFe/0
OGem028R8P0a<C40Hf=S07QhN00i>CT0Kfm_05=CD`0Y:BT0AdM708n?S`1FEUH0B4Q804m?C`0J6QX0
;Bd]06][J`2NWYh0@D5106QXJ00i>CT07alO05QHF02;Rh/0?Shn03Ph>01LG5`0:BTY02LW9`1[Jf/0
TI6A02PX:00j>SX0EeMG04I6AP0f=SH0M7Ad096AT@0V9RH0:2PX03Lg=`11@D40WIfM0:FUY@1;Bd/0
5ADE04E5A@1EEED0E5AD0;Jf]P1kNg/09bLW04I6AP20P800Hf=S08V9R@2YZJT0<C4a02l_;`1?Cdl0
OWin07=cL`1bLW80SHf=03Ph>00S8b<0A4A4069RHP0m?Cd0MGEe02l_;`0Q8B40@T9208Z:RP1aLG40
EeMG07EeM@0V9RH0;2`/07YjNP2OWil0@d=304E5A@1RHV80=3@d04A4A01hN7P0TI6A05ADE016ATH0
EUIF030`<019BDT0Q8B409RHV00W9bL0=cLg04e=C@0j>SX0EEEE09FEU@1LG5`08b<S04a<C01WIfL0
IVIV08^;R`1`L7008b<S02TY:@1=CDd0O7al04i>CP23Ph<0I6AT02/[:`19BDT0J6QX04m?C`1UIFD0
Ph>303Xj>P0h>3P0BTY:06m_K`1cLg<0Fe]K0:VYZ@1IFET0?3`l05MGE`20P800L71`06m_K`26QXH0
<S8b03Lg=`1SHf<0RXZ:05=CD`1mOGd0PX:202TY:@10@400L71`08^;R`1jNWX0MgMg03De=@0f=SH0
X:2P0;Rh^01RHV80RXZ:04U9B@0[:b/0K6a/0=kNgP2=SHd0EEEE07IfMP0b<S80=3@d06MWI`2h^;P0
F5QH03lo?`1:BTX09bLW05UIF@2_[jl0KFe]02d];@1;Bd/0H61P03@d=01NGUh0];Bd0:VYZ@0e=CD0
CDe=07=cL`1=CDd0UiNG0:NWY`0e=CD0BDU9059BDP1NGUh0Kfm_0;2`/01mOGd0>3Ph05eMG@1cLg<0
JVYZ0;>c/`28R8P08R8R03De=@15ADD0P820055AD@23Ph<0GEeM02LW9`1QHF40Q8B404a<C01SHf<0
Ph>3024Q8@0h>3P0]kNg09:BTP17AdL0EUIF03hn?P0c<c<0KVi^08:2PP0g=cL0L71`03/k>`0m?Cd0
Ogmo09nOW`0o?cl0FEUI05EEE@0b<S80@D5106m_K`0k>c/0AdM7059BDP0/;2`0@T9207alO01XJ6P0
9bLW06ATI019BDT0E5AD000F07IfMP1_Kfl0;Bd]04M7A`1RHV80?clo08F5Q@2a/K40FEUI02@T900o
?cl0KVi^061PH02>SXh0TY:B03Hf=P0g=cL0Bd];05aLG011@D40V9RH0:6QX@80>SXj0440BDU908>3
P`20P800TI6A0:b/[017AdL0;Rh^069RHP2VYZH0Shn?09FEU@1@D5008R8R03Ph>01^KVh0VIVI061P
H01oOgl0MWIf028R8P16ATH0K6a/061PH00k>c/0GemO05iNGP0S8b<0AdM707IfMP1CDe<0=3@d05EE
E@0i>CT07AdM03/k>`1nOWh0EUIF01dM7@1;Bd/0@D5105YJFP1RHV80ATI603hn?P18B4P0C4a<04A4
A01<C4`0BTY:059BDP1?Cdl0?clo05EEE@1nOWh0MWIf06YZJP1eMGD0FEUI05MGE`1SHf<0CDe=04Y:
BP0c<c<0AdM703dm?@0204=3@`80<c<c01@0?3`l04m?C`1XJ6P0QHF505MGE`0l?3`0AdM704m?C`1M
GEd0@T9204e=C@1OGel0FEUI04];B`0b<S808B4Q02h^;P0Y:BT0@d=303/k>`80?3`l04l0:2PX03Ph
>00m?Cd0@d=302`/;017AdL09RHV03hn?P0f=SH0;Bd]03<c<`0U9BD0@d=302h^;P0i>CT0?clo030`
<00/;2`0>3Ph04e=C@14A4@0G5aL04i>CP1aLG40IfMW03Ph>010@400EeMG05QHF01RHV809RHV034a
<@1<C4`0:BTY024Q8@1?Cdl0B4Q804A4A012@T80A4A403dm?@0n?Sh0>CTi02/[:`1<C4`0<c<c04I6
AP0];Bd09RHV0410@00n?Sh0?clo03De=@0b<S80?Shn02`/;00P8200;Bd]03Lg=`0h>3P0:BTY03<c
<`1<C4`0@41004U9B@0a<C40ADE5030`<01JFUX0HV9R04Y:BP1EEED0BDU905QHF01MGEd0UYJF05AD
E01ADE40EEEE0080ADE506H0B4Q80492@P1EEED0:2PX03lo?`1<C4`0=CDe04m?C`1]KFd0@T9208J6
QP1TI6@0@41005UIF@0N7Qh0MgMg0820P01ADE40K6a/03dm?@17AdL0H61P034a<@1ADE40>3Ph05MG
E`0a<C40<c<c03Ti>@14A4@0/k>c03Xj>P36a/H0JVYZ04E5A@1;Bd/0EEEE03`l?00_;bl0A4A404m?
C`0a<C40?Shn02d];@0N7Qh0Ogmo06=SH`0d=3@0GemO02DU9@0m?Cd0:b/[05=CD`2BTY80:b/[04a<
C015ADD0>c/k07EeM@1JFUX0HF5Q0820P013@d<0FUYJ02/[:`0n?Sh0FUYJ059BDP1<C4`0GemO0861
P@1PH600EEEE051@D00];Bd0>CTi04];B`14A4@0E5AD04Y:BP2LW9`0XZ:R055AD@1JFUX0BTY:05YJ
FP1NGUh0@T9205ADE00`<300N7Qh06ATI018B4P0EeMG04Y:BP2?Shl0IVIV07moO`2:RXX0;Bd]02/[
:`2IVIT204a<C00<07IfMP1PH600?Shn07AdM01<C4`0HF5Q05iNGP1MGEd0D51@04a<C01XJ6P0D51@
0P1RHV80A@1SHf<0Ogmo05ADE01RHV80J6QX05=CD`1ZJVX0@d=308n?S`1@D500>CTi04i>CP0k>c/0
;bl_04Q8B00a<C40<S8b03lo?`1LG5`0:b/[051@D01FEUH0DU9B04e=C@1FEUH0CTi>05aLG01CDe<0
IFEU03Ph>018B4P0DE5A038b<P0f=SH0C4a<05MGE`1TI6@0Lg=c06IVIP1YJFT0Ph>305IFEP2^[Zh0
P820051@D01bLW80MWIf061PH01]KFd0ATI606ATI01NGUh0Hf=S07UiN@1=CDd0D51@02/[:`1KFe/0
ATI607IfMP1[Jf/0BDU9051@D01QHF40ADE504e=C@1KFe/0Cdm?051@D002ooooo`000>l0W9bL079b
LP20P800EEEE04m?C`2:RXX0CTi>0410@01`L700D51@05MGE`2l_;`0QHF503Ph>01<C4`0@d=303hn
?P2XZ:P0KFe]02DU9@0Y:BT0D51@03De=@1UIFD0UiNG02DU9@0W9bL0?clo04E5A@1UIFD0b<S803lo
?`0Y:BT0=cLg069RHP1KFe/0R8R80;>c/`0X:2P0ADE503dm?@1fMWH0@4100:VYZ@3Lg=`08B4Q028R
8P1@D500XZ:R08b<S02CTi<0VYZJ01<C4`19BDT0RHV909ZJVP19BDT0P8200492@P0L71`0AdM707Ad
M010@400FEUI03Hf=P0F5QH0>CTi04E5A@14A4@0;2`/04i>CP0/;2`07AdM075aL@2:RXX0FUYJ03@d
=01KFe/09RHV02TY:@22PX80JVYZ01`L700a<C40@D5105EEE@1cLg<0SHf=04i>CP0I6AT0<C4a05AD
E01/K6`0GemO09RHV00c<c<06ATI03Ph>01/K6`0G5aL0:6QX@2GUiL071`L02HV9P1<C4`0RHV906=S
H`2PX:00TY:B02d];@14A4@0I6AT09^KV`1aLG40^;Rh07AdM00/;2`0K6a/079bLP1VIVH0KFe]0;Ng
]`0Y:BT0>SXj06=SH`1TI6@0>3Ph069RHP1PH600?Cdm03Ph>01iNGT0MGEe02`/;01KFe/0IfMW02PX
:012@T80HF5Q06=SH`0Z:RX0De=C05EEE@0Y:BT0K6a/09NGU`1LG5`0=cLg06=SH`1DE5@0<c<c09NG
U`3Kfm/0Bd];03lo?`1?Cdl0<S8b04A4A02/[:`0GemO03Lg=`1LG5`0B4Q805]KF`30`<00@d=302l_
;`10@400VIVI08>3P`1dM7@0[Zj^03<c<`0j>SX0ADE507YjNP25QHD0S8b<071`L00O7al0:RXZ04];
B`21PH40Bd];06UYJ@1eMGD0<30`02/[:`1DE5@0[:b/06ATI01kNg/0;bl_02d];@0m?Cd0E5AD05iN
GP1FEUH0H61P020P800c<c<0BDU907MgM`0c<c<0C4a<04I6AP0U9BD0E5AD0:6QX@1OGel0CDe=06EU
I@0n?Sh0=CDe0820P02OWil0ADE503<c<`0m?Cd0@d=307EeM@2?Shl0F5QH034a<@1NGUh0>3Ph07]k
N`2f][H0BDU902d];@14A4@0Bd];05EEE@2l_;`0Fe]K024Q8@1:BTX0KVi^05UIF@020:6QX@1a03/k
>`0g=cL0DU9B04I6AP2RXZ80T92@020P8016ATH0D51@05aLG01=CDd0_kno05ADE00X:2P0R8R80:BT
Y01;Bd/0U9BD08N7Q`0k>c/0>SXj07alO028R8P0GUiN07moO`13@d<0>c/k03hn?P24Q8@0Kfm_05YJ
FP1XJ6P09RHV02`/;01DE5@0HV9R05iNGP1;Bd/0H61P04i>CP0R8R80E5AD06ATI01MGEd0E5AD08F5
Q@0e=CD0<c<c09:BTP22PX80>3Ph03hn?P1OGel0@T920410@02;Rh/0L71`02LW9`0^;Rh0AdM705=C
D`11@D40NGUi075aL@0Z:RX07alO04Y:BP1CDe<0GEeM09fMW@1VIVH05ADE02d];@0k>c/0L71`03/k
>`2EUID0Q8B405mOG`1WIfL0<30`03@d=01<C4`0GUiN04];B`0k>c/0MGEe08Z:RP0g=cL0Cdm?05eM
G@1LG5`0FUYJ07emO@1fMWH0EUIF071`L018B4P0?Shn04A4A00h>3P0ATI603De=@0a<C40>CTi04Y:
BP0l?3`0A4A402@T900N7Qh0;bl_03`l?00f=SH00P0c<c<0?01;Bd/0?Cdm0492@P0d=3@0;bl_04];
B`0k>c/0?Shn02`/;00e=CD0?clo03dm?@14A4@0=3@d038b<P1:BTX0CDe=03Ti>@0h>3P0CTi>03dm
?@1NGUh0>3Ph02DU9@0n?Sh08B4Q04Y:BP0R8R807QhN02TY:@0h>3P0C4a<03<c<`0V9RH0;Rh^04Y:
BP0d=3@0DU9B05MGE`1KFe/0Hf=S05ADE00/;2`0GUiN03hn?P0m?Cd0HV9R02DU9@0/;2`0IFEU04U9
B@1<C4`0EeMG04m?C`1@D500DE5A0451@@0a<C40GemO02DU9@80=cLg03d0>c/k04M7A`0l?3`0?Cdm
04I6AP0n?Sh0@41002`/;00c<c<0A4A402<S8`1:BTX09RHV03hn?P0b<S80@T9202XZ:P0m?Cd0@T92
02LW9`0h>3P0@T9204i>CP1BDU80?clo03dm?@16ATH0De=C03`l?016ATH0B4Q803De=@0`<300>CTi
03Hf=P1:BTX0?3`l04];B`1EEED0@T92071`L01^KVh0=cLg07YjNP1YJFT0A4A408F5Q@10@400B4Q8
05EEE@0o?cl0P82004Y:BP19BDT0Cdm?04M7A`1EEED0<C4a07moO`0k>c/0@D510080DE5A00T0OWin
05IFEP1[Jf/0DE5A061PH01EEED0JVYZ03Xj>P12@T800P1NGUh0F`0Z:RX0LW9b05IFEP0Z:RX0K6a/
06i^KP0k>c/0>SXj01XJ6P1>CTh0>3Ph04A4A01MGEd0A4A4069RHP0i>CT0<c<c06QXJ01BDU80Jf][
08Z:RP13@d<0EEEE00h>3P0`<300EEEE051@D016ATH0EeMG09:BTP1:BTX0H61P051@D00/;2`0ADE5
04];B`1MGEd0Lg=c04A4A01PH600KVi^04M7A`1hN7P0E5AD03<c<`0e=CD0:2PX06UYJ@0n?Sh0A4A4
03/k>`1BDU80Bd];04Q8B02@T900FUYJ07=cL`2@T900J6QX03/k>`29RHT0GEeM04e=C@19BDT0HF5Q
03<c<`1KFe/0<C4a065QH@1:BTX0EEEE04=3@`0k>c/0HF5Q04A4A02<S8`0NGUi03/k>`1fMWH07AdM
075aL@1[Jf/0BTY:07MgM`0^;Rh0JVYZ0492@P0L71`0:BTY02PX:00V9RH00P12@T805`1;Bd/0@T92
0410@014A4@0FEUI05EEE@1LG5`0De=C04=3@`1;Bd/0CDe=061PH01RHV80?Cdm06EUI@1LG5`0:b/[
03@d=01BDU80EeMG06ATI02<S8`0J6QX0080M7Ad01`0Hf=S0;>c/`1`L700>3Ph07AdM01iNGT0KFe]
075aL@13@d<0EeMG02PX:00o?cl0FEUI04Y:BP1NGUh0;2`/0451@@10@400WinO0:>SX`1ADE40DU9B
07IfMP1?Cdl0DE5A05QHF01EEED0HF5Q0_ooool0002m06=SH`1UIFD0Z:RX07alO013@d<0JVYZ07]k
N`1UIFD0UIFE03Ph>01>CTh0Jf][08n?S`2LW9`0dM7A02h^;P11@D40>c/k07moO`26QXH0Ti>C08B4
Q00^;Rh0@T9204e=C@1:BTX0GEeM08>3P`12@T80<30`08F5Q@29RHT0=3@d04i>CP0o?cl09bLW03Xj
>P2@T900@D5102d];@1EEED0?Cdm01lO7`0a<C40Rh^;06a/K00^;Rh0EeMG03Lg=`0];Bd0EEEE07em
O@0X:2P0=cLg04U9B@1DE5@0PX:20::RXP0a<C40820P03hn?P14A4@0?3`l08>3P`2DU9@08R8R02PX
:01NGUh0DU9B05mOG`2_[jl0KFe]01dM7@0f=SH0Ogmo08f=S@1MGEd0UIFE02d];@0O7al0@T9208^;
R`1?Cdl0Ph>3071`L00G5aL0=SHf04e=C@1FEUH0ATI607IfMP1KFe/06ATI030`<01FEUH0Hf=S02PX
:01/K6`0F5QH01TI6@0j>SX0QhN7055AD@0b<S80JFUY03`l?00f=SH0GEeM08R8R01:BTX0?Cdm051@
D00X:2P0<C4a05YJFP29RHT0A4A406ATI01[Jf/0;Bd]04U9B@2][Jd0TI6A02d];@15ADD0HV9R04I6
AP1gMgL0U9BD02d];@0`<300ATI607IfMP14A4@0YZJV0<30`00`<300;Bd]055AD@2<S8`0Bd];09RH
V02>SXh09bLW038b<P1cLg<0SHf=0410@02ATI40BTY:03@d=013@d<0LW9b07UiN@1XJ6P0R8R802DU
9@0f=SH0?3`l07UiN@18B4P0JVYZ02l_;`1<C4`0IFEU06m_K`0l?3`0CDe=0492@P0c<c<0FEUI06a/
K01QHF40D51@07inOP1ADE40:BTY0820P02l_;`0JFUY03Lg=`1ADE40ATI603Ph>01[Jf/0WIfM03Ph
>00[:b/0D51@0080CTi>0440YjNW06UYJ@0J6QX0?clo05]KF`1MGEd0Lg=c0;Ng]`0a<C409bLW05eM
G@1WIfL0DU9B07moO`28R8P0820P03Xj>P1IFET0JVYZ06QXJ02YZJT0<30`02d];@11@D40HF5Q05eM
G@2EUID0QXJ601XJ6P1GEeL0YJFU0:^[Z`1TI6@0Z:RX02d];@1:BTX0JVYZ07]kN`1BDU80KVi^02HV
9P0S8b<0KFe]07UiN@1TI6@0MWIf034a<@0V9RH0@41007YjNP1EEED0H61P04E5A@0/;2`0K6a/0;^k
^`1MGEd0CDe=061PH00U9BD0ATI6096AT@1XJ6P0A4A406EUI@020492@P3o05iNGP2?Shl0AdM70410
@01>CTh0C4a<061PH021PH40Lg=c03Hf=P16ATH0FUYJ04Y:BP1dM7@0R8R804I6AP0U9BD0CTi>05]K
F`1LG5`0JVYZ07IfMP2[Zj/0<C4a04=3@`1KFe/0CTi>08V9R@3@d=00?3`l02<S8`1IFET0KFe]06YZ
JP2SXj<0Y:BT02XZ:P1<C4`0JFUY07=cL`1ADE40HF5Q07QhN00O7al0:BTY03@d=01XJ6P0@T9204i>
CP1<C4`07QhN02d];@17AdL0IFEU0410@00j>SX0HF5Q034a<@0/;2`0C4a<05eMG@1`L700B4Q8028R
8P0n?Sh0OGem06MWI`1ADE40>CTi0410@00k>c/0<S8b03<c<`1=CDd0IVIV061PH01cLg<0K6a/059B
DP1cLg<0E5AD05YJFP13@d<05aLG0410@00P8200<30`0410@01>CTh0De=C04M7A`1CDe<0HF5Q05iN
GP1CDe<0?3`l069RHP1UIFD0OWin051@D01:BTX0HF5Q04a<C01MGEd0=CDe03Ph>014A4@0=SHf04e=
C@0d=3@0?Shn055AD@0c<c<0>CTi03Lg=`1<C4`0>3Ph03dm?@0/;2`0@D5102`/;00Q8B40?3`l03@d
=01EEED09bLW02@T900/;2`0:b/[02d];@0k>c/0<30`04a<C01=CDd0BTY:06=SH`1KFe/09RHV02XZ
:P1BDU80=3@d05EEE@0k>c/0EEEE04A4A00N7Qh09BDU04e=C@1RHV80D51@0492@P0k>c/0;2`/0492
@P0f=SH0;Bd]03Ti>@0P8200=CDe02d];@0m?Cd0;Bd]03Xj>P0c<c<0?clo03Ti>@0o?cl0820P03De
=@0h>3P0<C4a0492@P0e=CD0>3Ph03dm?@13@d<0CTi>03lo?`1ADE40<30`04=3@`1=CDd0@d=3055A
D@0j>SX0D51@04I6AP1jNWX0?clo05EEE@1CDe<0;bl_03/k>`0b<S80=SHf04U9B@0R8R80=cLg04U9
B@0l?3`0Fe]K07AdM00];Bd0GemO069RHP1FEUH0M7Ad02DU9@1KFe/0D51@03De=@1MGEd0>3Ph08V9
R@1OGel0<30`04e=C@0f=SH0A4A403Ti>@1DE5@0:RXZ03hn?P2SXj<0=3@d0;6a/@1?Cdl0KFe]05AD
E01:BTX0;2`/03hn?P1SHf<0H61P02LW9`1CDe<0>c/k00D51@22PX80IfMW030`<01CDe<0;Rh^04];
B`0n?Sh0ADE508:2PP0Y:BT0BTY:03Hf=P0^;Rh0I6AT04Q8B011@D40GemO0040=cLg0@1/K6`203Hf
=P1_05QHF01ZJVX0Cdm?0451@@1[Jf/0=SHf07EeM@1VIVH06ATI02TY:@0R8R8092@T04A4A00c<c<0
WIfM0:JVYP14A4@0ADE504M7A`1MGEd0F5QH03Lg=`0n?Sh0>3Ph079bLP1QHF40@T9204M7A`1?Cdl0
ZJVY04U9B@1fMWH0UiNG05iNGP15ADD0GEeM03dm?@1CDe<0F5QH065QH@0o?cl0CTi>0410@01GEeL0
DU9B05mOG`1?Cdl0@D5107inOP1BDU80CTi>04e=C@1CDe<0Ph>30492@P16ATH0CTi>03Ph>01NGUh0
?3`l06][J`1NGUh0>c/k04I6AP0e=CD0?Shn051@D01PH600QHF505QHF01LG5`0>SXj06e]K@0l?3`0
?clo04i>CP1:BTX0De=C04a<C01OGel0QhN706YZJP0o?cl0Hf=S030`<01JFUX0GemO07=cL`1FEUH0
J6QX05YJFP2ATI40O7al055AD@2=SHd0HV9R04A4A027QhL0Fe]K07alO01QHF40Hf=S07emO@14A4@0
GemO079bLP1BDU80J6QX03Hf=P1FEUH0>CTi0080LG5a00H0FEUI03dm?@1BDU80BDU904E5A@17AdL2
05UIF@;ooooo0000Z`2EUID0CTi>055AD@2EUID0F5QH071`L00o?cl0BTY:06QXJ01LG5`0@41006e]
K@0e=CD0>c/k07QhN01RHV80<S8b04U9B@0b<S80:2PX05]KF`2IVIT0;Bd]03Ti>@1:BTX0?Shn05QH
F022PX80A4A401hN7P13@d<0GemO04m?C`2>SXh0HF5Q02LW9`0Q8B40@d=30492@P1?Cdl0[jn_07=c
L`0W9bL08b<S04=3@`1RHV80F5QH0<C4a01RHV80<30`05mOG`1SHf<0?clo06m_K`39bLT0<C4a02l_
;`2EUID0OGem06ATI029RHT0?Shn02TY:@1@D500W9bL05aLG01SHf<0J6QX02/[:`0M7Ad0Bd];05UI
F@0_;bl0EeMG05ADE00/;2`0EUIF07YjNP1KFe/0<C4a06UYJ@0f=SH0<S8b0451@@23Ph<0>CTi03/k
>`1]KFd0:BTY04E5A@1MGEd0OGem01TI6@0Y:BT0G5aL05MGE`1XJ6P0U9BD09VIV@0W9bL0;2`/04Y:
BP10@400Hf=S0:j^[P19BDT0<C4a04U9B@1ADE40BTY:06i^KP2TY:@0@D5102LW9`1IFET0SHf=06UY
J@2FUYH0S8b<0451@@0a<C40?Shn0861P@1;Bd/0Ti>C07AdM00P8200@T9205=CD`1XJ6P0ADE506UY
J@0k>c/0;Rh^04i>CP1aLG40GUiN04m?C`27QhL0@d=303Lg=`1QHF40M7Ad04U9B@1=CDd0FUYJ034a
<@15ADD0EEEE07alO00e=CD0HF5Q06=SH`0_;bl0G5aL0:FUY@1@D500;Rh^05=CD`1NGUh0MgMg0:VY
Z@0h>3P0@41005iNGP1OGel0E5AD07alO021PH409bLW04I6AP0208N7Q`2/05=CD`2^[Zh0GUiN0410
@00_;bl0M7Ad07alO01OGel0SXj>02`/;00j>SX0>c/k06QXJ023Ph<0NWYj092@T00Z:RX0>SXj04M7
A`1YJFT0A4A407MgM`1dM7@0?3`l04a<C01kNg/0MGEe04E5A@1aLG40F5QH04Y:BP1ADE40XZ:R04m?
C`1JFUX0ADE503dm?@1:BTX0PH610:6QX@0n?Sh0HV9R04i>CP0e=CD0H61P08Z:RP0c<c<0;Rh^034a
<@0h>3P0GUiN08n?S`1TI6@0;2`/05YJFP0e=CD0HF5Q0<?3``18B4P09RHV051@D00c<c<0H61P0;Vi
^@1VIVH09bLW03/k>`1NGUh0KVi^0;Zj^P24Q8@0<30`0410@01IFET0D51@08R8R02?Shl08b<S03/k
>`1UIFD0L71`05mOG`2^[Zh0M7Ad02LW9`1HF5P0LW9b051@D01`L700FEUI0451@@19BDT0JVYZ09jN
WP1iNGT0Shn?09RHV01DE5@0CDe=09BDU01oOgl0D51@0:^[Z`2=SHd0?Shn03Lg=`1EEED0NWYj061P
H01=CDd0J6QX03<c<`0i>CT0YjNW0;Bd]01=CDd0M7Ad0451@@0m?Cd0EeMG09fMW@1[Jf/0=SHf0861
P@0m?Cd0>c/k05YJFP2a/K40J6QX020P8018B4P0Bd];03@d=01EEED0Shn?02`/;00O7al0<c<c061P
H011@D40GUiN0:>SX`0i>CT09RHV04Y:BP1?Cdl0Q8B406][J`11@D40>SXj03dm?@1DE5@0De=C0410
@01HF5P0De=C01PH600f=SH0CDe=07inOP1ZJVX0G5aL04e=C@1:BTX0J6QX05YJFP1>CTh0De=C03/k
>`14A4@0=cLg0492@P80ADE506T0=CDe0451@@1>CTh0JFUY0861P@1;Bd/0=3@d05=CD`1hN7P0G5aL
04m?C`1EEED0GUiN06IVIP1DE5@0>SXj03Ph>00f=SH0@D51059BDP1DE5@0LW9b05=CD`17AdL0BTY:
05aLG01=CDd0<C4a05EEE@0c<c<0CTi>034a<@0O7al0;Bd]01dM7@10@400Cdm?02`/;00f=SH0BTY:
059BDP16ATH0;Rh^05IFEP1=CDd0HV9R06ATI01ZJVX0?Shn04E5A@1`L700=SHf06][J`0/;2`0:BTY
02`/;00];Bd0>c/k04];B`11@D40A4A4059BDP1>CTh0BDU9055AD@1FEUH0AdM704e=C@0a<C40>SXj
03Ti>@0d=3@0E5AD03dm?@12@T80ADE50410@00n?Sh0<c<c02l_;`1<C4`0;Rh^04m?C`0g=cL0@D51
038b<P0h>3P0;Bd]034a<@12@T80;2`/05]KF`1EEED0@T92055AD@17AdL0EUIF04I6AP1YJFT0=CDe
038b<P0c<c<0=CDe04M7A`0Z:RX00P0b<S80P00/;2`0=cLg04I6AP0_;bl0B4Q804m?C`0o?cl0ZZZZ
07]kN`15ADD0Ph>3024Q8@1[Jf/0MgMg04Y:BP1MGEd0>c/k05]KF`1[Jf/0;Rh^04Y:BP0e=CD0De=C
04M7A`12@T80?Shn04A4A01aLG40@D510;Rh^01UIFD0K6a/051@D01EEED08B4Q03Ph>01<C4`0GemO
02HV9P1QHF40BTY:020P801@D500Jf][034a<@1kNg/071`L05mOG`0/;2`0;bl_04m?C`0Y:BT0NGUi
04Q8B00];Bd0EUIF03Xj>P1PH600L71`01TI6@1GEeL0:BTY02LW9`18B4P0DU9B04I6AP1DE5@0YjNW
03`l?013@d<0BDU901DE5@18B4P0>SXj04I6AP1NGUh0=SHf04e=C@1NGUh0CTi>051@D01=CDd0@T92
03Hf=P0k>c/0Cdm?03@d=019BDT0>CTi04i>CP12@T80@41007QhN014A4@0Cdm?04];B`0g=cL0?Shn
059BDP19BDT0CTi>05=CD`1PH600E5AD05IFEP0j>SX0Fe]K04Y:BP1BDU80CDe=04Y:BP1SHf<0ADE5
06QXJ01aLG40AdM705mOG`15ADD0EEEE065QH@1=CDd0IVIV04E5A@2BTY80QXJ604Q8B01:BTX0ADE5
0`1FEUH0;@1QHF40=cLg04E5A@14A4@0G5aL03lo?`1:BTX0CTi>04a<C023Ph<0NGUi04m?C`1<C4`0
7QhN04=3@`1NGUh0?3`l03lo?`1:BTX0H61P051@D01[Jf/0DU9B055AD@1NGUh0M7Ad0:RXZ01LG5`0
IfMW0;:b/P1LG5`0Lg=c04e=C@0g=cL0Fe]K02`/;00i>CT0ADE504A4A01RHV80?Cdm03lo?`0d=3@0
TI6A07inOP0204M7A`0606i^KP1?Cdl0BDU906ATI01QHF40Fe]K0_ooool0000j0:>SX`1QHF40EUIF
05aLG01WIfL0^[Zj05IFEP12@T80DE5A05MGE`1bLW80[Zj^04M7A`0b<S80C4a<04e=C@1RHV80_kno
06QXJ00T92@0Bd];05ADE01=CDd0U9BD075aL@0E5AD0@d=305UIF@1RHV80EEEE0;>c/`0Q8B40;bl_
065QH@1IFET0GemO04a<C01SHf<06QXJ02PX:00_;bl0GUiN03hn?P1oOgl0JFUY028R8P0k>c/0OWin
08R8R00Y:BT0C4a<05IFEP0J6QX0FEUI0;2`/01RHV80>3Ph05eMG@80=cLg08X0S8b<03/k>`0M7Ad0
=CDe061PH00c<c<0FUYJ096AT@0_;bl051@D03<c<`13@d<0:b/[09>CT`2KVi/0B4Q802PX:01DE5@0
GUiN04U9B@2l_;`0GemO020P8010@400ADE505IFEP1YJFT0f=SH04E5A@0S8b<0Hf=S07emO@0h>3P0
FEUI08F5Q@0l?3`06a/K06IVIP1cLg<0@D51051@D01YJFT0=3@d03Hf=P2>SXh0];Bd04Q8B01KFe/0
AdM702LW9`15ADD0OWin07QhN015ADD0GEeM03hn?P0c<c<0HV9R08N7Q`11@D40@d=305EEE@0n?Sh0
BTY:07UiN@2EUID0=CDe02h^;P0k>c/0ATI607moO`2SXj<0G5aL01HF5P0m?Cd0O7al05EEE@1lO7`0
g]kN08f=S@0O7al0?3`l06MWI`1;Bd/0Ph>30<[:bP14A4@0?Shn05ADE01GEeL0FUYJ09ZJVP2d];@0
?clo05=CD`1oOgl0Ph>304];B`1oOgl0AdM705EEE@2BTY80PH6107inOP26QXH0;Bd]055AD@1gMgL0
];Bd06e]K@1@D500CDe=03@d=019BDT0NGUi0:6QX@1GEeL0LG5a05aLG016ATH0BDU909jNWP23Ph<0
>3Ph05QHF01GEeL092@T051@D02m_Kd0MGEe03`l?01OGel0>SXj03Ti>@1LG5`0TI6A02XZ:P0m?Cd2
04M7A`3;05MGE`2ATI40IVIV02LW9`1;Bd/0IFEU059BDP1dM7@0PX:2024Q8@0m?Cd0IfMW06m_K`21
PH40YJFU06m_K`0J6QX0Fe]K06UYJ@0m?Cd0IFEU05QHF00M7Ad0;Bd]079bLP21PH40D51@08R8R00m
?Cd0<c<c069RHP1eMGD0DE5A08N7Q`0R8R80=SHf04i>CP1lO7`0@T9205=CD`19BDT0;bl_05YJFP1k
Ng/0B4Q807IfMP1`L7009RHV04e=C@1jNWX0@41005EEE@1`L700:RXZ03Ti>@1NGUh0QXJ605EEE@1Q
HF40P8200451@@1mOGd0Z:RX06=SH`11@D40C4a<04E5A@13@d<0BTY:079bLP1FEUH0@41005EEE@0m
?Cd0=cLg07IfMP2OWil0D51@02`/;016ATH0H61P08F5Q@2<S8`0/k>c04];B`0c<c<0DE5A08V9R@1o
Ogl0Xj>S06ATI00V9RH0EUIF07YjNP2:RXX0Fe]K0>;RhP1GEeL07QhN0492@P19BDT0^;Rh061PH02;
Rh/0Hf=S02d];@16ATH0BDU9065QH@10@400Cdm?02d];@0_;bl0:RXZ04Q8B025QHD0=CDe05mOG`1K
Fe/0PH61079bLP0V9RH0<C4a05MGE`1HF5P0@T92038b<P1QHF40Kfm_02h^;P1BDU80E5AD05=CD`1A
DE40M7Ad05iNGP1=CDd0JFUY05iNGP15ADD0?Cdm020P801CDe<0>3Ph034a<@0o?cl0@41004U9B@13
@d<0EUIF05iNGP1EEED0@41002LW9`1ADE40Cdm?06a/K01<C4`0De=C05mOG`17AdL0DE5A03Lg=`16
ATH0CDe=034a<@1<C4`0@4100492@P1@D500=SHf04i>CP1QHF40@D5104=3@`1DE5@0=cLg05eMG@10
@400=3@d04Y:BP0X:2P0H61P034a<@1CDe<0C4a<04U9B@1BDU80BTY:03`l?01DE5@0IFEU04U9B@1^
KVh0LW9b0451@@15ADD0LG5a05EEE@1YJFT0Bd];04e=C@0/;2`00P0K6a/03@1:BTX0Fe]K065QH@0o
?cl0?3`l059BDP1=CDd0=cLg03`l?019BDT0?3`l04I6AP0l?3`00P1JFUX0J@14A4@0?Cdm04a<C019
BDT0>3Ph02DU9@1BDU80DE5A02`/;00k>c/0B4Q805YJFP0h>3P0Cdm?0492@P14A4@0CDe=03De=@14
A4@0ADE504=3@`1CDe<0?clo04Y:BP1;Bd/0MgMg051@D01dM7@0H61P03Ph>00o?cl0:BTY03/k>`0`
<300=SHf0451@@14A4@0<30`04=3@`19BDT0>c/k05IFEP17AdL0?Shn09JFUP17AdL0OGem05aLG01@
D500PH6104A4A01FEUH0De=C02d];@15ADD0HV9R09>CT`0T92@0A4A404];B`1GEeL0S8b<03De=@2I
VIT0EUIF05iNGP1HF5P0L71`03lo?`1:BTX0DE5A065QH@0L71`0UIFE06][J`0;2`/0I6AT05]KF`0[
:b/0Cdm?01PH6015ADD092@T02d];@1CDe<06a/K04i>CP0i>CT06a/K0492@P1>CTh0B4Q804m?C`0]
;Bd0I6AT03Ti>@0h>3P0DE5A04];B`10@400=CDe06QXJ00];Bd0I6AT06a/K00202XZ:P1_03`l?00a
<C40>SXj030`<01MGEd0Hf=S03lo?`1VIVH0?Cdm03lo?`14A4@0<S8b04U9B@0/;2`0IfMW04=3@`0g
=cL0:2PX03@d=02OWil09RHV059BDP1`L700=3@d02d];@1dM7@0AdM704Y:BP1LG5`0IfMW04e=C@1a
LG40>c/k05EEE@1>CTh0GEeM04=3@`0o?cl0KFe]04M7A`2>SXh0MWIf04e=C@29RHT0C4a<075aL@1e
MGD0F5QH06e]K@0T92@0NWYj09VIV@0e=CD0A4A405]KF`1ADE40?3`l03dm?@1:BTX0=3@d04e=C@0O
7al0=SHf02HV9P0Z:RX0=3@d04A4A01>CTh0@D5105]KF`1^KVh06a/K04I6AP20P800<S8b04e=C@0n
?Sh0AdM705]KF`2:RXX0Jf][04m?C`1:BTX0>CTi065QH@1;Bd/0CTi>09NGU`0k>c/0EUIF04E5A@10
@400GemO03Lg=`13@d<0B4Q803@d=01ZJVX0<C4a03hn?P11@D40RXZ:07YjNP1:BTX0DU9B06][J`1:
BTX0EEEE05ADE01ADE40Hf=S00;ooooo0000QP2IVIT0OWin09jNWP1ADE40BTY:07QhN02OWil0MgMg
09bLW00l?3`0Cdm?08j>SP24Q8@0FEUI06MWI`0W9bL0<30`05iNGP1mOGd0>c/k051@D01ADE40?3`l
04U9B@2@T900?Shn02d];@1>CTh0?clo05IFEP2OWil0CTi>02@T900l?3`0?Shn0492@P1FEUH0SHf=
04I6AP0K6a/0=cLg030`<011@D40VYZJ0<G5a@0^;Rh0;2`/05eMG@1UIFD0DE5A0;2`/01ZJVX0;Bd]
02h^;P1KFe/0K6a/051@D02^[Zh07AdM03De=@1KFe/0WinO05aLG02>SXh0:RXZ02d];@0U9BD0GUiN
06QXJ016ATH0KFe]020P800Z:RX0?Cdm071`L01NGUh0EeMG06QXJ00I6AT09RHV055AD@1TI6@0:RXZ
059BDP1:BTX07alO03Hf=P1eMGD0R8R802d];@0d=3@0CDe=04M7A`0n?Sh0Kfm_03/k>`0O7al0ATI6
05UIF@1CDe<0GEeM07=cL`0T92@0<C4a05QHF01]KFd0JVYZ0:^[Z`1XJ6P08B4Q03dm?@1FEUH0Hf=S
05iNGP2OWil0=3@d020P800l?3`0QHF507inOP25QHD0^[Zj02@T900c<c<0@T9208V9R@1ADE40TI6A
07moO`0a<C40<30`08>3P`2[Zj/0@d=30P1/K6`0F@11@D40@d=307alO03AdM40P82006QXJ01KFe/0
;2`/03dm?@1oOgl0QHF503hn?P1]KFd0;Rh^02LW9`1BDU80VIVI06MWI`0n?Sh0GUiN034a<@12@T80
GUiN059BDP1WIfL0F5QH0492@P1]KFd0SXj>03Xj>P0i>CT0G5aL04=3@`0f=SH0WYjN08N7Q`0Z:RX0
:b/[05MGE`24Q8@0Cdm?0:BTY02`/;00?3`l0492@P1;Bd/0K6a/05ADE020P800N7Qh030`<00d=3@0
H61P0;6a/@2DU9@0]KFe03De=@0l?3`0CDe=07moO`1JFUX0PH6107YjNP0M7Ad0<S8b04a<C01jNWX0
AdM705iNGP0n?Sh0;bl_065QH@1cLg<0EUIF03<c<`1MGEd0820P03@d=01gMgL0MGEe03Xj>P1:BTX0
DU9B028R8P1QHF40YJFU03Lg=`0Q8B40Bd];0080A4A40880Shn?05=CD`0h>3P0HV9R03Hf=P1FEUH0
T92@04Y:BP0X:2P0CDe=04];B`1WIfL0NGUi075aL@0f=SH0@D5105eMG@19BDT0R8R809:BTP0M7Ad0
@41006=SH`1@D500Ogmo0<S8b01?Cdl0:BTY06MWI`25QHD0E5AD0;>c/`25QHD0Bd];03hn?P1_Kfl0
Ogmo07IfMP31`L40KFe]03/k>`0j>SX0I6AT06i^KP2FUYH0Ph>304U9B@10@400D51@08>3P`28R8P0
DU9B07]kN`1>CTh0;bl_05eMG@2_[jl0YjNW06m_K`2UYJD0=3@d05eMG@1cLg<0R8R805]KF`1fMWH0
P82003Ti>@1BDU80X:2P0::RXP0^;Rh0<30`05mOG`0d=3@0=SHf05YJFP1VIVH0;Bd]03Hf=P1<C4`0
=SHf03hn?P23Ph<0M7Ad020P800X:2P0AdM705mOG`0n?Sh0RHV9096AT@1ZJVX0De=C02l_;`12@T80
Hf=S06IVIP1;Bd/0>SXj05]KF`14A4@06ATI02d];@1>CTh0M7Ad06UYJ@1ZJVX0H61P05EEE@1UIFD0
BDU90492@P0n?Sh06ATI03Hf=P0V9RH0<30`03dm?@0j>SX0=cLg059BDP1ZJVX0IVIV06UYJ@1DE5@0
>CTi06ATI01EEED0N7Qh0P1/K6`0X`1]KFd0Cdm?065QH@0U9BD0<c<c03Lg=`0i>CT0DE5A03lo?`1<
C4`0HF5Q03`l?01:BTX0D51@04Y:BP0^;Rh0@D5103Xj>P17AdL09bLW01lO7`0d=3@06ATI03hn?P0J
6QX0:BTY03<c<`0e=CD0<30`03Ti>@0W9bL0@41003Ph>00o?cl0H61P05IFEP1=CDd0HF5Q05]KF`0e
=CD0De=C02@T900f=SH0;Rh^01lO7`0U9BD0GUiN04E5A@1<C4`0D51@04=3@`0o?cl0Bd];03`l?013
@d<0CDe=02@T900c<c<0:BTY02PX:013@d<0=cLg03<c<`0h>3P0:b/[03/k>`0V9RH09bLW04=3@`0X
:2P0B4Q803@d=010@4009bLW03lo?`1FEUH0C4a<04Y:BP11@D40KFe]05iNGP0f=SH0@41003dm?@19
BDT0@d=305mOG`12@T80DU9B03`l?00Y:BT0?Cdm03/k>`1NGUh0F5QH034a<@0m?Cd0H61P05eMG@1J
FUX0GUiN04a<C01XJ6P0MGEe065QH@29RHT05ADE05IFEP1RHV80@41005eMG@0k>c/0T92@07YjNP0V
9RH0BTY:03Ph>01BDU80<S8b04=3@`0l?3`0:2PX09nOW`0_;bl0`/;207IfMP1XJ6P0C4a<04m?C`0c
<c<0>c/k04Q8B01DE5@092@T04Y:BP1KFe/01`L707AdM01cLg<0?Cdm069RHP0Y:BT0EUIF01hN7P0W
9bL0De=C01TI6@1GEeL0EEEE030`<00o?cl0@d=304U9B@1RHV808R8R069RHP1jNWX0?Cdm03hn?P1C
De<0ATI606ATI02NWYh00P1>CTh0LP17AdL08R8R02TY:@0d=3@0;Rh^04A4A00W9bL0LW9b07MgM`0a
<C40<S8b03De=@19BDT0ADE5038b<P0n?Sh06QXJ03Ph>00i>CT0>c/k03dm?@0k>c/0Hf=S02XZ:P1A
DE40EUIF030`<01GEeL0YZJV05iNGP1CDe<0D51@06i^KP1BDU80DE5A04];B`1RHV80=cLg03`l?011
@D40ADE505=CD`19BDT0Ph>307UiN@1EEED0OGem04Q8B01IFET0H61P038b<P1<C4`0<S8b04M7A`1U
IFD0>CTi0451@@0l?3`0Bd];05IFEP0b<S80D51@02TY:@11@D4071`L05iNGP1<C4`0>CTi0410@00`
<300>CTi02h^;P13@d<0CDe=02DU9@15ADD0K6a/02@T900`<300AdM7051@D01<C4`0DU9B05ADE01^
KVh0IVIV07MgM`2ATI40M7Ad04A4A01jNWX0@410071`L01HF5P0B4Q806EUI@1<C4`0F5QH05iNGP1=
CDd0I6AT03Hf=P1lO7`0Cdm?09:BTP1kNg/0FEUI04];B`1cLg<0EEEE04U9B@1RHV80GUiN05eMG@;o
oooo0000o`1OGel0LW9b08^;R`26QXH0@d=3051@D01NGUh0C4a<08V9R@0e=CD0?Cdm04I6AP1_Kfl0
Rh^;0;:b/P0Y:BT0;bl_04i>CP1OGel0JFUY0:BTY02MWId08B4Q04];B`1ZJVX0De=C08R8R02DU9@0
?Cdm02l_;`1JFUX0SHf=069RHP2=SHd0DE5A038b<P14A4@0GEeM05IFEP1BDU80SHf=04Q8B00H61P0
CDe=05ADE01`L700FUYJ08N7Q`0i>CT0;Rh^0492@P1kNg/0?Cdm03hn?P1ZJVX0;bl_04I6AP1SHf<0
B4Q8030`<01<C4`0;Rh^03Ti>@1MGEd0FEUI01hN7P0i>CT0@D5103dm?@1NGUh0VIVI04e=C@0G5aL0
=CDe03hn?P0f=SH0KFe]0;>c/`0^;Rh05QHF04E5A@1UIFD0C4a<0820P02:RXX05ADE02@T9011@D40
MWIf04m?C`27QhL0JFUY020P800_;bl0=3@d04];B`15ADD0[Jf]04i>CP0h>3P0De=C04I6AP1<C4`0
?clo08R8R00h>3P0>CTi04Y:BP22PX80ATI603/k>`1RHV80:BTY02DU9@1?Cdl0PH6102l_;`14A4@0
=SHf02DU9@0j>SX0OWin04a<C00W9bL0?3`l04I6AP0e=CD0IfMW0:RXZ00e=CD08B4Q04M7A`1KFe/0
>SXj09:BTP2`/;009RHV030`<010@400MWIf06][J`2QXJ40[Zj^01dM7@15ADD0HV9R05iNGP1lO7`0
][Jf03De=@0];Bd0GUiN06IVIP1SHf<0WIfM09ZJVP0V9RH0<c<c06MWI`1>CTh0][Jf08J6QP0k>c/0
?3`l07alO01bLW80DE5A09BDU01aLG40<c<c04e=C@2XZ:P0QXJ606IVIP1fMWH0A4A402d];@18B4P0
UiNG06UYJ@1GEeL0OGem01hN7P0^;Rh0Ng]k09FEU@1YJFT0C4a<07QhN00b<S80CTi>06a/K01FEUH0
;bl_04a<C01EEED0:RXZ06EUI@2MWId0CDe=02DU9@1_Kfl0IfMW04U9B@1hN7P0TY:B02PX:01;Bd/0
MgMg05EEE@1dM7@0RXZ:02h^;P0V9RH0@41006QXJ010@400TI6A07YjNP0f=SH0@410051@D01PH600
K6a/08N7Q`0L71`0@d=304e=C@1MGEd0Fe]K0;Ng]`0e=CD0=SHf07IfMP1TI6@0F5QH07QhN013@d<0
<C4a061PH02OWil0H61P08:2PP1=CDd0BDU906i^KP2ATI40@T9205mOG`0g=cL092@T04];B`2MWId0
Vi^K04U9B@005P1@D500=cLg0451@@1BDU80VYZJ04=3@`18B4P0BDU903<c<`15ADD0E5AD08f=S@16
ATH0Bd];05ADE00Q8B40FEUI0:FUY@1>CTh0:2PX04E5A@1?Cdl20492@P1<09jNWP2UYJD0=3@d03Lg
=`1NGUh0IVIV07MgM`2UYJD0B4Q802/[:`28R8P0LW9b04=3@`27QhL0];Bd03/k>`0e=CD0HV9R08Z:
RP1eMGD0QXJ607QhN00/;2`08B4Q04U9B@1dM7@0BDU908>3P`2CTi<07QhN01XJ6P1MGEd0MGEe05YJ
FP1GEeL0WIfM04=3@`0N7Qh0@T9207YjNP1bLW80LG5a04Q8B00h>3P0DE5A069RHP1FEUH0BTY:05MG
E`1WIfL0>SXj03Lg=`1RHV80T92@08V9R@28R8P0I6AT051@D01NGUh0ATI604a<C01BDU80;Rh^04E5
A@0`<300DU9B03dm?@0f=SH0;Rh^04=3@`19BDT0BTY:06UYJ@1BDU80De=C069RHP80F5QH01D0AdM7
059BDP1DE5@0D51@059BDP0`<300:b/[02l_;`1>CTh0F5QH03dm?@1;Bd/0AdM703De=@1<C4`0D51@
04Y:BP12@T80FEUI02XZ:P1?Cdl00P14A4@0301:BTX09bLW04a<C00W9bL0Bd];04M7A`15ADD0B4Q8
05=CD`0f=SH0EUIF04Y:BP<0K6a/01D0?Cdm0451@@1jNWX0@d=307alO00c<c<0?Cdm04Y:BP0j>SX0
>CTi0451@@1<C4`0CTi>05UIF@1HF5P0CTi>05iNGP0o?cl0EeMG05UIF@0l?3`00P0n?Sh09@0g=cL0
GEeM03Hf=P1>CTh0ATI60451@@10@400<c<c03De=@1FEUH0:2PX04];B`0c<c<0De=C02l_;`16ATH0
Bd];03Ti>@1<C4`0;Bd]04Q8B014A4@0;Rh^04U9B@12@T80DE5A03Ti>@1_Kfl0BTY:08R8R01RHV80
8b<S04A4A00Y:BT0>SXj01lO7`0[:b/00P0o?cl0H00n?Sh0AdM705=CD`1_Kfl0Ti>C07QhN023Ph<0
Ti>C05YJFP2;Rh/0QhN7065QH@1PH600?Shn05IFEP1BDU80<C4a0492@P16ATH0I6AT03/k>`12@T80
LW9b0492@P1cLg<06ATI0<71`@1iNGT0DE5A04U9B@1RHV80<30`04E5A@1IFET0Hf=S02`/;01DE5@0
HF5Q010@401NGUh0JFUY05EEE@2;Rh/0<c<c05QHF00_;bl0=cLg05=CD`0j>SX0DE5A05iNGP0T92@0
>SXj04a<C019BDT0IfMW01`L701FEUH0MGEe03hn?P1:BTX0CTi>03Ph>00e=CD0IFEU02`/;01CDe<0
ATI601@D5016ATH0H61P0492@P14A4@0:BTY04e=C@1dM7@0Cdm?03De=@0Y:BT0?3`l03hn?P0g=cL0
EEEE01hN7P1?Cdl0BDU903hn?P10@400DE5A08^;R`1FEUH0DU9B05MGE`1:BTX0=CDe04a<C080>3Ph
00P0@41004a<C011@D40CTi>02HV9P1:BTX0?clo04A4A080<S8b0240DE5A02LW9`13@d<0F5QH03Xj
>P1aLG40>CTi04m?C`1BDU80<c<c055AD@0X:2P0IFEU0:BTY00k>c/0@41005EEE@0j>SX0<C4a020P
801?Cdl0=SHf051@D00o?cl0G5aL05IFEP0a<C40<c<c02PX:01ADE40D51@06i^KP2BTY800P0g=cL0
101TI6@0>c/k05EEE@1?Cdl205MGE`0P079bLP1MGEd0L71`04m?C`14A4@0QhN706EUI@23Ph<0f][J
07MgM`1DE5@0ADE503lo?`1CDe<0<S8b02TY:@0f=SH0CTi>05eMG@0W9bL0@d=303hn?P1oOgl0GemO
0492@P1?Cdl0FUYJ0492@P13@d<0EUIF05aLG01QHF42ooooo`0004H0^KVi05aLG01/K6`0_kno07]k
N`2UYJD0@41005EEE@1JFUX0IfMW07=cL`1hN7P0:BTY03hn?P1aLG40B4Q803hn?P1<C4`0<S8b0451
@@19BDT0SXj>05ADE01>CTh0>c/k02DU9@0m?Cd0MGEe06IVIP0d=3@0BTY:01XJ6P1:BTX0Kfm_05aL
G00_;bl0<S8b05QHF00M7Ad0EEEE0;2`/02LW9`0:2PX03<c<`1=CDd08R8R05eMG@2n_[h0Ng]k020P
8012@T80DU9B04A4A01PH600_;bl03Lg=`0l?3`0EUIF04];B`1DE5@0ZZZZ03De=@0T92@0F5QH08B4
Q00o?cl0O7al06m_K`0O7al0?3`l0P1_Kfl0:00f=SH0JVYZ06i^KP0T92@0;bl_061PH01TI6@0?Shn
04m?C`0L71`0=CDe04M7A`24Q8@0<c<c02l_;`1JFUX0:RXZ03`l?01FEUH0KVi^02PX:00a<C40?Shn
03Ti>@0m?Cd0QXJ607=cL`0Q8B40<30`03Ti>@0j>SX0ADE50::RXP1HF5P07QhN03`l?01IFET0GEeM
05ADE02HV9P2030`<03o0451@@1cLg<0@d=309nOW`1]KFd08b<S051@D01;Bd/0Fe]K05eMG@2ZZZX0
J6QX034a<@0o?cl0ATI608j>SP1ADE40WIfM04U9B@0Z:RX0A4A407EeM@21PH40GemO08b<S01CDe<0
=cLg04M7A`1cLg<0De=C04M7A`2=SHd0:BTY038b<P2d];@0WIfM03/k>`1aLG40H61P02d];@1<C4`0
/[:b09bLW00l?3`0L71`04A4A01JFUX0Vi^K055AD@0g=cL0CDe=03`l?015ADD0MGEe07IfMP0a<C40
@41005YJFP0i>CT0O7al0<;2`P1^KVh0<C4a03De=@1YJFT0Fe]K08>3P`3Kfm/0?3`l02DU9@11@D40
P82005]KF`1TI6@0`L7104Q8B00c<c<0Bd];06EUI@1HF5P0WinO08J6QP0/;2`0<30`0492@P1cLg<0
CTi>096AT@1KFe/0@41005UIF@1YJFT0BTY:04E5A@1fMWH08B4Q034a<@2>SXh0Ogmo04e=C@1gMgL0
?clo02d];@1;Bd/0UIFE03/k>`1ADE40G5aL02@T901<C4`0ZZZZ06YZJP0o?cl0DE5A03Xj>P1BDU80
TI6A06EUI@19BDT0Fe]K02LW9`1FEUH0];Bd07MgM`0X:2P0C4a<05eMG@0m?Cd0Vi^K08^;R`0^;Rh0
E5AD06IVIP1PH600W9bL04U9B@0U9BD0;Bd]06=SH`1VIVH0Jf][0<;2`P1ADE40>CTi051@D01]KFd0
EUIF08b<S02BTY80:BTY0451@@1MGEd0MGEe065QH@2CTi<0Shn?02XZ:P0f=SH0C4a<06UYJ@1IFET0
YjNW0;2`/010@400=SHf0410@01BDU80AdM708B4Q02QXJ40ADE503Xj>P1FEUH0MWIf04A4A02OWil0
D51@02`/;014A4@0Jf][06ATI013@d<0SHf=05UIF@0U9BD0@D5108n?S`1VIVH0;2`/07alO017AdL0
7AdM04A4A02DU9@0Fe]K02l_;`0h>3P0<S8b02<S8`0g=cL0SHf=05]KF`0U9BD092@T03Lg=`1YJFT0
DE5A02@T900i>CT0L71`059BDP13@d<0;2`/04Y:BP1;Bd/0:b/[05YJFP1ADE40AdM704A4A01IFET0
OGem04m?C`1LG5`0AdM703dm?@0n?Sh0<C4a04E5A@0/;2`0;Rh^03Ph>01=CDd0=SHf04U9B@14A4@0
BTY:07=cL`1>CTh0?clo04U9B@1JFUX0AdM704E5A@1ADE40FEUI07IfMP1KFe/0<30`03<c<`0[:b/0
;Rh^03dm?@0b<S80?Shn003o03Lg=`0X:2P0ADE5055AD@0f=SH0>c/k03dm?@15ADD0BDU902<S8`0O
7al0>CTi024Q8@15ADD0;2`/02<S8`0Y:BT0@41004Y:BP18B4P0A4A40492@P1HF5P0E5AD08N7Q`1R
HV80D51@06EUI@1fMWH0HF5Q071`L01<C4`0EUIF02@T900J6QX07alO05iNGP11@D40FUYJ04A4A013
@d<0?clo04e=C@19BDT0DU9B055AD@0k>c/0CDe=03De=@0j>SX0C4a<04e=C@1?Cdl0Bd];04e=C@1E
EED0=cLg030`<013@d<0?3`l04];B`0a<C40De=C04];B`0o?cl0>c/k0451@@1:BTX0?Cdm055AD@18
B4P0;bl_059BDP15ADD0Fe]K04I6AP1hN7P0?3`l08N7Q`1ZJVX0?Cdm04m?C`0R8R80Bd];04=3@`0[
:b/0C4a<04];B`15ADD0EUIF05YJFP1CDe<0NWYj06=SH`1^KVh0NWYj02XZ:P1QHF40De=C05aLG02>
SXh0AdM706QXJ01YJFT0=SHf04E5A@11@D40FEUI02DU9@0f=SH0AdM703dm?@29RHT06ATI0:2PX01F
EUH0GEeM04i>CP22PX80@41002PX:010@400GUiN010@401<C4`0IVIV010@4013@d<0Kfm_03<c<`16
ATH05aLG04Y:BP16ATH0>SXj055AD@0l?3`0AdM704i>CP0e=CD0De=C05]KF`16ATH0HF5Q028R8P1i
NGT0WIfM04a<C01>CTh0DU9B03Lg=`0^;Rh0QhN702LW9`1NGUh0E5AD01LG5`0[:b/0=cLg02l_;`1=
CDd071`L06EUI@1lO7`0Bd];05iNGP0i>CT0?clo04A4A00f=SH0A4A401lO7`1<C4`0E5AD065QH@1P
H600B4Q808:2PP1?Cdl0De=C05MGE`10@400B4Q805UIF@0^;Rh0@T9204a<C01NGUh0Fe]K06EUI@1=
CDd0EEEE04e=C@1;Bd/0>CTi030`<01OGel0;bl_05eMG@1TI6@0>c/k0:RXZ01ADE40EUIF059BDP0`
<300IFEU03Lg=`1>CTh0NGUi02d];@0o?cl0ADE50492@P1=CDd0?3`l05QHF011@D40EeMG01hN7P1Q
HF40A4A4030`<015ADD0<S8b04a<C01FEUH0?3`l05IFEP0X:2P0<S8b05aLG00_;bl0=cLg030`<01A
DE40Hf=S08>3P`1BDU80Cdm?05=CD`1cLg<0Ogmo04i>CP1<C4`0J6QX02<S8`1EEED0?Cdm03hn?P1I
FET0ADE504I6AP1HF5P0;bl_000>06e]K@15ADD0Bd];055AD@1UIFD0GemO04Y:BP0i>CT0B4Q804A4
A019BDT0DE5A05eMG@1eMGD2ooooo`0001T0Y:BT059BDP1OGel0FEUI05EEE@2TY:@0EeMG04A4A01<
C4`0?Cdm07emO@2d];@0>3Ph03Lg=`1@D500BDU90820P02b/[80?clo03`l?01JFUX0M7Ad05ADE02c
/k<0W9bL0080:2PX00/0BTY:071`L02OWil0`l?303Ti>@0T92@0@D5107QhN01IFET0Ph>30:>SX`03
03Ph>02N07QhN01]KFd0C4a<08Z:RP0h>3P0=SHf04i>CP28R8P0BDU908Z:RP1MGEd071`L03Hf=P1J
FUX0De=C03hn?P1FEUH05aLG03/k>`1GEeL0JFUY03Ti>@1@D5009BDU03Xj>P1=CDd0Jf][03Hf=P0_
;bl0BDU903lo?`1;Bd/0C4a<06UYJ@0M7Ad0820P04A4A00i>CT0Cdm?0:RXZ00/;2`07alO02@T901E
EED0CTi>05QHF02ATI408B4Q038b<P0n?Sh0N7Qh05ADE01]KFd0MGEe02DU9@0e=CD0EUIF0:FUY@1W
IfL0NWYj06m_K`0E5AD0B4Q805]KF`1PH600@D5105QHF016ATH09BDU04=3@`1HF5P0D51@04Q8B01]
KFd0>3Ph030`<01?Cdl0Kfm_03dm?@1JFUX0KFe]01hN7P0h>3P0Bd];069RHP0^;Rh0>CTi059BDP0Z
:RX0=SHf08b<S01eMGD08B4Q0410@00k>c/0>SXj04Q8B02<S8`0J6QX03lo?`1:BTX0ADE5061PH01V
IVH0^[Zj055AD@0K6a/0F5QH07UiN@1IFET0WinO09^KV`0g=cL0;Rh^069RHP2LW9`0OGem0;Jf]P1L
G5`0BTY:09ZJVP1nOWh0P8200:2PX00o?cl0;bl_04m?C`1kNg/0J6QX07moO`24Q8@0<c<c03Xj>P1h
N7P0XJ6Q065QH@1UIFD0Ng]k03lo?`1;Bd/0TI6A0:f][@1;Bd/0HV9R055AD@0^;Rh0=CDe08b<S02B
TY80D51@05ADE00Y:BT0>3Ph05UIF@2FUYH0BTY:04E5A@10@40202l_;`2405=CD`1XJ6P0=cLg05UI
F@0o?cl0Hf=S08:2PP1iNGT0;Rh^01lO7`14A4@0ATI605MGE`2_[jl0HV9R02/[:`0h>3P0Kfm_04E5
A@1nOWh0NWYj02<S8`19BDT0M7Ad06ATI01PH600VIVI01dM7@0o?cl0M7Ad059BDP20P800][Jf03dm
?@0Q8B40GEeM09fMW@1HF5P0TI6A06e]K@1=CDd0F5QH07=cL`1:BTX0IFEU07QhN00J6QX0PX:20;jn
_P1WIfL0MWIf08f=S@1IFET0?Cdm07QhN02[Zj/0F5QH08J6QP1IFET0F5QH04a<C02?Shl0Q8B406MW
I`2GUiL0B4Q803hn?P18B4P0Ng]k05YJFP10@400EUIF02l_;`0o?cl0Kfm_0:BTY02YZJT0?3`l05aL
G01BDU80<S8b06IVIP37alL0XJ6Q04A4A01FEUH0=3@d03dm?@2ZZZX0K6a/03Ti>@15ADD0F5QH04=3
@`1=CDd0/k>c05iNGP0S8b<0>SXj051@D01?Cdl0BDU90:VYZ@1eMGD09bLW03@d=01HF5P0GemO06IV
IP1nOWh0ADE5018B4P0_;bl0;Rh^06=SH`1TI6@0KVi^04E5A@1VIVH0EEEE038b<P0d=3@0>c/k05=C
D`1/K6`0GEeM05]KF`1DE5@0;2`/02XZ:P18B4P0E5AD0P1OGel0<019BDT0@41004];B`10@400?clo
055AD@0_;bl0<S8b01lO7`0c<c<0=CDe03Ph>017AdL0FEUI06=SH`1ADE40FEUI059BDP1HF5P0HV9R
04m?C`1]KFd0MGEe08n?S`1TI6@0CDe=04m?C`0Q8B407alO02PX:014A4@0Cdm?02h^;P0d=3@0EEEE
03Lg=`0m?Cd0=cLg04];B`0n?Sh0@D5101`L700`<300;Bd]01hN7P0k>c/08R8R02h^;P80:RXZ0140
;bl_03@d=00W9bL0:b/[03<c<`0/;2`0:BTY030`<01PH600CDe=02l_;`0V9RH0A4A403dm?@13@d<0
=CDe02l_;`0201lO7`1902<S8`0d=3@0>c/k06=SH`19BDT0ATI604E5A@1:BTX0>SXj04Q8B00l?3`0
7alO02TY:@0N7Qh0>3Ph03<c<`0`<300<S8b03Hf=P0W9bL0=cLg01hN7P0g=cL0?Cdm024Q8@0n?Sh0
;bl_04=3@`0e=CD0>c/k04A4A01?Cdl0D51@03De=@1BDU80C4a<05=CD`1VIVH0@T9205ADE011@D40
FEUI03lo?`24Q8@0CDe=03Ti>@1UIFD0<S8b051@D01YJFT0>c/k04m?C`1:BTX0EeMG06=SH`1EEED0
ATI608Z:RP1hN7P0ZZZZ09bLW00R8R80LG5a07emO@1:BTX0J6QX03`l?01]KFd0DU9B04E5A@1HF5P0
BDU906ATI00203/k>`1H04m?C`17AdL0QhN702<S8`2SXj<0NGUi09JFUP1cLg<0FEUI03lo?`0i>CT0
ATI605=CD`0Y:BT0LW9b06QXJ00B4Q80E5AD08N7Q`0_;bl0G5aL02XZ:P15ADD0=cLg06ATI01hN7P0
;Rh^059BDP0l?3`06a/K03hn?P1:BTX0EEEE08R8R00U9BD0>c/k05iNGP10@400AdM704m?C`1BDU80
@T9207IfMP0/;2`0IVIV07]kN`0D51@092@T02l_;`1;Bd/0Ogmo02l_;`1SHf<0JVYZ03hn?P18B4P0
CTi>04];B`12@T80>3Ph0451@@0W9bL0EEEE04m?C`0g=cL0;bl_03Ph>022PX80DE5A07QhN01mOGd0
Fe]K0410@019BDT0>CTi04I6AP1?Cdl0EUIF04];B`1@D500;bl_04];B`0e=CD0?clo034a<@0c<c<0
BTY:02LW9`80EEEE02D0:BTY04m?C`19BDT0G5aL059BDP0P8200Bd];03@d=01>CTh0UYJF03Lg=`15
ADD0B4Q80410@01>CTh0<30`03Ti>@0_;bl0GUiN02DU9@1<C4`0=3@d05EEE@1CDe<0Cdm?06i^KP1R
HV80CDe=08>3P`1NGUh0AdM706ATI01=CDd0BTY:04A4A01;Bd/0ATI60080MWIf01h0E5AD03Lg=`13
@d<0QXJ6069RHP1XJ6P0K6a/03@d=01QHF40GEeM0410@01@D500>c/k04=3@`1IFET09bLW05QHF016
ATH0LW9b06m_K`1MGEd0GUiN06][J`1@D500DU9B05EEE@1=CDd0EEEE07YjNP23Ph<2ooooo`0000T0
YJFU07inOP2XZ:P0Lg=c04Y:BP24Q8@0Ph>308J6QP2RXZ800P0m?Cd0F`1oOgl0U9BD06a/K01nOWh0
5aLG02`/;01iNGT0IVIV03@d=01IFET0GemO02@T900f=SH0IVIV0492@P0o?cl0JVYZ02LW9`0b<S80
MGEe06=SH`0i>CT0N7Qh0410@00J6QX0E5AD08F5Q@0];Bd0:RXZ04];B`0m?Cd0@T9204e=C@1lO7`0
9RHV03<c<`1TI6@0AdM7055AD@2DU9@0Z:RX02/[:`0m?Cd0BDU90451@@2HV9P0[Jf]03Xj>P0W9bL0
H61P04e=C@1WIfL0/;2`03Ph>00O7al0?Shn065QH@0o?cl0HV9R0:VYZ@18B4P0<C4a03lo?`1MGEd0
ADE5065QH@26QXH0=CDe02PX:01^KVh0M7Ad02h^;P1GEeL0?Shn02DU9@0l?3`0JFUY05]KF`0Y:BT0
EUIF04M7A`0f=SH0@41007moO`0i>CT0=CDe059BDP0V9RH0De=C06YZJP1lO7`00P0U9BD0T@19BDT0
@d=303Lg=`1mOGd0Hf=S020P800o?cl0GEeM03Xj>P11@D40Rh^;05UIF@0N7Qh0@d=3061PH010@400
K6a/0<30`00/;2`09RHV05eMG@2;Rh/0IFEU06YZJP2b/[80:b/[02HV9P1CDe<0TY:B04a<C02:RXX0
MGEe01hN7P0c<c<0HV9R07inOP1QHF40Shn?05IFEP0Y:BT0ADE505mOG`1oOgl0B4Q807QhN00Y:BT0
:b/[04I6AP1dM7@0IFEU05=CD`1BDU806a/K03dm?@1FEUH0P82008F5Q@1PH600<30`04m?C`2BTY80
SHf=03hn?P13@d<0>CTi03lo?`1FEUH0KVi^04I6AP0k>c/0Fe]K05=CD`1EEED0I6AT09:BTP0h>3P0
>c/k05QHF01WIfL0L71`07YjNP1hN7P0;bl_04=3@`1JFUX0Rh^;05iNGP2`/;00?Shn02h^;P1?Cdl0
FUYJ04a<C01mOGd0YjNW02DU9@0k>c/0L71`05]KF`18B4P0[:b/05MGE`0O7al0BDU908b<S01ZJVX0
De=C06i^KP0X:2P0;bl_07IfMP2@T900>CTi05YJFP17AdL08b<S03hn?P1lO7`0Cdm?03@d=01KFe/0
:b/[03hn?P1`L700D51@04I6AP1IFET08b<S03dm?@2DU9@0KFe]03dm?@1>CTh0:BTY02l_;`1cLg<0
U9BD03dm?@1JFUX0E5AD059BDP2RXZ80YZJV03<c<`0j>SX00P1@D500:@1iNGT0W9bL04a<C00`<300
@410061PH021PH40YJFU09JFUP0l?3`0GUiN06=SH`1LG5`0N7Qh0=;BdP25QHD0;bl_06MWI`2KVi/0
P82008>3P`2RXZ80?clo02HV9P16ATH0JVYZ08j>SP1mOGd0^k^k06QXJ00M7Ad0?Shn08f=S@2VYZH0
WIfM0;no_`0k>c/0:b/[071`L02l_;`0HF5Q0080NWYj0=40?Shn05iNGP1eMGD0VIVI05UIF@1QHF40
V9RH02l_;`0/;2`0GemO09jNWP1DE5@0@d=307alO00e=CD0<30`06MWI`1MGEd0>3Ph04I6AP1/K6`0
92@T030`<02=SHd0Ph>306QXJ01ZJVX0<C4a03<c<`1JFUX0C4a<0451@@0[:b/0H61P06YZJP0/;2`0
>3Ph04a<C02ATI40UiNG08f=S@1[Jf/0EUIF079bLP12@T80De=C0492@P0j>SX0?Cdm03<c<`16ATH0
>CTi03/k>`0/;2`0@D5104i>CP1HF5P0TY:B05EEE@0h>3P0F5QH092@T01HF5P0?clo04i>CP1XJ6P0
S8b<04Y:BP0e=CD0?Shn02LW9`0d=3@0A4A404=3@`1;Bd/0BTY:02`/;01CDe<0GemO04e=C@1@D500
F5QH03Ti>@1>CTh0BDU903dm?@1IFET092@T04=3@`1ADE40=cLg03<c<`13@d<0CDe=04U9B@0];Bd0
CDe=0410@019BDT0Kfm_071`L00c<c<0>CTi07AdM01FEUH0QXJ603@d=01CDe<0?Cdm02LW9`0c<c<0
Cdm?02TY:@1@D500BDU904e=C@10@400Bd];03/k>`12@T80<c<c034a<@0j>SX09BDU028R8P15ADD0
>SXj03/k>`0j>SX0?Cdm04U9B@0B4Q808B4Q03Ph>00U9BD0?clo020P800d=3@0=SHf03Lg=`0b<S80
;2`/03`l?00g=cL0A4A403Xj>P0m?Cd0CTi>04M7A`14A4@0@D5105eMG@0l?3`0?clo03dm?@0b<S80
@D5102@T901>CTh0=CDe03lo?`0i>CT0JVYZ04M7A`1[Jf/0Fe]K06a/K02WYjL0JFUY065QH@1mOGd0
GUiN09RHV01fMWH0Rh^;0:>SX`1GEeL0QHF505aLG00S8b<0@D5104I6AP1TI6@0A4A4051@D01>CTh0
=3@d08f=S@0a<C40SHf=07alO01BDU80A4A406YZJP0f=SH0BDU906i^KP1hN7P0<S8b04];B`1CDe<0
5aLG02/[:`1bLW80?Shn06QXJ00S8b<0De=C02DU9@0205IFEP2501/K6`0k>c/0A4A404];B`1^KVh0
Fe]K03De=@1<C4`06QXJ04E5A@1PH600=cLg055AD@1?Cdl0De=C0492@P1kNg/0<30`05YJFP1KFe/0
8B4Q02PX:012@T80;bl_04m?C`11@D40GUiN0820P01aLG40J6QX05aLG017AdL0EeMG038b<P0i>CT0
61PH04A4A017AdL0IFEU04E5A@0^;Rh0KVi^030`<013@d<0?clo03@d=00h>3P0E5AD028R8P0f=SH0
;bl_05=CD`13@d<0GemO02l_;`12@T80@d=304M7A`0/;2`0;Bd]05EEE@0_;bl0JVYZ06ATI00O7al0
PX:204e=C@1SHf<0De=C02PX:01bLW80>3Ph03<c<`1RHV808b<S03`l?00`<300<C4a03Lg=`0Y:BT0
>c/k03Hf=P1BDU8092@T05EEE@0^;Rh0<c<c04A4A01>CTh0?3`l0451@@1=CDd0Rh^;05UIF@16ATH0
L71`03Ph>01;Bd/0BTY:06YZJP1CDe<0Ng]k04U9B@27QhL0BTY:051@D01/K6`0F5QH03Lg=`0`<300
820P08B4Q01HF5P0@D5105QHF015ADD0BDU905ADE00b<S80MWIf04e=C@15ADD0;Bd]08>3P`1OGel0
Bd];05EEE@1IFET0CTi>04m?C`1ZJVX0G5aL05iNGP02ooooo`0005`0SHf=04e=C@1dM7@0Vi^K04i>
CP1@D500A4A405QHF02QXJ40EEEE03`l?018B4P0>3Ph09FEU@2a/K40=cLg020P800m?Cd0BTY:0410
@02CTi<0T92@024Q8@0R8R80>3Ph03Lg=`1/K6`0^;Rh04I6AP0X:2P0<c<c03hn?P1BDU80WYjN08>3
P`0E5AD0>c/k06i^KP1VIVH0Cdm?09jNWP1SHf<05aLG04M7A`1>CTh0@41006UYJ@2JVYX0<c<c02/[
:`1lO7`0VIVI065QH@2@T900O7al01lO7`0o?cl0Y:BT08B4Q01]KFd0NWYj02<S8`0];Bd0Ng]k08V9
R@0c<c<0Cdm?04Y:BP0E5AD0<30`07inOP1DE5@05aLG04m?C`14A4@08b<S05iNGP2^[Zh0:BTY02XZ
:P11@D40?clo03Ti>@1[Jf/0LW9b01LG5`0L71`0Bd];05MGE`1:BTX0VYZJ05IFEP80;Bd]0180Hf=S
06EUI@1PH600_Kfm038b<P0[:b/0@T9207=cL`1FEUH0NGUi0:6QX@0^;Rh07AdM03lo?`1`L700AdM7
075aL@1`L70202HV9P0F05MGE`25QHD0?clo05eMG@1aLG40:BTY03Xj>P1JFUX0FEUI02DU9@1JFUX0
Cdm?03<c<`0b<S80E5AD04e=C@0m?Cd0BTY:03Ti>@15ADD0Bd];05YJFP80:BTY02l0ATI603Ti>@14
A4@0RHV907emO@0I6AT0A4A404i>CP16ATH0DU9B09NGU`18B4P08R8R03De=@1CDe<0DU9B07QhN02G
UiL0;Bd]02DU9@19BDT0K6a/0:BTY02k^k/0=cLg02LW9`1DE5@0Ng]k07IfMP1hN7P0>SXj02l_;`1[
Jf/0MGEe06EUI@1cLg<0Y:BT03Ti>@0g=cL0Cdm?05]KF`1OGel0IVIV0:f][@0Y:BT0BTY:05ADE002
07inOP2X0:RXZ02MWId0?Shn04I6AP1OGel0LW9b0451@@1PH600J6QX02DU9@0`<300Jf][05EEE@0_
;bl0Fe]K04A4A00[:b/0J6QX0:>SX`1>CTh0=SHf051@D00d=3@0IFEU09fMW@0j>SX09bLW03lo?`1T
I6@0@D5108n?S`1dM7@09BDU03De=@1BDU80Bd];05mOG`2QXJ40<c<c03/k>`1BDU80Bd];07YjNP2V
YZH0;Bd]02HV9P1HF5P0G5aL07emO@2UYJD0:b/[01hN7P14A4@0Ph>306ATI02ATI40G5aL02h^;P18
B4P0UYJF05MGE`1eMGD0@T9203Ti>@1>CTh0JVYZ08n?S`1WIfL0Q8B402XZ:P14A4@0N7Qh08V9R@1@
D500Hf=S04M7A`0e=CD0=SHf05ADE02[Zj/0H61P05iNGP1bLW80<30`05YJFP21PH40IfMW02l_;`1E
EED0JFUY02HV9P13@d<0U9BD0:JVYP14A4@0B4Q805aLG017AdL0EeMG0:VYZ@0n?Sh08R8R04E5A@18
B4P0?3`l075aL@2IVIT0<30`01hN7P1WIfL0Lg=c06IVIP1MGEd0Ti>C02h^;P0O7al0;Bd]06EUI@1M
GEd0D51@09JFUP0g=cL0:RXZ04Q8B01EEED0?Cdm06IVIP2ZZZX08b<S024Q8@1SHf<0PH6105=CD`19
BDT0<S8b02h^;P0m?Cd0C4a<04m?C`0l?3`0A4A403dm?@14A4@0AdM704I6AP0o?cl0>CTi04e=C@1V
IVH0EUIF06UYJ@1NGUh0A4A403hn?P0[:b/0CTi>04I6AP0i>CT0@T9206IVIP17AdL0BTY:02l_;`0a
<C40>3Ph0492@P0m?Cd0B4Q80P1;Bd/0<01<C4`0D51@04a<C013@d<0BTY:02TY:@0g=cL0>SXj030`
<016ATH0=cLg03Hf=P15ADD0<S8b03Ti>@0m?Cd0?clo03Hf=P14A4@0D51@05ADE00g=cL0;2`/04=3
@`0c<c<0GemO051@D014A4@0B4Q804A4A018B4P0?clo0492@P10@400ADE502h^;P21PH40KFe]03@d
=00i>CT0FUYJ04i>CP1=CDd0?Shn05MGE`1BDU80CDe=04i>CP80BTY:0>L0G5aL04=3@`14A4@0@D51
03`l?015ADD0?Cdm03Ti>@0^;Rh0BTY:02l_;`0j>SX0CDe=0451@@0c<c<0>SXj03`l?01IFET08B4Q
03<c<`12@T80=SHf03Ph>00^;Rh0BTY:04m?C`13@d<0CTi>04E5A@1FEUH0=3@d04a<C00_;bl0?Cdm
04m?C`0X:2P0@d=303lo?`25QHD0<30`059BDP0R8R80=CDe04i>CP0M7Ad0<c<c034a<@0f=SH0;bl_
02XZ:P0m?Cd0Cdm?0410@00];Bd0BDU903dm?@22PX80LG5a02/[:`16ATH0@T9204M7A`1KFe/0BDU9
05QHF013@d<0=3@d04M7A`1YJFT0VIVI02h^;P0d=3@0Cdm?05QHF025QHD0A4A40<W9b@2@T900J6QX
04Q8B024Q8@0De=C028R8P0m?Cd0E5AD02DU9@19BDT0Cdm?01XJ6P0h>3P0SHf=0451@@22PX80<S8b
04Y:BP0Q8B40?Shn04Q8B00M7Ad0Bd];04i>CP0_;bl0>c/k03Lg=`1?Cdl0DU9B02/[:`1cLg<0MWIf
04a<C01@D500DE5A05QHF01@D500Ng]k04a<C01RHV80H61P020P8014A4@0F5QH04E5A@1FEUH0BTY:
07AdM01lO7`0Hf=S07UiN@1WIfL0?Shn03Ti>@0f=SH0BTY:02`/;019BDT0CDe=03/k>`1CDe<0@D51
06QXJ00k>c/0MWIf07EeM@0h>3P0>SXj04i>CP0M7Ad0?Cdm03<c<`13@d<0?clo06QXJ00i>CT0ADE5
03Lg=`14A4@0=CDe02XZ:P1LG5`0=3@d04e=C@1?Cdl09bLW07alO01KFe/0DU9B04M7A`0E5AD0ADE5
03@d=00a<C40GemO02`/;015ADD0;2`/03Hf=P12@T809bLW04I6AP0Y:BT0EUIF02l_;`1LG5`0D51@
04M7A`1<C4`0GEeM065QH@1SHf<0RXZ:08b<S013@d<0<C4a05UIF@0g=cL0>SXj028R8P0o?cl0Bd];
096AT@1MGEd0EeMG065QH@1/K6`0OWin075aL@19BDT0ATI602PX:01FEUH0?Cdm04I6AP1XJ6P0<S8b
04A4A01EEED0=SHf075aL@1:BTX0BDU90451@@1LG5`0GemO04];B`1CDe<0DE5A04Q8B016ATH0NGUi
065QH@1cLg<00_ooool0000i0<O7a`1KFe/0FUYJ07inOP2@T900/;2`03`l?010@400I6AT07QhN01l
O7`0Ti>C03Hf=P0i>CT0C4a<05eMG@1fMWH0Ogmo034a<@10@400Hf=S0:2PX01?Cdl0IfMW05QHF00P
8200@41006m_K`1oOgl0EUIF075aL@0J6QX0?Shn06EUI@28R8P0ATI608V9R@1IFET0:RXZ0410@019
BDT0E5AD030`<00m?Cd0CDe=01TI6@19BDT0R8R804=3@`0O7al0>c/k03`l?00i>CT0[jn_0;Bd]00`
<300;Bd]0080@T9204@0R8R80<30`01>CTh06a/K04M7A`1jNWX0F5QH08Z:RP1`L700;2`/02XZ:P18
B4P0LW9b04I6AP25QHD0GEeM020P800`<300PH6104a<C01LG5`0LW9b02@T900g=cL0ATI607emO@1G
EeL0OGem07inOP0K6a/07AdM03dm?@20P800ATI6065QH@1iNGT08b<S02HV9P1MGEd0OGem038b<P1D
E5@0CTi>028R8P0g=cL0LW9b05]KF`0O7al0AdM705MGE`0[:b/0H61P092@T00h>3P0;2`/03`l?01=
CDd0=3@d07]kN`2BTY80;Rh^01dM7@1>CTh0HF5Q04M7A`2KVi/0Ng]k02PX:080@T9203l0BTY:06UY
J@2k^k/0GUiN01XJ6P19BDT0G5aL0451@@1EEED0Vi^K05MGE`0J6QX0E5AD0861P@1:BTX0S8b<08n?
S`0b<S80=3@d07emO@2<S8`0AdM706i^KP1@D5008B4Q04a<C029RHT0Kfm_04a<C01SHf<0=cLg04M7
A`2?Shl0N7Qh05EEE@1PH600;Rh^02/[:`2<S8`0PX:203Hf=P1@D500IVIV03Hf=P10@400ZJVY08b<
S00`<300?Cdm05=CD`12@T80De=C0;Bd]01bLW8092@T04m?C`19BDT0?clo08n?S`3Jf]X0BTY:03<c
<`1ADE400P0n?Sh0f`2?Shl0/[:b02l_;`0i>CT0@41004M7A`1?Cdl0[Jf]05ADE00c<c<0=CDe04U9
B@14A4@0JVYZ07UiN@0T92@0=CDe059BDP1NGUh0CTi>07]kN`0o?cl0>3Ph0451@@1hN7P0?clo06EU
I@12@T808B4Q04=3@`1HF5P0E5AD06EUI@1YJFT07AdM04];B`1IFET0Bd];055AD@1PH600;2`/0410
@02XZ:P0QXJ604I6AP2;Rh/0?3`l02TY:@1NGUh0R8R803Xj>P1CDe<0F5QH03`l?027QhL0SHf=03@d
=014A4@0J6QX06EUI@1KFe/0/K6a08j>SP0/;2`0D51@079bLP1_Kfl0][Jf096AT@0f=SH0?clo05IF
EP1jNWX0MgMg0;Ng]`2e]KD0?clo04E5A@1LG5`0TI6A04i>CP2c/k<0Zj^[03lo?`12@T80BDU90820
P01bLW80SHf=0;2`/01<C4`0Ng]k09ZJVP1_Kfl0L71`0:2PX01QHF40?Cdm04=3@`1ZJVX0KFe]059B
DP24Q8@0B4Q8038b<P15ADD0IfMW096AT@15ADD0J6QX05aLG00Y:BT0;2`/0492@P1PH600<c<c04M7
A`0_;bl06a/K03`l?01WIfL0EeMG02/[:`16ATH0?3`l05QHF01GEeL0<C4a030`<010@400DU9B04a<
C01?Cdl0K6a/05UIF@0Q8B40<c<c05=CD`1UIFD0GUiN05eMG@1DE5@0DE5A05]KF`0n?Sh0EUIF04E5
A@0W9bL0=cLg038b<P0i>CT0>SXj03Ti>@0o?cl0EeMG05UIF@1NGUh0H61P05IFEP0l?3`0FEUI06AT
I01_Kfl0DE5A05MGE`1ZJVX0F5QH05ADE00K6a/0;2`/03Ph>00/;2`0Cdm?03lo?`14A4@0Hf=S03`l
?014A4@0BDU906=SH`14A4@0F5QH03@d=00n?Sh0=CDe020P800h>3P092@T03Xj>P1:BTX0<30`024Q
8@0k>c/071`L02h^;P0X:2P0=cLg03Xj>P0g=cL0DU9B05EEE@1CDe<0GEeM04E5A@0o?cl0CTi>038b
<P0g=cL0;2`/024Q8@0W9bL0>SXj03@d=01;Bd/0=SHf02l_;`14A4@0=SHf03dm?@0204I6AP0;01dM
7@0Y:BT07AdM03hn?P0h>3P0<c<c03De=@10@400:b/[03Ti>@0E5AD00P0j>SX0B`0R8R80;Rh^02DU
9@0f=SH092@T02`/;00d=3@0=cLg0451@@0`<300ATI603Xj>P1FEUH0FEUI038b<P18B4P0?Shn055A
D@0l?3`0I6AT03Lg=`0X:2P0B4Q801hN7P1>CTh0<c<c05IFEP15ADD0BDU905IFEP2=SHd0Lg=c03lo
?`1fMWH0DU9B09JFUP1fMWH0;bl_05YJFP1NGUh0G5aL06m_K`19BDT0QhN7059BDP1>CTh0GEeM04A4
A01IFET0?Cdm04e=C@1ZJVX0HF5Q08V9R@0a<C40Kfm_04];B`2TY:@0GemO04E5A@0k>c/0@d=305IF
EP1WIfL07AdM05iNGP1_Kfl07alO05=CD`27QhL0BDU905mOG`0m?Cd0M7Ad02`/;002069RHP0M03De
=@1bLW80LW9b03hn?P1:BTX0@d=303lo?`1PH60061PH04I6AP1=CDd0?3`l04];B`1ADE40BTY:04m?
C`20P800Cdm?06UYJ@1UIFD0=cLg05]KF`1OGel0BDU906MWI`1GEeL0CTi>06UYJ@1CDe<00P1IFET0
IP0m?Cd0>CTi059BDP1;Bd/0IVIV05IFEP1JFUX0BTY:07IfMP17AdL0JVYZ05mOG`1=CDd0@D5104U9
B@0c<c<0CTi>034a<@0c<c<0@d=305mOG`1JFUX0JVYZ05UIF@19BDT0@D5105IFEP13@d<0=cLg05UI
F@1OGel0CTi>05iNGP14A4@0Lg=c06YZJP18B4P0Cdm?034a<@1DE5@0GEeM03hn?P24Q8@0:RXZ04=3
@`0k>c/0BTY:04I6AP10@400A4A404I6AP1DE5@0?clo059BDP19BDT0@41004Y:BP0h>3P0DU9B06][
J`15ADD0Lg=c0861P@11@D40Lg=c05eMG@17AdL0:RXZ04U9B@18B4P0IFEU04];B`1IFET0G5aL061P
H027QhL0EEEE05MGE`1DE5@0;Rh^07emO@1DE5@0EEEE06UYJ@0o?cl0JFUY05IFEP0];Bd0HF5Q04a<
C01OGel0=CDe07MgM`1]KFd0Bd];05QHF01UIFD0BDU904E5A@1:BTX0EUIF05aLG0;ooooo00001P2J
VYX0GUiN079bLP1CDe<0CTi>05mOG`80De=C06l0GEeM03Xj>P1SHf<0JVYZ051@D00k>c/0FUYJ02/[
:`1RHV80ZJVY06YZJP1BDU80>CTi04A4A016ATH0LW9b0820P00Q8B40;2`/03dm?@1;Bd/0]KFe09>C
T`0H61P09BDU03@d=01TI6@0ATI60:j^[P1BDU803Ph>03/k>`18B4P0De=C04E5A@1nOWh0Lg=c01PH
601=CDd0Q8B406QXJ014A4@0S8b<03hn?P0H61P0EeMG0:FUY@1FEUH0GemO04m?C`0Z:RX0;Rh^06][
J`1cLg<0FEUI07UiN@0H61P0<S8b05=CD`1XJ6P0<S8b05UIF@1WIfL0:RXZ04M7A`1oOgl0NGUi02d]
;@0a<C40CTi>030`<01;Bd/0V9RH04A4A00G5aL0?clo03`l?00R8R80@T9209>CT`0h>3P092@T03dm
?@0f=SH0=cLg07MgM`2HV9P09bLW01dM7@1:BTX0IfMW061PH02^[Zh0a<C402HV9P0];Bd0?Cdm069R
HP1?Cdl0S8b<07alO00g=cL0CTi>059BDP1ADE40J6QX09:BTP0a<C40:BTY03hn?P1@D5000P1QHF40
201mOGd06ATI02XZ:P0m?Cd0QHF504m?C`0j>SX0TI6A0P0[:b/0NP1ADE40OWin03Xj>P1NGUh0FEUI
02LW9`10@400Cdm?05]KF`0S8b<0CTi>03dm?@0Q8B40Hf=S08:2PP0c<c<0;Rh^059BDP1ADE40?Shn
0820P01mOGd08B4Q03Lg=`19BDT0HF5Q06MWI`2ZZZX0?3`l04=3@`1PH600G5aL08>3P`2j^[X0ATI6
02/[:`13@d<0Lg=c04Y:BP1iNGT0PH6103Ti>@15ADD0I6AT07UiN@1YJFT0MgMg05]KF`0W9bL0<C4a
05QHF02>SXh0IFEU08V9R@17AdL0=SHf03hn?P1XJ6P0R8R805eMG@1nOWh0;bl_02/[:`1=CDd0X:2P
07MgM`1]KFd0FUYJ02DU9@14A4@0H61P07AdM00[:b/0DE5A03hn?P0`<300B4Q808F5Q@1=CDd0=CDe
04m?C`0Y:BT0@41008:2PP18B4P07alO03Xj>P0d=3@0De=C08V9R@2=SHd0:RXZ02h^;P19BDT0;Rh^
06e]K@2SXj<0:b/[03dm?@1cLg<0CTi>08V9R@2;Rh/0=3@d02TY:@1`L700GUiN05=CD`39bLT0GUiN
03/k>`1IFET0Xj>S05aLG02DU9@0SHf=02PX:01IFET0NGUi055AD@1PH600KFe]0P0b<S80701SHf<0
TI6A04m?C`1`L700IFEU034a<@1KFe/0OGem05mOG`1VIVH0TY:B05IFEP0o?cl0@D5108b<S01fMWH0
BDU908J6QP0l?3`0<C4a03Xj>P1fMWH0RHV904Y:BP1[Jf/07QhN03De=@1DE5@209>CT`21065QH@22
PX80=CDe03Hf=P1fMWH0U9BD0410@01HF5P0CDe=05=CD`1<C4`0SXj>06=SH`0S8b<0=CDe03`l?01N
GUh0C4a<0:FUY@2FUYH09BDU03Ti>@16ATH0H61P055AD@2FUYH0JVYZ01@D500m?Cd0IfMW06ATI01?
Cdl0UYJF05MGE`1NGUh0Kfm_04I6AP0b<S80DU9B05iNGP1<C4`0>c/k06a/K01XJ6P0AdM70410@01;
Bd/0IFEU06MWI`1QHF40E5AD04a<C01RHV80IVIV05iNGP1;Bd/0<30`04U9B@0b<S80=cLg03Ph>00m
?Cd0<30`03dm?@1<C4`0J6QX0861P@1IFET0ADE505UIF@1nOWh0GUiN05MGE`1MGEd0HV9R075aL@1B
DU80<30`03@d=00];Bd0?Cdm04m?C`13@d<0Cdm?05aLG00_;bl0Bd];051@D01LG5`0Bd];06IVIP0l
?3`0Bd];02l_;`0M7Ad0CDe=03Ph>00n?Sh0MGEe024Q8@0P8200AdM704A4A01?Cdl0ATI604U9B@0j
>SX0BTY:06e]K@1VIVH0;Rh^034a<@1QHF40?Cdm05IFEP0P8200B4Q806ATI00g=cL0@d=304a<C00R
8R80E5AD04];B`19BDT0?3`l0451@@0e=CD0?Shn0080;bl_08@0=3@d02TY:@0M7Ad0BTY:0451@@0d
=3@0<C4a03dm?@13@d<071`L01/K6`0g=cL0;Rh^03<c<`0M7Ad0820P030`<00c<c<0ATI602@T9015
ADD0=CDe05EEE@0Z:RX0@D5105ADE01<C4`0D51@03Ti>@1HF5P0;2`/03Ph>00/;2`0;Rh^0451@@0Z
:RX0?3`l020P800a<C40>CTi06YZJP16ATH0CTi>059BDP1NGUh0PH6103Lg=`1QHF40QXJ60492@P2:
RXX0MWIf06UYJ@1UIFD0Cdm?05YJFP1<C4`08b<S03Lg=`11@D40GEeM059BDP1DE5@0BDU90451@@2D
U9@0ADE50<71`@1]KFd0EeMG04=3@`1DE5@0=3@d034a<@1[Jf/0Lg=c0492@P0l?3`0@D5101@D500d
=3@0JVYZ03Ti>@1fMWH0>3Ph04M7A`0^;Rh0HV9R06EUI@0O7al0<30`03<c<`0f=SH0KFe]04a<C00i
>CT0Fe]K01DE5@1FEUH0Hf=S04e=C@1>CTh0FUYJ05eMG@19BDT0H61P04M7A`1hN7P0PH6101dM7@11
@D40BDU903Lg=`1ADE40?clo06][J`2;Rh/0BTY:0492@P0n?Sh0CDe=051@D01GEeL0ATI603lo?`1>
CTh0HF5Q04a<C01HF5P0De=C09ZJVP1[Jf/305YJFP0C04Q8B01CDe<0JVYZ03hn?P18B4P0GemO07Ee
M@1XJ6P0Cdm?05eMG@19BDT0C4a<04Y:BP1KFe/0GEeM0451@@1ADE40GEeM04E5A@0207EeM@1206YZ
JP1YJFT0;2`/055AD@0m?Cd0BTY:08>3P`0c<c<0EEEE04i>CP19BDT0ADE504Q8B01=CDd0<c<c051@
D00n?Sh0Hf=S04i>CP13@d<0@T9203Ph>01:BTX0@d=303hn?P2LW9`0Ogmo06=SH`1fMWH0:RXZ03dm
?@0o?cl0DU9B04A4A01aLG40De=C04e=C@1iNGT0<30`04e=C@1HF5P0DE5A04=3@`0Z:RX0>SXj03Lg
=`12@T80DE5A02d];@0a<C40AdM704Y:BP1gMgL0?Cdm03lo?`1TI6@0];Bd08R8R01>CTh0OWin08Z:
RP1:BTX0ADE5061PH01TI6@0IfMW0_ooool0000O07=cL`1[Jf/0TI6A07IfMP13@d<0HV9R06a/K02B
TY80^;Rh03dm?@1>CTh0IfMW07AdM01jNWX0[Zj^03<c<`0`<300=cLg06IVIP1iNGT0RHV907YjNP0Y
:BT0C4a<04I6AP1=CDd0Ng]k07moO`0T92@0:RXZ06MWI`02059BDP0f07alO017AdL0:RXZ06=SH`1n
OWh0;bl_02h^;P1BDU80820P01lO7`0k>c/0N7Qh03Ti>@0Y:BT0HF5Q02d];@1:BTX0IFEU08F5Q@0i
>CT0?Shn05UIF@0g=cL0U9BD08F5Q@0U9BD08R8R03hn?P0`<300DU9B0<O7a`1PH60051@D04];B`24
Q8@0ADE506UYJ@2=SHd0:2PX01DE5@1<C4`0V9RH06QXJ01gMgL0Ph>302@T900a<C40>SXj05UIF@1B
DU80TY:B03Hf=P0_;bl0BTY:0P1<C4`0o`0o?cl0T92@04a<C00F5QH0ADE508V9R@1NGUh0CDe=051@
D00d=3@07alO0410@02<S8`0MgMg05MGE`1]KFd09BDU028R8P19BDT0VIVI03/k>`0j>SX0B4Q802`/
;011@D40Ogmo06YZJP0Z:RX0@T9204M7A`1=CDd0Ogmo08N7Q`0l?3`0820P04Y:BP1CDe<0Hf=S08B4
Q034a<@0<C4a03Ph>01<C4`0EEEE04Q8B02IVIT0Y:BT01/K6`0^;Rh0GUiN06a/K01:BTX0WIfM08Z:
RP0H61P0ATI609NGU`1^KVh0OWin0:RXZ00c<c<0?3`l05aLG02=SHd0EUIF07=cL`17AdL09RHV051@
D01[Jf/0Kfm_06][J`1JFUX09bLW05=CD`26QXH0R8R804U9B@1LG5`0?3`l02/[:`11@D40Ogmo04a<
C00a<C40KFe]04=3@`0c<c<0O7al096AT@0U9BD0;Rh^04E5A@0];Bd0;bl_08^;R`1/K6`0:RXZ03Xj
>P18B4P0E5AD04];B`2QXJ40BTY:02HV9P10@400Fe]K03dm?@1fMWH0Ng]k02/[:`0h>3P0DU9B07Ad
M01GEeL0/[:b06EUI@0R8R80?Cdm07QhN01MGEd0O7al09fMW@0T92@0;Bd]06EUI@2?Shl0DU9B07=c
L`0e=CD0820P05iNGP2TY:@0D51@03Ph>01ADE40:RXZ02d];@1^KVh0JFUY0410@01TI6@07alO03`l
?02;Rh/0IVIV04m?C`1NGUh09bLW02l_;`1NGUh0Hf=S02/[:`17AdL0=CDe03dm?@1FEUH0X:2P04E5
A@11@D40@d=3055AD@1dM7@0Ph>304Q8B00];Bd0@41004M7A`1eMGD0/[:b08B4Q00_;bl0A4A404Y:
BP0k>c/0Ng]k0<O7a`1bLW80=CDe03dm?@1ADE40CDe=06YZJP2UYJD0JVYZ03De=@0c<c<0>CTi079b
LP2>SXh0_kno03De=@0O7al0EEEE0861P@2=SHd0J6QX0:n_[`0^;Rh0CDe=06YZJP28R8P0@T9207al
O01NGUh0>c/k059BDP1oOgl0UIFE04e=C@1WIfL0Ogmo01`L700X:2P0IVIV0:>SX`1/K6`0?Cdm06e]
K@0K6a/0<C4a08b<S021PH40>c/k04A4A01:BTX06ATI030`<01BDU80K6a/04M7A`1;Bd/0:BTY02d]
;@0m?Cd0BTY:04U9B@0f=SH0G5aL06=SH`0T92@0@d=304I6AP14A4@0C4a<07EeM@1CDe<0C4a<07=c
L`0k>c/0A4A403hn?P0H61P0>CTi02/[:`007`0g=cL0ADE503`l?014A4@0?Shn05MGE`1KFe/0BDU9
0492@P0j>SX0C4a<05MGE`1<C4`0BDU904];B`18B4P0BTY:051@D00g=cL0<S8b03Xj>P0^;Rh0AdM7
03`l?010@400?clo02`/;00l?3`0@T9203hn?P0c<c<00P1=CDd0G`1DE5@0<S8b03@d=01@D500>3Ph
04e=C@1RHV80:b/[03hn?P14A4@0ATI604];B`16ATH0De=C05YJFP16ATH0Jf][06YZJP1KFe/0HF5Q
075aL@1BDU80Hf=S02PX:01BDU80H61P02PX:00T92@0CTi>01hN7P1JFUX0De=C04E5A@0g=cL0ATI6
03lo?`0k>c/0>CTi02<S8`12@T80:RXZ02HV9P10@400<c<c034a<@0l?3`0<S8b04Y:BP0T92@0>CTi
04A4A00];Bd0ATI602`/;014A4@0>CTi0451@@0i>CT0>SXj04=3@`0b<S80;bl_034a<@11@D40ATI6
028R8P1:BTX0FEUI07emO@0Z:RX0GEeM04M7A`0k>c/0EEEE024Q8@0c<c<0=CDe03Xj>P0e=CD0;Rh^
04=3@`1WIfL0FEUI065QH@2<S8`0?3`l06QXJ01KFe/07AdM03`l?018B4P0De=C0820P00g=cL0@410
0080>CTi00h0@d=304Y:BP1CDe<0;bl_03hn?P1UIFD0AdM706MWI`0Z:RX0Q8B404E5A@1MGEd0H61P
08J6QP80>3Ph03@0De=C06a/K00_;bl0DU9B05MGE`0Q8B40GEeM07emO@0m?Cd0H61P02h^;P1`L700
:b/[04a<C01:BTX071`L06UYJ@1:BTX0820P038b<P0a<C40KVi^07alO00_;bl0EeMG055AD@1:BTX0
BDU9061PH01LG5`0DE5A07]kN`0b<S80EeMG05aLG00c<c<0Jf][06MWI`17AdL0Jf][0410@01IFET0
Lg=c05=CD`1PH600GEeM03Xj>P0];Bd0>CTi06IVIP1RHV80IfMW0P1MGEd0=P24Q8@0AdM705]KF`14
A4@0NGUi07AdM01QHF40De=C07QhN016ATH0@d=305MGE`1mOGd0FUYJ075aL@12@T80CDe=04A4A01=
CDd0;2`/02XZ:P1QHF40A4A4079bLP1/K6`0Cdm?09FEU@1eMGD0IVIV06i^KP0i>CT0J6QX059BDP16
ATH0LG5a02/[:`0i>CT0?clo03hn?P0/;2`09RHV05QHF00V9RH0CDe=03`l?01JFUX0CDe=03dm?@0_
;bl0I6AT09nOW`1_Kfl0GemO055AD@80<C4a01T0Ph>302<S8`13@d<0C4a<08R8R01>CTh0LG5a05YJ
FP1_Kfl0Shn?04i>CP1EEED0BDU906m_K`1LG5`07AdM05mOG`1CDe<0IfMW07EeM@17AdL0?Cdm04A4
A00^;Rh0F5QH0080>CTi00H08b<S04m?C`1FEUH0BDU904I6AP18B4P204E5A@0304a<C01BDU80FEUI
00;ooooo0000jP2QXJ40Cdm?05IFEP2@T900LW9b09ZJVP0m?Cd0D51@07alO01[Jf/0@d=305aLG00d
=3@0B4Q806IVIP14A4@0;2`/04a<C00U9BD0?Cdm04Q8B023Ph<0@41004A4A00n?Sh0:RXZ092@T02[
Zj/0?3`l028R8P0j>SX0:BTY0451@@2ATI40De=C02<S8`15ADD0MWIf0492@P1XJ6P0WinO03<c<`0F
5QH0>SXj03hn?P1SHf<0GemO0<O7a`0^;Rh071`L06EUI@2?Shl0I6AT0861P@1gMgL09BDU034a<@1]
KFd0Jf][08Z:RP1IFET09bLW03Ti>@18B4P0Kfm_05iNGP21PH40L71`03<c<`0/;2`0C4a<06EUI@0e
=CD0Vi^K04a<C00[:b/0CDe=07emO@1<C4`0CDe=08n?S`0[:b/0:BTY05aLG027QhL07alO02<S8`1B
DU808b<S02DU9@1[Jf/0SHf=01dM7@0/;2`0@d=303lo?`1LG5`0GemO038b<P0F5QH0<S8b03lo?`0b
<S80U9BD0<C4a01BDU808B4Q04];B`1LG5`0EeMG09ZJVP24Q8@0820P02<S8`1TI6@0KFe]05aLG02C
Ti<0LW9b02h^;P0n?Sh0LW9b05eMG@1>CTh0YjNW06a/K00I6AT0<c<c04m?C`1kNg/0ATI607=cL`0f
=SH09BDU04I6AP1cLg<0E5AD03Ti>@1[Jf/0?Shn02@T901FEUH0NGUi038b<P0o?cl0?Shn01hN7P0i
>CT0WIfM06m_K`0Y:BT0BDU903Hf=P1ADE40MWIf06][J`0l?3`08b<S061PH016ATH0SHf=07moO`0V
9RH092@T04];B`1OGel0Hf=S09RHV01@D5008b<S03dm?@1KFe/0MgMg079bLP2l_;`0=SHf030`<00k
>c/0UYJF06i^KP1/K6`0U9BD02TY:@0_;bl0J6QX0:FUY@1CDe<0Z:RX09>CT`15ADD0Bd];06EUI@2@
T900JFUY0:FUY@22PX80=CDe04=3@`2;Rh/0OGem05MGE`2[Zj/0Bd];02PX:011@D40UiNG04];B`1B
DU80GEeM02XZ:P0g=cL0J6QX04E5A@0j>SX0EEEE03hn?P1CDe<0Jf][059BDP0[:b/0?3`l0451@@1>
CTh0QHF508R8R00o?cl0=SHf04A4A00_;bl0FUYJ09VIV@0];Bd08R8R03hn?P80I6AT0540YJFU03Lg
=`0h>3P0GEeM06MWI`1iNGT0Xj>S04];B`0Z:RX0DE5A065QH@1cLg<0Vi^K06YZJP0K6a/0B4Q808:2
PP2=SHd0Jf][09bLW00f=SH0;Bd]04m?C`2IVIT0GEeM06i^KP1SHf<0=SHf03dm?@1FEUH0[Jf]05eM
G@1KFe/0Cdm?028R8P0k>c/0E5AD05QHF018B4P0LW9b065QH@0O7al0@D5108J6QP2ATI40>3Ph0492
@P1BDU80?3`l05ADE026QXH0EeMG03<c<`15ADD0GemO04i>CP1bLW80QHF502LW9`0T92@0AdM703lo
?`0a<C40KFe]09nOW`0c<c<06a/K030`<01>CTh0GUiN05mOG`2GUiL09bLW01TI6@0j>SX0R8R8059B
DP1OGel0RHV901LG5`0d=3@00P19BDT06P1]KFd0Hf=S03`l?00c<c<0BDU905ADE01<C4`0?Shn05IF
EP1ADE40<30`04E5A@1=CDd0DE5A05QHF01WIfL0P820075aL@1fMWH0CTi>061PH012@T807AdM03De
=@0S8b<0<S8b0P0o?cl0:`18B4P0De=C04Q8B01NGUh0G5aL051@D01<C4`0GEeM06EUI@1LG5`0GUiN
06ATI01RHV80EUIF05UIF@0b<S80<c<c03Xj>P0h>3P0Cdm?03Hf=P0o?cl0H61P04Q8B01ADE40B4Q8
05aLG00e=CD0F5QH03lo?`0i>CT0:BTY02/[:`0k>c/0<30`03Ti>@1;Bd/08B4Q02d];@11@D40ADE5
0492@P0o?cl00P0k>c/0k@0h>3P0IFEU06IVIP0b<S80:BTY04A4A010@400CTi>05EEE@1_Kfl0P820
02PX:00[:b/0D51@02h^;P1GEeL0ADE503Xj>P11@D40ATI603<c<`13@d<0ADE501XJ6P0_;bl0820P
03Ti>@0m?Cd0<30`034a<@0n?Sh0<C4a04M7A`0L71`0?3`l03Ph>00P820092@T03De=@0c<c<0;Rh^
03<c<`1<C4`0;bl_05ADE010@400De=C02d];@1HF5P0GemO03hn?P17AdL0?Cdm05]KF`0_;bl0Ogmo
02HV9P0Q8B40Cdm?02HV9P1>CTh0<C4a0410@018B4P0>SXj05YJFP1UIFD0FUYJ03@d=01CDe<0@410
07UiN@1jNWX0<C4a06QXJ01lO7`0FUYJ06IVIP0];Bd0FEUI04M7A`0m?Cd0FEUI02@T900`<300=cLg
0492@P0g=cL0AdM709VIV@0a<C40emOG065QH@1kNg/0Bd];0492@P0d=3@0B4Q805YJFP1LG5`0>SXj
065QH@1HF5P08B4Q04e=C@1DE5@0>c/k05iNGP0m?Cd0HV9R02XZ:P1EEED0GemO02h^;P0c<c<0@D51
02PX:01;Bd/0CDe=03Ph>01DE5@06a/K055AD@15ADD0Fe]K05=CD`0[:b/0>SXj04E5A@1OGel0>c/k
06ATI01dM7@0<S8b0410@013@d<0BDU905ADE01VIVH0Kfm_08f=S@1IFET0=3@d04];B`1NGUh0FUYJ
04A4A00a<C40=3@d06][J`1cLg<0<c<c051@D01RHV80X:2P04I6AP0];Bd0>c/k04e=C@12@T80C4a<
03hn?P1=CDd0FUYJ05IFEP15ADD0?Cdm05=CD`1HF5P0>SXj04E5A@18B4P0=cLg05QHF013@d<0BDU9
04];B`0/;2`0>CTi04Y:BP1HF5P0CDe=018B4P10@400=CDe02HV9P2DU9@0?3`l0410@00^;Rh0<c<c
0492@P13@d<0DU9B04e=C@1RHV80@d=305eMG@14A4@0<c<c03hn?P0g=cL0?Cdm04=3@`0Z:RX0IVIV
04m?C`0d=3@0IFEU030`<01PH600?clo04=3@`1JFUX0Z:RX06EUI@1WIfL0Ng]k05QHF01PH600NGUi
08f=S@1nOWh0CDe=079bLP13@d<0<S8b04e=C@1MGEd0De=C06QXJ01<C4`0GEeM04e=C@1FEUH0<c<c
06MWI`0206ATI00306m_K`1HF5P0E5AD0080CTi>00<0LW9b06QXJ?ooool00Oooool000100;2`/01@
D500CTi>051@D01TI6@0Z:RX04Y:BP0c<c<0ATI606IVIP1ZJVX0UYJF030`<00S8b<0EEEE061PH01M
GEd0Zj^[03Lg=`0Q8B40>c/k06UYJ@13@d<0J6QX05IFEP0a<C40;bl_05EEE@23Ph<0CDe=06a/K00K
6a/0:RXZ03`l?028R8P0KFe]07inOP11@D40?Cdm04A4A01>CTh0IFEU04];B`1KFe/0De=C01HF5P1=
CDd0KFe]065QH@0i>CT0QXJ604I6AP0i>CT0IfMW09:BTP1=CDd0AdM70451@@0P8200J6QX0::RXP1?
Cdl0<c<c05QHF080:BTY0=P0RXZ:08b<S00c<c<0=SHf05ADE00k>c/0>SXj0;Ng]`28R8P06ATI02/[
:`1OGel0CTi>05UIF@2d];@0<C4a02LW9`0^;Rh0Cdm?06][J`14A4@0XJ6Q01dM7@0U9BD0=SHf05IF
EP19BDT0E5AD06=SH`0N7Qh0:BTY05IFEP1ZJVX0AdM708N7Q`1YJFT061PH03/k>`1QHF40Jf][03Lg
=`2KVi/0:RXZ02`/;01>CTh0MWIf04U9B@17AdL0Lg=c02`/;00R8R80Cdm?07IfMP0Y:BT0=cLg04a<
C00n?Sh0BTY:08>3P`2CTi<0;2`/04E5A@1JFUX0ADE505]KF`2QXJ40K6a/01hN7P18B4P0Fe]K051@
D01CDe<0/;2`05UIF@0Q8B40F5QH05aLG01GEeL0SXj>051@D00S8b<0;Bd]05UIF@1gMgL0GEeM09JF
UP0n?Sh09RHV03Ti>@1JFUX0BDU906IVIP26QXH0>CTi04a<C02ZZZX0GemO06ATI020P8007AdM03Lg
=`17AdL0FEUI03@d=01CDe<0Hf=S028R8P19BDT0L71`07UiN@0c<c<0CTi>04Q8B015ADD0@d=308>3
P`1DE5@092@T05]KF`1ADE40<30`05]KF`2PX:00A4A402l_;`1>CTh0<S8b02XZ:P1^KVh0WIfM034a
<@0g=cL0DE5A03lo?`1DE5@0XZ:R07MgM`0X:2P0B4Q805UIF@1RHV80RHV908j>SP0/;2`0;Bd]03dm
?@19BDT0KVi^0:VYZ@0i>CT0=3@d06EUI@1VIVH0>3Ph07MgM`15ADD07alO02l_;`1`L700I6AT08R8
R01eMGD09RHV02LW9`1NGUh0EUIF04U9B@1HF5P08R8R04I6AP1HF5P0J6QX0451@@1UIFD0?Cdm02l_
;`1aLG40N7Qh03@d=01TI6@0EeMG03Ti>@1DE5@0JFUY02/[:`10@400IFEU03<c<`1;Bd/0Kfm_06AT
I00b<S80FUYJ05=CD`1?Cdl0WinO09FEU@0d=3@0@d=305YJFP1GEeL0DE5A0;>c/`2ATI40;bl_02`/
;01QHF40LG5a05YJFP2RXZ80YZJV030`<00b<S80B4Q805EEE@0o?cl208^;R`1L03Lg=`1@D500G5aL
06a/K01gMgL0WIfM0410@016ATH0DE5A06QXJ01PH600GEeM09bLW00o?cl0<30`03Ti>@1ZJVX0QhN7
04i>CP27QhL0Hf=S02@T9017AdL0Cdm?05QHF019BDT0FUYJ03Hf=P0N7Qh0Hf=S06QXJ00];Bd09bLW
05IFEP0/;2`0EUIF04i>CP0h>3P0@T9207]kN`1HF5P0EEEE04Q8B01WIfL0L71`02PX:015ADD0CTi>
07emO@1^KVh0NGUi061PH015ADD0Fe]K051@D01RHV80EEEE03Ph>013@d<0>3Ph059BDP15ADD0;Bd]
02h^;P0n?Sh0Hf=S06UYJ@1SHf<0BTY:02l_;`1LG5`0KFe]05YJFP16ATH0D51@07IfMP2;Rh/0H61P
03Lg=`0j>SX0=SHf03@d=00o?cl0>3Ph04U9B@1GEeL0ADE504];B`17AdL0F5QH03`l?01EEED204I6
AP0e03<c<`0/;2`0A4A403@d=00j>SX0H61P03`l?00m?Cd0CDe=04U9B@1<C4`0B4Q804];B`11@D40
Cdm?08F5Q@20P800@41003`l?01bLW80A4A405MGE`0T92@0<c<c04M7A`0Q8B40:b/[03/k>`0P8200
C4a<04m?C`17AdL0?3`l04Y:BP0h>3P0ATI602h^;P0R8R80<30`020P800M7Ad0@d=303<c<`0a<C40
@d=303/k>`1>CTh06ATI03@d=01CDe<0;2`/0492@P0U9BD00P0_;bl06@0l?3`0;bl_02XZ:P17AdL0
>CTi04e=C@0N7Qh0?Cdm0410@00n?Sh0?3`l0492@P1TI6@092@T065QH@0g=cL0820P05IFEP0d=3@0
CDe=028R8P11@D40<30`04M7A`16ATH00P1oOgl04@1EEED0I6AT05UIF@1FEUH0K6a/04i>CP23Ph<0
HV9R079bLP1`L700ATI607moO`1HF5P0:b/[04Q8B00^;Rh0?Cdm0080?3`l0P14A4@03`1OGel0:b/[
06UYJ@11@D40KVi^04];B`2=SHd0<30`02DU9@1PH600G5aL02XZ:P10@400BDU902TY:@0206=SH`0T
04e=C@2IVIT0>SXj06=SH`0j>SX0C4a<05eMG@0i>CT0C4a<03`l?00d=3@0MGEe05YJFP1>CTh0JVYZ
02PX:01@D500>c/k03De=@0f=SH0@D5104I6AP1JFUX0VYZJ03Ph>019BDT0EEEE024Q8@17AdL0EEEE
0492@P1ADE40?Cdm07alO02UYJD0F5QH0P1IFET0IP0a<C40=SHf02h^;P1KFe/0?Cdm0410@016ATH0
?clo05IFEP0];Bd0H61P030`<01KFe/0IVIV0451@@0h>3P0Cdm?03Xj>P0c<c<0DU9B079bLP1@D500
BDU904A4A01IFET0@T9204Q8B00h>3P0<C4a05=CD`17AdL0M7Ad079bLP0l?3`0G5aL06=SH`1^KVh0
K6a/034a<@1DE5@0ATI604m?C`1bLW80H61P059BDP1<C4`0IVIV06ATI01KFe/0D51@03Ti>@15ADD0
=SHf06][J`1:BTX0AdM70492@P0_;bl0Bd];04m?C`0U9BD0MGEe05IFEP0i>CT0CDe=02LW9`13@d<0
B4Q805aLG00j>SX0D51@03/k>`1:BTX0NWYj065QH@1PH600DE5A05]KF`17AdL0@41007MgM`1BDU80
ATI6051@D00Z:RX0;Rh^04U9B@13@d<0DU9B03/k>`16ATH0DE5A07IfMP1HF5P0AdM7055AD@1DE5@0
@D5104A4A01CDe<0D51@05UIF@;ooooo0000^`25QHD0JFUY09VIV@1:BTX0FEUI05IFEP1IFET0Jf][
07AdM00X:2P0E5AD06EUI@1DE5@0D51@05iNGP0P8200@d=304Q8B019BDT09bLW06YZJP12@T80=CDe
059BDP1[Jf/0<30`03hn?P19BDT0<c<c08B4Q01nOWh0=SHf02DU9@1=CDd0;Bd]03Ti>@2OWil0UiNG
01`L700i>CT0EEEE04I6AP11@D40W9bL09ZJVP0I6AT0<c<c071`L01IFET0BTY:0:b/[01DE5@0:BTY
03Xj>P1gMgL0G5aL07QhN01cLg<07alO02@T901?Cdl0Kfm_05IFEP2KVi/0@T9202PX:00j>SX0QhN7
071`L01TI6@0KVi^030`<00X:2P0EEEE09RHV01oOgl0GemO08j>SP0O7al0=CDe05MGE`1KFe/0820P
04i>CP11@D40:BTY03Xj>P1OGel0=CDe04M7A`1`L700<c<c030`<01PH600TI6A02XZ:P0O7al0>SXj
03/k>`19BDT0QhN70861P@0O7al08R8R051@D010@400CTi>09RHV016ATH07alO03@d=01UIFD0Jf][
05mOG`2m_Kd0>3Ph01lO7`11@D40P82005=CD`1gMgL0NGUi01DE5@0W9bL0JFUY09:BTP1QHF40];Bd
0:NWY`0Q8B40=cLg06m_K`2EUID0CTi>06][J`19BDT09bLW0492@P1NGUh0Q8B403lo?`20P800?Cdm
02TY:@1[Jf/0O7al04A4A00^;Rh0Fe]K02TY:@0i>CT0QhN707moO`12@T80GEeM03Lg=`0_;bl0B4Q8
0861P@1:BTX0Hf=S04m?C`0g=cL0IFEU0;Ng]`1lO7`0:2PX05=CD`1:BTX0>c/k079bLP2RXZ80=3@d
03De=@1^KVh0DE5A04a<C01bLW80OWin024Q8@0m?Cd0D51@07EeM@1DE5@0UYJF051@D00m?Cd00P1:
BTX0V`1GEeL0LW9b07IfMP0V9RH0=cLg0451@@1BDU80DE5A06MWI`1TI6@071`L04a<C01PH600EUIF
0492@P2=SHd0JVYZ028R8P0^;Rh0J6QX059BDP1KFe/0Hf=S01hN7P0Z:RX0GemO079bLP0i>CT0C4a<
03Ph>00o?cl0CTi>06IVIP0a<C40<S8b04m?C`0M7Ad0Hf=S09BDU00k>c/0;Bd]03`l?010@400EUIF
07]kN`0c<c<0;2`/05=CD`0g=cL0Kfm_0;no_`15ADD08b<S04M7A`1DE5@0AdM709^KV`2;Rh/0<C4a
061PH01cLg<0C4a<092@T02;Rh/0>3Ph02l_;`1KFe/0QXJ608R8R02VYZH0Ogmo0451@@1;Bd/0I6AT
05UIF@21PH40ZZZZ04M7A`0l?3`0BTY:09:BTP1dM7@0NGUi08N7Q`0d=3@0;Rh^04a<C02@T900GUiN
0451@@1XJ6P0<30`02TY:@17AdL0MgMg06=SH`1<C4`0LG5a02TY:@19BDT0N7Qh0861P@0l?3`0@d=3
04a<C00U9BD0B4Q806ATI01LG5`07alO03dm?@1`L700:2PX03/k>`1PH600NGUi02PX:00g=cL0@d=3
03Xj>P1eMGD0O7al08B4Q00Q8B40:BTY05YJFP0l?3`0IFEU08f=S@0b<S80DU9B04e=C@0[:b/0;Rh^
0410@012@T80ADE5030`<01<C4`0?3`l01/K6`16ATH0?3`l04U9B@1>CTh0Hf=S06ATI01:BTX0DU9B
03lo?`16ATH0>SXj024Q8@0o?cl0;2`/0080?clo0400DE5A03Ti>@14A4@0=cLg04E5A@14A4@0?clo
03@d=015ADD0BDU903Ti>@14A4@0C4a<04];B`1@D500DU9B034a<@0c<c<0?Cdm02`/;00j>SX0=CDe
034a<@0];Bd0:BTY038b<P0c<c<0>SXj02LW9`0n?Sh0?3`l03lo?`0Y:BT071`L02`/;00o?cl0Fe]K
04];B`0Y:BT0<C4a04Q8B01PH600Cdm?03<c<`1DE5@0J6QX04E5A@1>CTh0EUIF059BDP1DE5@0IFEU
04Y:BP1QHF40?3`l065QH@1XJ6P0:BTY02/[:`19BDT0:RXZ061PH017AdL0@T920P11@D40600l?3`0
AdM704M7A`0c<c<0?Cdm03De=@17AdL0CDe=03dm?@0h>3P0C4a<03Lg=`1:BTX0;2`/04A4A01<C4`0
;bl_03De=@0Z:RX0?3`l04A4A012@T80AdM703Xj>P80DE5A02@0De=C03lo?`1GEeL0E5AD03@d=015
ADD0Cdm?07YjNP0O7al0Lg=c06YZJP0o?cl0Lg=c03Ph>01=CDd0<C4a03Ph>00_;bl0E5AD03Ti>@1>
CTh0Bd];0451@@2:RXX0ADE506QXJ01/K6`0>SXj07YjNP1^KVh0D51@06IVIP1=CDd0EeMG04E5A@0n
?Sh204E5A@1N05=CD`0b<S80ADE504e=C@1HF5P0S8b<02XZ:P2h^;P0Fe]K08V9R@1WIfL0F5QH02HV
9P0/;2`0EeMG04i>CP0];Bd0C4a<03Ph>00O7al0Jf][069RHP1:BTX0E5AD038b<P1MGEd0=3@d06=S
H`1kNg/0;bl_04M7A`11@D40@41004E5A@11@D40H61P06i^KP0Z:RX0IFEU02LW9`0g=cL0@41005EE
E@1OGel0?clo05YJFP0i>CT0D51@04e=C@0V9RH0LW9b07=cL`1BDU80O7al059BDP1FEUH0P82004M7
A`0a<C40FEUI03Xj>P10@400?clo03De=@0`<300@d=304M7A`1ADE40HV9R02l_;`1TI6@09bLW05IF
EP1dM7@0EEEE03Hf=P1>CTh0>c/k04Q8B01RHV80Cdm?04a<C01_Kfl0C4a<04i>CP1=CDd0FUYJ03Ph
>00[:b/0Cdm?04e=C@0m?Cd0CTi>03Ph>080I6AT0480EeMG05iNGP0S8b<0D51@03`l?00b<S80PX:2
04e=C@1eMGD0Cdm?04=3@`0k>c/0@41004Y:BP0V9RH0BTY:034a<@1JFUX0ADE502d];@0Z:RX0>3Ph
05YJFP1BDU80ATI6065QH@0l?3`0;bl_05QHF00e=CD0CTi>04=3@`18B4P0?Shn08B4Q01NGUh0HV9R
07EeM@1SHf<0N7Qh04m?C`1WIfL0=cLg01PH601GEeL0CDe=04M7A`1QHF40;Bd]04Y:BP1DE5@0=3@d
061PH00f=SH0@d=303Lg=`1oOgl0NWYj051@D01ADE40E5AD04Q8B01?Cdl0Bd];059BDP1OGel2oooo
o`0008/0RXZ:05ADE02IVIT0KVi^04e=C@1?Cdl0L71`092@T02WYjL0=cLg04E5A@1>CTh0@41007Mg
M`1aLG407AdM02l_;`1>CTh0D51@04M7A`2PX:00Rh^;01@D5014A4@0SHf=04M7A`28R8P0LG5a01`L
701;Bd/0EeMG04I6AP1HF5P0U9BD04a<C00I6AT0EUIF0::RXP1:BTX0FUYJ06=SH`0h>3P08B4Q05EE
E@26QXH0BDU906][J`1cLg<06ATI034a<@11@D40IfMW03/k>`1/K6`0?3`l02h^;P1IFET0Ti>C04m?
C`1FEUH0CDe=02LW9`0b<S80CDe=04a<C00Y:BT0MWIf05]KF`0o?cl0OGem06ATI00L71`08b<S03hn
?P13@d<0GEeM06EUI@2;Rh/08b<S034a<@10@400DU9B05MGE`1lO7`0HV9R02`/;00i>CT0IFEU04];
B`1<C4`0YZJV04Q8B00`<300;Rh^05YJFP1LG5`0EUIF071`L00N7Qh0:BTY02/[:`1oOgl0Hf=S04Y:
BP1PH6008B4Q03De=@1LG5`0LG5a03`l?01aLG40EEEE02DU9@0a<C40D51@069RHP0`<300Cdm?03lo
?`0Y:BT0@T9206MWI`13@d<0=SHf06i^KP0f=SH0:RXZ0861P@2][Jd0>3Ph02XZ:P1:BTX0>c/k03dm
?@2LW9`0UiNG02LW9`0];Bd0>3Ph0080?Cdm09L0Xj>S096AT@0O7al0=3@d051@D01LG5`0FUYJ09jN
WP0k>c/0;2`/05ADE01mOGd0Jf][09:BTP1ADE40:2PX03Hf=P1iNGT0OWin0;jn_P1YJFT0=CDe03Ph
>01^KVh0];Bd05UIF@2:RXX0>c/k03De=@1YJFT0KFe]05ADE01>CTh0PH61034a<@0T92@0F5QH09RH
V01cLg<0C4a<075aL@0N7Qh0>SXj061PH01FEUH0@d=305MGE`1HF5P09BDU069RHP2b/[80JVYZ03/k
>`1fMWH0E5AD03Lg=`20P800YZJV059BDP0k>c/0LW9b04A4A00k>c/0UYJF09jNWP0`<300AdM70451
@@0l?3`0LG5a0:^[Z`0`<3009BDU034a<@11@D40Jf][07IfMP0n?Sh07alO03Lg=`1JFUX0EUIF07in
OP1mOGd0;Bd]01TI6@1BDU80BDU9071`L022PX806QXJ02LW9`1UIFD0E5AD0451@@1/K6`09BDU0410
@01SHf<0CTi>03lo?`1ZJVX0=CDe0492@P1TI6@0M7Ad03Hf=P1YJFT0>c/k02TY:@1?Cdl0P82005EE
E@1BDU80EeMG02`/;00l?3`0PH6109^KV`1;Bd/0C4a<05EEE@0l?3`0Fe]K09FEU@2>SXh0>3Ph06e]
K@17AdL0C4a<05EEE@2PX:00K6a/02d];@0h>3P0EEEE04U9B@1]KFd0/k>c04m?C`0P8200@41005MG
E`1CDe<0LG5a0;Jf]P0o?cl09RHV05]KF`1dM7@0GUiN0080T92@03P0;Rh^02@T901TI6@0JVYZ04Y:
BP1aLG40YjNW01`L700S8b<0EeMG06=SH`13@d<0Lg=c05QHF00F5QH08b<S0451@@1cLg<0De=C059B
DP1fMWH0:RXZ02<S8`1kNg/0Ogmo05QHF01JFUX0?3`l0451@@1DE5@0DE5A06=SH`1:BTX0M7Ad065Q
H@0P8200CDe=04m?C`1_Kfl0KVi^07EeM@1jNWX0F5QH07EeM@17AdL0EEEE059BDP0N7Qh0=3@d02LW
9`0d=3@0>3Ph03Lg=`0d=3@0ATI606MWI`80I6AT01`0GemO03/k>`1ZJVX0Kfm_069RHP1CDe<0CTi>
065QH@1GEeL0FUYJ01lO7`0^;Rh0?Cdm02HV9P14A4@0@D5104=3@`1HF5P0:RXZ051@D00m?Cd0G5aL
02/[:`14A4@0F5QH04I6AP12@T8071`L0P0m?Cd0T@0];Bd0F5QH030`<00e=CD0AdM70410@01<C4`0
=cLg03`l?00^;Rh0@T9205UIF@1CDe<0?3`l0451@@1=CDd0<S8b04A4A00o?cl0<c<c034a<@0J6QX0
7alO04];B`0I6AT0=3@d03Ti>@0e=CD09RHV03<c<`0/;2`0:b/[02XZ:P0O7al09BDU02TY:@0X:2P0
?clo03<c<`0h>3P0?3`l02/[:`10@400<c<c02d];@0f=SH0;bl_03/k>`0i>CT0=3@d02l_;`15ADD0
EEEE03Lg=`1?Cdl0F5QH06a/K012@T80?3`l03De=@1;Bd/0DE5A051@D01OGel0>c/k05IFEP0o?cl0
AdM706][J`12@T80Cdm?04=3@`0m?Cd0;Bd]03Ti>@1:BTX0GUiN04M7A`0b<S80NGUi069RHP1bLW80
Ng]k03Lg=`2@T900KVi^05IFEP1jNWX0ATI607EeM@1DE5@0=SHf05UIF@1<C4`0EeMG03lo?`0i>CT0
@D510410@01kNg/0<c<c0<71`@1CDe<0FUYJ04M7A`1cLg<09bLW02TY:@1VIVH0Fe]K03Lg=`16ATH0
A4A401hN7P1mOGd0De=C02PX:01?Cdl0>3Ph075aL@0k>c/0<c<c04m?C`0P8200GemO0451@@0];Bd0
K6a/05EEE@0f=SH0@41001hN7P13@d<051@D03hn?P13@d<08R8R02`/;00n?Sh0H61P038b<P1GEeL0
G5aL02h^;P0];Bd00P0g=cL08@15ADD0D51@07EeM@2^[Zh0BTY:04U9B@1IFET0ATI604i>CP0`<300
<S8b030`<00m?Cd0A4A402@T9013@d<0:RXZ06][J`0];Bd0:2PX03dm?@15ADD0@D5105QHF00j>SX0
?clo05EEE@1GEeL0Bd];0451@@12@T80H61P03De=@0203/k>`0_030`<012@T80@D5104M7A`1EEED0
ADE506IVIP1hN7P0D51@05mOG`0I6AT0;Rh^03Lg=`0f=SH0Shn?04A4A01dM7@0>CTi03lo?`1ADE40
@41004a<C00U9BD0HV9R034a<@1PH600<c<c02l_;`14A4@0?clo07inOP1dM7@0>SXj05=CD`1JFUX0
>SXj07emO@16ATH0Jf][04=3@`1FEUH0ATI606YZJP0c<c<0BDU9065QH@1:BTX00P1BDU806@2UYJD0
Fe]K01/K6`1RHV80BDU9051@D01UIFD0<S8b06QXJ01FEUH0<c<c059BDP0o?cl0Fe]K02XZ:P1RHV80
J6QX06IVIP1HF5P0Fe]K04];B`16ATH0Bd];04e=C@1<C4`00_ooool0003o0;Vi^@1:BTX0Q8B40:FU
Y@1fMWH0M7Ad04Q8B01HF5P0QhN705=CD`1iNGT0OGem03lo?`16ATH0Ng]k03Xj>P17AdL0KFe]02h^
;P0b<S80MWIf09fMW@1=CDd0H61P02d];@0/;2`0@41006e]K@15ADD0<c<c055AD@0`<300?Shn07in
OP1EEED0;2`/03Ph>010@400<30`069RHP1cLg<09BDU01HF5P0e=CD0@D5103Hf=P29RHT0/;2`02`/
;00];Bd0FEUI059BDP1UIFD0]KFe08:2PP0O7al0=3@d06YZJP1OGel0Ng]k08F5Q@0Z:RX0=CDe03Hf
=P24Q8@0BDU909^KV`1bLW80;2`/034a<@1oOgl0EeMG05eMG@2/[:`0MGEe02d];@1CDe<0OGem05aL
G01XJ6P0O7al03Ph>00_;bl0FEUI05QHF00c<c<0De=C07alO00L71`0820P05IFEP1cLg<0<C4a04A4
A01UIFD0=cLg03@d=01YJFT0GemO01/K6`14A4@0?3`l04e=C@1FEUH0I6AT02/[:`0_;bl0IVIV02/[
:`1:BTX0YjNW07QhN00U9BD0=CDe04Y:BP1BDU80AdM70:NWY`1OGel092@T03Ph>01QHF40IFEU07mo
O`2d];@0;bl_03Ph>01MGEd0MWIf07emO@1GEeL0XJ6Q034a<@0b<S80GemO06IVIP11@D40FUYJ08F5
Q@0U9BD0=CDe04A4A01WIfL0De=C06m_K`19BDT08b<S04i>CP1ZJVX0EEEE03Ph>01DE5@0>CTi034a
<@1QHF40JFUY04=3@`12@T80JFUY03dm?@1PH600SHf=03Xj>P10@400FUYJ03@d=012@T80HF5Q07=c
L`0S8b<0=CDe05ADE01<C4`0Jf][08:2PP1IFET0820P03@d=017AdL0LW9b07UiN@2VYZH0:b/[02LW
9`1eMGD0De=C04Q8B02LW9`0Vi^K01HF5P0/;2`0P82007MgM`1FEUH0`<300861P@0R8R80=3@d07Ee
M@1>CTh0HV9R0:n_[`1?Cdl07AdM03`l?02CTi<0GEeM0<71`@1fMWH0:b/[04=3@`1TI6@0RXZ:05AD
E021PH40;Bd]02@T902;Rh/0UiNG0451@@1TI6@0=SHf02<S8`1@D500Z:RX07inOP18B4P0AdM702/[
:`19BDT0R8R80410@00m?Cd0Hf=S03/k>`1>CTh0SXj>03lo?`0e=CD0CTi>03lo?`1GEeL0UIFE05mO
G`0M7Ad0E5AD05mOG`1JFUX0Y:BT04i>CP0V9RH0>3Ph08f=S@1oOgl0PH61002R0:n_[`17AdL07alO
04=3@`2QXJ40K6a/08R8R02<S8`0<30`03/k>`1cLg<0Z:RX05ADE02b/[80PH6102HV9P1:BTX0Ph>3
08Z:RP1NGUh0NGUi07]kN`0U9BD0?Cdm08j>SP2LW9`0EUIF0:FUY@1OGel0=3@d04U9B@2PX:00Ng]k
04e=C@1NGUh0@D5104I6AP1IFET0HV9R03@d=00b<S80EeMG020P800U9BD0BDU906ATI01@D500<C4a
08:2PP1:BTX0<S8b08J6QP2?Shl09RHV02l_;`17AdL0ADE50492@P22PX80Vi^K03<c<`0L71`0<c<c
04i>CP1LG5`0MgMg051@D00g=cL0DE5A04Q8B01:BTX0ADE5065QH@1OGel0Cdm?07IfMP1^KVh0Ti>C
09nOW`1@D500@D5103lo?`1EEED0FUYJ04a<C017AdL0?Shn0492@P0a<C40CDe=0410@014A4@0<c<c
05ADE01ADE40F5QH07emO@1FEUH0ADE505YJFP1TI6@0EEEE06MWI`1UIFD0G5aL06=SH`1MGEd0?3`l
038b<P12@T80E5AD05QHF015ADD0D51@05IFEP0e=CD0C4a<04U9B@1ADE40<30`059BDP1NGUh0@T92
05=CD`0N7Qh0ADE50492@P0i>CT0M7Ad04M7A`0m?Cd0FEUI059BDP1PH6009bLW04a<C01=CDd0JFUY
05aLG01MGEd0>c/k04=3@`1jNWX0ADE5061PH00e=CD0@T92079bLP0a<C40=cLg06YZJP0@4100B4Q8
055AD@17AdL0ADE504m?C`0Z:RX0AdM704I6AP0b<S80;Rh^0P0a<C40[P1KFe/0>CTi03hn?P1FEUH0
?Shn05IFEP0K6a/0<30`05=CD`0X:2P0=cLg02LW9`0c<c<0<S8b03hn?P0c<c<0=cLg04e=C@0d=3@0
=CDe02l_;`0l?3`0B4Q8020P800S8b<0?clo061PH00m?Cd0<c<c03dm?@0f=SH0D51@0451@@1>CTh0
7alO030`<00_;bl0ADE504i>CP1`L700Fe]K051@D02@T900GEeM05mOG`20P800DE5A0::RXP1XJ6P0
DU9B06e]K@1_Kfl0[Zj^07IfMP12@T80EEEE055AD@1MGEd0AdM703hn?P18B4P0CDe=07EeM@0k>c/0
/k>c07EeM@1ZJVX0IFEU0:ZZZP0_;bl08B4Q0410@016ATH07alO04i>CP1FEUH09BDU07MgM`1BDU80
EUIF0861P@0d=3@0EUIF02l_;`1EEED0MWIf02LW9`0l?3`0<C4a038b<P1ADE40DU9B04M7A`16ATH0
:b/[05MGE`0e=CD0@T920410@00o?cl0CTi>03/k>`1XJ6P0:b/[01`L700^;Rh051@D03hn?P1;Bd/0
=SHf07AdM01ADE40EUIF08R8R016ATH0=CDe04i>CP0j>SX0?Cdm03Ph>01HF5P0ATI605YJFP1KFe/0
@d=305QHF00D51@0M7Ad02HV9P0g=cL0E5AD05IFEP0h>3P0EUIF0492@P0e=CD0DU9B061PH011@D40
GUiN03Ph>01=CDd0D51@05MGE`0a<C4092@T03Ti>@0c<c<0C4a<05mOG`0Y:BT0CTi>04m?C`1<C4`0
IVIV00`<300c<c<0<S8b024Q8@1bLW80;Bd]07QhN00j>SX0A4A403Ph>010@400EeMG01DE5@17AdL0
8B4Q06YZJP17AdL0?Shn061PH080F5QH0280BTY:03Ph>01RHV80CDe=01TI6@1XJ6P08B4Q05]KF`19
BDT0GEeM04E5A@1WIfL0CTi>07moO`1[Jf/0DE5A05EEE@0m?Cd0EUIF03/k>`0V9RH0IfMW03Lg=`19
BDT0EEEE024Q8@0`<300EeMG04A4A01@D500:b/[04U9B@0c<c<0P8200P18B4P01`1ZJVX0Hf=S04U9
B@17AdL0De=C05iNGP1?Cdl00_ooool000300:VYZ@1QHF40JVYZ05MGE`1XJ6P0TI6A05EEE@1CDe<0
Fe]K04Q8B01dM7@0Jf][03/k>`19BDT0E5AD03Xj>P1OGel0Ng]k02`/;00P8200DU9B06a/K01DE5@0
XJ6Q09ZJVP0U9BD0@41004Y:BP13@d<0S8b<0:b/[00G5aL0=cLg04A4A01KFe/0M7Ad092@T01fMWH0
7AdM03dm?@1MGEd0B4Q803Hf=P2?Shl0DU9B01DE5@0o?cl0L71`06UYJ@1;Bd/0GemO02l_;`0/;2`0
EeMG07YjNP1?Cdl0J6QX05aLG00K6a/0@D51071`L01JFUX0=SHf06=SH`0L71`0:2PX04i>CP1QHF40
;Bd]03hn?P1GEeL0<S8b05=CD`1]KFd0G5aL03Lg=`1eMGD0E5AD03/k>`2MWId0];Bd02d];@0T92@0
=CDe03lo?`0i>CT0RHV90;2`/00c<c<06ATI04U9B@1GEeL0EUIF09:BTP1lO7`0=cLg03@d=014A4@0
GUiN07QhN02VYZH0B4Q801/K6`0n?Sh0M7Ad05EEE@1UIFD0`/;203dm?@0M7Ad0FEUI09:BTP13@d<0
DE5A079bLP0[:b/0=SHf07UiN@2f][H0Cdm?05]KF`0j>SX0;bl_04M7A`2ATI40MgMg02DU9@1QHF40
Hf=S02TY:@1QHF40QXJ606EUI@0R8R80AdM7069RHP14A4@0MWIf09^KV`1:BTX0<30`059BDP1;Bd/0
<S8b08B4Q02LW9`0:2PX0492@P23Ph<0P82008F5Q@1oOgl0>c/k02/[:`17AdL0FEUI04Y:BP2EUID0
^;Rh0492@P1HF5P0P82007]kN`2HV9P0`<3005MGE`0/;2`0QHF506ATI016ATH0K6a/08R8R00];Bd0
DU9B06e]K@1WIfL0?Cdm05MGE`1OGel05ADE03`l?01QHF40JFUY03Hf=P1ZJVX0>CTi024Q8@1:BTX0
WinO04e=C@1JFUX0C4a<0P0X:2P0C01NGUh0R8R804Q8B012@T80CTi>02`/;00c<c<0NGUi07emO@0a
<C40BTY:03Ti>@0a<C40KFe]07moO`0[:b/0=3@d04U9B@15ADD0H61P07IfMP0j>SX0820P04Q8B01H
F5P0Fe]K09JFUP1QHF406a/K02<S8`1^KVh0Rh^;09jNWP1bLW806ATI03Xj>P1ADE40FEUI08N7Q`2`
/;00<C4a04U9B@1iNGT0E5AD0820P025QHD061PH0410@01^KVh0GemO04m?C`2HV9P0MgMg02@T901]
KFd0[jn_05ADE01aLG40Fe]K03Ti>@1UIFD0NGUi0;Ng]`1UIFD0GemO05iNGP1;Bd/0KFe]08j>SP1J
FUX0F5QH05UIF@17AdL0CTi>05UIF@27QhL203`l?03o05=CD`18B4P0?Cdm08J6QP2XZ:P0BDU902/[
:`0m?Cd0>c/k04=3@`2=SHd0R8R802LW9`0c<c<0C4a<08F5Q@2RXZ80QHF505QHF00U9BD0EeMG07al
O01<C4`0FUYJ0:2PX00n?Sh0<c<c03hn?P1UIFD0HV9R065QH@2d];@0KFe]04Q8B012@T80JVYZ05AD
E01]KFd0SHf=03`l?00N7Qh0ADE5071`L01EEED0EUIF06][J`0P8200FEUI05MGE`0W9bL0;bl_051@
D01;Bd/0D51@03lo?`1jNWX0SXj>02@T900h>3P0?Shn04E5A@19BDT0AdM706i^KP1ADE40E5AD03dm
?@10@400@d=302`/;00m?Cd0=CDe04=3@`15ADD0JFUY03lo?`1=CDd0@T9205ADE01XJ6P0@D5103Hf
=P11@D40BDU903`l?017AdL0ATI60492@P1CDe<0B4Q802l_;`0d=3@0:RXZ02h^;P0d=3@0@D5104E5
A@0`<300:b/[03Ti>@1@D500CDe=01`L700j>SX0C4a<0451@@1<C4`0=SHf04Y:BP0i>CT0<S8b059B
DP0n?Sh0>CTi04U9B@1EEED0BTY:038b<P15ADD0DE5A03hn?P2:RXX0Rh^;03hn?P18B4P0GUiN051@
D01NGUh0D51@065QH@1JFUX0=CDe03<c<`1?Cdl0=3@d04I6AP1:BTX0B4Q803lo?`15ADD0@D5103/k
>`16ATH092@T04I6AP0i>CT0=CDe055AD@18B4P0>c/k04I6AP10@400EUIF030`<00^;Rh0EEEE03`l
?019BDT0=SHf0410@00n?Sh0CTi>04I6AP10@400DU9B04i>CP1LG5`0>SXj03Ph>00];Bd0=CDe03lo
?`0n?Sh0HF5Q00d=3@1EEED0HF5Q03Lg=`1RHV80;Bd]04=3@`0X:2P0<c<c030`<00l?3`0>3Ph05=C
D`11@D40EUIF0:n_[`1<C4`0F5QH05iNGP0O7al0:b/[04a<C02<S8`0KVi^01lO7`0d=3@0?Cdm03Xj
>P1ADE40Lg=c07EeM@0`<300@d=305mOG`1ADE40N7Qh01lO7`2IVIT0BTY:05mOG`1FEUH0C4a<03Lg
=`0f=SH0D51@05mOG`0R8R80GEeM04i>CP0[:b/0QXJ605]KF`0c<c<0AdM703@d=01TI6@09bLW03hn
?P1SHf<092@T04i>CP13@d<0<S8b05EEE@1@D500E5AD05aLG00];Bd0CDe=010@400d=3@0B4Q804=3
@`1KFe/0CDe=06EUI@0n?Sh0Cdm?04M7A`0G5aL0?Cdm001W03lo?`0^;Rh0BDU9061PH01ZJVX0WYjN
059BDP10@400KVi^04];B`17AdL0<c<c02h^;P16ATH0CTi>0492@P0c<c<0Bd];024Q8@1]KFd0<30`
04E5A@1YJFT0HV9R02l_;`1>CTh0=cLg04E5A@1PH600FUYJ04A4A01=CDd0A4A4055AD@0e=CD0C4a<
04M7A`0/;2`0AdM704E5A@0l?3`0CDe=03De=@1ZJVX0L71`05IFEP1QHF405aLG03Ti>@0`<300<c<c
06IVIP0f=SH0GUiN04=3@`16ATH0DU9B03@d=019BDT0?Cdm05ADE017AdL0CTi>03Ph>00S8b<0?Cdm
03De=@1^KVh0JFUY04M7A`1cLg<0GUiN02PX:01[Jf/0<30`08>3P`1ADE40F5QH04U9B@2>SXh0Jf][
05MGE`1RHV80DU9B03lo?`19BDT0Ogmo04I6AP0h>3P0GemO06UYJ@1PH600KVi^04a<C01CDe<0EEEE
04];B`1WIfL0@T92051@D01<C4`0OGem05IFEP0204a<C080@T9200@0Bd];05iNGP1=CDd0D51@0_oo
ool0002^08J6QP1oOgl0c<c<04e=C@1;Bd/0O7al07]kN`2ZZZX0FUYJ04U9B@17AdL0SXj>059BDP2W
YjL0L71`03Ti>@0a<C40H61P04e=C@19BDT0PH610492@P0a<C40E5AD08b<S01FEUH0Q8B406e]K@0M
7Ad0FUYJ079bLP1QHF40@d=307YjNP0W9bL0?Shn04Y:BP1@D500<30`02TY:@1BDU80<S8b03/k>`1M
GEd0MWIf03`l?00n?Sh0EeMG055AD@1]KFd0L71`02PX:00W9bL0Cdm?05eMG@1BDU80TI6A08R8R00T
92@09RHV059BDP1iNGT0HF5Q0;Rh^00V9RH0:b/[04Q8B01[Jf/0FEUI06][J`2?Shl051@D02LW9`1?
Cdl0JVYZ04I6AP2j^[X0TY:B01XJ6P0Y:BT0DE5A04Q8B01QHF40I6AT02d];@0^;Rh0=SHf05QHF01C
De<0>SXj05ADE00T92@07QhN02`/;01LG5`0IfMW03Xj>P21PH40@T9202@T901iNGT0NWYj034a<@18
B4P0IFEU01/K6`15ADD0TI6A06YZJP0];Bd0>c/k059BDP0[:b/0E5AD09VIV@0V9RH07QhN030`<01@
D500?3`l096AT@21PH406ATI04E5A@13@d<0BDU905YJFP2f][H0PX:201TI6@0l?3`0JFUY04e=C@12
@T80MgMg071`L00K6a/0AdM709JFUP1XJ6P0CDe=061PH00g=cL092@T05YJFP1jNWX0?Shn07YjNP1i
NGT05ADE03De=@1oOgl0GemO03Ph>01FEUH0?3`l01lO7`10@400TY:B04m?C`1FEUH0;Rh^02@T901V
IVH0PX:208B4Q016ATH0K6a/0410@00Y:BT0F5QH0;bl_01TI6@0>3Ph0P1FEUH0S`1ADE40R8R80:>S
X`0[:b/0?clo04U9B@1:BTX0Ogmo08>3P`17AdL092@T03Xj>P15ADD0>3Ph0861P@2YZJT0<c<c02@T
900d=3@0EUIF05aLG02EUID0Ti>C02/[:`16ATH0ADE506QXJ01WIfL0MWIf04e=C@0M7Ad0B4Q806QX
J01:BTX0IFEU08N7Q`0M7Ad0B4Q806e]K@1WIfL0DE5A06e]K@0k>c/0>CTi0451@@24Q8@0DE5A04M7
A`1:BTX0820P05QHF01gMgL0?Cdm03Lg=`1HF5P06QXJ03De=@2TY:@0NGUi03dm?@1MGEd08B4Q07em
O@2n_[h0F5QH034a<@1IFET0@T9203<c<`2KVi/0OWin024Q8@0b<S80CTi>05=CD`20P800RHV902HV
9P0l?3`0HF5Q0861P@2LW9`0[jn_0:2PX00U9BD0>3Ph07QhN01MGEd0KFe]0:j^[P0i>CT0@410061P
H01UIFD0DE5A061PH02<S8`0=cLg02XZ:P1DE5@0RHV9065QH@1ZJVX0W9bL02l_;`0/;2`0D51@08F5
Q@1>CTh0MgMg05QHF00U9BD0=cLg069RHP1ZJVX0A4A405YJFP1kNg/0;Rh^03/k>`2BTY80R8R804I6
AP1]KFd0Cdm?01TI6@0S8b<0PH6107alO00h>3P0BTY:04E5A@0a<C40@d=308:2PP1TI6@09RHV03Hf
=P1>CTh0EeMG05]KF`25QHD0?Shn0080De=C0400Bd];05iNGP1kNg/0HV9R05QHF01;Bd/0ATI604U9
B@0W9bL0C4a<04M7A`1VIVH0LW9b07]kN`2_[jl0UIFE07moO`1;Bd/0G5aL05MGE`10@400@T9204I6
AP1LG5`0@D5104=3@`0m?Cd0GUiN06m_K`1PH600G5aL05eMG@1@D500HF5Q04a<C01QHF40EEEE059B
DP1JFUX0D51@05UIF@0Y:BT09RHV0451@@1@D500G5aL04Q8B012@T80DE5A03Hf=P0o?cl0:BTY03Ph
>00X:2P0<S8b04I6AP12@T80@D5102<S8`0i>CT0=cLg04i>CP1ADE40=SHf0P0i>CT0S`18B4P0?3`l
02d];@10@400CDe=034a<@18B4P0CTi>04=3@`1GEeL0@D510410@019BDT0=cLg03Ti>@1:BTX09bLW
02PX:01VIVH0:BTY05MGE`1FEUH0AdM704a<C01;Bd/0@41004I6AP12@T80;Rh^02l_;`0h>3P0=cLg
04m?C`11@D40=3@d04U9B@12@T80Cdm?03De=@0h>3P0BDU902PX:00o?cl0>3Ph038b<P0e=CD0@d=3
04M7A`0o?cl0EeMG04e=C@1BDU80;bl_05YJFP0];Bd0?3`l03Hf=P1HF5P0G5aL02DU9@1EEED0IFEU
06a/K01kNg/0=CDe04a<C00e=CD0?Cdm034a<@0g=cL0EEEE04i>CP17AdL0;2`/04M7A`1CDe<0M7Ad
079bLP0m?Cd0G5aL03dm?@1JFUX0NWYj03hn?P1kNg/0EUIF038b<P15ADD0:b/[03Xj>P17AdL0?3`l
04=3@`1DE5@0N7Qh03Xj>P36a/H0Lg=c07IfMP1NGUh0EEEE03Lg=`0o?cl0IFEU05UIF@0`<300J6QX
04i>CP0P8200Jf][04Y:BP0T92@0EeMG030`<01NGUh0=CDe03Ti>@1^KVh0<C4a05aLG011@D408b<S
04Q8B019BDT0=3@d03hn?P0];Bd0JVYZ03lo?`0j>SX0D51@03`l?01;Bd/0=CDe06EUI@0n?Sh09RHV
03dm?@0U9BD0@T9204e=C@1;Bd/0De=C0080MGEe06X0[:b/06MWI`1<C4`0IVIV06e]K@1@D500DE5A
03Xj>P0g=cL0H61P07QhN016ATH0GEeM02HV9P1`L700>c/k03Hf=P1BDU80FUYJ05aLG01jNWX0G5aL
04Q8B01BDU80HV9R06QXJ01GEeL0B4Q806ATI01<C4`0Cdm?0451@@15ADD0?Cdm04A4A013@d<0DU9B
0410@01PH600LW9b051@D01SHf<0>CTi04E5A@14A4@0B4Q808Z:RP11@D40CDe=03`l?01=CDd0K6a/
05IFEP1NGUh0:BTY05aLG00P8200CTi>04A4A01:BTX0IFEU04Y:BP1/K6`0M7Ad02d];@1FEUH0De=C
010@4029RHT0DE5A05EEE@0j>SX0Ogmo06=SH`1`L700Cdm?0;6a/@1eMGD0QXJ608N7Q`1`L700Z:RX
065QH@0h>3P0QHF505mOG`1oOgl0JVYZ03Hf=P10@400BTY:03`l?01@D500B4Q8079bLP0f=SH0Hf=S
04U9B@1XJ6P0Lg=c04];B`1HF5P0C4a<055AD@1WIfL0E5AD0_ooool0000307QhN01FEUH0J6QX0080
K6a/04X0E5AD03@d=01@D500VYZJ04I6AP1]KFd0IFEU03<c<`1CDe<0P820034a<@0j>SX0?3`l03De
=@1GEeL0Ng]k04i>CP0W9bL0@D5103Ph>01BDU80/k>c075aL@0S8b<0<30`05iNGP0i>CT0Lg=c0<o?
c`1CDe<051@D0451@@1BDU80@D5107=cL`2RXZ80>3Ph020P801KFe/0DE5A04Y:BP1lO7`0ZJVY02d]
;@0j>SX0OWin075aL@1<C4`0Jf][03`l?00W9bL0=3@d08:2PP1XJ6P0C4a<05UIF@0D51@0@D5107Ad
M01YJFT0<S8b08N7Q`1;Bd/0<c<c055AD@29RHT0BDU904e=C@1SHf<0=3@d04=3@`1WIfL0YJFU03Ph
>080AdM70P18B4P0X02NWYh0PH6101LG5`0c<c<0FUYJ04U9B@1HF5P0U9BD04Q8B00J6QX092@T02/[
:`1;Bd/0I6AT09NGU`0f=SH0:RXZ03/k>`1=CDd0D51@07QhN02SXj<09RHV03`l?00d=3@0Hf=S04a<
C01UIFD0H61P02l_;`16ATH0Fe]K05ADE012@T80J6QX03dm?@0F5QH0:2PX069RHP0c<c<0FEUI07Ad
M00g=cL0<c<c07=cL`2BTY80FUYJ05UIF@1jNWX0>3Ph02h^;P2OWil0Xj>S02LW9`10@400G5aL03Ph
>01ZJVX0O7al03Ti>@0T92@0ATI604m?C`0m?Cd0Ogmo09VIV@10@4007QhN05YJFP1UIFD0GUiN061P
H00f=SH06QXJ03@d=01UIFD0RHV90:JVYP0i>CT07alO02/[:`1ZJVX0H61P04E5A@2YZJT08R8R02`/
;00b<S80De=C079bLP1WIfL0R8R802PX:00^;Rh0JVYZ0820P01ADE40Shn?09VIV@0N7Qh08b<S08F5
Q@1[Jf/0>3Ph06a/K01:BTX0>CTi03/k>`1oOgl0MGEe03`l?01PH60071`L01XJ6P0k>c/0Vi^K051@
D00e=CD0DU9B01TI6@0c<c<0NWYj0:RXZ018B4P0E5AD0451@@0];Bd0LW9b09FEU@0/;2`0<C4a04e=
C@0d=3@0Cdm?09VIV@1JFUX092@T03/k>`19BDT0LW9b07QhN01fMWH09BDU03`l?01TI6@0=cLg05mO
G`29RHT0820P02<S8`1iNGT0SXj>069RHP20P8009RHV04=3@`1PH600HV9R071`L02LW9`203/k>`0h
07IfMP2BTY80G5aL08f=S@11@D40:b/[04m?C`2g]kL0Ph>304=3@`1HF5P08R8R03hn?P1[Jf/0[jn_
06a/K01ZJVX0De=C02PX:01OGel0Ogmo079bLP0g=cL0B4Q8051@D00m?Cd0F5QH0:>SX`1KFe/0>CTi
04Q8B00i>CT0ATI604U9B@21PH40HV9R02TY:@1JFUX0CTi>05]KF`23Ph<0VIVI02h^;P0_;bl0E5AD
05iNGP1FEUH0Ng]k092@T00[:b/07alO04=3@`1<C4`0EeMG08J6QP2FUYH201lO7`1^04A4A01RHV80
BDU907alO01WIfL0820P04M7A`1BDU80M7Ad04E5A@1YJFT0GemO01LG5`11@D40Ng]k071`L01TI6@0
OWin04Y:BP0e=CD0BDU903lo?`1/K6`0@d=305YJFP1ZJVX0:BTY07QhN01TI6@0EUIF05eMG@1ADE40
EEEE04i>CP1_Kfl0IFEU04U9B@14A4@08B4Q03Lg=`0a<C40?Cdm03De=@12@T80>c/k0451@@1DE5@0
FUYJ05]KF`1;Bd/0;2`/04Y:BP1;Bd/0A4A404I6AP1EEED0EUIF05YJFP17AdL0BDU903<c<`14A4@0
9bLW0410@00o?cl0CDe=0410@00b<S80>SXj03Ti>@19BDT0ATI604m?C`1FEUH0?Shn04m?C`0h>3P0
B4Q803De=@0Q8B40B4Q804A4A00m?Cd0=3@d04];B`1CDe<0@D51051@D017AdL0B4Q805iNGP1LG5`0
;Bd]03De=@1LG5`0ADE505aLG00c<c<0>3Ph06a/K00T92@0:b/[0410@00S8b<0?3`l04I6AP0m?Cd0
;Rh^03@d=00f=SH2030`<00_02LW9`0_;bl07alO034a<@0j>SX0@d=302XZ:P0o?cl0>CTi04e=C@0W
9bL0;Bd]03Xj>P11@D40?Cdm02TY:@0g=cL0ATI604Y:BP1IFET0;bl_04U9B@1GEeL0F5QH01hN7P16
ATH08B4Q04a<C00Z:RX0@d=3051@D00l?3`0?clo038b<P0Y:BT0@D5103<c<`19BDT07QhN04A4A00j
>SX0>CTi051@D01hN7P0Fe]K04i>CP1hN7P00P0j>SX0Z@1QHF40>3Ph07IfMP1;Bd/0JFUY06=SH`13
@d<0VIVI05UIF@1EEED0NGUi05UIF@1]KFd0A4A404Q8B017AdL0FUYJ07MgM`0P8200OWin05QHF02A
TI40Cdm?06UYJ@12@T80Ogmo079bLP1=CDd0:b/[05IFEP12@T8092@T07QhN01NGUh0>SXj07alO00c
<c<0>c/k03Ph>016ATH0NGUi03Lg=`1BDU80=cLg03De=@1aLG40FUYJ04M7A`13@d<0@T9208f=S@0o
?cl0Bd];055AD@0a<C40FUYJ04A4A01_Kfl0CDe=0451@@1TI6@05QHF04A4A01;Bd/0@D5105UIF@1<
C4`0CTi>08b<S01HF5P0O7al07moO`12@T80?Shn04A4A01KFe/0EUIF04U9B@1=CDd0?3`l051@D00h
>3P0[jn_07MgM`0h>3P0De=C05EEE@0Z:RX0B4Q803`l?00f=SH0B4Q805YJFP1SHf<0EEEE03De=@1C
De<0ATI604a<C00e=CD0>3Ph03`l?00d=3@0B4Q806=SH`0Z:RX0HF5Q05EEE@13@d<0JVYZ01@D501I
FET0@d=303Ti>@1KFe/07alO05EEE@15ADD0BDU902d];@10@400F5QH02HV9P0n?Sh07AdM051@D00[
:b/06ATI02XZ:P0P8200De=C059BDP0];Bd0T92@071`L00m?Cd0FUYJ02PX:01PH600EEEE06=SH`1R
HV80Ogmo05]KF`1<C4`0CTi>05MGE`1>CTh0K6a/09:BTP1GEeL0@D5105MGE`1IFET0A4A405IFEP1:
BTX0?clo04a<C01DE5@0I6AT03hn?P14A4@0ADE507moO`1LG5`0BTY:05IFEP0k>c/00P12@T800`1U
IFD0DE5A05EEE@02ooooo`0007d0_kno05=CD`1nOWh0GUiN09nOW`2/[:`0ATI603lo?`1@D500M7Ad
09nOW`27QhL0<c<c03De=@1NGUh0EEEE08:2PP1bLW80820P038b<P16ATH0I6AT08R8R02ZZZX0<c<c
03Ti>@1CDe<0M7Ad03hn?P1WIfL0De=C024Q8@0l?3`0IVIV07AdM012@T80A4A405aLG00X:2P0?clo
071`L01[Jf/0<S8b06QXJ00l?3`0:BTY05QHF02FUYH0CTi>02LW9`1GEeL0:b/[075aL@2EUID0>SXj
028R8P0`<300CDe=030`<02:RXX0W9bL02TY:@0T92@0DE5A02h^;P18B4P0Z:RX07EeM@0E5AD0@410
06YZJP1^KVh0IVIV0;Zj^P1@D500=SHf04];B`1JFUX0EUIF09BDU020P8007alO03Ph>01JFUX0UYJF
04];B`1_Kfl0QhN702d];@0N7Qh0EEEE0:2PX00f=SH0IVIV0451@@0K6a/0:RXZ07MgM`2QXJ40:2PX
08B4Q00O7al0:BTY0410@025QHD0GEeM05QHF01TI6@09BDU04A4A01VIVH0Rh^;04A4A00i>CT0EUIF
03/k>`0_;bl0SHf=08b<S00S8b<0=cLg03lo?`0m?Cd0NWYj09VIV@0203<c<`1703Ti>@1OGel0JFUY
09NGU`2^[Zh0>3Ph03lo?`1FEUH0S8b<05eMG@1aLG40W9bL03`l?00T92@0LG5a09ZJVP1bLW80UIFE
07inOP0O7al0>c/k0::RXP1BDU80GUiN07EeM@0_;bl0;Rh^05UIF@28R8P0=cLg09jNWP1UIFD0;2`/
06a/K028R8P0<c<c04M7A`1EEED09bLW03/k>`1ZJVX0NGUi02PX:00f=SH0CTi>03hn?P17AdL0Ph>3
07YjNP0^;Rh0C4a<04Y:BP0Z:RX0SXj>0:6QX@0l?3`09BDU04Y:BP13@d<0EEEE09fMW@1FEUH07QhN
02PX:00i>CT0C4a<05YJFP2OWil0>SXj01/K6`0T92@00P1OGel03`1hN7P0R8R802@T900V9RH0?Shn
0861P@1FEUH0W9bL04i>CP0`<300G5aL071`L01BDU80Jf][08F5Q@0202DU9@1906=SH`1XJ6P0@410
07UiN@16ATH08B4Q05UIF@2NWYh0N7Qh03dm?@1@D500;2`/030`<01hN7P0FEUI065QH@13@d<09BDU
055AD@1dM7@0BTY:03dm?@1JFUX0820P0492@P24Q8@0L71`01lO7`1[Jf/0@d=306ATI026QXH0GUiN
02LW9`0`<300Fe]K07=cL`2HV9P0WYjN04U9B@0X:2P0J6QX06EUI@1oOgl0XJ6Q09VIV@0[:b/0;Rh^
06i^KP23Ph<0N7Qh08B4Q025QHD0=3@d0492@P1_Kfl0U9BD079bLP2e]KD0YjNW02@T900d=3@0GemO
07emO@1=CDd0UYJF05]KF`0J6QX0F5QH0:NWY`1_Kfl0KVi^09fMW@0203lo?`0@05EEE@2;Rh/0KVi^
0410@01[Jf/09RHV02l_;`16ATH0L71`03Xj>P0Y:BT0GUiN02DU9@0d=3@0FEUI07MgM`80?3`l01d0
FEUI03dm?@0Z:RX0GEeM0:JVYP12@T808R8R03Ti>@0e=CD0D51@04Y:BP0i>CT0DU9B06a/K01GEeL0
CDe=04A4A01CDe<0LG5a04Y:BP11@D40ATI607inOP1iNGT0EeMG06i^KP1BDU80GEeM04E5A@0204=3
@`0302<S8`12@T80=3@d0080?clo03T0Lg=c0410@015ADD0G5aL06MWI`28R8P0FUYJ03Ph>01CDe<0
FUYJ059BDP15ADD0A4A4051@D01]KFd0FEUI03De=@0j>SX0C4a<03Ph>01<C4`0DE5A05aLG01=CDd0
;Rh^04=3@`1@D500Cdm?02l_;`0a<C40D51@07AdM00m?Cd05ADE03/k>`12@T80CTi>05UIF@0W9bL0
:b/[04m?C`1PH600A4A402TY:@17AdL0HF5Q03/k>`1eMGD0JFUY04e=C@1>CTh0D51@03De=@10@400
>SXj03Ph>01SHf<00P1;Bd/0J01FEUH08B4Q0451@@1:BTX0D51@03dm?@0c<c<0;Bd]02LW9`0X:2P0
;Bd]03hn?P0V9RH0:2PX04Q8B01DE5@06a/K04A4A013@d<0E5AD01XJ6P0Q8B40A4A402/[:`0d=3@0
<C4a02/[:`11@D40>c/k03Ti>@0m?Cd0EeMG03lo?`0g=cL0>CTi06=SH`0[:b/0;2`/034a<@1iNGT0
GUiN020P800o?cl0?Shn03De=@14A4@0=SHf02d];@0K6a/0>CTi03Lg=`16ATH0>SXj0492@P11@D40
@d=309ZJVP11@D40DU9B055AD@0^;Rh0BTY:03Xj>P1LG5`0GemO03<c<`0k>c/0?Cdm038b<P1?Cdl0
Kfm_06i^KP1]KFd0D51@04U9B@1TI6@0R8R802d];@2a/K40GEeM06=SH`1PH600Q8B403/k>`12@T80
K6a/06UYJ@0k>c/0HV9R055AD@0V9RH0NWYj05MGE`0H61P0ADE502HV9P19BDT092@T030`<01SHf<0
=3@d06UYJ@0i>CT0:2PX0P0e=CD0H01VIVH0G5aL03<c<`1<C4`0<c<c038b<P0g=cL0C4a<075aL@1@
D500P82003De=@2EUID0Xj>S03De=@1GEeL0H61P05ADE01iNGT0KVi^06MWI`2BTY80EUIF04=3@`1=
CDd0G5aL0410@01<C4`0AdM70492@P1@D500BDU904e=C@1ZJVX07alO06QXJ01CDe<0FUYJ07UiN@1/
K6`0>CTi04a<C016ATH0DU9B05aLG01RHV80DU9B06][J`1FEUH0F5QH05=CD`1DE5@0@41003Xj>P19
BDT0Fe]K0492@P1ADE40=3@d06e]K@1TI6@0=cLg04e=C@0H61P0?Cdm034a<@17AdL0NGUi018B4P10
@400?clo04a<C00l?3`0=SHf059BDP0`<300Cdm?03dm?@1IFET0=CDe02l_;`18B4P0=3@d07alO02@
T900@d=3055AD@17AdL0:RXZ07IfMP12@T80JVYZ075aL@1`L700IFEU0:2PX080NGUi01L0MGEe06AT
I020P800EEEE071`L01WIfL0D51@06EUI@1[Jf/0BTY:05mOG`1DE5@0BDU905iNGP18B4P0F5QH04a<
C01=CDd0?Shn05=CD`1DE5@0EUIF05eMG@0204U9B@0405ADE01lO7`0GEeM061PH0;ooooo00003@1k
Ng/0W9bL0;Zj^P1ADE40Hf=S09nOW`2;Rh/0LW9b04U9B@12@T80KFe]08V9R@13@d<00P1NGUh0f@0W
9bL0E5AD0:VYZ@1DE5@0CTi>06ATI00L71`0<c<c07moO`23Ph<0;bl_06][J`1=CDd0D51@09:BTP1d
M7@09RHV02TY:@1;Bd/0D51@06UYJ@1gMgL0KFe]01PH600S8b<0GEeM06m_K`25QHD0S8b<03<c<`0R
8R80=3@d071`L01dM7@0Shn?09BDU00`<300<S8b071`L020P800CDe=07inOP1iNGT0;2`/02h^;P1k
Ng/0IVIV04M7A`1dM7@07AdM01hN7P0l?3`0I6AT04I6AP1ZJVX0FUYJ01XJ6P0i>CT0@T9205mOG`0Y
:BT0Lg=c05aLG00W9bL0HF5Q09jNWP0e=CD0820P03hn?P0g=cL0:RXZ04E5A@2ATI40<S8b01LG5`0a
<C40AdM703/k>`1]KFd0EEEE01dM7@0W9bL0?3`l07UiN@1_Kfl0[Zj^03Ph>00K6a/0:b/[04Y:BP13
@d<0PX:209nOW`0G5aL0:RXZ03/k>`2<S8`0TI6A08Z:RP2_[jl06a/K03De=@1=CDd0PH6106a/K028
R8P0JFUY01DE5@1BDU80Q8B4079bLP1BDU80PX:205UIF@0X:2P0D51@06IVIP1BDU80<S8b061PH00h
>3P0<30`05ADE01_Kfl0B4Q803De=@1<C4`08b<S04E5A@1aLG40Shn?05ADE01QHF40BDU903Ti>@1D
E5@0QHF505ADE00R8R80>c/k0410@01;Bd/0U9BD09FEU@0`<300Bd];07MgM`1BDU80R8R8096AT@0Z
:RX0@d=304];B`1bLW80Cdm?07moO`23Ph<07QhN04m?C`1MGEd0K6a/05QHF02a/K40J6QX01LG5`18
B4P0OWin06QXJ01DE5@0S8b<02`/;00Y:BT0@T9208R8R01[Jf/0KFe]06YZJP0N7Qh0>SXj05mOG`2L
W9`0?Shn04U9B@0n?Sh0?Cdm06i^KP2;Rh/0Kfm_03Lg=`1IFET0?3`l03Ph>01VIVH0PX:203dm?@0j
>SX0GemO03Ti>@0n?Sh0O7al069RHP0g=cL0FEUI03hn?P1@D500PH6106MWI`0/;2`0=3@d065QH@1B
DU80L71`07QhN00T92@08R8R03lo?`10@4000P1[Jf/0200M7Ad0@41006UYJ@15ADD0Hf=S08f=S@0M
7Ad0<C4a0P1ZJVX0F011@D40UiNG03De=@0g=cL0MGEe08j>SP1CDe<0N7Qh07emO@0O7al0EeMG0:6Q
X@2i^KT0De=C0:ZZZP0b<S80B4Q808:2PP2ATI40MWIf071`L02HV9P0=3@d038b<P2;Rh/0YjNW05aL
G01EEED0P82002l_;`1JFUX0GUiN071`L01IFET0@T9205aLG00^;Rh0@41008b<S02QXJ40ATI604m?
C`1@D500=SHf04i>CP1WIfL0EEEE02PX:00n?Sh0Cdm?06ATI01OGel0LG5a03/k>`0R8R80ATI605QH
F01QHF40JFUY0;Vi^@11@D40:2PX03/k>`1YJFT0Bd];05MGE`2][Jd0@T920410@018B4P0Ng]k06EU
I@1QHF40W9bL030`<01JFUX0HV9R0492@P0j>SX0BTY:05ADE01CDe<0Bd];06ATI01RHV80=3@d05EE
E@1FEUH204I6AP0<079bLP1fMWH0EeMG07QhN01<C4`0B4Q80410@00M7Ad0=cLg02LW9`0k>c/09BDU
0P0b<S80/P18B4P0EUIF04m?C`1<C4`0DE5A03De=@1PH600Bd];05ADE014A4@0CDe=06UYJ@1TI6@0
M7Ad04E5A@0[:b/0C4a<030`<01=CDd0A4A404U9B@1IFET0=cLg05EEE@1@D500G5aL04U9B@12@T80
CDe=034a<@0o?cl08B4Q03<c<`17AdL0;Bd]04=3@`0e=CD0<30`02l_;`0Q8B40>c/k0492@P0m?Cd0
=SHf034a<@0m?Cd0A4A40451@@1>CTh0BDU903lo?`1DE5@0OGem07MgM`1QHF4061PH01dM7@1KFe/0
;Bd]04a<C01:BTX0Bd];04a<C01;Bd/0<C4a04I6AP12@T80<c<c02d];@0k>c/0I6AT04a<C010@400
=CDe065QH@11@D40CTi>034a<@0n?Sh0F5QH02l_;`11@D40?clo03Xj>P0a<C40@D5104M7A`0o?cl0
>CTi0492@P15ADD071`L04U9B@0j>SX0F5QH01lO7`14A4@0=CDe01PH600k>c/0A4A405YJFP1OGel0
6a/K03Xj>P0F5QH0>c/k02XZ:P0^;Rh0?3`l059BDP0a<C408R8R03hn?P0i>CT0IfMW05]KF`14A4@0
O7al02d];@0o?cl0G5aL03Ph>01gMgL0B4Q805=CD`1JFUX0<S8b051@D00i>CT0<S8b03/k>`1PH600
PH6103Ph>03Ti>@0KVi^0861P@1DE5@0L71`03<c<`1@D500Cdm?04Y:BP0h>3P0FEUI05=CD`1EEED0
T92@06e]K@0[:b/0F5QH03Lg=`1`L7009BDU03Xj>P1/K6`0<30`03lo?`1?Cdl0:b/[04i>CP0j>SX0
;Rh^04I6AP0_;bl0F5QH04=3@`18B4P0De=C03De=@12@T80E5AD06YZJP0g=cL0B4Q804m?C`0h>3P2
04M7A`0Q03hn?P0m?Cd0KVi^06YZJP2d];@0RXZ:05EEE@1TI6@0De=C05IFEP14A4@0>SXj03Lg=`1>
CTh0Cdm?034a<@1>CTh0?3`l0;Jf]P1LG5`09RHV04A4A01PH600@41006UYJ@1CDe<0>SXj03hn?P1I
FET0J6QX05IFEP0l?3`0H61P0080C4a<00<0;bl_04=3@`0c<c<00P10@400AP1>CTh0>SXj05eMG@1N
GUh0?Cdm06e]K@0;2`/0?Cdm038b<P0c<c<0FEUI02h^;P0m?Cd0=SHf04Y:BP1CDe<0@d=305YJFP0[
:b/0NGUi01TI6@1>CTh0>SXj02@T901:BTX07AdM04=3@`16ATH0@d=306i^KP1bLW80ADE505]KF`21
PH40Q8B404U9B@1eMGD0;Rh^06a/K013@d<0Ng]k08b<S01_Kfl0VYZJ04i>CP1fMWH0KFe]030`<01L
G5`0GEeM04];B`1SHf<0AdM704Q8B01:BTX0DU9B04I6AP11@D40ATI605IFEP1dM7@0EUIF059BDP2I
VIT0IFEU04a<C01XJ6P0Ng]k05UIF@20P802ooooo`0002/0NGUi07YjNP2`/;00EEEE04a<C01OGel0
XJ6Q0<_;b`1SHf<0=cLg04=3@`1gMgL0I6AT09VIV@23Ph<0>3Ph02PX:01YJFT0Jf][0:2PX02b/[80
9bLW04E5A@18B4P0V9RH061PH03>c/h0P82001/K6`1DE5@0KFe]04];B`1]KFd0QhN704E5A@0M7Ad0
MgMg08V9R@18B4P0D51@07MgM`0T92@0=3@d0080Rh^;00h0;bl_05QHF01aLG407alO03hn?P1nOWh0
CDe=03De=@1JFUX0=CDe02d];@1BDU80Rh^;03`l?080>3Ph07H0?3`l071`L01nOWh0@41001dM7@15
ADD0?clo04e=C@1nOWh0W9bL02@T900Y:BT0>CTi04i>CP0k>c/0VIVI0:>SX`0K6a/07QhN05MGE`14
A4@0GUiN0;^k^`1IFET061PH034a<@1WIfL0GemO06UYJ@2IVIT0;Rh^01TI6@13@d<0HF5Q0492@P1U
IFD0QHF501HF5P0g=cL0Jf][07IfMP0l?3`0MWIf04m?C`0J6QX0CDe=08F5Q@1NGUh0<30`06=SH`0k
>c/0;Bd]04];B`1mOGd0@41002PX:01JFUX0<30`02HV9P1MGEd0PX:201LG5`0X:2P0@T9203`l?01=
CDd0VYZJ07YjNP0L71`08b<S059BDP1GEeL0JFUY08f=S@13@d<09bLW04Y:BP1ZJVX0Hf=S06UYJ@1Z
JVX07alO03Ti>@1ADE40EEEE05aLG01fMWH0Q8B4024Q8@0a<C40IFEU07=cL`1MGEd0P82004=3@`0Z
:RX0Hf=S09NGU`1RHV80UYJF03Lg=`0];Bd0AdM706ATI01:BTX0DE5A07alO00N7Qh0>CTi04Y:BP1H
F5P0=cLg0492@P1gMgL09BDU03<c<`1MGEd0TY:B0P18B4P07`1CDe<09BDU05aLG02n_[h0H61P02LW
9`0m?Cd0:RXZ034a<@1CDe<0Zj^[04M7A`0[:b/0G5aL03Ph>017AdL0Xj>S0:6QX@0[:b/0=SHf05IF
EP1@D500FUYJ09fMW@0g=cL0:b/[03Ph>01TI6@0EeMG08>3P`2@T9000P0e=CD0^P1?Cdl0De=C05]K
F`2MWId0<C4a0410@019BDT0F5QH051@D01eMGD0JFUY02@T9013@d<0GemO03Xj>P12@T80@410028R
8P17AdL0J6QX04I6AP17AdL0KVi^03/k>`19BDT0Lg=c04Q8B00W9bL0AdM7034a<@10@400SHf=07If
MP0P8200>CTi03Xj>P1CDe<0Lg=c0:j^[P1ADE40;Bd]04=3@`0n?Sh0DU9B0:j^[P1OGel07alO06=S
H`1WIfL0<S8b06e]K@3Cdm<0PH6102<S8`11@D40GUiN03hn?P1oOgl0cLg=04Y:BP0`<300IFEU06QX
J01:BTX0K6a/0;>c/`15ADD07QhN0410@01YJFT0CTi>09nOW`2d];@0=SHf03De=@1>CTh0JVYZ05mO
G`2EUID0QXJ601lO7`1BDU80OWin06=SH`0[:b/0Hf=S06i^KP0W9bL0ADE508j>SP2ZZZX0?Shn05=C
D`19BDT0=CDe03lo?`1]KFd0Ng]k02TY:@0m?Cd0?Shn02d];@19BDT0DU9B04m?C`1<C4`0DU9B0492
@P11@D40Hf=S04E5A@1;Bd/0=SHf05EEE@1YJFT09BDU05aLG01FEUH0DE5A06QXJ01CDe<0MGEe055A
D@1LG5`0FEUI04I6AP11@D40?Cdm05eMG@0m?Cd0E5AD0451@@1JFUX0>3Ph051@D01KFe/0FEUI06EU
I@1CDe<0AdM705iNGP1ADE40Cdm?055AD@1MGEd0Lg=c09ZJVP1SHf<0;Rh^03Hf=P0o?cl0ADE505=C
D`0o?cl0Bd];05]KF`13@d<0Cdm?061PH01ZJVX0Cdm?04e=C@1KFe/0=CDe05UIF@0Z:RX0>SXj06IV
IP0d=3@0DU9B03/k>`0j>SX0BDU904a<C01GEeL0ADE505ADE014A4@0EEEE05eMG@1QHF40=SHf030`
<01GEeL0BDU9055AD@80:RXZ0800>c/k02`/;00d=3@0CDe=030`<017AdL0?3`l03Hf=P0T92@0?Shn
02XZ:P0c<c<0=3@d03Ph>00/;2`0:2PX02/[:`1@D500Fe]K03<c<`11@D40?Cdm04M7A`0R8R80820P
04E5A@19BDT0@41003`l?016ATH0>SXj04U9B@1SHf<0@T92059BDP1GEeL0GemO02DU9@1;Bd/0;bl_
03dm?@0L71`0Hf=S05ADE00c<c<0BDU905EEE@0d=3@0BDU9024Q8@0l?3`0:b/[04e=C@0M7Ad0=3@d
03dm?@1^KVh0@d=303<c<`20P800=CDe03hn?P19BDT0A4A403`l?00i>CT0EEEE071`L015ADD0/k>c
051@D00b<S80DE5A05ADE01QHF40>CTi04Y:BP1UIFD0HF5Q08F5Q@1;Bd/0SHf=055AD@1MGEd0ATI6
061PH00`<300H61P05QHF01EEED0@d=306EUI@1OGel0<c<c07moO`25QHD0Bd];04i>CP11@D40ADE5
02`/;00g=cL0GEeM02PX:017AdL0B4Q8034a<@1JFUX0C4a<03Hf=P1ADE40=3@d05mOG`0];Bd0<30`
04Q8B013@d<0FEUI06a/K01mOGd0G5aL07EeM@1^KVh0>c/k06IVIP1cLg<0J6QX06=SH`80GEeM05`0
OWin065QH@1VIVH0LW9b03hn?P0g=cL0<c<c059BDP16ATH0@d=304m?C`0m?Cd0DU9B02PX:01YJFT0
Fe]K04M7A`1OGel0Fe]K02/[:`1=CDd0<c<c02h^;P0h>3P0>SXj04];B`1LG5`0=CDe05=CD`14A4@0
E5AD02h^;P0f=SH0>CTi03Xj>P18B4P0KFe]02h^;P1EEED0BDU903/k>`1;Bd/0;2`/03dm?@0i>CT0
EeMG05mOG`0B4Q80CDe=03Lg=`0j>SX0;Rh^02HV9P1:BTX05ADE03Ti>@0M7Ad0EEEE04M7A`1@D500
LW9b04M7A`1BDU80GEeM04U9B@1ZJVX0JFUY03De=@1HF5P0<C4a04Q8B00m?Cd0HF5Q04I6AP20P800
ADE507EeM@1]KFd0IFEU08j>SP1lO7`0XJ6Q08Z:RP1:BTX0PH6106EUI@1@D500IFEU034a<@1JFUX0
<S8b04U9B@80ADE500`0IFEU05=CD`2EUID0DU9B061PH021PH40D51@04e=C@14A4@0H61P071`L01H
F5P2ooooo`0002D0NWYj05UIF@26QXH0MgMg08^;R`1^KVh0A4A406=SH`39bLT0KVi^08B4Q01QHF40
=SHf0410@01hN7P0>c/k03Ph>010@400>SXj0451@@1JFUX0?clo02@T9014A4@0:BTY03<c<`1IFET0
LW9b02h^;P0m?Cd0=CDe03/k>`2HV9P0YjNW03Ph>00M7Ad0=CDe0080AdM700D0BDU908R8R010@400
5aLG0451@@02059BDP1S07emO@2KVi/0:RXZ02LW9`1hN7P0Q8B405EEE@2][Jd0C4a<01`L700d=3@0
R8R805]KF`1fMWH0IFEU01XJ6P11@D40C4a<05EEE@15ADD0QXJ603Lg=`0_;bl0EEEE07=cL`1SHf<0
D51@075aL@0`<300?clo04I6AP27QhL0FEUI055AD@1<C4`07QhN02XZ:P1EEED0Rh^;02<S8`0`<300
EeMG02<S8`0e=CD0MGEe06YZJP0/;2`0=cLg0451@@12@T80Hf=S06i^KP0a<C408B4Q03dm?@13@d<0
GEeM08V9R@1dM7@06QXJ02/[:`0g=cL0EUIF05aLG032`/80OGem028R8P1KFe/0Hf=S0492@P1ADE40
cLg=05ADE00G5aL0Cdm?07UiN@16ATH0SXj>09NGU`0/;2`0=3@d04E5A@2@T900A4A4061PH01cLg<0
7alO03/k>`1eMGD0Ph>302/[:`15ADD0H61P02DU9@1GEeL0Rh^;04E5A@0T92@0EEEE0080=CDe0=L0
EeMG07alO00`<3008B4Q05IFEP0h>3P0@D51061PH010@40071`L03/k>`1:BTX0AdM70:^[Z`1?Cdl0
7AdM02@T9019BDT0>CTi08F5Q@36a/H0:b/[02PX:01`L700KVi^04E5A@1PH600R8R8038b<P0o?cl0
De=C06YZJP17AdL0PX:207YjNP0S8b<0>c/k04m?C`1LG5`0@T9207EeM@0V9RH0:b/[04Y:BP1;Bd/0
AdM704Y:BP20P800@T9202d];@1KFe/0Ng]k04Q8B01WIfL0FEUI02`/;00d=3@0NGUi07=cL`10@400
I6AT02XZ:P0];Bd0JFUY075aL@1ADE40Cdm?0861P@0`<300<c<c08J6QP1lO7`0>CTi04Q8B00d=3@0
@410061PH02^[Zh0IFEU03Lg=`1ADE40=cLg08N7Q`2>SXh07alO03/k>`1CDe<0E5AD061PH02IVIT0
8B4Q03lo?`23Ph<0EEEE05]KF`1lO7`0;Rh^01dM7@1KFe/0KFe]065QH@2<S8`09bLW02DU9@1=CDd0
XZ:R06a/K02@T900K6a/02<S8`1<C4`0G5aL09bLW01RHV80Xj>S05eMG@0/;2`0?Cdm06EUI@32`/80
De=C0861P@1LG5`0=CDe04M7A`1RHV80I6AT0492@P1FEUH0>3Ph01/K6`0c<c<0ADE507alO01>CTh0
J6QX04A4A00X:2P0DU9B07YjNP1]KFd0:2PX06UYJ@0X:2P0:BTY069RHP1SHf<0>3Ph024Q8@1=CDd0
>c/k03Ph>01dM7@0Kfm_01hN7P0K6a/0@D5106QXJ01[Jf/0PH6107MgM`0O7al0<C4a04E5A@1YJFT0
L71`07=cL`29RHT05aLG03@d=01aLG40OGem04];B`1BDU80;bl_03hn?P1MGEd0>SXj04M7A`0_;bl0
De=C05iNGP0C4a<0BDU904M7A`21PH40OGem05MGE`1ZJVX0CTi>05mOG`1FEUH0<C4a02XZ:P0G5aL0
=SHf02PX:00d=3@0:BTY04A4A00d=3@0@41005ADE01NGUh0N7Qh04i>CP0b<S80?clo04];B`1<C4`0
@41004I6AP19BDT0JFUY05eMG@02034a<@1403Lg=`0S8b<0>SXj04=3@`1LG5`0>CTi020P800e=CD0
EUIF055AD@0V9RH0>c/k04M7A`1@D500C4a<03Lg=`10@400Bd];030`<010@400BTY:04A4A016ATH0
D51@055AD@1<C4`0CTi>04e=C@18B4P0JFUY05mOG`13@d<0?clo05aLG01=CDd0HF5Q04Y:BP1WIfL0
D51@030`<00Y:BT0A4A4038b<P0o?cl0>3Ph03`l?01:BTX0@41003Ti>@0m?Cd0:RXZ038b<P10@400
>SXj04E5A@1BDU80F5QH04A4A01NGUh0ADE504M7A`0_;bl0CTi>05mOG`1<C4`0D51@04I6AP1GEeL2
04e=C@0?04Y:BP14A4@0De=C04=3@`1IFET0?clo05eMG@1GEeL0CDe=0492@P27QhL0EEEE038b<P1:
BTX0ADE50080A4A402H0<c<c0410@00Q8B40>c/k02PX:01<C4`0;bl_03hn?P0T92@09BDU05QHF00_
;bl0DU9B04];B`0j>SX0F5QH04e=C@1IFET0Q8B403lo?`1<C4`0A4A402d];@1>CTh0F5QH06][J`0d
=3@0<S8b03`l?01EEED0V9RH04U9B@2XZ:P0A4A4071`L01TI6@0Ph>30451@@80G5aL09<0ATI602d]
;@1BDU80@T9203@d=02=SHd0PH6104M7A`1SHf<0CDe=059BDP1;Bd/0D51@06YZJP0b<S80Cdm?04Q8
B00_;bl0>3Ph0451@@1EEED0IFEU03Xj>P0o?cl09bLW03/k>`18B4P0@D5105MGE`19BDT0Lg=c06MW
I`1cLg<0IFEU04=3@`0h>3P0ADE505iNGP1YJFT0Kfm_06ATI02BTY80GemO034a<@1BDU80G5aL04=3
@`1<C4`0@T9204U9B@1EEED0I6AT04a<C01aLG40>3Ph08:2PP1PH600CDe=07QhN01mOGd09BDU04m?
C`0e=CD0@D5104a<C015ADD0E5AD05=CD`0n?Sh0@d=303`l?018B4P0;Bd]02h^;P0i>CT0>c/k03De
=@1<C4`09RHV08Z:RP1LG5`0=cLg04m?C`0:2PX0GUiN03<c<`1?Cdl0H61P01TI6@0j>SX0=3@d0492
@P10@400>3Ph04];B`0f=SH0Hf=S02`/;01KFe/0?3`l0410@01=CDd0IVIV06QXJ01TI6@0A4A408N7
Q`2YZJT0EeMG09:BTP1=CDd0GemO055AD@1eMGD0Rh^;0:n_[`1EEED0NWYj07inOP1XJ6P0SHf=06a/
K01JFUX0G5aL04M7A`1lO7`0?Cdm051@D01HF5P0:BTY0451@@0`<300@d=3030`<00W9bL0?Shn03@d
=02JVYX0G5aL05mOG`1]KFd0HV9R05QHF01TI6@0GUiN05MGE`1KFe/00_ooool0003P0:6QX@1DE5@0
G5aL05]KF`1hN7P0QHF503`l?01DE5@0JFUY06][J`2ATI40Ng]k02`/;017AdL0BDU907AdM01RHV80
K6a/02LW9`0g=cL0?Shn061PH01dM7@0/k>c024Q8@0`<300KFe]07EeM@1OGel0^k^k06][J`0G5aL0
C4a<0:>SX`21PH40GUiN09nOW`2MWId07AdM038b<P1LG5`0Fe]K04m?C`1FEUH06QXJ02/[:`1HF5P0
IfMW04E5A@1TI6@0NGUi02/[:`0i>CT0OGem08b<S013@d<0HV9R0492@P0/;2`0BDU905QHF010@400
=CDe05=CD`0D51@0BDU906ATI01SHf<092@T0492@P16ATH0EUIF061PH01oOgl0Cdm?028R8P13@d<0
BDU905=CD`2GUiL0Q8B401TI6@0P8200>SXj07=cL`27QhL0Jf][08^;R`0M7Ad0:BTY03`l?01PH600
Fe]K06][J`0^;Rh06a/K04i>CP1cLg<0IfMW09jNWP2XZ:P0;bl_02/[:`1LG5`0MGEe03/k>`1YJFT0
Ng]k01TI6@0g=cL0H61P08:2PP17AdL0IfMW0820P00Z:RX0Cdm?08R8R020P800BTY:061PH00^;Rh0
;Bd]069RHP2EUID0GEeM03lo?`1KFe/0AdM704U9B@1oOgl0Ng]k03@d=00U9BD0DE5A04Q8B01:BTX0
JVYZ07]kN`0W9bL0=cLg065QH@1GEeL0C4a<09JFUP1UIFD06a/K04];B`2?Shl0IfMW04a<C01oOgl0
71`L03Ph>01CDe<0C4a<02l_;`27QhL0U9BD02TY:@18B4P0L71`04U9B@1EEED0GUiN02/[:`0X:2P0
De=C06=SH`0^;Rh0GUiN04U9B@0K6a/0<30`05QHF01?Cdl0?Cdm08J6QP0^;Rh0<S8b05aLG01XJ6P0
;Rh^03Ph>01`L700=3@d05MGE`2YZJT0Lg=c02TY:@10@400LW9b03Xj>P0h>3P0QhN704];B`0/;2`0
K6a/04e=C@1;Bd/0RXZ:0820P00Z:RX0;Bd]071`L01WIfL0Cdm?0;>c/`1bLW8051@D03dm?@1jNWX0
H61P05eMG@2>SXh0<C4a01hN7P1JFUX0Kfm_04Q8B01^KVh08b<S028R8P1KFe/208V9R@3o05ADE01A
DE408B4Q04Q8B01_Kfl0<C4a04m?C`0i>CT0:RXZ04U9B@2ATI40NGUi03hn?P1TI6@0:RXZ04i>CP1?
Cdl0B4Q802<S8`1QHF40ATI602PX:027QhL0LG5a02h^;P11@D40CTi>02l_;`1ZJVX0/[:b06EUI@0k
>c/0Hf=S04];B`0i>CT0R8R809>CT`0d=3@0>SXj04M7A`1SHf<0LW9b08f=S@26QXH09bLW030`<01?
Cdl0>3Ph05mOG`33`l<0V9RH02LW9`0c<c<0GEeM03lo?`1<C4`0/;2`09>CT`0M7Ad0=SHf08Z:RP28
R8P0ATI60;Zj^P12@T809bLW04e=C@1eMGD0Cdm?04A4A01RHV80;bl_030`<01?Cdl0Ng]k05ADE01:
BTX0Lg=c03@d=018B4P0HV9R09ZJVP1EEED0>SXj07IfMP0Q8B40?Shn06=SH`20P800>SXj04e=C@16
ATH05ADE05iNGP1ZJVX0CDe=04i>CP1XJ6P0Hf=S0492@P15ADD0IfMW0861P@18B4P0?Shn04E5A@1B
DU80DE5A04U9B@1QHF40CTi>06UYJ@1IFET0ATI602h^;P0/;2`0AdM702PX:00e=CD0:b/[04=3@`0U
9BD0@T9204];B`1RHV80EeMG059BDP0g=cL0HF5Q075aL@1`L700CTi>05UIF@1iNGT0E5AD06ATI00T
92@0<S8b04=3@`0];Bd0DE5A04M7A`16ATH0FEUI030`<01>CTh0F5QH06QXJ00d=3@0A4A4069RHP0^
;Rh0AdM702<S8`0`<300GEeM06QXJ01NGUh0<C4a02@T9016ATH0FEUI04a<C012@T80DE5A05MGE`16
ATH0C4a<051@D016ATH0F5QH06UYJ@0f=SH0GEeM05ADE013@d<0HV9R01XJ6P0I6AT0GEeM02DU9@0b
<S80?Shn02l_;`0j>SX0?clo024Q8@14A4@0?3`l03Lg=`0e=CD0?Cdm04U9B@1GEeL0ATI602l_;`1F
EUH0?Cdm04Y:BP0Q8B40=3@d04M7A`0a<C40@T9205IFEP17AdL0;2`/055AD@1FEUH0?Shn05]KF`1Q
HF40GEeM03hn?P1KFe/0AdM707alO019BDT0EEEE0492@P13@d<0D51@04A4A01NGUh0FEUI03Ph>01:
BTX0<S8b03hn?P0O7al0?Cdm04U9B@1VIVH0?Cdm04A4A01KFe/0Bd];07QhN01ADE40LW9b08N7Q`1B
DU80Fe]K0820P01]KFd0ZJVY05eMG@1@D500Lg=c04I6AP1LG5`0=CDe03`l?00n?Sh0G5aL000V0861
P@13@d<0[Jf]06=SH`1]KFd0@D51051@D00j>SX0I6AT04m?C`1BDU80?clo0861P@1<C4`0<30`096A
T@25QHD0?3`l04I6AP0e=CD0GUiN03Xj>P0];Bd0EUIF03De=@1_Kfl0GUiN03Hf=P1BDU80EUIF0492
@P1^KVh0BTY:06=SH`0g=cL0ADE504e=C@0l?3`204a<C00A06m_K`0o?cl0EeMG05YJFP0M7Ad0@D51
04A4A00k>c/0E5AD05aLG01<C4`0YjNW06IVIP1CDe<0KVi^04Q8B01@D5000P0l?3`0HP0m?Cd0F5QH
07UiN@0g=cL0Fe]K059BDP2KVi/0GemO04Y:BP1;Bd/0EUIF03De=@17AdL0<c<c03hn?P1>CTh0BDU9
05iNGP1IFET0C4a<04E5A@12@T80De=C038b<P0c<c<0<S8b03Ti>@0e=CD0C4a<038b<P1ADE40@T92
03Lg=`1GEeL06QXJ03<c<`0e=CD0E5AD06YZJP0F5QH0?Cdm02d];@1FEUH0?3`l03Lg=`1;Bd/0@D51
079bLP0h>3P0EeMG03Ph>00];Bd0ATI602`/;01bLW80L71`038b<P1LG5`0N7Qh04Q8B01OGel0F5QH
096AT@1^KVh0MGEe03Ti>@1OGel0BTY:05YJFP2>SXh0OWin0:FUY@1^KVh0R8R80:^[Z`1IFET0GUiN
05IFEP1OGel0J6QX03Xj>P0o?cl0@d=304i>CP1KFe/0BTY:04Q8B00N7Qh0EEEE03`l?01YJFT0E5AD
04U9B@1WIfL0De=C051@D01hN7P0J6QX0_ooool0000C0;Rh^02HV9P0QhN704Y:BP1SHf<0VIVI07Mg
M`2YZJT0@41003lo?`18B4P0JFUY05eMG@2NWYh0JVYZ02PX:012@T80I6AT04e=C@0205=CD`3o02PX
:00^;Rh0H61P06IVIP0c<c<0GUiN03@d=00V9RH0MgMg08V9R@0V9RH0:b/[04E5A@0g=cL0<30`05]K
F`1iNGT0;2`/024Q8@19BDT0=3@d07YjNP2IVIT0EUIF01@D5014A4@0K6a/04m?C`2FUYH0/k>c02`/
;00e=CD0EeMG09:BTP1;Bd/0YZJV06=SH`0G5aL0E5AD061PH01:BTX0I6AT09nOW`0O7al071`L08F5
Q@2[Zj/0G5aL07alO01jNWX09BDU0410@01XJ6P0JFUY04i>CP2EUID0AdM703Ph>01;Bd/0Q8B405MG
E`13@d<0Ogmo02<S8`0/;2`0GEeM05YJFP0n?Sh0ATI605eMG@0U9BD0>SXj08R8R025QHD0>3Ph04A4
A00c<c<051@D04];B`2<S8`0EeMG03De=@0m?Cd0Bd];03hn?P22PX80XJ6Q01lO7`0G5aL0AdM705IF
EP0k>c/0WYjN0;fm_@0K6a/09BDU05ADE01ADE40?clo09ZJVP11@D405aLG02h^;P1MGEd0JVYZ06a/
K01aLG40A4A402PX:01RHV80I6AT04e=C@0g=cL0Vi^K05=CD`0S8b<0HF5Q079bLP1;Bd/0<c<c06QX
J00^;Rh0=cLg05YJFP2ATI40CDe=0492@P0e=CD09bLW04=3@`1]KFd0IVIV02`/;01JFUX0<S8b02d]
;@1?Cdl0MWIf03/k>`1GEeL0>c/k04E5A@2ZZZX0O7al02LW9`0e=CD0Cdm?02d];@1;Bd/0/[:b065Q
H@0I6AT0;Rh^04a<C017AdL0IfMW0=;BdP1;Bd/05aLG04A4A024Q8@0>SXj06a/K02/[:`0=cLg024Q
8@1EEED0Q8B403lo?`1fMWH0Q8B404I6AP1=CDd0Fe]K07AdM013@d<0X:2P05IFEP0b<S80IVIV08>3
P`1<C4`0G5aL06QXJ016ATH0D51@059BDP1cLg<0<c<c04Y:BP1@D500;Rh^04E5A@1cLg<0BTY:02DU
9@1FEUH0;bl_03De=@1`L700EEEE01TI6@0c<c<0>c/k03@d=01BDU80Q8B402TY:@0e=CD0DU9B05EE
E@1aLG40D51@01TI6@0];Bd0FEUI07YjNP1VIVH0Zj^[02<S8`0b<S80JVYZ051@D017AdL0QHF504E5
A@0[:b/0>c/k069RHP1BDU80L71`06QXJ00m?Cd0<S8b05YJFP21PH40EUIF09bLW00h>3P0E5AD075a
L@1XJ6P0>SXj05MGE`2=SHd06QXJ0492@P29RHT0LW9b03dm?@1VIVH0JVYZ04];B`0W9bL0I6AT0037
0:ZZZP1/K6`0CTi>06EUI@0`<300>SXj055AD@2BTY80DE5A04m?C`1dM7@0;Rh^03/k>`1KFe/0JVYZ
02@T901SHf<0Bd];01`L701FEUH0Ph>303lo?`0F5QH0A4A405mOG`0n?Sh0B4Q809nOW`0o?cl092@T
055AD@1SHf<0BDU906ATI02`/;00>CTi01lO7`1@D500GemO03@d=01/K6`0/;2`02`/;01>CTh0MGEe
04e=C@1DE5@0X:2P05eMG@1aLG40?Shn05iNGP2=SHd09bLW0861P@1bLW80N7Qh06i^KP1SHf<0VYZJ
05QHF01VIVH0De=C03lo?`1OGel0:b/[059BDP18B4P0FUYJ0492@P1EEED0>SXj061PH00m?Cd0IfMW
079bLP1HF5P0G5aL059BDP1jNWX0CDe=075aL@1hN7P0H61P05EEE@13@d<0<S8b02/[:`0_;bl0EUIF
06ATI013@d<0ATI604a<C00j>SX0ATI6059BDP1IFET0:BTY05MGE`1YJFT0?clo05aLG00_;bl0<S8b
05iNGP0_;bl0@T9202DU9@0P8200CDe=04];B`1DE5@0:2PX05=CD`1BDU80GUiN07IfMP1EEED0=SHf
0451@@1JFUX0?clo069RHP1=CDd0De=C07IfMP0m?Cd0<S8b07EeM@0g=cL0@T9204a<C00h>3P0DE5A
059BDP0S8b<0CDe=0451@@19BDT0>SXj03dm?@0k>c/0HF5Q04E5A@1JFUX0Jf][051@D01GEeL0:BTY
04m?C`1]KFd0?clo05YJFP1MGEd0IFEU03<c<`1XJ6P0IfMW03lo?`1FEUH0G5aL06UYJ@0i>CT0DU9B
04i>CP1aLG40DU9B06i^KP1ADE409BDU051@D01LG5`0=SHf03dm?@1>CTh0Cdm?02XZ:P18B4P0;bl_
03/k>`10@400Fe]K04E5A@1DE5@0JVYZ02DU9@1GEeL0ATI603hn?P1IFET0Fe]K05QHF02OWil0C4a<
06UYJ@1@D500<C4a05ADE00205UIF@1W03lo?`0m?Cd0Bd];06IVIP2=SHd0K6a/0<O7a`0h>3P0K6a/
05UIF@1LG5`0<30`055AD@1oOgl0JFUY03Lg=`1YJFT0HF5Q024Q8@1QHF40GEeM05IFEP1aLG40@410
04=3@`11@D40CTi>06MWI`14A4@0>CTi04i>CP14A4@0NWYj06a/K013@d<0GUiN03<c<`1aLG40;Rh^
034a<@1<C4`0EeMG05ADE01EEED0OWin03hn?P1EEED0FEUI034a<@1=CDd0DU9B04i>CP1gMgL0LW9b
04U9B@1`L700B4Q803hn?P1OGel0E5AD03Xj>P0i>CT0Bd];03@d=01:BTX0Fe]K04];B`1PH600>3Ph
0:NWY`1PH600?Shn065QH@1EEED08B4Q06][J`1>CTh0ATI604m?C`1NGUh0SXj>05]KF`1>CTh0J6QX
05IFEP1<C4`0?3`l059BDP0n?Sh0B4Q805mOG`1IFET0De=C06IVIP1_Kfl0DU9B061PH00f=SH0BDU9
04E5A@1EEED0Jf][020P800203hn?P0h05QHF01CDe<0Cdm?04a<C00k>c/0OGem02/[:`1XJ6P0DU9B
06=SH`1gMgL0AdM705=CD`11@D40F5QH0:f][@2<S8`0?3`l08>3P`18B4P0GUiN04Y:BP1HF5P0OGem
09:BTP13@d<0Ti>C0820P01`L700TI6A05YJFP1MGEd0UiNG06e]K@2_[jl0JFUY04E5A@1JFUX0ATI6
06e]K@1OGel0Bd];04=3@`1CDe<0IVIV05=CD`1QHF40<c<c051@D01OGel0>SXj04A4A011@D40DE5A
05IFEP1IFET2ooooo`0003/0HV9R08^;R`2l_;`0D51@06QXJ015ADD0@d=306IVIP25QHD0>c/k06EU
I@0h>3P0=3@d06ATI025QHD09RHV04];B`14A4@0H61P07YjNP2SXj<0<S8b03Ti>@1ADE40DU9B05YJ
FP3?cll0I6AT01XJ6P14A4@0Kfm_06EUI@2MWId0c/k>03/k>`0S8b<0=SHf05YJFP25QHD0JVYZ0:VY
Z@0e=CD07alO04U9B@1UIFD0=CDe06a/K00/;2`07QhN04E5A@1XJ6P0DU9B051@D021PH407alO03lo
?`1RHV80MGEe02l_;`0203dm?@1[0451@@1HF5P0LG5a04=3@`0L71`0@d=303/k>`1:BTX0MgMg08B4
Q00N7Qh09bLW03Ph>016ATH0B4Q80:JVYP1eMGD07AdM03Ti>@1:BTX0>c/k05mOG`3AdM40HF5Q01TI
6@0g=cL0G5aL04Q8B01cLg<0OWin02XZ:P0H61P0=SHf06UYJ@16ATH0W9bL07QhN00C4a<0>3Ph04U9
B@12@T80Fe]K0:6QX@1gMgL051@D04Y:BP1cLg<0H61P0410@029RHT0AdM701`L700`<300HV9R04Q8
B00R8R80ADE502/[:`15ADD0Cdm?05UIF@0];Bd0@D51034a<@0];Bd0IfMW07moO`1_Kfl08b<S03dm
?@1?Cdl0BTY:06MWI`2PX:00KVi^01lO7`0l?3`0Fe]K05MGE`1QHF40RXZ:02l_;`0Z:RX0B4Q805AD
E01UIFD0Vi^K04I6AP0W9bL0@410065QH@1dM7@0F5QH0;>c/`0h>3P0<30`04m?C`28R8P0G5aL09nO
W`0k>c/0?Shn05aLG02HV9P0A4A4061PH01dM7@00P0d=3@0HP1OGel0ZJVY04A4A01@D500HF5Q02HV
9P13@d<0GUiN07QhN00j>SX0DU9B05IFEP0Z:RX0@d=307alO01>CTh0G5aL051@D00W9bL092@T04m?
C`2ATI40E5AD04I6AP1JFUX0=SHf06UYJ@2;Rh/0S8b<03/k>`0l?3`0Bd];02TY:@1PH600/k>c03Lg
=`0Y:BT0Fe]K05IFEP0n?Sh0PH610;:b/P0V9RH0:RXZ06UYJ@1HF5P0G5aL0:j^[P0j>SX0=SHf0492
@P1ZJVX0AdM709:BTP1KFe/09BDU04];B`1SHf<0FEUI07MgM`1NGUh08R8R05IFEP1nOWh0CDe=06=S
H`1bLW807alO03dm?@1iNGT0OGem04M7A`1_Kfl0>3Ph03/k>`1TI6@0NWYj03`l?01GEeL0:RXZ038b
<P1RHV80VYZJ04Q8B01IFET0DE5A034a<@1@D500FUYJ04m?C`0_;bl0GEeM05mOG`0k>c/0QXJ60<C4
a01LG5`0;bl_0P1ADE408@0g=cL0W9bL096AT@0[:b/07alO03<c<`1ADE40D51@08N7Q`2JVYX0;Bd]
03@d=01VIVH0GUiN05ADE01PH600X:2P02h^;P0];Bd0Lg=c0861P@15ADD0TY:B07]kN`0R8R8092@T
08>3P`24Q8@0ATI605EEE@0f=SH0@T9204=3@`0205EEE@2303`l?01ZJVX0KFe]030`<013@d<0FUYJ
055AD@0f=SH0@d=304e=C@0];Bd0ADE506e]K@13@d<0B4Q805ADE00l?3`0C4a<08^;R`19BDT0@d=3
02d];@1>CTh0Lg=c03Xj>P16ATH0CDe=07QhN02;Rh/0De=C07emO@1EEED0EeMG06YZJP0f=SH0=CDe
02PX:01:BTX0;Rh^03@d=00c<c<0BTY:02h^;P0n?Sh0>3Ph05eMG@1lO7`0Cdm?03hn?P19BDT0GemO
04M7A`10@400BDU905YJFP1`L700E5AD02`/;00b<S80@41003De=@12@T80@d=304U9B@0i>CT09BDU
03Xj>P1CDe<0@41002TY:@18B4P0ATI6051@D01:BTX0A4A404Y:BP1LG5`0Bd];04i>CP1?Cdl0B4Q8
04m?C`1=CDd0F5QH04E5A@1ADE40D51@04Q8B02KVi/0Fe]K03De=@15ADD0I6AT071`L021PH40Cdm?
04E5A@18B4P0<C4a038b<P19BDT0=3@d04=3@`1[Jf/0KFe]04a<C01CDe<0BTY:055AD@0h>3P0BDU9
04M7A`0m?Cd0@410069RHP0d=3@0@41006EUI@17AdL0H61P03De=@17AdL0HF5Q03hn?P1bLW80CTi>
06=SH`0m?Cd0IfMW06EUI@0j>SX00P1NGUh0:01_Kfl0<c<c069RHP1MGEd0TY:B06QXJ01WIfL0IFEU
03Ph>01VIVH0KVi^03/k>`1BDU80>c/k055AD@0M7Ad0@T9202XZ:P1LG5`0BDU905QHF00b<S80Cdm?
07moO`0W9bL0I6AT0451@@16ATH0LW9b05ADE01CDe<0YjNW065QH@2<S8`0PX:203dm?@1JFUX0G5aL
07QhN018B4P20451@@1`06IVIP25QHD0=CDe09nOW`1:BTX0Jf][06i^KP1dM7@0GemO05eMG@1>CTh0
BDU903<c<`1GEeL0BDU902l_;`2KVi/0T92@03dm?@18B4P0:2PX05QHF00[:b/0A4A407UiN@0T92@0
LW9b061PH00M7Ad0@d=304a<C012@T80Lg=c03/k>`1WIfL0;2`/04Q8B01DE5@07alO02`/;010@400
IfMW034a<@0Z:RX0@41002@T900`<300>3Ph02d];@0`<300D51@03Ph>022PX80C4a<03hn?P1GEeL0
A4A404M7A`0c<c<0=3@d0451@@15ADD0GEeM055AD@1oOgl0>SXj075aL@1KFe/0CTi>07AdM01XJ6P0
;Rh^04Q8B01CDe<0HF5Q06][J`1;Bd/0Jf][06=SH`1UIFD0G5aL06=SH`1LG5`0DU9B04i>CP1;Bd/0
DU9B04I6AP1FEUH0@D5106QXJ01JFUX0A4A4071`L00T92@0MWIf02h^;P0i>CT0De=C02XZ:P1HF5P0
DU9B05=CD`16ATH0IFEU07AdM01ADE40E5AD04=3@`26QXH0BDU903Lg=`80>CTi02`0EUIF05=CD`0m
?Cd0Cdm?069RHP0m?Cd0FEUI02`/;01HF5P0?3`l07MgM`1PH600TI6A05MGE`17AdL0Hf=S05=CD`1/
K6`0@d=308n?S`23Ph<0ATI605eMG@1>CTh0E5AD05IFEP0n?Sh0ATI603/k>`1BDU80D51@03hn?P0m
?Cd0<30`07QhN01RHV80EUIF07inOP1HF5P0EeMG05mOG`1[Jf/0I6AT065QH@;ooooo0000o`28R8P0
D51@079bLP1WIfL0U9BD055AD@13@d<0LW9b065QH@1JFUX0clo?06][J`0];Bd0LG5a07emO@1NGUh0
V9RH05IFEP0c<c<0CTi>06e]K@1/K6`0B4Q808B4Q00^;Rh0<S8b05aLG022PX80DU9B07MgM`1>CTh0
8b<S065QH@29RHT0Ogmo02`/;01bLW80ADE503De=@12@T80HF5Q03Hf=P0U9BD0AdM702`/;01UIFD0
VIVI06i^KP0Z:RX0?clo06ATI00e=CD0N7Qh0=KFeP12@T80:b/[061PH01QHF40@T92096AT@28R8P0
4Q8B03Ti>@1kNg/0IVIV05mOG`21PH40De=C03Hf=P1BDU80GemO06QXJ02IVIT0W9bL02l_;`0c<c<0
AdM708B4Q01DE5@0R8R804i>CP0K6a/0>SXj07inOP27QhL0EeMG05aLG00o?cl06QXJ034a<@1CDe<0
C4a<02@T9014A4@0;2`/02TY:@1LG5`0S8b<0451@@0U9BD0EEEE01/K6`0Q8B40M7Ad0:RXZ00Y:BT0
=CDe04U9B@14A4@0BTY:092@T01QHF406ATI02l_;`13@d<0EeMG07=cL`2OWil0:RXZ02HV9P1GEeL0
CTi>03Hf=P21PH40MWIf028R8P0^;Rh0Ph>309VIV@0g=cL0M7Ad07QhN00Y:BT0?Cdm05mOG`1`L700
>3Ph069RHP1CDe<06ATI05IFEP1PH600GUiN03De=@1iNGT0?clo020P801BDU80VIVI02l_;`0a<C40
E5AD024Q8@0];Bd0C4a<05ADE00M7Ad0B4Q804I6AP15ADD0S8b<03Ph>00T92@0=3@d04M7A`1FEUH0
Kfm_07moO`0S8b<0;2`/04M7A`1@D500IFEU06IVIP2<S8`0=SHf02LW9`1HF5P0FUYJ05IFEP27QhL0
SXj>01DE5@0f=SH0HV9R059BDP1OGel0VYZJ034a<@0C4a<0?Cdm08>3P`1XJ6P0E5AD07=cL`0b<S80
9RHV05=CD`2:RXX0BTY:07=cL`1hN7P0<30`024Q8@1bLW80Q8B403hn?P2CTi<0>SXj03Ti>@14A4@0
Kfm_06a/K01VIVH0OGem02XZ:P12@T80S8b<0861P@0`<300J6QX04E5A@0h>3P0Jf][0:VYZ@1/K6`0
Fe]K04i>CP0Y:BT0HV9R0:JVYP1?Cdl0?Shn04a<C00i>CT0QXJ60:FUY@0n?Sh0:RXZ05mOG`1GEeL0
I6AT0:f][@11@D40=SHf05iNGP1<C4`0P8200;Jf]P1OGel07QhN0492@P1/K6`0ATI60:6QX@00=@2K
Vi/0=CDe04];B`1MGEd0HF5Q06ATI02b/[80QHF5038b<P0n?Sh0G5aL07EeM@1?Cdl0T92@05]KF`0S
8b<0CDe=07moO`1NGUh0EEEE06m_K`1LG5`04a<C03lo?`2?Shl0IVIV03Hf=P1SHf<0BDU902XZ:P1F
EUH0W9bL08:2PP0n?Sh0De=C02LW9`12@T80G5aL06QXJ00d=3@0>SXj03lo?`0h>3P0A4A406i^KP1g
MgL08b<S03Lg=`1MGEd0BDU904A4A023Ph<0Zj^[0080>SXj03T0JFUY05IFEP1<C4`0PH6108f=S@0Y
:BT09BDU05ADE011@D40IFEU08:2PP1]KFd0BDU905YJFP1TI6@0QHF506a/K01LG5`0Ng]k05YJFP1`
L700KFe]05=CD`1EEED0CDe=092@T01jNWX0I6AT04U9B@16ATH0Hf=S04I6AP19BDT0?clo065QH@0k
>c/0CDe=038b<P23Ph<0BDU905eMG@1VIVH0EEEE061PH01EEED0JFUY05QHF01[Jf/0O7al061PH01B
DU80B4Q802h^;P0R8R80:RXZ03lo?`15ADD00P0e=CD0J@0i>CT0>3Ph03/k>`11@D40?clo03Xj>P1K
Fe/0A4A402l_;`0k>c/0BDU904I6AP1:BTX0?3`l0451@@0_;bl0;Bd]04I6AP18B4P0AdM702`/;011
@D40DU9B04I6AP1VIVH0CDe=04Q8B01HF5P0G5aL030`<01=CDd0D51@0492@P1gMgL0:RXZ02DU9@1e
MGD0@d=303hn?P1;Bd/0?3`l0410@00m?Cd0<C4a03Ti>@0a<C40?3`l02@T900X:2P0;bl_04Q8B00h
>3P0<S8b04Q8B010@400@D51030`<00c<c<0A4A403/k>`1?Cdl0@d=304M7A`1HF5P0BDU905ADE01@
D500LG5a05aLG01JFUX0CTi>08N7Q`1[Jf/0MgMg06MWI`2>SXh0Jf][03Xj>P1KFe/0K6a/0492@P1H
F5P0A4A405mOG`0T92@0C4a<02TY:@1CDe<0>c/k069RHP0k>c/0FUYJ08B4Q00Z:RX0QHF505=CD`1U
IFD0MGEe03`l?01LG5`0_Kfm08F5Q@2;Rh/0NGUi03De=@0205IFEP1K07=cL`0i>CT0B4Q805MGE`1R
HV80/K6a04A4A035aLD0=cLg05UIF@16ATH0GemO04Y:BP1NGUh0IVIV069RHP1@D500FUYJ05ADE00K
6a/0EUIF06EUI@0k>c/0O7al030`<01BDU80<C4a04Q8B01UIFD07alO03lo?`17AdL0;Rh^05iNGP1M
GEd0Bd];05UIF@0k>c/0PX:204Y:BP0_;bl0@D5103hn?P0g=cL0?Shn09:BTP17AdL0DE5A04];B`0j
>SX0AdM705YJFP0i>CT0DU9B05MGE`17AdL0QHF507IfMP14A4@0Cdm?03lo?`0i>CT0;bl_03Lg=`0k
>c/0J6QX07UiN@0];Bd0De=C02XZ:P2GUiL0CDe=02d];@1JFUX0FEUI02HV9P19BDT0De=C02/[:`0i
>CT0@D5105MGE`0n?Sh0@T9205QHF018B4P0G5aL03`l?00o?cl0EEEE05UIF@0204I6AP1503Lg=`1V
IVH0Jf][04=3@`16ATH08B4Q03Lg=`1ADE40EUIF05mOG`0d=3@0B4Q804i>CP1kNg/0EUIF04Y:BP11
@D40@41006][J`0/;2`0ATI603`l?00e=CD0C4a<03Ph>01`L700Kfm_05EEE@1gMgL0^KVi05aLG01n
OWh0C4a<06YZJP1DE5@0NWYj04M7A`1QHF40>SXj06a/K01TI6@0Cdm?07AdM015ADD0EeMG0:2PX01N
GUh0SXj>05ADE00k>c/0BDU90451@@1:BTX0DU9B04I6AP13@d<0C4a<05=CD`11@D40EeMG03/k>`1c
Lg<0MGEe04i>CP1YJFT0DU9B05eMG@2CTi<0NWYj00;ooooo0000o`1^KVh0LG5a07alO01=CDd0N7Qh
06YZJP1PH600TI6A04A4A00n?Sh0Shn?0:BTY01<C4`0B4Q80451@@0^;Rh0Ng]k08B4Q00h>3P0=3@d
04Q8B01ADE40P8200::RXP0Z:RX08R8R03/k>`1FEUH0D51@0<W9b@1oOgl05aLG01`L700l?3`0I6AT
04i>CP3=cLd0SHf=024Q8@1TI6@0H61P0492@P1JFUX0U9BD03Lg=`0J6QX0H61P05UIF@0k>c/0IFEU
06MWI`0K6a/0=cLg08f=S@1mOGd0Bd];07inOP0b<S806QXJ03/k>`2;Rh/0EeMG04m?C`1]KFd05ADE
034a<@1DE5@0JFUY02XZ:P1NGUh0>SXj02@T901=CDd0[:b/05QHF00h>3P0KVi^03Xj>P0O7al0IFEU
07MgM`0O7al0;2`/05EEE@10@400ATI606=SH`1aLG4051@D03Lg=`1IFET0DE5A05MGE`2FUYH0BDU9
02LW9`1=CDd0HV9R05YJFP1ZJVX0^[Zj02DU9@0O7al0A4A40861P@1LG5`0NGUi07=cL`0C4a<0:BTY
04m?C`1/K6`0>c/k06e]K@1lO7`09bLW02l_;`1OGel0CDe=038b<P1DE5@0=CDe028R8P1DE5@0LW9b
02`/;00`<300BDU905QHF00g=cL0Q8B408N7Q`0M7Ad0:RXZ05ADE00c<c<0DE5A061PH01lO7`0;2`/
02TY:@1TI6@0K6a/04e=C@25QHD0ADE501lO7`0/;2`0Kfm_04a<C01PH600T92@01/K6`0c<c<0@d=3
07EeM@1GEeL0OGem07YjNP13@d<0EeMG08R8R01QHF40QhN705EEE@0[:b/0FUYJ05UIF@1>CTh0CDe=
07MgM`0/;2`0;bl_07EeM@2e]KD0SHf=03Ph>01YJFT08b<S03/k>`1YJFT0[jn_055AD@1RHV80EUIF
02l_;`12@T80Lg=c08b<S00];Bd0CDe=055AD@0[:b/0EEEE06QXJ01ADE40<c<c04m?C`11@D40?3`l
06UYJ@24Q8@0>3Ph02HV9P0h>3P0?clo069RHP24Q8@0GemO028R8P15ADD0CDe=04A4A01cLg<0_kno
04Y:BP0J6QX0HV9R07IfMP1>CTh0KFe]03Ph>00P8200EEEE08F5Q@1VIVH0MWIf06][J`0D51@0=cLg
06i^KP1GEeL0GemO04M7A`0Z:RX0<C4a06a/K02^[Zh0LW9b0:>SX`0W9bL0>3Ph069RHP1NGUh0CTi>
06YZJP0];Bd0<C4a04U9B@1TI6@0@41005MGE`15ADD09bLW04a<C0006@1lO7`0FEUI04A4A01dM7@0
7AdM03Ph>01eMGD0Ng]k03/k>`1;Bd/0EeMG03De=@1SHf<0V9RH0:ZZZP15ADD0De=C06IVIP16ATH0
EUIF07QhN02:RXX0=cLg02DU9@1GEeL00P1YJFT0k024Q8@0JFUY02@T900l?3`0JFUY07moO`2=SHd0
][Jf030`<00/;2`0Cdm?04e=C@19BDT0PH610;Ng]`0i>CT0>SXj04Y:BP1YJFT0Bd];0820P02ATI40
7QhN02XZ:P12@T80M7Ad03hn?P1^KVh0RXZ:02TY:@0];Bd0@410079bLP0f=SH0;bl_03Hf=P0O7al0
ADE506i^KP1NGUh0B4Q805eMG@10@400De=C02d];@0l?3`0NGUi01`L7011@D40DU9B04m?C`1LG5`0
GEeM051@D011@D40DE5A04=3@`0k>c/0ADE503lo?`1BDU80EUIF04=3@`0l?3`0BDU904E5A@1;Bd/0
>3Ph061PH01LG5`0FEUI0451@@1QHF40IFEU06][J`18B4P0FEUI06=SH`1HF5P0KFe]04a<C00Z:RX0
BDU90492@P1ADE40A4A404I6AP1VIVH0=3@d051@D014A4@0FEUI01`L700i>CT0HF5Q03dm?@1GEeL0
:BTY02<S8`16ATH0=cLg03Xj>P10@400>3Ph03hn?P17AdL0@d=304e=C@13@d<0ADE504];B`31`L40
MWIf02`/;00a<C40IFEU06=SH`1dM7@0AdM704E5A@1NGUh0ATI604i>CP1WIfL0?3`l0410@01FEUH0
D51@04Y:BP16ATH0?Cdm04];B`0h>3P0@D5103Ph>00c<c<0;2`/04];B`0d=3@0>SXj055AD@1<C4`0
EUIF02DU9@0l?3`0ADE503Hf=P14A4@0@41003/k>`14A4@0@T9205=CD`0d=3@0>CTi05=CD`1HF5P0
;Rh^04Y:BP1GEeL0PH6106=SH`1QHF40@D51051@D01OGel0F5QH06UYJ@1EEED0@D5104i>CP0S8b<0
G5aL02HV9P1GEeL0B4Q809^KV`1=CDd0GEeM07moO`0V9RH0VIVI05QHF01MGEd0Ti>C0451@@1DE5@0
KVi^08N7Q`2k^k/0HF5Q04e=C@1eMGD0GEeM0820P00`<300>3Ph04Q8B00j>SX0Fe]K06EUI@2^[Zh0
IVIV0820P017AdL0LW9b03Ti>@1KFe/0IFEU05ADE01<C4`0MgMg06m_K`12@T80Ph>30861P@15ADD0
AdM70492@P1FEUH0>c/k03De=@1MGEd0:RXZ059BDP1YJFT0B4Q803Ph>01<C4`0Cdm?06EUI@15ADD0
EUIF04Q8B00j>SX0AdM70P1TI6@0BP13@d<0GUiN03Hf=P1JFUX0Cdm?02@T900_;bl0ADE503dm?@1A
DE40BDU902h^;P1aLG40GUiN04m?C`1aLG40@4100492@P0`<300ADE503Hf=P0/;2`0>3Ph02<S8`1;
Bd/0<C4a09FEU@1HF5P0>SXj06UYJ@1JFUX08R8R05UIF@1?Cdl0=3@d05UIF@0h>3P0E5AD06m_K`17
AdL0CDe=04=3@`1RHV80=SHf03Ph>010@400:BTY065QH@1FEUH0ADE504Y:BP1CDe<0EEEE07AdM00e
=CD0Cdm?03lo?`1HF5P0EeMG02TY:@1OGel0=CDe04A4A00c<c<0>SXj055AD@11@D40BDU902`/;01N
GUh0EEEE07=cL`1VIVH0HF5Q0P11@D40:P0U9BD0Kfm_096AT@1WIfL0GEeM05=CD`2XZ:P0OWin09VI
V@12@T80JVYZ02h^;P1]KFd0GUiN07moO`2XZ:P0BTY:07EeM@25QHD0@D5108B4Q01HF5P0CDe=04m?
C`0^;Rh0@410051@D01?Cdl07AdM02`/;00c<c<0?3`l06MWI`0i>CT0IVIV07EeM@1TI6@0GEeM05MG
E`1PH600G5aL07=cL`;ooooo0000N`2>SXh0ZJVY0;^k^`16ATH0G5aL06][J`26QXH0f=SH05mOG`0k
>c/0G5aL07alO01fMWH0[Jf]04M7A`0Y:BT09bLW05=CD`1EEED0IfMW071`L00X:2P0?3`l07MgM`1P
H600GUiN08Z:RP0X:2P0=cLg04Y:BP1WIfL0=CDe05]KF`13@d<092@T03Ti>@1JFUX0VYZJ03De=@1G
EeL0FEUI020P800V9RH0NGUi06e]K@0X:2P0>SXj02l_;`1>CTh0U9BD07UiN@0c<c<0<C4a0492@P0g
=cL0EeMG0:n_[`1JFUX06ATI02XZ:P1?Cdl0EeMG06i^KP2XZ:P08B4Q01hN7P0d=3@0BDU906UYJ@2a
/K40MWIf010@400P8200G5aL06i^KP1BDU80alO705QHF00J6QX0;bl_06EUI@1:BTX0FUYJ0:6QX@0X
:2P0;Rh^055AD@2LW9`0E5AD06UYJ@1JFUX061PH03Ti>@1RHV80Ph>303hn?P0f=SH0A4A4028R8P0g
=cL0GEeM05aLG00Z:RX0?3`l02d];@0Y:BT0C4a<07moO`0U9BD09bLW03Ti>@0g=cL0AdM707UiN@1f
MWH061PH03Hf=P1?Cdl0CDe=04];B`2IVIT0?Shn02@T900204e=C@0h051@D01/K6`0V9RH03@d=00/
;2`0@D51075aL@0o?cl0L71`0::RXP1GEeL09BDU03dm?@1MGEd0EEEE06UYJ@2YZJT0=3@d030`<014
A4@0Fe]K06=SH`2LW9`0ADE501dM7@0g=cL0JFUY065QH@0[:b/0B4Q801hN7P0/;2`0Hf=S07alO00f
=SH0EUIF02<S8`13@d<0F5QH06QXJ00S8b<0?Cdm04i>CP0o?cl0F5QH08J6QP1dM7@0820P02`/;01[
Jf/0Lg=c07moO`2KVi/0=CDe01`L7017AdL203lo?`0]08N7Q`2/[:`0:RXZ02l_;`16ATH0CDe=0451
@@2SXj<0QhN702@T900c<c<0C4a<06][J`1]KFd0[Jf]07emO@0O7al0D51@05eMG@1aLG40EeMG092@
T00O7al0?3`l071`L01UIFD0EEEE04];B`1IFET08B4Q05MGE`1/K6`0IVIV04I6AP2CTi<0@d=304];
B`2BTY80U9BD04i>CP1WIfL0<S8b02<S8`1YJFT0UIFE0080E5AD0380EUIF02TY:@1EEED0NWYj02DU
9@0i>CT0@D51051@D01bLW80bLW904E5A@0b<S80CTi>0410@01IFET0SHf=04=3@`0U9BD0Cdm?05IF
EP1=CDd0R8R808:2PP0Q8B40B4Q807=cL`1MGEd0Hf=S0;:b/P0f=SH0<C4a069RHP2i^KT0E5AD09VI
V@2NWYh092@T03hn?P1MGEd0LW9b04I6AP1kNg/0O7al01hN7P1<C4`0T92@0:2PX01_Kfl0K6a/0;^k
^`80CDe=0:`0Hf=S09>CT`1]KFd0IVIV09FEU@19BDT0GemO0;Fe]@2>SXh0@T9207YjNP0m?Cd0?Shn
03Xj>P1UIFD0GemO02XZ:P1GEeL0;2`/02@T901>CTh0TI6A05]KF`0M7Ad0?clo05ADE00b<S80@d=3
079bLP1IFET0:RXZ04I6AP1JFUX0CDe=06m_K`1RHV809BDU04Q8B01eMGD0>3Ph03/k>`1SHf<0?clo
07emO@0j>SX0Bd];08>3P`0Q8B40GUiN04m?C`1<C4`0CDe=04U9B@1dM7@0EEEE06m_K`1XJ6P0<C4a
03/k>`0M7Ad0Cdm?038b<P1BDU80B4Q806UYJ@0n?Sh0EEEE04E5A@1bLW80S8b<06ATI017AdL0F5QH
06a/K01UIFD0CDe=05ADE01JFUX0Ogmo061PH01;Bd/0ADE5055AD@17AdL0EUIF05MGE`1SHf<0IVIV
04U9B@1<C4`0CDe=05ADE00^;Rh0ATI605]KF`1EEED0FUYJ04M7A`1:BTX0Lg=c03Lg=`18B4P0EUIF
04m?C`1IFET0@D5105YJFP1ADE40D51@04];B`1@D500FEUI05MGE`13@d<0?3`l05ADE00a<C40ATI6
02TY:@0^;Rh0Cdm?02l_;`0`<300CDe=03@d=00o?cl0EUIF05EEE@0n?Sh0>CTi0492@P0m?Cd0:RXZ
03`l?00g=cL0=3@d034a<@1EEED08B4Q02@T900];Bd0>3Ph04E5A@0R8R80;Rh^0451@@0_;bl0@410
030`<00h>3P0CTi>03lo?`13@d<0FEUI071`L00o?cl0>3Ph04Q8B01TI6@0C4a<0492@P1<C4`0Ti>C
05IFEP1=CDd0C4a<06QXJ01GEeL0@d=30451@@19BDT07QhN0P10@400]P1:BTX0<S8b04a<C00m?Cd0
Ph>307]kN`0a<C40CDe=03dm?@1HF5P0C4a<03De=@2ATI40ZZZZ05aLG01>CTh0D51@03Xj>P0n?Sh0
Kfm_07emO@19BDT0@T9205eMG@1HF5P0VIVI05=CD`2RXZ80NWYj04Q8B01NGUh0NGUi0451@@1jNWX0
KFe]051@D00M7Ad0AdM705iNGP0Z:RX0L71`08V9R@1_Kfl0Fe]K04Y:BP1GEeL0FEUI065QH@20P800
>SXj04a<C01fMWH0CTi>05aLG01^KVh0IFEU07alO01CDe<0Jf][04U9B@0l?3`0E5AD04=3@`0h>3P0
A4A406a/K00V9RH0HV9R05ADE00d=3@0>CTi04Y:BP18B4P0De=C06a/K01<C4`0QHF506QXJ01=CDd0
IFEU05YJFP16ATH0=CDe03Ti>@0o?cl0B4Q8055AD@0c<c<0F5QH04M7A`1TI6@0KVi^051@D01/K6`0
JFUY01LG5`0d=3@0=SHf03<c<`1>CTh0>CTi06=SH`1;Bd/0E5AD04a<C00o?cl0B4Q803De=@0f=SH0
Fe]K03<c<`0j>SX0@T9203Xj>P1fMWH0F5QH02TY:@19BDT06QXJ06QXJ00g=cL0A4A405IFEP0O7al0
DE5A03@d=017AdL0EeMG061PH01MGEd0ATI606IVIP0i>CT0U9BD05EEE@0m?Cd0=cLg03De=@1oOgl0
R8R804a<C02=SHd0Ti>C059BDP1IFET0=3@d05ADE01BDU80ATI605iNGP2:RXX0A4A407=cL`15ADD0
De=C07=cL`1MGEd0PX:20861P@1>CTh0EeMG04Y:BP1=CDd0F5QH04I6AP1>CTh0Cdm?04];B`16ATH0
?clo03hn?P1GEeL0Q8B403hn?P1@D500Shn?04Y:BP1JFUX0?Shn04=3@`1UIFD0De=C0_ooool0000_
069RHP1WIfL0WinO06EUI@1bLW80DE5A04I6AP1bLW80SXj>05=CD`25QHD0ADE502/[:`1MGEd0SXj>
03`l?01QHF40?3`l030`<01BDU80KVi^02DU9@13@d<0B4Q804E5A@1EEED0SXj>0492@P0N7Qh0H61P
065QH@1:BTX0RXZ:05mOG`0I6AT06a/K06a/K026QXH0Cdm?0:b/[02?Shl07QhN02XZ:P1RHV80M7Ad
04a<C02KVi/00P0^;Rh00`1EEED0Kfm_03<c<`02075aL@0k03Ti>@0`<300CDe=09>CT`1JFUX0L71`
03/k>`0N7Qh0@41004Q8B019BDT0@d=3071`L00c<c<0<30`09FEU@2a/K40BDU9059BDP1ADE40;Bd]
02/[:`22PX80Ph>3034a<@1[Jf/0EUIF02DU9@18B4P0WinO05QHF00V9RH0<c<c04a<C00Z:RX0FEUI
08j>SP0h>3P05aLG03<c<`0i>CT0@d=308Z:RP2BTY804Q8B03<c<`0g=cL0FUYJ05IFEP2RXZ80GEeM
01PH601FEUH0GUiN04U9B@1XJ6P0Xj>S03dm?@0D51@00P1<C4`0300o?cl0B4Q807IfMP0U9BD0>SXj
05]KF`1NGUh0:b/[069RHP1YJFT0820P03De=@80G5aL03/0<30`07YjNP1iNGT07alO02HV9P1_Kfl0
H61P02TY:@0l?3`08b<S038b<P0o?cl0JVYZ04e=C@0f=SH0C4a<03Ti>@11@D40MGEe061PH00K6a/0
=SHf04i>CP1ZJVX0Fe]K07inOP0];Bd06a/K02`/;01GEeL0LW9b096AT@0J6QX0=CDe05]KF`2ATI40
BTY:05EEE@1RHV806a/K03Ph>01CDe<0O7al04E5A@1]KFd0Rh^;02@T900U9BD0MWIf06QXJ00/;2`0
JFUY05ADE00Q8B40:2PX071`L01RHV80ADE505iNGP02020P803L03Lg=`2>SXh0JVYZ0410@01NGUh0
8b<S02`/;00f=SH0HF5Q03Hf=P1ADE40EEEE02d];@1oOgl0Zj^[055AD@0];Bd0FUYJ05aLG00l?3`0
W9bL0:RXZ00U9BD0>3Ph04A4A00m?Cd0AdM709ZJVP1PH6007QhN04i>CP1RHV80De=C0;Bd]01KFe/0
5ADE04Q8B01bLW80Cdm?07AdM01`L700:BTY04];B`1JFUX0ADE5061PH01YJFT05QHF03Ph>01NGUh0
MgMg06EUI@2QXJ40;Bd]03dm?@2UYJD0MWIf05=CD`1WIfL0:b/[02l_;`1XJ6P0VYZJ051@D01GEeL0
CTi>02XZ:P1:BTX0MgMg065QH@0Z:RX0DE5A03Ti>@16ATH0I6AT08f=S@17AdL0:RXZ06m_K`1BDU80
@D5106][J`24Q8@0Fe]K02TY:@1GEeL0EEEE04a<C00n?Sh0Q8B404Y:BP0U9BD0BDU904=3@`0`<300
JFUY0:>SX`1DE5@0<30`04A4A016ATH0@D5109ZJVP1XJ6P09BDU04A4A017AdL0@T9204A4A01fMWH0
Bd];01@D5011@D40O7al08V9R@13@d<0Cdm?03dm?@0o?cl0GemO075aL@1XJ6P0H61P08f=S@1nOWh0
9BDU05iNGP27QhL0D51@0451@@1JFUX0B4Q805=CD`1iNGT0Bd];07IfMP1IFET0H61P09^KV`0n?Sh0
EeMG055AD@1bLW80UIFE06IVIP1TI6@0@D51051@D01=CDd0ADE50451@@0c<c<0FEUI02h^;P1:BTX0
ATI6059BDP0N7Qh0C4a<01dM7@1CDe<0Bd];05MGE`0k>c/0Lg=c08:2PP2<S8`0C4a<05YJFP1jNWX0
MWIf06][J`0V9RH0<S8b04I6AP0l?3`0DE5A04Q8B014A4@0GUiN03dm?@1FEUH0CTi>06][J`12@T80
@d=3071`L00o?cl0BTY:03Ph>00a<C40JFUY05]KF`1EEED0D51@04e=C@1MGEd0DE5A06UYJ@1GEeL0
FUYJ06QXJ01KFe/0PH6107]kN`1IFET0G5aL06a/K017AdL0KFe]03dm?@0j>SX0TI6A03/k>`0^;Rh0
QHF505EEE@1HF5P0EeMG04U9B@80DU9B01H0@d=304Y:BP1;Bd/0Cdm?03<c<`12@T80FUYJ05EEE@0m
?Cd0ADE5055AD@1GEeL0DE5A03@d=00l?3`0HF5Q0492@P1IFET0<S8b04I6AP17AdL0CTi>0P12@T80
V01;Bd/0@d=304a<C00e=CD0>c/k06QXJ01>CTh0FEUI05eMG@1ADE40CTi>065QH@1BDU80<S8b03`l
?00P8200@41002`/;01ADE407AdM04=3@`1<C4`0XJ6Q03Lg=`1HF5P0Jf][03De=@1gMgL0BTY:04m?
C`1IFET0=CDe03/k>`1OGel0KFe]06IVIP1=CDd0Cdm?07IfMP1ADE40FEUI051@D010@400<30`03De
=@1QHF40A4A40;2`/01NGUh0NGUi055AD@1FEUH0@T9206ATI02ATI40GEeM030`<01[Jf/0Hf=S018B
4P2VYZH0XJ6Q04U9B@1TI6@0D51@071`L01>CTh0Jf][07QhN00e=CD0MGEe06UYJ@0V9RH0G5aL04m?
C`0l?3`0EEEE02l_;`1SHf<0Bd];05UIF@1UIFD0C4a<04i>CP1ADE40Lg=c04a<C01hN7P0LW9b03@d
=00k>c/0B4Q803lo?`1^KVh0S8b<059BDP2BTY80Lg=c04a<C01VIVH0Cdm?04=3@`0m?Cd0B4Q804m?
C`18B4P0EUIF0451@@1NGUh0;Rh^08:2PP1PH600>c/k069RHP2BTY80>CTi0410@00m?Cd0@41005AD
E01FEUH0MGEe05iNGP1<C4`0Cdm?04Q8B01>CTh0<c<c03Hf=P18B4P0<30`04M7A`18B4P0>3Ph04e=
C@1[Jf/0Bd];069RHP0e=CD0Cdm?05IFEP1iNGT0MWIf04m?C`1JFUX0GEeM06ATI01ZJVX0GemO05EE
E@0o?cl0IFEU0P0j>SX0<00S8b<0GEeM07IfMP0l?3`0M7Ad06][J`1?Cdl0K6a/0<71`@1CDe<0IfMW
03@d=01aLG40SXj>069RHP1UIFD0WYjN0820P02`/;00H61P071`L02CTi<0CTi>07alO02ATI40@T92
06QXJ01?Cdl0M7Ad069RHP11@D40DE5A03/k>`1oOgl0?Cdm055AD@0c<c<0;bl_06IVIP11@D40BDU9
05MGE`19BDT0HF5Q059BDP1EEED0JFUY069RHP;ooooo0000g@1YJFT0EUIF08J6QP20P800V9RH07Qh
N00l?3`0A4A406MWI`1QHF40`/;204Y:BP0g=cL0Bd];09BDU01LG5`0OGem04Y:BP0S8b<0C4a<06a/
K018B4P0JFUY092@T00L71`0>CTi06a/K01?Cdl0E5AD092@T027QhL06a/K051@D02j^[X0GUiN03Hf
=P1YJFT0FUYJ02PX:01?Cdl0T92@05ADE00k>c/0CDe=01dM7@0V9RH0HV9R06e]K@0R8R80@T92051@
D00`<300EeMG08J6QP0j>SX0;Rh^05YJFP0h>3P0EEEE0;Jf]P1UIFD07AdM02`/;01=CDd0?3`l07=c
L`2MWId0<c<c028R8P1ADE40Lg=c03lo?`1mOGd0WIfM02`/;00Y:BT0F5QH05iNGP11@D40X:2P09>C
T`0L71`0=cLg06UYJ@1jNWX0EEEE07QhN016ATH0?clo04m?C`1MGEd0V9RH04=3@`2?Shl0EUIF02LW
9`0X:2P0MgMg04i>CP1BDU80FEUI01lO7`0W9bL0?Shn07]kN`0g=cL0?Shn03Ph>00W9bL0;bl_08Z:
RP2;Rh/0;2`/0410@012@T80<S8b04m?C`2JVYX0Jf][024Q8@1?Cdl0A4A403`l?01bLW80/k>c04Y:
BP0U9BD0CTi>04=3@`1HF5P0Shn?0<k>cP12@T80<c<c0451@@1IFET0GEeM08f=S@0g=cL06ATI02h^
;P1DE5@0FUYJ06][J`25QHD07QhN02PX:01IFET0RHV90451@@18B4P0MWIf02<S8`0h>3P0GUiN07=c
L`0[:b/0BTY:03@d=00n?Sh0Ph>304];B`0Q8B40F5QH0492@P13@d<0DE5A08:2PP0g=cL0Bd];06m_
K`15ADD0>CTi04I6AP1YJFT0D51@02HV9P12@T80>CTi0492@P2OWil0KVi^01lO7`0^;Rh0@d=3038b
<P1NGUh0ZZZZ04m?C`0S8b<0?Cdm04m?C`1KFe/0P8200<W9b@11@D40=cLg055AD@1JFUX0A4A408N7
Q`1nOWh08B4Q02HV9P1CDe<0GUiN04Y:BP2GUiL0DU9B02DU9@0o?cl0JVYZ03dm?@1/K6`0EEEE01lO
7`15ADD0DU9B06ATI01>CTh0JVYZ0080:b/[0?l0IfMW08F5Q@0e=CD0GemO02d];@0W9bL0Fe]K09:B
TP0k>c/0ADE504M7A`0l?3`0Vi^K0;bl_01NGUh0E5AD06UYJ@11@D40G5aL0:>SX`0k>c/08b<S06][
J`1EEED0E5AD08f=S@12@T8092@T061PH01aLG40J6QX0:6QX@2:RXX0;Rh^038b<P1/K6`0XJ6Q0861
P@34a<@0Hf=S03<c<`1GEeL0Kfm_05eMG@1ZJVX0]kNg04];B`0k>c/0MgMg06MWI`20P800GemO0<G5
a@1aLG40?clo059BDP1;Bd/0PH6105mOG`2QXJ40CTi>04Q8B015ADD0D51@06UYJ@2XZ:P0QHF503/k
>`0X:2P0Bd];08b<S014A4@0Cdm?0492@P0j>SX0>CTi06=SH`1gMgL0<c<c04E5A@1DE5@0:2PX0451
@@29RHT0MGEe01PH600Y:BT0CTi>03Ti>@0^;Rh0Lg=c09NGU`0l?3`0;2`/04U9B@0_;bl0EeMG06QX
J00k>c/0?Cdm09^KV`1EEED0EeMG03Lg=`12@T80KFe]03@d=01jNWX0FUYJ07inOP1/K6`0DE5A079b
LP1;Bd/0EUIF06e]K@0k>c/0BTY:03@d=01XJ6P0>SXj061PH01?Cdl0Kfm_03De=@1ADE406QXJ05mO
G`1hN7P0J6QX04i>CP1VIVH0/K6a06IVIP1PH600Hf=S06m_K`2OWil0I6AT04U9B@1=CDd0C4a<04i>
CP1RHV80G5aL07QhN01RHV80BTY:065QH@1JFUX0IVIV02h^;P1OGel0L71`05MGE`1UIFD0>3Ph02XZ
:P1OGel0@D5104U9B@0i>CT0>3Ph05]KF`1ADE40De=C03/k>`18B4P0CTi>06=SH`1nOWh0Xj>S051@
D013@d<0GUiN04I6AP1JFUX0Jf][06UYJ@29RHT0;bl_02`/;01SHf<0=CDe03dm?@1ZJVX0CDe=05MG
E`1LG5`0?3`l05IFEP0n?Sh0DE5A02l_;`14A4@0@D5105QHF00k>c/0?clo04M7A`1:BTX0DE5A03@d
=00/;2`0Cdm?03lo?`1:BTX0BDU905ADE014A4@0D51@06IVIP1=CDd0HV9R061PH01/K6`0BDU906MW
I`1_Kfl0De=C05EEE@1lO7`0NWYj04a<C017AdL0H61P04M7A`1EEED0<30`0492@P0K6a/0@D5101LG
5`15ADD09RHV04A4A00k>c/0F5QH07IfMP0o?cl0KFe]05UIF@1QHF40KFe]04A4A01WIfL0QXJ608>3
P`26QXH0L71`034a<@1MGEd0EUIF05]KF`0a<C4001`0=cLg04=3@`0m?Cd0QhN704U9B@2DU9@0PX:2
07=cL`1QHF40E5AD05YJFP1:BTX0Hf=S06ATI013@d<0M7Ad06YZJP0T92@0E5AD05QHF016ATH0OWin
03`l?01TI6@0<S8b06QXJ01cLg<07alO0P0l?3`08`0Z:RX0HF5Q05]KF`1:BTX0Lg=c04i>CP1WIfL0
Cdm?02l_;`0o?cl09bLW059BDP1ADE40RHV901HF5P1CDe<0CTi>02d];@0l?3`0BTY:03`l?017AdL0
LW9b05QHF02l_;`0VYZJ05YJFP1RHV80Cdm?07MgM`1CDe<0?Cdm04E5A@1iNGT0T92@0080BTY:04P0
EeMG0<o?c`2ATI40BTY:04A4A01^KVh0>CTi071`L01_Kfl0A4A405=CD`1;Bd/0QHF506EUI@1JFUX0
M7Ad04m?C`1HF5P0DE5A05MGE`1EEED0?Shn07=cL`1fMWH0CDe=05mOG`1RHV80GUiN09:BTP1SHf<0
MGEe05iNGP1iNGT0OGem038b<P1LG5`0LW9b07inOP12@T80CDe=06QXJ00k>c/0De=C02<S8`1jNWX0
<C4a03De=@0o?cl0;bl_06IVIP1NGUh0clo?0=;BdP3Ng]h0[Zj^07UiN@2VYZH0Kfm_0:RXZ02@T900
HF5Q075aL@10@400AdM704i>CP1iNGT0MgMg04M7A`2<S8`0JVYZ059BDP2<S8`203Ph>00C0410@00j
>SX0BDU90492@P11@D40=CDe05ADE017AdL0Bd];07emO@0a<C40C4a<0:2PX01ADE40CTi>05ADE01Q
HF40MGEe069RHP02ooooo`000?l0[Zj^07]kN`2YZJT0De=C05MGE`1mOGd0F5QH08:2PP0n?Sh0E5AD
08V9R@2NWYh0@d=305mOG`0i>CT0@410065QH@25QHD0<30`0492@P17AdL0=CDe07=cL`2@T900<C4a
02XZ:P1OGel0=cLg030`<02CTi<0Fe]K02DU9@0^;Rh0D51@03`l?01LG5`0_;bl05=CD`0T92@0>3Ph
05MGE`1:BTX0MGEe0;^k^`15ADD0<S8b03Lg=`19BDT0FUYJ09:BTP26QXH08b<S04a<C01@D500HF5Q
06MWI`2MWId0@d=303<c<`19BDT0TI6A05aLG01UIFD0H61P02`/;011@D40RHV907AdM018B4P0NGUi
03lo?`0J6QX0@T9209RHV01/K6`0:2PX05MGE`0a<C407alO04e=C@2@T900De=C02PX:00h>3P092@T
02/[:`14A4@0IVIV02DU9@0V9RH0:b/[03Lg=`0j>SX0PX:2071`L00V9RH0?Cdm03lo?`0[:b/0Lg=c
09BDU00R8R80=SHf04A4A019BDT0=CDe08j>SP1oOgl06a/K0410@015ADD0FUYJ04e=C@2ATI40BTY:
02@T900i>CT0EUIF06UYJ@1OGel0T92@03De=@0I6AT0AdM7038b<P17AdL0A4A407moO`0f=SH09RHV
04=3@`1CDe<0Fe]K04i>CP1eMGD0A4A402/[:`1/K6`0KFe]03Hf=P1EEED0GEeM01TI6@13@d<0Shn?
05EEE@0];Bd0E5AD04U9B@0k>c/0NGUi0:2PX00c<c<08B4Q055AD@0n?Sh0H61P09JFUP1:BTX09bLW
05=CD`10@400EEEE09jNWP1SHf<09bLW0492@P18B4P0@41006m_K`2][Jd0EUIF02/[:`17AdL0Fe]K
07AdM01aLG40`L7104M7A`0/;2`0CDe=06YZJP0h>3P0GUiN071`L00T92@0@d=306e]K@1hN7P0=CDe
07=cL`14A4@0:2PX02`/;02>SXh0V9RH04M7A`1_Kfl0;2`/02DU9@13@d<0WYjN05=CD`1ADE40Jf][
020P800R8R80H61P08j>SP0^;Rh0GUiN05IFEP0l?3`0P8200:^[Z`0g=cL09RHV061PH01<C4`0@T92
07UiN@10@4008R8R03dm?@1WIfL0H61P09^KV`1]KFd07AdM03dm?@1_Kfl0BTY:07MgM`1@D500:2PX
04Y:BP1mOGd0MgMg09jNWP25QHD0=cLg05UIF@1gMgL0JVYZ04m?C`2?Shl0>c/k059BDP1RHV80G5aL
0451@@2>SXh0@d=303Hf=P19BDT005T0LG5a05MGE`18B4P0GEeM028R8P1?Cdl0LG5a06m_K`0j>SX0
G5aL07EeM@0N7Qh092@T09JFUP2ATI40<C4a04E5A@1<C4`0>CTi03Ph>01MGEd0QXJ603De=@1@D500
Hf=S02HV9P1:BTX0ZZZZ06UYJ@0T92@0A4A404];B`0m?Cd0GEeM0:ZZZP1;Bd/0:b/[04Y:BP1=CDd0
OGem0:BTY02CTi<09bLW04=3@`1JFUX0GUiN04I6AP2=SHd0XZ:R03Hf=P0n?Sh0HV9R0820P01:BTX0
KVi^08b<S00^;Rh08B4Q04U9B@1<C4`0A4A40820P025QHD0820P04=3@`1:BTX0=CDe03hn?P1?Cdl0
@T9205EEE@0a<C40@41007IfMP0I6AT0AdM703/k>`1cLg<0Ti>C055AD@1NGUh0?Cdm05ADE01ADE40
?Cdm04M7A`0g=cL0BTY:03@d=0020410@00E055AD@0Y:BT0@T9201/K6`1OGel0E5AD05iNGP0l?3`0
I6AT06m_K`1KFe/0ATI6055AD@1ZJVX0I6AT05aLG00i>CT0?clo05IFEP0d=3@0CDe=0080CTi>04@0
C4a<03De=@15ADD0Fe]K05aLG00h>3P0?Cdm04m?C`0i>CT0C4a<03/k>`0i>CT0FEUI05YJFP1HF5P0
AdM704E5A@1SHf<0Lg=c05MGE`14A4@0EeMG07YjNP1BDU80EeMG08:2PP1OGel0D51@05QHF01FEUH0
IfMW03dm?@0b<S80LG5a03hn?P16ATH0Ogmo05EEE@1<C4`0HF5Q05=CD`1@D500DU9B04M7A`1?Cdl0
A4A404E5A@0f=SH0@d=304Y:BP1HF5P0;Bd]05YJFP1NGUh0CDe=04Q8B00/;2`0@D51069RHP0n?Sh0
GemO04e=C@1NGUh0Bd];06ATI01[Jf/0H61P06ATI080DU9B0<L0Fe]K05UIF@1`L700Hf=S07EeM@1U
IFD0UiNG06MWI`1FEUH0M7Ad04I6AP1BDU80?Cdm04Q8B00Y:BT0FUYJ038b<P1YJFT0CTi>06IVIP1A
DE40QHF508B4Q01?Cdl0LW9b055AD@1MGEd0JVYZ05MGE`1jNWX0RXZ:07YjNP1HF5P0GUiN0492@P1W
IfL0K6a/08Z:RP14A4@0AdM705EEE@19BDT0Rh^;03Xj>P3;bl/0VYZJ07emO@1bLW80DU9B06e]K@1Q
HF40KVi^05YJFP0W9bL0DE5A04Y:BP0];Bd0Ph>308^;R`14A4@0Bd];04I6AP26QXH0@41004Q8B01<
C4`0;Rh^069RHP1JFUX0<30`04=3@`10@400GUiN07IfMP18B4P0Bd];02/[:`19BDT0EeMG03Lg=`1T
I6@0BDU905MGE`0G5aL0Jf][05EEE@0F5QH0ATI605iNGP0a<C40GEeM069RHP0X:2P0Hf=S04e=C@1E
EED0M7Ad03<c<`1:BTX0;2`/03hn?P0c<c<0=CDe05eMG@0b<S80FUYJ020P801QHF40C4a<034a<@1h
N7P0MGEe01TI6@0m?Cd0B4Q803@d=01HF5P0>SXj05aLG01JFUX0?clo051@D00m?Cd0CDe=02/[:`0/
;2`0ADE501hN7P0e=CD0@410020P801ZJVX0J6QX03Ti>@1^KVh0:b/[04];B`0j>SX0EeMG05mOG`0I
6AT0@T9202l_;`0k>c/0@d=302l_;`1CDe<0;bl_04e=C@0X:2P0EUIF02LW9`0i>CT0C4a<03Hf=P1C
De<0[Zj^0?ooo`36a/H0T92@04M7A`1DE5@0UIFE09:BTP15ADD0ATI605MGE`1/K6`0Kfm_0:2PX00c
<c<0LG5a08f=S@13@d<0JFUY05mOG`0l?3`0IFEU04A4A01PH600JVYZ03Hf=P1:BTX0EUIF0861P@1C
De<0BDU902d];@1DE5@0T92@04Y:BP0j>SX0DU9B04m?C`1<C4`0BTY:051@D01MGEd0K6a/00;ooooo
000206IVIP110;Bd]01=CDd0EUIF06EUI@1kNg/0U9BD04I6AP0n?Sh0EEEE04E5A@1UIFD0/K6a04I6
AP0^;Rh0Cdm?07IfMP1YJFT0T92@065QH@0^;Rh0?3`l06YZJP1IFET0OWin07emO@0f=SH0:RXZ04=3
@`1]KFd0Lg=c09JFUP1?Cdl0:b/[02d];@17AdL0NWYj03/k>`1mOGd0HF5Q01DE5@0];Bd0EUIF06MW
I`0f=SH0F5QH02DU9@0n?Sh0Jf][07]kN`1FEUH0LW9b05EEE@0L71`0A4A406EUI@1iNGT0<S8b07Ee
M@0_;bl09BDU06ATI024Q8@0:RXZ024Q8@1CDe<00P1;Bd/0o`2HV9P0E5AD01<C4`0S8b<0ADE5069R
HP1TI6@0[Zj^059BDP0C4a<09RHV07AdM01^KVh0Hf=S07]kN`0J6QX07AdM02LW9`1FEUH0BDU905=C
D`1^KVh07QhN038b<P1LG5`0LG5a04a<C01SHf<0F5QH01TI6@0O7al0IFEU069RHP0l?3`0Ng]k02`/
;00W9bL0BTY:07YjNP0n?Sh0>SXj05aLG00X:2P08B4Q06EUI@26QXH0;Rh^03<c<`14A4@0?3`l03Ti
>@25QHD0Cdm?02TY:@1=CDd0HF5Q02`/;018B4P0TY:B04Y:BP0E5AD0=cLg04m?C`0l?3`0Fe]K08:2
PP14A4@09RHV04Y:BP0l?3`0@T9206i^KP1[Jf/09BDU028R8P1IFET0MWIf03`l?01TI6@0<C4a02PX
:01CDe<0[:b/08B4Q01<C4`0EeMG03<c<`0O7al0R8R80;Zj^P1;Bd/0LW9b03Xj>P0N7Qh0MWIf09ZJ
VP15ADD0De=C03lo?`0P8200<30`04=3@`1XJ6P0?Cdm05]KF`1YJFT09BDU030`<025QHD0LW9b02<S
8`1FEUH0@T9204A4A01HF5P0Zj^[05ADE00Z:RX0CTi>03lo?`0f=SH0MGEe07IfMP0/;2`0:BTY05EE
E@1/K6`0EeMG09BDU010@40092@T03De=@1@D500F5QH09^KV`2PX:00:b/[03Xj>P0o?cl0KVi^05EE
E@2KVi/0W9bL01hN7P1GEeL0U9BD06ATI01;Bd/0SXj>02LW9`1;Bd/0IVIV05UIF@0h>3P0DE5A02PX
:00Y:BT0EUIF08f=S@0m?Cd0FEUI07AdM00o?cl0DU9B05mOG`0X:2P0Hf=S04a<C011@D40Lg=c0:b/
[018B4P0@41006i^KP0i>CT0@410096AT@2SXj<0UiNG0820P00n?Sh0BTY:07AdM01EEED09bLW04];
B`1KFe/0HF5Q06m_K`2VYZH0:BTY03/k>`1FEUH0GemO05eMG@23Ph<0[:b/03Lg=`0a<C40CTi>06AT
I01ZJVX0PX:207inOP0T92@07AdM05EEE@1_Kfl0L71`09RHV02`/;00=cLg01dM7@1QHF40Ogmo05]K
F`1jNWX0IfMW03/k>`1UIFD0LG5a07EeM@1<C4`0NWYj03De=@0L71`0@T9206YZJP18B4P0@41005YJ
FP0e=CD071`L038b<P1dM7@0CTi>01hN7P14A4@0Bd];02`/;00e=CD0Lg=c05IFEP0Y:BT0IVIV0451
@@0Y:BT0=CDe05eMG@13@d<0CTi>06=SH`12@T80B4Q806i^KP00o`1<C4`0EeMG03lo?`1>CTh0NWYj
01/K6`16ATH0@D5105=CD`1VIVH0EeMG08Z:RP1JFUX0N7Qh05ADE016ATH0DU9B03Lg=`1DE5@08B4Q
03De=@11@D40D51@01TI6@1<C4`07alO06m_K`1?Cdl0I6AT04I6AP1_Kfl0Q8B407=cL`1<C4`0GUiN
08F5Q@1_Kfl0IFEU02/[:`0e=CD0De=C03lo?`1IFET0Bd];05IFEP1^KVh0@T92061PH01?Cdl0IVIV
03dm?@13@d<0Kfm_0410@01LG5`0@T9202PX:01XJ6P0>SXj04M7A`0k>c/0<c<c05]KF`16ATH0EEEE
03Hf=P19BDT0CTi>07=cL`1>CTh0QXJ603lo?`11@D40KFe]03Hf=P1@D500De=C051@D01XJ6P09bLW
02@T901SHf<0=3@d03/k>`1DE5@0A4A405EEE@1JFUX0?Shn051@D01>CTh0A4A402d];@0o?cl0ADE5
04a<C00m?Cd0CTi>04e=C@15ADD0AdM7038b<P0c<c<0De=C03@d=018B4P0De=C059BDP0k>c/0D51@
06e]K@1CDe<0F5QH06YZJP20P800E5AD05IFEP1cLg<0R8R805EEE@11@D40OGem04a<C01QHF40KVi^
05YJFP1NGUh0@410051@D00Y:BT0D51@03<c<`1?Cdl0DE5A06EUI@14A4@0AdM707YjNP1EEED0NGUi
05QHF01bLW80Ogmo04E5A@1JFUX0LW9b08>3P`2HV9P0Ogmo04E5A@1VIVH0CTi>06MWI`18B4P0BDU9
04I6AP1CDe<0X:2P05IFEP2?Shl0PH6107]kN`1RHV80J6QX07QhN01ZJVX0NGUi08Z:RP0o?cl0Fe]K
05UIF@0G5aL0Rh^;07QhN00k>c/0EeMG03Ph>01DE5@0?3`l055AD@1XJ6P06a/K0451@@1HF5P07alO
04A4A01IFET0@410071`L01SHf<0E5AD0410@00g=cL0AdM702d];@15ADD0M7Ad0:>SX`0/;2`0DE5A
05iNGP0R8R80DU9B06UYJ@0a<C40BDU905]KF`11@D40Shn?06YZJP0i>CT0CDe=034a<@1SHf<0>3Ph
03Hf=P0i>CT0DE5A05iNGP0a<C40?clo02DU9@2IVIT0MgMg02XZ:P17AdL0@T92018B4P1DE5@0GUiN
02DU9@1<C4`0;Bd]05EEE@1HF5P0B4Q8055AD@15ADD0@d=303<c<`0e=CD0CDe=02HV9P1SHf<0JFUY
01`L701<C4`0ADE503<c<`1PH6008B4Q05=CD`0Q8B40CDe=05iNGP006@0I6AT0@d=3051@D01MGEd0
FUYJ04];B`1bLW80>SXj05UIF@0T92@0JVYZ03Xj>P0i>CT0@4100492@P1FEUH0XJ6Q0=[JfP1FEUH0
G5aL0410@01CDe<0Y:BT08V9R@10@4000P1GEeL03`1FEUH0@D51051@D01=CDd0G5aL08^;R`1WIfL0
alO709^KV`1HF5P0GUiN04E5A@1TI6@0EEEE03<c<`0203Ph>00?051@D00k>c/0B4Q803Xj>P1<C4`0
NWYj03dm?@13@d<0S8b<04e=C@1NGUh0AdM705EEE@1NGUh0EeMG00;ooooo0000o`1SHf<0DU9B08j>
SP1ZJVX0YjNW04Y:BP18B4P0K6a/08b<S01QHF40^[Zj03lo?`0d=3@0EeMG09:BTP17AdL0SHf=02<S
8`0W9bL0KVi^08b<S01:BTX0CDe=05UIF@0I6AT0<30`06IVIP12@T808R8R05IFEP0W9bL0?Shn05QH
F01QHF408R8R03<c<`0o?cl0<30`04A4A01KFe/0Ogmo01/K6`0Q8B40EUIF03/k>`1RHV80N7Qh02TY
:@0E5AD0<c<c07=cL`17AdL0U9BD092@T00P82007alO04E5A@2<S8`0B4Q80;Rh^00j>SX0?3`l04e=
C@1BDU80C4a<04];B`1]KFd06QXJ038b<P0h>3P0Lg=c03lo?`1JFUX0Cdm?01hN7P0/;2`0G5aL07Yj
NP0_;bl0=cLg030`<00];Bd0CDe=069RHP19BDT0>CTi05mOG`0_;bl0=SHf075aL@2?Shl0<30`02DU
9@12@T80;Rh^02`/;01bLW80P820020P800K6a/0:BTY04m?C`1ADE40YJFU04];B`0Q8B40;Rh^03Ti
>@0o?cl0Fe]K09:BTP0U9BD06a/K02`/;01DE5@0@d=307=cL`20P8009bLW02PX:011@D40IFEU03/k
>`25QHD0Ti>C04];B`0];Bd0E5AD06QXJ00i>CT0HV9R07]kN`0T92@09bLW06a/K01_Kfl0ADE5071`
L00n?Sh08R8R04Q8B01lO7`0FUYJ04];B`1QHF408B4Q04I6AP1oOgl0B4Q802HV9P1;Bd/0F5QH04I6
AP1<C4`0RHV903@d=00M7Ad0?Shn06QXJ01JFUX0Ph>3024Q8@0P8200@D5106m_K`1GEeL0K6a/06UY
J@0E5AD0;Rh^020P8019BDT0?Cdm07AdM02YZJT0:BTY01lO7`0o?cl0GEeM051@D02<S8`0=3@d02LW
9`18B4P0MgMg061PH02;Rh/0/k>c0492@P0/;2`0Bd];07UiN@1WIfL0IVIV0:BTY00e=CD0>c/k06][
J`1PH600CTi>08R8R01/K6`06a/K04E5A@1/K6`0?Cdm04U9B@1bLW80?clo01dM7@1FEUH0Xj>S04Q8
B00i>CT0>c/k034a<@1ADE40U9BD05aLG00M7Ad0CTi>0492@P1DE5@0NGUi0451@@0O7al0=SHf04m?
C`1YJFT0JVYZ07EeM@0J6QX0=CDe05IFEP19BDT0UiNG06=SH`0I6AT0?Cdm071`L01GEeL0RXZ:09JF
UP0_;bl0:b/[08N7Q`2IVIT0f=SH08R8R00R8R80CTi>08b<S01cLg<0@T9207=cL`003P1JFUX0:b/[
04e=C@2@T900JVYZ03hn?P1fMWH0ATI60410@01;Bd/0JVYZ05mOG`0l?3`0Ng]k0P0e=CD0`01MGEd0
GUiN06ATI00k>c/0O7al04Y:BP0S8b<0EeMG0:BTY01IFET0<C4a03hn?P0o?cl0?Shn07EeM@2HV9P0
9BDU02h^;P1FEUH0?Shn04i>CP2HV9P0MGEe01DE5@0h>3P0I6AT04Y:BP1/K6`0SXj>04Q8B00M7Ad0
9BDU061PH01WIfL0BDU907MgM`1PH600:RXZ02d];@1KFe/0QhN704A4A02GUiL0Cdm?03@d=01;Bd/0
GUiN03`l?01DE5@0KVi^04=3@`0k>c/0Z:RX069RHP1_Kfl0C4a<04=3@`1dM7@0A4A406e]K@1?Cdl0
Bd];06a/K01:BTX0QhN706a/K01MGEd0CTi>04A4A01?Cdl0Bd];07EeM@0l?3`0ADE50492@P2<S8`0
<C4a04E5A@0E5AD0De=C06EUI@1@D500Bd];05IFEP1SHf<0Bd];051@D01KFe/0KVi^09RHV01OGel0
@T9202h^;P1?Cdl0GUiN06=SH`13@d<0HV9R04a<C011@D40BTY:04a<C01DE5@092@T069RHP1VIVH0
CTi>051@D01FEUH0?Shn07=cL`0o?cl0Bd];051@D018B4P0GEeM05=CD`1LG5`0?clo05EEE@1DE5@0
Lg=c04M7A`27QhL0BTY:04U9B@1nOWh0@41007QhN01<C4`0?clo0:b/[00f=SH0:b/[08Z:RP15ADD0
@D51061PH012@T80Fe]K059BDP17AdL0IVIV04A4A01=CDd0B4Q80492@P16ATH0K6a/051@D01LG5`0
EUIF059BDP1GEeL0?3`l03/k>`1TI6@0?clo05iNGP1>CTh0J6QX04A4A01UIFD0GUiN051@D01QHF40
Cdm?051@D017AdL0DU9B05mOG`1@D500?Cdm02l_;`1@D500@41006IVIP1?Cdl0<c<c03/k>`1:BTX0
ADE501dM7@11@D409BDU04i>CP0k>c/0G5aL02d];@1/K6`0HV9R03Hf=P<0HV9R0300P82004Y:BP1R
HV80JFUY06i^KP1EEED0Cdm?03Xj>P1_Kfl0Jf][08B4Q01@D500DE5A05EEE@13@d<0XZ:R065QH@2H
V9P0LW9b06i^KP1FEUH0N7Qh061PH01JFUX0MGEe061PH00o?cl0V9RH06UYJ@0L71`0Rh^;0861P@12
@T80P82004I6AP1IFET0>SXj07alO021PH409RHV04];B`1XJ6P0;Rh^06e]K@1WIfL0A4A40820P01T
I6@2079bLP0Q03dm?@1KFe/0;Bd]04Y:BP11@D40E5AD02@T901<C4`0ATI601`L700S8b<0<S8b030`
<015ADD0DE5A02HV9P1dM7@0HV9R028R8P13@d<0:2PX03Ph>011@D40=3@d03Hf=P0b<S80Fe]K02l_
;`1<C4`07AdM061PH018B4P09RHV0080DU9B05L02@T903Ph>019BDT08B4Q04m?C`11@D40QHF5055A
D@18B4P0F5QH0410@013@d<0<C4a03lo?`1ADE40=cLg04A4A019BDT05aLG04a<C012@T80<c<c069R
HP0V9RH0Cdm?03dm?@1dM7@0Rh^;01/K6`1MGEd0Cdm?05ADE00d=3@0>SXj05ADE00X:2P0@d=301dM
7@1gMgL0>3Ph05ADE01MGEd0>3Ph05UIF@25QHD0UiNG051@D00e=CD0B4Q807emO@2m_Kd0N7Qh03hn
?P1;Bd/0C4a<061PH01EEED0K6a/020P801NGUh0K6a/03`l?01LG5`0E5AD03Lg=`1mOGd0:b/[05=C
D`17AdL0>3Ph05QHF00i>CT0HF5Q03dm?@1SHf<0=cLg05MGE`1hN7P0<30`04m?C`29RHT0DE5A04Y:
BP1HF5P0DE5A08>3P`1HF5P00_ooool0000D0:2PX01XJ6P0JFUY04a<C029RHT0WIfM04Q8B01YJFT0
DU9B06m_K`2][Jd0EeMG03Hf=P18B4P0AdM706UYJ@25QHD0;bl_020P800[:b/204U9B@1<09:BTP24
Q8@07QhN02LW9`11@D40IfMW069RHP37alL0HV9R01`L700h>3P0Hf=S05IFEP2CTi<0ZJVY038b<P0Y
:BT0>SXj05EEE@14A4@0EUIF06IVIP0P8200:RXZ04U9B@1BDU80:2PX06ATI016ATH09BDU05ADE025
QHD0?Shn03Lg=`1LG5`092@T024Q8@1_Kfl0Jf][01TI6@0_;bl0F5QH0451@@1ADE40[jn_04m?C`0b
<S80EEEE03hn?P14A4@0QhN708R8R00Q8B406a/K02l_;`1ADE40Cdm?0820P01ZJVX05aLG04a<C01b
LW80EUIF055AD@29RHT0?3`l020P800c<c<0JVYZ05eMG@1gMgL0XZ:R02<S8`15ADD0BDU908V9R@80
L71`05<0QHF501dM7@0k>c/0De=C06i^KP0h>3P0PH6104i>CP0^;Rh0ATI607MgM`1lO7`0?clo075a
L@16ATH09bLW03/k>`2EUID0EUIF03Hf=P1@D5008B4Q01TI6@1BDU80PX:20492@P0[:b/0P82003dm
?@0R8R80GUiN08n?S`13@d<06ATI05aLG01BDU80?Shn09>CT`1/K6`0820P0451@@1IFET0DE5A06=S
H`2IVIT0:RXZ038b<P1MGEd0O7al04];B`2WYjL0]kNg01hN7P0m?Cd0Ogmo05iNGP1IFET0Ti>C03Xj
>P15ADD0PX:206MWI`1CDe<0TI6A03dm?@1>CTh0GUiN06e]K@0f=SH0DU9B0492@P0S8b<09bLW05UI
F@2IVIT0DU9B02d];@1DE5@0;bl_0492@P1aLG40P820034a<@020451@@0O02`/;01ADE40/[:b05mO
G`0Y:BT0=cLg03Ph>00R8R80GemO0:j^[P1^KVh0@41005QHF00m?Cd0DE5A09jNWP2WYjL0<S8b03@d
=01hN7P0Cdm?05=CD`2OWil0NWYj024Q8@1DE5@0A4A4055AD@1lO7`0JVYZ01LG5`0204e=C@0R059B
DP1ZJVX0WIfM03dm?@0X:2P0KVi^06][J`1FEUH0Shn?03`l?00M7Ad0IFEU09ZJVP1:BTX0GEeM05YJ
FP0[:b/0AdM709>CT`1CDe<0Ph>305MGE`0_;bl0Bd];08n?S`19BDT0>3Ph07AdM00b<S80@41009>C
T`1HF5P0;Bd]06a/K080B4Q800X0PH6107moO`0Z:RX0?Shn04i>CP1ZJVX0PX:209NGU`1MGEd0:BTY
0P1HF5P0FP0l?3`0IfMW0<W9b@18B4P0;Bd]04U9B@1CDe<0C4a<06QXJ03Hf=P0L71`02/[:`0i>CT0
A4A405IFEP18B4P0^KVi04a<C00e=CD0BDU905ADE019BDT0DE5A07AdM00Z:RX0BTY:05=CD`21PH40
@T92059BDP1KFe/07alO03`l?018B4P0IVIV04i>CP1PH600IfMW01dM7@0O7al0@41007QhN00^;Rh0
=SHf03lo?`0K6a/0=cLg05=CD`1]KFd0:RXZ03De=@0_;bl09BDU0451@@1GEeL0@T9203lo?`1:BTX0
>CTi05]KF`18B4P0CTi>08>3P`0g=cL0>c/k04A4A01ADE40EEEE04Q8B01hN7P0FUYJ0861P@29RHT0
CDe=04];B`0P8200Cdm?02XZ:P0e=CD0@41004a<C00^;Rh0D51@02/[:`1=CDd0KVi^05]KF`1;Bd/0
DE5A05QHF080Bd];01`0Cdm?059BDP1GEeL0E5AD03hn?P0g=cL0?Shn03`l?01=CDd0DE5A06EUI@1C
De<0?clo051@D01aLG40GEeM03@d=00c<c<0CTi>06EUI@1LG5`0@41002`/;01GEeL0>CTi04I6AP1A
DE40ADE50P17AdL08@1?Cdl0AdM704e=C@1BDU80D51@05QHF01_Kfl0CDe=04i>CP1NGUh0EUIF07Mg
M`1CDe<0G5aL08n?S`1EEED0@D5106e]K@15ADD0@41005UIF@1;Bd/0CDe=04=3@`1ADE40CDe=03/k
>`0j>SX0@41002h^;P0m?Cd0Bd];03Ti>@0204I6AP0U03dm?@1@D50092@T04E5A@1=CDd0>c/k061P
H019BDT0E5AD05MGE`1MGEd0Fe]K06=SH`1^KVh0H61P07YjNP1UIFD0Hf=S07UiN@1JFUX0I6AT03lo
?`1WIfL0BTY:05MGE`1eMGD0@D51051@D00e=CD0DU9B02DU9@1HF5P0:2PX04I6AP0f=SH0HV9R04a<
C00206m_K`0I03Lg=`1QHF40L71`07AdM02>SXh0R8R807MgM`1YJFT0UYJF06QXJ01cLg<0>3Ph05AD
E01XJ6P0OWin04Y:BP0o?cl0?Shn03Xj>P2c/k<0Lg=c08Z:RP1/K6`0LW9b06UYJ@0206i^KP1Z07Ee
M@2ATI40GemO020P8019BDT0GUiN02@T9020P800RHV904e=C@1ADE40>SXj05aLG00g=cL0EUIF069R
HP0M7Ad0GUiN05eMG@0M7Ad0>c/k04a<C00d=3@0EeMG04M7A`1BDU80GemO03Xj>P1BDU80=3@d065Q
H@1KFe/0N7Qh01hN7P1:BTX0DU9B02`/;00c<c<0@T9203Ti>@11@D40GEeM04=3@`2<S8`0M7Ad03dm
?@1OGel0@D5104A4A00j>SX0;Rh^03/k>`0f=SH0Kfm_03Ti>@1;Bd/0>3Ph08n?S`1cLg<0?Cdm05UI
F@1KFe/092@T04E5A@1ADE407alO05UIF@11@D40OGem05MGE`1EEED0EUIF04A4A01CDe<0>CTi03lo
?`0n?Sh08B4Q04U9B@1?Cdl06QXJ04i>CP0_;bl0?clo06e]K@0[:b/0I6AT030`<01VIVH0MGEe01LG
5`1:BTX0A4A404M7A`1>CTh0>3Ph0492@P0j>SX0GUiN03Hf=P1[Jf/0@T9204E5A@0l?3`0@d=306AT
I080Bd];02T0TI6A05eMG@1cLg<0`<300;no_`2BTY80ATI6059BDP25QHD0SHf=05=CD`1hN7P0;2`/
05iNGP2:RXX0GUiN08J6QP1GEeL0@D51065QH@16ATH0E5AD05IFEP0c<c<0>3Ph04i>CP1aLG40?clo
03Ph>016ATH0EeMG06EUI@0e=CD0>3Ph07MgM`16ATH0FEUI04m?C`1>CTh0EeMG05eMG@02ooooo`00
0640Rh^;09:BTP2PX:00CTi>07emO@1_Kfl0NGUi09^KV`0o?cl0EUIF0861P@1]KFd0NGUi0;^k^`18
B4P0DU9B08J6QP1/K6`0@T9205eMG@1WIfL07AdM03Ph>01^KVh0@41003hn?P1EEED07AdM038b<P1F
EUH0RXZ:02l_;`1CDe<0ATI603Hf=P1?Cdl0O7al061PH00[:b/0@d=30451@@1CDe<0MgMg0:RXZ01<
C4`0:2PX04M7A`1LG5`0ATI609:BTP1=CDd061PH03Ti>@1UIFD0FEUI06=SH`2c/k<0;Rh^02LW9`17
AdL0GUiN04i>CP1UIFD0Lg=c034a<@0h>3P0I6AT05eMG@1eMGD0NGUi0410@00U9BD0Fe]K079bLP1[
Jf/0G5aL09BDU00m?Cd0>CTi06=SH`23Ph<0@d=304A4A01?Cdl07QhN01dM7@0k>c/0H61P028R8P0b
<S80@d=301hN7P0o?cl0J6QX04I6AP0N7Qh0ATI60080=cLg06H0GEeM071`L00S8b<07alO04=3@`0^
;Rh0@T9208f=S@1dM7@05aLG034a<@17AdL0BDU906UYJ@2l_;`0@d=301`L700/;2`0CDe=05MGE`1Y
JFT0Xj>S02d];@0R8R80<S8b05=CD`1^KVh0EUIF0:FUY@0l?3`0;Rh^03Ti>@17AdL0N7Qh04E5A@28
R8P0:b/[03lo?`1VIVH0M7Ad03Xj>P1ADE40D51@024Q8@0f=SH0I6AT06a/K00_;bl0CDe=02XZ:P0L
71`0BTY:06][J`10@400?Shn06i^KP0T92@0:b/[06EUI@26QXH0;2`/05mOG`0T92@0;Bd]07alO01S
Hf<0:2PX05MGE`13@d<0@D5109>CT`1VIVH0:b/[01DE5@1@D500FEUI05ADE01MGEd0]kNg038b<P0V
9RH0IFEU0820P01@D500UIFE06i^KP0S8b<09bLW07EeM@2e]KD0ATI608b<S01TI6@0;Rh^02d];@1b
LW80UiNG04m?C`1eMGD07alO02LW9`0o?cl2061PH00E04Q8B021PH40=3@d03<c<`13@d<0JVYZ04=3
@`2<S8`0BTY:024Q8@1`L700Ogmo04i>CP1ADE40Jf][02`/;00l?3`0UiNG07emO@0i>CT0@4100080
>3Ph03@0Ng]k06=SH`0O7al0?Cdm04m?C`1ADE40JFUY06i^KP0W9bL0CTi>03lo?`16ATH0`<3008V9
R@0S8b<0AdM705MGE`12@T80Lg=c0<g=c@1[Jf/0;bl_04m?C`1bLW80U9BD0<g=c@0`<300ATI605EE
E@1VIVH0HF5Q09^KV`2QXJ40@D5104I6AP1bLW80PX:204];B`1jNWX0P82003De=@0Y:BT0V9RH071`
L00i>CT0IFEU06MWI`0[:b/0>SXj04U9B@1oOgl0@d=30P1ADE407`0`<300<c<c05=CD`1YJFT0;bl_
06=SH`1LG5`0?3`l06IVIP1gMgL0A4A402XZ:P1@D500;Bd]059BDP21PH40QXJ603Hf=P0^;Rh0BDU9
04E5A@1UIFD0KFe]0:2PX00h>3P06a/K03hn?P1ADE40I6AT09ZJVP1XJ6P00P0Q8B40:P19BDT0E5AD
04E5A@24Q8@0L71`01<C4`1?Cdl0M7Ad06IVIP1;Bd/0IFEU05ADE01fMWH0>SXj03Lg=`1LG5`061PH
03@d=00];Bd0GemO09^KV`1EEED0KFe]04m?C`1EEED0CDe=04m?C`1KFe/0?Shn05YJFP0Y:BT0?clo
04];B`1GEeL06QXJ04a<C00O7al0H61P065QH@1PH600>c/k06i^KP80KFe]00D0BDU9065QH@1iNGT0
Hf=S06UYJ@0202/[:`0>04Q8B010@400EeMG03Xj>P0m?Cd0D51@03Lg=`0b<S80<c<c04I6AP0M7Ad0
ADE505IFEP0a<C4203Hf=P0D02/[:`10@400EEEE05]KF`16ATH0>CTi05YJFP1^KVh0D51@04E5A@1C
De<0Kfm_05mOG`0i>CT0EEEE04Y:BP1@D500DE5A03Ph>01<C4`2055AD@0>05YJFP0Z:RX092@T05iN
GP1IFET0D51@04m?C`15ADD0Fe]K05eMG@19BDT0FEUI055AD@17AdL203/k>`0A05mOG`1NGUh0HV9R
05aLG01EEED0AdM705EEE@0f=SH0HV9R05ADE00f=SH0Cdm?05MGE`1?Cdl0>3Ph04M7A`1HF5P00P1>
CTh02`1GEeL0Jf][04a<C01[Jf/0GUiN06ATI018B4P0;bl_06ATI01CDe<0EeMG0080GemO01d0FUYJ
03/k>`1EEED09bLW05eMG@0^;Rh0Fe]K05=CD`1]KFd0IfMW08b<S01lO7`0E5AD0:VYZ@1dM7@0LW9b
07UiN@11@D40P82008>3P`2;Rh/0Lg=c06m_K`10@400NGUi075aL@2ATI40DE5A051@D00204M7A`1B
07alO01_Kfl0QXJ6096AT@2GUiL0DU9B07alO01CDe<0Cdm?05]KF`1eMGD0A4A407YjNP1TI6@04Q8B
06EUI@28R8P0=CDe05iNGP19BDT0Fe]K05ADE01_Kfl0QhN701/K6`11@D40Cdm?03De=@1FEUH0GUiN
04a<C01RHV80E5AD05eMG@1aLG40CTi>065QH@0S8b<0BTY:03dm?@1`L700;bl_06EUI@1aLG409bLW
03<c<`11@D40=SHf05]KF`1cLg<0=3@d08R8R01]KFd0>CTi059BDP1HF5P0CDe=03<c<`0e=CD0@D51
03Ti>@1_Kfl0DU9B065QH@0I6AT0PH6105UIF@0g=cL0OGem06i^KP0X:2P0@T9204E5A@0e=CD0L71`
04e=C@1bLW80I6AT06EUI@1FEUH0BDU9051@D080?Cdm01/0EUIF034a<@17AdL0Bd];024Q8@1_Kfl0
FEUI03Lg=`1HF5P0;2`/065QH@0k>c/0N7Qh096AT@0L71`0C4a<04i>CP1ADE40C4a<0410@01<C4`0
?Cdm08:2PP0^;Rh0MWIf034a<@1DE5@00P1QHF40;01SHf<0J6QX05EEE@1WIfL0C4a<051@D02<S8`0
F5QH02l_;`1DE5@0De=C059BDP1>CTh0EeMG06YZJP1RHV80Y:BT09nOW`1FEUH0T92@079bLP1DE5@0
IfMW02PX:01:BTX0B4Q803Ti>@17AdL0Bd];05aLG01CDe<0CTi>03De=@0k>c/0Bd];04M7A`1CDe<0
JFUY04m?C`1PH600GemO05YJFP29RHT0JVYZ0_ooool0000306=SH`1/K6`0[Jf]0080F5QH04l0@410
06i^KP2`/;00DU9B03De=@1QHF40?3`l04Q8B023Ph<0A4A403hn?P1@D500GUiN05eMG@2CTi<0SXj>
02DU9@0a<C40D51@03Xj>P1aLG40W9bL024Q8@0/;2`0?clo05iNGP2;Rh/0/;2`07emO@0L71`0@D51
05EEE@1aLG40Kfm_08V9R@0i>CT09RHV03lo?`1eMGD0UIFE055AD@1bLW807QhN02d];@1jNWX0Ti>C
0492@P1<C4`0;bl_03Ti>@18B4P0PX:209nOW`12@T80GUiN03Xj>P0O7al0CDe=06a/K00^;Rh0<30`
05]KF`0V9RH0ADE505]KF`1;Bd/0;Bd]03`l?00m?Cd0=CDe04Q8B01kNg/0MgMg01dM7@0d=3@0B4Q8
05=CD`25QHD0UYJF00808b<S07<0;2`/04m?C`1VIVH0IFEU06][J`0K6a/0=CDe04M7A`1kNg/0G5aL
09>CT`1BDU803`l?04M7A`1NGUh0FEUI05aLG02ATI40=cLg02HV9P1VIVH0SHf=04A4A01DE5@0L71`
01`L700H61P0I6AT0820P00S8b<0Hf=S04i>CP0E5AD0;bl_06QXJ01UIFD07alO04];B`0d=3@0820P
024Q8@1eMGD0N7Qh02<S8`0j>SX0C4a<03De=@0h>3P0QXJ607YjNP0a<C40Cdm?0410@00e=CD0PH61
08^;R`0e=CD0>CTi05IFEP10@400De=C09BDU010@4007AdM04A4A01`L700@T9205iNGP2WYjL0:BTY
01TI6@1DE5@0PX:205mOG`2=SHd0:BTY02HV9P1aLG40Lg=c0492@P2>SXh0N7Qh01dM7@0[:b/0L71`
06YZJP0d=3@0T92@06IVIP15ADD0:2PX06a/K01ZJVX0ADE505QHF00k>c/09RHV03/k>`21PH40B4Q8
04U9B@1OGel0@41004];B`1BDU80RHV90410@00l?3`0A4A40492@P1DE5@0Rh^;05QHF00N7Qh0B4Q8
0080ATI60880CDe=08V9R@0f=SH0:2PX03/k>`1BDU80?clo0;bl_01jNWX0:BTY04M7A`1DE5@0B4Q8
08j>SP2MWId0<C4a020P801=CDd0PH6105eMG@1hN7P07AdM03Ti>@1?Cdl0MGEe04U9B@2:RXX0;bl_
02h^;P1VIVH0OGem04=3@`1/K6`0E5AD01TI6@1mOGd0^[Zj0492@P1BDU80@41001LG5`0`<300RHV9
08R8R01[Jf/0Fe]K028R8P1CDe<0UYJF06ATI00_;bl0Kfm_04Y:BP0^;Rh0FEUI09^KV`19BDT0@410
06e]K@11@D40FEUI0820P023Ph<0;Bd]03<c<`1IFET0EUIF05EEE@1gMgL0X:2P02h^;P0/;2`0EeMG
03hn?P1SHf<0YZJV0;6a/@0X:2P0:BTY04Y:BP1;Bd/0GUiN0;>c/`2UYJD0:2PX04e=C@1hN7P0JVYZ
06][J`2d];@0@d=302DU9@17AdL0L71`06QXJ01lO7`0WYjN03lo?`0_;bl0@41007moO`2<S8`0@d=3
092@T00e=CD08b<S0451@@1WIfL0FUYJ03lo?`1XJ6P0;Rh^02d];@1FEUH0MGEe03Xj>P1^KVh0EEEE
03hn?P1HF5P0YZJV075aL@1HF5P0;Bd]03lo?`2UYJD0EEEE06a/K01KFe/0Hf=S0P1KFe/0T`1VIVH0
I6AT05IFEP1lO7`0EEEE04E5A@19BDT0J6QX03De=@0d=3@0BTY:07]kN`0l?3`0FUYJ01hN7P1TI6@0
V9RH06e]K@1;Bd/0M7Ad08j>SP1BDU80HV9R06YZJP1^KVh0YZJV05UIF@15ADD0=3@d03Ti>@1HF5P0
DE5A03`l?019BDT0=CDe02h^;P0[:b/0Cdm?0410@00V9RH0Cdm?04i>CP18B4P0@d=304a<C01:BTX0
IFEU0451@@19BDT0@41003Lg=`1ADE40B4Q805EEE@0g=cL0CTi>05UIF@1oOgl0?clo05eMG@0o?cl0
ATI607EeM@0g=cL0J6QX0410@016ATH0YjNW03Ti>@0T92@0MgMg03lo?`0i>CT0G5aL03Ph>01?Cdl0
AdM703hn?P1ADE40@d=30492@P0`<300;bl_03Lg=`1FEUH0CTi>04Y:BP12@T80@410059BDP0W9bL0
B4Q8065QH@0_;bl0GUiN04Q8B01LG5`0AdM705YJFP1EEED0E5AD05YJFP1?Cdl0EEEE03Xj>P1EEED0
I6AT06YZJP0m?Cd0;Bd]055AD@19BDT0MgMg04Y:BP0m?Cd0@41004A4A01>CTh09bLW04Q8B00T92@0
@D5103@d=01CDe<0?3`l075aL@1;Bd/0:b/[04];B`1:BTX0HF5Q08J6QP11@D40G5aL06MWI`1aLG40
KFe]04E5A@0o?cl0N7Qh06][J`1YJFT0@T9204A4A01BDU80Cdm?09:BTP020:JVYP2J07IfMP1KFe/0
EEEE05iNGP1CDe<0K6a/08Z:RP2ATI40=CDe05=CD`1XJ6P0;2`/07]kN`21PH40?3`l07YjNP0l?3`0
EEEE03De=@1IFET0P82002XZ:P13@d<0CTi>02PX:019BDT0F5QH030`<019BDT0?clo07EeM@1UIFD0
>SXj05EEE@0m?Cd0FUYJ04Y:BP1_Kfl0@D5103lo?`1@D500:b/[0492@P1GEeL0ADE504Y:BP1?Cdl0
9bLW08^;R`1jNWX0A4A405EEE@1?Cdl0FUYJ051@D00_;bl0ATI603Hf=P1lO7`0?Cdm051@D00[:b/0
XJ6Q07IfMP1BDU80YZJV08j>SP0W9bL0BTY:04i>CP0U9BD0D51@0451@@25QHD0KVi^06YZJP1OGel0
FUYJ055AD@11@D40CDe=04U9B@0g=cL0Hf=S04i>CP0D51@0CDe=04M7A`0g=cL0Q8B403<c<`1DE5@0
;bl_04a<C01MGEd04A4A05YJFP16ATH0AdM704a<C014A4@0CDe=03lo?`1CDe<0?clo05UIF@0f=SH0
A4A404e=C@1QHF40OWin06EUI@1jNWX0ZZZZ055AD@1OGel0OGem03hn?P0O7al0CTi>055AD@1lO7`0
IFEU069RHP2:RXX0=CDe055AD@1bLW80Kfm_08F5Q@1aLG40GEeM06i^KP1FEUH0Cdm?05MGE`17AdL0
GEeM05aLG01GEeL0@T9205EEE@1MGEd0C4a<05]KF`0o?cl0@41005iNGP1:BTX0F5QH04U9B@1BDU80
EUIF05=CD`;ooooo0000@`1VIVH0GUiN07YjNP26QXH0^;Rh04Y:BP15ADD0FUYJ07UiN@2?Shl0^;Rh
03hn?P12@T80D51@069RHP1mOGd0]kNg01`L7016ATH0GemO075aL@1GEeL0GUiN06IVIP0Z:RX0D51@
07MgM`1<C4`0=cLg05UIF@0f=SH0;bl_09BDU030`<00E5AD06MWI`1>CTh0:b/[02HV9P1bLW80QXJ6
02TY:@0O7al0>3Ph024Q8@1NGUh0Kfm_04=3@`0M7Ad0BDU904=3@`1KFe/0XZ:R06IVIP0K6a/0:BTY
04E5A@1JFUX0KVi^0:^[Z`0l?3`09bLW024Q8@1ADE40BDU907AdM02<S8`00P0X:2P0K@1>CTh0Kfm_
065QH@2GUiL0MGEe028R8P0m?Cd0CDe=06m_K`1UIFD0UIFE04I6AP0/;2`0<c<c079bLP1MGEd0ADE5
05mOG`0`<3009RHV04=3@`1TI6@0=cLg04I6AP2CTi<0@T92030`<01nOWh0Lg=c034a<@0d=3@0CDe=
030`<01?Cdl0K6a/04I6AP0M7Ad0<30`0492@P1@D500IFEU09:BTP0];Bd06a/K03Ph>01;Bd/0?3`l
07alO02h^;P0<30`010@4017AdL0G5aL055AD@2GUiL0K6a/02<S8`0H61P0FEUI07IfMP1RHV80Ogmo
0820P00`<300:2PX05EEE@1XJ6P0?3`l06UYJ@0j>SX09RHV05UIF@2FUYH0ADE505=CD`1PH600<30`
0410@01=CDd0MWIf04I6AP1IFET0FUYJ028R8P13@d<0Fe]K03lo?`13@d<0EEEE04a<C00Z:RX0O7al
02/[:`0/;2`0>SXj02l_;`16ATH0O7al07MgM`0U9BD0<C4a0492@P0_;bl0A4A40;2`/02SXj<09BDU
02d];@0m?Cd00P1EEED0k@2TY:@0IfMW02<S8`0Y:BT0DE5A06MWI`1IFET0/;2`04a<C00f=SH0CDe=
05MGE`1PH600QHF509:BTP0T92@0DE5A06QXJ01BDU80C4a<06e]K@1^KVh092@T03dm?@1EEED0JVYZ
04m?C`1aLG40>3Ph03Hf=P1JFUX0Ti>C02h^;P1;Bd/0=cLg02LW9`0e=CD0Lg=c05QHF00];Bd0EeMG
02HV9P1:BTX0C4a<04U9B@0X:2P0E5AD034a<@0Z:RX0V9RH08j>SP0R8R80BDU904M7A`1BDU80PX:2
06UYJ@0a<C40ADE505]KF`17AdL0YjNW07emO@0K6a/0;Bd]069RHP1^KVh0SHf=09FEU@0N7Qh0>SXj
06EUI@1eMGD0CDe=0:BTY01:BTX0@41005mOG`1NGUh0L71`07EeM@2][Jd0=SHf0492@P27QhL0YZJV
04e=C@1MGEd0TY:B030`<00X:2P0EeMG08J6QP1VIVH0ADE509NGU`0i>CT092@T04Y:BP2FUYH0MgMg
0451@@1YJFT0:RXZ02PX:01:BTX0IfMW03@d=010@400De=C03De=@10@400MgMg0820P00X:2P0BDU9
03Hf=P0c<c<0?clo07AdM01/K6`0;Bd]03lo?`0i>CT0?clo07EeM@2k^k/0E5AD01PH600k>c/0EUIF
03Lg=`1OGel0a/K607=cL`0K6a/0ADE506][J`0j>SX0AdM705EEE@18B4P0?3`l0451@@0k>c/0DU9B
03Ph>00W9bL0EEEE02DU9@0T92@0:RXZ061PH02?Shl0@d=304E5A@13@d<0Cdm?04a<C00o?cl0Cdm?
020P8016ATH0@41004I6AP1?Cdl0@d=30451@@16ATH09bLW03hn?P1JFUX0De=C03<c<`1:BTX0GemO
04I6AP11@D40?Shn04Y:BP1gMgL0CTi>03<c<`0m?Cd0=3@d02PX:00n?Sh0D51@06=SH`1EEED0=3@d
03Lg=`1WIfL0D51@02/[:`0];Bd0ADE506EUI@1FEUH0;Bd]01/K6`0f=SH0Bd];04U9B@1=CDd0CTi>
04Q8B01>CTh0F5QH05IFEP1@D500GemO06][J`1oOgl0K6a/04];B`17AdL0Ogmo03Ph>01ZJVX0ADE5
04A4A02SXj<0H61P05YJFP1`L700@D5104=3@`1RHV80CDe=05IFEP1HF5P0EeMG06EUI@1FEUH0?Cdm
04=3@`0203`l?01605]KF`1FEUH0F5QH05ADE011@D40GUiN02`/;01CDe<0IfMW03hn?P1XJ6P0D51@
05aLG01UIFD0J6QX05iNGP1OGel0IFEU05mOG`1`L700EUIF05YJFP1nOWh0FEUI061PH00i>CT0F5QH
0492@P16ATH0BTY:04U9B@13@d<0>c/k04Q8B00T92@0ADE50492@P1=CDd0>3Ph06ATI01;Bd/0Rh^;
071`L00k>c/0NGUi05mOG`22PX80V9RH04e=C@1eMGD0PH6109RHV02h^;P0O7al03lo?`1/K6`0Kfm_
08F5Q@14A4@0FUYJ061PH00m?Cd0Ti>C06=SH`1aLG40N7Qh08Z:RP1[Jf/0LG5a04i>CP80B4Q80780
G5aL0410@01MGEd0Cdm?02HV9P23Ph<0WinO04I6AP1?Cdl0D51@05mOG`1:BTX0EeMG08N7Q`0S8b<0
AdM704];B`0K6a/0C4a<05]KF`0d=3@0CDe=0451@@1OGel0HV9R03Ph>015ADD0<30`05ADE015ADD0
Hf=S01PH601PH600F5QH01/K6`0/;2`0AdM702h^;P1FEUH0LG5a03dm?@1iNGT0NWYj05mOG`25QHD0
G5aL04E5A@1=CDd0@D5104];B`0m?Cd0LW9b055AD@1XJ6P0ATI6069RHP15ADD0@d=306m_K`26QXH0
=cLg05]KF`1DE5@0@T9207YjNP1CDe<0MWIf07]kN`1eMGD0EUIF055AD@1VIVH0@D5105=CD`1QHF40
CTi>04];B`1OGel0=3@d06ATI014A4@0?clo061PH016ATH0Jf][04Y:BP1eMGD0LG5a03De=@1>CTh0
DE5A06YZJP1GEeL0D51@05IFEP18B4P0GEeM02TY:@1eMGD0?3`l0410@018B4P0Jf][08b<S01BDU80
PH6109^KV`0h>3P0L71`051@D016ATH0>3Ph04=3@`1ADE4205MGE`0604A4A01GEeL0GemO06=SH`1e
MGD0ADE50`1NGUh05021PH40<c<c06=SH`1QHF40@d=304e=C@0l?3`0Kfm_03Ti>@0m?Cd0:RXZ04U9
B@1TI6@0ATI604e=C@1MGEd0Bd];059BDP1SHf<0GUiN0P1JFUX2ooooo`0004l0Ph>307YjNP26QXH0
AdM708b<S023Ph<0EeMG07]kN`0h>3P0?clo092@T01DE5@0@41004i>CP16ATH0CTi>07inOP0m?Cd0
8b<S04Y:BP1BDU80Bd];05MGE`1nOWh0:b/[02h^;P1[Jf/0CDe=05eMG@2HV9P0<30`018B4P0`<300
Fe]K04U9B@2GUiL0ZJVY020P800b<S80ADE505mOG`1BDU80IVIV07AdM0092@T08B4Q03lo?`1fMWH0
AdM70:b/[00m?Cd07AdM04M7A`1TI6@0=CDe051@D01DE5@06a/K02d];@0g=cL0IfMW02XZ:P1=CDd0
>3Ph01lO7`0d=3@0FUYJ03`l?00a<C40D51@02@T900Q8B40Fe]K08b<S00];Bd0;2`/04U9B@0_;bl0
=3@d0080KVi^05P0820P03Hf=P0/;2`0=cLg065QH@1gMgL0=cLg02@T900^;Rh0ADE50410@027QhL0
T92@02PX:00b<S80ADE5065QH@17AdL0[:b/07inOP0^;Rh0<c<c065QH@1JFUX0DE5A0:6QX@1oOgl0
5ADE0451@@1HF5P0EeMG04I6AP2=SHd0ADE5020P8012@T80Kfm_06a/K01=CDd0Cdm?02LW9`0U9BD0
K6a/0:2PX019BDT0;Bd]05eMG@0e=CD0;Bd]051@D01ZJVX0B4Q803/k>`1EEED0=3@d05ADE01gMgL0
Q8B4030`<00^;Rh0G5aL03Lg=`1>CTh0Ogmo02h^;P0P8200@41003`l?00c<c<0PH610:2PX00Z:RX0
;2`/05QHF01=CDd0HF5Q092@T01bLW80;Rh^06MWI`1JFUX0A4A409>CT`0T92@07AdM055AD@1[Jf/0
=SHf0P1GEeL0D@0I6AT06a/K05]KF`2RXZ80>c/k04U9B@1cLg<07AdM02DU9@1QHF40SXj>04];B`1R
HV80DU9B02<S8`13@d<0EEEE06IVIP0`<300CTi>05IFEP0S8b<0?clo08V9R@1SHf<0<S8b0451@@12
@T80CTi>07EeM@1TI6@08R8R02DU9@12@T80G5aL05QHF021PH40@T9201XJ6P0d=3@0AdM7055AD@2K
Vi/0KFe]01/K6`0d=3@0?clo06ATI01HF5P0Zj^[0410@00b<S80EUIF04U9B@1>CTh0KFe]03Ph>00G
5aL0ATI608B4Q016ATH0TI6A02DU9@0Z:RX0De=C04m?C`0l?3`0QXJ606IVIP0M7Ad0<C4a05YJFP17
AdL0E5AD05=CD`0V9RH0A4A4069RHP13@d<0@D51075aL@0203<c<`2G06ATI01jNWX0<C4a0451@@1O
Gel0<c<c05UIF@24Q8@0MWIf0410@01;Bd/0GEeM03dm?@1kNg/0Xj>S03lo?`0R8R80=SHf04];B`12
@T80QhN709jNWP1JFUX09BDU02d];@0h>3P0HF5Q08n?S`2OWil0?Shn02@T901BDU80Jf][04I6AP2A
TI40NGUi02TY:@0V9RH0DE5A08R8R015ADD0[Jf]07]kN`0X:2P0:BTY05aLG01hN7P0Kfm_09:BTP1m
OGd092@T03Lg=`1hN7P0Q8B4030`<00o?cl0FUYJ028R8P0S8b<0@T9206m_K`0g=cL0?clo02/[:`0U
9BD0BTY:05IFEP16ATH0>SXj061PH00m?Cd0FUYJ03/k>`0_;bl0K6a/02@T9010@400>SXj05ADE01U
IFD0>3Ph07AdM01HF5P0Lg=c055AD@19BDT0Jf][028R8P1HF5P0<C4a03dm?@1:BTX0F5QH01dM7@17
AdL0?Cdm05iNGP1UIFD0G5aL03Ti>@1cLg<0NGUi06][J`19BDT0KVi^07]kN`1NGUh0K6a/03<c<`0W
9bL0?3`l03hn?P1HF5P0@D5103Xj>P1GEeL0;bl_030`<00j>SX0CTi>028R8P0d=3@0CDe=030`<00d
=3@0>c/k02TY:@0m?Cd0Cdm?04a<C00Y:BT0;Bd]051@D01UIFD0ADE503De=@17AdL0JVYZ05eMG@0n
?Sh0DE5A05MGE`1LG5`0EeMG05iNGP1^KVh0DE5A061PH01dM7@0;bl_01dM7@0204e=C@1Z04i>CP11
@D40<C4a04];B`14A4@0=SHf04U9B@1BDU80=SHf02d];@0/;2`0DE5A04Y:BP0j>SX0ADE504i>CP0Y
:BT0=cLg02DU9@1ADE40ADE502HV9P10@400De=C04U9B@0m?Cd0Cdm?07=cL`1IFET0I6AT07IfMP2>
SXh0F5QH06YZJP1^KVh0EeMG04Q8B012@T80L71`03dm?@1IFET0HF5Q07emO@1OGel0@T9205]KF`0T
92@0GemO02XZ:P1=CDd0>SXj06=SH`0o?cl0E5AD05UIF@0d=3@0Fe]K0492@P1ADE40HF5Q05=CD`1j
NWX0MGEe06UYJ@1HF5P0G5aL0410@01@D500FUYJ08V9R@1>CTh0@T920410@014A4@0c/k>08^;R`1k
Ng/0PH6108^;R`1:BTX0Ti>C05MGE`1SHf<0KFe]09JFUP1EEED0LG5a071`L01:BTX0H61P06UYJ@18
B4P0EUIF0410@01LG5`0De=C05EEE@2;Rh/0AdM706i^KP1/K6`0@T9204U9B@1IFET0Hf=S07UiN@80
Hf=S07/0IVIV051@D01OGel0>CTi05ADE01BDU80G5aL02@T901JFUX0Hf=S02TY:@0g=cL0B4Q8030`
<01ADE40Jf][04a<C02ATI40MWIf04Q8B01EEED0DE5A079bLP1IFET0?3`l05]KF`0_;bl0P82004=3
@`1SHf<0@D5109VIV@1cLg<0DE5A07MgM`1^KVh0<c<c05ADE01GEeL0?3`l05IFEP1BDU80T92@05eM
G@1RHV80LG5a055AD@1?Cdl0@T9204m?C`1FEUH0@d=305EEE@1@D500=3@d075aL@1UIFD0?clo05mO
G`0V9RH0De=C03Ph>01`L700T92@01DE5@1ADE40ADE506e]K@1?Cdl0?3`l05IFEP1<C4`0D51@04E5
A@1DE5@0?3`l05=CD`1EEED0C4a<03lo?`1=CDd0IFEU07IfMP1MGEd0^;Rh07EeM@25QHD0KVi^06AT
I01PH600Hf=S05mOG`1lO7`0WinO05mOG`1SHf<0IfMW065QH@2MWId0NWYj06=SH`1QHF40?clo04=3
@`11@D40@41004e=C@0b<S80AdM704I6AP0l?3`0?Cdm05YJFP1RHV80;bl_04m?C`2g]kL0Fe]K05UI
F@1YJFT0G5aL061PH01eMGD00_ooool0000k07alO02b/[80TI6A04Q8B01TI6@0Vi^K09BDU03;bl/0
?Shn04U9B@1=CDd0FUYJ08b<S028R8P0=3@d04Y:BP1>CTh0EeMG05eMG@1lO7`0C4a<02PX:00l?3`0
DU9B04a<C01ZJVX0T92@02LW9`0_;bl0KFe]09:BTP1GEeL0IfMW06UYJ@0^;Rh0;2`/05aLG011@D40
>SXj05UIF@0];Bd0<S8b03/k>`1XJ6P0FEUI02d];@10@400;bl_03<c<`1@D500C4a<020P800e=CD0
Bd];04Y:BP1PH600[Zj^03dm?@0^;Rh00P1<C4`0@@1JFUX0Q8B408Z:RP0H61P0>c/k05eMG@1HF5P0
FEUI08R8R00];Bd0410@04e=C@26QXH0Ng]k06YZJP2LW9`07QhN01<C4`0_;bl0EUIF03De=@1KFe/0
FEUI014A4@0^;Rh0>SXj05]KF`0X:2P0EeMG06QXJ00Q8B4092@T05IFEP1QHF40;bl_07EeM@16ATH0
7QhN03Ti>@1]KFd06QXJ02LW9`1EEED0<S8b01`L701OGel0S8b<02l_;`0j>SX0BDU902DU9@0f=SH0
Ogmo08^;R`0G5aL0>c/k04A4A01LG5`0M7Ad0;bl_016ATH0410@03Lg=`1UIFD0JVYZ0080HV9R00`0
:b/[01TI6@0m?Cd0IVIV059BDP1dM7@0VIVI02PX:00];Bd0CTi>05mOG`1BDU8207AdM02D02LW9`0h
>3P0Lg=c06a/K00k>c/0MWIf01XJ6P0^;Rh0C4a<075aL@15ADD0GUiN05EEE@0G5aL0@D5105eMG@28
R8P0G5aL07MgM`16ATH0EUIF08R8R01VIVH0;2`/05ADE012@T80CDe=05IFEP26QXH0:BTY01/K6`1C
De<0I6AT05QHF01TI6@0XJ6Q038b<P0I6AT0@T9205IFEP0i>CT0O7al09NGU`0M7Ad0=3@d05MGE`1I
FET0B4Q808n?S`2JVYX09BDU0492@P1<C4`0F5QH065QH@23Ph<09RHV024Q8@12@T80JVYZ06ATI01b
LW80Ng]k01`L700U9BD0F5QH06a/K00k>c/0M7Ad04U9B@0Q8B40?clo07QhN011@D40FUYJ03dm?@0Q
8B40<S8b07=cL`1gMgL0?3`l059BDP0K6a/0<c<c09JFUP1gMgL0=CDe05=CD`0Z:RX0EUIF07QhN01W
IfL0<C4a05IFEP13@d<0>c/k0;6a/@33`l<0<S8b03hn?P1IFET0?Cdm08:2PP2d];@0>c/k02d];@1Q
HF40EUIF07QhN02o_kl0:BTY02<S8`1KFe/0SXj>05MGE`1]KFd0PH6103Xj>P1SHf<0M7Ad06QXJ013
@d<0Ng]k07AdM00V9RH0<S8b09bLW01/K6`0B4Q806a/K01<C4`0>CTi02l_;`1nOWh0Ph>303lo?`1A
DE40EUIF03Hf=P1>CTh0UiNG07inOP1>CTh0Hf=S0492@P0`<300=3@d07QhN080DE5A02H0C4a<02TY
:@0/;2`0@d=307QhN018B4P0=cLg059BDP0Z:RX0<S8b0492@P22PX80>c/k03De=@0d=3@0C4a<071`
L02BTY80Lg=c02h^;P0Y:BT0CDe=03`l?017AdL0Vi^K08F5Q@0Q8B40EeMG06YZJP1NGUh0@d=3059B
DP14A4@0EEEE0451@@19BDT0MgMg03Ph>080:RXZ0?l0CTi>06i^KP1GEeL0CTi>0451@@1JFUX0Cdm?
04i>CP1NGUh0Cdm?04i>CP18B4P0ATI604i>CP1FEUH0;bl_04m?C`0Y:BT0@D5105]KF`1DE5@0CTi>
065QH@1^KVh0I6AT06i^KP1]KFd0KVi^09JFUP1VIVH0?3`l03dm?@1=CDd0EeMG065QH@1>CTh0Fe]K
06EUI@11@D40>3Ph05]KF`1[Jf/0;2`/05eMG@1OGel0ATI605=CD`1;Bd/0;2`/05YJFP18B4P0AdM7
03lo?`0c<c<0Fe]K04];B`1IFET0=cLg04e=C@1JFUX0Q8B404=3@`1YJFT0=3@d03De=@1eMGD0?3`l
04Q8B00l?3`0;Bd]05iNGP0g=cL0:b/[06=SH`0_;bl0<30`04m?C`12@T80CTi>03dm?@14A4@0EEEE
03Lg=`19BDT0=SHf02l_;`0];Bd0E5AD04Y:BP1>CTh0@d=30492@P1<C4`07AdM02l_;`1MGEd08B4Q
04e=C@0i>CT0DE5A04Y:BP1BDU80AdM7051@D01>CTh0BTY:04a<C00k>c/0C4a<06UYJ@1gMgL0ADE5
03<c<`1CDe<0Fe]K07MgM`1DE5@0?Shn04Y:BP11@D40De=C03De=@1JFUX09BDU05=CD`1>CTh0WIfM
04Y:BP2GUiL0IfMW03@d=023Ph<0CDe=092@T02[Zj/0D51@08V9R@2JVYX0Y:BT0;bl_01eMGD0C4a<
07alO01bLW80TY:B055AD@19BDT0GEeM05UIF@1hN7P0Ph>3092@T025QHD0QhN705=CD`1=CDd0A4A4
05MGE`1VIVH0NGUi05eMG@2_[jl0NWYj01@D501bLW80U9BD05=CD`1LG5`0JVYZ06MWI`1UIFD0@T92
07alO00g=cL0?Shn05EEE@0Y:BT0ADE504U9B@15ADD0D51@05IFEP1<C4`0GUiN0410@015ADD0:b/[
04Q8B01CDe<0LG5a03/k>`1UIFD0GEeM02XZ:P17AdL0E5AD051@D01EEED0GUiN030`<02BTY80P820
059BDP1IFET0?Cdm06e]K@1[Jf/0B4Q804e=C@0k>c/0IfMW03hn?P1CDe<0<S8b08J6QP1KFe/0=CDe
075aL@1SHf<05ADE05UIF@1JFUX0<30`05=CD`0m?Cd0L71`05UIF@1EEED0F5QH051@D016ATH0>CTi
065QH@1OGel0A4A407EeM@1^KVh09RHV059BDP1>CTh0=CDe07inOP0e=CD0FEUI03/k>`0o?cl0FUYJ
02TY:@18B4P0?Cdm079bLP1YJFT0F5QH07=cL`1;Bd/001X0I6AT03@d=01WIfL0?Shn03dm?@0b<S80
JFUY07EeM@0h>3P0>SXj051@D015ADD0IFEU069RHP2QXJ40LW9b04A4A013@d<0De=C05MGE`10@400
DU9B01/K6`10@400IFEU04Q8B080H61P01L0De=C0820P00b<S80BDU903`l?00b<S80BDU903Hf=P1J
FUX0>CTi04a<C01>CTh0NGUi07moO`14A4@0E5AD0;Jf]P1;Bd/0Fe]K06EUI@1HF5P0Rh^;06QXJ002
ooooo`000?l0MGEe04m?C`1oOgl0G5aL09NGU`0j>SX0C4a<05iNGP1TI6@0HV9R09ZJVP0i>CT0<30`
07QhN01SHf<0H61P07=cL`11@D40@d=305mOG`1`L700<30`04U9B@14A4@0>SXj04U9B@27QhL0=cLg
02TY:@1ADE40:RXZ05eMG@2MWId0K6a/02LW9`0h>3P0GemO03Ti>@1:BTX0XJ6Q08N7Q`0O7al0<C4a
030`<00l?3`0Cdm?09VIV@0b<S80=3@d05MGE`1=CDd0?Cdm06e]K@1CDe<05ADE03@d=01DE5@0Jf][
05UIF@23Ph<0;bl_02DU9@16ATH0Kfm_04U9B@1=CDd0=3@d02PX:01;Bd/0JFUY06e]K@0V9RH0GUiN
04A4A00Z:RX0ADE5075aL@1TI6@092@T05]KF`0c<c<0>CTi06QXJ01gMgL07alO02<S8`18B4P0@410
04U9B@1CDe<0Jf][01dM7@0^;Rh0>c/k04I6AP0o?cl0Shn?06UYJ@0R8R80?clo051@D00o?cl0DU9B
0:NWY`17AdL071`L04e=C@1;Bd/0<c<c07emO@2MWId08R8R03@d=00c<c<0GUiN03`l?01aLG40D51@
01/K6`0k>c/0@D5106e]K@13@d<0JVYZ04U9B@0M7Ad0<c<c07EeM@1KFe/0;Bd]04Q8B01CDe<07alO
04];B`2KVi/0BTY:03dm?@1DE5@0:b/[028R8P1@D500Rh^;03hn?P0];Bd0?3`l02h^;P1ZJVX0T92@
03`l?00O7al0;bl_03hn?P0c<c<0T92@0:^[Z`0G5aL09bLW03<c<`16ATH0I6AT0:BTY00L71`0A4A4
05EEE@1?Cdl0=SHf08N7Q`1XJ6P08R8R03dm?@2FUYH0N7Qh05]KF`2a/K40Hf=S0492@P1EEED0PH61
08R8R012@T80O7al04m?C`0`<300EEEE09JFUP1ZJVX0CTi>07]kN`0a<C40>c/k06MWI`2;Rh/0G5aL
05EEE@1hN7P0:BTY04Y:BP1GEeL0IFEU038b<P1=CDd0?Shn03Hf=P1EEED0RXZ:02l_;`0f=SH0BDU9
04=3@`11@D40XZ:R09>CT`0V9RH0A4A404Q8B00d=3@0TY:B06=SH`0L71`0<c<c05UIF@12@T80B4Q8
07alO00O7al051@D05IFEP1MGEd0>SXj07YjNP0O7al0>CTi05MGE`1VIVH0Bd];079bLP14A4@08b<S
06][J`2l_;`0D51@08>3P`1OGel09RHV03dm?@27QhL0Kfm_04I6AP12@T80;Rh^04Q8B01aLG40G5aL
03@d=01XJ6P006`0>c/k04=3@`1^KVh0KFe]03Xj>P0d=3@0G5aL04I6AP1@D500MgMg07inOP0i>CT0
?3`l05MGE`0_;bl0AdM7075aL@1OGel07alO02TY:@13@d<0E5AD05eMG@1fMWH0N7Qh01dM7@0b<S80
@41005iNGP1>CTh0Vi^K0451@@0/;2`0E5AD04Y:BP1KFe/0Rh^;09>CT`0Z:RX0?clo06YZJP1WIfL0
FUYJ05EEE@2;Rh/0=cLg028R8P0o?cl0IVIV04A4A01FEUH0GUiN02/[:`0S8b<0C4a<07IfMP1LG5`0
BTY:06IVIP0[:b/0820P04A4A02;Rh/0ADE5055AD@1OGel0Bd];04Y:BP1OGel0AdM705ADE00f=SH0
=3@d07alO00Q8B40@D5104I6AP1QHF40TY:B06MWI`1eMGD0BDU9096AT@1aLG40BDU906UYJ@0R8R80
GUiN03Xj>P16ATH0DE5A06ATI014A4@0@T9204Y:BP1@D500K6a/05EEE@0k>c/0De=C06IVIP1NGUh0
?3`l04a<C01LG5`0Fe]K05aLG00_;bl203@d=005038b<P16ATH0B4Q804I6AP1<C4`00P0f=SH03P13
@d<0C4a<03<c<`0a<C40@41005EEE@1;Bd/0>SXj03Lg=`1@D500CDe=04a<C01BDU80Cdm?0P1CDe<0
`@1FEUH0C4a<04i>CP1HF5P0Ng]k06i^KP1kNg/0A4A404E5A@1[Jf/0D51@06=SH`1BDU80@D5106a/
K01EEED0@D5106m_K`1@D500A4A405ADE013@d<0@D510492@P1EEED0Bd];04E5A@17AdL0CTi>04a<
C00`<300Bd];051@D01?Cdl0B4Q80451@@1BDU80<C4a03lo?`1IFET0?clo05QHF01ADE40EUIF061P
H01QHF40H61P05eMG@1NGUh0Fe]K06YZJP1BDU80A4A407]kN`17AdL0@d=303<c<`1PH600Cdm?04=3
@`19BDT0BTY:055AD@18B4P0BTY:020P800o?cl0Bd];059BDP0[:b/0Bd];0451@@2PX:00I6AT02h^
;P1DE5@0>CTi04m?C`1OGel0=CDe05eMG@1DE5@0EEEE061PH019BDT0<c<c0492@P1kNg/0MgMg04E5
A@1HF5P0FEUI02l_;`1oOgl0B4Q805ADE01UIFD0Jf][04I6AP1oOgl0Cdm?07IfMP2;Rh/0N7Qh04A4
A019BDT0FUYJ01dM7@1`L700PH6105UIF@2_[jl0Fe]K05YJFP1mOGd0Lg=c0:n_[`1BDU80F5QH07=c
L`0o?cl0GUiN05QHF00k>c/0L71`05iNGP0l?3`0EUIF0410@01CDe<09bLW05UIF@1PH600NGUi03dm
?@1UIFD0FEUI04=3@`0`<300>3Ph0451@@1<C4`0IVIV04A4A022PX80O7al06=SH`2;Rh/0?clo051@
D01ADE40ATI6061PH00S8b<0EeMG04M7A`1oOgl0<C4a07QhN01LG5`0>3Ph08f=S@1kNg/04Q8B04A4
A01ADE40CDe=09NGU`1]KFd0Z:RX06e]K@1iNGT0JFUY05UIF@1DE5@0BTY:05eMG@1;Bd/0=SHf03`l
?018B4P051@D05]KF`1=CDd0=3@d06ATI00_;bl0GemO02/[:`1SHf<0PH6102DU9@1^KVh00P1ADE40
200k>c/0DE5A06ATI01EEED0ADE505YJFP24Q8@0Bd];0P15ADD0;@0o?cl0?Cdm030`<01GEeL0M7Ad
03<c<`0i>CT0A4A4075aL@0_;bl0A4A404U9B@1eMGD0N7Qh059BDP1eMGD0;Rh^06YZJP2>SXh0@D51
07emO@1EEED0NGUi09nOW`0o?cl0CDe=03Hf=P14A4@0EUIF034a<@1<C4`08b<S03`l?00g=cL0R8R8
07]kN`0j>SX0EUIF0:6QX@1BDU80EeMG05aLG01<C4`0De=C065QH@02ooooo`0002T0KFe]055AD@1H
F5P0Fe]K0:VYZ@1LG5`0Cdm?06EUI@1]KFd0T92@0<g=c@11@D40@T9204Q8B01;Bd/0Ogmo08V9R@0U
9BD0?Shn07YjNP21PH40BDU907IfMP1WIfL0820P03`l?01jNWX0KVi^05mOG`2ZZZX08B4Q01TI6@13
@d<0I6AT05QHF01oOgl0Xj>S038b<P0K6a/0>SXj07YjNP0205YJFP1c055AD@0P82007alO05MGE`1f
MWH0ADE5065QH@0f=SH0:BTY06YZJP2<S8`09bLW04A4A016ATH08R8R02h^;P2ATI40CDe=01/K6`0h
>3P0Bd];02`/;01YJFT0Kfm_02<S8`0h>3P0C4a<07QhN00b<S80LW9b0820P00H61P0@T92055AD@1`
L700EUIF0:^[Z`1BDU807alO04=3@`1RHV80EUIF069RHP2RXZ80:2PX02HV9P0g=cL0BTY:03Hf=P1F
EUH0PX:201@D500[:b/0<c<c06EUI@1;Bd/0GEeM06MWI`0J6QX0:2PX04A4A01SHf<0;bl_055AD@14
A4@09bLW04U9B@1RHV80B4Q803<c<`1KFe/0<30`051@D01OGel0NGUi02XZ:P0k>c/0Cdm?02/[:`1=
CDd0XJ6Q04e=C@0T92@0?3`l04M7A`1:BTX0?clo096AT@1`L700;bl_02PX:01@D500EeMG05iNGP2H
V9P0>3Ph01LG5`0d=3@0GUiN06m_K`1UIFD0MWIf01XJ6P0R8R80CDe=06e]K@0_;bl0Jf][06a/K00a
<C40>3Ph05YJFP1ADE40?Cdm07EeM@0202l_;`1>08n?S`1WIfL0<S8b051@D00W9bL07QhN05EEE@23
Ph<0;2`/03@d=012@T80=SHf03/k>`1/K6`0S8b<02@T900_;bl0EEEE03Lg=`1YJFT0YJFU06QXJ00Q
8B40>c/k04];B`0o?cl0Ng]k0<71`@1ADE408B4Q03Hf=P1HF5P0Bd];0861P@2g]kL0:b/[04a<C019
BDT0C4a<05MGE`1SHf<0E5AD01`L701FEUH0I6AT04Q8B01GEeL0PX:204=3@`0k>c/0EeMG092@T01I
FET0Jf][04M7A`0Y:BT0BTY:06a/K012@T80I6AT07EeM@0];Bd0?clo079bLP11@D40>SXj08:2PP0g
=cL0;Rh^07AdM00j>SX092@T04a<C00f=SH0>CTi08n?S`1bLW808R8R0P11@D40900g=cL0CDe=08Z:
RP13@d<0@T9204A4A01?Cdl0TI6A061PH00T92@0=SHf05mOG`1FEUH0Hf=S0;Jf]P1KFe/07alO05QH
F01jNWX0EEEE07UiN@3:b/X0@41002/[:`1MGEd0MGEe03hn?P1^KVh0Z:RX03Hf=P0Q8B40EeMG09:B
TP1<C4`0P82009RHV080ADE506<0KFe]09>CT`19BDT0J6QX06YZJP0_;bl0<c<c08^;R`2QXJ40>CTi
06QXJ01iNGT0;Bd]04M7A`23Ph<0TY:B02TY:@19BDT0=CDe030`<010@400SHf=05iNGP0S8b<0;bl_
04e=C@0];Bd0FUYJ05mOG`0m?Cd09BDU03Lg=`1=CDd0=CDe079bLP29RHT0ATI602LW9`0a<C40DU9B
0492@P1GEeL0HV9R055AD@0h>3P0A4A403Ti>@1EEED0<c<c02`/;01KFe/0:BTY05mOG`1`L700E5AD
07QhN01FEUH0Lg=c04m?C`1iNGT0Cdm?04];B`1SHf<092@T04e=C@0f=SH0@D5105IFEP1KFe/06a/K
04=3@`0Z:RX0EeMG05iNGP1MGEd0?clo07moO`1^KVh0MgMg069RHP1cLg<0NGUi06IVIP1^KVh0;Bd]
02HV9P0Z:RX0>SXj06EUI@1@D500De=C07emO@1<C4`0D51@04U9B@1VIVH0;Rh^051@D01UIFD00P12
@T802015ADD0:2PX04i>CP1;Bd/0@41003Ph>00[:b/0De=C0P1;Bd/0800/;2`0@d=304e=C@1CDe<0
=3@d055AD@1<C4`0BTY:07IfMP0e=CD0DE5A05aLG015ADD0QHF503`l?00S8b<0HF5Q04E5A@0l?3`0
D51@03/k>`1=CDd0DE5A03/k>`1BDU80@41004a<C00`<300:RXZ02/[:`1CDe<0DE5A0P16ATH203hn
?P0801TI6@0a<C40Bd];02<S8`0n?Sh0@41004E5A@10@40204U9B@0I04Q8B01>CTh0EeMG06UYJ@1L
G5`0De=C06i^KP1LG5`0FUYJ05aLG01fMWH0K6a/05YJFP1TI6@0NGUi07=cL`0];Bd0HF5Q03Lg=`1E
EED08b<S055AD@0n?Sh0Ng]k051@D00207inOP1<03dm?@29RHT0GemO071`L02TY:@0HF5Q06EUI@1c
Lg<0Ng]k06YZJP1nOWh0>3Ph05YJFP1=CDd0GemO05ADE01<C4`0BDU903hn?P2OWil0M7Ad09JFUP1g
MgL0IVIV0410@01>CTh0AdM703`l?01;Bd/0OWin061PH022PX80Rh^;024Q8@21PH40QHF503Ti>@1<
C4`0B4Q805UIF@1WIfL0@41006EUI@0n?Sh0H61P06UYJ@0h>3P0MWIf075aL@1UIFD0Ph>304U9B@27
QhL0JFUY03Ph>01@D500>3Ph079bLP1?Cdl0Ph>306][J`27QhL0P82003Xj>P0n?Sh0B4Q803Ti>@1V
IVH0SHf=04a<C02>SXh0Ng]k04Q8B017AdL0A4A405]KF`80DE5A0680E5AD04A4A01JFUX0?clo04i>
CP1@D500Ogmo06UYJ@12@T80Cdm?05aLG00o?cl0Bd];05=CD`12@T80Bd];05ADE02<S8`0ATI6051@
D01MGEd0ATI604E5A@0n?Sh0BDU906IVIP1QHF40D51@05QHF00e=CD0PX:207alO019BDT0MgMg03De
=@1aLG40C4a<071`L020P800<S8b05ADE01EEED0R8R8096AT@1mOGd0KFe]075aL@2ATI40>c/k07]k
N`15ADD0I6AT04i>CP1BDU80LW9b04A4A010@400AdM703<c<`1>CTh0FEUI07=cL`1QHF40IFEU0492
@P16ATH0EEEE04];B`1aLG407alO04U9B@1PH600EEEE0:BTY01>CTh0D51@07=cL`1?Cdl0MGEe04E5
A@0h>3P0BTY:04U9B@1hN7P0@d=304i>CP0T92@0ATI6055AD@1@D500BTY:08b<S01:BTX0FUYJ04a<
C018B4P0H61P07=cL`;ooooo0000o`2NWYh0Xj>S06ATI01<C4`0E5AD071`L01dM7@0Ph>303`l?01P
H600[Zj^08:2PP1:BTX0KFe]04A4A01BDU80IFEU06=SH`0/;2`0IFEU05ADE00h>3P0Cdm?055AD@0e
=CD0D51@05iNGP0K6a/0@T9209ZJVP1RHV808B4Q075aL@0f=SH09RHV06][J`2RXZ80CTi>02LW9`1>
CTh0>3Ph06i^KP2QXJ40KFe]02h^;P0Q8B40?3`l04M7A`1EEED0ZJVY03De=@0F5QH0;Rh^08>3P`1c
Lg<0QhN709VIV@0O7al08B4Q03/k>`1NGUh0>SXj08j>SP10@400:b/[03Ti>@1RHV80A4A404Y:BP1T
I6@06ATI03Xj>P1;Bd/0KFe]0451@@1/K6`0RXZ:02LW9`0^;Rh0FEUI06e]K@0i>CT0?3`l03Lg=`0N
7Qh0>SXj05EEE@19BDT09RHV051@D00e=CD0=cLg04i>CP24Q8@0@D51024Q8@1FEUH0>3Ph04m?C`1n
OWh0U9BD01HF5P0V9RH0ADE505mOG`1GEeL0U9BD06YZJP0E5AD0C4a<04Q8B01IFET0D51@09>CT`0o
?cl0:2PX03/k>`17AdL0FEUI06MWI`1dM7@07alO01/K6`0];Bd0MWIf0451@@1UIFD0HV9R01/K6`0[
:b/0>SXj07MgM`1JFUX0GemO04];B`0S8b<0@d=305UIF@1bLW80ADE5069RHP10@400=SHf05]KF`1J
FUX0BTY:03Ph>01eMGD0<c<c0451@@1UIFD0JFUY01`L700f=SH0ATI604Y:BP1MGEd0QXJ6059BDP0/
;2`0?Cdm06QXJ020P800^[Zj02`/;00W9bL0;bl_05MGE`13@d<0N7Qh09jNWP0J6QX0<C4a03lo?`19
BDT0E5AD06UYJ@2GUiL0;2`/01hN7P11@D40I6AT0451@@1lO7`0CDe=024Q8@0e=CD0Fe]K07inOP0f
=SH0F5QH03@d=00P8200?Cdm05iNGP1FEUH0=CDe05eMG@0D51@0=SHf069RHP1NGUh0:2PX0492@P1T
I6@07alO05=CD`2IVIT0LW9b02TY:@1[Jf/0@D5103lo?`2NWYh0UIFE02DU9@12@T80J6QX03Lg=`22
PX80^[Zj03/k>`0f=SH0MGEe05eMG@14A4@0[jn_03dm?@0Z:RX0EEEE04U9B@1nOWh0Shn?02`/;00V
9RH0IVIV08j>SP22PX80WinO04];B`0W9bL0A4A407AdM01DE5@0UYJF065QH@0Q8B40De=C09>CT`1a
LG40>SXj06ATI00Q8B40=CDe079bLP00L`1gMgL0@D5107alO01RHV80;Bd]04Q8B02HV9P0P82004=3
@`1TI6@0D51@03`l?01MGEd0Vi^K05iNGP10@400BTY:03Lg=`0d=3@0BTY:092@T01=CDd0:b/[04U9
B@0i>CT08R8R051@D02g]kL0G5aL03Hf=P1:BTX0EUIF04i>CP1bLW80VYZJ03Ph>00b<S80BTY:06MW
I`1aLG40VYZJ04A4A00T92@0=CDe06=SH`2CTi<0IFEU08N7Q`1LG5`0@D51055AD@1UIFD0Hf=S04Y:
BP1YJFT0HV9R01`L700/;2`0NWYj071`L011@D40GEeM0451@@0Q8B40HV9R07alO01VIVH0AdM704a<
C016ATH0IFEU065QH@1CDe<0Kfm_03dm?@1MGEd0?Shn04e=C@1fMWH0F5QH07IfMP1_Kfl0KFe]05=C
D`1@D500N7Qh04m?C`1VIVH0De=C05iNGP1MGEd0I6AT030`<01EEED0<C4a05IFEP1`L700Hf=S05QH
F01_Kfl0DU9B05eMG@10@400K6a/08N7Q`1oOgl0KVi^04=3@`0[:b/0:2PX04A4A01UIFD0?clo04m?
C`22PX800P12@T80;@19BDT0C4a<01`L7010@400BTY:03lo?`11@D40B4Q804Y:BP1LG5`0AdM704=3
@`1<C4`0@d=3065QH@1JFUX0G5aL03Ti>@1=CDd0DU9B08N7Q`10@400Kfm_04M7A`14A4@0Ogmo03`l
?019BDT0Jf][0492@P1MGEd0?Shn02/[:`1`L700@d=303`l?01VIVH0@D510492@P10@400=SHf04Y:
BP12@T80A4A403/k>`0202l_;`0B04Y:BP19BDT0FEUI05EEE@18B4P0FUYJ02d];@0a<C40GemO03dm
?@1OGel0CDe=04m?C`0n?Sh0IfMW05=CD`1EEED0DE5A0P1EEED0a`0m?Cd0>CTi05=CD`1CDe<0AdM7
03Ti>@1EEED0Fe]K05YJFP1@D500@D5104m?C`0];Bd0CDe=03`l?01EEED0>CTi05eMG@0g=cL0RHV9
06EUI@2b/[80O7al05IFEP2@T900G5aL07AdM02ATI40GUiN0;2`/02/[:`0M7Ad069RHP1PH600DU9B
06YZJP1EEED0EeMG03<c<`0n?Sh0EEEE04E5A@1jNWX0L71`08V9R@1lO7`0Ph>305ADE01?Cdl0G5aL
061PH01aLG40IfMW04e=C@2@T900Ogmo02/[:`1KFe/0O7al04a<C02FUYH0F5QH06UYJ@1TI6@0D51@
0:FUY@17AdL0LG5a071`L00d=3@0Ogmo05aLG00m?Cd0De=C051@D01LG5`0KVi^05=CD`1QHF409RHV
051@D018B4P0MGEe04m?C`17AdL0ADE503Hf=P11@D40De=C0451@@0n?Sh0FUYJ02PX:02_[jl0SXj>
051@D01LG5`0>c/k0861P@1dM7@0@D5106=SH`0/;2`0SHf=0451@@1QHF40E5AD08n?S`2ATI40FUYJ
07inOP1kNg/061PH05YJFP1`L700>SXj069RHP18B4P0];Bd061PH01LG5`0LW9b05iNGP1IFET0>SXj
05IFEP1<C4`0EeMG059BDP1LG5`08b<S04I6AP1DE5@0=CDe07YjNP0X:2P0HV9R030`<01VIVH0QHF5
02DU9@1aLG40?3`l04I6AP0k>c/0=cLg04a<C00d=3@0>CTi02l_;`1JFUX0;Bd]03De=@0d=3@0>3Ph
04A4A00X:2P0<C4a051@D00f=SH0ADE50410@017AdL0?Cdm0451@@1:BTX0P82007QhN01iNGT0ZZZZ
0451@@2:RXX0TI6A06][J`2`/;00Lg=c0:>SX`2XZ:P0@D5104A4A00o?cl0C4a<06ATI00];Bd0@T92
02HV9P1=CDd0?Shn059BDP1;Bd/0<c<c04=3@`1_Kfl0@41004i>CP1<C4`0Bd];07alO01HF5P00_oo
ool0000405iNGP27QhL0M7Ad04Q8B080HV9R0?l0NWYj08N7Q`0f=SH0>CTi05YJFP1gMgL0KVi^08J6
QP0d=3@0?clo04E5A@1cLg<0NGUi0:n_[`1iNGT061PH03<c<`1;Bd/0C4a<0:6QX@2[Zj/0:BTY04=3
@`0l?3`0Kfm_071`L03Bd]80Cdm?03De=@17AdL0ATI605EEE@1FEUH0TI6A02PX:00A4A40De=C06IV
IP0l?3`0EeMG05QHF00G5aL07QhN05IFEP21PH40=cLg05mOG`0Y:BT09RHV03hn?P1XJ6P0?Cdm03`l
?01?Cdl08R8R02LW9`1VIVH0L71`02LW9`0m?Cd0?3`l0492@P1DE5@0Lg=c04i>CP0K6a/0?3`l05MG
E`0h>3P0EeMG0:JVYP1@D5005aLG04a<C01IFET0GemO092@T01WIfL06QXJ02<S8`1@D500IfMW04a<
C02OWil0JVYZ01PH600e=CD0Fe]K07MgM`1OGel0bl_;034a<@0R8R80=SHf05IFEP0m?Cd0LG5a08b<
S00O7al0=CDe05iNGP1dM7@0=3@d05eMG@1RHV8051@D034a<@1KFe/0Hf=S03Xj>P1YJFT0BDU902h^
;P1PH600J6QX04I6AP0Y:BT0Bd];03Ph>00l?3`0T92@08B4Q00j>SX06a/K03lo?`0e=CD0@d=308^;
R`2VYZH09bLW03/k>`1FEUH0FEUI05IFEP2WYjL0QXJ6024Q8@0l?3`0HV9R04E5A@1LG5`0^[Zj03@d
=00K6a/0GEeM09FEU@1CDe<0J6QX05IFEP0Q8B40:b/[05aLG01GEeL0BDU907=cL`0>3Ph071`L05]K
F`1[Jf/0820P04];B`0g=cL0820P02l_;`23Ph<0BTY:02HV9P1MGEd0;bl_02TY:@18B4P0YZJV06YZ
JP0V9RH0Cdm?034a<@13@d<0HF5Q08R8R00X:2P0:BTY05IFEP13@d<0MWIf0:^[Z`21PH4092@T0410
@01JFUX0B4Q805YJFP2^[Zh0;2`/01/K6`0e=CD0De=C04a<C01TI6@0S8b<01dM7@0K6a/0AdM70861
P@1JFUX0cLg=03hn?P0_;bl0@T9209:BTP1EEED0HF5Q04M7A`0];Bd0IfMW08>3P`1_Kfl0D51@06YZ
JP0I6AT0<S8b075aL@1PH600Cdm?05]KF`0/;2`0=3@d08V9R@1LG5`0?clo04m?C`0d=3@0GEeM09BD
U01hN7P092@T04=3@`11@D40=CDe07YjNP2DU9@09RHV03<c<`19BDT0GEeM069RHP2UYJD0;bl_01lO
7`1=CDd0IfMW05=CD`2SXj<0/k>c02<S8`0b<S8005H0JFUY071`L01;Bd/0][Jf06EUI@0Q8B40<C4a
08F5Q@1cLg<0V9RH0:>SX`1;Bd/0<30`03Lg=`1VIVH0Lg=c05MGE`1jNWX0@D51038b<P0h>3P0LG5a
07alO01aLG40XJ6Q0410@00l?3`0Bd];07QhN01QHF40F5QH05]KF`0[:b/0;Bd]05=CD`24Q8@0>CTi
04I6AP1SHf<0>CTi03@d=00i>CT0H61P03Ti>@0c<c<0ADE503De=@0m?Cd0IFEU0820P00V9RH09BDU
02LW9`1=CDd0B4Q807]kN`1`L7007alO07emO@1VIVH0DE5A04I6AP1QHF40G5aL05EEE@12@T80C4a<
092@T01ADE40B4Q804M7A`1IFET0S8b<055AD@1VIVH0Cdm?06][J`1_Kfl0FEUI065QH@0n?Sh0Bd];
0451@@16ATH0ADE506][J`80BDU90780>CTi04e=C@1OGel0EEEE0451@@1GEeL0Hf=S05QHF018B4P0
C4a<055AD@1_Kfl0GUiN0492@P16ATH0A4A403hn?P15ADD0AdM705]KF`1IFET0BDU904m?C`1ADE40
E5AD020P800f=SH0CTi>05UIF@1MGEd0B4Q802@T901?Cdl0BDU903`l?01@D500BTY:04i>CP1HF5P0
DE5A04I6AP13@d<0CDe=06i^KP1_Kfl0S8b<04m?C`17AdL0Ti>C03Ph>01CDe<0MWIf0451@@1ZJVX0
Bd];05iNGP1WIfL0?Cdm03/k>`1LG5`0@D5104E5A@0m?Cd0D51@05MGE`10@400Cdm?03Xj>P0h>3P0
:RXZ051@D01JFUX0DE5A04Y:BP0d=3@0Cdm?02HV9P0_;bl0BTY:020P8018B4P0CDe=059BDP1LG5`0
Hf=S04e=C@1LG5`0F5QH05YJFP1SHf<0H61P04=3@`1TI6@0GEeM05YJFP14A4@0Ogmo06m_K`1]KFd0
Jf][04];B`1DE5@0<S8b051@D00i>CT0BTY:03@d=01BDU80@D5106EUI@1>CTh0LG5a06QXJ01>CTh2
07AdM00A08b<S02HV9P0JFUY04I6AP1?Cdl0Hf=S06UYJ@1dM7@0>c/k05EEE@1GEeL0IfMW03`l?018
B4P0HV9R03lo?`2@T9000P2:RXX0H01hN7P0F5QH04Y:BP1KFe/0G5aL05ADE026QXH0TI6A051@D01A
DE40G5aL02d];@1TI6@0Jf][03/k>`10@400<S8b04E5A@1@D500>3Ph075aL@0];Bd0EUIF05MGE`0W
9bL0?clo04e=C@0e=CD0G5aL03hn?P1?Cdl0G5aL038b<P11@D40?Cdm07moO`1EEED0RHV904m?C`1n
OWh0Ng]k03Hf=P0c<c<0DE5A0410@01QHF40NGUi03Lg=`1LG5`0FEUI05mOG`2JVYX0GUiN06ATI01A
DE40FEUI061PH00i>CT0Hf=S05iNGP1kNg/0BDU90<g=c@2<S8`0>CTi08b<S02ATI40<30`059BDP1V
IVH0I6AT08b<S01LG5`0K6a/06m_K`1WIfL0CTi>04Y:BP1dM7@0ADE504a<C01_Kfl0Lg=c08B4Q021
PH40=cLg092@T029RHT0BTY:08n?S`16ATH0LG5a04i>CP1BDU80GEeM01`L7080@41002X0Bd];04m?
C`1:BTX0De=C04U9B@1SHf<0<c<c06=SH`0V9RH0@d=305ADE00o?cl0GemO034a<@1;Bd/0I6AT05iN
GP17AdL0Cdm?075aL@1@D500Fe]K04Y:BP1FEUH0Hf=S065QH@2:RXX0=cLg07AdM021PH40E5AD09:B
TP1QHF40CDe=06EUI@1CDe<0MWIf05IFEP0_;bl0<30`03Ph>01LG5`204E5A@0<03<c<`1QHF40Hf=S
04=3@`1GEeL0Shn?04=3@`1BDU80H61P04M7A`1=CDd0IFEU0_ooool0000805QHF01GEeL0PH6108R8
R02:RXX0?clo05MGE`1mOGd207]kN`1m09JFUP0_;bl0CTi>051@D01WIfL0Ti>C0:NWY`0O7al0=cLg
05EEE@1VIVH0De=C06UYJ@0o?cl09bLW03hn?P16ATH0Bd];051@D01IFET05ADE03De=@1mOGd0YJFU
03`l?00d=3@0ADE501LG5`0o?cl0YJFU0:RXZ00[:b/0;Bd]04I6AP0/;2`0GEeM08:2PP0/;2`05aLG
03Ph>01HF5P0De=C09RHV01OGel05QHF02XZ:P11@D40?3`l07UiN@2BTY807AdM02l_;`1UIFD0HF5Q
05]KF`1LG5`0@41001dM7@1BDU80M7Ad07=cL`0k>c/0OGem03Ph>00M7Ad0=CDe06ATI01KFe/0@D51
05UIF@0[:b/05ADE038b<P1WIfL092@T02h^;P1?Cdl07alO024Q8@13@d<0I6AT01HF5P0b<S80;2`/
02TY:@0k>c/0U9BD06=SH`0H61P0=3@d038b<P0M7Ad0De=C09:BTP0g=cL07alO03/k>`0c<c<0>3Ph
09bLW02k^k/08b<S01/K6`0];Bd0DE5A059BDP2LW9`0Shn?024Q8@0b<S80BDU904m?C`1WIfL0MgMg
030`<00I6AT0>c/k06QXJ022PX80Bd];08Z:RP0i>CT08B4Q03Ti>@1dM7@00P1BDU80C`1ADE40;2`/
03Hf=P1@D500I6AT05MGE`1EEED0HV9R01dM7@0c<c<0JVYZ07=cL`0_;bl0F5QH059BDP0d=3@0PH61
08n?S`0Y:BT0=cLg051@D01BDU80Fe]K0;Ng]`0S8b<07AdM055AD@1JFUX0@D5108n?S`1CDe<09BDU
04E5A@1cLg<0B4Q808Z:RP2XZ:P0DU9B01TI6@0f=SH0F5QH07UiN@1NGUh0T92@02<S8`0X:2P0?clo
061PH01_Kfl0HV9R0:n_[`0Z:RX0:2PX06MWI`21PH40=cLg04a<C01@D5007alO04e=C@1dM7@0HV9R
04=3@`1JFUX0@41002d];@1VIVH0Q8B404a<C00b<S80EEEE038b<P15ADD0O7al079bLP0Q8B40GEeM
03`l?016ATH00P1QHF40`00Z:RX0Cdm?05UIF@1PH600OGem09fMW@0L71`0820P05]KF`12@T80KVi^
07=cL`0R8R80>CTi04i>CP14A4@0GEeM09fMW@1;Bd/092@T06][J`23Ph<0>c/k06m_K`0i>CT0@410
04M7A`27QhL0HV9R06MWI`1LG5`07QhN065QH@1nOWh0FEUI04A4A01SHf<0:RXZ0492@P1[Jf/0QXJ6
04];B`1LG5`0Kfm_020P801;Bd/0Ph>308J6QP0j>SX0<30`05UIF@0T92@0?Shn07UiN@1eMGD09RHV
03`l?01NGUh0>CTi0492@P2IVIT0Vi^K024Q8@0d=3@0F5QH03hn?P1QHF40Xj>S06EUI@0S8b<0ADE5
04U9B@1CDe<0Kfm_09BDU00m?Cd09bLW04a<C01BDU80=SHf05iNGP2LW9`0:b/[03Hf=P13@d<0CTi>
04m?C`1JFUX0IFEU01/K6`0[:b/0Cdm?079bLP17AdL0GemO07=cL`0I6AT0;Rh^06i^KP1YJFT0<C4a
05IFEP1KFe/0F5QH05=CD`13@d<0;bl_05mOG`1DE5@0>SXj06a/K00k>c/0G5aL06QXJ01TI6@0KFe]
04U9B@1nOWh0Lg=c079bLP1>CTh0B4Q807UiN@0^;Rh0EeMG05=CD`1>CTh0LW9b05aLG00n?Sh0Hf=S
04A4A01KFe/0FEUI06=SH`1JFUX0Lg=c05UIF@21PH40JFUY07MgM`1nOWh0Hf=S06MWI`0f=SH07AdM
01hN7P12@T80E5AD0410@00m?Cd0HF5Q0410@01EEED0>c/k04i>CP0I6AT0>CTi05=CD`0`<300=SHf
0410@00];Bd0CTi>05IFEP1BDU80ATI603dm?@1MGEd0MgMg061PH01?Cdl0EEEE06MWI`20P800>CTi
05IFEP15ADD0@D510820P022PX80LW9b06=SH`0b<S80CDe=05=CD`0b<S80GEeM04E5A@1;Bd/0Jf][
03Xj>P80@4100500<S8b04E5A@0h>3P0AdM703dm?@0W9bL0:b/[0492@P14A4@0ATI604Y:BP1;Bd/0
D51@01dM7@0`<300G5aL02HV9P1DE5@0@410059BDP14A4@0Cdm?04=3@`1LG5`0IFEU059BDP1LG5`0
D51@05YJFP1TI6@0DU9B04];B`1@D500OGem05QHF01TI6@0Lg=c06YZJP1YJFT0>SXj06][J`0o?cl0
K6a/0451@@1QHF40>SXj07MgM`1bLW80^k^k0:>SX`1VIVH0RHV906MWI`2GUiL0V9RH04U9B@1OGel0
FUYJ05mOG`1^KVh0Jf][04A4A01ADE40?3`l05iNGP0k>c/0C4a<04U9B@0`<300MgMg0861P@1TI6@0
KVi^05QHF01;Bd/0O7al08j>SP1IFET0DU9B05iNGP80G5aL06/0E5AD028R8P1cLg<0SHf=0410@01I
FET0A4A405mOG`1TI6@0@T9208>3P`0j>SX0L71`069RHP0Q8B40ADE504a<C00_;bl0IFEU03Ph>012
@T80IFEU04a<C01?Cdl09bLW03`l?00];Bd0MWIf0451@@1GEeL0IFEU030`<00e=CD0CTi>03Ph>01<
C4`0FEUI020P801dM7@0HV9R038b<P1@D500@41004U9B@1=CDd0>3Ph04E5A@0Q8B40GUiN03hn?P1;
Bd/0>CTi08Z:RP1/K6`0@D5106IVIP1CDe<06a/K04A4A01@D500;Rh^05]KF`0m?Cd0K6a/03dm?@1?
Cdl0EEEE04I6AP1?Cdl0:b/[04I6AP0o?cl0@41004I6AP17AdL05aLG03`l?01RHV80?Cdm05UIF@0S
8b<0Cdm?03Ti>@1TI6@0R8R801lO7`14A4@0ADE505MGE`16ATH0=SHf051@D018B4P0HV9R028R8P1T
I6@09BDU02l_;`0f=SH0Cdm?07moO`1?Cdl0?clo04E5A@1FEUH0ATI603Lg=`0204Y:BP0O04U9B@17
AdL0G5aL061PH02=SHd0[Jf]02/[:`1aLG40W9bL07MgM`2i^KT0IVIV06YZJP1oOgl0<30`03dm?@0d
=3@0ATI6030`<00Z:RX0CDe=03dm?@12@T80;Rh^04A4A01HF5P0B4Q804U9B@1[Jf/0ATI605MGE`02
04U9B@0305IFEP1QHF7ooooo007ooooo0000O`20P800QXJ606][J`1GEeL0PX:205eMG@1JFUX0GEeM
06YZJP2`/;00`/;205mOG`0e=CD0Fe]K03Ph>01CDe<0WYjN069RHP0`<300DU9B04I6AP1ZJVX0a/K6
09BDU00O7al0?3`l03Xj>P0i>CT0RXZ:0=3@d015ADD0;bl_03De=@1jNWX0CTi>09>CT`1fMWH05QHF
02`/;00^;Rh0Ph>306=SH`29RHT0@D5101TI6@0M7Ad0ATI606a/K01YJFT0Ph>301XJ6P0O7al0Bd];
07YjNP1<C4`0Kfm_08:2PP0W9bL0;2`/06m_K`1^KVh0?3`l059BDP0Z:RX09RHV05mOG`1PH6008b<S
02h^;P1HF5P0IVIV03hn?P21PH40ATI6020P800[:b/0De=C03/k>`10@400PH6104m?C`0P8200;Rh^
05YJFP1dM7@0IfMW08Z:RP0P82008R8R03@d=01GEeL0DE5A07AdM01_Kfl051@D02PX:013@d<0GUiN
06=SH`29RHT0@d=301@D500e=CD0C4a<05aLG01GEeL0/[:b030`<00O7al0;Bd]05aLG01;Bd/0EEEE
06IVIP0P82006ATI055AD@2BTY80FEUI051@D01IFET09BDU0451@@1YJFT0KVi^028R8P0b<S800P0c
<c<0300j>SX0Ph>309BDU00R8R80<c<c03Xj>P0a<C40F5QH08R8R00l?3`08b<S05IFEP80E5AD0<<0
Rh^;06a/K00F5QH07AdM0492@P1RHV80D51@09VIV@1OGel0:BTY0410@01[Jf/0@D5106MWI`2=SHd0
?3`l04E5A@1mOGd0BDU904e=C@1[Jf/0:RXZ03Hf=P1LG5`0`<3003`l?01MGEd0Bd];01hN7P0h>3P0
QhN707EeM@0_;bl0?clo069RHP0V9RH0L71`0:ZZZP1bLW80=cLg06YZJP1?Cdl092@T05YJFP35aLD0
P82002XZ:P15ADD0Fe]K05UIF@2CTi<0T92@03/k>`0c<c<0GemO051@D01OGel0[Zj^061PH00O7al0
A4A406MWI`1IFET0JFUY09:BTP0^;Rh07alO05ADE029RHT0EeMG0:FUY@1EEED07AdM03lo?`1^KVh0
<c<c08:2PP1MGEd06ATI03lo?`2LW9`0Fe]K04U9B@1GEeL0<30`034a<@1YJFT0DU9B04e=C@1RHV80
7AdM03Lg=`1XJ6P0Shn?03hn?P1<C4`0=CDe04I6AP1mOGd0FUYJ02<S8`16ATH0B4Q8038b<P1TI6@0
WIfM03Lg=`0Y:BT0JVYZ05QHF01TI6@0Ph>302l_;`0V9RH0DE5A061PH01CDe<0Ng]k0<O7a`0j>SX0
820P06UYJ@2RXZ80HV9R07=cL`2ZZZX0?Shn02TY:@1:BTX0SXj>069RHP24Q8@0YZJV03hn?P15ADD0
GEeM07YjNP13@d<0FEUI07]kN`0^;Rh0AdM704m?C`1HF5P0E5AD06UYJ@1IFET0;bl_05eMG@24Q8@0
DU9B04m?C`1^KVh0GEeM03Ph>00i>CT0KFe]06][J`0`<300B4Q804e=C@0S8b<0>c/k06QXJ01FEUH0
:b/[03Ti>@13@d<0@41004Q8B021PH40H61P02@T9015ADD0CDe=059BDP1[Jf/0Hf=S05=CD`19BDT0
GEeM061PH01UIFD0De=C051@D02NWYh0Lg=c04Y:BP17AdL0D51@07AdM01_Kfl0Fe]K03Xj>P1YJFT0
0P1?Cdl0=P1RHV80?3`l055AD@1HF5P0GUiN06IVIP1KFe/0>3Ph05]KF`1BDU80F5QH06UYJ@1<C4`0
@T9206UYJ@1DE5@0GemO038b<P1EEED0IfMW07QhN01JFUX0@T9202h^;P0a<C40AdM705QHF00j>SX0
ATI605MGE`0m?Cd0>3Ph05IFEP1JFUX07QhN04M7A`1DE5@0?clo04A4A01HF5P0Cdm?05mOG`12@T80
@D5106MWI`1PH600De=C0410@01CDe<0D51@04M7A`0k>c/0I6AT04Q8B080H61P0>`0BDU905UIF@0f
=SH0@d=305IFEP0l?3`0EeMG03`l?00X:2P0CTi>03Hf=P0h>3P0D51@0410@00_;bl0>c/k03Ti>@15
ADD0>c/k03lo?`0n?Sh0<S8b03Xj>P18B4P0Hf=S04A4A00l?3`0BTY:04a<C00J6QX0<C4a03Ph>00o
?cl0BDU903Xj>P1=CDd0M7Ad05UIF@1MGEd0F5QH055AD@1CDe<0E5AD04a<C011@D40HF5Q05IFEP14
A4@06ATI08F5Q@1?Cdl0Hf=S079bLP1=CDd0EEEE02d];@1OGel0BTY:06a/K011@D40EeMG04E5A@2F
UYH0O7al0;Zj^P2NWYh0GEeM08b<S01YJFT0Rh^;0;Ng]`1IFET0HV9R07alO01]KFd0GUiN069RHP1J
FUX0L71`04m?C`1PH600ATI604Y:BP1BDU80?3`l05mOG`1eMGD0GEeM08f=S@21PH40GemO0451@@1N
GUh0N7Qh08R8R023Ph<0?clo05MGE`1VIVH09BDU05mOG`1/K6`0?Cdm07UiN@1GEeL0AdM705ADE00d
=3@0SHf=038b<P0k>c/0CDe=01`L701KFe/0DE5A01/K6`17AdL0=SHf04m?C`1HF5P0D51@05iNGP0Z
:RX0De=C02l_;`2?Shl0G5aL05IFEP1OGel09bLW03/k>`1QHF40AdM704E5A@1;Bd/0:RXZ07]kN`1^
KVh0>c/k05IFEP0o?cl0FUYJ06e]K@0h>3P0DU9B01/K6`1nOWh0;bl_04M7A`0c<c<0GUiN059BDP0o
?cl0JFUY06QXJ00J6QX0Hf=S06i^KP0l?3`0IFEU055AD@1^KVh0C4a<051@D01JFUX0CTi>051@D00e
=CD0Cdm?0492@P1CDe<0NGUi06m_K`0N7Qh0D51@075aL@16ATH0J6QX03@d=01DE5@0<30`0492@P1L
G5`04A4A04i>CP0g=cL0ADE504I6AP0k>c/0@41003@d=01<C4`092@T06a/K00`<300ATI603lo?`0l
?3`0DU9B034a<@0k>c/0CTi>04U9B@1nOWh07alO04i>CP16ATH0B4Q805=CD`1iNGT0UiNG05UIF@1l
O7`0DU9B08>3P`2<S8`0@T9206i^KP1DE5@0HV9R05IFEP0_;bl0Bd];03De=@0_;bl0@41002`/;010
@400>CTi04a<C00n?Sh0GEeM04I6AP0l?3`0D51@0861P@80CDe=00@0GemO05=CD`1WIfL0JVYZ0_oo
ool0000]08f=S@2/[:`0OWin04E5A@1UIFD0H61P092@T01WIfL0>3Ph04];B`2h^;P0TY:B07MgM`25
QHD0=CDe04M7A`1aLG40SHf=05UIF@1]KFd0>c/k01PH6011@D40O7al04e=C@2;Rh/0EEEE020P800U
9BD0F5QH06][J`15ADD0EeMG024Q8@0/;2`0@T9206ATI00_;bl0@41004=3@`0Z:RX0;Bd]05=CD`1K
Fe/0:BTY0080?Cdm0;`0;2`/03dm?@26QXH0@d=302LW9`1@D500Cdm?0492@P1WIfL0NWYj02@T900`
<300Bd];03dm?@1TI6@0UYJF02HV9P13@d<0BDU906m_K`16ATH0G5aL079bLP0c<c<0:b/[05EEE@1N
GUh0EeMG07]kN`2VYZH09BDU03Lg=`0i>CT0C4a<05EEE@20P800GUiN01TI6@0X:2P0;Rh^05]KF`0f
=SH0DU9B03Ti>@0J6QX0E5AD05EEE@0Z:RX0@41006][J`0S8b<07AdM071`L01nOWh071`L02/[:`1?
Cdl0:RXZ02/[:`1lO7`0HF5Q018B4P0j>SX0E5AD030`<01NGUh0W9bL03Xj>P0Q8B40;Bd]059BDP13
@d<0GUiN08Z:RP0T92@07AdM04E5A@21PH40Jf][08:2PP1^KVh061PH034a<@1ADE40T92@04I6AP1J
FUX0ATI6018B4P0c<c<0=CDe04E5A@17AdL0GemO04U9B@0D51@0Fe]K096AT@18B4P0E5AD05=CD`0T
92@0<C4a065QH@20P800:2PX03Ph>00n?Sh0=CDe03Hf=P21PH40LG5a030`<01LG5`0EeMG04m?C`2D
U9@0@d=301lO7`1:BTX0Cdm?0451@@22PX80SXj>020P800X:2P0>SXj06m_K`0m?Cd0J6QX0:FUY@0/
;2`0<30`04m?C`1cLg<0@d=308f=S@1GEeL0;bl_04U9B@17AdL0PH61059BDP21PH40<c<c01PH601@
D500IVIV05IFEP1OGel0RXZ:02l_;`0T92@0GemO06a/K00Y:BT0EEEE051@D00Y:BT0Fe]K07inOP1U
IFD0CDe=08B4Q00i>CT0:RXZ08n?S`2h^;P0F5QH069RHP15ADD0;Bd]06i^KP28R8P0<S8b05=CD`0j
>SX0D51@08b<S01hN7P0:RXZ05=CD`1IFET0=cLg07IfMP2IVIT05ADE01`L7080C4a<03P0E5AD0:FU
Y@1BDU80:BTY06IVIP1iNGT0@41006i^KP1:BTX0:RXZ03Lg=`27QhL0SXj>06UYJ@2HV9P08B4Q04=3
@`1BDU80GEeM04e=C@2BTY80GUiN03Hf=P1YJFT0QhN706a/K01GEeL0SXj>04Y:BP0g=cL0EeMG07Qh
N015ADD0@D5104m?C`0X:2P0>3Ph05iNGP2LW9`0NWYj01`L700h>3P0=3@d04M7A`1@D500WinO06][
J`0];Bd0EeMG02PX:01<C4`0YZJV0;Zj^P1?Cdl0=cLg05eMG@80AdM70400PX:2069RHP0e=CD09BDU
05YJFP1iNGT0FEUI09^KV`2ATI40:RXZ02PX:01OGel0JVYZ079bLP1aLG40?clo02DU9@0k>c/0I6AT
06MWI`1TI6@0PH6103dm?@0c<c<0IfMW05mOG`1EEED0C4a<06IVIP1BDU80GemO04i>CP0g=cL0Kfm_
03Ti>@1>CTh0FUYJ06UYJ@2FUYH0KVi^06m_K`1@D500KVi^06][J`1dM7@0Fe]K038b<P1EEED0?Shn
04E5A@0j>SX0IVIV03/k>`15ADD0=CDe0410@01jNWX0EEEE03`l?01CDe<0GUiN04Y:BP10@400DU9B
0P1?Cdl0>P1ADE40?clo02/[:`0^;Rh0<S8b0451@@1;Bd/0Fe]K05ADE011@D40ADE506a/K01TI6@0
9RHV03Ph>01IFET0I6AT06IVIP18B4P08R8R04i>CP1BDU80CTi>04M7A`0Z:RX0C4a<05aLG01=CDd0
ATI604Q8B01ADE40JVYZ05mOG`1fMWH0ATI603`l?01VIVH0HV9R07=cL`0k>c/06a/K04=3@`1CDe<0
Bd];05aLG00n?Sh0ATI605ADE00`<300:b/[03De=@1>CTh0ATI6030`<00o?cl0>SXj02XZ:P0U9BD2
0410@01?0492@P14A4@0A4A404U9B@0`<300;Rh^05QHF00P8200A4A403hn?P1>CTh0=CDe03lo?`0i
>CT0E5AD05YJFP1;Bd/0DE5A061PH01hN7P0LW9b06QXJ01ADE40?Cdm08>3P`1CDe<0P82006a/K01@
D500GemO03Ti>@1QHF40>SXj05=CD`0j>SX0DU9B03lo?`1@D500GemO0:NWY`2EUID0KFe]0:n_[`1d
M7@0QhN70<?3``1kNg/0^k^k0:ZZZP1[Jf/0JFUY092@T017AdL0GUiN059BDP1/K6`09bLW03`l?017
AdL0<S8b06MWI`1iNGT0FEUI06ATI017AdL0DU9B03Hf=P25QHD0BTY:04i>CP1WIfL0?Cdm0492@P1T
I6@0BDU906QXJ01eMGD0>SXj04Y:BP0205MGE`1@06UYJ@14A4@0JFUY04=3@`1<C4`0J6QX03Ti>@18
B4P0BTY:01dM7@1eMGD0Bd];03lo?`1NGUh0C4a<05=CD`0_;bl0JFUY02/[:`1NGUh0DE5A05aLG01K
Fe/0:b/[02DU9@0h>3P0;Bd]05=CD`1SHf<06ATI06MWI`1RHV80?3`l069RHP1:BTX0@41003lo?`0[
:b/0?Shn01<C4`1FEUH0<S8b059BDP0];Bd0MWIf065QH@0e=CD0L71`08b<S00H61P0?Cdm04M7A`12
@T80NWYj05iNGP2>SXh0CTi>069RHP1FEUH0Bd];05MGE`0h>3P0B4Q804e=C@1EEED0@T9204U9B@0B
4Q80DU9B061PH00_;bl0DU9B01HF5P1XJ6P0<30`05EEE@1RHV803`l?03lo?`0d=3@204U9B@0A03dm
?@1;Bd/0A4A404m?C`0h>3P0Xj>S03Xj>P18B4P0BTY:04i>CP1HF5P0<c<c05ADE01dM7@0IfMW05EE
E@0a<C400P1ADE408`1EEED0@d=305MGE`1XJ6P0LG5a09:BTP0a<C40PX:209>CT`1IFET0TI6A09JF
UP1mOGd0Ng]k06=SH`20P800F5QH03Xj>P0i>CT0>SXj04Y:BP0g=cL0ADE501/K6`1LG5`0E5AD04Q8
B01?Cdl0PH6104i>CP18B4P0De=C04m?C`1IFET0I6AT00;ooooo0000?P1DE5@0NGUi07UiN@1MGEd0
HF5Q04a<C01^KVh0QHF503/k>`1:BTX0IFEU0451@@1XJ6P0TI6A03hn?P0c<c<0@T9203Ph>01?Cdl0
[:b/06MWI`0L71`0:BTY04U9B@10@400Ogmo08J6QP0S8b<0:RXZ03lo?`1=CDd0JFUY09NGU`0l?3`0
8R8R05ADE01^KVh0@41007inOP2TY:@07QhN02XZ:P1CDe<0CDe=03dm?@1jNWX0MWIf01<C4`0c<c<0
@T9204i>CP1BDU80Jf][03@d=00e=CD0BDU905iNGP15ADD0EeMG06UYJ@0Z:RX06a/K0P1bLW80R`0]
;Bd0Cdm?024Q8@0P82009RHV05EEE@1PH600=cLg06EUI@0^;Rh09RHV04I6AP1^KVh0F5QH01lO7`1=
CDd0:b/[034a<@19BDT0GEeM02HV9P0[:b/0@T9203<c<`13@d<0X:2P05aLG00E5AD09bLW03Xj>P0b
<S80IVIV09ZJVP0Y:BT051@D03Xj>P1PH600DU9B06MWI`1kNg/0>3Ph03De=@0_;bl0H61P05IFEP1Z
JVX0IFEU01HF5P12@T80E5AD071`L00c<c<0MgMg04Y:BP0O7al0?Shn07AdM01JFUX0EUIF061PH00Y
:BT0@d=305IFEP1^KVh0>CTi03<c<`1<C4`0<S8b03@d=01HF5P0QhN702HV9P0];Bd0A4A4030`<010
@400S8b<05YJFP0D51@09RHV059BDP1;Bd/0IVIV07AdM00L71`07alO04A4A01LG5`0GUiN07emO@1X
J6P08R8R03De=@17AdL0Ng]k06QXJ01gMgL0<c<c05aLG01:BTX0Cdm?02l_;`2EUID07alO034a<@1:
BTX0IfMW04];B`12@T80L71`01lO7`0U9BD0ATI607UiN@16ATH0=SHf05aLG00I6AT0ATI606UYJ@1`
L700=cLg05IFEP1`L700=cLg07=cL`1eMGD0IVIV02TY:@0l?3`0EeMG04U9B@1cLg<0Zj^[07MgM`0T
92@0DE5A06QXJ01:BTX00P27QhL0JP0C4a<092@T06=SH`1TI6@0JVYZ09bLW00h>3P06ATI04m?C`2D
U9@0EEEE06QXJ015ADD0;Rh^079bLP1lO7`0@d=30:>SX`1bLW80:RXZ04];B`2CTi<0?clo04A4A00g
=cL0<30`04=3@`2GUiL0E5AD0492@P1EEED0;Rh^028R8P1OGel0Ng]k02DU9@12@T80:2PX03/k>`1L
G5`0SXj>03<c<`0j>SX0?Cdm02TY:@1XJ6P0cLg=05aLG00`<300HF5Q02h^;P0b<S80VYZJ0:FUY@0W
9bL0AdM707AdM01BDU80GemO0;:b/P2NWYh0;2`/03De=@1^KVh0GemO08>3P`28R8P0;bl_02@T900h
>3P0IfMW092@T01MGEd0OWin03hn?P0L71`0?Shn07IfMP21PH40Ng]k0::RXP14A4@0:2PX03Hf=P1c
Lg<0DE5A04a<C02RXZ80IfMW04I6AP1EEED0GEeM04Q8B01LG5`0FEUI02`/;018B4P0FEUI09bLW01U
IFD0BTY:0451@@0I6AT0ADE5075aL@2?Shl204Y:BP0P07alO00_;bl0=CDe07QhN01VIVH0=CDe05EE
E@1TI6@0Cdm?0451@@1BDU80>c/k05]KF`0i>CT09bLW07inOP0Z:RX0=CDe03hn?P1>CTh0H61P051@
D01`L700De=C08:2PP1IFET0Cdm?079bLP0`<300EeMG04Y:BP16ATH205=CD`0_034a<@1CDe<0=SHf
04Y:BP1FEUH0G5aL038b<P1UIFD0HF5Q06i^KP11@D40JFUY07]kN`1SHf<0IFEU034a<@0i>CT0<C4a
03Ti>@1@D500?clo02l_;`1EEED0AdM703hn?P0f=SH0E5AD03De=@0l?3`0Cdm?03Hf=P0h>3P0>SXj
02d];@0m?Cd0?clo03Ti>@0n?Sh0?Cdm04];B`1FEUH0@d=304E5A@18B4P0Hf=S06e]K@10@4000P1O
Gel04@1IFET0HF5Q02h^;P0l?3`0ADE5059BDP1IFET0=SHf01lO7`1?Cdl0D51@04=3@`1:BTX0;2`/
02l_;`0n?Sh0ATI60080AdM700h0ADE5030`<00P8200<S8b04];B`1EEED0?3`l04M7A`15ADD0?Cdm
01XJ6P1@D500BDU902HV9P80ATI60P1EEED0c@1QHF40G5aL05MGE`19BDT0Cdm?05ADE00o?cl0>3Ph
05IFEP18B4P0>CTi02<S8`1YJFT0:RXZ0410@019BDT0L71`04M7A`0_;bl0@41004];B`1CDe<0>CTi
0492@P14A4@0Rh^;04=3@`1VIVH0KVi^04a<C02@T900EEEE09NGU`2f][H0MgMg06m_K`2>SXh0JVYZ
06UYJ@1hN7P0LG5a06a/K01LG5`0KFe]051@D01EEED0DU9B03hn?P1dM7@0BDU904Y:BP1DE5@0Cdm?
05EEE@1DE5@0SXj>051@D01HF5P0LG5a03Xj>P1=CDd0EEEE03dm?@2>SXh0Z:RX03Lg=`1@D500EEEE
05eMG@28R8P0=SHf09NGU`1NGUh0MGEe07MgM`0a<C40D51@05EEE@0f=SH0B4Q803Ti>@17AdL0J6QX
0451@@1LG5`0Cdm?05YJFP0l?3`0LW9b05]KF`1MGEd0MgMg03Ti>@0d=3@0BDU902XZ:P1;Bd/0BDU9
02DU9@2KVi/0M7Ad03Lg=`1ADE40DU9B03lo?`17AdL0=CDe04Q8B00J6QX0EUIF04=3@`1ADE40=SHf
05=CD`1;Bd/0;bl_07inOP1oOgl0:BTY055AD@1JFUX0?Cdm065QH@1PH600RXZ:04Q8B01KFe/0F5QH
04e=C@1>CTh0>CTi04I6AP14A4@0FEUI05=CD`1QHF40?clo05MGE`1oOgl0>CTi06ATI00O7al0BDU9
02XZ:P1GEeL0IFEU02XZ:P1:BTX0>CTi04E5A@18B4P0@T9205aLG014A4@0CDe=03/k>`1GEeL0=SHf
05eMG@1>CTh0I6AT07QhN01QHF40Bd];05QHF011@D40OWin059BDP1FEUH0HV9R07AdM01VIVH0MGEe
09ZJVP1kNg/0^;Rh04Q8B01jNWX0X:2P09RHV036a/H0JVYZ08Z:RP1gMgL0?3`l04U9B@1>CTh0@T92
03Ti>@0j>SX0L71`04a<C01>CTh08R8R07inOP1ADE40@T9203De=@1mOGd0ATI604M7A`1KFe/0BTY:
05MGE`1NGUh00_ooool0000I05aLG023Ph<0SHf=07QhN025QHD0?Cdm069RHP2KVi/0LG5a0;>c/`2e
]KD0?3`l05MGE`27QhL0GUiN06][J`2GUiL0=cLg04E5A@1RHV80YJFU06][J`2?Shl0;bl_038b<P02
05IFEP3o05]KF`1ZJVX0M7Ad01`L7010@400SXj>09bLW014A4@0D51@02/[:`0U9BD0F5QH06i^KP1M
GEd0=SHf05eMG@0/;2`07alO04a<C01dM7@0@41003Lg=`1KFe/0>CTi03Xj>P1`L700GEeM02<S8`1S
Hf<0?clo03<c<`1;Bd/0Q8B402/[:`0Z:RX0A4A404U9B@1QHF40IfMW059BDP0F5QH0;bl_051@D01L
G5`0M7Ad08^;R`0i>CT05aLG04=3@`1OGel0Cdm?05MGE`1eMGD06ATI028R8P0a<C40HF5Q04a<C01G
EeL0P82001LG5`0U9BD0<C4a07YjNP10@400Kfm_05=CD`0H61P0:RXZ0410@019BDT0:2PX04Y:BP0N
7Qh06QXJ03<c<`1IFET0CTi>02PX:01NGUh0:b/[03Ph>02BTY80Ph>30410@00d=3@0De=C03<c<`0l
?3`0PX:205aLG00H61P0:RXZ05QHF00g=cL0IfMW08F5Q@0d=3@05ADE03Lg=`1ZJVX0Cdm?0861P@3:
b/X0A4A401hN7P0l?3`0G5aL04M7A`1KFe/0GUiN01/K6`0R8R80FEUI08j>SP1CDe<0DU9B04];B`0G
5aL0?clo06][J`1cLg<0Bd];0:>SX`0i>CT08B4Q05QHF01eMGD0=SHf03De=@1_Kfl0:BTY03Ti>@2P
X:00;bl_03De=@1MGEd0=3@d038b<P1cLg<0De=C01lO7`1CDe<0FUYJ05eMG@1FEUH0Ph>305EEE@0U
9BD0DU9B04m?C`18B4P0VYZJ0;^k^`0b<S806ATI04Q8B01BDU80De=C0:>SX`2TY:@0<30`03Hf=P1_
Kfl0Jf][04Y:BP1iNGT0CTi>01<C4`13@d<0N7Qh08^;R`22PX80UiNG06MWI`0R8R80FEUI08>3P`17
AdL0@41006i^KP0Z:RX0@T92059BDP1JFUX0>c/k06ATI00W9bL0ATI60820P02=SHd0ADE504I6AP0k
>c/0@D51075aL@2>SXh0:2PX03hn?P1?Cdl0CDe=05IFEP1ZJVX08B4Q034a<@1FEUH0D51@07]kN`2a
/K40>3Ph01lO7`1<C4`0IfMW04a<C02d];@0BDU902@T900o?cl0TY:B06QXJ02<S8`0Q8B402`/;00T
92@0LW9b09jNWP1_Kfl0ZZZZ03Lg=`1;Bd/0EUIF06][J`1VIVH0LG5a08:2PP0U9BD0C4a<07EeM@2:
RXX0FUYJ05iNGP24Q8@0;2`/04i>CP2@T900OGem02l_;`1CDe<0OWin03lo?`1<C4`0Ng]k096AT@0b
<S80BTY:000=05EEE@0a<C40@d=307MgM`1_Kfl092@T059BDP0j>SX0Fe]K05EEE@2ATI40O7al02HV
9P020492@P2805aLG025QHD0MGEe024Q8@0`<300@D51061PH01OGel0VIVI09ZJVP0Q8B40<c<c0410
@01OGel0Cdm?071`L01aLG407AdM0451@@1XJ6P0H61P03hn?P1YJFT0QhN705iNGP0o?cl0H61P04e=
C@1_Kfl0Hf=S03Hf=P1RHV80@D51059BDP1UIFD0Hf=S07emO@1HF5P0NGUi06e]K@1UIFD0H61P05mO
G`1^KVh0DU9B07AdM01=CDd0@d=30410@01KFe/0?Cdm055AD@0f=SH0G5aL07QhN01TI6@0D51@07Yj
NP1WIfL0Kfm_06=SH`1UIFD0NWYj08f=S@1eMGD0ATI604A4A016ATH0@d=3069RHP1=CDd0ADE506a/
K018B4P0Bd];059BDP1TI6@06ATI04m?C`1ZJVX0EEEE04i>CP1BDU80?3`l05QHF01GEeL0?clo055A
D@0e=CD0EUIF05]KF`1EEED0@41004e=C@1DE5@0MWIf04];B`1TI6@0@41003De=@1iNGT0?3`l04Q8
B01CDe<0:b/[0492@P0l?3`0:RXZ06QXJ010@400?3`l06QXJ00j>SX0AdM703dm?@14A4@0D51@02XZ
:P14A4@0@41003hn?P0/;2`0BTY:04I6AP17AdL0EEEE051@D015ADD092@T03Xj>P1LG5`0:b/[04E5
A@0f=SH0CTi>04e=C@80BDU90400A4A404M7A`1QHF40KVi^04a<C01ADE40LG5a08V9R@1GEeL06QXJ
07IfMP13@d<0IVIV071`L016ATH0DU9B024Q8@1BDU80@D5104e=C@0f=SH0AdM703Lg=`1>CTh0<C4a
079bLP1lO7`0?3`l0<G5a@1KFe/0H61P06UYJ@17AdL0BDU905UIF@1BDU80G5aL06YZJP13@d<0DU9B
04=3@`16ATH0;Rh^03Hf=P0e=CD0:b/[0410@01WIfL0AdM706UYJ@1hN7P0IfMW03/k>`1IFET0BTY:
05YJFP1eMGD0>c/k06IVIP1dM7@0?Cdm059BDP1UIFD0FUYJ0P1ADE402`1;Bd/0Ogmo04E5A@1/K6`0
@D5105IFEP1jNWX0>CTi055AD@1FEUH0820P0080DE5A0780=3@d05UIF@1ADE40JVYZ0451@@1UIFD0
?3`l061PH01[Jf/0FEUI05aLG00j>SX0DE5A07QhN01ADE40E5AD0410@00b<S80GUiN06EUI@0c<c<0
ADE503Ti>@1<C4`0E5AD04M7A`1OGel0;bl_05YJFP0j>SX0B4Q803Ti>@2@T900IFEU04I6AP1cLg<0
PH6103Xj>P1`L700Ng]k04=3@`1EEED0JVYZ0:ZZZP1FEUH0EeMG06UYJ@1UIFD0Cdm?03Ti>@1JFUX0
CDe=04Y:BP1@D500GUiN02TY:@1ADE40OGem03hn?P1QHF40<30`055AD@14A4@0G5aL06MWI`0Y:BT0
AdM705EEE@1RHV80DU9B055AD@1RHV80DU9B05IFEP0k>c/0KFe]02`/;00f=SH0=CDe04=3@`0n?Sh0
De=C04U9B@1LG5`0C4a<04M7A`1GEeL0RHV9075aL@1KFe/0KFe]07AdM02XZ:P0[Jf]0<S8b01EEED0
QhN707QhN018B4P0MWIf04A4A01iNGT0Ng]k03Ph>01=CDd0>c/k04m?C`19BDT0<S8b05QHF018B4P0
EUIF03Xj>P1MGEd205iNGP0803De=@1bLW80C4a<05ADE01NGUh0@41005]KF`1fMWH2ooooo`0002l0
RXZ:09nOW`1TI6@0FUYJ09NGU`1=CDd0Rh^;04e=C@13@d<0Jf][0;:b/P1hN7P0CTi>05QHF00e=CD0
H61P09FEU@19BDT0=CDe04U9B@0h>3P0:BTY065QH@1kNg/08b<S04M7A`12@T80;bl_05=CD`2>SXh0
<S8b024Q8@1GEeL0GEeM04m?C`2IVIT0A4A401HF5P0d=3@0F5QH06ATI01gMgL0VIVI08J6QP0K6a/0
De=C06=SH`0206MWI`0;0:RXZ00_;bl06QXJ06UYJ@2;Rh/0EeMG0:n_[`1EEED06ATI02/[:`1LG5`0
0P1CDe<0A01hN7P09BDU034a<@10@400GemO04A4A024Q8@0MgMg01DE5@0/;2`0JFUY08V9R@0n?Sh0
IVIV08N7Q`0f=SH0>c/k06UYJ@1;Bd/07QhN051@D00/;2`06QXJ03dm?@2;Rh/0@D5102@T901@D500
BTY:04I6AP1hN7P0MWIf01LG5`0f=SH0De=C0451@@1ADE40QHF503Hf=P0<30`09bLW04E5A@0m?Cd0
I6AT07inOP0g=cL03@d=030`<01YJFT0CDe=07AdM01QHF40=3@d02/[:`0l?3`0G5aL04M7A`1OGel0
>c/k014A4@16ATH0D51@04U9B@0h>3P0FEUI02PX:00Y:BT0ADE50P1TI6@0?`0j>SX0A4A403Ti>@0Y
:BT0>c/k08R8R01CDe<0;2`/04i>CP0b<S80@T920:RXZ01kNg/09RHV02/[:`0m?Cd0=SHf065QH@2c
/k<0MWIf01HF5P0T92@0ADE504];B`1eMGD0[Zj^05UIF@0Y:BT0Jf][051@D01fMWH0_Kfm02h^;P0Q
8B40A4A407UiN@15ADD0V9RH05QHF00Q8B40BDU903Xj>P1LG5`0<C4a07moO`21PH40;Bd]02HV9P1Q
HF40LW9b05IFEP1=CDd0>CTi02PX:01@D500Kfm_05iNGP0^;Rh0F5QH03dm?@0/;2`0GUiN0861P@02
03lo?`1O05]KF`0W9bL0>3Ph09BDU02@T900;Bd]02h^;P0i>CT0Fe]K069RHP2JVYX0>SXj03<c<`1B
DU80Bd];05ADE02=SHd0=cLg01/K6`1?Cdl0Jf][05ADE02CTi<0?Shn024Q8@1PH600ZJVY04Y:BP1S
Hf<0HV9R02LW9`16ATH0J6QX059BDP1FEUH0EeMG02PX:01>CTh0HF5Q04m?C`10@400IVIV03Lg=`0T
92@0GEeM06][J`0b<S80ADE502XZ:P0g=cL0?3`l06e]K@1<C4`0>CTi06UYJ@0b<S80@T9206ATI01L
G5`0;bl_061PH012@T80;2`/08:2PP2n_[h0ATI602@T901ADE40JVYZ055AD@2NWYh0Y:BT02l_;`0U
9BD0AdM706IVIP1SHf<0M7Ad0;>c/`14A4@09RHV04=3@`1iNGT0ATI608b<S02ATI40<C4a04=3@`1L
G5`0S8b<04i>CP2FUYH0Cdm?03De=@1=CDd00P1^KVh0=P1TI6@0Ng]k03Hf=P0V9RH0ADE507]kN`20
P800A4A406e]K@19BDT0;Bd]03De=@1]KFd0CTi>03Lg=`0j>SX0=3@d02l_;`0a<C40K6a/04=3@`0d
=3@0CDe=03/k>`0[:b/0P82006EUI@1PH600BTY:07alO01[Jf/0BTY:034a<@0/;2`0SXj>03Ph>00/
;2`0>c/k04Y:BP1gMgL0EUIF055AD@1@D500H61P08F5Q@1<C4`0D51@02XZ:P13@d<0>3Ph0492@P14
A4@0E5AD03lo?`80>c/k00h0BDU906ATI015ADD0<c<c059BDP18B4P0A4A4034a<@0o?cl0Cdm?07Ee
M@1PH600<c<c04E5A@80<c<c03P0>3Ph04A4A01KFe/0BTY:04=3@`0l?3`0GEeM04i>CP0O7al0=cLg
04=3@`1TI6@0FUYJ03`l?00c<c<0BDU904E5A@1:BTX0GUiN04U9B@1EEED0HV9R05mOG`1MGEd0EeMG
065QH@2:RXX0HF5Q0820P01HF5P0AdM708B4Q01]KFd0MgMg06][J`12@T80FUYJ04m?C`12@T80Jf][
04Q8B010@400I6AT05EEE@1<C4`0ADE504A4A017AdL0>SXj04I6AP0n?Sh0=cLg02PX:00o?cl0?3`l
04Q8B080AdM700D0CTi>03dm?@0n?Sh0CTi>03@d=00204Y:BP0V05MGE`1EEED0GemO05eMG@1OGel0
EUIF04e=C@16ATH0C4a<04M7A`1ADE40Bd];04A4A00n?Sh0K6a/03hn?P19BDT0Bd];04m?C`17AdL0
;Bd]04M7A`0c<c<0ADE503Ph>01<C4`0CTi>06QXJ00f=SH0CDe=05QHF012@T80I6AT04a<C02?Shl0
U9BD05aLG01PH60206EUI@0;08n?S`1ZJVX0@D5104e=C@1CDe<0IVIV03@d=01BDU80De=C01lO7`0o
?cl00P1OGel08`1NGUh0?clo04i>CP0g=cL0EUIF055AD@1iNGT0WYjN04U9B@12@T80CDe=03`l?01T
I6@0TY:B03Ph>01OGel0Hf=S05iNGP28R8P0?clo09jNWP1CDe<0IVIV08>3P`0i>CT0FEUI05iNGP0f
=SH0DE5A0492@P1HF5P0LG5a03/k>`1DE5@0>c/k0080EUIF02L0PX:205aLG01BDU80EUIF03Hf=P0[
:b/0@d=3030`<01;Bd/0BTY:01hN7P1hN7P0DE5A02/[:`13@d<0?Cdm05UIF@1oOgl0=SHf05]KF`0n
?Sh0OWin03`l?018B4P0@41006UYJ@1?Cdl0>CTi07IfMP1lO7`0:BTY04a<C01OGel0C4a<079bLP1i
NGT0PH6105iNGP1ZJVX00P1CDe<0C01WIfL0@T9204=3@`0o?cl0D51@07inOP1WIfL0;bl_055AD@1h
N7P0?clo09>CT`10@400CDe=038b<P1XJ6P0NWYj028R8P1CDe<0?clo05YJFP1?Cdl0Bd];055AD@0d
=3@0@D510410@01oOgl0=cLg04E5A@0g=cL0D51@05QHF019BDT0MWIf0:>SX`11@D40Bd];03De=@1<
C4`0Hf=S07emO@14A4@0IVIV07UiN@1WIfL0Rh^;02LW9`1aLG40TY:B05UIF@2e]KD0K6a/0:NWY`29
RHT0IfMW08:2PP1;Bd/0?Cdm05EEE@1_Kfl0QhN705]KF`1JFUX0?3`l08^;R`1?Cdl0De=C03lo?`1c
Lg<0CDe=04i>CP1_Kfl0De=C06][J`1_Kfl2ooooo`0006H0EEEE0:^[Z`1ZJVX0F5QH065QH@1aLG40
Rh^;04m?C`0c<c<0A4A406QXJ01lO7`0P82008:2PP0/;2`0>c/k061PH01_Kfl0JFUY0:FUY@0g=cL0
<S8b04];B`1YJFT0IFEU09FEU@13@d<0>3Ph05IFEP1UIFD0Fe]K04I6AP1<C4`07AdM04=3@`1hN7P0
MWIf04Q8B01bLW80Ph>302TY:@0f=SH0KVi^09ZJVP1EEED0G5aL0492@P0O7al0B4Q807]kN`1lO7`0
Cdm?06i^KP0a<C40=CDe07alO02RXZ80>c/k05EEE@1ADE40>CTi06IVIP2PX:00@d=302l_;`0b<S80
<30`0492@P1eMGD0ZZZZ03`l?00M7Ad0=CDe03Ti>@10@400S8b<0;Ng]`0/;2`0<C4a065QH@1CDe<0
@D510::RXP1:BTX03@d=0410@01?Cdl0F5QH051@D02][Jd0<30`024Q8@13@d<0EUIF03lo?`1DE5@0
KFe]01TI6@0N7Qh0C4a<06i^KP0_;bl206YZJP0=01dM7@0P8200GemO05iNGP0/;2`0>c/k02/[:`0R
8R80<c<c06MWI`0a<C406a/K04E5A@0202XZ:P2P0820P02DU9@07QhN02@T901CDe<0;bl_061PH028
R8P0D51@00/;2`0e=CD0IVIV06EUI@15ADD0KFe]055AD@0Y:BT0:RXZ04];B`1FEUH0CTi>07MgM`1;
Bd/09RHV03Ti>@1aLG40?3`l04];B`1BDU809RHV03Lg=`1VIVH0S8b<03/k>`1DE5@0@d=3020P8017
AdL0IFEU06e]K@16ATH0ADE502l_;`1CDe<0O7al04i>CP0h>3P0DE5A02HV9P18B4P0GEeM08V9R@0d
=3@0>CTi051@D00c<c<0HF5Q06e]K@1^KVh0?Shn03Lg=`0m?Cd0<30`059BDP2EUID0I6AT024Q8@10
@400E5AD05=CD`1SHf<0[jn_07]kN`0N7Qh0EEEE079bLP1EEED0MgMg0;Vi^@0Q8B406a/K04M7A`1R
HV80B4Q807=cL`17AdL05aLG038b<P1gMgL0JFUY04I6AP26QXH07alO02XZ:P1IFET0Fe]K04E5A@1/
K6`0@d=302`/;01XJ6P0L71`02`/;01NGUh0G5aL028R8P17AdL0UYJF03Xj>P0f=SH0A4A402XZ:P1F
EUH0UIFE03Ti>@0a<C40MWIf04I6AP0i>CT0RXZ:06EUI@0N7Qh0?Shn05YJFP1?Cdl0Q8B4038b<P0X
:2P0G5aL05QHF01UIFD0Hf=S0;no_`0a<C40:BTY09NGU`1kNg/0G5aL08F5Q@1=CDd0:2PX03/k>`35
aLD0W9bL061PH02;Rh/0=SHf04a<C01ADE40[jn_07QhN01HF5P0Ng]k02XZ:P0e=CD0A4A405eMG@1V
IVH0@41007QhN080:RXZ04T0Cdm?0:2PX01gMgL0E5AD075aL@0W9bL0>c/k05mOG`1WIfL0;Bd]03Xj
>P1<C4`0<c<c055AD@1ZJVX0L71`02XZ:P0m?Cd0=SHf04M7A`1:BTX0VIVI0820P00V9RH0<S8b03hn
?P1=CDd0Kfm_079bLP1ADE40:RXZ0451@@12@T80GUiN061PH01fMWH0?Cdm02l_;`1CDe<0Fe]K05EE
E@0i>CT0Fe]K03Ph>01<C4`0=3@d01PH601/K6`0;bl_03@d=01BDU80EEEE06UYJ@1>CTh0UYJF071`
L01VIVH0EeMG0410@01WIfL0:b/[04Y:BP0h>3P0@41003Ti>@1PH600;Bd]04E5A@0g=cL0EeMG069R
HP1EEED0>3Ph0080FUYJ0180TY:B065QH@1DE5@0Hf=S06a/K01XJ6P0<30`0451@@0h>3P0:b/[05AD
E01@D500?Cdm06=SH`13@d<0<30`03Ph>01FEUH202d];@0504];B`16ATH0?3`l03@d=00W9bL00P0l
?3`0GP0o?cl0=SHf02<S8`18B4P0Hf=S0492@P0Z:RX0>c/k06MWI`1=CDd0;Rh^04=3@`1GEeL0GUiN
05IFEP0c<c<0>SXj04m?C`1OGel0Hf=S03Xj>P0P8200@T9204m?C`0n?Sh0?3`l02d];@0m?Cd0>CTi
03Hf=P0d=3@0@T9203/k>`0Z:RX092@T030`<01?Cdl0ATI604];B`1@D500B4Q803`l?00U9BD0DU9B
05mOG`0`<300Bd];05ADE01KFe/0>SXj05=CD`1kNg/0HF5Q05QHF01EEED0GEeM059BDP1JFUX0HV9R
05QHF01?Cdl0=3@d06UYJ@0l?3`0GUiN06][J`1?Cdl0J6QX03hn?P1:BTX08B4Q05aLG00j>SX0E5AD
03Ti>@25QHD0EEEE08^;R`23Ph<0;Bd]09bLW02>SXh0QhN70;Vi^@1dM7@0EEEE06m_K`1PH600GEeM
075aL@17AdL0E5AD02l_;`1<C4`203@d=02O03De=@0R8R80IFEU04E5A@0b<S80Cdm?04I6AP1?Cdl0
CDe=05aLG00_;bl0C4a<06MWI`14A4@0Cdm?061PH00`<300Jf][08R8R00k>c/0@d=304Y:BP1@D500
FUYJ03Ti>@1KFe/0D51@05EEE@1HF5P0;2`/04a<C01ADE40=CDe06QXJ00b<S80@D5105MGE`14A4@0
G5aL03Hf=P1cLg<0;2`/05EEE@1KFe/0CDe=05mOG`0h>3P0=SHf0492@P1?Cdl0JVYZ04];B`0l?3`0
O7al05YJFP0/;2`0=3@d03Lg=`1MGEd0P82005ADE01]KFd09bLW05YJFP1CDe<0G5aL051@D02GUiL0
M7Ad034a<@1cLg<0P82001`L701[Jf/0PX:203Ph>00n?Sh0C4a<0820P00m?Cd0ADE505]KF`13@d<0
>c/k02d];@1:BTX0>CTi04m?C`1@D500B4Q802XZ:P1fMWH0Vi^K04Q8B01OGel0<C4a06=SH`0m?Cd0
G5aL07emO@0[:b/0@D5103lo?`1GEeL0BTY:04=3@`1:BTX0F5QH05YJFP0_;bl0HV9R02TY:@14A4@0
CDe=05ADE01GEeL0F5QH04Q8B01@D500A4A405QHF01LG5`0EEEE04a<C01JFUX0F5QH09ZJVP2?Shl0
Kfm_0:6QX@0g=cL0U9BD0;:b/P2UYJD0jNWY051@D01WIfL0J6QX03De=@1>CTh0<c<c03Ti>@15ADD0
<c<c05QHF00k>c/0ATI602DU9@1KFe/0F5QH07UiN@14A4@0MgMg06EUI@1NGUh0K6a/061PH01oOgl0
QXJ600;ooooo0000:`1BDU80IfMW07IfMP1oOgl0OGem03@d=01kNg/0QXJ605aLG02JVYX0UYJF0492
@P1iNGT0M7Ad03Ph>019BDT0OWin0451@@16ATH0IfMW06UYJ@0^;Rh0Jf][03Hf=P0e=CD0JFUY07]k
N`0S8b<0;2`/04m?C`1RHV80EUIF09BDU01>CTh071`L04U9B@1JFUX0<c<c07moO`1hN7P08R8R02@T
9014A4@00P1@D500B@2UYJD0OWin01LG5`0U9BD0Bd];055AD@1TI6@0`l?303@d=00M7Ad0<30`05]K
F`1;Bd/0TI6A07]kN`0F5QH0@d=30820P01aLG40Fe]K08R8R00m?Cd0?Shn04];B`1hN7P0Kfm_05mO
G`2@T900;Bd]03`l?013@d<0WYjN09:BTP0e=CD0KVi^01TI6@14A4@0E5AD07MgM`0];Bd0AdM706AT
I00I6AT06a/K05UIF@1/K6`06ATI059BDP0i>CT0=SHf04Q8B028R8P0ATI602<S8`17AdL08b<S02l_
;`2CTi<0YZJV02/[:`0U9BD0AdM704A4A015ADD0Shn?05eMG@0M7Ad08b<S03hn?P17AdL0H61P07Ad
M00N7Qh00P0b<S804020P800BTY:05MGE`1dM7@09BDU02PX:01`L700SHf=03dm?@1;Bd/0NWYj02/[
:`0/;2`0@d=305IFEP0X:2P204];B`0>02XZ:P0];Bd0EEEE06QXJ00e=CD0FEUI04];B`1<C4`0G5aL
06UYJ@0a<C408B4Q03`l?01EEED206IVIP1B04U9B@0K6a/09bLW04M7A`1LG5`0F5QH06UYJ@0V9RH0
:2PX079bLP1RHV80BDU908N7Q`0];Bd051@D051@D02SXj<0Fe]K06i^KP1PH600:BTY038b<P1=CDd0
IVIV04Y:BP1JFUX0EeMG01TI6@0e=CD0De=C06e]K@1;Bd/0BTY:04];B`0K6a/0?Shn06YZJP23Ph<0
AdM7051@D00n?Sh06ATI03`l?029RHT0Lg=c03dm?@1@D500=SHf02TY:@1^KVh0Lg=c02d];@0^;Rh0
BDU90410@01HF5P0/K6a06YZJP0/;2`0CDe=03Hf=P1HF5P0ZJVY06i^KP0a<C40De=C055AD@18B4P0
YJFU0;:b/P0g=cL0;Rh^055AD@0k>c/0GemO06MWI`0U9BD0?clo05UIF@1<C4`0AdM709JFUP80=3@d
05/0DE5A07emO@1CDe<0Ti>C05MGE`0_;bl0Jf][07YjNP0j>SX0KVi^04m?C`0_;bl0De=C09ZJVP2:
RXX0>SXj07UiN@10@400=CDe06e]K@27QhL0=cLg03Hf=P1:BTX0DU9B04m?C`2<S8`0GUiN02HV9P1M
GEd0G5aL05YJFP1VIVH0QhN703/k>`0_;bl0CTi>0410@01HF5P0FEUI08J6QP14A4@09bLW04];B`13
@d<0EEEE05QHF02RXZ80=cLg02LW9`1CDe<0JVYZ05UIF@2BTY80RHV9030`<00W9bL0DE5A092@T02?
Shl0Vi^K06m_K`0M7Ad0;Rh^05EEE@27QhL0Cdm?05UIF@1KFe/061PH03Lg=`1;Bd/0S8b<04m?C`14
A4@0C4a<01`L700h>3P0TI6A09NGU`0d=3@0FEUI06][J`1_Kfl0?Cdm06e]K@15ADD0EeMG04a<C00d
=3@0LG5a0080@4100600ADE50451@@1aLG40G5aL04m?C`15ADD0De=C05MGE`1<C4`0GEeM04m?C`1=
CDd0A4A4065QH@0g=cL0CTi>03@d=01=CDd0?Shn04i>CP1JFUX0DU9B04E5A@1;Bd/0De=C059BDP0o
?cl0C4a<04Q8B01JFUX0FEUI05MGE`1;Bd/0@41005YJFP1VIVH0EUIF04M7A`1YJFT0CTi>0451@@1;
Bd/0H61P01HF5P1DE5@0I6AT04e=C@1BDU80@d=3038b<P1BDU80@41003hn?P1>CTh0;Bd]04i>CP1G
EeL0HF5Q03@d=01CDe<0Fe]K07MgM`16ATH0LW9b051@D00l?3`0S8b<04U9B@12@T80C4a<024Q8@0j
>SX0=SHf02`/;01JFUX0=3@d03<c<`1EEED0BDU90451@@0g=cL0CDe=04E5A@0b<S80Bd];04i>CP0k
>c/09BDU04M7A`1@D500?Cdm03hn?P1CDe<0BDU901/K6`0^;Rh204];B`1J05=CD`0f=SH0?Shn04];
B`18B4P0ADE504M7A`1=CDd0FUYJ06MWI`14A4@0AdM705EEE@2CTi<0GEeM04Y:BP1]KFd0GemO08F5
Q@1VIVH0H61P04U9B@1ADE40De=C02LW9`1DE5@0De=C04m?C`14A4@0HV9R03De=@3>c/h0ZZZZ03@d
=02WYjL0V9RH08F5Q@2WYjL0QHF508j>SP2KVi/0GUiN06YZJP1KFe/0D51@06MWI`2?Shl0O7al02l_
;`12@T80DU9B03Hf=P0_;bl0DU9B06YZJP1GEeL0Cdm?05YJFP0m?Cd0AdM70451@@1mOGd0VYZJ03`l
?01/K6`0H61P02/[:`1IFET0PX:203dm?@1QHF40H61P04E5A@1UIFD0ADE50820P010@400De=C06EU
I@0/;2`0G5aL059BDP0E5AD0AdM704E5A@24Q8@0SXj>059BDP1WIfL09BDU0P14A4@0EP1iNGT0GEeM
03Ph>01BDU80:b/[03@d=01IFET0>SXj03@d=00f=SH09bLW07QhN01EEED0;Bd]04E5A@0U9BD0=3@d
04i>CP0`<300C4a<01hN7P1_Kfl0;Rh^04U9B@0[:b/0W9bL07inOP0o?cl0OWin08j>SP0X:2P0?Cdm
05MGE`1BDU80MgMg05UIF@1hN7P0EEEE05aLG014A4@0Bd];04m?C`0b<S80@41003<c<`12@T80J6QX
061PH00D51@0:b/[051@D00m?Cd0Ogmo03Lg=`0e=CD0:RXZ03lo?`1EEED06a/K0451@@0d=3@0C4a<
051@D00j>SX0=SHf03<c<`0m?Cd0@d=307=cL`1<C4`0@D5102TY:@1MGEd0I6AT0410@01:BTX0GemO
04e=C@1UIFD0GemO09VIV@1aLG40FEUI05aLG01JFUX0F5QH0P2GUiL07@1ZJVX0I6AT08J6QP1fMWH0
TI6A06YZJP1dM7@0Q8B404E5A@1@D500FEUI05QHF01XJ6P0FEUI061PH017AdL0MWIf04m?C`1jNWX0
<c<c04a<C00i>CT0IfMW04m?C`1:BTX0J6QX04m?C`1HF5P0L71`00;ooooo0000o`1eMGD0PH61065Q
H@1SHf<0QHF50451@@1SHf<0Cdm?05ADE01_Kfl0b/[:06YZJP1<C4`0FEUI05QHF01YJFT0T92@03@d
=00a<C40EeMG06e]K@2<S8`0UiNG03<c<`0Y:BT0?3`l07moO`1LG5`0P82005]KF`0c<c<0;Bd]06i^
KP1TI6@0FEUI09jNWP0T92@0?Shn0451@@1dM7@0J6QX075aL@2][Jd0=3@d0451@@1YJFT0F5QH0492
@P1RHV80F5QH01HF5P0b<S80C4a<04E5A@0d=3@0NGUi02d];@0H61P0@D5105EEE@0_;bl0A4A404e=
C@0a<C40@T92069RHP1CDe<06QXJ02XZ:P16ATH0CTi>05EEE@1HF5P06QXJ020P800h>3P0FUYJ08>3
P`1NGUh0Ng]k02DU9@0N7Qh0I6AT0861P@1CDe<0K6a/0:>SX`0V9RH0:b/[06=SH`1lO7`0>CTi08:2
PP1_Kfl06QXJ03lo?`1KFe/0Hf=S051@D01VIVH09BDU01XJ6P1=CDd0VYZJ06UYJ@0l?3`0EeMG01TI
6@0_;bl0EUIF09bLW00l?3`0?Cdm04=3@`0[:b/0>c/k0861P@1fMWH0;Rh^07UiN@0];Bd0:b/[06YZ
JP1[Jf/0@41003Hf=P1@D500=3@d05MGE`1KFe/0VYZJ07EeM@0S8b<0Cdm?05IFEP11@D40L71`0:>S
X`0U9BD09RHV04i>CP1OGel0B4Q80:6QX@1gMgL07AdM05=CD`1QHF40F5QH06QXJ02GUiL0=cLg03Ph
>01RHV80IfMW03De=@1WIfL0PH61030`<00j>SX0M7Ad02LW9`1:BTX0MGEe034a<@11@D40LG5a05mO
G`0l?3`0G5aL034a<@0n?Sh0E5AD07moO`0_;bl09BDU04i>CP1:BTX0ADE507=cL`2NWYh0E5AD01/K
6`1EEED0GUiN06EUI@1eMGD0Kfm_01dM7@0P8200A4A407MgM`1PH600QhN706][J`0Q8B40:BTY04A4
A01SHf<0De=C09NGU`0`<300<C4a06YZJP1QHF40D51@06EUI@26QXH0:b/[03Ph>02JVYX0ZJVY04U9
B@1TI6@0820P04];B`21PH40QXJ604e=C@1aLG40<S8b02DU9@1CDe<0V9RH06ATI01:BTX0LW9b02TY
:@0e=CD0Q8B40492@P1>CTh0HV9R02<S8`1CDe<0][Jf07IfMP0`<300Bd];03dm?@1?Cdl0R8R808Z:
RP0k>c/0HF5Q03hn?P1;Bd/0X:2P04U9B@0Y:BT0A4A4075aL@1PH600EUIF0;Jf]P00K`16ATH0CTi>
06EUI@2DU9@0T92@08j>SP1oOgl0<C4a03dm?@1eMGD0YZJV06YZJP2BTY80Hf=S03@d=015ADD0MgMg
07YjNP1VIVH0_kno06UYJ@0I6AT0BTY:07MgM`1dM7@0De=C0:^[Z`1JFUX06a/K04Y:BP1cLg<0NGUi
03`l?01`L700;Bd]03@d=01<C4`0MGEe05=CD`18B4P0GEeM01PH600c<c<0S8b<09VIV@12@T80;Bd]
051@D018B4P0A4A4092@T02GUiL0;2`/034a<@0l?3`0D51@07IfMP1aLG40FEUI02@T900S8b<0=3@d
05]KF`1QHF40HV9R06MWI`1LG5`0BTY:0820P01_Kfl0E5AD03/k>`19BDT0WYjN07=cL`0c<c<0ADE5
05UIF@2MWId0PX:206QXJ01DE5@0KFe]07EeM@1UIFD0HV9R0410@01DE5@0>c/k04A4A01>CTh0JVYZ
05MGE`13@d<09bLW05ADE02=SHd0E5AD034a<@1;Bd/0HF5Q06YZJP16ATH0@D5105UIF@2CTi<0OWin
04E5A@1:BTX0=3@d02h^;P0203lo?`0n05eMG@1DE5@0@d=302XZ:P1ADE40D51@02`/;00b<S80D51@
04a<C01BDU80@T9203<c<`0m?Cd0<c<c03/k>`1QHF40Cdm?04];B`1HF5P0HF5Q05IFEP1GEeL0FEUI
07MgM`1FEUH0PX:205eMG@1:BTX0LW9b05aLG01OGel0FEUI03Ti>@1IFET0EEEE05IFEP1;Bd/0=SHf
03De=@1?Cdl0;Rh^0410@00j>SX0A4A404i>CP0i>CT0@d=302h^;P0d=3@0:BTY03/k>`0_;bl0@D51
04=3@`0k>c/0@D5103<c<`0j>SX0C4a<038b<P12@T820410@01Z05UIF@10@400C4a<05YJFP1]KFd0
FEUI05ADE015ADD0Bd];04U9B@0g=cL0>SXj02h^;P1>CTh06ATI0451@@13@d<0EEEE04Y:BP0I6AT0
>3Ph01hN7P19BDT0;bl_05=CD`15ADD0JVYZ051@D01[Jf/0E5AD03De=@1OGel0Lg=c09:BTP2GUiL0
IfMW04Y:BP1XJ6P0IfMW0:f][@2:RXX0B4Q804=3@`0o?cl0EUIF02/[:`0f=SH0:b/[03De=@1@D500
=CDe03Lg=`0j>SX0=3@d05YJFP16ATH0Fe]K02XZ:P0j>SX0CTi>03De=@18B4P0DE5A04e=C@2;Rh/0
Zj^[03Xj>P0h>3P0Bd];05QHF01iNGT0>CTi07EeM@18B4P0IfMW07]kN`0i>CT0@D5103dm?@0X:2P0
Jf][05]KF`16ATH0Bd];03hn?P19BDT0B4Q806EUI@1>CTh0De=C051@D01DE5@0J6QX04i>CP0i>CT0
?Cdm04M7A`1:BTX0GEeM04A4A01OGel0AdM703<c<`1EEED0ADE503Ti>@80De=C0680JVYZ02@T901E
EED0?clo05MGE`12@T80H61P05QHF00f=SH0C4a<05MGE`0l?3`0BDU904m?C`12@T80BDU905aLG01e
MGD0@D51051@D01?Cdl0BTY:05=CD`17AdL0@T9204A4A01MGEd0AdM704E5A@0E5AD0:RXZ06i^KP0Z
:RX0CDe=024Q8@1WIfL0>3Ph04E5A@1JFUX0:BTY04e=C@0l?3`0>c/k04I6AP0m?Cd0B4Q804i>CP1<
C4`0EEEE0820P00d=3@0PH6105MGE`16ATH0Bd];03hn?P1ZJVX0FUYJ03Ph>01FEUH0<C4a04M7A`10
@400GemO0410@01WIfL0PH6104m?C`1fMWH0KFe]07inOP2>SXh0TI6A0<K6aP2][Jd0/;2`07emO@18
B4P0De=C03dm?@0d=3@0AdM704];B`1GEeL0DU9B05QHF00i>CT0LW9b05ADE01LG5`0<C4a04Y:BP1A
DE40>c/k05=CD`13@d<0G5aL075aL@;ooooo00009P1fMWH0d];B051@D01`L700QXJ607EeM@2a/K40
GEeM03lo?`1EEED0KFe]08V9R@2^[Zh0MgMg02XZ:P0e=CD0FUYJ051@D01]KFd0QHF502/[:`0a<C40
NWYj05iNGP11@D40FEUI03`l?00Y:BT0EEEE09nOW`0o?cl0>c/k0410@00V9RH0<30`08J6QP1fMWH0
;Bd]0P0h>3P0<P0Y:BT0>3Ph07IfMP19BDT06ATI04=3@`16ATH0=cLg096AT@2g]kL0:b/[028R8P1I
FET0?Cdm04];B`2n_[h0MWIf00h>3P0k>c/0GemO04a<C02>SXh0Zj^[020P800Y:BT0GEeM061PH012
@T80FEUI07IfMP0Y:BT0;Bd]06MWI`1[Jf/0:RXZ03Hf=P16ATH09BDU03Ph>01FEUH0EEEE038b<P1Q
HF4092@T01dM7@0i>CT0H61P04U9B@0h>3P0Fe]K0P0^;Rh0o`14A4@0K6a/020P800P8200;Rh^034a
<@1EEED0LW9b05=CD`0G5aL0<c<c03Lg=`0b<S80Hf=S08V9R@0Q8B406QXJ02/[:`1OGel0GEeM05aL
G01ZJVX06a/K02h^;P0j>SX0F5QH04I6AP2a/K40CTi>01XJ6P0n?Sh0HF5Q03dm?@1BDU80MgMg03De
=@0J6QX09RHV05UIF@2^[Zh0EeMG06a/K00_;bl09BDU03lo?`1RHV80Lg=c03<c<`1gMgL08R8R020P
801CDe<0S8b<038b<P0n?Sh0J6QX01LG5`0i>CT0S8b<07UiN@0^;Rh0?3`l03Lg=`0[:b/0ADE50:>S
X`1@D5009bLW06MWI`13@d<0EUIF0;2`/011@D408B4Q05QHF01cLg<0Hf=S09bLW01_Kfl071`L03Lg
=`1mOGd0IVIV071`L023Ph<0DU9B01lO7`15ADD0Rh^;07alO01OGel0O7al02HV9P10@400GUiN05aL
G01>CTh0KVi^08>3P`0l?3`0@D5106QXJ01^KVh0=cLg05QHF01VIVH0<S8b03Ti>@1TI6@0K6a/01/K
6`1?Cdl0GemO02<S8`1FEUH0WYjN04];B`14A4@0G5aL03Ph>019BDT0TI6A04a<C00O7al0H61P05eM
G@1@D500Vi^K05]KF`0Z:RX0A4A4061PH01DE5@0K6a/0:VYZ@0d=3@0820P04Q8B01;Bd/0LG5a0:2P
X00J6QX0<c<c08>3P`1UIFD0I6AT09RHV00/;2`0;Bd]06IVIP2?Shl0D51@08f=S@0n?Sh0:2PX05aL
G01kNg/0=3@d07MgM`2JVYX0<C4a03/k>`1_Kfl0FUYJ03lo?`1jNWX0=CDe03dm?@1XJ6P0V9RH05MG
E`1=CDd0SHf=03`l?01>CTh0IFEU0820P00f=SH0>SXj04Q8B00h>3P0HV9R06m_K`2BTY80E5AD02/[
:`1HF5P0>CTi03hn?P1nOWh0]kNg05ADE00b<S80DU9B055AD@19BDT0P82004E5A@0S8b<0=SHf06i^
KP1KFe/0KVi^0:^[Z`0/;2`06ATI03De=@1VIVH0SXj>07MgM`1lO7`0>CTi03Xj>P0h>3P0FEUI04e=
C@1TI6@0Q8B401/K6`0P8200>CTi03<c<`10@400FUYJ05]KF`11@D40;Bd]06a/K01DE5@0FUYJ05EE
E@1?Cdl0De=C059BDP10@4008R8R04i>CP10@400<C4a04M7A`13@d<0Cdm?0410@01bLW80Jf][055A
D@0m?Cd0@T9204m?C`11@D40<c<c03/k>`1WIfL0B4Q804A4A000>00m?Cd0GemO0410@011@D40C4a<
06IVIP1[Jf/0FUYJ04a<C01RHV80GemO04A4A00f=SH0?3`l05QHF00m?Cd0=cLg02XZ:P18B4P0DU9B
04Y:BP0];Bd0BTY:03hn?P0T92@0<c<c0492@P0S8b<0>CTi0492@P0m?Cd0E5AD03De=@0];Bd0>3Ph
04I6AP1BDU80@T9202DU9@11@D40DU9B03Hf=P0[:b/0;2`/065QH@14A4@0=CDe03hn?P1@D500EEEE
04Q8B00_;bl0>SXj055AD@1EEED0E5AD0P0V9RH0401IFET0DU9B04a<C01JFUX0;2`/04i>CP16ATH0
@d=304I6AP1>CTh0CDe=03Xj>P0d=3@0?Shn04m?C`1=CDd3055AD@1W04Q8B00Y:BT0@d=305eMG@0i
>CT0DU9B04M7A`1CDe<0BTY:05mOG`17AdL0BDU903/k>`18B4P0DE5A04Y:BP1OGel0EEEE05ADE01N
GUh0DU9B071`L00X:2P0EeMG04];B`11@D40ADE501/K6`12@T80=SHf05UIF@11@D40H61P05IFEP26
QXH0CTi>0::RXP1kNg/0A4A406ATI01PH600Shn?09>CT`1/K6`0GEeM06EUI@0o?cl0Cdm?065QH@1/
K6`0P82004i>CP1YJFT0Lg=c05EEE@0c<c<0@D5103Hf=P15ADD0C4a<0451@@1SHf<0GEeM03/k>`1E
EED0Bd];04Y:BP1XJ6P0BTY:05MGE`1]KFd0<C4a04Y:BP1?Cdl0BTY:05=CD`1LG5`0?Shn04m?C`0c
<c<0Ti>C04a<C00j>SX0Bd];02h^;P1]KFd0Fe]K01lO7`13@d<0=CDe05ADE01BDU80De=C05iNGP0b
<S80>c/k03<c<`1EEED0De=C03Hf=P1<C4`09BDU03lo?`0203`l?01]038b<P1@D500ADE505IFEP14
A4@0>c/k051@D00g=cL0ATI606i^KP0k>c/0G5aL01PH601QHF40>3Ph05ADE010@400Ph>306QXJ00i
>CT0NGUi079bLP0D51@0A4A405=CD`0o?cl0Hf=S04Y:BP1TI6@0D51@05ADE013@d<0>3Ph04a<C00a
<C40ADE503Lg=`1FEUH0AdM703hn?P0F5QH0?Cdm05MGE`0n?Sh0G5aL01hN7P0a<C40@d=304I6AP1H
F5P09RHV04];B`0j>SX0ADE5055AD@1<C4`0H61P07QhN01fMWH0>c/k03hn?P0_;bl0>c/k02PX:01C
De<0MgMg03dm?@1QHF40MgMg06i^KP1HF5P0Ng]k08:2PP27QhL0Ogmo08B4Q02HV9P0N7Qh06QXJ02_
[jl0OWin0:j^[P31`L40fMWI0>o_k`1@D500EUIF065QH@1NGUh0Jf][04A4A019BDT0Kfm_05=CD`1/
K6`0BTY:069RHP1TI6@0MgMg06YZJP1UIFD0?clo06QXJ02ATI40FUYJ05UIF@1>CTh0KFe]07UiN@02
ooooo`000640FEUI096AT@1eMGD0LG5a05ADE01ZJVX0MWIf079bLP0i>CT0L71`059BDP1QHF40MgMg
08F5Q@0c<c<0A4A40492@P1TI6@0MgMg0:FUY@0a<C40:b/[0451@@1]KFd0Cdm?07AdM00o?cl08b<S
02`/;01mOGd0K6a/07AdM01XJ6P07QhN04Y:BP0k>c/0K6a/055AD@1dM7@0Fe]K01<C4`0a<C40ATI6
05]KF`0o?cl0Ng]k04];B`0Q8B40;Rh^059BDP0g=cL0D51@06QXJ00S8b<0;Bd]03`l?01mOGd0BTY:
051@D00l?3`09bLW02l_;`1JFUX0BDU904a<C01=CDd09BDU04=3@`1JFUX0Jf][024Q8@0R8R80<c<c
04];B`1EEED0OGem07EeM@0M7Ad08R8R02LW9`11@D40FEUI0:6QX@1>CTh061PH0451@@0k>c/0DE5A
07emO@3;bl/0@410018B4P0j>SX0ADE502`/;01SHf<0TI6A008092@T05@0@D5105ADE00b<S80QXJ6
05]KF`0P8200>CTi075aL@1IFET0ATI607EeM@0f=SH0:BTY04i>CP1jNWX0BTY:03Hf=P14A4@05aLG
03<c<`1JFUX0GUiN02XZ:P0i>CT0EUIF01lO7`1IFET0Zj^[08R8R00d=3@0;bl_04i>CP0a<C40DE5A
0:n_[`1>CTh06QXJ04A4A01JFUX0>SXj04a<C033`l<0FUYJ018B4P1=CDd0Hf=S055AD@2;Rh/0Y:BT
02TY:@0U9BD0Hf=S069RHP1BDU80RXZ:06ATI00K6a/0@T9204a<C01XJ6P0L71`07=cL`0J6QX0<C4a
05ADE01XJ6P0D51@061PH00E5AD0>c/k04];B`1fMWH0@T9204E5A@1`L7009BDU034a<@21PH40OGem
030`<00];Bd0>c/k034a<@0h>3P207QhN01V02<S8`0f=SH0BDU904m?C`2?Shl0TI6A03hn?P0Y:BT0
ATI605UIF@0a<C40MgMg0;Vi^@0c<c<0:2PX03lo?`1CDe<0Bd];0:6QX@1mOGd092@T03Xj>P1SHf<0
H61P09:BTP2j^[X0:b/[0451@@1:BTX0LW9b05QHF02][Jd0;bl_04Y:BP1oOgl0QXJ606m_K`1lO7`0
Fe]K02TY:@1>CTh0YJFU08N7Q`1EEED0@41001dM7@15ADD0YZJV06=SH`0f=SH0GEeM03<c<`0m?Cd0
UIFE05eMG@0U9BD0@41003`l?012@T80QhN708j>SP0T92@0Cdm?04M7A`12@T80JVYZ0<;2`P1<C4`0
>SXj07UiN@1QHF40GEeM0:2PX026QXH0:2PX04U9B@2GUiL0LG5a06a/K02f][H0FEUI02LW9`1GEeL0
/[:b05YJFP1EEED0Ogmo024Q8@0e=CD0EEEE08f=S@1nOWh0Fe]K09fMW@0e=CD0@41005aLG02DU9@0
O7al06MWI`1gMgL08B4Q0P1MGEd0<`18B4P0=cLg059BDP10@4007alO06m_K`2JVYX0I6AT04=3@`1U
IFD0BDU902DU9@1CDe<0H61P059BDP0[:b/0A4A402d];@19BDT0BTY:096AT@1[Jf/09BDU03Xj>P0e
=CD0<c<c07inOP2YZJT0?Shn02XZ:P1TI6@0Ogmo096AT@17AdL0G5aL03lo?`1MGEd0IFEU01TI6@1/
K6`0C4a<03Ph>01MGEd0Cdm?07AdM01XJ6P0M7Ad07inOP1QHF40D51@03dm?@0204=3@`1?03lo?`0e
=CD0>3Ph03Ti>@1>CTh0?3`l03lo?`0h>3P0CTi>065QH@1;Bd/0<S8b05ADE01KFe/0Cdm?04a<C01M
GEd0@D51051@D012@T80?3`l0410@00];Bd0@d=304U9B@0m?Cd0<30`04Q8B01@D5009bLW04I6AP18
B4P071`L06i^KP1XJ6P0Bd];04E5A@14A4@0<30`04i>CP0n?Sh0;Bd]04I6AP0e=CD0CTi>04=3@`1C
De<0@D5102/[:`10@400HF5Q0492@P1ZJVX0Cdm?03Xj>P1bLW80BTY:04E5A@1=CDd07AdM04=3@`0W
9bL0;Rh^04E5A@0Q8B407alO03Xj>P0X:2P0=3@d02LW9`12@T80;Bd]02@T900l?3`0>SXj02h^;P0Q
8B40<c<c04];B`02034a<@0N04=3@`14A4@07QhN02/[:`14A4@0CTi>0410@00j>SX0AdM705QHF00n
?Sh0B4Q804M7A`1FEUH0Cdm?06ATI00j>SX0?Cdm04M7A`1iNGT0CDe=03De=@1?Cdl0Fe]K07IfMP1=
CDd0?clo05]KF`0^;Rh0EUIF0P0i>CT0J@0a<C40BDU905MGE`25QHD0EUIF0;no_`2@T900=3@d06YZ
JP2GUiL0IFEU071`L020P800Vi^K07AdM01BDU80IFEU05IFEP0o?cl0GEeM055AD@1LG5`0;bl_03Ph
>011@D40ATI605YJFP0_;bl0Bd];05ADE00];Bd0;bl_030`<01IFET0<S8b04A4A01JFUX0?3`l04E5
A@1[Jf/0=CDe061PH01[Jf/0?Shn05MGE`1IFET0;Bd]05aLG01<C4`0RHV9059BDP1GEeL0FEUI04];
B`0b<S80?3`l030`<01>CTh0HV9R05IFEP1DE5@0?3`l05EEE@0a<C40@d=3051@D01UIFD0IVIV04U9
B@1EEED0>SXj03/k>`1<C4`0DE5A04A4A01LG5`0EEEE06][J`0i>CT0B4Q805mOG`0V9RH0B4Q806AT
I00m?Cd0E5AD0492@P23Ph<0Fe]K05EEE@17AdL0T92@07EeM@0f=SH0Jf][069RHP0I6AT0Cdm?07]k
N`11@D40Hf=S04Q8B01oOgl0FUYJ061PH002059BDP1<04i>CP0l?3`0DE5A03dm?@1HF5P0IfMW05YJ
FP0K6a/0?clo04a<C00n?Sh0QXJ603<c<`14A4@0ATI605UIF@1TI6@09RHV0451@@0k>c/0B4Q805iN
GP0h>3P0Bd];04E5A@17AdL0@D5107emO@0M7Ad0ADE503lo?`10@400BDU906m_K`1>CTh0AdM704m?
C`2:RXX0?Cdm055AD@1KFe/0C4a<04A4A01QHF40E5AD08b<S02MWId0>CTi04I6AP1?Cdl0@d=307Qh
N01IFET0MgMg079bLP14A4@0EUIF06][J`1bLW80Fe]K03De=@19BDT0JVYZ07AdM01=CDd0GEeM04M7
A`1_Kfl0M7Ad06EUI@1=CDd0BTY:05ADE01WIfL0Ph>306=SH`;ooooo00009P1@D500LW9b0861P@2X
Z:P0IVIV0451@@1PH600Rh^;071`L02QXJ40MgMg04Y:BP1PH600LW9b04Y:BP2LW9`0Fe]K038b<P16
ATH0M7Ad05mOG`28R8P0M7Ad03@d=00h>3P0JVYZ0820P01=CDd0BTY:03Ph>00a<C40C4a<07UiN@0j
>SX0<30`04I6AP0j>SX0;Bd]0P28R8P0o@0];Bd0>CTi071`L00W9bL0<c<c079bLP1TI6@08R8R04m?
C`0i>CT0:b/[04e=C@2BTY80D51@02PX:01<C4`0=CDe04];B`1ZJVX0N7Qh02`/;01;Bd/0ATI603hn
?P2>SXh0];Bd02HV9P0W9bL0BTY:05YJFP0k>c/0L71`09FEU@0O7al08B4Q04i>CP1nOWh0I6AT07Yj
NP2<S8`05QHF02l_;`1ZJVX0IFEU030`<02o_kl0L71`01TI6@1:BTX0JFUY0861P@0e=CD0P82002l_
;`0S8b<0?3`l061PH00^;Rh0<S8b05QHF00O7al0;Bd]0820P01PH6009RHV02XZ:P12@T80=3@d038b
<P1mOGd0J6QX01dM7@0`<300CDe=05UIF@1WIfL0MWIf020P800Q8B40AdM7071`L01DE5@0NWYj06YZ
JP0I6AT0:RXZ07IfMP2g]kL0>3Ph05aLG01lO7`07alO03Ph>01[Jf/0SHf=03<c<`1eMGD0GemO02@T
900g=cL0GemO06ATI00o?cl0YZJV02d];@0a<C40E5AD08F5Q@1BDU80ADE505aLG00k>c/0DE5A06MW
I`2TY:@0<30`02h^;P1FEUH0>c/k05aLG02^[Zh09bLW02/[:`1@D500?Cdm05=CD`2XZ:P0Bd];02h^
;P1SHf<0O7al05YJFP1mOGd0]KFe02`/;00f=SH0BTY:06IVIP1TI6@0LG5a06QXJ00C4a<0>c/k04=3
@`1`L700IFEU06m_K`0k>c/05QHF03Ph>01YJFT0MWIf04M7A`21PH40IfMW024Q8@10@400C4a<05aL
G014A4@0IfMW02h^;P0O7al0EUIF07moO`0a<C40DU9B05=CD`0];Bd0?clo09VIV@1jNWX0=cLg05]K
F`0a<C40=SHf0861P@25QHD0<c<c05YJFP1[Jf/0Kfm_08j>SP1^KVh0=cLg03lo?`1PH600Bd];08N7
Q`21PH407alO03@d=01FEUH0KVi^05aLG02WYjL0@T9202/[:`21PH40MGEe05EEE@1mOGd08b<S03Ti
>@1?Cdl0Ng]k05IFEP2d];@0@D5102TY:@16ATH0EeMG06EUI@1QHF40WIfM02h^;P11@D40AdM709JF
UP1MGEd0IfMW04=3@`0^;Rh0?Cdm059BDP1VIVH0ADE507QhN01PH600@D5104M7A`1?Cdl0EeMG0410
@01FEUH0?3`l02l_;`0i>CT0Hf=S04m?C`0a<C40CTi>03Xj>P0i>CT0HF5Q06e]K@0b<S80?Cdm065Q
H@0k>c/0ATI6092@T024Q8@00P0/;2`0A@1aLG40JVYZ06EUI@29RHT0IVIV028R8P0/;2`0Bd];05AD
E01QHF40WYjN04E5A@0[:b/0>CTi04U9B@23Ph<0FEUI08^;R`1PH6008B4Q03Ti>@1CDe<0CDe=05AD
E01ZJVX0Cdm?03lo?`0f=SH0P82006IVIP1:BTX0<C4a03@d=01aLG40IFEU02TY:@0o?cl0ATI607Ui
N@1FEUH0JVYZ05ADE01SHf<0K6a/04m?C`1HF5P0ATI6051@D018B4P0C4a<04Y:BP1PH600De=C05MG
E`0m?Cd0Hf=S08J6QP1SHf<0?Shn05]KF`1CDe<0QXJ604];B`1=CDd0FEUI08R8R01jNWX0CTi>04I6
AP0204A4A00B069RHP1GEeL0>SXj05IFEP19BDT08B4Q03lo?`1?Cdl04Q8B02l_;`11@D40G5aL05=C
D`0m?Cd0BTY:04m?C`0g=cL0<c<c0P1HF5P01P12@T80GEeM03/k>`17AdL0<C4a04m?C`80AdM70?@0
GemO04=3@`0o?cl0EUIF06=SH`1PH600CDe=03dm?@1KFe/0AdM704Q8B013@d<0:RXZ02h^;P0g=cL0
>3Ph034a<@0V9RH0>3Ph02d];@0/;2`0<C4a038b<P0^;Rh0;bl_02XZ:P0m?Cd0?3`l03Xj>P0n?Sh0
>c/k030`<00_;bl0@41003De=@0i>CT0AdM703dm?@16ATH0?3`l04Q8B01ADE40H61P0492@P16ATH0
ADE5079bLP1GEeL0AdM704i>CP0n?Sh0FEUI02`/;018B4P0>3Ph0451@@19BDT09BDU03`l?00];Bd0
?Shn0451@@0k>c/0Bd];04m?C`1CDe<0[Jf]08R8R00_;bl0Ogmo07=cL`1lO7`0R8R8059BDP10@400
M7Ad071`L023Ph<0MGEe04U9B@1aLG40Ng]k07QhN00n?Sh0CDe=05YJFP11@D40LG5a02d];@1UIFD0
JVYZ03Ti>@12@T80;Bd]055AD@1<C4`0Kfm_08Z:RP0l?3`0?Shn04a<C01EEED0GemO07QhN01LG5`0
?Cdm04A4A00/;2`0GEeM02XZ:P1TI6@0=3@d04Q8B01PH600BDU903lo?`1=CDd0820P04M7A`1MGEd0
Cdm?0492@P0h>3P0Cdm?05aLG01GEeL0HF5Q05IFEP1IFET0G5aL07moO`1ADE40>3Ph03dm?@15ADD0
Ti>C07MgM`0b<S80:BTY038b<P1gMgL0RXZ:03lo?`11@D40DE5A05ADE01lO7`0<30`061PH012@T80
I6AT06EUI@1TI6@0C4a<0492@P22PX80NWYj04Y:BP10@400Cdm?03hn?P1cLg<0E5AD059BDP1LG5`0
JFUY04=3@`0n?Sh0FUYJ02h^;P0d=3@0;Rh^065QH@10@400=cLg02PX:00n?Sh0@D5103Hf=P1>CTh0
9RHV06YZJP0h>3P0?3`l055AD@0c<c<0GUiN0492@P0`<300@T92059BDP1?Cdl0De=C03hn?P0];Bd0
BTY:03@d=018B4P0GemO04a<C01:BTX0?Shn05=CD`1FEUH0EeMG0410@00b<S80FUYJ065QH@1JFUX0
CTi>07inOP1CDe<0ADE507alO00O7al0IFEU05iNGP0l?3`0ATI60820P02NWYh0MGEe06e]K@1bLW80
?3`l03dm?@1<C4`0E5AD061PH010@400Cdm?03@d=029RHT0Cdm?055AD@1;Bd/0GUiN05IFEP1CDe<0
HV9R05ADE01RHV80WIfM0_ooool0003o0861P@2ZZZX0CTi>05mOG`2;Rh/0HV9R0:6QX@1BDU80@410
06a/K023Ph<0BTY:075aL@1:BTX0=cLg06IVIP28R8P0>3Ph06][J`1TI6@09RHV04Y:BP1cLg<0;Rh^
01hN7P14A4@0G5aL05]KF`22PX80DU9B02HV9P0Z:RX0G5aL07inOP20P800SXj>02HV9P0];Bd0?3`l
06QXJ017AdL0SXj>0<K6aP0S8b<06ATI05ADE01LG5`0CTi>08R8R01UIFD06ATI02PX:01_Kfl0M7Ad
06][J`1mOGd04a<C024Q8@0/;2`0HV9R04i>CP1CDe<0ATI601PH600b<S80JVYZ06UYJ@0];Bd0DE5A
04=3@`0Z:RX0Fe]K07emO@0m?Cd0820P03hn?P0_;bl09RHV06UYJ@2BTY809BDU01XJ6P0`<300=CDe
02HV9P1aLG40J6QX01TI6@0/;2`0ADE505MGE`17AdL0[jn_08f=S@0A4A40@d=306a/K01BDU80FEUI
092@T00h>3P04A4A04E5A@20P800HV9R06QXJ01^KVh04Q8B03@d=00m?Cd0K6a/04A4A01QHF40De=C
01TI6@1BDU80IfMW05]KF`17AdL0EeMG02DU9@0b<S80IVIV07emO@0_;bl09RHV03Lg=`0Z:RX0<S8b
05UIF@1mOGd0>SXj024Q8@1:BTX0=cLg02h^;P1lO7`0TI6A034a<@0_;bl0JVYZ03/k>`0a<C40]kNg
08R8R00O7al0:BTY05YJFP19BDT0EUIF0:^[Z`1>CTh09bLW05QHF026QXH0MgMg06e]K@28R8P0>3Ph
034a<@2<S8`0RHV9051@D02>SXh0820P04=3@`1YJFT0IfMW05iNGP1LG5`0:b/[03Lg=`1>CTh0LG5a
06UYJ@0i>CT0HF5Q059BDP0b<S80Kfm_0861P@12@T80<c<c05EEE@0a<C40:BTY06a/K01iNGT09BDU
02/[:`1>CTh0@41004Q8B01cLg<0QHF502LW9`0f=SH0GEeM04E5A@1kNg/0U9BD03dm?@0W9bL0?Shn
059BDP15ADD0X:2P08>3P`0Q8B40>SXj04A4A01ZJVX0LG5a09:BTP0R8R80<c<c0492@P1fMWH0G5aL
05mOG`19BDT0820P04Q8B01LG5`0?Cdm06MWI`20P8009RHV04i>CP1iNGT0<S8b04m?C`1UIFD09BDU
04=3@`1eMGD0LW9b03Xj>P1bLW80CDe=03Xj>P25QHD0DU9B02<S8`16ATH0:BTY02`/;025QHD0NWYj
02@T901?Cdl0G5aL03<c<`1IFET0U9BD000:04m?C`0j>SX0Fe]K03lo?`1jNWX0UIFE06m_K`0[:b/0
EUIF05MGE`80CDe=05L0SXj>0:VYZ@0l?3`0De=C05QHF00m?Cd0JFUY0:f][@1YJFT08B4Q05ADE01O
Gel0>c/k061PH02UYJD0MgMg024Q8@1HF5P0YZJV03dm?@1aLG40_Kfm02l_;`0h>3P0M7Ad0;2`/01`
L700E5AD05iNGP0a<C40<c<c04U9B@1/K6`0?clo05MGE`1YJFT09BDU0492@P1LG5`0JFUY03Hf=P0g
=cL0DU9B01hN7P0h>3P0AdM706EUI@0S8b<0;Rh^04m?C`0n?Sh0@D5105QHF01TI6@0E5AD04Y:BP11
@D40>CTi055AD@1BDU806QXJ06a/K01BDU80;Bd]04E5A@1JFUX0GUiN05QHF028R8P0Ng]k05MGE`0j
>SX0=cLg05=CD`0f=SH0>SXj02HV9P14A4@0?Cdm05mOG`0a<C40B4Q804Y:BP1@D500CTi>059BDP0o
?cl00P16ATH02P1GEeL0HF5Q05UIF@1?Cdl0@D5105UIF@0i>CT0ADE503dm?@0l?3`2051@D01O05AD
E01OGel0BDU902TY:@19BDT0CDe=02TY:@0o?cl0FEUI02d];@0j>SX0<30`020P800j>SX0E5AD05EE
E@0l?3`092@T05=CD`1gMgL0De=C03lo?`17AdL0EUIF05aLG00e=CD0DE5A05IFEP1=CDd0NWYj03Xj
>P0h>3P0BTY:0492@P1BDU808B4Q01lO7`0m?Cd0<C4a038b<P1<C4`0;Bd]03Ph>00m?Cd0AdM704=3
@`0f=SH0BTY:0451@@1>CTh0>c/k04U9B@1HF5P0CDe=04i>CP1SHf<0CTi>03hn?P0i>CT0HV9R03/k
>`1ADE40@D5104];B`1<C4`0DE5A03Xj>P1ADE40ATI604m?C`1;Bd/0>CTi03@d=014A4@0De=C04=3
@`1BDU80NGUi03Ti>@1FEUH0AdM7071`L01FEUH07alO04I6AP1:BTX0FEUI03@d=014A4@0RHV907Qh
N01/K6`0Ph>3069RHP0W9bL00P1BDU80D`17AdL0Bd];04e=C@1/K6`0IVIV04=3@`1>CTh0Cdm?04=3
@`11@D40A4A405=CD`16ATH0>c/k02TY:@0h>3P0MgMg04A4A01DE5@0CDe=04A4A01;Bd/0BTY:06AT
I00k>c/0<30`04E5A@0a<C40CDe=05mOG`15ADD0PH6109^KV`13@d<0AdM705iNGP1@D500M7Ad03`l
?02?Shl0DE5A06EUI@1cLg<0@D5104E5A@1>CTh0B4Q807AdM01BDU80De=C055AD@1DE5@0JVYZ04A4
A00m?Cd0<c<c05UIF@1WIfL0>SXj05ADE00M7Ad0;bl_03De=@1:BTX0>c/k06a/K01YJFT0<S8b034a
<@1HF5P0GemO04I6AP13@d<0NGUi0492@P1NGUh0?Shn092@T01FEUH0IVIV05QHF01^KVh0Jf][0080
BTY:02P0Bd];03Ph>00n?Sh0EEEE04Q8B01@D500I6AT06MWI`1>CTh0F5QH061PH01KFe/0Bd];04I6
AP1EEED0A4A405QHF01`L700C4a<03@d=01NGUh0J6QX04=3@`1PH600<30`04E5A@1DE5@0Hf=S06QX
J00/;2`0C4a<05UIF@1DE5@0C4a<04=3@`14A4@0G5aL04];B`1UIFD0MWIf0P1FEUH0301@D500BTY:
05mOG`1>CTh0M7Ad08R8R01DE5@0FUYJ03dm?@1=CDd0Cdm?08R8R080HV9R01P0MGEe05=CD`22PX80
B4Q808b<S01bLW80BTY:06=SH`1KFe/0Lg=c06ATI00j>SX0CTi>04a<C017AdL0De=C03dm?@17AdL0
D51@05QHF01:BTX0GEeM0492@P1<C4`204i>CP0605EEE@1>CTh0GemO05IFEP1PH600JFUY0_ooool0
000X08R8R02^[Zh0G5aL05YJFP1/K6`0Kfm_0;jn_P1OGel0BDU905iNGP2IVIT0JVYZ0;fm_@1JFUX0
<C4a04e=C@2;Rh/0BTY:09NGU`23Ph<09bLW03`l?01fMWH0IfMW06a/K01YJFT09bLW030`<01RHV80
G5aL03/k>`1EEED0@D5101dM7@10@400C4a<04A4A00g=cL0IVIV03hn?P80<S8b0?l0GUiN05aLG00l
?3`0IFEU03Ti>@0e=CD0F5QH05=CD`0W9bL0AdM704U9B@0S8b<0Hf=S096AT@12@T806a/K02l_;`0X
:2P0<30`08N7Q`23Ph<06QXJ02XZ:P0j>SX0Bd];05YJFP2e]KD0OGem014A4@0k>c/0EeMG0492@P1M
GEd0WYjN04i>CP0H61P0Bd];04e=C@1:BTX0GUiN096AT@0G5aL09bLW04E5A@1<C4`0BTY:09FEU@2`
/;007QhN02/[:`13@d<0GEeM03lo?`19BDT0D51@01DE5@0[:b/0C4a<04A4A00H61P0@D51024Q8@0W
9bL0AdM705mOG`0e=CD06a/K04A4A00P82008B4Q04U9B@2@T900Cdm?02DU9@1NGUh0H61P05aLG01o
Ogl09BDU01lO7`0f=SH0DE5A0410@01gMgL0V9RH01hN7P0R8R80EEEE08f=S@1[Jf/0De=C0;Rh^00/
;2`061PH051@D02CTi<0IfMW06=SH`2BTY80;Rh^01dM7@1GEeL0XZ:R04e=C@1FEUH0GEeM03@d=01I
FET0Lg=c06e]K@19BDT0GUiN03dm?@0R8R80B4Q807moO`1KFe/0A4A403De=@0i>CT0Hf=S0861P@11
@D408R8R03hn?P0/;2`0FUYJ0:ZZZP19BDT08R8R034a<@1HF5P0DE5A05aLG02@T900A4A4034a<@0m
?Cd0BTY:03Ti>@1jNWX0Vi^K02d];@0d=3@0;bl_06EUI@1=CDd0T92@08V9R@0I6AT0<C4a03/k>`1N
GUh0EEEE07moO`2IVIT0820P02XZ:P1OGel0FUYJ03hn?P1WIfL0;Bd]028R8P19BDT0Ng]k03Ph>01>
CTh0H61P024Q8@1?Cdl0M7Ad06ATI00k>c/0LW9b02LW9`15ADD0RXZ:07=cL`0M7Ad0?Shn05EEE@0n
?Sh0N7Qh0<71`@1?Cdl0>CTi05eMG@1@D500Kfm_07inOP0I6AT09BDU05iNGP1dM7@0EUIF08f=S@0m
?Cd0=CDe05MGE`18B4P0@D5107emO@0^;Rh071`L04Y:BP1LG5`0<c<c07moO`1mOGd0=CDe05=CD`1L
G5`0Hf=S055AD@1^KVh0;Bd]04];B`2UYJD0/K6a05MGE`2?Shl0Ph>302DU9@0l?3`0Ogmo08n?S`1F
EUH0GemO05eMG@0`<300BTY:06][J`27QhL0FEUI04a<C01HF5P07AdM038b<P1WIfL0VYZJ05YJFP1O
Gel0D51@02TY:@1GEeL0Ph>305EEE@0Z:RX0?Shn04Y:BP1GEeL0K6a/07EeM@0m?Cd000d0:BTY03dm
?@14A4@0C4a<0:ZZZP2n_[h08b<S02HV9P1KFe/0EEEE04E5A@22PX80SXj>00807QhN00P0GUiN07Qh
N019BDT0E5AD06UYJ@0Z:RX0=SHf05]KF`80KFe]05@0@D5105QHF00o?cl0Hf=S06YZJP11@D40UYJF
08N7Q`0f=SH0=CDe04Y:BP21PH40IFEU04I6AP14A4@0CDe=06=SH`1GEeL0DE5A03lo?`1GEeL0B4Q8
04I6AP15ADD0K6a/04i>CP14A4@0=3@d06EUI@2IVIT0G5aL0410@01ZJVX0Rh^;06m_K`1CDe<0CDe=
05]KF`1WIfL0EEEE03De=@0l?3`0;Rh^04M7A`1=CDd0?clo02l_;`17AdL0BDU902l_;`12@T80FEUI
01dM7@0o?cl0L71`03lo?`1?Cdl0?clo03Xj>P1BDU80@d=302l_;`1:BTX0=3@d04Y:BP0n?Sh0CDe=
05IFEP16ATH0>CTi04A4A013@d<0CDe=04Y:BP0h>3P0DE5A04A4A015ADD0CTi>0451@@1DE5@0:RXZ
02d];@0j>SX2055AD@0K04A4A00d=3@0@41003`l?010@400:b/[03Hf=P0m?Cd0ADE503Lg=`0^;Rh0
=cLg05eMG@0m?Cd0@D5104Q8B01=CDd0<S8b0410@01=CDd0A4A404U9B@1=CDd0D51@05iNGP1EEED0
GEeM0080EEEE0<T0JFUY071`L00n?Sh0BTY:05IFEP1?Cdl0BDU903Ph>01QHF40ADE504i>CP15ADD0
:2PX04M7A`0K6a/0>SXj038b<P0d=3@0;bl_03/k>`19BDT0>3Ph05]KF`2TY:@0MWIf02XZ:P2ATI40
PX:205iNGP1dM7@0Ogmo096AT@1hN7P0CDe=059BDP18B4P0Fe]K069RHP1LG5`0I6AT06EUI@1JFUX0
<30`04=3@`1ADE40>c/k07alO01nOWh0O7al07=cL`0[:b/0ADE503Ti>@18B4P0De=C02/[:`15ADD0
FUYJ038b<P1=CDd0EEEE03lo?`1EEED0D51@03Ph>01UIFD0>CTi09JFUP14A4@0BDU905UIF@1;Bd/0
Hf=S05QHF00h>3P0CDe=055AD@1DE5@0Fe]K02h^;P13@d<0;Bd]04M7A`0i>CT0HF5Q04U9B@1BDU80
J6QX0492@P1?Cdl0Fe]K05UIF@1NGUh0F5QH04E5A@1JFUX0B4Q8061PH01RHV809RHV05mOG`23Ph<0
D51@05]KF`0`<300GEeM06ATI01;Bd/0DE5A0:2PX01cLg<0C4a<06][J`1MGEd0Bd];05mOG`2CTi<0
GEeM055AD@1UIFD0Rh^;04i>CP1ADE40EEEE05ADE01:BTX0B4Q804M7A`19BDT0A4A404i>CP1[Jf/0
;2`/04A4A00o?cl0Jf][09jNWP18B4P0GUiN04Q8B01eMGD0Ogmo04Q8B010@400B4Q805UIF@1CDe<0
EUIF07EeM@1WIfL0Hf=S07YjNP2VYZH0<C4a02TY:@17AdL0MWIf05aLG00b<S80DE5A04a<C01ZJVX0
UiNG05MGE`28R8P0GUiN04U9B@0k>c/0E5AD04a<C01lO7`0Vi^K051@D01BDU80H61P06a/K01^KVh0
IfMW08V9R@1PH600CTi>05QHF00h>3P0BDU903hn?P0i>CT0BTY:04E5A@1SHf<0AdM7096AT@1@D500
NWYj07UiN@1;Bd/0OWin05=CD`1MGEd0IfMW08:2PP1eMGD00_ooool0001>05EEE@2b/[80VYZJ0:6Q
X@1BDU80FUYJ05eMG@2XZ:P0Fe]K07AdM01=CDd0JFUY0861P@1YJFT0EeMG06QXJ010@400=cLg04a<
C02ATI40Bd];05mOG`1GEeL08b<S05EEE@2WYjL0FEUI034a<@1?Cdl0AdM7034a<@2ATI40WYjN0410
@00h>3P0EUIF02h^;P0m?Cd0/K6a0820P00^;Rh0=3@d05QHF011@D40DU9B0:b/[00o?cl071`L03Xj
>P1/K6`0=cLg06MWI`26QXH09RHV01XJ6P1EEED0BDU905ADE01jNWX09BDU01hN7P0j>SX0QhN703lo
?`14A4@0E5AD01lO7`0U9BD0C4a<07UiN@0o?cl0H61P05=CD`0U9BD0:RXZ051@D01/K6`0:BTY0P1;
Bd/0o`0f=SH0?3`l05aLG00m?Cd05QHF05eMG@0l?3`08R8R05ADE02MWId0ATI601lO7`1@D500B4Q8
02/[:`1UIFD0QHF5024Q8@0C4a<0=SHf0492@P1QHF40Rh^;04m?C`0R8R80;Bd]05UIF@17AdL0D51@
08B4Q00k>c/06a/K04E5A@1DE5@0FEUI05IFEP1TI6@05aLG02/[:`19BDT0HF5Q03Lg=`1iNGT0IVIV
02/[:`0b<S80S8b<07alO00Z:RX0IfMW05QHF00R8R80@T9209NGU`1<C4`07alO02/[:`15ADD0;2`/
05=CD`2KVi/0@41001/K6`0j>SX0BDU906e]K@1mOGd0JFUY01hN7P0^;Rh0M7Ad05ADE01/K6`0[Zj^
075aL@0O7al071`L05UIF@1jNWX0P82007=cL`0G5aL0Cdm?05iNGP1GEeL0BTY:06e]K@0Q8B407alO
05=CD`20P800B4Q806m_K`1UIFD0?3`l02LW9`22PX80X:2P04E5A@1TI6@0IVIV03<c<`0a<C40OWin
08J6QP0k>c/0GEeM04=3@`0k>c/0F5QH09bLW014A4@0<c<c055AD@17AdL0:RXZ061PH02ZZZX0?3`l
02l_;`1>CTh0B4Q804m?C`2BTY80@T9203Ph>00l?3`0>SXj04Y:BP1OGel0Ph>302/[:`0];Bd0HF5Q
05MGE`1gMgL0/[:b02LW9`0`<300K6a/09jNWP1PH600GEeM04I6AP0e=CD0De=C08b<S01VIVH0O7al
03`l?00`<300EeMG065QH@0h>3P0B4Q806MWI`0T92@0>c/k08R8R01YJFT0=SHf05ADE00h>3P0?clo
08n?S`1HF5P0;2`/05EEE@0o?cl0<30`06IVIP2PX:00;Rh^03Ph>01KFe/0B4Q808^;R`2NWYh0RHV9
02h^;P17AdL0FEUI03Ti>@2BTY80_kno055AD@0e=CD0GEeM07QhN01CDe<0R8R809FEU@0W9bL0:2PX
03Ti>@1LG5`0E5AD08B4Q02MWId0:BTY01lO7`0n?Sh0LG5a06=SH`2LW9`0KFe]01lO7`0`<300IVIV
06][J`1YJFT0Ph>307UiN@0];Bd0;2`/05eMG@1^KVh0F5QH07AdM01IFET07alO03dm?@23Ph<0JVYZ
03dm?@1;Bd/0ADE503@d=00o?cl0WYjN07moO`0T92@0@D5103Hf=P0S8b<0?Cdm07MgM`17AdL092@T
08F5Q@1dM7@0BTY:03`l?01oOgl0K6a/04a<C016ATH09bLW05IFEP0n?Sh0;bl_0492@P1JFUX0Lg=c
05mOG`00:@1NGUh0CDe=06=SH`16ATH0@T9205]KF`0g=cL0=3@d03`l?00g=cL0CDe=05YJFP12@T80
CTi>02/[:`11@D40EUIF05]KF`0b<S80A4A403dm?@1MGEd0EUIF059BDP1MGEd0LW9b06IVIP0k>c/0
H61P04e=C@0b<S80BTY:04E5A@1IFET0FUYJ03Ph>00W9bL0IVIV055AD@0O7al0:b/[0080ATI606T0
CDe=01dM7@0K6a/0<S8b05EEE@1ADE40>3Ph03@d=01=CDd0Lg=c05MGE`1YJFT0BDU9071`L01BDU80
>SXj04I6AP1GEeL0J6QX0820P01GEeL0E5AD05iNGP10@400J6QX04A4A011@D40=3@d03De=@0d=3@0
BDU904M7A`0k>c/0<30`03dm?@0c<c<0<30`02l_;`0T92@0=cLg03De=@0i>CT0=3@d04M7A`1?Cdl0
A4A403/k>`0g=cL0B4Q804a<C00d=3@0ATI603dm?@14A4@0EEEE04U9B@0d=3@0D51@06EUI@15ADD0
B4Q80492@P1:BTX0EEEE08n?S`1ZJVX0EUIF09BDU01OGel0EeMG05UIF@0k>c/0HV9R03lo?`0h>3P0
@T9204Q8B01BDU80De=C08J6QP1>CTh0N7Qh09bLW01iNGT0;2`/0410@017AdL0JVYZ096AT@1YJFT0
Cdm?06IVIP1fMWH0UiNG05iNGP0c<c<0FUYJ07AdM01]KFd0=SHf051@D01LG5`0B4Q8059BDP0m?Cd0
0P1JFUX0PP0e=CD0ADE50492@P1BDU80BDU908J6QP2FUYH0=CDe03/k>`1BDU80C4a<05]KF`1]KFd0
CTi>02h^;P10@400?clo05YJFP0[:b/0BTY:03`l?01BDU80Hf=S03lo?`0d=3@0>CTi02/[:`1FEUH0
EEEE04];B`1ADE40CDe=04m?C`0Z:RX0B4Q802/[:`1XJ6P0@410051@D01cLg<07AdM02XZ:P0i>CT0
<30`061PH01`L700=CDe0;jn_P19BDT0HF5Q08:2PP1ZJVX0=SHf04M7A`1?Cdl0NWYj05EEE@1dM7@0
@41006EUI@17AdL0I6AT0410@00X:2P0P82006EUI@0I6AT08b<S05MGE`0I6AT0BDU9051@D01WIfL0
E5AD06ATI01FEUH0CDe=069RHP0l?3`0@d=304A4A01SHf<0D51@04m?C`1MGEd0UiNG06m_K`0h>3P0
BDU904e=C@2CTi<0Kfm_07IfMP1bLW80>CTi069RHP1;Bd/0?3`l04=3@`1]KFd0I6AT0410@00d=3@0
>c/k05UIF@0m?Cd0<c<c034a<@17AdL0Bd];03lo?`1fMWH0Kfm_03<c<`0g=cL07QhN034a<@1RHV80
[Zj^07QhN02@T900NGUi051@D01cLg<0?clo07YjNP1HF5P0OGem0:f][@0i>CT2059BDP0E07YjNP23
Ph<0=cLg02LW9`0`<300EeMG05IFEP0_;bl0@T9204Q8B02b/[80=CDe04E5A@1iNGT0JFUY055AD@1>
CTh0JFUY059BDP1@D500Q8B400;ooooo00004`1JFUX0I6AT05]KF`2?Shl0IVIV04Y:BP1IFET0JVYZ
06MWI`2h^;P0HV9R038b<P1dM7@0IfMW05=CD`2EUID0Cdm?02DU9@0`<3000P20P800_@1aLG40Jf][
024Q8@0P8200H61P08R8R01@D500KVi^03<c<`14A4@0@D5104a<C00n?Sh0E5AD06i^KP0S8b<0;2`/
02l_;`1DE5@0?Cdm04m?C`1LG5`09BDU02l_;`16ATH0GEeM03Hf=P1LG5`0@D5102/[:`19BDT0IfMW
04a<C016ATH0HV9R02<S8`0Z:RX0NGUi04a<C00E5AD0>3Ph03Ti>@0b<S80LW9b0;Fe]@0X:2P07QhN
03`l?017AdL0=cLg09fMW@2WYjL04a<C02l_;`0f=SH0BDU90451@@2@T900KFe]01PH601GEeL0Lg=c
0492@P14A4@0UYJF05UIF@0B4Q80ATI606][J`1XJ6P0DE5A0;2`/018B4P0>3Ph05UIF@1LG5`0@T92
05EEE@1GEeL05ADE02l_;`0k>c/0J6QX03lo?`1SHf<0JVYZ01/K6`14A4@0FUYJ061PH00b<S80B4Q8
01lO7`0^;Rh0GUiN05QHF00m?Cd0<S8b051@D00V9RH092@T08:2PP1aLG4092@T02/[:`19BDT0DU9B
03<c<`2OWil0TY:B02<S8`0/;2`0Jf][06EUI@0i>CT0PH6106m_K`0E5AD0>3Ph059BDP1;Bd/0A4A4
08J6QP0b<S806QXJ05IFEP1VIVH0BTY:0410@028R8P0>3Ph02<S8`1DE5@0T92@04I6AP1dM7@0I6AT
02TY:@14A4@0Lg=c02DU9@13@d<0>SXj02HV9P1XJ6P0WinO03Hf=P0T92@0?3`l04E5A@0_;bl0QHF5
07AdM00V9RH07QhN04=3@`1YJFT0EEEE06UYJ@1`L7005ADE04Y:BP1@D500Q8B4055AD@2:RXX0MGEe
01/K6`1;Bd/0Ph>304=3@`1XJ6P0Ti>C04Y:BP0X:2P0@D5109RHV022PX80EEEE065QH@0V9RH0:RXZ
04M7A`1YJFT0IFEU07YjNP0[:b/092@T03`l?00205UIF@2F069RHP1XJ6P0:BTY03Ph>01YJFT0BDU9
028R8P1kNg/0ATI603hn?P1NGUh0IFEU02<S8`17AdL0@D5104A4A02?Shl0TI6A01LG5`11@D40FEUI
05]KF`1VIVH0TY:B02DU9@0Y:BT0FEUI06][J`1OGel0OGem02<S8`0];Bd0KVi^069RHP0m?Cd0LW9b
03Ti>@0P8200AdM707inOP14A4@0I6AT07MgM`0V9RH0;bl_07IfMP2HV9P0IFEU075aL@1RHV80EEEE
055AD@1MGEd0Ph>304e=C@2l_;`0<30`0492@P17AdL0IVIV05]KF`1UIFD0MgMg038b<P0l?3`0B4Q8
05]KF`1LG5`0D51@06UYJ@0k>c/0;Rh^07emO@2:RXX0BTY:051@D01QHF40=CDe03@d=01EEED0MWIf
034a<@0h>3P0>CTi028R8P1FEUH0Y:BT05iNGP0O7al0@D5104Q8B00^;Rh0HF5Q096AT@0m?Cd08b<S
028R8P0f=SH0GEeM04];B`2?Shl0D51@02TY:@1<C4`0CDe=05]KF`1?Cdl0De=C05eMG@1IFET0@T92
04=3@`0d=3@0Cdm?04];B`0G5aL0NWYj051@D00W9bL0C4a<06EUI@2GUiL0LG5a08>3P`1QHF40Jf][
05=CD`1<C4`0Hf=S02`/;00m?Cd0:b/[03<c<`1?Cdl0J6QX03Lg=`1;Bd/0@T9205MGE`1XJ6P0IfMW
03Lg=`1LG5`0GUiN0820P01PH600Ph>307IfMP1DE5@0G5aL0P0Y:BT08P0P8200<30`03dm?@1HF5P0
>3Ph04U9B@14A4@0>3Ph04M7A`1XJ6P0<30`02XZ:P1TI6@0=SHf04E5A@0X:2P07alO04m?C`14A4@0
>SXj03Lg=`0Z:RX0DE5A03dm?@15ADD0DU9B04A4A00g=cL0EEEE03hn?P1DE5@0BTY:02DU9@1FEUH2
03De=@0A05UIF@1BDU80CTi>028R8P0O7al0=cLg04e=C@19BDT0ADE502TY:@13@d<0?Shn03Lg=`0/
;2`0BDU90451@@0e=CD00P12@T804016ATH0ADE504a<C01JFUX0Bd];03Ti>@0d=3@0FEUI061PH00i
>CT0DE5A05YJFP1EEED0C4a<05=CD`1DE5@204I6AP2:061PH01lO7`0B4Q804I6AP1;Bd/0DE5A05IF
EP1OGel0Ph>306UYJ@1`L700=SHf055AD@18B4P0>3Ph038b<P0h>3P0?3`l02XZ:P0e=CD0ADE503Xj
>P19BDT0DU9B06=SH`14A4@0Q8B406e]K@1TI6@0OGem06QXJ01[Jf/0EEEE03Xj>P1BDU80@T920451
@@13@d<0ADE5055AD@0j>SX0>3Ph02d];@13@d<0GUiN03Lg=`1<C4`0Lg=c04=3@`1ADE40DU9B05=C
D`0c<c<06a/K03Hf=P0W9bL0=CDe059BDP0l?3`0LG5a09ZJVP1ADE40AdM7055AD@14A4@0LW9b020P
801bLW80?3`l055AD@1nOWh0G5aL04=3@`17AdL0>c/k08J6QP1UIFD0@d=306e]K@1?Cdl0IfMW02h^
;P0i>CT0?Cdm0820P01PH600:b/[02`/;00U9BD0AdM705EEE@0n?Sh09BDU03lo?`1:BTX0/k>c08J6
QP0Q8B40;bl_030`<01<C4`0P82002LW9`11@D40;bl_0:VYZ@1:BTX0:2PX03<c<`2QXJ40OGem03Hf
=P10@400@T92030`<00m?Cd0Jf][02d];@1EEED0DU9B08:2PP14A4@0CTi>07YjNP18B4P0?clo04M7
A`1>CTh0=SHf04Y:BP2HV9P0MgMg03@d=015ADD0A4A404m?C`2RXZ808B4Q0P0n?Sh09P1iNGT0O7al
03<c<`0e=CD0CTi>05ADE01:BTX0?clo05=CD`1KFe/0@d=305iNGP2?Shl0@D5105YJFP1HF5P0E5AD
05EEE@0Z:RX0D51@05MGE`0i>CT0F5QH03lo?`1ZJVX0>CTi03Lg=`0i>CT0?3`l04A4A01iNGT0QXJ6
0492@P1:BTX0=3@d030`<00h>3P0BDU90P1PH6005@0f=SH0AdM70451@@17AdL0@d=302PX:00c<c<0
<30`0410@00W9bL0A4A405aLG01dM7@0@D51065QH@2EUID0Hf=S05=CD`1_Kfl0Ng]k08^;R`02oooo
o`000?l0Shn?096AT@1?Cdl0MWIf06YZJP1WIfL0NGUi0492@P1EEED0Q8B408j>SP1KFe/0HF5Q03/k
>`16ATH0MWIf0;6a/@1EEED0JFUY05ADE010@400GEeM0:VYZ@1OGel0@d=30410@00^;Rh0E5AD08N7
Q`22PX80>CTi055AD@15ADD0ATI605mOG`1oOgl0?clo02l_;`1=CDd0?Cdm03Ph>01TI6@0TY:B02TY
:@0];Bd0CDe=055AD@1DE5@0RXZ:07YjNP0C4a<0<C4a05eMG@15ADD0Cdm?061PH00j>SX07AdM04I6
AP1hN7P0>SXj08F5Q@0g=cL07QhN02PX:01UIFD0=3@d02/[:`1WIfL08b<S02DU9@1<C4`0Q8B402l_
;`0d=3@0IFEU02LW9`0D51@0CTi>07emO@0[:b/07alO03De=@0K6a/05ADE05iNGP1PH6006QXJ03Lg
=`12@T80:BTY05aLG01;Bd/0E5AD01/K6`1:BTX0DE5A03<c<`1bLW80Z:RX04E5A@0F5QH0>SXj04E5
A@13@d<0RXZ:08n?S`0L71`0;Rh^03lo?`1?Cdl0E5AD0:2PX00a<C40820P030`<01RHV80FEUI05aL
G01gMgL0:b/[02DU9@19BDT0IfMW04A4A00g=cL0IFEU01/K6`0n?Sh0@d=307emO@1ZJVX0EEEE06a/
K00/;2`0:BTY04Q8B02;Rh/0FUYJ03Ti>@1dM7@0<C4a03Hf=P1cLg<0QXJ602TY:@0f=SH0I6AT0451
@@1>CTh0[jn_05mOG`0a<C40=cLg04Q8B01<C4`0UIFE09BDU00a<C40;2`/0820P00j>SX0LG5a07Ui
N@0R8R807alO04m?C`1OGel0FUYJ07]kN`0Z:RX0;Rh^03hn?P1aLG40P82004I6AP1oOgl0?3`l03De
=@1FEUH0DU9B03@d=00f=SH0EUIF024Q8@0i>CT0HF5Q092@T00j>SX0?clo04Q8B00T92@0BDU906][
J`29RHT08R8R02`/;015ADD0?3`l04Q8B01gMgL0B4Q802TY:@0o?cl08B4Q07inOP2QXJ40P82002DU
9@1>CTh0@D5105EEE@1_Kfl0TY:B02DU9@0j>SX0De=C05eMG@0o?cl0YjNW05eMG@0P8200DE5A05]K
F`0k>c/0PX:203hn?P0U9BD0@d=308j>SP1:BTX0PX:205eMG@0T92@0E5AD079bLP1?Cdl0>3Ph08V9
R@0S8b<0EEEE07YjNP1MGEd0;Bd]04A4A00f=SH0Bd];07QhN01NGUh0=SHf05EEE@0n?Sh0AdM705mO
G`2OWil005H0Cdm?03Hf=P1CDe<0C4a<06=SH`2YZJT0[:b/04m?C`1WIfL0FUYJ055AD@1BDU80WinO
07emO@0d=3@0ADE504];B`1:BTX0MGEe0;>c/`1VIVH0;bl_04U9B@1EEED0CTi>07EeM@2k^k/0IVIV
02`/;011@D40IFEU04e=C@1mOGd0V9RH02l_;`0h>3P0CTi>07emO@1cLg<0Q8B406i^KP0Q8B40<C4a
05IFEP2=SHd0K6a/09>CT`2=SHd0?3`l02d];@1ADE40PH6104=3@`1_Kfl0FEUI03Ph>00W9bL0Fe]K
07moO`0X:2P0@4100492@P0];Bd0=cLg05aLG01bLW80Cdm?02d];@1NGUh0@d=3051@D01?Cdl07QhN
06m_K`1UIFD0>c/k069RHP1YJFT0V9RH07EeM@1lO7`0JVYZ05iNGP1DE5@0Bd];05QHF080B4Q80740
@d=304U9B@1JFUX0IFEU03De=@1DE5@0:BTY04m?C`1<C4`0FUYJ04m?C`1ADE40KFe]04m?C`1GEeL0
Fe]K05IFEP1BDU80GUiN04A4A012@T80;Rh^038b<P1;Bd/0IFEU04i>CP1LG5`0B4Q803Ph>01;Bd/0
Jf][01XJ6P0a<C40IVIV03lo?`10@400:2PX03De=@15ADD0AdM70410@00f=SH09BDU05IFEP1@D500
EeMG06QXJ01UIFD0GUiN079bLP11@D40K6a/06IVIP17AdL0PX:204a<C01=CDd0JFUY0451@@1jNWX0
@D5103Ph>01>CTh0>3Ph03dm?@1EEED0=CDe04I6AP12@T80?clo03Xj>P10@400Bd];03Hf=P1HF5P0
>c/k038b<P0o?cl0EUIF05EEE@1MGEd0BTY:04I6AP0l?3`0Fe]K034a<@1BDU80?Shn05YJFP18B4P0
GEeM0451@@1>CTh0Cdm?051@D01<C4`0EEEE04i>CP1LG5`0OGem05eMG@19BDT0J6QX06i^KP1dM7@0
>3Ph028R8P0m?Cd0@41004=3@`0b<S80?3`l04a<C00204e=C@2d05MGE`27QhL0]kNg09FEU@0a<C40
D51@06=SH`1^KVh0VYZJ07YjNP1:BTX0Lg=c07UiN@1mOGd0OWin03/k>`1SHf<0G5aL0861P@0k>c/0
BTY:04A4A016ATH0G5aL04Y:BP12@T80J6QX04i>CP1GEeL0<C4a051@D019BDT09bLW03dm?@1>CTh0
H61P08B4Q00o?cl0>CTi03Lg=`0a<C40BDU904Y:BP0Z:RX0AdM701dM7@1QHF409BDU01dM7@0d=3@0
:b/[04M7A`12@T806QXJ04A4A01>CTh0F5QH059BDP0b<S80?Cdm04E5A@19BDT0?Shn04A4A01<C4`0
E5AD065QH@0`<300ADE5069RHP1:BTX0ADE504m?C`0g=cL0QXJ605iNGP1DE5@0GEeM03/k>`0h>3P0
D51@03dm?@1ADE40ATI604U9B@13@d<0?Cdm02d];@1KFe/0EUIF02PX:01MGEd0CTi>028R8P18B4P0
M7Ad03Ti>@17AdL0ATI6065QH@18B4P0BTY:03Lg=`10@400B4Q802@T900d=3@0A4A404e=C@0e=CD0
CTi>05IFEP1ZJVX0Cdm?02PX:018B4P0EEEE05aLG013@d<0B4Q805MGE`0b<S80>SXj0451@@18B4P0
IVIV04A4A01PH600MGEe05ADE01ZJVX0RHV903<c<`0d=3@09RHV03<c<`0j>SX0;bl_0820P01gMgL0
EEEE06i^KP0^;Rh0DU9B02h^;P1IFET0<C4a05ADE013@d<0=CDe04M7A`0Y:BT0E5AD03hn?P0j>SX0
JFUY06][J`2][Jd0N7Qh04m?C`1JFUX0<c<c03`l?00i>CT0Bd];04U9B@17AdL0Lg=c04m?C`21PH40
;bl_05IFEP1RHV80HF5Q04];B`19BDT0Hf=S07YjNP1cLg<0I6AT0_ooool0001006ATI02_[jl0L71`
05aLG01NGUh0WYjN09bLW01>CTh0<C4a05iNGP1KFe/0K6a/0;Ng]`13@d<0>SXj04U9B@1MGEd0Bd];
08:2PP1cLg<0;bl_0410@01iNGT0Hf=S06][J`24Q8@08B4Q0492@P1ZJVX0];Bd071`L02TY:@0?clo
01TI6@11@D40MWIf04A4A01ADE40`L7104i>CP0V9RH0;Bd]0451@@1>CTh0ATI6069RHP0K6a/0>CTi
04E5A@1LG5`0?clo05QHF00l?3`05QHF030`<01[Jf/0?clo04A4A01YJFT09bLW0451@@14A4@0@T92
01PH6080=CDe04h0@d=304I6AP2JVYX0?3`l01TI6@0U9BD0ATI604Y:BP1DE5@0WinO03De=@0I6AT0
9bLW0410@01LG5`0JFUY07emO@0M7Ad09bLW03<c<`1hN7P0=3@d07MgM`1eMGD05aLG03Hf=P0i>CT0
CDe=02@T9022PX80@D5102DU9@17AdL0G5aL0451@@0c<c<0JVYZ02<S8`0H61P0DU9B06YZJP0m?Cd0
>SXj05IFEP0O7al0;bl_03lo?`1BDU80<c<c05ADE00m?Cd0:2PX0492@P1aLG40:b/[01/K6`17AdL0
>CTi04a<C018B4P0Ph>302<S8`0N7Qh0:RXZ03dm?@16ATH0Jf][0;Vi^@0W9bL07AdM02/[:`17AdL0
?clo07MgM`2n_[h0;Rh^04A4A01SHf<206UYJ@3K08J6QP1mOGd07alO04A4A01BDU80EEEE079bLP2J
VYX0FEUI01XJ6P15ADD0KVi^05MGE`1HF5P0I6AT02`/;01@D500UYJF04Q8B00`<300Cdm?028R8P10
@400BDU906IVIP0Q8B40ADE50451@@0a<C40>c/k09nOW`1jNWX0;Rh^04A4A01BDU80C4a<061PH02F
UYH0<c<c01HF5P12@T80L71`05aLG01nOWh0HV9R01dM7@0Y:BT0ATI606e]K@1JFUX0N7Qh09jNWP0M
7Ad0EeMG07EeM@1ADE40@T9208J6QP0[:b/08b<S06EUI@28R8P0Bd];05ADE00e=CD0=cLg06IVIP21
PH40CTi>06][J`1oOgl08b<S03dm?@1YJFT0NWYj04a<C01=CDd0G5aL02XZ:P1PH600Rh^;05IFEP1C
De<0=cLg030`<01RHV80TY:B02LW9`16ATH0HV9R03dm?@1LG5`0TI6A03De=@0Y:BT0KFe]06IVIP1O
Gel0WinO03lo?`0L71`0GUiN06e]K@1:BTX0VYZJ07alO00_;bl0ADE5096AT@21PH40IFEU08>3P`0c
<c<0A4A405aLG02][Jd0IfMW0::RXP2;Rh/0>c/k07AdM02ATI40SXj>05]KF`1hN7P0FEUI02@T9010
@400O7al09FEU@1EEED0GemO05aLG00P8200ATI6075aL@2>SXh0DU9B05]KF`0g=cL0:RXZ06a/K01e
MGD0EeMG03Ti>@1RHV80=cLg02<S8`1^KVh0OGem059BDP0e=CD0IfMW03De=@0X:2P0MWIf09RHV012
@T80<30`05IFEP0c<c<0<C4a06ATI027QhL0:BTY02`/;01:BTX0EeMG03Ti>@22PX80XJ6Q02XZ:P0a
<C40GemO06m_K`1;Bd/0?3`l06IVIP14A4@0B4Q8065QH@0n?Sh0JVYZ07=cL`0_;bl0AdM704a<C02D
U9@0KVi^04a<C016ATH0Cdm?061PH01IFET0CTi>03Ti>@16ATH0;bl_02h^;P11@D40GemO05ADE01>
CTh0=CDe04e=C@1bLW80Bd];034a<@1BDU80FEUI05EEE@1_Kfl0IFEU05eMG@1_Kfl0G5aL03De=@0m
?Cd0ATI60080FUYJ00X0IfMW04m?C`1LG5`0E5AD04];B`1>CTh0HF5Q02TY:@1=CDd0E5AD0P1=CDd0
o`0S8b<07alO02TY:@0`<300>CTi04e=C@0i>CT0EeMG05IFEP1IFET0ATI605QHF01NGUh0MGEe04=3
@`1XJ6P0JFUY04U9B@23Ph<0IVIV05mOG`1GEeL0A4A407MgM`1EEED0ADE50410@00b<S80?3`l061P
H01;Bd/0BTY:0451@@12@T80=cLg04M7A`1;Bd/0@d=305YJFP11@D40=3@d04i>CP1?Cdl0CDe=05YJ
FP1CDe<0CDe=0492@P1SHf<0>CTi05QHF01ADE40HV9R04E5A@1PH600DE5A061PH01BDU80GEeM05mO
G`1^KVh0CTi>05=CD`1EEED0IFEU055AD@1nOWh0CTi>07IfMP1VIVH0=cLg05=CD`0`<300HV9R04m?
C`15ADD0ATI605MGE`1;Bd/0D51@07QhN01ZJVX0IfMW02TY:@1BDU80I6AT08N7Q`2@T900IVIV05]K
F`1FEUH0AdM705IFEP1@D500GUiN04U9B@12@T80IFEU04];B`15ADD0?Cdm03Xj>P1NGUh0F5QH04I6
AP1YJFT0?3`l06EUI@0l?3`0DE5A03Ti>@0g=cL0EeMG01lO7`0R8R80@T9205YJFP1FEUH0FUYJ04];
B`10@400Bd];03`l?01;Bd/09RHV06IVIP0d=3@0<C4a04m?C`0n?Sh0@T9204m?C`0S8b<0FUYJ06e]
K@2=SHd0LW9b03@d=01>CTh0ADE505aLG015ADD0Lg=c069RHP1ADE40HF5Q01XJ6P0i>CT0BDU903Ti
>@1IFET0CTi>02l_;`1CDe<0LW9b06QXJ01lO7`0@T9203De=@1@D500@D5106MWI`0l?3`0LG5a065Q
H@1?Cdl0?Cdm079bLP1]KFd09bLW06m_K`1[Jf/0=CDe02`/;01EEED0>3Ph06a/K01ADE40NGUi05YJ
FP1LG5`0Cdm?0492@P1XJ6P0<30`02l_;`0b<S80A4A405IFEP1DE5@0>SXj0;Bd]01DE5@0?3`l07Yj
NP1:BTX0HF5Q04e=C@20P800N7Qh04];B`1bLW80Bd];0451@@1DE5@0F5QH061PH01GEeL0>SXj05aL
G021PH40>3Ph05MGE`0h>3P0Cdm?04a<C00b<S80EEEE059BDP1CDe<0FUYJ07=cL`1ZJVX0@D5106MW
I`11@D40S8b<04];B`1FEUH0NGUi02d];@1OGel0KFe]069RHP1hN7P0@D5106UYJ@1MGEd0BTY:05]K
F`0h>3P0@41003hn?P0k>c/0Bd];03<c<`1:BTX0ADE508f=S@18B4P0D51@079bLP1HF5P0GEeM04m?
C`00101EEED0EeMG05UIF@27QhL2ooooo`0008<0De=C0861P@20P800UYJF04m?C`1:BTX0IfMW09^K
V`2BTY80];Bd05=CD`1;Bd/0LW9b06YZJP1?Cdl0N7Qh04];B`0h>3P0I6AT07alO01NGUh0MGEe08V9
R@0Z:RX0EUIF08J6QP1JFUX0?Cdm06e]K@0h>3P0BDU909RHV01SHf<07QhN03@d=00l?3`0;Rh^04U9
B@2>SXh0Ogmo02TY:@0c<c<0ADE5051@D01QHF40UIFE0410@00V9RH0EUIF04U9B@13@d<0MgMg079b
LP0F5QH09RHV04=3@`0e=CD0IfMW0;>c/`0Z:RX0;Bd]03lo?`1SHf<0A4A407EeM@1?Cdl08b<S02/[
:`1EEED0FEUI04M7A`1YJFT0E5AD01TI6@0d=3@0JVYZ07MgM`0g=cL0GUiN02d];@0K6a/0ADE5069R
HP0j>SX09RHV05eMG@0N7Qh08B4Q05eMG@25QHD0>CTi02HV9P1>CTh0:RXZ03`l?01SHf<0IfMW02XZ
:P0_;bl0Bd];03lo?`19BDT0N7Qh06EUI@0F5QH061PH04E5A@16ATH0E5AD07MgM`0[:b/0;2`/04M7
A`1MGEd0De=C08F5Q@1mOGd07AdM01/K6`1?Cdl0BDU904A4A02d];@0DE5A0451@@0m?Cd0G5aL08N7
Q`18B4P0OGem059BDP0203/k>`80NWYj0=80B4Q806a/K01OGel05aLG03Hf=P1^KVh0Fe]K02d];@1]
KFd0<S8b01TI6@1CDe<0V9RH034a<@0^;Rh0M7Ad05MGE`0n?Sh0Kfm_0861P@0O7al0:BTY05]KF`0j
>SX0J6QX06ATI00V9RH0=CDe06m_K`1MGEd0Kfm_09NGU`0];Bd0>CTi04I6AP1WIfL0?Cdm07EeM@1h
N7P07AdM03De=@1PH600N7Qh05iNGP20P800K6a/02LW9`0_;bl0GemO07=cL`14A4@0IFEU03/k>`0M
7Ad0GUiN08^;R`1IFET0<C4a08:2PP0o?cl0;Bd]04M7A`1dM7@0HF5Q030`<01cLg<0<S8b02h^;P1O
Gel0DE5A03De=@1=CDd0<c<c04=3@`27QhL0IfMW01lO7`1ADE40G5aL0410@01ZJVX0][Jf03Hf=P0X
:2P0MgMg06=SH`2BTY80/[:b05UIF@0R8R80<S8b06IVIP1lO7`0WinO05iNGP0a<C40De=C06UYJ@1U
IFD0PH610:BTY00_;bl0FEUI07AdM01WIfL0C4a<06QXJ00R8R80@d=3096AT@1bLW80>c/k05IFEP0a
<C40;bl_05aLG026QXH0:BTY05UIF@1=CDd0:RXZ05eMG@1`L700EeMG03@d=01FEUH0Bd];04M7A`1F
EUH0Kfm_04U9B@0i>CT0GEeM03hn?P1@D500SHf=079bLP0Z:RX0;Rh^0451@@1QHF40LG5a08J6QP20
P8009BDU020P8010@400G5aL04m?C`1bLW80EUIF01LG5`1;Bd/0GemO05]KF`1@D500W9bL07alO00J
6QX0A4A406=SH`1YJFT0De=C08f=S@0c<c<05aLG04=3@`1[Jf/0EEEE06=SH`2TY:@0BDU902DU9@0i
>CT0HF5Q05UIF@13@d<0QHF502HV9P0];Bd0?clo04i>CP0g=cL09RHV07=cL`1kNg/0Kfm_05=CD`1^
KVh0Fe]K04e=C@1WIfL08b<S04Q8B01EEED0;Rh^051@D021PH40M7Ad05=CD`25QHD0UIFE069RHP16
ATH0A4A405]KF`1?Cdl0>CTi030`<01BDU8205eMG@1W04=3@`1>CTh0>c/k0410@011@D40F5QH05AD
E012@T80>SXj04i>CP1HF5P0IVIV071`L01EEED0Fe]K03hn?P0_;bl08b<S03Hf=P0h>3P0BTY:05AD
E01KFe/0@T9203@d=01NGUh0De=C03Ph>01?Cdl0BDU903Lg=`0f=SH0:RXZ04m?C`1=CDd0E5AD04a<
C00c<c<08b<S03lo?`1CDe<0EEEE05UIF@1FEUH0DU9B06MWI`1>CTh0HF5Q04a<C013@d<0G5aL03Ti
>@0h>3P0@T920410@022PX80>SXj03Ph>01;Bd/0@D5104E5A@1:BTX0;Rh^03lo?`0k>c/0@d=303lo
?`14A4@0@D5103`l?016ATH0ADE502XZ:P0a<C40BTY:04A4A01;Bd/0=CDe0492@P10@400Bd];051@
D01IFET0De=C05YJFP1OGel0De=C04a<C01JFUX0GUiN05]KF`1JFUX0De=C04a<C01DE5@0FUYJ07Qh
N019BDT0NGUi06MWI`22PX80L71`0410@00204];B`0D06IVIP1ADE40ATI604U9B@1NGUh0AdM704a<
C02<S8`0X:2P08N7Q`0_;bl0BDU9075aL@27QhL0WIfM09VIV@2WYjL0Ogmo06YZJP1KFe/203Ti>@1^
05]KF`1=CDd0Bd];02XZ:P0c<c<0=cLg0451@@1;Bd/0D51@06ATI01MGEd0A4A405IFEP1CDe<0EUIF
03Xj>P15ADD0EeMG02`/;00`<300@T9204e=C@1CDe<0NWYj055AD@1DE5@0F5QH03/k>`1BDU809BDU
0861P@0d=3@0:BTY0410@00/;2`0@T9204=3@`11@D40GUiN05ADE01>CTh0E5AD04Y:BP1IFET0E5AD
06=SH`1LG5`0QhN707UiN@1UIFD0T92@00l?3`0j>SX0De=C0451@@1jNWX0Hf=S03/k>`2BTY80OWin
04Q8B01ADE40;bl_03hn?P1VIVH0BDU905=CD`0l?3`0Ng]k03/k>`28R8P0?3`l0820P01iNGT0BTY:
079bLP1oOgl07alO02XZ:P1NGUh08B4Q04I6AP19BDT0N7Qh05YJFP1PH600C4a<04];B`1MGEd0>SXj
03@d=01;Bd/0GEeM04];B`15ADD0?Shn055AD@0_;bl0DE5A0::RXP17AdL0RHV904A4A01hN7P0KVi^
02LW9`0o?cl0Bd];03/k>`1PH60203lo?`0506YZJP1EEED0ADE505mOG`0Z:RX00P0g=cL0;@17AdL0
Bd];03/k>`1^KVh0F5QH03/k>`1VIVH0>CTi06e]K@1CDe<0P82005YJFP18B4P0EUIF04];B`23Ph<0
J6QX08>3P`1NGUh0KFe]09jNWP17AdL0];Bd079bLP16ATH0AdM702TY:@10@400?Cdm02h^;P0n?Sh0
?clo05MGE`0`<300D51@0451@@1NGUh0De=C05eMG@27QhL0E5AD04m?C`1_Kfl0Jf][07UiN@02oooo
o`000480KVi^071`L018B4P0L71`07YjNP19BDT0H61P03dm?@1EEED0Xj>S05]KF`0m?Cd0Cdm?03dm
?@0l?3`0Ogmo05IFEP0T92@0?Cdm05IFEP0a<C40K6a/0:FUY@12@T807alO05=CD`1aLG40DE5A08j>
SP0Z:RX0<c<c04I6AP1UIFD0MWIf08j>SP1DE5@0<C4a03Ph>01@D500LG5a05iNGP1ZJVX0K6a/02TY
:@0j>SX0L71`06IVIP1=CDd0H61P03/k>`0Y:BT0?clo092@T01ADE40AdM705MGE`0M7Ad0>CTi06=S
H`1]KFd0:b/[06UYJ@13@d<092@T07inOP23Ph<202h^;P3o04a<C00Y:BT0:BTY07MgM`26QXH061PH
020P800n?Sh0<c<c08R8R02EUID0>SXj01<C4`0/;2`0?clo02l_;`1=CDd0[:b/03Ph>00O7al0B4Q8
04E5A@1ADE40EUIF08b<S00];Bd0820P06e]K@22PX80EeMG06m_K`1kNg/07AdM02l_;`1ZJVX0[Jf]
079bLP1dM7@0?Cdm01lO7`16ATH0M7Ad07emO@1?Cdl0IfMW01`L700a<C40FEUI08n?S`1?Cdl0=cLg
06UYJ@0R8R806a/K059BDP1ZJVX08b<S02h^;P1>CTh0<S8b03De=@1PH600HF5Q02/[:`0l?3`0@D51
04Y:BP0i>CT0X:2P07]kN`0Y:BT0;Bd]061PH01NGUh0H61P09bLW012@T807QhN03Xj>P28R8P0IFEU
03dm?@26QXH0@T9202`/;018B4P0K6a/04A4A020P800SHf=03Lg=`1>CTh0aLG503/k>`1LG5`0H61P
02l_;`0`<300GEeM06m_K`0k>c/0NWYj034a<@0/;2`0BDU9069RHP16ATH0?3`l07inOP0M7Ad0A4A4
06a/K01dM7@0:RXZ02l_;`0n?Sh0E5AD069RHP2NWYh0A4A401dM7@0^;Rh0G5aL08J6QP1SHf<0ZZZZ
04m?C`0L71`0Cdm?04E5A@1fMWH0FUYJ0:ZZZP0/;2`0;Bd]06][J`1PH600GEeM0820P00n?Sh06ATI
04e=C@1^KVh0;2`/06QXJ01BDU809RHV03dm?@1jNWX0B4Q804Y:BP2NWYh0<S8b02TY:@1_Kfl0[Zj^
04m?C`1OGel0;Bd]03Xj>P1jNWX0O7al03dm?@1IFET0IfMW024Q8@1SHf<0YjNW05=CD`12@T80Lg=c
03<c<`0o?cl0UIFE04i>CP0[:b/0CDe=04i>CP1FEUH0KVi^04Y:BP0V9RH0?Shn04m?C`19BDT0[:b/
09jNWP0];Bd0ADE506m_K`1UIFD0JFUY0:6QX@1aLG40;2`/0410@01YJFT0F5QH07AdM02c/k<0G5aL
03Ph>01=CDd0Hf=S03hn?P1IFET0IFEU02d];@0a<C40EUIF07YjNP1XJ6P0DU9B0861P@10@400E5AD
071`L01bLW80<C4a04e=C@1WIfL09BDU03`l?01^KVh0];Bd06a/K01PH600Hf=S02TY:@0h>3P0Shn?
06ATI00`<300?Cdm05IFEP0W9bL0?Cdm05]KF`1OGel071`L038b<P14A4@09bLW05UIF@2WYjL0?clo
01TI6@12@T80ADE503Lg=`1JFUX0Hf=S05iNGP1PH600BDU9000=03lo?`0d=3@0DU9B04a<C00`<300
GemO06UYJ@0l?3`0Lg=c08>3P`2i^KT0MGEe065QH@0205YJFP0306YZJP1EEED0J6QX0080>3Ph03l0
=SHf04Y:BP1HF5P0HF5Q03Lg=`1CDe<0C4a<05EEE@1LG5`0EUIF03De=@1:BTX0CTi>07=cL`20P800
L71`0820P01RHV80Jf][05EEE@0i>CT0:BTY05=CD`1QHF40IFEU0492@P1KFe/0DU9B030`<00e=CD0
De=C024Q8@0];Bd0GUiN03Xj>P15ADD04a<C02HV9P0m?Cd0>SXj02PX:00h>3P0<30`04=3@`0k>c/0
?Cdm02`/;00f=SH0@41004E5A@0_;bl0AdM705EEE@18B4P0KFe]04U9B@17AdL0HF5Q061PH023Ph<0
AdM703dm?@0n?Sh00P0k>c/0;P0l?3`0=3@d03`l?00`<300>3Ph02`/;00l?3`0>c/k03De=@16ATH0
:RXZ02/[:`1:BTX0@410030`<01<C4`0@D5103Ti>@0h>3P0BTY:02d];@14A4@0=SHf0451@@0k>c/0
A4A405EEE@17AdL0?clo05iNGP1^KVh0De=C05QHF01JFUX0DE5A06YZJP17AdL0Hf=S06EUI@20P800
LG5a05UIF@1BDU80=SHf05QHF01FEUH204I6AP09065QH@1HF5P0H61P07MgM`2<S8`0Ph>3059BDP1?
Cdl0HV9R0080Q8B40:/0Cdm?02d];@1NGUh0M7Ad05EEE@2@T900B4Q8075aL@1>CTh0J6QX03/k>`0n
?Sh0<c<c05=CD`1EEED0FUYJ034a<@1:BTX0=CDe05aLG013@d<0C4a<02h^;P1:BTX0EUIF01XJ6P0m
?Cd0Cdm?04A4A00`<300CTi>04M7A`18B4P0CDe=03@d=01@D5006ATI05]KF`0/;2`09bLW04U9B@0Y
:BT0>SXj04A4A00X:2P0=cLg05=CD`1OGel0JVYZ034a<@1<C4`0@410055AD@15ADD0LW9b06=SH`16
ATH0FEUI02XZ:P0o?cl0F5QH04e=C@1aLG40MGEe02<S8`1DE5@0DE5A06a/K02JVYX08b<S01/K6`1>
CTh0;Rh^065QH@0f=SH0Fe]K03lo?`1TI6@071`L08j>SP1dM7@07AdM04i>CP1?Cdl06QXJ02XZ:P1N
GUh0:2PX06YZJP1HF5P0HV9R03lo?`1CDe<0ADE503Ti>@13@d<0<30`02TY:@0[:b/0BTY:055AD@14
A4@0BTY:09:BTP1SHf<09bLW059BDP1MGEd0LG5a04a<C01FEUH0FUYJ03hn?P1SHf<0@41002XZ:P0g
=cL0>CTi02/[:`17AdL0<C4a04E5A@1GEeL0=SHf051@D00/;2`0FEUI061PH00n?Sh0JVYZ05ADE00e
=CD0IFEU03`l?016ATH0:b/[05EEE@17AdL0Ogmo05mOG`1EEED0Ti>C0492@P1FEUH0<C4a03`l?01W
IfL0@d=305YJFP1VIVH0@d=304a<C00/;2`0@T9203Ph>00W9bL0>SXj02PX:016ATH0=SHf05=CD`0e
=CD0ADE505IFEP1<C4`0DU9B0410@01CDe<0M7Ad065QH@1`L7000_ooool0003o09VIV@2EUID0EEEE
04m?C`1[Jf/0RXZ:0:b/[00d=3@0ADE507UiN@1[Jf/0Lg=c0:j^[P1;Bd/0BDU906m_K`2HV9P0Cdm?
06][J`1LG5`0A4A404=3@`1QHF40H61P05eMG@1OGel0;Bd]04I6AP1=CDd0=SHf04m?C`1dM7@0=CDe
02h^;P1JFUX0YJFU02l_;`0g=cL0EUIF03Ph>00^;Rh0EEEE051@D00S8b<0;Bd]04];B`0c<c<0D51@
06QXJ013@d<0;Bd]03Lg=`11@D40De=C071`L01SHf<06ATI03@d=012@T80<30`05IFEP2VYZH0FEUI
01@D500j>SX0BDU904I6AP1ZJVX0QXJ602`/;00g=cL0=CDe06ATI01EEED0Ng]k0:NWY`0O7al0;2`/
04Y:BP1VIVH0>SXj06MWI`1ADE406QXJ02h^;P16ATH0Kfm_028R8P1KFe/0GUiN02h^;P14A4@0EUIF
069RHP0^;Rh0HV9R02TY:@0`<300BTY:06][J`0W9bL06ATI05=CD`0_;bl0<c<c08F5Q@1GEeL05aLG
01TI6@0`<300BTY:04A4A01cLg<0=CDe01HF5P14A4@0HF5Q06MWI`20P800W9bL02LW9`0G5aL0<c<c
06a/K01FEUH0Lg=c07UiN@0G5aL0=cLg05=CD`1KFe/0A4A4059BDP1kNg/07QhN02d];@1WIfL0MgMg
03lo?`1HF5P0MWIf01DE5@1:BTX0TI6A06][J`0/;2`0D51@02<S8`0h>3P0DU9B079bLP0i>CT0@D51
04E5A@0X:2P0?Shn05iNGP2WYjL0@41003Xj>P2FUYH0@D5107alO02[Zj/0=CDe04=3@`14A4@0ADE5
06MWI`2a/K40A4A401TI6@1CDe<0KFe]04];B`1XJ6P0`/;205IFEP0S8b<0D51@08n?S`1VIVH0FUYJ
06a/K00d=3@0@D5105]KF`1jNWX0BDU905=CD`0k>c/0:b/[04a<C024Q8@0U9BD04I6AP1SHf<0EUIF
02`/;01>CTh0Q8B406i^KP0e=CD0CTi>02`/;01DE5@0SHf=08:2PP11@D40A4A404Y:BP0c<c<0SHf=
07MgM`0P8200;Bd]05MGE`0[:b/0KFe]0;jn_P19BDT09bLW04M7A`1JFUX0FEUI09BDU01CDe<071`L
04E5A@1^KVh0ADE507=cL`1VIVH07AdM0451@@29RHT0AdM707MgM`2=SHd0820P024Q8@1PH600OWin
05QHF02XZ:P092@T02d];@18B4P0FEUI04a<C01NGUh0ATI603Xj>P0i>CT0O7al001M04Y:BP16ATH0
I6AT03/k>`0h>3P0Kfm_0;no_`1KFe/0Ng]k07QhN00j>SX0=SHf07QhN02KVi/0CTi>059BDP18B4P0
=CDe08V9R@1/K6`0Hf=S051@D01KFe/0DU9B024Q8@1<C4`0RHV903/k>`0a<C40G5aL05IFEP0j>SX0
MGEe0;Fe]@0a<C40:BTY04=3@`0j>SX0=cLg09FEU@2j^[X0:BTY03Ti>@15ADD0E5AD06MWI`1nOWh0
PX:201DE5@0P8200:2PX04Q8B00e=CD0Bd];06MWI`0N7Qh06a/K05IFEP1CDe<0:2PX05EEE@1IFET0
8B4Q02@T901KFe/0KVi^04M7A`0`<300CTi>04];B`1bLW80DE5A01XJ6P1^KVh0OWin030`<017AdL0
De=C05iNGP1:BTX0HV9R06MWI`1ADE40?clo04Q8B01BDU80=CDe02d];@0Z:RX0@D5104E5A@1EEED0
BTY:0080C4a<02D0?clo0492@P19BDT0?Shn04I6AP1HF5P0CTi>06UYJ@1MGEd0AdM705QHF01SHf<0
BDU903Lg=`0h>3P0?Shn04];B`1JFUX0L71`06e]K@1?Cdl0<S8b05eMG@1bLW80:b/[03`l?01YJFT0
H61P069RHP0R8R80:2PX04E5A@0m?Cd0<C4a0492@P0f=SH0ATI60080A4A404X0B4Q804A4A00n?Sh0
Cdm?04U9B@1JFUX0ADE503<c<`1KFe/0Kfm_06][J`0i>CT0;bl_04Y:BP10@400A4A403De=@0`<300
>c/k0492@P1;Bd/0ADE502d];@1;Bd/0>CTi02/[:`17AdL0CDe=04U9B@0X:2P0:BTY04A4A00k>c/0
>CTi059BDP1=CDd0?Shn03Ti>@1ADE40Cdm?05QHF019BDT0De=C06UYJ@1=CDd0@d=305ADE01EEED0
A4A403`l?010@400>SXj03Lg=`1^KVh0IVIV06YZJP1kNg/0EUIF06UYJ@16ATH0@T9204E5A@0_;bl0
Fe]K04U9B@0c<c<0>c/k04M7A`11@D40=3@d055AD@24Q8@0Kfm_0492@P80J6QX00`0PH61092@T027
QhL0GEeM06ATI01PH600D51@09>CT`1<C4`0NGUi04U9B@1XJ6P204=3@`1B055AD@1;Bd/0AdM703hn
?P1MGEd0I6AT05YJFP1VIVH0?3`l055AD@1@D500HV9R07MgM`1@D500=3@d0410@01JFUX0BTY:06EU
I@1=CDd0?3`l04i>CP10@400EEEE01hN7P1RHV80=CDe03Ph>01bLW8051@D03Hf=P11@D407alO04U9
B@1=CDd0?clo05MGE`0i>CT0Bd];04E5A@1DE5@0BTY:079bLP1<C4`0BTY:05QHF00I6AT0=3@d04I6
AP0a<C40=3@d04Q8B00c<c<0KVi^04e=C@13@d<0?Shn02<S8`0g=cL0N7Qh02LW9`1DE5@0820P069R
HP0Z:RX0B4Q802TY:@1GEeL0F5QH03/k>`2<S8`0RXZ:03@d=00K6a/0CTi>01TI6@12@T80De=C07Ui
N@1@D500DU9B05UIF@80CDe=02H0?clo04Q8B00n?Sh0De=C06m_K`1fMWH0?3`l06=SH`1fMWH0De=C
08J6QP1JFUX0GUiN04I6AP1^KVh0GemO02DU9@0e=CD0>c/k01TI6@11@D40:RXZ02/[:`1RHV80De=C
06ATI01dM7@0BDU904M7A`0X:2P0@D5104E5A@0o?cl0MWIf05=CD`1RHV80MGEe03Lg=`80DE5A00h0
FUYJ03Ph>01BDU80@T92030`<01QHF40GEeM08>3P`0o?cl0F5QH07EeM@0g=cL0PH61071`L080EUIF
01<0<30`04I6AP0l?3`0?clo04i>CP0h>3P0BTY:05ADE01mOGd0EUIF04a<C029RHT0Cdm?05QHF01>
CTh0FEUI06ATI01CDe<0I6AT00;ooooo0000o`1JFUX0SXj>05mOG`1iNGT0BDU904M7A`27QhL0RXZ:
06YZJP2<S8`0@T9205=CD`1/K6`0BTY:03lo?`1VIVH0?Cdm061PH02UYJD0GUiN02l_;`11@D40EeMG
03Xj>P1^KVh0VIVI02XZ:P0n?Sh0D51@034a<@19BDT0Shn?02d];@0/;2`0<S8b05MGE`1>CTh0HF5Q
0820P00S8b<08R8R03Hf=P28R8P0E5AD06a/K01iNGT0820P03Ph>01@D500IfMW05QHF01LG5`0<C4a
020P8014A4@0D51@03Ph>019BDT0Jf][024Q8@0T92@0A4A406i^KP0[:b/0ATI603Ti>@0P8200>c/k
055AD@16ATH07QhN04e=C@0V9RH061PH04M7A`2RXZ80Bd];024Q8@1ADE40:BTY034a<@1[Jf/0OWin
02XZ:P0R8R80D51@04Q8B00^;Rh0R8R809^KV`0W9bL0<c<c05MGE`19BDT0ADE50;Ng]`1nOWh051@D
03Ti>@1eMGD0ADE505ADE02UYJD0BTY:01`L700W9bL0K6a/03/k>`1RHV80KVi^014A4@0[:b/0DE5A
04a<C00R8R80L71`06][J`0E5AD0<c<c061PH01RHV80<C4a069RHP0e=CD08B4Q071`L02e]KD0D51@
01TI6@0o?cl0B4Q802XZ:P1VIVH0XJ6Q02l_;`0K6a/0<c<c06IVIP15ADD0JFUY0;>c/`0X:2P08R8R
06a/K01dM7@0Ng]k09ZJVP0^;Rh09RHV03`l?021PH40J6QX075aL@2YZJT0:RXZ03/k>`1HF5P0Kfm_
05=CD`1RHV80>c/k02HV9P1GEeL0U9BD06i^KP1FEUH0GemO01/K6`0_;bl0J6QX09NGU`0f=SH0EEEE
06UYJ@0P8200DE5A0492@P1QHF40BDU905]KF`12@T80<C4a05=CD`1FEUH0:RXZ02l_;`1VIVH0@410
04];B`2b/[80MGEe01hN7P0o?cl0E5AD04=3@`1MGEd0aLG50:ZZZP0P8200=CDe071`L01=CDd0GUiN
08R8R00U9BD071`L04U9B@1LG5`0DE5A08B4Q00e=CD07QhN04I6AP2TY:@0H61P07UiN@1nOWh0:BTY
059BDP1FEUH0EeMG04U9B@1/K6`0<c<c04Q8B01PH600I6AT03De=@1KFe/0ADE502<S8`1TI6@0WIfM
03/k>`1LG5`0@T92038b<P19BDT0T92@05mOG`14A4@0Cdm?02d];@0b<S80PH61069RHP0S8b<0CDe=
03<c<`1jNWX0MWIf05iNGP0Q8B40DE5A05QHF000?P1ADE40UIFE0:6QX@0^;Rh0=CDe04I6AP1iNGT0
GUiN0::RXP2NWYh0=3@d03`l?00d=3@0H61P069RHP2RXZ80T92@02TY:@0h>3P0Fe]K061PH01EEED0
MGEe06e]K@0b<S809RHV05iNGP1fMWH0@d=3065QH@16ATH0?Shn03Ph>01?Cdl0IFEU0492@P2BTY80
:RXZ02LW9`12@T80HF5Q03/k>`18B4P0IFEU02HV9P0R8R80PH610::RXP1CDe<0:BTY05=CD`0`<300
9bLW07]kN`2PX:00AdM703@d=016ATH0<30`02l_;`1jNWX0VYZJ0P0^;Rh0G`1fMWH0MgMg04];B`0V
9RH0De=C05MGE`1CDe<0D51@01/K6`1HF5P0De=C02l_;`1VIVH0KVi^07UiN@1WIfL0SXj>08b<S01Q
HF40BDU904e=C@1[Jf/0<c<c02/[:`0Q8B40<S8b04A4A01cLg<0<C4a055AD@0^;Rh0EEEE04Q8B01B
DU80<30`04i>CP1;Bd/0IFEU08N7Q`1SHf<0LW9b05EEE@1VIVH0@d=302PX:00Q8B40>3Ph04a<C01U
IFD09bLW03lo?`18B4P0>CTi03lo?`13@d<09bLW03hn?P1:BTX0>3Ph04I6AP0N7Qh0<C4a03hn?P1?
Cdl0Bd];02l_;`0P8200EeMG07MgM`1TI6@0B4Q804];B`1JFUX0F5QH03`l?01GEeL0DE5A04U9B@1/
K6`0@D5104I6AP1DE5@0Cdm?06][J`0d=3@0?Shn04e=C@1/K6`0GEeM04Y:BP0e=CD0CDe=02LW9`0f
=SH09BDU0080?Cdm03l0:b/[03dm?@0g=cL0=SHf04I6AP1<C4`0Bd];055AD@0j>SX0>CTi04I6AP1;
Bd/0>CTi04a<C01LG5`0De=C03dm?@18B4P0F5QH04m?C`1ADE40Bd];04m?C`1=CDd0GUiN04=3@`0e
=CD0?Cdm04I6AP1?Cdl0Bd];05QHF01>CTh0Ogmo05]KF`0R8R80CDe=04I6AP10@400=SHf03Lg=`17
AdL0JVYZ06ATI02:RXX0KFe]03/k>`1GEeL0FUYJ07]kN`2SXj<0S8b<05iNGP1fMWH0FUYJ04U9B@2C
Ti<0Bd];07QhN01WIfL0MWIf04Q8B00g=cL00P0f=SH0M`1=CDd0KVi^05]KF`1NGUh0=cLg04M7A`0o
?cl0ATI603De=@0l?3`0IfMW02TY:@0o?cl0BTY:05YJFP13@d<0S8b<075aL@18B4P0AdM70410@01Q
HF40:RXZ069RHP0Y:BT0:b/[04E5A@0K6a/0?Shn04Q8B00n?Sh0GEeM05UIF@10@400Ogmo03dm?@1?
Cdl0BTY:055AD@1<C4`0M7Ad06EUI@1?Cdl0IVIV02<S8`0f=SH0CTi>04U9B@1OGel0LW9b0451@@2B
TY80P82005EEE@1QHF407alO02XZ:P18B4P0?Cdm05iNGP11@D40M7Ad02h^;P1OGel0=3@d06UYJ@1O
Gel07AdM04Y:BP18B4P0<30`01PH601MGEd0>3Ph04Q8B01HF5P0MGEe05ADE01=CDd0@41003lo?`13
@d<0:BTY03`l?010@400A4A404Y:BP1<C4`0?Shn09VIV@2k^k/0ATI608N7Q`1`L700LG5a04=3@`1_
Kfl0GEeM03`l?01BDU80CTi>03dm?@1ADE40?Cdm05EEE@1PH600BDU907]kN`20P800>CTi051@D00S
8b<0B4Q804e=C@0n?Sh0HF5Q04];B`0l?3`0?Shn0080DU9B02@0@D5105YJFP1HF5P0H61P04e=C@0T
92@0Rh^;03Hf=P1IFET0;Bd]04Y:BP1aLG40@d=309FEU@1DE5@0ADE504i>CP1DE5@0EEEE03Lg=`0^
;Rh0BTY:04I6AP1;Bd/0>c/k05]KF`1;Bd/0=cLg06EUI@1BDU80EeMG04a<C01JFUX0J6QX05eMG@1c
Lg<2ooooo`000=L0EEEE06EUI@2BTY80TI6A05=CD`15ADD0Kfm_0820P02WYjL0];Bd02l_;`1:BTX0
K6a/05IFEP22PX80`<3006EUI@0R8R80JVYZ07YjNP1HF5P0T92@06e]K@0b<S80;bl_07AdM02;Rh/0
IFEU08b<S00W9bL0>SXj055AD@1VIVH0AdM707emO@0h>3P0?clo0492@P1EEED0Cdm?03Ti>@1IFET0
;Bd]03Ph>01@D500OWin04A4A00j>SX0EUIF03<c<`15ADD0O7al079bLP0S8b<0?Cdm0410@018B4P0
IVIV09VIV@0b<S80820P03De=@0l?3`0EeMG08^;R`1RHV807QhN03Lg=`1;Bd/0A4A405iNGP2BTY80
=CDe02<S8`0c<c<0M7Ad05=CD`1XJ6P0T92@02@T900K6a/0BDU905]KF`0n?Sh0DU9B0;Bd]00`<300
8R8R0451@@1CDe<0EeMG04m?C`1PH6006QXJ02l_;`13@d<0OWin04I6AP0`<300@d=3024Q8@0K6a/0
E5AD07moO`0h>3P0>SXj0451@@0C4a<0AdM709FEU@19BDT051@D03@d=00o?cl0>SXj06e]K@2<S8`0
<S8b01LG5`1GEeL0IfMW03/k>`2LW9`0Jf][02HV9P0f=SH0FEUI09JFUP1HF5P0Q8B4059BDP10@400
B4Q806a/K01GEeL0?clo061PH00n?Sh0:BTY04];B`1cLg<0N7Qh04m?C`1UIFD09BDU04I6AP2FUYH0
U9BD01/K6`18B4P0CDe=02d];@0Z:RX0O7al06UYJ@0M7Ad0@T9205iNGP18B4P0Ng]k07UiN@0U9BD0
>CTi05]KF`1>CTh0P82008n?S`0K6a/09RHV0410@01jNWX0EEEE07inOP2OWil07alO04e=C@1GEeL0
Bd];055AD@2/[:`0T92@01LG5`17AdL0OWin05MGE`1?Cdl0QHF505IFEP0M7Ad0CTi>09nOW`1:BTX0
SHf=09JFUP0i>CT09RHV05aLG02c/k<0C4a<071`L01dM7@0>3Ph02/[:`1mOGd0LW9b0492@P18B4P0
9BDU03<c<`1ADE40Lg=c02l_;`1ADE40>3Ph038b<P0207IfMP2<03/k>`1GEeL0Jf][02`/;01<C4`0
WYjN07inOP0_;bl0ADE5065QH@1=CDd0QHF506UYJ@0O7al0AdM704m?C`17AdL0VYZJ08B4Q00X:2P0
?clo04e=C@1@D500K6a/092@T00Z:RX0;Bd]04a<C01aLG40B4Q806ATI00U9BD0B4Q8079bLP1@D500
>SXj0861P@1WIfL0<C4a06ATI02RXZ80SHf=0451@@22PX80<c<c04I6AP1bLW80[Zj^05YJFP1WIfL0
Ng]k03hn?P17AdL0N7Qh0:^[Z`1@D500;bl_05IFEP0c<c<0>SXj0820P030`<00GEeM02d];@1<C4`0
@d=305UIF@2UYJD0R8R802d];@0i>CT0BTY:03<c<`1WIfL0`/;207EeM@0Z:RX0;Rh^04i>CP13@d<0
FEUI0:f][@0`<300;Rh^02l_;`1`L700JFUY04Q8B02`/;00<c<c03Xj>P1@D500IFEU04I6AP0k>c/0
GEeM028R8P0f=SH0C4a<04e=C@1;Bd/0?clo05iNGP1aLG40CTi>02HV9P13@d<0A4A406QXJ01OGel0
:2PX065QH@2;Rh/0>SXj03<c<`1TI6@0ZZZZ08f=S@1^KVh0BDU905EEE@1^KVh0FEUI05EEE@14A4@0
C4a<04M7A`11@D40B4Q806YZJP19BDT0GemO03lo?`1PH600NWYj065QH@18B4P0CDe=06ATI015ADD2
04m?C`0405ADE01QHF40L71`04Y:BP80<c<c03D0EeMG05]KF`1TI6@0>c/k05YJFP1WIfL0>c/k0410
@01LG5`0A4A405EEE@1FEUH0<S8b03/k>`0B4Q80=3@d03/k>`0Y:BT0820P034a<@0S8b<0?Cdm030`
<00k>c/0=CDe03Ph>00R8R80<C4a03lo?`16ATH0ADE502l_;`1ADE40@d=304I6AP0j>SX0<30`05AD
E00`<300?3`l04e=C@0M7Ad06a/K034a<@0];Bd0=CDe02PX:00^;Rh09RHV03<c<`0d=3@0;Rh^03hn
?P0202TY:@3@03`l?00f=SH0<c<c03/k>`14A4@0>c/k02HV9P1FEUH0?clo04A4A00];Bd0ADE504A4
A012@T80?3`l03Hf=P1:BTX0B4Q804i>CP16ATH0BTY:055AD@18B4P0DU9B05aLG01YJFT0<C4a04Y:
BP1<C4`0?3`l04A4A00U9BD0CDe=034a<@0e=CD0@41004Q8B011@D40>3Ph04];B`1jNWX0JVYZ03Lg
=`1>CTh0DU9B05ADE01YJFT0MgMg08R8R01cLg<0Jf][05]KF`1kNg/0BDU904m?C`13@d<0FEUI05MG
E`17AdL0>c/k03lo?`1>CTh0A4A406IVIP1IFET0DU9B04U9B@0i>CT0>SXj03/k>`1KFe/0I6AT02l_
;`1:BTX0EUIF055AD@0h>3P0F5QH05=CD`1OGel0FEUI0492@P1[Jf/0;Rh^06IVIP0S8b<09BDU04a<
C00H61P0De=C04e=C@0/;2`0De=C05UIF@14A4@0GemO03/k>`1;Bd/0>c/k04Y:BP1NGUh0VYZJ07Mg
M`13@d<0QHF503Hf=P1CDe<0Ph>305mOG`1WIfL0KVi^04=3@`1DE5@0IFEU05aLG023Ph<0?Cdm02TY
:@1<C4`0=3@d06MWI`0h>3P0D51@03<c<`1ADE40A4A409jNWP2OWil0:b/[05mOG`1IFET06a/K02DU
9@1cLg<09bLW03lo?`1;Bd/0IfMW04U9B@1CDe<0A4A403dm?@1>CTh0=cLg02h^;P0h>3P0Bd];05EE
E@1BDU80ATI609JFUP3YjNT0Shn?07inOP1JFUX0L71`04E5A@21PH40IVIV03@d=01?Cdl0C4a<059B
DP1CDe<0DE5A04E5A@1VIVH0B4Q805YJFP1QHF408B4Q03<c<`0^;Rh0De=C05EEE@10@400BTY:05YJ
FP1MGEd0EeMG05ADE01/K6`0Jf][07QhN01ZJVX0JFUY06e]K@1UIFD0S8b<055AD@23Ph<0CDe=07Yj
NP2BTY80FUYJ09JFUP1OGel0B4Q80451@@0^;Rh0@T9205IFEP1=CDd0EEEE04U9B@1[Jf/0HV9R07Qh
N080FUYJ00P0L71`05=CD`1kNg/0EUIF06QXJ027QhL0I6AT06IVIP;ooooo00009@2NWYh0M7Ad04i>
CP1^KVh0IFEU05aLG021PH40>c/k07EeM@2e]KD0Lg=c05eMG@25QHD0B4Q803/k>`23Ph<0S8b<03`l
?01XJ6P0?Cdm02LW9`14A4@0LG5a03De=@15ADD0EEEE02l_;`1oOgl0X:2P03<c<`0];Bd0G5aL03lo
?`0f=SH0Q8B404e=C@0L71`00P0d=3@0o`0g=cL0ATI60820P00n?Sh0;2`/0410@01kNg/0EUIF06UY
J@24Q8@0<c<c03Lg=`1LG5`0H61P05EEE@22PX80E5AD02@T901?Cdl0IfMW051@D00m?Cd0LG5a04I6
AP0M7Ad0;Rh^05eMG@0c<c<0?Shn04m?C`0R8R80?3`l05UIF@1gMgL071`L04M7A`1FEUH0:BTY02`/
;021PH40I6AT02`/;00f=SH0@41003Ph>014A4@0Ti>C07MgM`0R8R80?Cdm034a<@0i>CT0GEeM09nO
W`19BDT08R8R04U9B@0o?cl0H61P06IVIP2CTi<08B4Q038b<P0o?cl0HF5Q05MGE`2@T900LW9b02DU
9@0^;Rh0?3`l06EUI@0l?3`0HF5Q01lO7`0W9bL0A4A406YZJP1dM7@0@41008F5Q@0U9BD0820P05UI
F@1UIFD0:2PX030`<01NGUh0:RXZ0410@01:BTX0EUIF01dM7@0_;bl0Kfm_030`<010@400ZJVY08V9
R@0U9BD0?3`l04M7A`1:BTX0GEeM0:ZZZP0];Bd09BDU03Xj>P1MGEd0>3Ph08N7Q`2:RXX0:BTY03De
=@1:BTX0MWIf04m?C`2OWil0WYjN02/[:`1ADE40NWYj05EEE@2@T900De=C03Xj>P16ATH0QHF507mo
O`1YJFT0W9bL01/K6`0b<S80ADE507MgM`1?Cdl0=3@d05UIF@0V9RH0;bl_05mOG`2NWYh0@T9204E5
A@1DE5@0<30`03dm?@1LG5`0Hf=S02<S8`1ADE40EUIF01dM7@1GEeL0X:2P04A4A00O7al0@T9204=3
@`1;Bd/0][Jf0<C4a00i>CT0:b/[04=3@`14A4@0NGUi0;:b/P0e=CD0:BTY04A4A01?Cdl0E5AD0:JV
YP1YJFT061PH04I6AP1fMWH0?Shn07alO01hN7P09BDU028R8P1iNGT0OWin04E5A@1JFUX07QhN03De
=@1@D500M7Ad03Xj>P29RHT0<S8b01lO7`17AdL0I6AT04U9B@0l?3`0CDe=02DU9@0a<C40Jf][051@
D00c<c<0Jf][02`/;01UIFD0VYZJ0410@00b<S80F5QH04Q8B00a<C40KFe]08R8R00T92@0<30`06m_
K`1aLG40EEEE0<G5a@14A4@0=CDe04Q8B021PH40KFe]09:BTP38b<P0?Shn03Ti>@1DE5@0Ogmo07al
O01jNWX0Ph>302l_;`0d=3@0B4Q808B4Q02LW9`0L71`08:2PP0O7al0?Shn07inOP1gMgL0FEUI07Mg
M`1iNGT071`L04U9B@2;Rh/0MGEe04];B`00=@1kNg/0KFe]034a<@0n?Sh0Ng]k051@D00P8200?Shn
04Q8B00W9bL09RHV05eMG@1cLg<06a/K03@d=00e=CD0=SHf05UIF@1LG5`0BDU9024Q8@0j>SX0C4a<
028R8P1PH600EeMG08>3P`1[Jf/0A4A4071`L02@T900CDe=0492@P0_;bl0DU9B05iNGP0d=3@0>CTi
061PH01_Kfl0IFEU07=cL`1NGUh0Cdm?04U9B@1ADE40G5aL02d];@0a<C40>SXj02PX:018B4P0GEeM
0080BDU900T0>3Ph04];B`1CDe<0EeMG034a<@15ADD0F5QH06MWI`1OGel00P1CDe<00`17AdL0G5aL
04a<C00203Hf=P0@03@d=00a<C40@D5104a<C01CDe<0@41003Xj>P1QHF40EeMG02TY:@0a<C40Fe]K
055AD@18B4P04A4A01dM7@80B4Q805/0=cLg04U9B@0h>3P0A4A404E5A@1:BTX0ATI605YJFP12@T80
BTY:05QHF01KFe/0DE5A03@d=01ZJVX0GEeM065QH@1=CDd0@D5107EeM@1HF5P0EEEE059BDP0c<c<0
=3@d059BDP1;Bd/0ADE503<c<`1>CTh0>SXj03@d=016ATH0B4Q804U9B@0R8R80<S8b04E5A@19BDT0
B4Q804U9B@0i>CT0?Shn03Ph>016ATH0ADE504A4A01CDe<0DU9B06IVIP1FEUH0@D5105UIF@1?Cdl0
A4A403Ph>011@D40B4Q803`l?01`L700G5aL061PH01oOgl0BTY:075aL@1ADE40Bd];03De=@0W9bL0
?3`l034a<@0d=3@0@D5103Lg=`0k>c/0F5QH0492@P1kNg/0Lg=c04M7A`1CDe<0KVi^06ATI02?Shl0
LW9b059BDP1WIfL0ADE504M7A`1mOGd0JVYZ0080JFUY0:80EUIF038b<P0m?Cd0=CDe02`/;00h>3P0
=3@d07inOP1JFUX0=SHf05ADE010@400Fe]K02l_;`0d=3@0B4Q802HV9P0/;2`0ADE504Q8B011@D40
Vi^K06EUI@11@D40Bd];05MGE`1fMWH0;Rh^08B4Q014A4@0>CTi06][J`0/;2`0?clo04E5A@0W9bL0
ATI606ATI00g=cL0F5QH02DU9@0n?Sh0>SXj03lo?`1BDU80E5AD065QH@16ATH0QHF5020P800X:2P0
A4A405=CD`1RHV80SXj>05ADE01]KFd0Lg=c05=CD`2EUID07AdM03Ti>@1?Cdl0@D5107AdM01;Bd/0
GEeM03Ph>01WIfL0EEEE04A4A01DE5@0:BTY06=SH`1QHF407QhN00h>3P1GEeL0:b/[059BDP1XJ6P0
S8b<03lo?`15ADD0FUYJ04a<C00j>SX0?clo04E5A@0l?3`0CTi>07alO01]KFd0QHF50<[:bP1oOgl0
MgMg08^;R`1fMWH0Ogmo04Q8B01ADE40EUIF03@d=01<C4`0IfMW03Ph>01CDe<0GEeM03De=@12@T80
;bl_06YZJP1OGel071`L04a<C00a<C40EeMG05iNGP1PH600DU9B04e=C@14A4@0BTY:03<c<`10@400
;2`/04Q8B010@400L71`06YZJP0];Bd0Vi^K05UIF@1jNWX0C4a<05]KF`1MGEd0@41008>3P`1QHF40
G5aL065QH@0m?Cd0@D5102`/;01SHf<0GEeM02PX:01CDe<0C4a<07=cL`16ATH0CDe=08j>SP1CDe<0
FUYJ059BDP1ZJVX0J6QX05eMG@2:RXX2ooooo`000340OWin0:b/[019BDT0GUiN06IVIP1[Jf/0_;bl
05mOG`19BDT0JFUY05QHF02ATI40/[:b04A4A015ADD0AdM705MGE`1RHV80_kno06YZJP0R8R80A4A4
04E5A@1;Bd/0U9BD0;Bd]00U9BD0;2`/07emO@1]KFd0IfMW0;Vi^@10@400?Cdm0410@01JFUX0?clo
06UYJ@1MGEd08b<S03dm?@0o?cl0AdM704Y:BP1IFET0@d=301TI6@0j>SX0KFe]0080AdM70300JFUY
03<c<`0[:b/0MWIf069RHP0S8b<0=SHf04U9B@14A4@0CTi>06m_K`1BDU8061PH03Hf=P11@D40BDU9
06QXJ02FUYH08B4Q034a<@1CDe<0J6QX04E5A@2<S8`0KVi^02<S8`0b<S80<C4a05aLG01>CTh0TY:B
05mOG`0I6AT09bLW04I6AP1LG5`0@41008j>SP2?Shl06a/K03Hf=P22PX80TI6A03<c<`1dM7@0<C4a
024Q8@1DE5@207YjNP0:04a<C01_Kfl092@T01hN7P14A4@0LW9b05IFEP10@400HF5Q02XZ:P80BDU9
0500?Cdm01XJ6P0d=3@0@D5104I6AP1ADE40Vi^K02DU9@0O7al0=cLg05EEE@1KFe/0R8R807AdM00]
;Bd07alO05ADE01`L700@d=306YZJP1iNGT0?Cdm01LG5`1UIFD0ZJVY04Q8B01RHV80EUIF0451@@1>
CTh0QHF509:BTP1aLG40VIVI03Hf=P0W9bL0HV9R0<S8b01IFET0EeMG06YZJP0^;Rh0:RXZ05mOG`2<
S8`0?Cdm03`l?00g=cL0=3@d07QhN02ATI40?3`l0492@P1RHV80FEUI04=3@`2EUID0AdM702DU9@1D
E5@0EUIF04I6AP1WIfL0^[Zj03hn?P0_;bl0CDe=04a<C01CDe<0I6AT0:RXZ00N7Qh0=cLg04e=C@2;
Rh/0FUYJ08B4Q01_Kfl0:BTY02l_;`80IfMW00T0EEEE09^KV`1dM7@0:RXZ02h^;P1gMgL0C4a<04=3
@`1`L7000P0/;2`0[@1UIFD0UYJF03lo?`1JFUX071`L02TY:@1jNWX0PX:20410@011@D40@d=302TY
:@1?Cdl0P82004a<C00`<300Jf][05=CD`1RHV80[Jf]03dm?@0S8b<0A4A404];B`1ZJVX0_kno061P
H00N7Qh0ADE504Q8B00o?cl0I6AT07UiN@0K6a/0?clo04Q8B01=CDd0Hf=S0:VYZ@0W9bL0;Bd]06m_
K`1YJFT0DE5A07AdM00d=3@0@d=306e]K@1gMgL0GemO055AD@2FUYH0=SHf059BDP2;Rh/0SXj>03dm
?@16ATH0CDe=02h^;P0i>CT0E5AD07AdM00b<S80M7Ad08V9R@0_;bl0@d=308F5Q@1IFET0;Bd]05EE
E@13@d<08B4Q06i^KP2a/K40K6a/03Ti>@1=CDd0E5AD02h^;P1mOGd0XZ:R04a<C00h>3P0AdM704a<
C017AdL0TY:B09jNWP0];Bd0:b/[03Xj>P1GEeL0A4A409fMW@2NWYh06a/K02PX:00c<c<0LW9b04i>
CP1kNg/0NWYj01PH600^;Rh0AdM703/k>`0];Bd0Fe]K05aLG00_;bl0?clo06UYJ@1DE5@0=cLg02LW
9`0n?Sh0CTi>07alO01EEED0:2PX06MWI`1[Jf/0<C4a03lo?`1bLW80QHF507QhN023Ph<0KFe]07If
MP1UIFD0GemO07IfMP1=CDd0=CDe03Lg=`0n?Sh0CTi>06i^KP14A4@0H61P03Ti>@1PH600F5QH05UI
F@0];Bd0DU9B06m_K`1VIVH0OGem06e]K@1bLW80IFEU06i^KP1?Cdl0?3`l0451@@0h>3P0?Shn05eM
G@0];Bd0ADE504Y:BP0[:b/0>c/k05iNGP0m?Cd0=CDe069RHP0];Bd0De=C00808b<S0;@0?clo03hn
?P0h>3P0<C4a01PH6019BDT0C4a<0492@P0X:2P0>c/k055AD@1?Cdl0=SHf04=3@`1CDe<0C4a<05EE
E@0[:b/0:RXZ04a<C01CDe<0E5AD02@T900b<S80CTi>05MGE`12@T80>CTi02LW9`0m?Cd0A4A402`/
;00[:b/0B4Q803@d=00W9bL0=cLg02/[:`0];Bd0;Rh^03/k>`17AdL0?clo02`/;00d=3@0AdM704i>
CP0c<c<0A4A404e=C@0n?Sh0<c<c03Ti>@1=CDd0C4a<05=CD`1DE5@0GUiN065QH@1_Kfl0DU9B03hn
?P12@T80DE5A05YJFP0^;Rh0BTY:04E5A@1nOWh0IfMW034a<@1;Bd/0EUIF04M7A`0j>SX0A4A405aL
G01dM7@0F5QH0861P@1kNg/0BTY:05]KF`1UIFD0FEUI06m_K`1JFUX0GEeM05aLG01;Bd/0NGUi05AD
E00i>CT0Cdm?04I6AP1RHV80D51@04E5A@0d=3@0<30`05MGE`0k>c/0?Cdm04E5A@0g=cL0EeMG06YZ
JP1;Bd/0>c/k0451@@1PH6007alO03Lg=`1OGel0CTi>02d];@1NGUh0@D5104i>CP18B4P0>SXj05QH
F00T92@0TY:B020P800U9BD0C4a<02PX:018B4P0CDe=04=3@`1LG5`0EUIF03lo?`1IFET0?3`l059B
DP1?Cdl0BDU905EEE@1_Kfl0Q8B403Ti>@27QhL06a/K038b<P1?Cdl0@D51065QH@23Ph<0<S8b06UY
J@1[Jf/0?clo07EeM@0I6AT0?Cdm06YZJP0S8b<0EEEE034a<@1kNg/0;2`/05IFEP0h>3P0Jf][06YZ
JP0];Bd0IFEU07=cL`15ADD0<C4a07MgM`0g=cL0=CDe04m?C`1KFe/0>c/k04M7A`0l?3`204E5A@0N
02d];@0c<c<0<c<c04M7A`1ADE40D51@04I6AP27QhL0`/;20=_Kf`2ATI40JVYZ04];B`1>CTh0QHF5
065QH@0];Bd0E5AD07EeM@1<C4`0A4A405mOG`1KFe/0De=C04I6AP1nOWh0GemO03Lg=`1=CDd0AdM7
0P2<S8`0:`1cLg<0QXJ6065QH@10@400D51@05EEE@1FEUH0<C4a07EeM@1BDU80MgMg059BDP13@d<0
PX:205aLG01eMGD0>SXj05IFEP1fMWH0DU9B08:2PP16ATH0C4a<05MGE`0c<c<0ADE503Ph>018B4P0
EEEE02d];@1PH600CTi>071`L01=CDd0B4Q805iNGP1?Cdl0JFUY05EEE@1VIVH0LG5a06=SH`1eMGD0
0_ooool0000<05aLG02QXJ40JVYZ08:2PP1>CTh0EEEE09FEU@1iNGT0[Zj^07moO`0j>SX0@4100P1W
IfL0801@D500Fe]K02TY:@0j>SX0Kfm_0:NWY`1<C4`0FEUI03@d=00Y:BT0>SXj08:2PP1/K6`0>c/k
03lo?`0V9RH0=SHf05eMG@1HF5P0=cLg061PH015ADD0:BTY075aL@2UYJD0?3`l020P800m?Cd0B4Q8
04a<C01fMWH0NWYj0P0O7al0N01>CTh0F5QH06QXJ02NWYh0@D51038b<P0f=SH0C4a<04U9B@1LG5`0
PH61018B4P12@T80HF5Q05EEE@1>CTh0Kfm_03dm?@0`<300>3Ph07QhN01JFUX0;2`/04i>CP0W9bL0
7QhN051@D01dM7@0DU9B03lo?`1YJFT07alO034a<@1CDe<0KVi^04U9B@0i>CT0ATI602`/;00`<300
G5aL07alO00[:b/08B4Q0492@P0e=CD0J6QX08V9R@16ATH07AdM030`<00/;2`0?3`l09:BTP2_[jl0
9BDU01dM7@13@d<0ADE50451@@1OGel0XJ6Q02HV9P0X:2P0IfMW04m?C`0b<S80MWIf05iNGP0J6QX0
=SHf07=cL`15ADD0CTi>07UiN@0n?Sh06ATI05IFEP2RXZ80D51@03Xj>P1;Bd/0@D5101lO7`1>CTh0
W9bL051@D00O7al0EeMG04i>CP1EEED0Fe]K05IFEP0X:2P0<c<c05ADE00X:2P0BDU90:NWY`1QHF40
6QXJ02h^;P1KFe/0DU9B061PH02NWYh0A4A401HF5P14A4@0NWYj055AD@1/K6`0<C4a024Q8@13@d<0
LG5a06MWI`20P800J6QX02XZ:P80DU9B0700RXZ:059BDP2ZZZX0IfMW038b<P19BDT0CDe=05YJFP19
BDT0IfMW03`l?00R8R80DE5A071`L01TI6@0BDU908Z:RP0Z:RX0:b/[04E5A@1/K6`0>SXj05eMG@1O
Gel0;Rh^03<c<`1FEUH0NWYj038b<P1ADE40B4Q804];B`1@D500QHF50451@@0_;bl0C4a<05MGE`1V
IVH0QhN7038b<P0K6a/0D51@04];B`1HF5P0Vi^K08b<S00[:b/0?Cdm09^KV`1_Kfl0FEUI08b<S01]
KFd09RHV06MWI`1dM7@0?Shn06][J`0n?Sh0;bl_07emO@2[Zj/0>c/k07alO01LG5`0;Bd]05UIF@2D
U9@0@d=305=CD`1NGUh0<S8b04I6AP2@T900OWin02d];@1MGEd0<30`04m?C`1kNg/0Fe]K02d];@1/
K6`0C4a<03dm?@1hN7P0V9RH03De=@0a<C40BDU905iNGP1eMGD0V9RH0::RXP0c<c<0>c/k03dm?@1[
Jf/0LW9b09VIV@2EUID0?3`l03/k>`14A4@0HF5Q05]KF`2KVi/0GemO034a<@1GEeL0Kfm_0P19BDT0
6P1cLg<0D51@02`/;01[Jf/0Q8B4034a<@1DE5@0HF5Q03<c<`0e=CD0EUIF08J6QP1GEeL0Jf][05eM
G@0a<C40=SHf059BDP2EUID0F5QH0451@@1HF5P07AdM01DE5@0k>c/0Kfm_0P0`<300=@1JFUX0;Bd]
02l_;`1NGUh0S8b<06EUI@1OGel0E5AD07IfMP15ADD0<30`04U9B@1JFUX0NGUi06IVIP0_;bl0GemO
06a/K00l?3`0Kfm_07YjNP2=SHd0L71`08N7Q`2DU9@0C4a<05UIF@1DE5@0F5QH04=3@`0h>3P0>c/k
03dm?@0o?cl0D51@03Xj>P1KFe/0B4Q8069RHP1EEED0HV9R0410@01JFUX0LW9b04e=C@1fMWH0Ng]k
05]KF`1VIVH0Jf][05=CD`0f=SH0?Shn0080BDU901l0IFEU03Lg=`1BDU80D51@03dm?@0g=cL0IVIV
04a<C01ADE40HF5Q02TY:@10@4008B4Q03Hf=P1?Cdl0@D5103Ti>@0j>SX071`L05IFEP13@d<0DU9B
03Xj>P11@D40ADE5061PH013@d<0E5AD06YZJP0f=SH0N7Qh0080@41001/0?clo02`/;01TI6@0<S8b
03dm?@1:BTX08b<S03Ph>01;Bd/0;bl_04U9B@0e=CD0?3`l028R8P0j>SX0?Cdm02DU9@1?Cdl07alO
024Q8@0Z:RX0@d=3055AD@18B4P0?Shn04E5A@0b<S800P1GEeL01`1JFUX0DU9B05EEE@10@400DU9B
0410@01?Cdl00P16ATH0b01:BTX0ATI602l_;`0o?cl0GEeM06QXJ01_Kfl0MWIf04];B`1^KVh0BDU9
030`<018B4P0De=C061PH00i>CT0>SXj04Q8B01CDe<0D51@04U9B@1HF5P0L71`06UYJ@19BDT0HV9R
071`L01hN7P0Z:RX0861P@1XJ6P0N7Qh0451@@1:BTX0Ph>304i>CP1kNg/0GEeM05MGE`1EEED0Bd];
04E5A@14A4@08B4Q034a<@1EEED0E5AD04U9B@1BDU80@T9206a/K01WIfL0OGem07QhN00P82009BDU
04e=C@1;Bd/0;bl_06MWI`0l?3`0CTi>059BDP0m?Cd0F5QH028R8P1JFUX06QXJ01dM7@1=CDd05ADE
04Y:BP1WIfL07alO03Ti>@1CDe<0=cLg04m?C`0b<S80H61P0492@P0b<S80F5QH07emO@1aLG40AdM7
07EeM@0f=SH0>c/k061PH01@D500DE5A071`L01EEED0[Zj^07inOP1HF5P0/K6a03De=@0a<C40BTY:
02l_;`1bLW80:b/[05QHF00];Bd0Hf=S03<c<`2=SHd0Ogmo02/[:`15ADD0A4A401lO7`0D51@0EEEE
030`<00h>3P0EeMG079bLP1EEED0Hf=S059BDP1GEeL0J6QX04A4A017AdL0A4A406UYJ@1IFET0GEeM
01hN7P1DE5@0h>3P0>CTi029RHT0Hf=S051@D01:BTX0KFe]07]kN`0V9RH0<S8b05=CD`0k>c/0?clo
05UIF@1bLW80Ogmo055AD@2@T900VIVI051@D01OGel0KFe]051@D01DE5@0BTY:03/k>`14A4@0GUiN
04e=C@0k>c/0EeMG03De=@1BDU80:RXZ05MGE`0k>c/0@d=3096AT@1LG5`0Hf=S02TY:@24Q8@0WIfM
051@D020P800Hf=S05ADE01NGUh0=CDe0492@P1<C4`0De=C055AD@0l?3`0MgMg069RHP1aLG40FEUI
05=CD`1]KFd0J6QX09JFUP1?Cdl0G5aL08:2PP1EEED0NGUi0_ooool0002=06UYJ@1JFUX0OGem096A
T@19BDT0AdM705EEE@16ATH0TY:B0:n_[`0h>3P0?3`l055AD@1NGUh0GEeM07]kN`0/;2`09BDU059B
DP1]KFd0GUiN08J6QP1EEED051@D04E5A@1mOGd0MgMg075aL@2?Shl06QXJ01PH601BDU80KVi^06][
J`2?Shl0=3@d04I6AP1<C4`0I6AT05MGE`1ADE40HF5Q01/K6`0b<S80EEEE09BDU01OGel0E5AD04a<
C00^;Rh0=cLg055AD@1OGel0ADE505iNGP0m?Cd0=SHf04i>CP1bLW80F5QH03<c<`0n?Sh0;Bd]04Q8
B02;Rh/0@d=302DU9@0a<C40=cLg03Xj>P1QHF40YJFU02TY:@0H61P0@D5104];B`1GEeL0Fe]K09JF
UP0];Bd04a<C05QHF01jNWX0I6AT08:2PP2KVi/0:RXZ01/K6`0n?Sh0I6AT075aL@1OGel0PH6101/K
6`0Q8B40CDe=075aL@1KFe/0Shn?04E5A@0F5QH09RHV05aLG01UIFD0=3@d07YjNP0n?Sh09bLW02d]
;@1OGel0AdM702LW9`1NGUh0:BTY02HV9P1WIfL0N7Qh02TY:@0Z:RX0BDU903lo?`0m?Cd0SHf=04e=
C@0G5aL07alO05]KF`23Ph<0EeMG092@T01DE5@07AdM02XZ:P1CDe<0Xj>S04E5A@2YZJT0DU9B01`L
700m?Cd0AdM70080Bd];01l0EeMG01TI6@0];Bd0Cdm?04e=C@12@T80G5aL059BDP0K6a/0;bl_06a/
K021PH40>c/k07alO014A4@08b<S05aLG01[Jf/0=SHf04Y:BP0R8R809BDU096AT@2b/[80@41002h^
;P1CDe<0;Rh^04a<C02PX:00WYjN0080=SHf02`0EUIF055AD@1@D500QhN704Y:BP0D51@0<S8b06IV
IP1]KFd0OWin0=;BdP1HF5P061PH04U9B@1VIVH0EeMG09jNWP2@T900;Bd]03<c<`1TI6@0SHf=04Y:
BP2RXZ80MGEe038b<P1EEED0CTi>05ADE00d=3@0E5AD01TI6@0];Bd0S8b<05]KF`0b<S80IFEU05IF
EP0a<C40LG5a0;6a/@1jNWX0L71`05eMG@80;Bd]04@0QXJ6092@T018B4P0FEUI030`<01=CDd0I6AT
04M7A`0d=3@0DE5A038b<P19BDT0XJ6Q08V9R@0W9bL0?Shn05=CD`1QHF40[jn_08>3P`0M7Ad0ATI6
05MGE`1OGel0IFEU0;Bd]00c<c<092@T059BDP1QHF40@d=30:VYZ@1DE5@0;2`/03Lg=`1_Kfl0E5AD
06IVIP2b/[80820P03Lg=`1TI6@0YJFU07UiN@1EEED0Hf=S020P8013@d<0J6QX07]kN`1PH600CTi>
05EEE@0U9BD0@D5108R8R02KVi/0?3`l03Hf=P1LG5`0;Bd]03hn?P2>SXh0XJ6Q04];B`1LG5`0IfMW
04U9B@80N7Qh00h0;bl_02HV9P16ATH0DU9B03`l?02HV9P0Zj^[02XZ:P0];Bd0;Rh^04Q8B01LG5`0
M7Ad0:6QX@80>SXj0340ADE504m?C`0m?Cd0FUYJ08>3P`0O7al0:RXZ03hn?P1]KFd0ADE50<71`@1A
DE40Lg=c04Q8B016ATH0Bd];05EEE@1gMgL0MGEe03<c<`1QHF40RHV904a<C011@D40IFEU06][J`1M
GEd0NGUi08N7Q`1@D500IVIV06EUI@1RHV80?clo02TY:@11@D40?Cdm04U9B@1NGUh0?clo04e=C@0j
>SX0D51@061PH01EEED0<S8b04Y:BP1WIfL0I6AT0080JVYZ0P1JFUX0101]KFd0IFEU04=3@`12@T82
03dm?@0503lo?`17AdL0E5AD0492@P0g=cL00P1DE5@0;P0m?Cd0>SXj05QHF012@T80@d=301LG5`0T
92@0CTi>03`l?00g=cL0D51@0451@@1DE5@0BDU905ADE01:BTX0Cdm?04I6AP1PH600EeMG05UIF@1K
Fe/0?3`l06i^KP1IFET0CDe=04U9B@0h>3P0MGEe030`<012@T80EEEE02h^;P18B4P0HV9R04Q8B019
BDT0?clo04];B`0m?Cd0>3Ph0451@@0n?Sh0EEEE02DU9@0V9RH20451@@0?05=CD`1>CTh0BTY:03hn
?P0h>3P0Bd];02`/;00l?3`0D51@05EEE@1PH600GUiN04a<C01IFET0De=C0080H61P02`0HF5Q04E5
A@1DE5@0ATI605YJFP1;Bd/0J6QX051@D01]KFd0DU9B04Q8B01EEED0FEUI04=3@`0n?Sh0?Cdm0451
@@1<C4`0CDe=04=3@`1@D500F5QH07alO00e=CD0E5AD07EeM@1nOWh0WinO0820P01`L700PX:205YJ
FP2=SHd0Jf][04m?C`1LG5`0L71`06QXJ013@d<0?clo03hn?P0[:b/0?3`l03<c<`80Fe]K00D0I6AT
05ADE013@d<0C4a<03dm?@0204Y:BP2B02TY:@0k>c/0Bd];04Y:BP0e=CD0QXJ605eMG@11@D40EEEE
05ADE01kNg/0>CTi07AdM00O7al0;bl_06ATI00?3`l0?Cdm04M7A`0I6AT0=SHf04e=C@0n?Sh0IfMW
02h^;P1;Bd/0=cLg04e=C@1IFET0GemO06a/K00m?Cd0O7al04A4A019BDT0Ng]k05EEE@29RHT0S8b<
03Ph>01_Kfl0EeMG03Lg=`22PX80Ph>307UiN@1?Cdl0ADE505mOG`1?Cdl0JFUY05IFEP1bLW80=3@d
05QHF01RHV809BDU05ADE01JFUX0<C4a02DU9@1HF5P0DU9B07inOP1bLW80L71`04i>CP1GEeL0DE5A
04a<C015ADD0BDU904M7A`16ATH0GemO05=CD`1LG5`0?clo05=CD`16ATH0Rh^;08V9R@1RHV80Kfm_
05mOG`27QhL0N7Qh03De=@1:BTX0EEEE04Q8B01:BTX0Fe]K02l_;`16ATH0>SXj0:6QX@2?Shl0ADE5
04m?C`17AdL0U9BD08V9R@1JFUX0J6QX04m?C`0k>c/0BTY:06=SH`1WIfL0CTi>096AT@1BDU80IFEU
05UIF@1?Cdl0Lg=c05IFEP1KFe/0:2PX06][J`1mOGd0BTY:08>3P`18B4P0H61P06i^KP1<C4`0E5AD
04=3@`1ADE40Cdm?03lo?`1]KFd0Fe]K07AdM01JFUX0FEUI07=cL`1ADE40Hf=S05IFEP1IFET0JVYZ
05]KF`24Q8@2ooooo`000=l0VYZJ06ATI01?Cdl0Ph>30861P@2BTY80PH6105QHF01>CTh0Shn?07Yj
NP2>SXh0WIfM04=3@`1;Bd/0KVi^079bLP1DE5@0S8b<03hn?P0k>c/0I6AT09NGU`0o?cl0J6QX06UY
J@0/;2`0CDe=06=SH`22PX80:2PX05aLG00d=3@0>CTi04e=C@1<C4`05QHF02/[:`1?Cdl0>c/k0451
@@1NGUh0=3@d010@400e=CD0>3Ph04];B`1XJ6P0MWIf02<S8`0g=cL0De=C03Ti>@1HF5P0NGUi07=c
L`0J6QX0FUYJ05EEE@1FEUH0GUiN07inOP0F5QH08b<S05ADE01jNWX0DE5A07]kN`10@400<c<c04Q8
B01@D500Ng]k03Hf=P1fMWH0DE5A014A4@0k>c/0Bd];04Y:BP0R8R80IfMW01TI6@0V9RH0C4a<05QH
F014A4@0820P05UIF@0Y:BT0=SHf04Y:BP23Ph<0BDU902`/;01[Jf/0@D5104I6AP2UYJD0U9BD02<S
8`0];Bd0?clo038b<P17AdL0ZJVY05QHF00M7Ad0@D5105QHF01LG5`0ADE509RHV00e=CD05aLG03Hf
=P1ZJVX0CDe=06i^KP2GUiL051@D02@T900b<S80J6QX04E5A@1ADE40LW9b01hN7P0e=CD0HF5Q071`
L00_;bl0CDe=079bLP0T92@0=SHf05eMG@1gMgL09bLW04e=C@0i>CT0=CDe07EeM@2^[Zh0B4Q802d]
;@1GEeL0FUYJ05ADE02:RXX0WIfM02DU9@0H61P0CDe=06UYJ@0h>3P0R8R808^;R`0Q8B40Bd];092@
T01WIfL0WYjN034a<@0c<c<0@d=306IVIP1[Jf/0Lg=c0:f][@0M7Ad0=CDe05ADE01LG5`0C4a<07=c
L`1oOgl07QhN03@d=01=CDd0Rh^;03Xj>P1GEeL0BDU901hN7P0j>SX0Jf][06IVIP11@D40WIfM02h^
;P0O7al0H61P0:>SX`1YJFT0>CTi06i^KP0c<c<0B4Q807emO@1cLg<0=SHf0451@@1IFET0<S8b07If
MP2m_Kd0Hf=S02l_;`1PH600B4Q804E5A@2WYjL0JFUY02@T900[:b/0IVIV06ATI01iNGT0V9RH02h^
;P13@d<0@T920080HF5Q0980V9RH02@T900/;2`0JFUY03/k>`1>CTh0OGem030`<00O7al0EUIF07mo
O`18B4P0Hf=S03/k>`0E5AD0DE5A07emO@0i>CT0LW9b06m_K`0K6a/0<C4a07inOP1[Jf/0B4Q8061P
H00W9bL0;Rh^05eMG@1WIfL0;Rh^05]KF`1:BTX0<c<c05iNGP2JVYX0C4a<01lO7`15ADD0CTi>05AD
E01WIfL0Shn?02LW9`0Z:RX0De=C05ADE01LG5`0IVIV092@T00f=SH08R8R04];B`1`L700MWIf07in
OP2NWYh09BDU03dm?@1:BTX0Hf=S05QHF02[Zj/0TY:B02LW9`1SHf<0P820061PH01LG5`0RXZ:05iN
GP0H61P0?Shn08:2PP1UIFD0=SHf065QH@0l?3`0820P04E5A@27QhL0IfMW02XZ:P1?Cdl0GUiN02`/
;00f=SH0MWIf04e=C@0Z:RX0@d=303hn?P0S8b<0>SXj075aL@24Q8@0KFe]0492@P1ADE40IVIV05eM
G@1KFe/09bLW07QhN01QHF40>c/k05mOG`1/K6`0J6QX05mOG`1bLW80R8R804E5A@1=CDd0BTY:05EE
E@1@D500@41004A4A01ADE40De=C06ATI019BDT0Fe]K04I6AP1@D500>c/k065QH@14A4@0Fe]K05UI
F@1PH600OWin0:6QX@1eMGD0FUYJ079bLP1UIFD0?Cdm03Xj>P12@T80BDU906MWI`0a<C40D51@05MG
E`80@41007D0FEUI03dm?@0n?Sh0I6AT02/[:`10@4005aLG020P8010@400?Cdm03@d=00l?3`07alO
04=3@`1?Cdl0A4A404I6AP1:BTX0Bd];05IFEP11@D40Cdm?06IVIP11@D40EeMG03lo?`0m?Cd0ADE5
04=3@`1fMWH0AdM705IFEP1IFET0@d=304Q8B00o?cl0:2PX03Hf=P0l?3`0=cLg02PX:00o?cl0;2`/
02/[:`16ATH0;Rh^02LW9`0c<c<0>3Ph05EEE@15ADD0?clo04=3@`1JFUX0I6AT03Lg=`1ADE40B4Q8
051@D00n?Sh0ATI604];B`1LG5`0H61P06QXJ01RHV80FUYJ05QHF01FEUH0E5AD07=cL`1:BTX0PH61
05IFEP1iNGT0IVIV051@D01MGEd0IVIV065QH@1FEUH0>c/k04];B`1CDe<0IfMW06ATI01?Cdl0MGEe
08^;R`16ATH0C4a<06EUI@1CDe<0M7Ad06UYJ@1JFUX0E5AD04e=C@1:BTX0OWin04A4A01UIFD0DU9B
06YZJP1>CTh0@D5103<c<`0a<C40EUIF03lo?`1JFUX0DU9B03Ti>@0j>SX0EeMG065QH@16ATH00P1>
CTh0K00X:2P0?Cdm05QHF01VIVH0BDU905UIF@0m?Cd0G5aL06IVIP0f=SH0BTY:03Lg=`1]KFd0=CDe
02h^;P1=CDd0820P04Y:BP1>CTh0<C4a06=SH`1TI6@0>c/k06QXJ00/;2`0@T9203Lg=`0];Bd0EUIF
05mOG`1VIVH09bLW051@D00Z:RX0;2`/059BDP0l?3`0BDU906e]K@13@d<0RXZ:07IfMP13@d<0Zj^[
0:2PX02e]KD0SXj>04];B`1`L700DE5A06EUI@1[Jf/0GEeM071`L01^KVh0L71`03/k>`26QXH0WIfM
0410@00f=SH0DU9B03@d=00g=cL0D51@06QXJ01<C4`0Cdm?04U9B@0h>3P0C4a<03Xj>P0i>CT0;bl_
04i>CP1CDe<0K6a/02PX:01<C4`0EeMG05aLG01PH600AdM704m?C`1=CDd0L71`06ATI00j>SX0DU9B
04];B`10@400>c/k03lo?`0l?3`0Lg=c03Lg=`17AdL0BTY:04Q8B01MGEd0?clo0410@01@D500;Bd]
04Q8B01CDe<0BDU905IFEP80?Cdm02@09bLW0492@P19BDT0NWYj030`<01CDe<0MgMg05YJFP1cLg<0
;Rh^069RHP21PH40H61P0:NWY`1_Kfl0WinO06a/K010@400ADE503Ph>01VIVH0?Shn04M7A`1[Jf/0
E5AD07=cL`1bLW80F5QH07=cL`1fMWH0W9bL06MWI`1TI6@0PH6105mOG`1nOWh2ooooo`000640I6AT
09JFUP1;Bd/0Shn?055AD@1EEED0T92@059BDP1HF5P0GUiN03/k>`1BDU80TI6A03Ph>011@D40BDU9
01hN7P1iNGT0a/K605iNGP0c<c<0<30`04];B`1>CTh0PX:207UiN@0O7al0>c/k04a<C01ZJVX0IFEU
0:n_[`0e=CD0<C4a04E5A@1PH600Bd];07IfMP2?Shl07AdM03dm?@1QHF40G5aL06e]K@2:RXX0BDU9
02<S8`1@D500UYJF055AD@1@D500GemO02PX:00Y:BT0Fe]K092@T01?Cdl0Ng]k06i^KP0M7Ad0<c<c
05UIF@1=CDd0;bl_04Y:BP0S8b<0=SHf055AD@1TI6@08B4Q02<S8`1>CTh0>c/k03<c<`1gMgL0RHV9
034a<@0X:2P0DE5A051@D01?Cdl0/K6a051@D00@41009RHV04m?C`1>CTh0D51@08R8R00n?Sh06ATI
02PX:01;Bd/0G5aL05=CD`2/[:`0DU9B0080:b/[0>D0RHV904e=C@24Q8@0TI6A01LG5`0Q8B40:RXZ
05aLG00j>SX0G5aL04];B`0>3Ph0:2PX02LW9`1GEeL09bLW04Y:BP0d=3@0:b/[04Q8B01JFUX0<C4a
02LW9`19BDT0<c<c061PH01/K6`0TY:B02/[:`0N7Qh0@d=3065QH@1gMgL0MGEe08j>SP0a<C40:2PX
0492@P23Ph<0I6AT07]kN`1iNGT061PH03Hf=P1EEED0I6AT09:BTP2NWYh0=3@d03dm?@10@400Kfm_
07MgM`2>SXh0QhN702l_;`0l?3`0A4A407MgM`11@D40HV9R02LW9`14A4@0OGem08>3P`0a<C40MgMg
03De=@0U9BD0AdM709NGU`1ZJVX0<C4a06UYJ@0o?cl0?Cdm051@D02YZJT0@T9202/[:`1>CTh0?clo
02l_;`25QHD0T92@02HV9P0W9bL0AdM704I6AP10@400/k>c05iNGP0I6AT09bLW05]KF`1jNWX0JVYZ
0;>c/`10@4009BDU055AD@2=SHd0IfMW08J6QP1JFUX0;Bd]030`<01XJ6P0Y:BT06EUI@2d];@0@410
030`<00c<c<0J6QX04E5A@16ATH0?clo038b<P11@D40IVIV04e=C@13@d<0De=C028R8P1FEUH0FEUI
05=CD`0W9bL0D51@02/[:`1<C4`0^[Zj075aL@0/;2`0@D5104Y:BP0h>3P0T92@07YjNP0S8b<08B4Q
04U9B@0h>3P0TI6A0:6QX@0J6QX0@41004i>CP1?Cdl0GUiN0;Rh^01?Cdl09BDU06ATI01[Jf/0EEEE
0;>c/`22PX80<30`03@d=01GEeL0NGUi061PH01aLG40KFe]03@d=013@d<0FEUI06i^KP12@T80QHF5
06a/K00h>3P0C4a<07IfMP1KFe/0ATI606MWI`14A4@0:2PX05mOG`1/K6`0Jf][03Lg=`1ZJVX0E5AD
038b<P1JFUX0S8b<03<c<`0g=cL0@d=302h^;P0`<300QHF509fMW@11@D40?clo03dm?@11@D40P820
07UiN@1JFUX05ADE01hN7P0c<c<0Bd];05EEE@2HV9P0R8R8024Q8@0m?Cd0AdM703dm?@1>CTh0Rh^;
06a/K00O7al0@D5104A4A01QHF40=CDe02h^;P0o?cl0Bd];07IfMP26QXH0=SHf0080JVYZ01<0?3`l
03hn?P1YJFT0LG5a06QXJ02@T900TY:B03Ti>@1ADE40ATI6075aL@13@d<09RHV03dm?@0];Bd0ADE5
05EEE@14A4@0HF5Q0080C4a<02X0BTY:05ADE00n?Sh0EUIF05eMG@1NGUh0EeMG05iNGP1RHV80IVIV
075aL@1BDU80:RXZ02h^;P1DE5@0Fe]K04i>CP0h>3P0C4a<04];B`18B4P0>c/k05eMG@1@D500@D51
05YJFP0Z:RX0A4A401PH600_;bl0Cdm?03`l?00_;bl0Bd];02l_;`1:BTX0ADE504A4A013@d<0Bd];
0451@@1TI6@2061PH03c07IfMP0f=SH0OGem04M7A`0o?cl0A4A403`l?01JFUX0<c<c0451@@1=CDd0
;Bd]03Ph>014A4@0<C4a03hn?P0a<C40AdM703Ti>@0a<C40=3@d0451@@1BDU808b<S02d];@1@D500
<30`04=3@`19BDT0EEEE03/k>`0c<c<0BTY:04a<C01ADE40>CTi05ADE01@D500De=C0410@01>CTh0
AdM705IFEP1WIfL0B4Q8061PH01<C4`0EEEE07YjNP26QXH0];Bd079bLP23Ph<0HF5Q07AdM01]KFd0
?Cdm06a/K01QHF40DU9B04];B`1=CDd0>CTi03Lg=`18B4P0O7al08n?S`1IFET0HF5Q07QhN01ZJVX0
XJ6Q08>3P`1SHf<0JVYZ06e]K@1TI6@0Ti>C06e]K@2:RXX0JFUY07MgM`1eMGD0De=C03Xj>P0f=SH0
AdM70492@P25QHD0EEEE04U9B@0m?Cd0?clo075aL@1=CDd0C4a<05EEE@0X:2P08b<S03dm?@1ZJVX0
;Rh^07MgM`1GEeL0@d=305IFEP0d=3@0IfMW03Xj>P1OGel061PH02DU9@1<C4`092@T04Y:BP1BDU80
<c<c03Hf=P16ATH0@T9206][J`1>CTh0DU9B04I6AP0i>CT0JFUY061PH01mOGd08R8R04i>CP0`<300
:BTY04m?C`13@d<0IVIV07EeM@0[:b/0`L7109:BTP0o?cl0SHf=05=CD`1WIfL0P82005QHF01dM7@0
>SXj096AT@12@T80K6a/04Y:BP1UIFD0J6QX01<C4`18B4P0?3`l01lO7`0=3@d0DE5A02HV9P0a<C40
E5AD07alO01IFET0GEeM05YJFP1HF5P0KFe]03/k>`10@400@d=305IFEP20P800PH6101/K6`1ADE40
;2`/01TI6@1ADE40=CDe051@D01=CDd0IFEU061PH00R8R80B4Q805]KF`1=CDd0ADE504Y:BP0o?cl0
DU9B0410@01lO7`0H61P020P8010@4009RHV04=3@`1HF5P0A4A4065QH@1>CTh0A4A404e=C@0g=cL0
B4Q80451@@1IFET0GEeM07=cL`1LG5`0UiNG0;2`/022PX80RXZ:0451@@2SXj<0WinO04e=C@1PH600
?3`l04a<C01HF5P0Cdm?06i^KP19BDT0>CTi03/k>`12@T80I6AT05MGE`1@D500Cdm?04U9B@1;Bd/0
ATI6069RHP1MGEd0GemO08j>SP1KFe/0IFEU00;ooooo0000i@1PH600QhN707alO02/[:`0DU9B0492
@P1aLG40GemO0;Zj^P2CTi<0?clo05MGE`1cLg<0IVIV08J6QP1kNg/0?Cdm03Ti>@1XJ6P0Ph>304a<
C01OGel0;bl_01TI6@1FEUH0GEeM03hn?P1ADE40YjNW03Lg=`0Z:RX0IfMW075aL@13@d<0HV9R02HV
9P0S8b<0;Rh^06e]K@11@D409bLW04a<C00J6QX09bLW0861P@1gMgL071`L02PX:00j>SX0;2`/09NG
U`2i^KT0EEEE02`/;00c<c<0CDe=06e]K@2QXJ40Fe]K01`L700i>CT0?3`l05UIF@1CDe<0Vi^K03lo
?`0D51@0CDe=08>3P`1RHV80LG5a08^;R`0f=SH09RHV05=CD`1VIVH0B4Q804A4A01aLG406QXJ030`
<01IFET0IVIV0451@@1DE5@0D51@01XJ6P0j>SX0F5QH07emO@0g=cL0?Shn03dm?@0L71`0<C4a06EU
I@1XJ6P0;bl_03Xj>P0S8b<0;Bd]04U9B@1mOGd0ADE501lO7`19BDT0820P034a<@2XZ:P0[jn_02/[
:`0V9RH0=3@d055AD@12@T80Shn?07emO@0G5aL0@D5105]KF`1=CDd0JFUY0;>c/`14A4@07AdM03lo
?`1RHV80R8R80451@@21PH40>CTi01dM7@1CDe<0K6a/04I6AP0m?Cd0SXj>020P800/;2`0IVIV07mo
O`0f=SH0AdM704E5A@0C4a<0=SHf07EeM@1UIFD0:BTY04m?C`0a<C407alO05EEE@2TY:@0HV9R02l_
;`1GEeL0?clo03Lg=`24Q8@0<C4a024Q8@0i>CT0H61P07UiN@2[Zj/0I6AT02@T9010@400GemO05iN
GP1TI6@0/k>c05MGE`0T92@0<30`05ADE01JFUX0GUiN08n?S`0b<S80<c<c04A4A01IFET0>SXj07Qh
N02?Shl092@T02<S8`1RHV80Q8B404=3@`20P800CTi>02HV9P0m?Cd0J6QX07QhN00o?cl0MGEe04Y:
BP0];Bd0NGUi0:VYZ@1>CTh0?Cdm055AD@0b<S80?clo09bLW01=CDd09bLW05ADE00l?3`0IVIV07Ui
N@27QhL0;Bd]04M7A`1<C4`0BTY:08J6QP2g]kL0?Shn03Xj>P1LG5`0FUYJ06YZJP2ATI400P0j>SX0
5`17AdL0LG5a05MGE`2KVi/0>CTi02`/;017AdL0IFEU05EEE@1dM7@0IfMW01TI6@12@T80L71`03Ph
>01ADE40LW9b03Lg=`14A4@0LG5a06UYJ@16ATH0QHF50080:b/[0280L71`07emO@0j>SX0CTi>05]K
F`0f=SH0?Cdm07moO`2SXj<0ADE504];B`1CDe<0@d=30451@@2>SXh0Y:BT03/k>`0i>CT0EEEE05QH
F01NGUh0UYJF07UiN@0O7al0:BTY0410@01TI6@0J6QX08N7Q`19BDT09RHV03lo?`18B4P0AdM70P24
Q8@0NP0T92@0:RXZ075aL@27QhL0=CDe06i^KP1PH6008b<S02d];@1_Kfl0OWin03Hf=P1MGEd0ADE5
02PX:00K6a/0DU9B09JFUP0j>SX0=SHf05]KF`0M7Ad0=cLg04M7A`1]KFd0>CTi04A4A01BDU80QhN7
07AdM01GEeL0@41004Q8B01;Bd/0AdM702l_;`1oOgl0IVIV055AD@10@400Kfm_075aL@1RHV80UYJF
0820P01EEED0EUIF04Y:BP1bLW80ATI60451@@16ATH0>SXj03Ti>@1QHF40A4A406i^KP18B4P0FUYJ
04];B`1bLW80?Shn06ATI01cLg<0LG5a07QhN01cLg<0KVi^079bLP2>SXh0LW9b05EEE@14A4@0ADE5
051@D01ZJVX0CDe=05MGE`1@D500ADE503Lg=`1ADE40BDU903/k>`1>CTh0=SHf04=3@`0U9BD0=SHf
04U9B@0^;Rh0;bl_04M7A`0Y:BT0=3@d04I6AP1<C4`0D51@05iNGP14A4@0C4a<06IVIP1MGEd0HF5Q
03dm?@26QXH0C4a<04Y:BP14A4@0<30`06EUI@19BDT0EEEE04Q8B00a<C40=SHf04a<C00f=SH0=3@d
03Xj>P0m?Cd0>SXj0P0a<C40?@0c<c<0C4a<020P800j>SX0<C4a028R8P0o?cl0>c/k03Lg=`0n?Sh0
<c<c05UIF@0];Bd0ATI60451@@1>CTh0IVIV04E5A@1>CTh0HV9R06UYJ@1LG5`0De=C05IFEP1;Bd/0
D51@04e=C@1HF5P0De=C06IVIP1hN7P0S8b<065QH@1[Jf/0IVIV02l_;`1=CDd0EEEE059BDP15ADD0
ATI604A4A025QHD0EEEE079bLP1mOGd0A4A4075aL@1dM7@0HF5Q0:NWY`2EUID0Ti>C08>3P`1YJFT0
NWYj07MgM`1;Bd/0GUiN07YjNP1^KVh00P1ADE40W`18B4P0ATI605IFEP0o?cl0MGEe05aLG01[Jf/0
D51@0492@P1RHV80@d=304];B`1CDe<07alO03Lg=`1<C4`0TY:B04Q8B01lO7`0Fe]K04e=C@1MGEd0
?Cdm05EEE@0j>SX0RHV903<c<`0W9bL0Bd];02`/;015ADD0BDU903Lg=`0k>c/0D51@03lo?`1GEeL0
<S8b03@d=00i>CT0AdM705MGE`1KFe/0KFe]03Xj>P1;Bd/0=cLg03@d=01[Jf/0De=C05IFEP1VIVH0
9BDU055AD@19BDT0:b/[0820P027QhL0[Jf]0;Jf]P2JVYX0OWin03/k>`1YJFT0BTY:09BDU01BDU80
Q8B407inOP0J6QX0GEeM069RHP0T92@04a<C075aL@0e=CD0FUYJ05IFEP1OGel0CDe=05EEE@1OGel0
BTY:0410@00h>3P0BTY:03Hf=P16ATH0G5aL05YJFP0/;2`0JVYZ05]KF`0M7Ad0F5QH03lo?`1/K6`0
CDe=07]kN`1^KVh0?Shn06IVIP1;Bd/0@41004E5A@1LG5`0CTi>05]KF`0b<S80LW9b05UIF@0f=SH0
NGUi02TY:@1EEED0GUiN03Ph>01JFUX0<C4a04A4A01EEED0B4Q804];B`0d=3@0Kfm_02l_;`1XJ6P0
?Shn05EEE@1HF5P0DU9B04U9B@0m?Cd0K6a/08Z:RP1JFUX0YJFU04I6AP1ADE40C4a<03Ph>01<C4`0
?Cdm04];B`0d=3@0?clo04e=C@1NGUh0Hf=S05YJFP1IFET0DE5A05ADE01dM7@0E5AD04Q8B01TI6@0
CDe=06YZJP02ooooo`000580OGem04Y:BP1OGel0NWYj07inOP1OGel0M7Ad04M7A`1KFe/0KFe]04e=
C@1_Kfl0IFEU02TY:@1EEED0VYZJ05MGE`0f=SH0D51@03`l?01_Kfl0_;bl07YjNP0`<300Fe]K06AT
I016ATH0LW9b0;Zj^P0f=SH09bLW02l_;`1>CTh0ADE507emO@1<C4`0<C4a04Y:BP1>CTh0AdM707=c
L`2<S8`0:RXZ02DU9@0J6QX0Fe]K04I6AP1PH600CTi>018B4P0b<S80BDU903`l?00m?Cd0Jf][02l_
;`0E5AD0Kfm_06MWI`0V9RH0?Cdm03Xj>P0L71`0?Shn04U9B@1MGEd08R8R05EEE@1SHf<0:RXZ03Ph
>01gMgL0A4A4024Q8@12@T80=CDe038b<P0j>SX0JFUY02XZ:P0O7al0?Cdm0P0^;Rh04P1QHF40Lg=c
01dM7@0G5aL0>3Ph07AdM01eMGD0Jf][05mOG`0I6AT09BDU04];B`1KFe/0M7Ad0:b/[00l?3`051@D
03Ti>@80M7Ad00H0ADE508:2PP0K6a/04a<C030`<01OGel2059BDP1B05mOG`0I6AT07alO04Q8B01n
OWh0@41004U9B@1GEeL04Q8B02PX:01PH600HF5Q02@T901GEeL0H61P03Lg=`1:BTX0NGUi04U9B@0X
:2P0GEeM04Y:BP0];Bd0GemO0;Ng]`1eMGD04a<C0451@@1XJ6P0<30`069RHP20P8006ATI03Xj>P1@
D500G5aL05YJFP2PX:00EeMG01HF5P0b<S80F5QH06YZJP10@400ZJVY03De=@0R8R80De=C04a<C01J
FUX0IFEU01PH600U9BD0HF5Q07inOP1<C4`0Rh^;05YJFP0X:2P0=SHf07=cL`28R8P0:RXZ03/k>`1B
DU80>CTi055AD@1hN7P0HV9R01DE5@1EEED0AdM7034a<@1GEeL0Xj>S04a<C00P8200C4a<03Hf=P1a
LG40`L7109>CT`80;Bd]06T0D51@0492@P1mOGd0^[Zj08Z:RP0/;2`0<30`05YJFP1QHF40RXZ:08j>
SP0X:2P0=SHf05EEE@18B4P0@d=307MgM`0f=SH0=cLg05MGE`26QXH0FEUI061PH018B4P0<c<c06e]
K@2`/;00Jf][05IFEP1XJ6P0>c/k059BDP1[Jf/0BTY:03Hf=P1IFET0<c<c03Hf=P1UIFD0N7Qh02HV
9P11@D40@41002HV9P1RHV80WinO04E5A@0f=SH0EeMG03<c<`1?Cdl0S8b<03Hf=P0];Bd0EEEE05MG
E`1OGel0[jn_05IFEP0Y:BT0Fe]K06UYJ@19BDT0IFEU09jNWP0Y:BT0:b/[06UYJ@2CTi<0CTi>096A
T@1fMWH0=CDe03/k>`1GEeL0RXZ:07AdM01cLg<0NGUi02@T901CDe<0BDU9061PH00m?Cd0@d=305iN
GP0Q8B40>CTi08V9R@2>SXh0<C4a05iNGP0h>3P0?3`l05UIF@2?Shl0H61P02l_;`1<C4`0ATI604e=
C@1mOGd0Q8B403Xj>P0d=3@00P14A4@0D00c<c<0KVi^09>CT`0Y:BT061PH02TY:@1IFET0@d=307]k
N`20P8008R8R02d];@1CDe<0ADE504A4A01TI6@0CTi>07QhN00o?cl09bLW030`<016ATH0M7Ad065Q
H@0];Bd0RHV906QXJ016ATH0@D5106][J`1nOWh0IfMW0820P01]KFd0<30`05eMG@1CDe<0KVi^03hn
?P0O7al0=cLg02TY:@0m?Cd0FEUI04U9B@1PH600=cLg05aLG01^KVh0Jf][03@d=019BDT0D51@06QX
J01ZJVX0Lg=c0820P01iNGT0P82005mOG`18B4P0@41004A4A015ADD0Cdm?03Lg=`18B4P0E5AD0451
@@1ADE40IFEU04Y:BP0f=SH0HF5Q04I6AP1SHf<0:b/[028R8P1=CDd0@d=30P15ADD0o@0Y:BT0FUYJ
05mOG`1DE5@0DE5A04Q8B01;Bd/0CTi>0451@@19BDT0IfMW05=CD`1OGel0Fe]K03hn?P0l?3`0<C4a
04i>CP0/;2`0>3Ph05iNGP19BDT0C4a<055AD@0U9BD0<c<c03`l?00g=cL09BDU02TY:@0e=CD0=cLg
05UIF@0M7Ad0?3`l04a<C00R8R80B4Q804m?C`0n?Sh0ATI603/k>`1UIFD0<C4a05ADE010@400GEeM
04U9B@1EEED0=3@d0410@00n?Sh0D51@04e=C@1EEED0IVIV05QHF019BDT0LW9b05QHF02XZ:P0S8b<
08n?S`1JFUX0?Shn06a/K00W9bL0ATI603`l?00^;Rh0B4Q804a<C016ATH0CDe=04E5A@1hN7P0PH61
051@D01CDe<0J6QX06UYJ@22PX80H61P04i>CP1OGel0I6AT06IVIP1`L700?clo065QH@1?Cdl0JVYZ
06i^KP18B4P0<C4a05YJFP1dM7@0C4a<096AT@1EEED0ATI603Ti>@0o?cl0I6AT05aLG01@D500GemO
02PX:00j>SX0CDe=09RHV017AdL0L71`04e=C@1<C4`0EUIF04U9B@1UIFD0=CDe07]kN`0V9RH0<30`
05UIF@0C4a<0AdM704a<C00b<S80>SXj051@D00`<300O7al03Hf=P0k>c/0AdM703Hf=P1LG5`0CTi>
06ATI017AdL0K6a/03Hf=P0W9bL0=cLg04=3@`1bLW80Ogmo038b<P1UIFD0A4A402PX:02GUiL0IfMW
0861P@2_[jl0QhN7061PH015ADD0G5aL04=3@`1HF5P0@D5105UIF@1OGel06ATI07MgM`2:RXX0:b/[
01DE5@1;Bd/0>c/k03dm?@16ATH0GUiN04m?C`1=CDd0Cdm?03lo?`18B4P0<c<c04=3@`0];Bd0BDU9
05=CD`1/K6`09bLW03dm?@0d=3@07QhN05]KF`12@T80@d=304];B`1OGel0DE5A034a<@1;Bd/0Jf][
04E5A@0i>CT0BTY:03Ph>01^KVh0=cLg06QXJ017AdL06a/K03hn?P0V9RH0IfMW06ATI01[Jf/0Ph>3
04a<C01@D500@T9205aLG01MGEd09RHV051@D00c<c<0HV9R01lO7`1hN7P0KFe]07emO@1bLW80<C4a
07moO`1gMgL0CDe=07UiN@1GEeL0N7Qh05UIF@0l?3`0D51@02/[:`15ADD061PH03<c<`0o?cl0H61P
05aLG01NGUh0AdM7055AD@1nOWh0U9BD06][J`1ADE40Ng]k05iNGP1^KVh00_ooool0001@0:2PX01P
H600C4a<069RHP1NGUh0NGUi09JFUP0h>3P0HF5Q08N7Q`1JFUX0^KVi08N7Q`0o?cl0=CDe05QHF01P
H600JVYZ09nOW`0i>CT0>3Ph06EUI@1bLW80?clo07QhN01UIFD09RHV05IFEP2OWil0K6a/05eMG@1d
M7@09bLW04m?C`1<C4`0MGEe02XZ:P1;Bd/0GUiN02l_;`0];Bd0MgMg08B4Q00W9bL0I6AT02`/;00]
;Bd0LW9b07emO@0a<C40?Cdm055AD@0O7al0Cdm?09fMW@1OGel061PH04M7A`1>CTh0=CDe061PH02K
Vi/08R8R030`<01OGel0GEeM03Lg=`1`L700E5AD02XZ:P0_;bl0E5AD04];B`16ATH0Xj>S06EUI@0H
61P0>c/k03Xj>P0g=cL205]KF`0C01/K6`0[:b/0>SXj059BDP0_;bl0<S8b04E5A@0:2PX0;bl_05AD
E01RHV80<c<c06][J`1HF5P061PH02`/;012@T80HF5Q02PX:00202l_;`3o024Q8@1FEUH0NGUi04=3
@`0I6AT0<C4a02XZ:P0R8R80G5aL09:BTP0e=CD04Q8B02h^;P13@d<0B4Q807YjNP20P80061PH01`L
700f=SH0E5AD03Ph>029RHT0Vi^K01/K6`0G5aL0DU9B08:2PP0^;Rh0Shn?075aL@0/;2`07alO03`l
?01iNGT0@T9206EUI@17AdL0<S8b04i>CP1bLW80EUIF05mOG`1]KFd0ATI602/[:`1TI6@0T92@055A
D@0k>c/0JFUY03De=@0b<S80OWin05mOG`0T92@0@41004i>CP1lO7`0Xj>S03@d=00V9RH0BTY:05YJ
FP1CDe<0TY:B0:j^[P0U9BD0>c/k04];B`1NGUh0ADE507moO`20P8005ADE028R8P17AdL0N7Qh04I6
AP2m_Kd0CTi>01@D5016ATH0PH6106ATI01CDe<0VIVI04a<C00G5aL0=SHf07moO`1RHV80FUYJ0820
P00V9RH0:BTY04e=C@2:RXX0D51@06=SH`19BDT06QXJ03`l?01hN7P0K6a/04U9B@1SHf<05aLG04=3
@`2SXj<0EeMG03Ti>@10@400@D51059BDP2ATI40SXj>034a<@0c<c<0J6QX06ATI01XJ6P0QXJ602DU
9@0m?Cd0LW9b06a/K02:RXX0Rh^;02DU9@0h>3P0DE5A04m?C`1LG5`0Q8B406QXJ00G5aL0=SHf07If
MP19BDT0J6QX07emO@0N7Qh0=CDe05YJFP17AdL0Bd];05MGE`0I6AT0>c/k04e=C@1TI6@0?Shn05eM
G@1GEeL0=CDe069RHP1IFET0@T9203<c<`1MGEd0CDe=03Ti>@1LG5`0N7Qh04A4A00^;Rh0G5aL0410
@01<C4`0F5QH06MWI`0g=cL09RHV065QH@1<C4`0EEEE07inOP1eMGD071`L02l_;`1:BTX0HV9R06=S
H`2NWYh0L71`02TY:@1BDU80LW9b05EEE@1_Kfl0X:2P02`/;00Y:BT0I6AT08^;R`1IFET0GUiN07al
O00i>CT08b<S04];B`2BTY80LG5a05IFEP1DE5@0EEEE024Q8@0h>3P0Vi^K06EUI@0Z:RX0HV9R051@
D00W9bL0?Cdm05]KF`2FUYH0I6AT030`<00k>c/0AdM70820P01XJ6P0@D5108V9R@26QXH0BDU9059B
DP1TI6@0L71`069RHP1[Jf/0NWYj03hn?P15ADD0BTY:05=CD`1GEeL0;Bd]03`l?00_;bl0;Bd]059B
DP19BDT0Bd];04A4A01DE5@0FEUI06MWI`1@D500J6QX06EUI@1HF5P0MWIf000X08f=S@1mOGd0WIfM
09NGU`1TI6@0C4a<04i>CP1EEED0F5QH06m_K`16ATH0De=C05QHF01<C4`0>3Ph04e=C@0o?cl0C4a<
061PH00/;2`0C4a<01PH600^;Rh0E5AD04I6AP0e=CD0@d=302l_;`1=CDd0>CTi03/k>`1:BTX0ADE5
03lo?`1>CTh0AdM704i>CP1TI6@0;2`/05=CD`80A4A403`0CDe=04Q8B01/K6`0=cLg03hn?P1;Bd/0
8b<S02/[:`17AdL0;bl_02d];@0/;2`0?clo03Lg=`0i>CT0<c<c038b<P19BDT0?Cdm03<c<`1<C4`0
=SHf04=3@`16ATH0ADE503lo?`18B4P0G5aL03`l?01=CDd0BTY:05YJFP19BDT0DE5A059BDP1=CDd0
De=C05aLG01?Cdl0H61P0410@01@D500Bd];06i^KP1QHF40Jf][07QhN02?Shl0QhN70:VYZ@3hn?P0
AdM703`l?01ADE40?clo03`l?00m?Cd0FEUI05mOG`1<C4`207]kN`0g05]KF`1FEUH0N7Qh07QhN02:
RXX0L71`05QHF02:RXX0OWin05QHF01/K6`0IFEU07EeM@1OGel0H61P03@d=016ATH0?Cdm04Y:BP12
@T80<S8b05ADE01HF5P0B4Q804i>CP1IFET0HV9R05IFEP21PH40MgMg028R8P0l?3`0HV9R08>3P`1M
GEd0];Bd06UYJ@1MGEd0De=C03`l?01QHF40De=C06YZJP0G5aL0<30`04Q8B00c<c<0B4Q804m?C`0j
>SX0HV9R06ATI00l?3`0KVi^03dm?@0203Ph>01g03/k>`1JFUX0?Cdm06UYJ@0S8b<0EEEE04M7A`0b
<S80Bd];04m?C`1:BTX0GemO02h^;P1ZJVX0CDe=028R8P1QHF40DU9B0492@P1[Jf/0RXZ:06=SH`0/
;2`0JVYZ03Lg=`1OGel0Bd];05]KF`1UIFD08b<S059BDP1?Cdl0<30`01LG5`1ADE40ATI603<c<`1<
C4`0E5AD05EEE@1FEUH0B4Q803/k>`1FEUH0@41004A4A00n?Sh0IFEU05aLG01^KVh0ATI604a<C016
ATH08B4Q06m_K`14A4@0CTi>03@d=01YJFT0GemO02/[:`19BDT0C4a<04M7A`1FEUH0B4Q80451@@1H
F5P0ADE507moO`1LG5`0=CDe04U9B@0c<c<0JFUY04];B`0Y:BT0;bl_024Q8@0a<C40=CDe04I6AP19
BDT0ATI6061PH01=CDd0T92@02LW9`1/K6`0DE5A04Y:BP1<C4`08B4Q0861P@1VIVH0FUYJ09JFUP15
ADD0DU9B04];B`1DE5@0Lg=c03Ti>@1:BTX0:RXZ04];B`1<C4`0PH6107QhN01TI6@0NWYj05aLG01A
DE40GemO04i>CP1<C4`0QhN705EEE@23Ph<00_ooool0000406a/K024Q8@0DU9B08f=S@80BDU905D0
M7Ad05YJFP1DE5@0EEEE03Ph>01KFe/0QXJ604=3@`0d=3@0A4A4024Q8@0h>3P0OGem06m_K`0M7Ad0
?clo04E5A@0h>3P0EeMG079bLP0S8b<0:b/[04A4A00c<c<0Ph>30::RXP0X:2P08B4Q04];B`1JFUX0
D51@08V9R@1cLg<0;bl_03`l?01<C4`0BTY:05YJFP2IVIT0=cLg030`<01@D500AdM703De=@1^KVh0
Shn?01lO7`0Z:RX0F5QH05mOG`1;Bd/0MgMg03Hf=P0^;Rh0@T9206ATI019BDT0AdM707inOP0a<C40
;Rh^05=CD`1jNWX0=3@d04Y:BP2:RXX0=cLg03Ph>01IFET0IfMW03@d=010@400ADE502TY:@13@d<0
JVYZ03<c<`0I6AT0<S8b03hn?P0U9BD0EEEE08J6QP13@d<04a<C0080>c/k09T0<c<c0:>SX`2XZ:P0
6QXJ02`/;016ATH0>SXj030`<01_Kfl0N7Qh01LG5`0^;Rh0CDe=05QHF00W9bL0H61P03dm?@0U9BD0
=cLg034a<@1[Jf/0@D51079bLP0b<S805ADE0451@@1?Cdl08R8R034a<@18B4P0:2PX01`L701KFe/0
QXJ603De=@0/;2`0DE5A03`l?010@400I6AT06MWI`0N7Qh0<C4a05YJFP11@D40ADE509:BTP2HV9P0
<C4a03<c<`1BDU80Bd];05iNGP1iNGT0ATI602HV9P0m?Cd0LG5a08B4Q01/K6`0TY:B02TY:@0h>3P0
GUiN06a/K01@D500QHF503Xj>P14A4@0IVIV07inOP1dM7@0/;2`03Ph>00j>SX0De=C0820P01cLg<0
EEEE0:VYZ@1JFUX0>SXj04i>CP1dM7@0>3Ph03Hf=P1CDe<0:BTY02HV9P1mOGd0Q8B402`/;017AdL0
A4A403/k>`0i>CT0R8R806a/K00g=cL0ADE50410@016ATH0Lg=c09BDU00a<C40;Rh^03Lg=`1?Cdl0
E5AD09RHV01BDU8061PH04a<C016ATH0BTY:07MgM`2j^[X071`L01lO7`1=CDd0ATI605EEE@1RHV80
>3Ph034a<@1bLW80P82004a<C01HF5P0EEEE024Q8@1@D500Kfm_06IVIP0l?3`0LG5a02PX:00o?cl0
PH6107MgM`0o?cl0LG5a03Ti>@0];Bd0Kfm_09ZJVP0h>3P0=3@d0410@00l?3`0CDe=08V9R@0U9BD0
0P1;Bd/0i`0e=CD0MgMg0:6QX@10@400>3Ph05QHF01`L700FEUI0:b/[02>SXh09RHV04=3@`1TI6@0
FUYJ055AD@2ZZZX0NGUi03Hf=P0o?cl0HV9R06m_K`1BDU80/K6a05EEE@0c<c<0B4Q805ADE01?Cdl0
C4a<09bLW01KFe/08b<S05iNGP1PH600>3Ph05EEE@2XZ:P0>SXj03dm?@2?Shl0V9RH03hn?P19BDT0
DU9B02`/;012@T80Lg=c06a/K00_;bl0A4A404Q8B00R8R80>CTi08f=S@1PH6008B4Q03Ph>01;Bd/0
@41003`l?01_Kfl0J6QX01/K6`0T92@0?3`l04i>CP19BDT0Ogmo07QhN00P8200=SHf05]KF`1cLg<0
HV9R03dm?@1LG5`0J6QX07AdM01QHF40>CTi04i>CP1JFUX0B4Q803hn?P1DE5@0L71`07=cL`1YJFT0
KVi^03`l?01IFET0EUIF06MWI`0o?cl0>3Ph05ADE00i>CT0>3Ph05UIF@18B4P0D51@03lo?`1>CTh0
LW9b05]KF`0g=cL0Bd];06EUI@1OGel0HF5Q07MgM`1fMWH0WinO09JFUP1JFUX0?Cdm04];B`11@D40
@41004A4A01HF5P0GemO04i>CP16ATH0EUIF06ATI00h>3P0=3@d05EEE@15ADD0HV9R03De=@0d=3@0
E5AD05MGE`1?Cdl0IVIV03lo?`1FEUH0A4A404a<C01ADE40De=C03hn?P1;Bd/0IFEU06ATI01VIVH0
?Shn07YjNP1@D500AdM705ADE00`<300HF5Q059BDP1=CDd0EEEE03/k>`0o?cl0EeMG02`/;00e=CD0
>CTi04=3@`0V9RH0<c<c03@d=00i>CT0F5QH02@T901CDe<0CTi>030`<01<C4`0GUiN04A4A01<C4`0
@d=304Q8B012@T80ADE504=3@`1ADE40GUiN04m?C`0j>SX0Bd];05MGE`1NGUh0GEeM04U9B@17AdL0
B4Q804U9B@1ZJVX0Cdm?08N7Q`1`L700UYJF0;Fe]@3<c<`0e]KF04m?C`16ATH0GemO04Y:BP17AdL0
BTY:06][J`1^KVh0MGEe09:BTP1oOgl0DE5A04Y:BP1NGUh0JFUY09:BTP24Q8@0SXj>08b<S01MGEd0
IfMW05aLG00b<S80L71`07EeM@1hN7P0@d=304a<C00204U9B@0N05QHF01;Bd/0S8b<06ATI01mOGd0
Hf=S03dm?@17AdL0?Shn04E5A@18B4P06a/K038b<P1@D500MgMg04M7A`1RHV80Bd];04I6AP1ADE40
C4a<06UYJ@0`<300FEUI01`L700o?cl0E5AD02/[:`1=CDd0De=C0P0c<c<0:019BDT0<C4a061PH00c
<c<0De=C04=3@`0g=cL0GEeM04E5A@1LG5`06QXJ05]KF`0`<3007alO04Y:BP15ADD0EEEE06i^KP0j
>SX0GEeM04];B`0Q8B40GEeM03`l?011@D40Xj>S03dm?@1VIVH0>3Ph06][J`1GEeL0OGem069RHP1N
GUh0JVYZ02XZ:P1BDU80EeMG04Q8B00a<C42059BDP1C04Q8B01ADE40FEUI04a<C01DE5@0AdM703Xj
>P1:BTX0>SXj04I6AP0i>CT0L71`059BDP1PH600BDU907UiN@1aLG40=cLg06=SH`19BDT0EeMG0410
@01XJ6P0IVIV03De=@1/K6`0C4a<03Lg=`1:BTX0GEeM03hn?P1NGUh0ADE5096AT@18B4P0<C4a055A
D@0];Bd0HV9R07=cL`1BDU80EUIF034a<@18B4P0<C4a05aLG01EEED0>CTi03lo?`0/;2`0GemO03Hf
=P1OGel0@d=3079bLP1UIFD0?3`l0:FUY@1cLg<0Ogmo0;Ng]`1DE5@0MWIf05eMG@0o?cl0D51@03`l
?01:BTX0@41003Ph>011@D40EeMG05ADE01ADE40CTi>05QHF01TI6@0IFEU06=SH`19BDT0L71`055A
D@1^KVh00_ooool0000Q06UYJ@1MGEd0De=C09fMW@1MGEd0B4Q8069RHP1`L700X:2P09NGU`0g=cL0
GEeM05YJFP1XJ6P0RHV90:NWY`0Z:RX0Cdm?05IFEP1_Kfl0H61P09jNWP0c<c<0:BTY034a<@1IFET0
D51@08B4Q02ATI4061PH03hn?P1OGel0IfMW0080MGEe02h0EUIF01hN7P0k>c/0JVYZ03lo?`1MGEd0
IVIV02l_;`0K6a/0Cdm?06e]K@0S8b<0DU9B03hn?P0Z:RX0LW9b07moO`0f=SH0<C4a05eMG@0`<300
9RHV08B4Q01RHV8071`L03Ph>00o?cl0?Shn04m?C`2ATI40BTY:01TI6@0i>CT0@d=304Y:BP1WIfL0
TY:B059BDP0S8b<0B4Q803Lg=`0m?Cd0MGEe079bLP0L71`08b<S0P1TI6@04@1SHf<0OGem03`l?00A
4A40@410059BDP1GEeL0>c/k05MGE`0[:b/0820P04I6AP1SHf<0KFe]02l_;`1dM7@09RHV0080;bl_
0?l0D51@03Ti>@0g=cL0IVIV02<S8`19BDT0SHf=05IFEP0E5AD092@T0410@00_;bl0=CDe08j>SP1j
NWX09BDU03Xj>P1=CDd0ADE505mOG`1WIfL08R8R01hN7P15ADD0GEeM03Xj>P1WIfL0VIVI03Hf=P0Z
:RX0CDe=06m_K`1?Cdl0EUIF0<71`@0i>CT07AdM05]KF`1jNWX0@T9204a<C00^;Rh0:BTY03Xj>P1]
KFd0JFUY0410@01MGEd07QhN034a<@1YJFT0[Zj^06][J`0S8b<0FUYJ02h^;P11@D40GEeM02l_;`17
AdL0DE5A038b<P0d=3@0PX:205eMG@0O7al0GemO04=3@`0[:b/0KFe]0<;2`P1WIfL0;Bd]04];B`1@
D500De=C08^;R`2FUYH0>3Ph01@D501@D500N7Qh05IFEP2MWId0P82002h^;P0];Bd0ADE506MWI`1a
LG40UYJF04A4A00];Bd0Bd];09NGU`1]KFd0Jf][061PH00f=SH0;bl_05mOG`2GUiL0BDU9075aL@1L
G5`0;bl_04];B`2d];@0M7Ad04Q8B01OGel0ADE503hn?P2RXZ80RXZ:02<S8`14A4@0Ogmo05aLG02>
SXh0QXJ602TY:@0];Bd0CTi>04e=C@1/K6`0YZJV03/k>`0f=SH0BDU90410@01TI6@0/k>c05aLG00L
71`0?clo075aL@1kNg/0JVYZ07UiN@0L71`0<S8b05aLG00o?cl0LW9b07inOP0c<c<0>SXj069RHP18
B4P0GUiN06e]K@0/;2`0@d=305EEE@1WIfL0?clo06YZJP1ADE40:RXZ04M7A`1;Bd/0I6AT04=3@`1<
C4`0AdM703Hf=P16ATH0Lg=c06UYJ@0k>c/0Cdm?04i>CP0k>c/0ADE507YjNP26QXH0;Rh^05YJFP1N
GUh0<c<c069RHP34a<@0]KFe03Lg=`14A4@0IfMW05MGE`1bLW80HF5Q02DU9@0f=SH0BTY:05=CD`10
@400LG5a05YJFP0U9BD07AdM04a<C02<S8`0<C4a06YZJP1PH600820P04e=C@1aLG40KVi^024Q8@18
B4P0IFEU02`/;00m?Cd0ATI607IfMP0T92@0A4A404a<C01gMgL0K6a/04I6AP0n?Sh0>c/k05QHF01I
FET0?3`l06ATI01aLG40Bd];06IVIP20P800HF5Q079bLP1oOgl0SXj>03lo?`12@T80ADE507YjNP1N
GUh09BDU03De=@0[:b/0?Shn059BDP18B4P0GEeM0492@P1PH600C4a<075aL@13@d<0Bd];08B4Q01O
Gel00@1oOgl1079bLP80[Jf]0?l0U9BD06MWI`12@T80DE5A0410@017AdL0M7Ad03De=@1?Cdl0De=C
04Q8B01>CTh0E5AD03<c<`0j>SX0Hf=S03Ph>01ADE406ATI02LW9`1@D500Cdm?04U9B@16ATH07alO
03hn?P1<C4`0EEEE04Y:BP19BDT0EEEE05IFEP0l?3`0A4A4059BDP1?Cdl0LG5a06=SH`1JFUX0GEeM
051@D01`L700?clo03`l?01RHV80?clo04=3@`15ADD0<C4a03lo?`0i>CT0?3`l03De=@13@d<0;Bd]
03Lg=`15ADD0>3Ph03<c<`0l?3`0;bl_04];B`0f=SH0@D5104m?C`19BDT0IfMW0451@@1CDe<0CTi>
05YJFP0m?Cd0ADE505IFEP1IFET0E5AD059BDP1:BTX0EeMG05EEE@1JFUX0BDU907UiN@1DE5@0RXZ:
07QhN026QXH0/[:b0=3@d02d];@0IfMW06ATI01YJFT0CTi>03lo?`16ATH0G5aL07alO01OGel0ZJVY
09:BTP1jNWX0Kfm_092@T01aLG40JVYZ04U9B@1EEED0LG5a071`L01oOgl0L71`03hn?P1?Cdl0?Cdm
05]KF`1<C4`0>CTi03/k>`1IFET0Fe]K07UiN@1;Bd/0>c/k03Xj>P0n?Sh0>SXj05ADE01nOWh0NWYj
06][J`0;2`/0=3@d05QHF01eMGD0GUiN0;Rh^01UIFD0D51@04Y:BP13@d<0Fe]K0410@01KFe/06a/K
03Lg=`1=CDd061PH04=3@`17AdL0>SXj061PH01IFET0>c/k061PH00e=CD0BDU9038b<P0f=SH0BTY:
03Xj>P1GEeL0;2`/051@D01ADE40@T9207]kN`1IFET0FUYJ07alO00e=CD0GEeM05IFEP17AdL0F5QH
04M7A`1BDU80?Cdm030`<01RHV80?Shn051@D018B4P0GUiN05eMG@1OGel0J6QX01PH601QHF40I6AT
05eMG@0X:2P0De=C04m?C`1jNWX0FEUI07]kN`0o?cl0A4A405EEE@17AdL0BTY:03lo?`1ADE40<S8b
05QHF01PH600KFe]0492@P1:BTX0GUiN03Xj>P1ZJVX0JFUY06EUI@1FEUH0I6AT05EEE@0j>SX0GUiN
04m?C`0k>c/0?Shn04a<C00n?Sh0I6AT04=3@`29RHT0De=C03Hf=P1ADE40?clo07inOP1EEED0Hf=S
08V9R@10@400@D5102l_;`11@D40C4a<0492@P1ADE40HV9R0:FUY@1@D500N7Qh04e=C@2EUID0MGEe
02d];@1oOgl0F5QH059BDP27QhL001H0EEEE05=CD`1VIVH0Fe]K06][J`1<C4`0@410038b<P10@400
@D51061PH01eMGD0GUiN06][J`1CDe<0Hf=S06][J`1?Cdl0AdM707moO`1EEED0LG5a0_ooool0001?
0;6a/@1MGEd0CDe=09ZJVP28R8P0KVi^07=cL`0i>CT0N7Qh09^KV`1GEeL0Ph>307]kN`0b<S80C4a<
08f=S@23Ph<0ATI6061PH00f=SH0FUYJ071`L01[Jf/0>CTi05iNGP19BDT0@41005IFEP2NWYh0Cdm?
04=3@`1EEED07AdM03hn?P2BTY80HV9R03<c<`0e=CD0?Shn03Ti>@1[Jf/0QHF503Lg=`0Y:BT0@d=3
059BDP1NGUh0Ph>304A4A00G5aL08R8R05]KF`0o?cl0JVYZ0:FUY@11@D407AdM02l_;`1ADE40?3`l
08>3P`2<S8`05ADE02TY:@0d=3@0KFe]04M7A`1aLG40CTi>010@400L71`0F5QH05mOG`0k>c/0MGEe
03Hf=P0L71`092@T06UYJ@0203Hf=P3S04e=C@0@4100ADE509JFUP1PH600=3@d02XZ:P1QHF40>SXj
02d];@1jNWX0MGEe01LG5`0d=3@0@T9203dm?@14A4@0T92@0410@00H61P0BDU905IFEP11@D40FUYJ
09nOW`0B4Q806a/K04Q8B01OGel0?Cdm04E5A@1KFe/09BDU03Ph>019BDT0IfMW04Y:BP1YJFT0820P
02/[:`16ATH0IfMW04=3@`0g=cL0Q8B405IFEP0W9bL0:2PX04a<C01?Cdl0<C4a05aLG00c<c<09BDU
04Q8B01aLG40R8R803Ti>@1?Cdl0BTY:055AD@2?Shl0E5AD01PH600S8b<0ADE505=CD`1ADE40UiNG
0492@P0Y:BT0ADE5051@D01bLW80IFEU09NGU`0Z:RX0A4A405YJFP0f=SH0IfMW07]kN`0e=CD0?clo
04A4A01ADE40?Cdm09>CT`1cLg<0;Bd]02XZ:P1OGel0KFe]059BDP1HF5P0MgMg024Q8@0g=cL0T92@
0820P00/;2`0EUIF02@T900k>c/0HF5Q079bLP13@d<0>3Ph05ADE00N7Qh0>CTi08J6QP2>SXh0:BTY
04A4A01ADE40<c<c09RHV02WYjL0CDe=02LW9`17AdL0>SXj06ATI03?cll0VIVI03De=@0`<300DE5A
05QHF01kNg/0UiNG03Ti>@0U9BD0F5QH09VIV@1gMgL0LW9b0410@01EEED0De=C0:BTY01fMWH0J6QX
06EUI@0K6a/0=cLg08R8R01`L700FUYJ06e]K@0Q8B40<30`06m_K`2OWil0DU9B06UYJ@10@400:2PX
06QXJ01kNg/0@d=304i>CP12@T80820P06m_K`2YZJT0?Cdm03hn?P1<C4`0<C4a04Q8B02RXZ80GemO
02h^;P1JFUX0DE5A05MGE`2;Rh/0X:2P02h^;P0g=cL0I6AT04];B`1MGEd0MGEe0:VYZ@0W9bL0>SXj
05UIF@1UIFD0O7al09VIV@2KVi/0:BTY03`l?00o?cl0JFUY04=3@`2>SXh0GEeM02HV9P0e=CD0JVYZ
096AT@1cLg<0Q8B4065QH@0N7Qh0DU9B08n?S`1DE5@0A4A406QXJ00X:2P0=cLg055AD@1UIFD0?3`l
04U9B@1RHV80;bl_02d];@0m?Cd0NGUi0410@00S8b<00P1JFUX0YP14A4@0CTi>06m_K`0W9bL08b<S
03Ti>@0_;bl0=cLg05YJFP1^KVh0LW9b051@D00e=CD0CDe=05EEE@1aLG40EUIF04Q8B01gMgL0IVIV
04E5A@11@D40HF5Q08b<S02VYZH0Vi^K05UIF@0m?Cd0E5AD04Y:BP1XJ6P0BDU9034a<@0h>3P0EEEE
04e=C@1<C4`0>CTi06e]K@1WIfL0I6AT04a<C01/K6`0Jf][06e]K@29RHT0HF5Q09ZJVP2i^KT0X:2P
08f=S@2>SXh0QXJ602HV9P12@T80HF5Q06][J`1cLg<0@d=305IFEP1PH600EUIF051@D01EEED09BDU
0451@@1hN7P0=CDe05eMG@0I6AT0:b/[06ATI01MGEd0CTi>05aLG00/;2`0G5aL03/k>`10@400E5AD
04e=C@1FEUH0E5AD04Q8B01DE5@0I6AT03<c<`1XJ6P0BDU903lo?`1IFET0=CDe06QXJ012@T80@D51
07YjNP0k>c/0@T9206IVIP0c<c<0A4A403Ph>014A4@0;Rh^02d];@0_;bl0=3@d05]KF`0];Bd0:BTY
0410@00T92@0Bd];03dm?@0i>CT0A4A403Hf=P1;Bd/0>c/k04I6AP0c<c<0BDU903`l?01;Bd/0@410
04U9B@1;Bd/0C4a<059BDP18B4P0@D5104I6AP1?Cdl0JFUY06][J`27QhL0GEeM07moO`2DU9@0820P
04Y:BP1PH600HV9R04];B`0o?cl0BDU905EEE@1IFET0J6QX07moO`2XZ:P0R8R805YJFP1SHf<0MgMg
08b<S02e]KD0Ng]k06=SH`1aLG40M7Ad06EUI@1_Kfl0BTY:079bLP1>CTh205eMG@2P051@D00n?Sh0
C4a<06ATI01OGel0Q8B406ATI019BDT0EUIF05EEE@1NGUh0<S8b03lo?`1ADE40:RXZ04M7A`1NGUh0
CTi>04E5A@1PH600FUYJ059BDP1NGUh0EEEE07alO01IFET0IFEU03Ph>00n?Sh0De=C03De=@1BDU80
F5QH03lo?`0g=cL0BDU903<c<`11@D40>c/k0492@P0];Bd08b<S04I6AP1FEUH0Kfm_01hN7P1=CDd0
=CDe02/[:`1NGUh0D51@061PH02BTY80@T92059BDP1LG5`0>3Ph06i^KP1CDe<0ATI60410@00N7Qh0
E5AD04E5A@2FUYH0L71`05QHF01FEUH0Kfm_07emO@0/;2`0FUYJ061PH00n?Sh0820P061PH01JFUX0
Cdm?0410@01HF5P0@41005ADE013@d<0A4A405ADE00o?cl0?Cdm03Ph>01JFUX0GEeM07]kN`0f=SH0
De=C07AdM00a<C40JVYZ04I6AP1ADE40ADE505mOG`1IFET0=3@d04E5A@1ZJVX0?clo04E5A@1FEUH0
>3Ph05eMG@15ADD0OWin05IFEP0a<C40BTY:01/K6`1?Cdl0ATI604A4A01CDe<0<c<c05=CD`1JFUX0
BTY:04m?C`0j>SX0@41003lo?`1GEeL0>c/k06i^KP1`L700IVIV05]KF`10@400dM7A09NGU`28R8P0
WinO05=CD`1BDU80?Shn02l_;`13@d<0CDe=06UYJ@0Z:RX0?clo03`l?02<S8`0Fe]K0820P01kNg/0
EEEE06i^KP1cLg<0IVIV05QHF02RXZ80BDU907emO@;ooooo0000CP1dM7@0JVYZ04U9B@1RHV80EUIF
05iNGP2?Shl0>c/k0451@@1FEUH0C4a<0:VYZ@2OWil0=3@d034a<@1NGUh0C4a<08R8R02g]kL0D51@
02PX:01dM7@0Lg=c079bLP2ATI40Fe]K03Xj>P1<C4`0Shn?07AdM02UYJD0T92@028R8P0L71`0Bd];
092@T01lO7`0TY:B04A4A00X:2P0<C4a04m?C`1XJ6P0De=C0:^[Z`0I6AT06a/K05ADE01PH6009bLW
05YJFP1DE5@07alO03Ph>01hN7P0Lg=c04U9B@1cLg<09BDU03Lg=`13@d<0GemO03Xj>P0Y:BT0FEUI
02TY:@0j>SX0UiNG09FEU@0W9bL0;2`/03Ti>@0f=SH0G5aL0;2`/02HV9P08R8R02LW9`80AdM70?<0
F5QH08V9R@0/;2`05ADE02LW9`1DE5@0ATI604m?C`21PH407alO01/K6`0X:2P0JVYZ03/k>`1jNWX0
F5QH01@D500Z:RX0F5QH05YJFP0X:2P0=cLg03lo?`0J6QX0=SHf05]KF`0c<c<09bLW04U9B@0d=3@0
:b/[04A4A02;Rh/08B4Q01hN7P1>CTh0=3@d03Xj>P1^KVh0?3`l014A4@0Z:RX0@T9203hn?P1=CDd0
X:2P0:6QX@0I6AT0<30`03@d=013@d<0E5AD0;:b/P2JVYX05ADE02`/;01ADE40GUiN04Y:BP2RXZ80
Rh^;01XJ6P1BDU80Fe]K04I6AP1WIfL0Hf=S01dM7@1;Bd/0JFUY06YZJP0U9BD0E5AD079bLP0U9BD0
ATI607MgM`1GEeL08B4Q059BDP0N7Qh0GEeM0:2PX01;Bd/0<C4a04i>CP0W9bL0;Bd]09JFUP1cLg<0
71`L02/[:`1IFET0Bd];061PH02FUYH0M7Ad020P800/;2`0GUiN06MWI`1CDe<0XJ6Q05YJFP0Z:RX0
D51@06i^KP1`L700I6AT05]KF`0Z:RX05aLG03Hf=P1MGEd0ATI607AdM025QHD06ATI034a<@1?Cdl0
H61P051@D01OGel0=CDe01TI6@1LG5`0Ng]k04I6AP18B4P0F5QH01HF5P0W9bL0UYJF07IfMP0e=CD0
Cdm?02TY:@0n?Sh0IfMW05EEE@0P8200ADE5051@D018B4P0HV9R06a/K00b<S80>CTi05mOG`15ADD0
GEeM09JFUP0/;2`0820P03/k>`16ATH0E5AD09jNWP1^KVh071`L03Lg=`1:BTX0De=C09ZJVP1]KFd0
71`L03Lg=`12@T80CDe=07IfMP1XJ6P06a/K02h^;P11@D40J6QX065QH@2GUiL0@T9203Hf=P1QHF40
MgMg04m?C`1KFe/0Rh^;04i>CP0W9bL0EEEE079bLP1=CDd0IfMW0820P00_;bl09bLW05mOG`1ZJVX0
ADE503Ph>01/K6`0A4A4030`<01ZJVX0M7Ad03/k>`1DE5@0G5aL038b<P13@d<0VIVI08B4Q00[:b/0
>SXj030`<00m?Cd0Ogmo09JFUP12@T80;Bd]04a<C017AdL0BDU907QhN02m_Kd0BDU902TY:@0l?3`0
BTY:06EUI@1ADE40UYJF02d];@0[:b/0A4A403dm?@11@D40E5AD06e]K@0W9bL08B4Q03De=@1@D500
Ng]k08Z:RP1MGEd00P0l?3`0o`1LG5`0IfMW04=3@`1QHF40OGem05EEE@1mOGd0RXZ:07=cL`1PH600
Rh^;0;Ng]`11@D40CTi>059BDP1WIfL0EEEE02XZ:P16ATH0=3@d03`l?01NGUh0BDU904A4A010@400
F5QH05MGE`1JFUX0@D51059BDP22PX80De=C04i>CP1GEeL0EUIF08f=S@1oOgl0?Cdm03Xj>P15ADD0
?clo04I6AP1@D500Cdm?061PH01>CTh0Bd];04m?C`1LG5`0CTi>07moO`1QHF40A4A4069RHP11@D40
IfMW07EeM@1IFET0EeMG07]kN`1KFe/0FUYJ04I6AP1OGel0K6a/075aL@1SHf<0GUiN08B4Q01`L700
EEEE04A4A01dM7@0Kfm_05QHF01`L700ATI607moO`1JFUX0BDU907QhN011@D40ATI606a/K00g=cL0
A4A403Xj>P1PH600DU9B03dm?@1=CDd0Kfm_06QXJ015ADD0A4A4061PH00b<S80ADE504I6AP1ADE40
BTY:03hn?P1@D500I6AT05YJFP16ATH0DU9B061PH01;Bd/0EUIF06a/K01QHF40EEEE04E5A@1CDe<0
AdM705ADE011@D40HF5Q04Q8B01]KFd0J6QX06m_K`1HF5P0=SHf04e=C@1<C4`0EEEE05ADE011@D40
>3Ph04E5A@1OGel0JFUY0820P01PH600O7al06UYJ@1mOGd0S8b<0:f][@35aLD0FEUI08f=S@2KVi/0
NGUi09nOW`1QHF40FEUI06][J`1CDe<0HV9R03hn?P0o?cl0Bd];03/k>`1;Bd/0GemO08>3P`19BDT0
EUIF04];B`0Z:RX0C4a<0492@P18B4P0De=C01/K6`1;Bd/0IfMW06m_K`1KFe/0MWIf04m?C`1DE5@0
FUYJ05QHF01PH600>3Ph051@D00Y:BT0BTY:055AD@0Z:RX0@D5104Y:BP0o?cl0ATI606=SH`1<C4`0
EeMG03Hf=P10@400<c<c02LW9`12@T80;Bd]04i>CP0J6QX0<30`02XZ:P0N7Qh0EeMG0492@P13@d<0
IfMW028R8P1jNWX0H61P028R8P0n?Sh0<c<c02TY:@0/;2`06ATI04m?C`0Z:RX0FEUI04=3@`1KFe/0
F5QH09JFUP2XZ:P0;Rh^061PH01TI6@0=CDe02h^;P1SHf<0IVIV09FEU@1EEED0IVIV04E5A@1<C4`0
Bd];03/k>`0l?3`0>c/k03Ph>00^;Rh0Cdm?04i>CP1SHf<0?Shn07EeM@22PX80BTY:0:JVYP19BDT0
DU9B03`l?021PH40NWYj03/k>`00=P1NGUh0AdM702XZ:P0W9bL0EeMG03Ti>@1BDU80ATI608V9R@1F
EUH0ADE5059BDP0o?cl0G5aL04I6AP1OGel0LG5a04I6AP1>CTh092@T04e=C@1:BTX0De=C04Q8B01?
Cdl0F5QH028R8P1EEED0?3`l08>3P`1nOWh0GEeM071`L017AdL0ADE507IfMP1LG5`0R8R805aLG010
@400B4Q80410@018B4P0?Shn03Ti>@1:BTX0EUIF05]KF`1HF5P0O7al04a<C01IFET0H61P06QXJ080
GemO00<0G5aL08f=SOooool00Oooool0003o069RHP1oOgl0GemO08F5Q@15ADD0D51@09^KV`1RHV80
K6a/05iNGP1>CTh0CDe=096AT@1]KFd0JFUY03Xj>P0m?Cd0<30`06ATI02;Rh/0>SXj06QXJ00K6a/0
:b/[05EEE@1_Kfl0<30`05eMG@1WIfL07AdM05eMG@2=SHd0HV9R04Q8B01YJFT0>3Ph02l_;`1FEUH0
Kfm_02XZ:P0[:b/0=cLg03@d=01CDe<0RXZ:05mOG`0P8200A4A4059BDP0m?Cd0L71`0:BTY00Z:RX0
<30`05ADE01SHf<0GUiN08n?S`1MGEd05aLG04];B`1?Cdl0E5AD07UiN@2WYjL0?Cdm01PH600W9bL0
IFEU051@D01^KVh0LG5a01LG5`0i>CT0EeMG07UiN@10@400F5QH03dm?@0I6AT0=cLg059BDP1GEeL0
?3`l06=SH`0I6AT08B4Q03/k>`1]KFd0DU9B02`/;01fMWH092@T01TI6@1[Jf/0QXJ602TY:@0U9BD0
@41004a<C01=CDd0MWIf06UYJ@0C4a<0820P059BDP0i>CT0?Shn0820P00c<c<0:BTY04A4A01WIfL0
CDe=05iNGP24Q8@0>c/k03@d=00h>3P0FUYJ02l_;`1IFET0HF5Q01hN7P0Y:BT0EeMG05YJFP0j>SX0
B4Q806ATI00G5aL0;Rh^059BDP1aLG40>3Ph02`/;01BDU809BDU02PX:01PH600[Jf]034a<@0c<c<0
@T9201XJ6P0c<c<0TY:B06IVIP0N7Qh0?clo05IFEP17AdL0HV9R07]kN`0_;bl06a/K04M7A`1OGel0
DE5A04Q8B00M7Ad0@d=304m?C`1<C4`0CTi>092@T00Q8B408b<S07AdM02OWil092@T03<c<`1KFe/0
;bl_02LW9`1KFe/0RXZ:03/k>`0e=CD0KFe]03hn?P0m?Cd0BTY:06IVIP1<C4`0E5AD05iNGP0U9BD0
H61P09bLW01JFUX0=cLg069RHP1=CDd0<S8b05IFEP2JVYX0ATI603Xj>P1KFe/08b<S05iNGP2[Zj/0
U9BD03Xj>P0h>3P0EEEE04E5A@1nOWh0[jn_02h^;P0G5aL0Bd];075aL@14A4@0NWYj0410@00a<C40
EEEE05IFEP1SHf<0L71`06QXJ00L71`0CDe=071`L01>CTh0FEUI07emO@0M7Ad0?clo07]kN`17AdL0
B4Q805YJFP0Q8B40820P0451@@28R8P0=3@d06QXJ00g=cL0>3Ph04M7A`1]KFd0:RXZ05UIF@0k>c/0
6a/K05mOG`2][Jd0CTi>03Hf=P1SHf<0:2PX000I07EeM@2e]KD0Ng]k03@d=01<C4`0BDU903`l?01T
I6@0[jn_08F5Q@12@T80Bd];05=CD`19BDT0VIVI0;Rh^016ATH092@T03`l?01<C4`0G5aL07]kN`2`
/;00C4a<028R8P0205MGE`1>03Ti>@20P800XZ:R03`l?00j>SX0Hf=S09:BTP1EEED0NWYj04U9B@0K
6a/0:2PX07]kN`2<S8`0:b/[04Y:BP0g=cL08B4Q02HV9P1SHf<0PX:20492@P1<C4`0De=C01/K6`19
BDT0SHf=07QhN00V9RH0@4100492@P0W9bL0ATI60:FUY@2IVIT0:2PX03Lg=`1NGUh0HV9R04Q8B013
@d<0C4a<05=CD`1XJ6P0Cdm?03De=@1`L700G5aL04I6AP13@d<0GEeM07]kN`20P800Q8B405mOG`0a
<C40ATI603lo?`1OGel0B4Q801dM7@0d=3@0@d=305UIF@1>CTh0@D5105UIF@1HF5P0CDe=04A4A016
ATH0Fe]K06m_K`1EEED0ADE508^;R`2TY:@0Ogmo0P1hN7P0201VIVH0=CDe03Ti>@1RHV80IfMW05eM
G@0c<c<0ATI60P1>CTh04@1;Bd/0EUIF038b<P0n?Sh0F5QH0492@P1?Cdl06QXJ02d];@0l?3`0Cdm?
05eMG@0h>3P07alO03`l?01HF5P0Hf=S0080De=C09X0IfMW07EeM@1@D500EeMG05iNGP11@D40HF5Q
04];B`15ADD0D51@03dm?@1VIVH0Kfm_05EEE@1DE5@0@4100451@@1GEeL0>SXj03Hf=P0_;bl0?Cdm
02XZ:P0W9bL09BDU02HV9P1<C4`0=SHf024Q8@0o?cl05aLG04M7A`1>CTh0>3Ph04e=C@0j>SX0Hf=S
02h^;P1:BTX0ATI605UIF@0h>3P0AdM704m?C`1=CDd0@d=304a<C01:BTX0FUYJ079bLP1QHF40BDU9
07QhN01DE5@0OGem075aL@1QHF40U9BD06QXJ02GUiL0IfMW06m_K`1YJFT0GemO04=3@`1<C4`0LW9b
08b<S01mOGd0Rh^;08J6QP1VIVH0RXZ:09RHV02FUYH0S8b<06=SH`1_Kfl0Cdm?065QH@1nOWh0EUIF
03/k>`1RHV80BTY:06e]K@13@d<0?Shn03dm?@13@d<0BDU907QhN01cLg<0A4A403Ti>@13@d<0B4Q8
05]KF`1OGel0H61P0861P@0b<S80:BTY03Ph>01BDU80Jf][09jNWP1EEED0@d=304Y:BP1EEED0H61P
05IFEP1WIfL09RHV03dm?@1<C4`07AdM03dm?@1@D500?3`l04Q8B01HF5P0<S8b04Q8B017AdL0BDU9
04];B`0Q8B40?Shn03Xj>P1=CDd0;Bd]03@d=00b<S805QHF0410@00h>3P0@d=305]KF`0[:b/0PH61
06][J`0L71`0DE5A03`l?00Y:BT0FEUI03<c<`1UIFD0@D5108J6QP1IFET0JVYZ0P1MGEd03P1/K6`0
9BDU06i^KP1^KVh0=cLg02d];@1ADE40AdM705YJFP19BDT0O7al04Y:BP1ADE40HF5Q0P1?Cdl0?@1;
Bd/0CDe=03hn?P1MGEd0HF5Q075aL@0d=3@0ADE5051@D00V9RH0BTY:04U9B@1fMWH0BTY:05aLG01:
BTX0:BTY0451@@1]KFd0?Cdm02@T9013@d<08b<S06ATI00k>c/0V9RH04i>CP0a<C40BDU902/[:`1V
IVH0CDe=06i^KP1cLg<0?clo04M7A`0`<300Fe]K0410@00i>CT0@d=304I6AP1CDe<0:b/[06IVIP16
ATH0Fe]K05MGE`0L71`0Ogmo05QHF01@D500L71`04m?C`1BDU80GemO04I6AP1DE5@0?Shn055AD@0P
82000P0k>c/0301UIFD0B4Q8061PH01FEUH0EeMG065QH@1MGEd0De=C04Q8B01VIVH0Cdm?06UYJ@;o
oooo0000Q@1[Jf/0CDe=04m?C`2NWYh0FUYJ04m?C`1VIVH0BDU907]kN`2=SHd0>3Ph04Y:BP1>CTh0
DE5A0:>SX`1VIVH0;Rh^02@T901HF5P0C4a<06ATI032`/80;Bd]02@T900a<C40HV9R04Y:BP2>SXh0
Shn?02/[:`0Q8B40@d=305UIF@1bLW80`L710492@P14A4@0BTY:05ADE01OGel0OWin08V9R@0J6QX0
ATI606EUI@1_Kfl0EeMG0:RXZ01@D500:BTY03/k>`1FEUH0E5AD06a/K02NWYh09BDU02LW9`19BDT0
Lg=c03hn?P1hN7P0?Cdm01dM7@0/;2`0NGUi05YJFP0X:2P0BDU902@T900H61P0@T9208>3P`0j>SX0
6ATI03Ph>01@D500>3Ph06a/K01<C4`051@D01`L7010@400=3@d069RHP2/[:`0<30`01LG5`0Z:RX0
Hf=S059BDP15ADD0_[jn0410@00Z:RX07alO05MGE`1BDU80E5AD09^KV`0B4Q80:b/[02d];@1hN7P0
DU9B06ATI025QHD051@D01/K6`0g=cL0FEUI02<S8`1bLW80L71`01DE5@0D51@0FUYJ0492@P0H61P0
Cdm?01dM7@0T92@0@d=307alO00e=CD06QXJ05EEE@1;Bd/0=CDe079bLP2CTi<0<C4a01/K6`15ADD0
0P12@T80M01/K6`0O7al01LG5`0F5QH0>c/k06IVIP1GEeL0O7al07=cL`0H61P09bLW05eMG@1_Kfl0
MGEe05iNGP0m?Cd0<c<c04U9B@1DE5@0FUYJ05EEE@1TI6@0:RXZ03<c<`1EEED071`L03Ph>013@d<0
=SHf05YJFP2FUYH0JVYZ02LW9`14A4@0DE5A03<c<`1[Jf/0YZJV04E5A@0I6AT0=cLg059BDP0j>SX0
Hf=S07emO@0k>c/092@T05YJFP13@d<0@D510:^[Z`2XZ:P09bLW02`/;01NGUh0GEeM04m?C`2PX:00
Hf=S02HV9P1=CDd0O7al04m?C`1dM7@0PH6103/k>`0P8200?Shn08J6QP1@D500FUYJ06=SH`14A4@0
@T9205mOG`1YJFT0FUYJ06QXJ010@400@T9206e]K@1FEUH0<30`05]KF`0g=cL0:b/[06e]K@2MWId0
IFEU03hn?P1JFUX0<c<c04I6AP2<S8`0BDU903Lg=`1>CTh0>CTi07MgM`2MWId0?Shn01TI6@0f=SH0
CTi>03/k>`2ZZZX0HF5Q020P801>CTh0EEEE04];B`20P800EUIF01dM7@13@d<0MgMg0P1RHV80;P2=
SHd09BDU03Ti>@1LG5`0QXJ605aLG01aLG40MGEe04M7A`1ADE40G5aL06ATI01GEeL0KFe]065QH@0[
:b/0>c/k05QHF01VIVH0>CTi059BDP0o?cl08R8R04i>CP1lO7`0Hf=S04M7A`1]KFd0@41001lO7`1K
Fe/0RHV905ADE00];Bd0Hf=S03Lg=`0`<300JVYZ08:2PP0_;bl08b<S03dm?@0n?Sh0E5AD06YZJP1A
DE42020P800L03hn?P18B4P0DU9B08b<S01kNg/07AdM01lO7`1CDe<0PX:203dm?@26QXH0JFUY02HV
9P0_;bl0AdM707=cL`1=CDd0L71`051@D01hN7P0EUIF02XZ:P0f=SH0=CDe071`L01lO7`0BTY:05eM
G@80E5AD04/0D51@07MgM`2TY:@0XZ:R09RHV01YJFT0?Cdm05mOG`1MGEd0JFUY04];B`0];Bd0ADE5
03Lg=`11@D40EeMG03dm?@1LG5`0C4a<0861P@1<C4`0Fe]K0492@P1?Cdl0LG5a03/k>`1]KFd0G5aL
07inOP2XZ:P0U9BD07UiN@0^;Rh0:BTY03<c<`0j>SX0EUIF03/k>`1>CTh0DE5A04i>CP17AdL0EeMG
03Ti>@1MGEd0IFEU03Ti>@1IFET0:2PX06a/K01cLg<0DU9B04U9B@1`L700FEUI05]KF`15ADD0DU9B
079bLP1nOWh0Bd];051@D01ZJVX0FUYJ05]KF`1ADE40JVYZ04];B`17AdL0JVYZ05IFEP1]KFd0ATI6
03Hf=P1dM7@00P1EEED06P1PH600<30`03Lg=`0j>SX0D51@03Hf=P10@400;Bd]03/k>`1@D500?Cdm
02HV9P1:BTX0820P059BDP1EEED0?Cdm04];B`1<C4`0EeMG04Y:BP1EEED0?clo051@D01MGEd0CDe=
0P1EEED0E@1BDU80GEeM04i>CP1LG5`0?clo04e=C@11@D40H61P06YZJP1^KVh0GUiN05MGE`1LG5`0
AdM705]KF`1GEeL0G5aL059BDP0j>SX0@T9204Q8B01WIfL0C4a<07=cL`26QXH0Ogmo07UiN@33`l<0
a<C40>GUi@3Jf]X0L71`0=3@d02?Shl0P82009NGU`1XJ6P0E5AD07UiN@1:BTX0J6QX04a<C01;Bd/0
@41003hn?P1VIVH0OGem06e]K@15ADD0Bd];06e]K@14A4@0D51@03Ti>@1?Cdl0G5aL01TI6@1ADE40
I6AT05QHF01BDU80IfMW04Y:BP1VIVH0Hf=S05YJFP1WIfL0J6QX08J6QP0S8b<0?clo04a<C00_;bl0
>SXj04];B`0b<S80BDU905MGE`0j>SX0EUIF04Y:BP1RHV80?Cdm02LW9`1=CDd00P1ADE40:@0n?Sh0
>c/k02HV9P0N7Qh0EUIF03Hf=P1;Bd/0JFUY01hN7P1@D500FUYJ02d];@1fMWH0820P01/K6`0n?Sh0
6a/K04Y:BP0f=SH0EUIF04A4A01:BTX0Cdm?06m_K`1iNGT071`L06=SH`1kNg/0>SXj02l_;`1UIFD0
JVYZ06IVIP1ADE40GemO05YJFP1LG5`0@T9203Xj>P1FEUH0?Shn0080<c<c0280FUYJ055AD@1OGel0
EeMG07=cL`1WIfL0<S8b08>3P`0f=SH0?clo03<c<`1NGUh0G5aL02/[:`1<C4`0DU9B04a<C01GEeL0
CTi>05ADE01@D500ADE507inOP0a<C40=SHf04a<C00N7Qh0M7Ad071`L01nOWh0RHV903<c<`1gMgL0
=3@d0P1;Bd/0901kNg/0J6QX07]kN`1oOgl0?clo08n?S`13@d<0I6AT04e=C@0c<c<0]KFe06EUI@1A
DE40Ng]k05ADE01IFET0Bd];04Q8B01ADE40<S8b05ADE00M7Ad0D51@05=CD`2QXJ40GEeM06YZJP1T
I6@0IVIV07IfMP1/K6`0De=C05YJFP1dM7@0C4a<05eMG@;ooooo0000C`2/[:`0CTi>04e=C@1LG5`0
LG5a07AdM022PX80@T9206=SH`1lO7`0DU9B09NGU`1=CDd0>SXj07IfMP2EUID0BTY:04e=C@1gMgL0
DU9B03dm?@1gMgL0V9RH065QH@1YJFT0;Bd]02<S8`1;Bd/0Kfm_04U9B@1RHV80G5aL02<S8`0];Bd0
F5QH08:2PP11@D40BTY:04Q8B00L71`0Hf=S0:VYZ@1MGEd0:2PX03Ph>00e=CD0<C4a06i^KP1NGUh0
6ATI038b<P0^;Rh08B4Q059BDP2OWil0ATI601`L700b<S80C4a<04];B`2LW9`0QhN702XZ:P0e=CD0
E5AD04I6AP1FEUH0TI6A03Ti>@0O7al08R8R05MGE`1]KFd0De=C08V9R@0h>3P0:2PX03Ti>@1/K6`0
0P1NGUh0H01MGEd06QXJ02DU9@1CDe<0Hf=S03De=@1KFe/0I6AT02@T900^;Rh0GemO061PH00W9bL0
=SHf03Ti>@0H61P0<S8b07UiN@0m?Cd0;Bd]04=3@`0f=SH0=CDe04m?C`2JVYX09bLW01XJ6P0_;bl0
<S8b02DU9@1bLW80TI6A02<S8`0M7Ad09bLW04Y:BP1ZJVX0P82003<c<`0D51@09RHV051@D01BDU80
EEEE08V9R@1YJFT05ADE038b<P2DU9@0Lg=c05YJFP1QHF40>c/k02<S8`0m?Cd0OWin06IVIP0T92@0
De=C02DU9@0O7al0IfMW08J6QP0];Bd0;bl_03/k>`0U9BD0=cLg08B4Q01_Kfl07alO03hn?P0j>SX0
Bd];06][J`2f][H0GemO02DU9@1FEUH0;Bd]05UIF@1`L7004a<C034a<@1nOWh0NWYj06UYJ@27QhL0
?Cdm0410@019BDT0IVIV06QXJ01;Bd/0RHV90492@P80:BTY04/0IFEU075aL@1<C4`0RHV904a<C00]
;Bd0ATI609bLW01NGUh0ADE505eMG@0L71`09BDU05]KF`20P800<C4a04];B`1<C4`0<S8b03Ph>02H
V9P0IFEU02/[:`15ADD0De=C034a<@23Ph<0RXZ:02/[:`14A4@0ATI6034a<@1fMWH0dM7A0820P00/
;2`0IVIV05IFEP16ATH0TI6A05YJFP0X:2P0<C4a07AdM01LG5`0De=C05aLG00W9bL0De=C05UIF@1B
DU80GUiN06a/K00K6a/0ADE506][J`1hN7P0@41006i^KP13@d<06QXJ059BDP1oOgl0?3`l04Y:BP0g
=cL0;bl_05YJFP1iNGT0=cLg04Y:BP1NGUh0@D510492@P1OGel00P17AdL0K01PH600>SXj04E5A@2I
VIT0SHf=03De=@19BDT0ATI603Lg=`1>CTh0Ph>306MWI`0S8b<0ATI6069RHP17AdL0EeMG0:6QX@2X
Z:P092@T02TY:@1TI6@0EeMG04a<C02l_;`0IFEU028R8P0j>SX0KFe]08R8R01BDU80][Jf06][J`0P
8200EEEE079bLP14A4@0ADE5079bLP0Y:BT0;bl_05IFEP1GEeL0;bl_04A4A01hN7P0>3Ph02h^;P11
@D40QXJ6059BDP0V9RH0AdM701TI6@0`<300Bd];05iNGP0f=SH08R8R04E5A@0g=cL0<C4a05UIF@1C
De<0PH6109:BTP1<C4`0=cLg03`l?01?Cdl0A4A402PX:01/K6`0Q8B405=CD`1?Cdl0GUiN069RHP1Z
JVX0XJ6Q06IVIP1EEED0CTi>04M7A`28R8P0AdM701hN7P0i>CT0>3Ph04=3@`1ADE40@d=3055AD@19
BDT0HV9R06][J`1XJ6P0AdM705EEE@1gMgL0K6a/07QhN01nOWh0Lg=c08N7Q`2IVIT0RHV904a<C080
?Shn03l0BTY:06IVIP1GEeL0JVYZ06ATI01OGel0J6QX079bLP0Z:RX0>SXj05]KF`1EEED0F5QH024Q
8@0];Bd0D51@069RHP1WIfL0BDU902/[:`1<C4`0Bd];05IFEP1WIfL0F5QH04];B`1EEED0C4a<04i>
CP16ATH0>CTi05mOG`1WIfL0FEUI04Y:BP0/;2`0E5AD06YZJP1HF5P0GUiN03De=@0W9bL0EEEE04I6
AP0_;bl0:2PX04e=C@12@T8092@T03/k>`1DE5@0DU9B03@d=00W9bL0D51@02LW9`0l?3`0@D5103Ti
>@0g=cL0;Rh^04E5A@0k>c/00P0o?cl02016ATH0?3`l03Xj>P0h>3P0B4Q805ADE016ATH0AdM70P1@
D500601GEeL0CTi>06e]K@18B4P0NWYj071`L01GEeL0OWin07=cL`2PX:00D51@05ADE01/K6`0JVYZ
04U9B@1BDU80I6AT06QXJ027QhL0WinO0;:b/P20P800GemO07emO@80d];B01l0GUiN04a<C016ATH0
EUIF07]kN`1RHV80ATI605=CD`18B4P0EUIF04I6AP1<C4`0?Shn02XZ:P11@D40Q8B407IfMP1VIVH0
KFe]05UIF@14A4@0D51@055AD@16ATH0G5aL02<S8`0h>3P0ADE505MGE`1XJ6P0Rh^;0080BTY:08X0
AdM7051@D01RHV80?Cdm069RHP0Y:BT0D51@05MGE`0i>CT0D51@05QHF00j>SX0?clo05aLG01<C4`0
J6QX03Ti>@11@D40Cdm?02/[:`11@D40:2PX05UIF@0R8R80=CDe05EEE@0c<c<0GEeM04I6AP0[:b/0
B4Q801HF5P1MGEd0NGUi02DU9@1ADE407alO02DU9@18B4P0<c<c05]KF`19BDT0H61P05YJFP1LG5`0
EEEE08N7Q`2ATI40=SHf06][J`1TI6@0FUYJ04E5A@1_Kfl0C4a<08:2PP1GEeL0Jf][059BDP1JFUX0
EUIF04Q8B01CDe<0BDU904Q8B012@T80JFUY05EEE@1]KFd0A4A4059BDP1QHF40?clo06QXJ01ADE40
J6QX04A4A025QHD0PH61059BDP1NGUh0CTi>0492@P18B4P0H61P03Lg=`1GEeL0@D51059BDP14A4@0
BDU904Q8B00_;bl0C4a<03/k>`1aLG40EEEE03De=@12@T8071`L04Q8B00n?Sh0CDe=03<c<`18B4P0
CDe=04=3@`1`L700>c/k07MgM`1KFe/0=cLg06m_K`1=CDd0Hf=S0::RXP18B4P0FEUI04a<C01;Bd/0
GEeM05iNGP2ATI40BTY:04U9B@0c<c<0H61P05iNGP1MGEd0QhN706a/K01SHf<0D51@06UYJ@1EEED0
GEeM05UIF@1kNg/2ooooo`0000L0MgMg06i^KP1FEUH0NGUi03lo?`1FEUH0YjNW0080EUIF06D0CDe=
0451@@2>SXh0VYZJ04i>CP1ADE40Jf][04e=C@1KFe/0GUiN03dm?@0_;bl0I6AT04e=C@25QHD0YjNW
03Hf=P0K6a/0>c/k05UIF@0m?Cd0CTi>08b<S00d=3@0:2PX04e=C@1SHf<0LW9b07EeM@0i>CT09RHV
01dM7@1BDU80EeMG07emO@1_Kfl051@D01hN7P1=CDd0O7al0492@P27QhL0H61P01`L700K6a/0AdM7
05iNGP1:BTX0TI6A020P800Y:BT0FUYJ05]KF`1:BTX0@T9208Z:RP0Y:BT09BDU065QH@1DE5@0;bl_
034a<@0l?3`09bLW02@T9018B4P0CTi>02DU9@1DE5@0;bl_028R8P1jNWX0Ogmo02<S8`0M7Ad0=cLg
03De=@0a<C40IVIV07UiN@0N7Qh05aLG03dm?@1>CTh0ATI607EeM@1fMWH0820P02`/;014A4@0PX:2
065QH@20P800AdM702l_;`0k>c/0EeMG05ADE01=CDd0GemO01/K6`02028R8P0@05EEE@10@400;bl_
061PH00G5aL0;Rh^0451@@1BDU807AdM034a<@1;Bd/0:b/[034a<@1LG5`0IfMW01hN7P80<c<c04X0
?3`l06i^KP1nOWh0Bd];018B4P0V9RH0>3Ph04a<C01ADE40Xj>S05EEE@0?3`l09bLW05eMG@17AdL0
LW9b06a/K00a<C40:BTY04Y:BP1TI6@0EeMG08>3P`1KFe/05ADE03hn?P0l?3`0R8R805UIF@1aLG40
:BTY04U9B@1=CDd0=cLg04i>CP1ZJVX08B4Q04M7A`1UIFD0JVYZ02TY:@1:BTX0U9BD04i>CP0h>3P0
ZZZZ09FEU@0V9RH0>c/k05YJFP0Y:BT0?Cdm0;2`/01SHf<09BDU034a<@19BDT0IVIV06][J`2/[:`0
;2`/034a<@16ATH0MWIf06IVIP1kNg/0KFe]02<S8`0b<S80=cLg06e]K@1MGEd0Ogmo04M7A`80;bl_
03X0GEeM04e=C@2IVIT0UIFE028R8P0P8200DU9B08>3P`1<C4`0KVi^03De=@0W9bL0=3@d065QH@0f
=SH0A4A4038b<P0V9RH0@d=305]KF`0h>3P0>c/k04a<C00Y:BT0F5QH0:BTY01>CTh0>CTi04];B`14
A4@0=3@d0861P@1lO7`0;Rh^02l_;`0i>CT0CTi>08Z:RP19BDT09BDU04E5A@0j>SX0@T9209fMW@2R
XZ80;bl_05UIF@1HF5P0ADE50861P@2XZ:P0Fe]K030`<01EEED0HV9R04e=C@1cLg<0MgMg0P0e=CD0
M02CTi<0[Zj^04Y:BP1iNGT0Kfm_03Lg=`0_;bl0@T92075aL@1UIFD0G5aL08f=S@0h>3P0:BTY05QH
F026QXH0;Bd]0410@019BDT09bLW03/k>`1[Jf/0MGEe03lo?`1FEUH0DE5A02DU9@1;Bd/0Shn?04Q8
B00O7al0AdM703hn?P0N7Qh0BTY:09nOW`17AdL0;bl_04A4A015ADD0@T9206e]K@2a/K409BDU030`
<00a<C40GEeM0492@P0Z:RX0Q8B402/[:`1>CTh0Bd];04i>CP25QHD0EeMG01`L700f=SH0B4Q807Yj
NP1GEeL0:RXZ04I6AP1OGel0LW9b04M7A`1YJFT0Ogmo0861P@2[Zj/0Q8B404M7A`1IFET0Cdm?08Z:
RP1YJFT0<C4a04m?C`1FEUH0A4A4065QH@1=CDd0KFe]04A4A027QhL0E5AD06EUI@1;Bd/0CTi>07Yj
NP1MGEd0TI6A08V9R@2KVi/0UYJF07emO@1dM7@0<C4a03Xj>P0e=CD0@d=306][J`0f=SH0ATI604e=
C@1:BTX0@T92069RHP0d=3@0?Shn06=SH`0m?Cd0EUIF02d];@0k>c/0F5QH0P14A4@0A`1<C4`0=SHf
059BDP1QHF40Jf][06IVIP1TI6@0JFUY06a/K01=CDd0EeMG06ATI01DE5@0D51@03De=@0c<c<0G5aL
061PH01ZJVX0C4a<02DU9@1RHV80>SXj03lo?`1DE5@0<30`0410@00o?cl0BTY:03Lg=`0k>c/0;Rh^
02XZ:P17AdL0ADE502DU9@1<C4`0>3Ph04];B`1>CTh0?clo04U9B@1=CDd0F5QH03dm?@1:BTX0DE5A
059BDP19BDT0Cdm?05]KF`1=CDd0A4A404i>CP18B4P0G5aL06YZJP1ADE40?Cdm04];B`1IFET0Ogmo
04e=C@10@400HV9R04Q8B01`L700C4a<04i>CP1DE5@0?Cdm0080?clo0;D0Hf=S065QH@1[Jf/0OGem
075aL@25QHD0d];B0;:b/P3YjNT0gMgM07EeM@20P800PH61079bLP2MWId0GemO05=CD`1UIFD0D51@
05]KF`1_Kfl0ADE502d];@1:BTX0Jf][06MWI`1KFe/0BTY:0410@01;Bd/0?Shn04M7A`1mOGd0Ph>3
08b<S00l?3`0A4A405EEE@0j>SX0OGem0<C4a01]KFd0BDU904A4A00i>CT0D51@04U9B@1/K6`0;Rh^
04E5A@13@d<0:BTY03Lg=`17AdL0;Bd]055AD@1GEeL0ATI607EeM@0Q8B40ADE502LW9`0h>3P0BDU9
02h^;P1MGEd0ATI604Y:BP0m?Cd08B4Q04E5A@0i>CT0B4Q8065QH@1BDU80?clo065QH@14A4@0LW9b
06UYJ@0P8200@D5102PX:01ADE40?Shn06QXJ01JFUX0AdM705MGE`1PH600I6AT02TY:@1TI6@0MGEe
04I6AP0];Bd0@d=304Y:BP1QHF40J6QX08B4Q01=CDd0BTY:06IVIP1?Cdl0BTY:055AD@16ATH0>3Ph
05aLG020P800S8b<055AD@1CDe<0DE5A03Hf=P1UIFD0?Shn04a<C00l?3`0HF5Q05QHF00e=CD0De=C
09FEU@1MGEd0EEEE04Y:BP0i>CT0F5QH05ADE02<S8`0:BTY03Hf=P16ATH06a/K05=CD`0f=SH0GUiN
05QHF00e=CD0CDe=028R8P1HF5P0@41004m?C`11@D40F5QH05UIF@1_Kfl0X:2P03Lg=`20P800LW9b
03De=@22PX80@d=305mOG`1nOWh0MgMg09ZJVP1aLG40C4a<04i>CP0W9bL0ADE501XJ6P0m?Cd09RHV
05iNGP1:BTX0De=C05IFEP1:BTX0HF5Q04a<C01^KVh0I6AT06UYJ@1PH600JFUY00;ooooo0000801J
FUX0NWYj06QXJ02OWil0@d=304i>CP22PX80MGEe0:^[Z`1eMGD0=CDe05YJFP2SXj<0NWYj0;2`/01J
FUX0>CTi0492@P1VIVH0GEeM07alO02n_[h0>3Ph028R8P1VIVH0P82004i>CP1bLW80MGEe020P8014
A4@0I6AT0P1;Bd/0n`1RHV8092@T034a<@1LG5`0M7Ad03@d=01GEeL0ADE501/K6`0o?cl0NGUi03lo
?`0T92@0Bd];03lo?`0n?Sh0R8R8096AT@0`<300=SHf034a<@1=CDd0EUIF092@T00l?3`06ATI03lo
?`1RHV80DU9B06][J`2OWil0@D5101dM7@1@D500EUIF055AD@1YJFT0Y:BT02HV9P0_;bl0<c<c06IV
IP1GEeL0Q8B4034a<@0I6AT092@T059BDP0n?Sh0@T9208j>SP0P82007QhN034a<@1HF5P0CTi>03Lg
=`1cLg<06ATI01XJ6P0c<c<0EeMG02d];@0e=CD0Kfm_02TY:@0g=cL0E5AD0492@P0A4A40<C4a059B
DP0Q8B40De=C08b<S00];Bd071`L03<c<`0o?cl0>3Ph05aLG01nOWh08R8R01hN7P11@D40A4A403/k
>`1PH600OGem01lO7`0c<c<0EEEE06m_K`19BDT0KFe]09FEU@0R8R80>3Ph05aLG02RXZ80>c/k03Xj
>P1NGUh09RHV03Ti>@1dM7@0Vi^K04E5A@19BDT0?clo01hN7P0h>3P0K6a/03`l?00i>CT0GemO03Xj
>P0];Bd0N7Qh0:BTY00n?Sh0@41005iNGP10@400<30`08:2PP0N7Qh0AdM7065QH@0h>3P0Ogmo075a
L@0n?Sh07alO059BDP1mOGd0B4Q807YjNP2XZ:P0@41001hN7P1RHV80ZJVY04];B`1iNGT0V9RH02<S
8`0X:2P0F5QH0;Vi^@1>CTh0RXZ:06MWI`0I6AT0ATI60861P@24Q8@0;2`/09:BTP0c<c<0=SHf06AT
I01`L700>CTi03dm?@1;Bd/0:RXZ03`l?01jNWX0XZ:R03lo?`1FEUH0=SHf02h^;P29RHT0a<C406IV
IP0_;bl0DE5A03dm?@1@D500YjNW08V9R@0j>SX0G5aL051@D01XJ6P0Y:BT08>3P`0M7Ad0>CTi05IF
EP11@D40Ogmo08>3P`0O7al0CTi>06IVIP1;Bd/0HV9R08n?S`0P8200;Rh^05=CD`1gMgL0B4Q808R8
R00a<C407AdM05EEE@1TI6@0CDe=05MGE`0T92@07AdM04Y:BP2;Rh/0BTY:04A4A01NGUh09bLW05YJ
FP1aLG40Hf=S04I6AP1HF5P0EUIF03De=@1MGEd0UiNG0492@P0U9BD0@d=305]KF`1GEeL0GUiN08n?
S`1QHF409BDU05UIF@15ADD0GEeM065QH@2h^;P0DU9B03Hf=P0n?Sh0CTi>0492@P2BTY80XJ6Q0080
;Rh^0?l0I6AT061PH01EEED0/k>c09jNWP0b<S80=SHf06ATI01PH600B4Q8075aL@0c<c<08R8R04Y:
BP19BDT0QHF50492@P16ATH0IFEU01hN7P0M7Ad0HF5Q05mOG`0O7al0CTi>02/[:`0L71`0;2`/06YZ
JP1BDU809BDU05UIF@1]KFd0N7Qh04i>CP0Q8B40GEeM07EeM@1/K6`0DU9B03`l?01lO7`0NWYj08J6
QP1JFUX0IVIV09FEU@2ZZZX0JFUY055AD@1HF5P0Jf][06ATI01QHF40BDU902l_;`1LG5`0Bd];05mO
G`1hN7P0F5QH07MgM`17AdL0Ogmo06i^KP1]KFd0G5aL05MGE`2>SXh0J6QX092@T02^[Zh0Z:RX0;6a
/@2/[:`0Shn?03`l?013@d<0A4A405=CD`1gMgL0BDU905YJFP1?Cdl0CTi>04m?C`1MGEd0=CDe05EE
E@1^KVh0@d=306UYJ@0`<300=CDe06IVIP1EEED0BTY:06QXJ00_;bl0IFEU03dm?@1>CTh0B4Q804E5
A@0m?Cd0F5QH04];B`1RHV80GEeM0451@@1aLG40CTi>04A4A01VIVH0?Cdm055AD@13@d<0?Cdm061P
H01JFUX0IFEU059BDP0j>SX0=SHf03dm?@10@400<c<c03@d=00[:b/0;Bd]04a<C00/;2`0;Rh^04A4
A00M7Ad0>c/k055AD@0];Bd0?Cdm030`<01JFUX0BDU904];B`10@400EUIF04E5A@1DE5@0?Shn03dm
?@1?Cdl0EUIF06=SH`1JFUX0AdM7069RHP1FEUH0NWYj0451@@1TI6@0LG5a05eMG@2KVi/0H61P09>C
T`1JFUX0GemO06a/K01ADE40De=C04E5A@1bLW80F5QH096AT@2[Zj/0R8R807UiN@1QHF40L71`08V9
R@1iNGT0EeMG0;Rh^02b/[80GemO07EeM@0l?3`0Bd];04Q8B00];Bd0C4a<02TY:@0h>3P0@D5102PX
:00g=cL0Lg=c07IfMP1JFUX0JFUY06MWI`1@D500@d=303Hf=P0[:b/0@D5101dM7@1>CTh0D51@02<S
8`0f=SH0HV9R03`l?01ADE40Cdm?05=CD`1ZJVX0<C4a06MWI`0P8200=cLg04U9B@0S8b<0<S8b0451
@@0L71`0=CDe04Q8B016ATH0E5AD03hn?P1WIfL0:BTY02LW9`0/;2`0CDe=07=cL`0[:b/0Fe]K03Ti
>@0Y:BT0?Shn04Q8B01=CDd0Hf=S04I6AP0e=CD0JVYZ04m?C`1FEUH0LG5a04M7A`1XJ6P0A4A4051@
D01KFe/000`0Ph>308j>SP1JFUX0CDe=06][J`20P800:RXZ05aLG01PH600<c<c04Q8B027QhL205AD
E01B03@d=01@D500B4Q804Q8B01>CTh0?3`l04];B`10@400>3Ph03De=@1>CTh0ATI605MGE`0e=CD0
BDU90451@@0l?3`0Kfm_04m?C`1EEED0@41008j>SP2IVIT0ATI604M7A`1GEeL0AdM704m?C`1`L700
;bl_06ATI00`<300EUIF03lo?`0j>SX0@D5103`l?02CTi<0GemO051@D01LG5`09bLW05IFEP0S8b<0
?clo0451@@1PH600ADE506IVIP18B4P0A4A405mOG`1BDU80OGem06MWI`1TI6@0clo?05mOG`1[Jf/0
L71`0492@P18B4P0Fe]K04i>CP1FEUH0@T9205aLG00j>SX0Bd];03hn?P2KVi/0PX:207YjNP2@T900
F5QH05mOG`0n?Sh0HF5Q04m?C`1HF5P0GemO07IfMP;ooooo0000o`2SXj<0EUIF06EUI@23Ph<0Fe]K
06][J`1PH600?3`l06m_K`24Q8@0Cdm?069RHP0o?cl0CTi>06UYJ@2=SHd0>SXj03`l?018B4P0:BTY
03hn?P1oOgl0CDe=03Ti>@1EEED0>c/k04E5A@1YJFT0Ng]k034a<@0i>CT0EEEE05=CD`2IVIT0_;bl
038b<P0Y:BT0;2`/04U9B@1CDe<0WinO06m_K`0K6a/05QHF03<c<`0i>CT0H61P0:VYZ@1@D5005ADE
03De=@1=CDd0@4100820P01aLG407AdM02TY:@1]KFd0V9RH03Lg=`1hN7P0De=C01lO7`12@T80Ng]k
0:FUY@11@D40IFEU03/k>`0];Bd0@T9204e=C@1BDU80;bl_04m?C`0M7Ad0@D5104i>CP1OGel07QhN
03De=@16ATH0;Rh^05QHF01iNGT0=3@d01TI6@0d=3@0>c/k04A4A01?Cdl0P82005]KF`0>3Ph0=CDe
04e=C@15ADD0EUIF09nOW`0U9BD07alO05mOG`1YJFT0Bd];075aL@25QHD07QhN01TI6@1TI6@0K6a/
03Xj>P1[Jf/0:RXZ02TY:@0b<S80QHF506][J`0j>SX0BDU9034a<@0O7al0<S8b05ADE00i>CT071`L
06QXJ00`<300:2PX04Y:BP1WIfL0>3Ph02/[:`1:BTX0<c<c04E5A@1GEeL0H61P02/[:`0M7Ad0>3Ph
059BDP1>CTh0IfMW06IVIP0I6AT07AdM055AD@1TI6@0H61P09fMW@0];Bd0=SHf04E5A@1GEeL0AdM7
07QhN035aLD0<30`02h^;P1LG5`0A4A407YjNP21PH409RHV03dm?@1UIFD0I6AT04Q8B01]KFd0B4Q8
01dM7@1@D500Jf][05iNGP0T92@0AdM704=3@`0Y:BT0EEEE0:RXZ00e=CD09BDU04Y:BP16ATH0A4A4
09jNWP2j^[X0;Rh^01/K6`0k>c/0BTY:05QHF02e]KD0MWIf02LW9`1?Cdl0KVi^059BDP1nOWh0Ph>3
02HV9P0n?Sh0F5QH0;2`/020P800TY:B05aLG00J6QX0Bd];05EEE@1YJFT0L71`08B4Q01<C4`0;bl_
03dm?@1gMgL0KFe]0;:b/P1HF5P08R8R07YjNP2f][H0HV9R055AD@1/K6`0;bl_03hn?P20P800@410
03Ti>@0l?3`07AdM05QHF01cLg<0D51@028R8P1MGEd0<c<c05iNGP1ZJVX0G5aL020P8012@T80>CTi
05aLG02f][H0EeMG02PX:00l?3`0G5aL04a<C02WYjL0/;2`02d];@00>P0_;bl0IFEU06YZJP1BDU80
[Zj^0:2PX00`<300BTY:05IFEP1YJFT0GemO08^;R`0l?3`0>CTi059BDP1QHF40IVIV03lo?`2LW9`0
JVYZ02h^;P0l?3`0IVIV06QXJ017AdL0SHf=06ATI00V9RH0?3`l07EeM@1MGEd0>c/k07EeM@0W9bL0
;Bd]05EEE@2IVIT0I6AT0410@01UIFD09bLW0492@P2CTi<0IVIV02HV9P0b<S80EUIF02l_;`0n?Sh0
Vi^K09:BTP0_;bl0:2PX059BDP1DE5@0>3Ph07]kN`1]KFd201dM7@1:075aL@1UIFD0B4Q807emO@16
ATH0NGUi051@D00e=CD0?clo03`l?01nOWh0JVYZ04I6AP1gMgL0W9bL05ADE00f=SH0D51@06IVIP1[
Jf/0/k>c06i^KP1SHf<0CTi>04];B`2BTY80Bd];02TY:@0d=3@0=cLg03Xj>P1GEeL0C4a<04Q8B014
A4@0E5AD08b<S01jNWX0ATI604m?C`1fMWH0Lg=c051@D01PH600De=C07inOP21PH40I6AT0451@@1;
Bd/0@D5103dm?@1=CDd0H61P06=SH`15ADD0?clo06IVIP1[Jf/0<C4a03Hf=P17AdL0CTi>05]KF`0h
>3P0@D51061PH01HF5P0DU9B071`L011@D40HF5Q0492@P1ADE4205QHF01o04i>CP1OGel0J6QX08:2
PP1XJ6P0AdM707MgM`1@D500?clo08>3P`12@T80Lg=c079bLP11@D40MGEe03<c<`0m?Cd0G5aL04Q8
B00_;bl0<C4a051@D013@d<0=CDe03/k>`0g=cL0GUiN04E5A@0];Bd0C4a<02h^;P15ADD0FUYJ03Lg
=`15ADD0A4A406IVIP1EEED0De=C04m?C`1ZJVX0F5QH061PH01BDU80De=C04Y:BP1PH600CDe=05aL
G01;Bd/0D51@04i>CP1FEUH0?Cdm05MGE`1[Jf/0I6AT06e]K@1ADE40NWYj03lo?`17AdL0CDe=03hn
?P1=CDd0ATI605ADE01BDU80UiNG0<k>cP2n_[h0OGem09RHV01gMgL0SHf=09nOW`1RHV80G5aL06MW
I`1ADE40L71`04i>CP10@400Jf][04Q8B01/K6`0@D5104Y:BP1KFe/0;bl_04e=C@2EUID0U9BD079b
LP18B4P0Cdm?03Ph>017AdL0N7Qh05MGE`1OGel08B4Q04M7A`1HF5P0AdM707]kN`2n_[h0AdM70410
@011@D40IfMW06ATI00o?cl0C4a<02XZ:P1?Cdl0C4a<02HV9P0l?3`0@41001PH601:BTX0Fe]K03Ti
>@1PH6007alO0410@00203<c<`1f0410@01;Bd/0QXJ6028R8P1<C4`0@410010@401CDe<0:BTY04A4
A01HF5P07QhN02`/;01]KFd0<30`06YZJP1cLg<08R8R03Xj>P0L71`0EEEE02@T9013@d<0ATI604m?
C`1PH600][Jf08b<S00X:2P0FUYJ05]KF`1>CTh0@d=305MGE`1?Cdl0IVIV05ADE027QhL0DU9B05QH
F01aLG40DE5A04Q8B01<C4`0CDe=04=3@`1FEUH0Ng]k09BDU01PH600FEUI04U9B@13@d<0SXj>04=3
@`1=CDd0Bd];08Z:RP1OGel0?3`l05eMG@1jNWX0Fe]K04E5A@1BDU80?clo04A4A00i>CT0Shn?0410
@012@T80@d=302d];@11@D408b<S051@D01ADE407alO051@D00f=SH0BDU903/k>`1OGel0BDU905IF
EP16ATH0Bd];07UiN@1<C4`0S8b<05=CD`0i>CT0FUYJ04i>CP1hN7P0PX:203Xj>P1@D500?Cdm04A4
A01ADE40CTi>07alO00m?Cd0@D5103Hf=P1MGEd0AdM705EEE@2PX:00GUiN07]kN`1ZJVX0OGem06QX
J01SHf<0Cdm?05eMG@;ooooo0000?P1XJ6P0MgMg04Q8B01RHV80FEUI0:RXZ027QhL0<c<c04E5A@1R
HV80NGUi09>CT`15ADD0=CDe03hn?P1nOWh0MGEe0:FUY@1cLg<0;2`/0410@01=CDd0IFEU06=SH`2M
WId0;bl_02XZ:P1CDe<0^[Zj07MgM`1mOGd0BTY:03`l?01>CTh0EUIF06IVIP1;Bd/0M7Ad038b<P0O
7al0M7Ad0;Zj^P1@D500@D5105QHF00N7Qh09BDU05ADE01oOgl09bLW04i>CP0V9RH09BDU0410@01_
Kfl0>3Ph03@d=016ATH0<C4a03Lg=`1KFe/0J6QX0P0Q8B40f`10@400Cdm?051@D01gMgL0@T9202DU
9@0i>CT0ATI605=CD`1]KFd0V9RH02/[:`0V9RH0EeMG08:2PP13@d<0FEUI0492@P0d=3@0:BTY075a
L@1[Jf/0:b/[06m_K`26QXH09BDU02TY:@1YJFT0OGem02TY:@1GEeL0BDU901LG5`0^;Rh0F5QH07em
O@0l?3`0IfMW03<c<`0_;bl0B4Q807AdM00];Bd0820P04m?C`0M7Ad0DE5A08>3P`1@D5005ADE02HV
9P0g=cL09RHV05mOG`2@T900:RXZ01@D500U9BD0@d=303lo?`1BDU80YJFU05QHF00S8b<0=cLg05=C
D`1GEeL0Jf][09VIV@0o?cl05ADE03@d=01aLG40LW9b051@D01bLW807AdM02TY:@10@400IFEU06UY
J@0m?Cd0De=C02d];@0d=3@0Fe]K05UIF@0U9BD0>SXj03hn?P0P8200ATI60820P01iNGT0<c<c04Q8
B00[:b/0GemO08>3P`0S8b<09BDU03dm?@1=CDd0DU9B09:BTP1MGEd07alO02d];@18B4P0Ph>306e]
K@2UYJD0L71`020P800n?Sh0LG5a08N7Q`1QHF40[Zj^03Hf=P0i>CT0B4Q807MgM`1JFUX0Jf][05QH
F00D51@0=cLg05YJFP1nOWh0>CTi04M7A`12@T807QhN051@D01LG5`0@T9202h^;P1MGEd0>CTi04M7
A`2d];@0R8R803@d=00m?Cd0BTY:01hN7P18B4P0]kNg06MWI`0`<300A4A402`/;00m?Cd0Zj^[09>C
T`0[:b/0?Shn05YJFP1_Kfl0Ng]k08:2PP0S8b<0<S8b04M7A`1WIfL0PH6108b<S00Q8B40:2PX065Q
H@1UIFD0EUIF0;Ng]`0Q8B40?Cdm06=SH`1<C4`0@41005MGE`0Q8B409BDU06QXJ02PX:00EeMG08B4
Q01UIFD0=cLg04e=C@1SHf<0ADE504=3@`1:BTX0;2`/03<c<`1NGUh0Ti>C05EEE@1>CTh0K6a/03Lg
=`1cLg<0^;Rh09JFUP0/;2`0@D5106QXJ00o?cl0<C4a06QXJ02=SHd0:2PX03lo?`14A4@0@d=306QX
J02DU9@0UiNG034a<@0203hn?P0>04=3@`1fMWH0TY:B02d];@0i>CT0BTY:065QH@1GEeL0K6a/0;^k
^`15ADD0B4Q8061PH01cLg<204i>CP1A09ZJVP1:BTX0BDU906=SH`1VIVH0?Cdm03Ti>@1HF5P07alO
02/[:`1PH600FUYJ04=3@`0l?3`0FEUI028R8P0e=CD0G5aL06ATI02HV9P0QhN703lo?`14A4@0BTY:
065QH@15ADD0=cLg05eMG@1XJ6P0MWIf03hn?P1MGEd0Lg=c07alO02i^KT0NWYj055AD@1>CTh0EEEE
08j>SP1DE5@07alO04U9B@1@D500?Cdm05iNGP0l?3`0FUYJ03/k>`1iNGT0GemO06MWI`15ADD0D51@
08J6QP1^KVh0VYZJ08B4Q02EUID0/[:b0:RXZ02EUID0EUIF04i>CP1@D500B4Q808R8R018B4P0HV9R
059BDP16ATH0Bd];06ATI017AdL0?3`l06ATI00l?3`0GEeM03hn?P0V9RH0A4A40080C4a<07<0A4A4
02TY:@10@400IFEU06=SH`0h>3P0?Shn05mOG`1CDe<0=SHf0492@P1MGEd0LW9b06e]K@1VIVH0E5AD
06MWI`1=CDd0Hf=S06EUI@18B4P0CTi>05EEE@1SHf<0ATI602PX:00];Bd0@D5103/k>`0/;2`0C4a<
03Lg=`0l?3`0BDU9059BDP0g=cL0AdM703dm?@16ATH0=3@d034a<@0o?cl0H61P04I6AP0Z:RX0?Cdm
05]KF`1ADE40<30`04e=C@1kNg/0HV9R05MGE`1BDU80FUYJ07EeM@1CDe<0IVIV04I6AP1WIfL0>3Ph
04i>CP20P800LG5a09VIV@1`L700QhN7059BDP1FEUH0K6a/04Y:BP1ADE40>c/k06YZJP1:BTX0OGem
08>3P`1]KFd0De=C08B4Q01kNg/0^;Rh0<G5a@1`L700MGEe0:>SX`1=CDd0/;2`04m?C`0o?cl0@d=3
05MGE`1MGEd0@T9203/k>`16ATH0;Bd]04E5A@1IFET0HF5Q051@D01<C4`0GUiN05QHF01EEED0=cLg
04a<C01PH6005ADE03lo?`16ATH06QXJ06a/K01kNg/0>SXj0080ATI605T0C4a<06MWI`11@D40EeMG
03Ph>01GEeL0E5AD03@d=00b<S80>3Ph02HV9P0/;2`0@41003De=@14A4@0<S8b05MGE`0W9bL092@T
028R8P1ZJVX0K6a/04=3@`1_Kfl0<S8b02HV9P1SHf<0ADE503`l?01EEED0:b/[07MgM`25QHD0@410
06][J`1_Kfl0=cLg04i>CP0/;2`0?Shn03dm?@1GEeL0GEeM05ADE01=CDd0De=C05YJFP0U9BD0IVIV
0820P01BDU80?3`l055AD@0m?Cd0BTY:02LW9`1BDU80>CTi03dm?@16ATH0@d=30492@P19BDT0CTi>
03Xj>P16ATH0C4a<05MGE`13@d<0BTY:03lo?`1IFET0Jf][03/k>`1;Bd/0CDe=07MgM`1VIVH0<C4a
03Ti>@1BDU80B4Q803Ti>@1UIFD0=cLg04i>CP1DE5@0Ph>303@d=00203Ph>00^01TI6@1GEeL0:BTY
0492@P1IFET0>c/k05UIF@0V9RH0@T9203dm?@1IFET0@T9206IVIP1DE5@0KVi^09VIV@0[:b/0GEeM
05EEE@14A4@0NGUi03De=@1KFe/0KVi^06MWI`2:RXX0D51@03Xj>P16ATH0?Cdm05MGE`0g=cL0ATI6
04A4A01aLG40C4a<05QHF01nOWh0EeMG08b<S01HF5P0Ph>305eMG@1KFe/0Rh^;09RHV0;ooooo0000
o`1LG5`0MgMg08J6QP2PX:00@d=3055AD@1UIFD0FEUI09^KV`1TI6@0<C4a061PH01XJ6P0HV9R07al
O01WIfL0<C4a04E5A@2ATI40D51@04a<C01:BTX0<c<c02h^;P2?Shl0Lg=c03@d=011@D40<30`03/k
>`1EEED0Jf][03@d=017AdL0IfMW051@D01>CTh0O7al02l_;`0H61P0=cLg069RHP1aLG40GEeM06e]
K@0G5aL06a/K03De=@1bLW80EEEE09VIV@1YJFT051@D03Ti>@1<C4`0E5AD06ATI026QXH08b<S02d]
;@1BDU80UIFE05mOG`1CDe<0UIFE02<S8`12@T80BTY:051@D00^;Rh0C4a<03<c<`0K6a/0?Shn05AD
E01VIVH0ATI604];B`0S8b<0?3`l07IfMP1EEED09bLW02TY:@17AdL0<C4a02@T901PH600Q8B402l_
;`0N7Qh0@D510492@P11@D40I6AT0451@@0H61P0820P034a<@1JFUX0EeMG09:BTP1BDU806a/K02/[
:`18B4P0E5AD06MWI`2EUID071`L014A4@1FEUH0GemO03Ph>01:BTX0Kfm_01@D500O7al0BTY:05QH
F00/;2`0C4a<04Y:BP0I6AT0:2PX05UIF@2<S8`0<c<c04e=C@1ADE406ATI0451@@1HF5P0MWIf02<S
8`0c<c<0@T92028R8P1?Cdl0Shn?04U9B@0D51@0Fe]K04Y:BP0/;2`0IVIV08f=S@0T92@09RHV055A
D@1TI6@0Bd];096AT@1WIfL04Q8B034a<@1HF5P0J6QX061PH023Ph<07alO03Ph>01RHV80De=C06i^
KP1OGel0;Bd]04a<C01RHV80Shn?0410@01BDU80IfMW02DU9@0m?Cd0FEUI07emO@0f=SH0F5QH04Q8
B00`<300@T9206IVIP1bLW8071`L04Q8B00k>c/0@D51061PH023Ph<0?Cdm028R8P1;Bd/0IVIV05MG
E`23Ph<0PH6101hN7P18B4P0D51@06MWI`1EEED0XZ:R05MGE`0P8200JFUY0:VYZ@1;Bd/0R8R80861
P@0/;2`0:BTY03lo?`1SHf<0BTY:07IfMP0V9RH09bLW05mOG`2HV9P0GemO06MWI`11@D40;bl_06UY
J@23Ph<0>c/k055AD@1EEED07alO065QH@27QhL0CDe=04I6AP1IFET09BDU03De=@25QHD0IFEU01lO
7`1=CDd0<S8b03Hf=P1mOGd0BDU901`L700`<300>3Ph04Y:BP1_Kfl0NWYj02LW9`0n?Sh0Bd];04m?
C`00o`1ZJVX0MWIf02l_;`0j>SX0B4Q805eMG@1LG5`0QHF509nOW`0k>c/0@41006QXJ02FUYH0=cLg
06MWI`2=SHd0=CDe03Ti>@1IFET0Shn?05UIF@21PH40VIVI02PX:00];Bd0BTY:08V9R@0`<300GemO
06EUI@0_;bl0B4Q807QhN01bLW80=SHf06QXJ014A4@0:b/[02XZ:P1aLG40O7al028R8P1VIVH0=CDe
024Q8@0m?Cd0GEeM03Ti>@0N7Qh0A4A405UIF@13@d<0GEeM07QhN016ATH07alO04A4A00j>SX0>3Ph
05UIF@2JVYX0>3Ph01dM7@13@d<0EeMG09NGU`1FEUH0A4A406m_K`1hN7P0L71`05QHF00n?Sh0LW9b
065QH@1dM7@0FEUI06m_K`26QXH0YJFU07UiN@16ATH0EUIF055AD@1LG5`0I6AT04E5A@0];Bd0DU9B
04e=C@1<C4`0GemO04];B`1RHV80ATI607UiN@1KFe/0IFEU05UIF@1:BTX0R8R805YJFP20P800SXj>
09:BTP2b/[80X:2P06a/K011@D40>c/k05YJFP1DE5@0N7Qh04E5A@1BDU80FEUI04];B`1>CTh0GemO
02HV9P13@d<0J6QX03Ti>@1YJFT0C4a<02TY:@1YJFT0E5AD04U9B@1aLG40<30`07alO014A4@0Cdm?
05IFEP14A4@0G5aL05IFEP17AdL0H61P04e=C@0a<C40G5aL04=3@`0n?Sh0EUIF04];B`1BDU80De=C
03De=@1NGUh0<S8b03<c<`1FEUH0>c/k03Ti>@0n?Sh0@d=302h^;P0e=CD0<S8b03Ph>019BDT0>3Ph
02XZ:P1:BTX092@T03Ph>01GEeL0>SXj04U9B@0j>SX0GemO03Ph>01ADE40AdM705QHF019BDT0FUYJ
03lo?`0k>c/0?Cdm05=CD`1dM7@0DE5A04E5A@1ADE40CDe=065QH@10@400Q8B409>CT`2[Zj/0WIfM
06e]K@1WIfL0AdM706a/K01HF5P0AdM704a<C015ADD0GEeM06QXJ020P800[:b/0;Bd]01mOGd0JVYZ
05iNGP2IVIT0V9RH04Q8B01fMWH0N7Qh059BDP1QHF40=cLg03<c<`1TI6@0CTi>07YjNP1<C4`0Bd];
051@D00o?cl0IVIV075aL@1YJFT0Kfm_0451@@1OGel0CDe=05ADE01BDU80D51@07EeM@0W9bL0MgMg
06ATI00D51@0Kfm_08>3P`0d=3@0IfMW04i>CP1ADE40FEUI0410@01dM7@09bLW03lo?`13@d<06a/K
05QHF0009`1WIfL06a/K03hn?P17AdL0>CTi05ADE00_;bl0ADE5038b<P0V9RH0>SXj03dm?@1;Bd/0
92@T03hn?P0Y:BT05aLG06IVIP0e=CD0DE5A05EEE@0M7Ad0Lg=c08f=S@0i>CT0>c/k04E5A@0B4Q80
;2`/01@D500o?cl05aLG03dm?@15ADD0@4100492@P2BTY80WIfM03hn?P020451@@1G02XZ:P1@D500
Ph>30410@01@D500@41005]KF`0n?Sh0CTi>05=CD`1=CDd0JFUY04m?C`1CDe<0CDe=05EEE@1NGUh0
M7Ad051@D01:BTX09RHV05QHF02?Shl0AdM704a<C00d=3@0Z:RX08:2PP0_;bl0@T9206ATI01WIfL0
HF5Q06IVIP1DE5@0MWIf0410@01eMGD0@D51038b<P0c<c<06a/K07AdM00_;bl0Fe]K05eMG@0/;2`0
FUYJ03hn?P1_Kfl0@41005YJFP1IFET0I6AT05ADE01NGUh0JFUY04U9B@1`L700EUIF03Xj>P2;Rh/0
>CTi05iNGP1fMWH0BTY:05=CD`19BDT0@410059BDP1DE5@0GemO03`l?01eMGD0K6a/0861P@1EEED0
H61P07]kN`1?Cdl0Jf][04U9B@1LG5`0JVYZ06UYJ@1LG5`0F5QH00;ooooo0000D@1oOgl0FUYJ06UY
J@30`<00J6QX05ADE01BDU80A4A409ZJVP2KVi/0@41005EEE@1<C4`0GEeM06QXJ025QHD0;Rh^030`
<016ATH0J6QX075aL@2d];@0<S8b03Lg=`0l?3`0IfMW06UYJ@23Ph<0<S8b03Ph>01QHF40GemO05eM
G@2KVi/0P82001`L700Y:BT0?3`l05ADE01XJ6P0[Zj^05ADE00a<C40B4Q807QhN01@D500?Shn08:2
PP0b<S809bLW05MGE`21PH40=CDe03`l?00];Bd06a/K0451@@1DE5@0?clo05mOG`1bLW80@d=303dm
?@1=CDd0NGUi05MGE`0R8R80ATI603`l?01?Cdl0L71`05mOG`0G5aL0=CDe04E5A@1GEeL0EEEE0:6Q
X@0i>CT05ADE03<c<`02055AD@2K07UiN@2o_kl0<C4a03@d=00W9bL0DE5A06MWI`1DE5@0Rh^;020P
800X:2P0ATI606a/K01@D500E5AD07UiN@0L71`0@D5105eMG@1fMWH0?Shn05IFEP1jNWX051@D0410
@01^KVh0FUYJ01lO7`0m?Cd0=SHf01hN7P1IFET0N7Qh02l_;`0[:b/0=SHf02l_;`0g=cL0Kfm_07Yj
NP0G5aL04Q8B038b<P1`L700Cdm?08b<S02DU9@09RHV03hn?P1:BTX0D51@04=3@`1oOgl0K6a/02LW
9`15ADD0ATI607=cL`0l?3`0G5aL03Ph>00O7al0EEEE07EeM@15ADD0:2PX06ATI00Z:RX0A4A404m?
C`1]KFd0>CTi05YJFP24Q8@05ADE04A4A01bLW809bLW0492@P1>CTh08b<S06QXJ02DU9@0;Bd]03<c
<`19BDT0ATI603hn?P27QhL0ZJVY0410@00X:2P0AdM706=SH`17AdL0XZ:R0:>SX`0Y:BT0:b/[05eM
G@2;Rh/0FEUI0:j^[P21PH408R8R04=3@`1cLg<0LG5a06][J`2JVYX0CTi>028R8P1:BTX0SXj>0410
@012@T80?3`l024Q8@0h>3P0JVYZ07inOP0_;bl0@D5103@d=00];Bd0CTi>07QhN00n?Sh0<C4a061P
H00m?Cd0>3Ph075aL@1?Cdl0=CDe059BDP0i>CT0K6a/09NGU`1IFET09BDU05EEE@1;Bd/0@D5109RH
V01kNg/07alO03Ti>@1`L700Cdm?04i>CP2<S8`0=SHf02h^;P18B4P00P1EEED0702JVYX0@D510451
@@1]KFd0MWIf04A4A01[Jf/0;Rh^02XZ:P1EEED0Q8B4065QH@1jNWX0Lg=c02LW9`1>CTh0Cdm?03hn
?P1HF5P0Rh^;05YJFP0U9BD0E5AD05]KF`1HF5P0>CTi071`L01CDe<203Lg=`0406][J`1EEED0:RXZ
08:2PP80@41004d0C4a<08>3P`14A4@092@T04U9B@15ADD0@d=30861P@1lO7`0:2PX03lo?`1?Cdl0
EeMG04a<C02/[:`0QhN7030`<00i>CT0@d=3059BDP1:BTX0U9BD09FEU@0M7Ad08R8R05YJFP2=SHd0
De=C071`L028R8P0820P03Ph>01BDU80E5AD04=3@`1eMGD0?Shn01dM7@0S8b<0FUYJ06IVIP1?Cdl0
NWYj0861P@2UYJD0GemO04=3@`18B4P0@41006QXJ01QHF40ADE507]kN`1cLg<0EEEE03@d=016ATH0
HF5Q07QhN02EUID0FUYJ07IfMP1ADE40C4a<09nOW`1?Cdl0:b/[03De=@0n?Sh0@T92065QH@1DE5@0
CTi>04I6AP1@D500C4a<06][J`0205EEE@0A07AdM024Q8@0FUYJ065QH@1_Kfl0IfMW07alO01ZJVX0
C4a<03dm?@12@T80@D5105ADE01FEUH0De=C04Q8B00i>CT00P1>CTh0B00U9BD0>CTi04e=C@0h>3P0
HV9R059BDP10@400HV9R04a<C017AdL0MGEe03dm?@1oOgl0B4Q8051@D01NGUh0E5AD05]KF`1RHV80
G5aL07IfMP1MGEd0Bd];07alO01EEED0BTY:08:2PP0o?cl0GUiN07EeM@1JFUX0Hf=S03lo?`0m?Cd0
D51@04E5A@0V9RH0=SHf05=CD`17AdL0ADE504=3@`0b<S80H61P04a<C011@D40D51@03Lg=`1:BTX0
I6AT03lo?`19BDT0A4A4065QH@1@D500EUIF04m?C`1WIfL0Hf=S06][J`1LG5`0E5AD04=3@`1GEeL0
Cdm?05ADE01ADE40Bd];06EUI@1FEUH0?clo05ADE080FEUI03@0Jf][06m_K`1cLg<0DE5A04=3@`1@
D500?3`l04E5A@0l?3`0@410051@D01NGUh0ZJVY09RHV01DE5@0Y:BT065QH@2?Shl0];Bd06ATI02/
[:`0YJFU05QHF01lO7`0D51@05MGE`1WIfL0PX:206ATI00m?Cd0A4A404e=C@0V9RH0>SXj071`L02<
S8`0FUYJ055AD@1;Bd/0AdM70492@P1JFUX0M7Ad06IVIP0P8200EUIF07emO@0O7al0FEUI07EeM@0c
<c<0?clo0P14A4@0R01_Kfl0?Cdm07moO`0U9BD0>c/k0410@00B4Q808b<S03Xj>P0L71`0?Shn04E5
A@1<C4`0Hf=S01`L7018B4P0<30`03`l?00k>c/0IfMW061PH00T92@0AdM704I6AP0V9RH0>c/k04I6
AP0k>c/0ADE503De=@13@d<0Jf][03Hf=P1>CTh0E5AD02d];@16ATH0<30`06IVIP0R8R80DE5A05YJ
FP14A4@0;Rh^04a<C01ADE407QhN04I6AP17AdL09BDU03De=@10@400D51@09:BTP1HF5P0DU9B05]K
F`1BDU80D51@04=3@`18B4P0A4A404e=C@0g=cL0?Shn069RHP1kNg/0HF5Q09VIV@1WIfL0C4a<06EU
I@0n?Sh0Cdm?03/k>`1UIFD0L71`051@D01eMGD0E5AD04I6AP0l?3`0Fe]K04M7A`1;Bd/0DE5A08j>
SP12@T80;2`/03Ti>@10@400IfMW04M7A`1UIFD0FUYJ03`l?01LG5`0?Cdm03Xj>P16ATH0F5QH05mO
G`27QhL0EUIF06m_K`2>SXh0Bd];06QXJ01HF5P0GEeM08:2PP1<C4`0GemO06i^KP1:BTX0Fe]K06IV
IP1/K6`0IFEU05MGE`1ADE40=CDe055AD@1XJ6P0IFEU04m?C`1IFET0Hf=S05IFEP1KFe/0EEEE06IV
IP18B4P0BDU905]KF`1YJFT2ooooo`0001H0WYjN06QXJ01BDU80IFEU08J6QP2k^k/0LW9b0451@@1G
EeL0Y:BT092@T02n_[h0>c/k04Q8B01NGUh0UIFE09>CT`2OWil0MGEe03@d=01;Bd/0EeMG0P18B4P0
?01gMgL0:RXZ03`l?01JFUX0Lg=c04M7A`1nOWh0>CTi02LW9`1?Cdl0LG5a04a<C00`<300ATI601DE
5@0b<S80EeMG06ATI00V9RH0<c<c04i>CP0`<300GEeM0861P@17AdL07alO04A4A01?Cdl0<S8b07mo
O`1>CTh08B4Q02TY:@1<C4`0<c<c04E5A@2BTY80RHV902PX:010@400K6a/06m_K`1>CTh0OWin02TY
:@0X:2P0HF5Q09fMW@1DE5@0D51@05iNGP0X:2P0>3Ph05iNGP1cLg<0<C4a04E5A@0g=cL071`L02HV
9P80FEUI0?l08b<S055AD@16ATH0;Rh^03`l?01cLg<0CDe=018B4P0n?Sh0BTY:034a<@1HF5P0QhN7
01TI6@0W9bL0Cdm?03Xj>P0`<300OGem0:NWY`0O7al0<C4a04I6AP1ADE40?Shn07EeM@1;Bd/06a/K
0451@@19BDT0>3Ph05iNGP1SHf<05QHF03Hf=P0h>3P0EEEE03`l?00d=3@0I6AT02DU9@0G5aL0DE5A
05ADE00n?Sh0;Rh^06UYJ@0h>3P05ADE05]KF`2/[:`0@T9202XZ:P1ADE407AdM02d];@1lO7`0WIfM
02HV9P0^;Rh0DE5A04E5A@1DE5@0UYJF02<S8`0W9bL0BTY:07]kN`1KFe/0IfMW09nOW`0[:b/08B4Q
0410@00_;bl0FUYJ04I6AP0f=SH0=cLg06e]K@1MGEd0FEUI08B4Q00T92@0<S8b03Hf=P1TI6@0Kfm_
059BDP2][Jd0<c<c04Q8B014A4@0J6QX06ATI00j>SX0FEUI03De=@0f=SH0FEUI07UiN@0_;bl0=cLg
04m?C`0Z:RX0=SHf07QhN01KFe/08R8R03@d=01SHf<0CTi>09:BTP1nOWh09BDU030`<01CDe<0E5AD
05mOG`2m_Kd0HF5Q01hN7P0i>CT0I6AT05ADE01PH600Xj>S04E5A@0i>CT0De=C05QHF01OGel0Ogmo
034a<@0/;2`0Lg=c06YZJP0f=SH0VYZJ06UYJ@0G5aL0A4A409nOW`1LG5`0?3`l04A4A00U9BD0>c/k
051@D01KFe/0CDe=05eMG@0];Bd0=cLg08J6QP1gMgL0>CTi04I6AP0T92@0De=C0820P01JFUX0;Rh^
06=SH`0h>3P0<S8b09BDU02[Zj/0<30`03Ph>01=CDd0=3@d06ATI039bLT0ZZZZ02@T900o?cl0BDU9
04e=C@1NGUh0_Kfm09NGU`0W9bL0A4A404e=C@1TI6@0BTY:0:>SX`2<S8`0;bl_05QHF01>CTh0F5QH
04=3@`28R8P0EUIF04E5A@1EEED0IfMW05ADE01OGel0GUiN01lO7`13@d<0F5QH07UiN@1=CDd0E5AD
09^KV`0_;bl0;Rh^05]KF`1cLg<0ADE505QHF01bLW80<C4a03/k>`1EEED0OWin04e=C@0h>3P0Cdm?
02l_;`1LG5`0J6QX079bLP0Z:RX0@410030`<018B4P0Bd];08N7Q`1;Bd/0HF5Q071`L01EEED0G5aL
06UYJ@1VIVH0E5AD0451@@1aLG40IVIV075aL@0l?3`0FEUI0820P01`L700]kNg069RHP1MGEd0EUIF
04Q8B021PH4002T0GEeM02TY:@10@400G5aL06UYJ@1^KVh0@T9205]KF`14A4@0OWin04Y:BP1FEUH0
EEEE04I6AP1dM7@0LG5a09BDU02:RXX0Z:RX09NGU`2HV9P0R8R805MGE`17AdL0E5AD04U9B@21PH40
@D5104M7A`1<C4`0A4A404];B`1@D500=CDe03dm?@1MGEd0@41007=cL`1CDe<09BDU051@D002059B
DP0Z05eMG@16ATH0F5QH05UIF@1FEUH0B4Q804];B`1?Cdl0DU9B04=3@`1BDU80Cdm?04Q8B01LG5`0
EEEE051@D01VIVH0BDU905UIF@1KFe/0<c<c055AD@14A4@0?3`l04I6AP0g=cL09bLW0451@@14A4@0
=SHf04I6AP0f=SH0=CDe04];B`0m?Cd0<C4a04I6AP0c<c<0ADE504U9B@0h>3P0@D510P1>CTh0>`0]
;Bd0@D5105aLG01CDe<0Bd];055AD@1QHF40EEEE05UIF@1[Jf/0FUYJ06MWI`1CDe<0GemO04m?C`1Z
JVX0>SXj05mOG`2IVIT0TY:B09JFUP1gMgL0NWYj06a/K01?Cdl0IfMW03dm?@1KFe/0@T9206IVIP1@
D500IVIV08V9R@27QhL0?Cdm04a<C01JFUX0e=CD0<K6aP1FEUH0H61P06EUI@1KFe/0WYjN03Hf=P0k
>c/0BTY:04e=C@1QHF40=3@d03/k>`16ATH092@T03hn?P1WIfL0KFe]05QHF00e=CD0CTi>0080MGEe
03l0BDU903@d=01EEED0:BTY04I6AP1ADE406a/K05YJFP1mOGd0=CDe051@D019BDT0E5AD07emO@0j
>SX0Ph>30492@P1;Bd/0DE5A02<S8`0i>CT0D51@02l_;`16ATH0@d=303Xj>P1ADE406QXJ03dm?@0S
8b<0<30`028R8P1JFUX0EeMG04];B`2XZ:P0Bd];02@T900f=SH0ADE50820P01oOgl0?clo05UIF@1Z
JVX0FEUI08B4Q01`L700:2PX03Ti>@0M7Ad0>3Ph02LW9`1<C4`0EeMG051@D010@400GEeM075aL@0o
?cl0E5AD06UYJ@1GEeL00P0`<300E00S8b<0DU9B01hN7P1<C4`0BDU904I6AP1QHF40Bd];04e=C@1@
D500GUiN04i>CP1KFe/0IFEU07emO@1ADE40FUYJ02d];@1JFUX0LW9b05=CD`2SXj<0EeMG06i^KP1Q
HF40;Rh^03De=@1ZJVX0GUiN04Q8B01ADE40;bl_06=SH`1<C4`0Ph>304Y:BP1VIVH0?Cdm03hn?P1`
L700BDU909NGU`2MWId0ADE506QXJ01NGUh0BDU903`l?01TI6@0CTi>05eMG@11@D40JVYZ09BDU029
RHT0QhN7075aL@1[Jf/0QXJ606IVIP2NWYh0[Zj^05UIF@1OGel0<S8b03@d=016ATH0@D51059BDP0a
<C40FUYJ05IFEP1eMGD0Jf][05EEE@1^KVh0E5AD0::RXP1@D500EUIF06YZJP1dM7@0IFEU07YjNP;o
oooo0000o`20P800JFUY06IVIP2;Rh/0@T9207MgM`2EUID0A4A408V9R@17AdL0IFEU07alO01CDe<0
@T9205=CD`12@T80;Rh^08:2PP2?Shl0:BTY0451@@18B4P0>3Ph07]kN`2VYZH0<30`02LW9`0e=CD0
EUIF05UIF@2CTi<0DE5A020P800h>3P0Q8B4069RHP2?Shl0Ogmo01DE5@0C4a<0B4Q808N7Q`1CDe<0
HV9R08^;R`0T92@0:BTY04E5A@19BDT0<C4a06YZJP0^;Rh0<30`0410@014A4@06QXJ02h^;P12@T80
6QXJ03dm?@1YJFT0QhN705]KF`0j>SX0DE5A020P800R8R80D51@04e=C@0^;Rh0?3`l03De=@11@D40
ATI607MgM`0V9RH08R8R03De=@18B4P0=cLg07IfMP1UIFD07QhN01/K6`17AdL0IfMW04E5A@2FUYH0
Vi^K01TI6@0^;Rh0CTi>05=CD`1HF5P0QhN704A4A00C4a<0;Rh^065QH@20P800Bd];09^KV`0n?Sh0
8B4Q03Ti>@1mOGd0GUiN03dm?@1aLG40820P03Hf=P0j>SX0FEUI034a<@0j>SX0BTY:01hN7P14A4@0
Q8B405=CD`0I6AT0ATI604M7A`1=CDd0FEUI09>CT`13@d<04a<C0451@@0j>SX0ADE506UYJ@2>SXh0
BTY:024Q8@0g=cL0Jf][05aLG01UIFD0U9BD02<S8`0P8200@41006i^KP0h>3P0Hf=S065QH@0@4100
A4A4071`L02MWId0@T9205iNGP0^;Rh0>SXj05IFEP1eMGD0CDe=03Hf=P14A4@07AdM08J6QP22PX80
8B4Q03Lg=`12@T80:RXZ03Xj>P2[Zj/0MgMg01hN7P0h>3P0Hf=S0451@@0f=SH0YjNW08F5Q@0X:2P0
Bd];03<c<`1=CDd0RHV90;^k^`11@D40:BTY04a<C01[Jf/0C4a<07YjNP22PX80:BTY02XZ:P1WIfL0
OWin04a<C01gMgL0Ng]k01PH601DE5@0XZ:R04Y:BP1QHF40]KFe03hn?P0O7al0KFe]0:NWY`0g=cL0
GemO04M7A`11@D40?Cdm061PH016ATH0>SXj065QH@0T92@0IVIV0<30`01ZJVX0<C4a05mOG`0n?Sh0
>CTi0:6QX@2SXj<0=cLg03Ti>@14A4@0BDU906m_K`1hN7P08b<S02`/;010@400B4Q807alO02a/K40
:BTY02`/;01WIfL0H61P055AD@2LW9`0<c<c02@T901MGEd0IVIV05]KF`2c/k<0HF5Q01lO7`0h>3P0
MGEe08N7Q`00>`1dM7@0I6AT02DU9@12@T80GUiN06=SH`1<C4`0N7Qh07UiN@0U9BD0?Shn05mOG`2>
SXh0@41004I6AP1]KFd07alO034a<@15ADD0EUIF03Ph>01<C4`0J6QX024Q8@0h>3P0VIVI07]kN`0U
9BD0Bd];03hn?P0m?Cd0M7Ad0:^[Z`1/K6`0:2PX051@D01>CTh0?clo075aL@2a/K40A4A402TY:@18
B4P0HV9R04A4A01QHF40[Zj^03Ph>00[:b/0=cLg07inOP1IFET0GemO07inOP0Q8B407AdM03Ph>01_
Kfl0AdM70080Ng]k01406a/K01hN7P1;Bd/0L71`0:>SX`1MGEd0?3`l05eMG@1GEeL0Kfm_05]KF`0^
;Rh0NWYj07alO01gMgL0@41006YZJP0207YjNP0808:2PP1UIFD0FUYJ05]KF`1DE5@0M7Ad04U9B@0T
92@20410@00H04A4A01HF5P0Cdm?071`L01JFUX0OGem04Q8B01ADE40FUYJ04a<C01cLg<0Ph>308B4
Q02VYZH0QHF509ZJVP2NWYh0JVYZ059BDP14A4@0G5aL05EEE@1SHf<0C4a<0P1?Cdl0EP0o?cl0BDU9
05ADE00d=3@0DE5A05YJFP0k>c/0GUiN05QHF00U9BD0GEeM055AD@10@400MWIf0410@027QhL0@410
03Ph>01FEUH0Bd];04Y:BP1EEED0@T92061PH01KFe/0?Shn06m_K`18B4P0?clo075aL@1EEED0EeMG
065QH@0n?Sh0EUIF03hn?P0j>SX0FUYJ03lo?`0N7Qh0>CTi04U9B@16ATH0=3@d03`l?018B4P0Fe]K
0410@00/;2`0GUiN03Ph>00l?3`0Cdm?059BDP1;Bd/0>CTi05=CD`1HF5P0G5aL03dm?@1ADE40D51@
05eMG@16ATH0AdM70451@@1BDU80GUiN05QHF01@D500HV9R04I6AP1HF5P0@41007=cL`2EUID0/K6a
09:BTP1FEUH0K6a/065QH@1BDU80EeMG03hn?P1@D500EEEE0P14A4@0N01NGUh0WIfM0:RXZ01VIVH0
Kfm_07IfMP1nOWh0K6a/04=3@`1kNg/0N7Qh03Lg=`1XJ6P0;bl_03dm?@1^KVh0B4Q805mOG`0g=cL0
C4a<04i>CP0b<S80BDU907IfMP1mOGd0LG5a030`<01<C4`0>SXj04A4A01@D500BTY:06m_K`0X:2P0
UiNG079bLP0I6AT0@d=306][J`0_;bl0K6a/051@D017AdL0C4a<03Xj>P1mOGd0:b/[03lo?`0k>c/0
5QHF04=3@`1KFe/0;bl_03dm?@15ADD0IfMW07UiN@0i>CT0EEEE03Hf=P0j>SX0;bl_05ADE01;Bd/0
9BDU04U9B@0/;2`02@T9030`<00_;bl0>3Ph04Q8B00<30`0De=C05aLG00N7Qh0GUiN05IFEP0S8b<0
@D5101@D501?Cdl06ATI04i>CP1;Bd/0ADE504a<C01CDe<0FUYJ03<c<`1PH600Fe]K01`L700S8b<0
ADE502d];@1MGEd0=SHf06=SH`1JFUX0D51@04];B`1GEeL0KVi^0492@P1DE5@0Fe]K051@D01CDe<0
P8200492@P1fMWH0?Shn04I6AP1TI6@0=CDe04Y:BP0^;Rh0JFUY05YJFP80@41003T0E5AD03`l?019
BDT0C4a<03Ti>@1gMgL0Cdm?075aL@0l?3`0@41004];B`0X:2P0J6QX03Lg=`14A4@0B4Q8051@D01c
Lg<0Fe]K07=cL`1DE5@0F5QH03Lg=`1UIFD0=CDe04m?C`1[Jf/07alO04e=C@1CDe<0J6QX07MgM`1K
Fe/0BDU904Y:BP1LG5`0NGUi0451@@12@T80BTY:04=3@`1[Jf/0@T9208:2PP1MGEd0EEEE03hn?P10
@400GemO03@d=01CDe<0>c/k06ATI01WIfL0LG5a06a/K02PX:000_ooool0000F06QXJ020P800Shn?
0<K6aP12@T80@d=3075aL@1bLW80`/;204Y:BP19BDT0G5aL05QHF01]KFd0XJ6Q04Y:BP0g=cL0>3Ph
06QXJ01HF5P0Zj^[0820P080<S8b07<0DE5A06UYJ@1>CTh0IVIV01TI6@0`<300@T9204];B`0a<C40
DU9B07UiN@0U9BD0?Cdm05QHF012@T80;bl_05YJFP0h>3P0<C4a05iNGP28R8P0;2`/034a<@19BDT0
<c<c03/k>`2FUYH0KVi^01LG5`0o?cl0HV9R0492@P0j>SX0E5AD01PH600B4Q80>c/k0::RXP2MWId0
G5aL096AT@0n?Sh09BDU04A4A01:BTX0IVIV09fMW@1HF5P061PH02h^;P1EEED0J6QX0410@01hN7P0
71`L01/K6`0V9RH0JVYZ04I6AP0m?Cd0R8R802`/;00K6a/0?clo05eMG@1<C4`0@d=3061PH00D51@0
7alO02`/;01UIFD08B4Q04U9B@0m?Cd04A4A04A4A026QXH0@D5101DE5@0Y:BT0=cLg038b<P24Q8@0
[jn_02/[:`0E5AD09BDU05=CD`0n?Sh0SHf=06MWI`0J6QX07AdM03/k>`1HF5P0A4A408n?S`17AdL0
7AdM03dm?@1?Cdl0GemO034a<@1GEeL0L71`01TI6@11@D40IVIV04m?C`0S8b<0B4Q804U9B@0W9bL0
Cdm?0080CTi>09h09bLW07EeM@0d=3@0=SHf06e]K@2@T900:BTY01/K6`0o?cl0FEUI05ADE02_[jl0
@d=302LW9`11@D40GUiN065QH@1NGUh0Jf][02`/;00i>CT0MgMg04Y:BP24Q8@0Ph>302DU9@0n?Sh0
@41008^;R`1>CTh0Hf=S08B4Q00S8b<09bLW03lo?`1WIfL0@d=306YZJP1:BTX08b<S02l_;`1^KVh0
VIVI03Hf=P16ATH0=3@d02DU9@0n?Sh0OWin04e=C@0l?3`0D51@02`/;01>CTh0I6AT08n?S`0T92@0
;2`/04A4A00b<S80HV9R0<K6aP1?Cdl0:RXZ02l_;`1>CTh0;Rh^07IfMP1]KFd08b<S04];B`1hN7P0
D51@05UIF@2=SHd092@T02HV9P1=CDd0Shn?04M7A`2_[jl0B4Q8030`<01HF5P0M7Ad03lo?`1NGUh0
BDU902LW9`1YJFT0Q8B404=3@`1IFET0EeMG01dM7@11@D40VYZJ069RHP15ADD0De=C02/[:`0^;Rh0
MgMg07UiN@0b<S80LG5a02LW9`0l?3`0V9RH092@T00b<S80Kfm_03`l?00b<S80VIVI0:FUY@15ADD0
>CTi05MGE`0k>c/0?Shn06i^KP2LW9`0CTi>02PX:014A4@0BDU9061PH01bLW80Y:BT04a<C00[:b/0
EeMG04Q8B01XJ6P0X:2P07MgM`0S8b<0>c/k06UYJ@1oOgl0K6a/0;6a/@18B4P0;2`/04A4A01ZJVX0
PH6104];B`2>SXh0D51@02PX:014A4@0FEUI08^;R`11@D40MgMg02h^;P80;bl_0400NWYj09^KV`0]
;Bd0De=C04M7A`0X:2P0<S8b06MWI`1ADE40@D5104I6AP0U9BD0=cLg05EEE@1fMWH0>CTi02`/;00g
=cL0EUIF08:2PP1IFET0;bl_04A4A01;Bd/0NWYj05eMG@1=CDd0PX:207moO`1]KFd0FEUI06UYJ@1b
LW80WinO07YjNP1<C4`0BTY:04E5A@1ADE40Cdm?04A4A00_;bl0=SHf03Xj>P1ADE40L71`05]KF`1H
F5P0>CTi05EEE@19BDT0FUYJ04a<C012@T80CTi>08V9R@1BDU80JVYZ05]KF`1EEED0KVi^05QHF01D
E5@0Bd];0P15ADD0G@1[Jf/0IFEU06IVIP1;Bd/0?3`l06=SH`1PH600=cLg028R8P0f=SH0ADE507=c
L`1LG5`0@D5105eMG@1KFe/0BDU908F5Q@16ATH0TY:B04U9B@12@T80GemO04Y:BP1<C4`0EEEE04I6
AP1MGEd0G5aL0451@@1hN7P0H61P04I6AP1hN7P0>SXj05EEE@1cLg<0DE5A05MGE`1RHV80LW9b05MG
E`19BDT092@T03Hf=P0o?cl0?Cdm03<c<`0_;bl06QXJ03hn?P0m?Cd0>CTi04A4A00/;2`0@D5105MG
E`0d=3@0C4a<03/k>`1GEeL0<S8b0451@@18B4P0EUIF06a/K01LG5`0AdM705ADE01<C4`0F5QH0492
@P1CDe<0BDU904m?C`1SHf<0K6a/03dm?@1YJFT0RXZ:05aLG01jNWX0BDU905aLG01gMgL0?Cdm05=C
D`0l?3`0DU9B0451@@1QHF40EEEE07YjNP0207AdM00304i>CP1`L700OGem0080aLG50380B4Q808N7
Q`23Ph<0@d=308>3P`0f=SH0EeMG079bLP19BDT0G5aL04a<C01BDU80Cdm?03hn?P1EEED0Ogmo07in
OP1^KVh0ADE5059BDP18B4P0GEeM04Y:BP1?Cdl0GemO02l_;`0];Bd0BTY:01XJ6P1LG5`0Fe]K02l_
;`1:BTX0EeMG04i>CP23Ph<0@T9206UYJ@0X:2P0=CDe03Hf=P0<30`0;bl_04M7A`0O7al0?Cdm03lo
?`0e=CD0Cdm?01HF5P80=3@d07L0EeMG03`l?01TI6@0B4Q8030`<01;Bd/0@d=301@D500f=SH0=CDe
04I6AP15ADD04A4A07=cL`1`L700B4Q80;6a/@23Ph<0;Bd]04M7A`0i>CT0IfMW03Hf=P1LG5`0GUiN
079bLP1CDe<0JVYZ06UYJ@0A4A40Cdm?05IFEP0Q8B40?Cdm04e=C@1<C4`0N7Qh0492@P1@D500FUYJ
055AD@1=CDd0>CTi04Q8B012@T80D51@03lo?`1CDe<0GEeM07moO`1>CTh0YjNW02`/;01`L700QhN7
03Ti>@1IFET0A4A409JFUP22PX80GUiN051@D01FEUH0Bd];03Ti>@1>CTh0;2`/05MGE`19BDT0Jf][
03@d=00i>CT0@D51051@D01jNWX0E5AD05aLG01@D500=3@d05QHF014A4@0AdM703Lg=`1jNWX0=cLg
071`L00a<C40@41004A4A00Q8B40JFUY03`l?01XJ6P0U9BD03dm?@1OGel0C4a<03Xj>P1IFET0ADE5
075aL@1XJ6P0AdM704i>CP0n?Sh0CDe=06QXJ01hN7P0FUYJ05EEE@1XJ6P0@d=305MGE`0d=3@0CDe=
04a<C01NGUh0EUIF05YJFP02ooooo`0005P0WIfM04i>CP1@D500JVYZ06EUI@1`L700BDU90410@02;
Rh/0MGEe03<c<`1?Cdl0?Cdm04a<C02DU9@0ZJVY03Hf=P1?Cdl0@D5102`/;01ZJVX0V9RH02d];@0l
?3`0A4A405]KF`1/K6`0OGem03/k>`0_;bl0DU9B04Q8B013@d<0UiNG0<30`01;Bd/0;2`/051@D01b
LW80KVi^0:VYZ@1KFe/0410@03Hf=P1IFET0C4a<08f=S@2[Zj/0<30`02LW9`1BDU80KVi^04M7A`1b
LW80BTY:02HV9P0j>SX0FEUI02TY:@0k>c/0@d=308R8R02>SXh0?Shn04M7A`1iNGT0BTY:06YZJP0R
8R806a/K04M7A`1`L7009BDU02`/;01BDU80AdM7055AD@1nOWh0@T9201TI6@0k>c/0A4A404I6AP1a
LG40QhN702d];@0H61P0@D510P1@D5003P1eMGD0X:2P01hN7P0R8R80;2`/06a/K014A4@0QhN707in
OP0I6AT09bLW03Lg=`1FEUH09bLW0P1?Cdl0>00;2`/0;Rh^06YZJP1IFET0C4a<04M7A`0M7Ad06a/K
03dm?@1nOWh0AdM702d];@0/;2`06a/K02d];@1:BTX0LG5a030`<00^;Rh0H61P04a<C015ADD0Hf=S
0:6QX@0^;Rh07AdM059BDP1NGUh0?3`l0820P01cLg<0:2PX02/[:`1?Cdl0=3@d05iNGP2j^[X0VIVI
01lO7`1;Bd/0QHF506YZJP1GEeL0QhN702@T900L71`0EEEE08J6QP13@d<0QXJ607UiN@0Y:BT0@T92
04U9B@0X:2P0BDU90P0e=CD0W`1ADE40GemO03`l?00T92@0De=C02<S8`0a<C40DE5A09jNWP1>CTh0
;2`/04M7A`0j>SX0G5aL07moO`1HF5P07alO02PX:00g=cL0Jf][05EEE@2GUiL0Lg=c02<S8`1<C4`0
DE5A04M7A`1_Kfl0^[Zj02PX:00`<300EeMG07moO`1PH600P82007AdM00/;2`0ATI605iNGP2YZJT0
FEUI08Z:RP0i>CT0;Rh^05QHF02>SXh0@d=305EEE@1YJFT0<c<c04i>CP1mOGd0PH6103De=@1HF5P0
<S8b03Ti>@1cLg<0P82002TY:@1;Bd/0E5AD0451@@1gMgL0SXj>03@d=00k>c/0BTY:03/k>`1QHF40
OGem02d];@0S8b<0C4a<06ATI01YJFT0T92@03@d=00K6a/0?3`l04];B`1ADE40^k^k03Ph>00J6QX0
9RHV05iNGP0m?Cd0Xj>S06a/K00E5AD0:BTY07AdM01JFUX0IfMW0;bl_01;Bd/0B4Q804E5A@1GEeL0
?clo05MGE`23Ph<0De=C02DU9@1NGUh0I6AT05iNGP1<C4`0QhN703hn?P0W9bL0FUYJ06EUI@0c<c<0
;bl_06MWI`1;Bd/0>3Ph06IVIP24Q8@0>CTi04m?C`1IFET0>CTi04=3@`1iNGT0SXj>038b<P0_;bl0
@D5104U9B@1>CTh0UIFE05aLG00N7Qh0=SHf03Lg=`1/K6`0BTY:0861P@1jNWX0;bl_03lo?`11@D40
A4A406][J`24Q8@0820P02d];@1GEeL0FUYJ051@D012@T80EeMG05eMG@2/[:`0LG5a03Hf=P0204=3
@`1L06m_K`1[Jf/0ADE507alO021PH40Fe]K038b<P11@D40?clo04A4A02>SXh0KVi^05UIF@1BDU80
AdM7096AT@1?Cdl0<C4a03dm?@1=CDd0@D5105=CD`0c<c<0C4a<0492@P1FEUH0@d=305IFEP16ATH0
>SXj0410@01<C4`0K6a/07moO`1lO7`0TI6A0:FUY@1_Kfl0D51@0492@P17AdL0@41005MGE`10@400
@d=3034a<@0_;bl0>CTi03De=@0U9BD0=3@d04Q8B00_;bl0<C4a03<c<`0Q8B40>c/k059BDP1/K6`0
FEUI0410@01;Bd/0NGUi065QH@19BDT0@d=305EEE@1>CTh0Cdm?05iNGP1TI6@0H61P07YjNP1nOWh0
HF5Q06YZJP14A4@0DE5A04];B`0c<c<0=cLg03De=@0W9bL0AdM7038b<P0V9RH0ATI604e=C@0f=SH0
?3`l03Xj>P0a<C4205QHF00A038b<P1BDU80?3`l05MGE`1MGEd0?clo059BDP1ADE40H61P03Ph>01?
Cdl0EUIF05UIF@1:BTX0De=C04M7A`1<C4`00P1?Cdl02P1>CTh0Fe]K04a<C01DE5@0C4a<05ADE015
ADD0JVYZ0:2PX02:RXX207EeM@0?04M7A`1aLG40Cdm?05eMG@1ADE40G5aL0492@P1ZJVX0Fe]K06m_
K`1gMgL0RHV906][J`1VIVH0Shn?0080Z:RX0:/0Fe]K08B4Q020P800ADE507emO@16ATH0@d=305QH
F017AdL0F5QH03`l?011@D40@T9203hn?P25QHD0Kfm_06MWI`1GEeL0<C4a05eMG@1=CDd0GEeM05AD
E01SHf<0Ng]k01TI6@0O7al0AdM702XZ:P1KFe/0IfMW03@d=01:BTX0EEEE04Q8B01nOWh0:b/[07]k
N`16ATH0>c/k04U9B@0];Bd0=SHf04];B`0b<S80>c/k04];B`15ADD0IFEU014A4@0j>SX0:b/[02h^
;P0W9bL0Fe]K05QHF01JFUX0Rh^;0451@@0O7al0@T9203dm?@26QXH0IVIV02@T9019BDT0Cdm?02@T
901PH600EeMG02DU9@17AdL071`L04];B`0H61P0CDe=04I6AP1;Bd/0GUiN07emO@25QHD0?clo08j>
SP2DU9@0ADE503Hf=P0h>3P0@d=305]KF`0W9bL0>CTi04e=C@10@400FEUI03Xj>P1EEED0A4A4059B
DP1@D500Bd];065QH@26QXH0B4Q806QXJ00[:b/0FEUI05mOG`1?Cdl0RHV903Ti>@1PH600EEEE04=3
@`17AdL0F5QH0492@P14A4@0Fe]K04e=C@1eMGD0BDU9079bLP1EEED0GEeM055AD@0b<S80BDU903Xj
>P1TI6@0Fe]K059BDP1bLW80DE5A05EEE@0i>CT0GemO03<c<`21PH40=cLg05iNGP1;Bd/0:BTY07Qh
N00i>CT0D51@07inOP0_;bl0S8b<06][J`1IFET0KVi^03hn?P10@400?clo03De=@1LG5`0@T92059B
DP0n?Sh0Lg=c05=CD`1HF5P0RXZ:06MWI`1`L700C4a<065QH@1^KVh0MGEe051@D01XJ6P00_ooool0
000<0;Fe]@1ZJVX0Bd];05eMG@1RHV80S8b<075aL@10@400G5aL06UYJ@2=SHd0Vi^K0P0a<C40l@1/
K6`0VYZJ06QXJ02][Jd0EUIF02`/;014A4@0O7al04e=C@1KFe/0KVi^02DU9@15ADD0QhN708V9R@1B
DU80RHV9038b<P0a<C40@41008N7Q`1aLG40KFe]05]KF`0F5QH0>c/k05MGE`23Ph<0CDe=05=CD`1=
CDd0:2PX04i>CP2HV9P0OWin03dm?@1BDU80D51@03Lg=`1]KFd0SHf=03Ti>@17AdL0E5AD03<c<`0T
92@0>SXj02/[:`1EEED0CDe=04Y:BP0m?Cd0Hf=S0;6a/@0l?3`07alO03<c<`24Q8@0DU9B06i^KP2[
Zj/08B4Q03Xj>P1WIfL0Hf=S05EEE@2WYjL0EUIF020P800b<S80Hf=S07emO@0h>3P0Vi^K08V9R@0L
71`0=3@d05aLG01NGUh0<c<c05YJFP0i>CT0=CDe05YJFP1/K6`0:BTY02h^;P23Ph<0AdM703Xj>P1K
Fe/0KVi^02d];@0`<300>c/k04a<C01NGUh0I6AT028R8P0H61P08b<S04];B`1cLg<0HV9R05eMG@0I
6AT08R8R03/k>`1KFe/0Cdm?04];B`2RXZ80=CDe028R8P1FEUH0VYZJ07QhN01DE5@0I6AT01lO7`0R
8R80F5QH07inOP13@d<0?Cdm06QXJ00W9bL061PH04U9B@2ATI40@T9203`l?01<C4`06ATI05MGE`2c
/k<0MGEe02l_;`11@D40?Shn04Q8B01SHf<0Lg=c02XZ:P0U9BD0CDe=05aLG02BTY80Rh^;01/K6`15
ADD0GEeM06][J`1LG5`0][Jf05eMG@0G5aL0?3`l065QH@1YJFT0IFEU0;6a/@17AdL0>CTi04m?C`1V
IVH0Fe]K05QHF026QXH07alO030`<01KFe/0HF5Q034a<@0c<c<0CTi>02LW9`14A4@0UiNG08V9R@0/
;2`0JVYZ03hn?P0g=cL0GEeM08f=S@0/;2`0=SHf05]KF`1GEeL0D51@0:6QX@2>SXh0820P03De=@1A
DE40ADE507IfMP2c/k<0<C4a03<c<`1;Bd/0KVi^06MWI`2][Jd0HV9R02<S8`1LG5`0JVYZ05QHF025
QHD0E5AD03hn?P1?Cdl0HF5Q05QHF02CTi<0Fe]K01dM7@1KFe/0F5QH04m?C`1JFUX0N7Qh02HV9P1@
D500ZZZZ07EeM@0a<C40HV9R02/[:`0S8b<0MWIf08J6QP0j>SX0EeMG03Ph>00b<S80RHV90:ZZZP0j
>SX00P17AdL0fP0a<C40>SXj08N7Q`1mOGd0<30`04Y:BP1LG5`0De=C07QhN02ZZZX0Ti>C024Q8@0l
?3`0Bd];04I6AP1cLg<0X:2P09>CT`0X:2P0B4Q8075aL@1QHF40G5aL0:>SX`11@D40>c/k04Y:BP1S
Hf<0HF5Q07moO`1fMWH08R8R05UIF@1ZJVX0HV9R04e=C@20P800WinO02/[:`1JFUX0CTi>04a<C00/
;2`0D51@05=CD`0Q8B40?Shn055AD@1PH600?Shn04m?C`1>CTh09RHV02@T901QHF40KVi^02PX:00e
=CD0>CTi02TY:@0k>c/0RHV905iNGP2RXZ80Lg=c04];B`18B4P0>SXj059BDP10@400=SHf04M7A`1T
I6@0Fe]K05QHF01UIFD0EUIF05]KF`1RHV80DE5A069RHP1ADE40BTY:06IVIP1@D500=cLg03lo?`1=
CDd0IVIV06][J`1:BTX0IfMW04A4A01]KFd0=cLg051@D01VIVH0AdM707moO`1hN7P0TI6A0;:b/P2T
Y:@0YZJV09RHV01XJ6P0ATI604e=C@1QHF40Cdm?07emO@1?Cdl0FUYJ03Hf=P0a<C40C4a<05aLG00_
;bl0@41006=SH`0X:2P0DE5A06e]K@0U9BD0GemO061PH015ADD0HV9R03hn?P23Ph<0ADE502l_;`10
@400>3Ph03<c<`0e=CD0<c<c04];B`1LG5`0>c/k04m?C`11@D40;bl_05MGE`1>CTh0CDe=059BDP0i
>CT0G5aL0451@@15ADD0Hf=S038b<P0K6a/0<S8b04Y:BP0e=CD0?Cdm03/k>`0_;bl0ATI604e=C@0e
=CD0@41002d];@0c<c<0De=C03Xj>P12@T80:BTY04Y:BP10@400A4A403@d=014A4@0BTY:04m?C`0l
?3`0?Shn04E5A@1>CTh0G5aL05EEE@1[Jf/0J6QX04U9B@1SHf<0@D5108N7Q`2LW9`0RHV906ATI01P
H600EUIF05UIF@12@T80D51@03Xj>P1DE5@0@D51055AD@0g=cL0EeMG07MgM`24Q8@0DE5A08J6QP2N
WYh0VIVI0:FUY@1/K6`0PH6108B4Q01HF5P0OWin03@d=019BDT0MGEe0P11@D40X@1]KFd0ADE503lo
?`17AdL0Cdm?07YjNP1UIFD0OWin07IfMP1YJFT0CDe=05]KF`0j>SX0?Shn06][J`0R8R80BDU904e=
C@0G5aL0K6a/07alO00^;Rh0DE5A04a<C011@D40H61P04Q8B01YJFT0<S8b04E5A@12@T809RHV04Y:
BP1FEUH0EeMG059BDP1=CDd0Cdm?06YZJP18B4P0Cdm?03`l?00o?cl0ADE506i^KP2>SXh0?Cdm059B
DP11@D404a<C02d];@0a<C40ATI604a<C00C4a<0GUiN061PH00b<S80LG5a05eMG@0b<S80AdM703Hf
=P1HF5P0;2`/06ATI01NGUh0Cdm?069RHP1TI6@0Ph>303hn?P19BDT0De=C04i>CP0g=cL0?3`l02d]
;@1KFe/0:b/[0492@P1RHV80A4A405QHF00j>SX0EeMG03hn?P1:BTX0@d=304M7A`1HF5P0L71`030`
<02DU9@0ATI606=SH`1FEUH0ATI605MGE`0_;bl0IfMW059BDP0i>CT0>c/k06QXJ01CDe<0BDU904Q8
B00j>SX0G5aL04Q8B01mOGd0C4a<0492@P0h>3P0<C4a05MGE`1BDU80P82006EUI@0R8R80DE5A03Ti
>@0j>SX0=SHf05=CD`1EEED0SHf=04U9B@1UIFD0BTY:04I6AP1PH600Bd];0820P02>SXh0HF5Q08f=
S@1DE5@0ATI605UIF@19BDT0FEUI05EEE@1<C4`0GEeM05MGE`1VIVH0>SXj06UYJ@1>CTh0BTY:06EU
I@16ATH0D51@04a<C01RHV80FUYJ069RHP1MGEd0R8R800;ooooo0000101UIFD0OGem08>3P`22PX82
0410@03o05QHF01CDe<0UYJF06m_K`10@400SXj>065QH@1?Cdl0E5AD03Lg=`17AdL0MgMg07AdM00S
8b<0Bd];05QHF00h>3P0J6QX069RHP0];Bd0:2PX055AD@14A4@0KFe]09nOW`0d=3@092@T03De=@1L
G5`0N7Qh06e]K@21PH4071`L02DU9@1PH600D51@04i>CP2HV9P0OWin02@T900Z:RX0BDU906a/K01Q
HF40O7al02`/;00j>SX0DU9B05aLG016ATH0NGUi06m_K`0J6QX06a/K030`<013@d<0EUIF06UYJ@1S
Hf<09RHV03Ph>01OGel0FUYJ03`l?01`L700=cLg024Q8@19BDT0MWIf07alO00l?3`0K6a/02<S8`15
ADD0DU9B06=SH`0O7al0ATI605=CD`0i>CT0;Rh^06i^KP1oOgl0<C4a02@T900b<S80FEUI04E5A@1c
Lg<0?clo01XJ6P0d=3@0CDe=03Hf=P1bLW80]kNg03/k>`0I6AT0B4Q806UYJ@1>CTh0Lg=c08j>SP0V
9RH09BDU05]KF`2IVIT0EEEE07=cL`1>CTh06ATI038b<P1RHV80>3Ph01TI6@1LG5`0=3@d01@D500/
;2`0Fe]K07YjNP0H61P0>3Ph04E5A@0`<300>SXj08F5Q@0c<c<05QHF03De=@1QHF40BTY:06ATI029
RHT0@D5101dM7@0_;bl0NGUi05YJFP1gMgL0KFe]01/K6`0i>CT0De=C075aL@1JFUX0RHV903<c<`0g
=cL0JFUY05=CD`1DE5@0IFEU04A4A00T92@0HV9R07alO01ADE40Hf=S05aLG00N7Qh0BDU9071`L02>
SXh0>SXj05mOG`1iNGT0=3@d02h^;P1SHf<0MGEe01lO7`1IFET0@T9205UIF@1ADE40Ti>C05YJFP0M
7Ad0EeMG05]KF`0m?Cd0I6AT05mOG`0T92@0<C4a05UIF@1cLg<0F5QH0;2`/01<C4`071`L0492@P1]
KFd0CTi>07EeM@2GUiL0:BTY02LW9`1ADE40Q8B405ADE02@T900L71`02<S8`17AdL0LG5a05eMG@0k
>c/0D51@01TI6@12@T80M7Ad06e]K@13@d<0Cdm?034a<@0X:2P0P82009BDU00_;bl0Cdm?03lo?`0`
<300MgMg0:VYZ@1=CDd0>3Ph04I6AP1CDe<0UIFE07]kN`0j>SX08b<S06YZJP0m?Cd0NWYj09bLW00Z
:RX09bLW03dm?@1hN7P0Q8B409VIV@18B4P0820P06][J`2KVi/0IFEU0:ZZZP2;Rh/0;Rh^038b<P1E
EED0HV9R001C06][J`2@T900IFEU02DU9@0/;2`0LW9b092@T016ATH0KFe]07=cL`0h>3P0?3`l071`
L02CTi<0D51@07QhN01_Kfl09RHV034a<@2:RXX0OGem03`l?01]KFd0Cdm?02TY:@1RHV80[Zj^06AT
I00_;bl0GEeM05IFEP0];Bd0G5aL065QH@1WIfL0<C4a05IFEP0h>3P0ATI609BDU021PH40<C4a02h^
;P16ATH0AdM704=3@`1kNg/0K6a/03<c<`11@D40?Cdm059BDP14A4@0M7Ad061PH011@D40>SXj04Y:
BP1NGUh0MgMg04E5A@0h>3P0I6AT05iNGP1IFET0HV9R051@D01IFET0PH6106EUI@0f=SH0HV9R07mo
O`2>SXh0SHf=06=SH`1ZJVX0IVIV05MGE`1_Kfl0CDe=04=3@`1<C4`00P1:BTX0g@1[Jf/0@d=305QH
F01FEUH0G5aL0451@@1>CTh0DU9B04i>CP1JFUX0NGUi06QXJ01WIfL0MWIf09fMW@2BTY80IfMW04];
B`1HF5P0CTi>0410@01ADE40Jf][06ATI01;Bd/0>c/k05ADE01ADE40;2`/04M7A`1;Bd/0>CTi04i>
CP1LG5`0Bd];06IVIP1XJ6P0EEEE07EeM@1HF5P0Vi^K04m?C`1JFUX0Fe]K04];B`1<C4`0Bd];0492
@P1RHV80H61P04I6AP1cLg<0H61P04A4A029RHT0@D5105UIF@1aLG40D51@061PH016ATH0BDU906AT
I01?Cdl0;Rh^03Xj>P1<C4`0<S8b0410@016ATH0<c<c05=CD`1NGUh0ATI60492@P0l?3`0Bd];06=S
H`0k>c/0DE5A04M7A`1LG5`0CDe=05iNGP1=CDd0FUYJ04=3@`1OGel0@T9205ADE016ATH0A4A4034a
<@13@d<0AdM704a<C01nOWh0L71`03dm?@18B4P0FEUI09FEU@1kNg/0EUIF05]KF`1DE5@0@41004e=
C@0h>3P0FEUI061PH01EEED0Bd];05iNGP2BTY80T92@0492@P1SHf<0K6a/0:f][@2<S8`0L71`09bL
W029RHT0FUYJ07QhN01?Cdl0GUiN05]KF`1_Kfl0De=C03Xj>P1:BTX0DU9B05QHF01cLg<0TY:B07Yj
NP1cLg<0B4Q8051@D017AdL0GEeM065QH@1VIVH0MgMg04=3@`1cLg<0GemO01LG5`1>CTh0IfMW02TY
:@0h>3P0ATI603Xj>P1eMGD0<30`07=cL`0W9bL0>3Ph04Y:BP0C4a<0:RXZ03lo?`0P8200@D510410
@00f=SH0C4a<01XJ6P0k>c/0>CTi051@D01IFET0J6QX09FEU@0j>SX0B4Q805EEE@0Q8B40>SXj03Ph
>016ATH0Cdm?028R8P1bLW80JVYZ03Ph>023Ph<0IVIV01dM7@0h>3P08B4Q04Y:BP0I6AT0De=C04a<
C01LG5`0I6AT07UiN@2FUYH0>SXj05]KF`1JFUX08R8R04A4A01EEED0=SHf05eMG@1;Bd/0GUiN04Q8
B019BDT0CTi>03dm?@1<C4`0BTY:061PH01CDe<0IFEU0080PH6100X0@T9206a/K016ATH0De=C06MW
I`0m?Cd0CDe=03dm?@2:RXX0JFUY0P1@D500:`1KFe/0BDU904e=C@1MGEd0<30`05YJFP1MGEd0Rh^;
05mOG`1VIVH0Cdm?03Ph>01RHV80<C4a06IVIP1cLg<0DU9B07=cL`0l?3`0Kfm_04U9B@1FEUH0=cLg
0410@00S8b<0=cLg03Hf=P1<C4`0MGEe03hn?P1eMGD0P82003dm?@2KVi/0J6QX05iNGP1cLg<0>c/k
0492@P16ATH0;2`/04I6AP0a<C400P11@D40301TI6@0AdM705EEE@1/K6`0D51@04];B`1:BTX0HF5Q
05UIF@1aLG40L71`06IVIP;ooooo00001@1hN7P0FUYJ06][J`2OWil0BDU90080D51@07h0HV9R0:f]
[@1UIFD0<S8b04m?C`1FEUH0P8200;bl_00f=SH0>c/k05IFEP1dM7@0AdM708j>SP1CDe<0?clo0492
@P2BTY80QHF506i^KP1[Jf/0=cLg03Ti>@1VIVH0XZ:R05YJFP1eMGD0Ph>302l_;`1@D500OWin05mO
G`0n?Sh0Xj>S04A4A00_;bl0=CDe06MWI`0k>c/0ATI605EEE@0[:b/0>3Ph069RHP1PH6006ATI0410
@00l?3`0;Rh^05EEE@18B4P06QXJ01dM7@0/;2`0@d=30492@P1hN7P0Kfm_01@D500X:2P0Bd];04i>
CP15ADD0X:2P05=CD`0E5AD07alO05IFEP16ATH0HV9R08n?S`0Y:BT05aLG04Q8B02@T900EeMG08b<
S02e]KD0;Bd]01LG5`14A4@0Ph>305QHF01IFET0Fe]K00X:2P0P8200FEUI05IFEP0V9RH0LG5a05YJ
FP0B4Q80<S8b06QXJ01PH6007alO06ATI00Z:RX0<C4a03lo?`1ZJVX0=SHf02/[:`0i>CT05ADE03<c
<`1=CDd0Ogmo03Ti>@0Z:RX0E5AD02/[:`15ADD0V9RH04];B`0@41008b<S05aLG01bLW80E5AD09VI
V@1NGUh05aLG04Q8B01DE5@204I6AP3o09BDU00T92@08R8R03<c<`1>CTh0KFe]0410@01kNg/0=cLg
028R8P1XJ6P0IVIV03<c<`16ATH0MGEe01DE5@0m?Cd0EEEE05YJFP0U9BD0=cLg05ADE00U9BD0Kfm_
06YZJP0K6a/0DU9B04];B`0e=CD0Rh^;09FEU@0Z:RX06a/K034a<@0l?3`0Fe]K09^KV`32`/80:2PX
0492@P1FEUH0Jf][05IFEP2YZJT0O7al034a<@1MGEd0EEEE07alO01XJ6P0`/;206UYJ@0^;Rh0FUYJ
09:BTP1XJ6P0MGEe08j>SP0^;Rh0=CDe07YjNP2@T900Cdm?0410@01JFUX09RHV0451@@2^[Zh0I6AT
04A4A01JFUX0=3@d03Ph>01PH600V9RH04Y:BP0b<S80Hf=S03@d=028R8P0Zj^[05QHF00M7Ad0GemO
04i>CP1MGEd0/K6a06QXJ00J6QX0=SHf06e]K@1=CDd0R8R804e=C@0Y:BT0;bl_07emO@2=SHd0OWin
06IVIP0J6QX0@41006EUI@24Q8@0Bd];09ZJVP0Z:RX0<30`04e=C@1@D500IFEU07emO@0I6AT0<c<c
07YjNP1cLg<09RHV06MWI`0k>c/09BDU0451@@1bLW80>c/k02XZ:P16ATH07AdM03@d=01^KVh0OWin
02d];@0j>SX0De=C04A4A01GEeL0Ogmo09BDU00d=3@0<S8b04=3@`1:BTX0E5AD07alO02?Shl09BDU
02/[:`1:BTX0Hf=S069RHP2WYjL0H61P02XZ:P0m?Cd0FUYJ06i^KP1fMWH0V9RH06=SH`0b<S80?Cdm
05=CD`1YJFT0@d=305eMG@0`<3005QHF04a<C01QHF40J6QX0492@P1mOGd0<C4a01TI6@14A4@0KVi^
03@d=015ADD0De=C03De=@0M7Ad0C4a<09:BTP1<C4`0:BTY04M7A`1`L700Lg=c04a<C00h>3P0=CDe
02TY:@17AdL0CTi>04E5A@1TI6@0KFe]05aLG00i>CT0EUIF065QH@1kNg/0SXj>0:RXZ01YJFT0GemO
04i>CP2MWId0FUYJ02@T900k>c/0A4A4055AD@1YJFT0=CDe0451@@0h>3P0Cdm?0492@P1/K6`0FUYJ
04Q8B01JFUX0LG5a07emO@2JVYX0Ng]k06ATI01cLg<0O7al051@D00n?Sh0GemO04U9B@1UIFD0DE5A
05MGE`1<C4`0CDe=04a<C014A4@0=3@d04E5A@1EEED0=CDe03lo?`1>CTh0:b/[03lo?`1LG5`0KVi^
06ATI01eMGD0IfMW05mOG`1LG5`0HV9R001H04m?C`1VIVH0FUYJ05IFEP1OGel0GUiN05EEE@1YJFT0
M7Ad079bLP1^KVh0AdM705eMG@1BDU80<S8b03hn?P12@T80ATI604e=C@0j>SX0<30`04U9B@11@D40
=SHf04M7A`0n?Sh0B4Q804Y:BP1HF5P0=3@d04A4A00c<c<0BTY:04M7A`0a<C40@41005MGE`1>CTh0
=SHf04e=C@1MGEd0E5AD04i>CP1@D500CDe=05]KF`1CDe<0GemO05=CD`1TI6@0A4A405=CD`1=CDd0
GEeM04E5A@1DE5@0QHF507]kN`1ZJVX0PX:206=SH`1[Jf/0FUYJ06QXJ00i>CT0GemO03dm?@1]KFd0
Cdm?04e=C@1bLW80MGEe05ADE01iNGT0_[jn0;Zj^P25QHD0EUIF04E5A@1IFET0IVIV079bLP0a<C40
92@T05=CD`0l?3`0>SXj04A4A0<0CTi>00D0FEUI09VIV@2RXZ80O7al05YJFP0207AdM00S05mOG`0U
9BD0=cLg069RHP19BDT0FUYJ069RHP10@400Ogmo09VIV@10@400@T9204M7A`1CDe<0PX:20410@01b
LW80?Shn04Q8B01EEED092@T03Lg=`1<C4`07alO04Q8B010@400=SHf04m?C`0A4A40?3`l02XZ:P0`
<300<S8b02l_;`2NWYh00P1>CTh0G01VIVH08B4Q03/k>`0];Bd0CTi>04m?C`0E5AD0DE5A05QHF00d
=3@0G5aL05EEE@0d=3@0IFEU0451@@1?Cdl0>c/k07moO`1QHF40@410059BDP1TI6@0R8R802TY:@1]
KFd0MWIf02TY:@19BDT0EUIF0492@P1=CDd0=SHf0451@@15ADD0?3`l05=CD`0e=CD0Bd];03Ti>@1<
C4`0?3`l05=CD`1SHf<0M7Ad0451@@1eMGD0BTY:04e=C@1EEED0>3Ph05IFEP0S8b<0HV9R03Ti>@11
@D40?clo08f=S@1@D500=SHf03@d=00`<300RHV90410@01YJFT0AdM7059BDP1LG5`0>SXj065QH@0c
<c<0QhN7061PH00P8200DU9B03Lg=`0c<c<0:b/[06EUI@0i>CT0G5aL038b<P0l?3`071`L02`/;01f
MWH0BDU906QXJ01jNWX0AdM707AdM01WIfL0?Shn0P1EEED04`1ADE40J6QX04M7A`1;Bd/0ADE503lo
?`0i>CT0L71`059BDP1?Cdl0Q8B405EEE@1KFe/0IFEU06UYJ@1/K6`0JFUY06][J`1fMWH00_ooool0
001g0<W9b@1@D500G5aL09fMW@1oOgl0UYJF04Q8B00o?cl0O7al09^KV`1^KVh0L71`04Y:BP0i>CT0
De=C06QXJ010@400GemO03dm?@0e=CD0DU9B06][J`0f=SH0AdM706=SH`0H61P0CTi>07moO`1:BTX0
<c<c051@D00o?cl0;Bd]07UiN@2IVIT0=3@d02/[:`1BDU80@41006IVIP2;Rh/0IVIV01/K6`0m?Cd0
EeMG04i>CP1kNg/0ZJVY02`/;00];Bd0@d=305ADE015ADD0XJ6Q05ADE00H61P0:RXZ06ATI019BDT0
DU9B08F5Q@0`<3008B4Q030`<01QHF40ATI606i^KP1VIVH08b<S028R8P1:BTX0Ng]k03Lg=`1?Cdl0
CTi>02<S8`0^;Rh0HV9R04Q8B00[:b/0ADE502PX:00Y:BT0@D5105aLG014A4@07QhN03dm?@0a<C40
@41005eMG@1VIVH06a/K01TI6@1<C4`0CDe=051@D01eMGD0MgMg01DE5@0B4Q80@D5105UIF@1@D500
XZ:R04E5A@0G5aL08b<S061PH012@T80GemO0820P00H61P0;Rh^05EEE@0k>c/0C4a<04e=C@1_Kfl0
0P0S8b<0?01PH600M7Ad030`<014A4@0O7al02@T900O7al0GemO08n?S`0j>SX08R8R05ADE00U9BD0
=cLg08Z:RP1hN7P08R8R03@d=01:BTX0<C4a05MGE`1gMgL0Rh^;02TY:@0`<300E5AD02d];@2EUID0
cLg=02h^;P0K6a/0EEEE069RHP1QHF40NWYj07alO00S8b<0<C4a06EUI@1?Cdl0SHf=06ATI00Y:BT0
=CDe07IfMP19BDT0CDe=06IVIP0];Bd071`L04m?C`2@T900GemO03`l?01]KFd0:RXZ02<S8`10@400
QhN704E5A@80AdM705L0:BTY0410@025QHD0/;2`05EEE@0g=cL0?Cdm03Lg=`1>CTh0TI6A05UIF@0^
;Rh0De=C051@D01jNWX0Ti>C07alO00R8R80<30`065QH@1aLG40IVIV0:VYZ@0g=cL0@d=305eMG@1F
EUH0ADE5061PH02_[jl0>c/k03hn?P2OWil0aLG503hn?P1VIVH0<C4a03`l?01KFe/0R8R804a<C01V
IVH0CTi>02/[:`1>CTh0Kfm_03lo?`1MGEd09bLW03Ph>01/K6`0HV9R03<c<`0i>CT0De=C020P801>
CTh0][Jf06ATI00/;2`0EeMG03Lg=`1[Jf/0/K6a034a<@0X:2P0A4A405=CD`18B4P0NWYj04Y:BP0I
6AT0@d=3069RHP1bLW80OGem07MgM`0S8b<07alO04Y:BP1[Jf/0DE5A07MgM`28R8P0;2`/03Xj>P1R
HV800P24Q8@0C@28R8P0[Zj^03Ti>@18B4P0FUYJ06a/K01IFET0De=C071`L00T92@0>c/k06MWI`1a
LG40B4Q805eMG@1CDe<09RHV04];B`1>CTh0GemO03hn?P0a<C40NWYj03/k>`1PH600S8b<05aLG00L
71`08b<S04M7A`0b<S80De=C0;^k^`2DU9@08B4Q02`/;01XJ6P0C4a<065QH@20P800>CTi01HF5P0c
<c<0O7al0861P@1OGel0R8R80492@P1RHV80GemO051@D01OGel0FEUI05iNGP1^KVh0D51@07AdM01`
L700IfMW06EUI@1]KFd0G5aL09JFUP1gMgL0EEEE06IVIP1OGel0De=C069RHP1=CDd0@41004=3@`1A
DE40GemO065QH@10@400GEeM0080GemO0240@T9204e=C@1JFUX0E5AD05MGE`1lO7`0GUiN07MgM`24
Q8@0Ogmo09BDU01UIFD0?Shn03dm?@1LG5`0EeMG05]KF`0n?Sh0EeMG065QH@10@400ATI604Y:BP0]
;Bd0BDU904M7A`0b<S80?clo065QH@1CDe<0NGUi06][J`1ADE400P1TI6@0;01]KFd0CDe=04=3@`1>
CTh0@T9203De=@10@400@d=304e=C@1ADE40?clo04=3@`0f=SH0<30`0410@00k>c/0A4A405MGE`0e
=CD0Hf=S03<c<`0f=SH0M7Ad04I6AP0Q8B40:b/[03`l?00/;2`0>SXj03Lg=`0Z:RX0>CTi051@D00c
<c<0B4Q803@d=00h>3P0DU9B038b<P0n?Sh0:2PX04i>CP11@D40C4a<0P1;Bd/0500h>3P0BTY:04Y:
BP13@d<0ATI605MGE`1cLg<0I6AT06EUI@1`L700EUIF06][J`1VIVH0UYJF09:BTP29RHT0KVi^07Ui
N@1fMWH0De=C0P1BDU80AP15ADD0BTY:04];B`1=CDd0@41004Q8B01nOWh0W9bL05=CD`1_Kfl0W9bL
0:j^[P2ATI40E5AD0451@@1HF5P0Bd];07AdM00i>CT08R8R07=cL`1=CDd0>SXj04=3@`12@T80D51@
03De=@0f=SH0F5QH05mOG`1RHV80@D5105eMG@15ADD0IFEU03Hf=P12@T80GemO02HV9P24Q8@0K6a/
0492@P1@D500Hf=S04];B`1?Cdl0BDU903Ph>01RHV80Bd];05YJFP0m?Cd0>c/k059BDP0i>CT0Bd];
05ADE014A4@0Fe]K05EEE@1BDU80EeMG03dm?@1PH600>CTi030`<011@D40?3`l07emO@0h>3P204e=
C@1`01lO7`0j>SX0?3`l05]KF`1?Cdl0;Bd]08V9R@20P800;bl_06MWI`1=CDd05QHF04=3@`0W9bL0
@D5101HF5P14A4@0CTi>04a<C01OGel0Rh^;0:ZZZP0i>CT0GUiN05MGE`0Q8B40<S8b04U9B@0W9bL0
ADE5034a<@1:BTX0CTi>04];B`1KFe/0B4Q804=3@`17AdL0De=C04Q8B026QXH0IFEU06IVIP19BDT0
LW9b059BDP1WIfL0LG5a03lo?`1CDe<0ATI6071`L01?Cdl0ATI602d];@1VIVH0CDe=055AD@1<C4`0
9bLW04M7A`16ATH0QXJ60492@P1XJ6P0>c/k02h^;P1EEED0=CDe06a/K01XJ6P0>3Ph059BDP0S8b<0
Bd];04=3@`1NGUh0EeMG061PH016ATH0CDe=01DE5@0f=SH0F5QH04i>CP1^KVh0K6a/04];B`23Ph<0
HF5Q04M7A`1HF5P0Fe]K08>3P`1TI6@0;Bd]04i>CP1;Bd/0De=C03Lg=`1[Jf/0K6a/071`L01fMWH0
NGUi07emO@1FEUH0J6QX05eMG@1^KVh0QhN708B4Q0;ooooo0000CP1lO7`0JFUY061PH01HF5P0EeMG
0:6QX@1MGEd0=SHf04m?C`1mOGd0NGUi096AT@0g=cL0=SHf05UIF@1YJFT0HF5Q0:j^[P1;Bd/08b<S
04a<C01DE5@0G5aL075aL@2OWil0:RXZ02h^;P1OGel0GEeM07AdM02][Jd0>c/k02l_;`0[:b/0ATI6
07AdM01mOGd0SHf=01HF5P0Y:BT0E5AD06ATI01FEUH0T92@08^;R`0b<S80;bl_07MgM`1XJ6P0EeMG
07YjNP0/;2`07AdM04Y:BP1TI6@0:RXZ03Hf=P11@D406ATI04Q8B016ATH0Hf=S02HV9P11@D40<c<c
01PH601^KVh0Xj>S03De=@0F5QH0>SXj04M7A`0k>c/0Jf][07inOP0I6AT0820P04E5A@80De=C05@0
Rh^;03Ti>@0C4a<0?3`l07=cL`1iNGT0?Cdm0:2PX01UIFD05aLG03@d=01=CDd0D51@04e=C@2LW9`0
8b<S01PH600[:b/0BTY:030`<018B4P0KVi^020P800I6AT0ADE506QXJ00e=CD0DE5A04U9B@0N7Qh0
<c<c06m_K`1oOgl09bLW06m_K`0_;bl07alO0492@P2@T900ADE501@D500b<S80DU9B03/k>`1HF5P0
U9BD03<c<`0>3Ph0BTY:06e]K@17AdL0HF5Q07]kN`0T92@08b<S04i>CP1bLW80=CDe05iNGP1[Jf/0
5aLG02l_;`1VIVH0J6QX0451@@1TI6@0EUIF02PX:01>CTh0RHV906=SH`11@D40Fe]K03@d=00m?Cd0
Ng]k09:BTP0`<300;Rh^0451@@0Y:BT0MGEe0861P@0O7al203Lg=`28055AD@1SHf<0Q8B4030`<00U
9BD0=3@d05ADE01NGUh0Jf][0<S8b019BDT09BDU02d];@1GEeL0DE5A07inOP2i^KT0;Bd]03De=@12
@T80HV9R05aLG021PH40@D5101lO7`1DE5@0FEUI065QH@1CDe<0aLG5059BDP0E5AD0I6AT06m_K`0f
=SH0E5AD06][J`0b<S80:2PX07AdM01^KVh0;Bd]04A4A00n?Sh0B4Q804i>CP2>SXh0=3@d02h^;P16
ATH0=SHf069RHP34a<@0Hf=S024Q8@1:BTX0C4a<04=3@`2CTi<0MWIf02LW9`0c<c<0GemO06UYJ@1i
NGT0De=C01/K6`1PH600MgMg04E5A@2;Rh/0KFe]02XZ:P0g=cL0Ph>307YjNP1dM7@0Ti>C03/k>`0d
=3@0J6QX06][J`1VIVH0RHV902DU9@0g=cL0E5AD05iNGP0i>CT0EeMG06ATI00T92@0EUIF0:j^[P1`
L700B4Q806a/K01@D500;2`/05eMG@1gMgL0EEEE02DU9@16ATH0@d=30492@P1KFe/0RXZ:07IfMP0^
;Rh0CDe=03lo?`1?Cdl0IFEU096AT@1;Bd/0>3Ph05EEE@13@d<0Fe]K09fMW@2GUiL09bLW04E5A@1T
I6@0K6a/05ADE01cLg<0TY:B0451@@0Z:RX0De=C08b<S017AdL0CTi>06i^KP80;Bd]0540GemO0861
P@0f=SH0=cLg04I6AP0F5QH0:b/[055AD@1KFe/07QhN02LW9`10@40092@T04I6AP1@D500M7Ad06MW
I`19BDT0>CTi04A4A00e=CD0H61P05MGE`14A4@0GemO08N7Q`1]KFd0@D5105EEE@2>SXh0_;bl0;^k
^`2][Jd0OWin061PH01GEeL0MgMg04E5A@0c<c<0BDU903lo?`0a<C40EEEE055AD@1CDe<0?Shn06UY
J@1HF5P0JVYZ07]kN`12@T80PH610:ZZZP2?Shl0M7Ad08^;R`1gMgL0WIfM06i^KP1?Cdl0BDU905YJ
FP13@d<0LG5a04M7A`1]KFd0EEEE03/k>`1IFET0GUiN02PX:00m?Cd0F5QH04i>CP1IFET0G5aL02LW
9`11@D40F5QH05MGE`1VIVH00P1ZJVX0;@1;Bd/0CDe=075aL@1OGel0CTi>04e=C@1aLG40Lg=c06IV
IP19BDT0GUiN061PH01<C4`0RHV903/k>`1BDU80N7Qh06ATI01OGel0=CDe03hn?P1_Kfl0ATI602@T
900_;bl0C4a<03Ph>00b<S80?Shn04Q8B01?Cdl0EeMG03`l?01NGUh0>SXj03/k>`1DE5@0>c/k0410
@00d=3@0DU9B04a<C01IFET0BTY:04i>CP0204m?C`1/03Ti>@1>CTh0De=C04Q8B00l?3`0CDe=03Ti
>@0o?cl0IVIV05]KF`13@d<0C4a<05YJFP2CTi<0PH6106a/K01aLG40EUIF05YJFP1BDU80=cLg04Y:
BP11@D40E5AD03lo?`1ADE40YZJV09:BTP1PH600ZJVY09jNWP2?Shl0YJFU05IFEP16ATH0MGEe05AD
E01mOGd0DU9B02/[:`1aLG40BDU904i>CP1?Cdl0CTi>04e=C@0n?Sh0Bd];08V9R@2<S8`0Kfm_04E5
A@1dM7@0D51@079bLP0k>c/0?Shn06MWI`0`<300E5AD0820P00Y:BT0IfMW06=SH`0_;bl0DE5A04i>
CP0l?3`0GUiN04e=C@1fMWH0>3Ph03lo?`1:BTX0>SXj051@D01RHV808b<S03Lg=`19BDT0B4Q8059B
DP0F5QH0;Rh^03Ti>@1EEED0Bd];06=SH`1eMGD0@D5104e=C@1?Cdl05QHF06MWI`0i>CT0BTY:03Ph
>00<30`0>c/k05YJFP10@400Ph>306=SH`0U9BD0@T9203`l?01CDe<0:2PX0P1BDU80;P0n?Sh0FUYJ
051@D01^KVh0=3@d05UIF@1LG5`04a<C0492@P1DE5@0?clo06a/K01@D500BDU908R8R01jNWX0Fe]K
04i>CP1WIfL0>3Ph055AD@1NGUh0MWIf05QHF01^KVh0GemO079bLP2;Rh/0@410061PH00o?cl0C4a<
02XZ:P28R8P0I6AT0451@@1EEED0GUiN03hn?P1JFUX0F5QH04U9B@1KFe/0Bd];07inOP1IFET20410
@00^02h^;P1>CTh0820P0<30`02ATI40=CDe05EEE@0f=SH0BTY:02l_;`1gMgL0EUIF06][J`0[:b/0
DU9B04Q8B00_;bl0FEUI03Ph>01mOGd0RXZ:04];B`1RHV80G5aL04Q8B01IFET0?3`l04E5A@1BDU80
<S8b04m?C`0_;bl0BTY:0451@@1[Jf/0BTY:059BDP1KFe/0C4a<05EEE@18B4P0EEEE07EeM@1JFUX0
L71`075aL@;ooooo0000101XJ6P0IfMW0;Bd]01gMgL204a<C03507AdM01QHF40]kNg04e=C@1YJFT0
U9BD07=cL`1aLG40UYJF034a<@19BDT0RHV9092@T01IFET0N7Qh075aL@0W9bL0EeMG08j>SP22PX80
Jf][08B4Q00K6a/0?Cdm04=3@`1?Cdl0>3Ph04e=C@1EEED061PH06IVIP2LW9`0A4A403Xj>P1GEeL0
:RXZ01lO7`1`L700SXj>02PX:00Q8B40?Shn0410@01QHF40RHV904I6AP0L71`0?clo05eMG@14A4@0
N7Qh07=cL`0F5QH07alO04=3@`1hN7P0EUIF08Z:RP1EEED07QhN01LG5`1NGUh0P82004a<C020P800
9BDU04];B`0o?cl0GUiN04I6AP1;Bd/0L71`01hN7P0[:b/0@D5105aLG00X:2P0B4Q803Ph>00e=CD0
;Bd]05iNGP1WIfL08R8R02d];@0a<C40<S8b04];B`25QHD0DE5A00h>3P0h>3P0=CDe03<c<`1lO7`0
`/;205UIF@0F5QH0@D5102PX:00n?Sh0OWin08F5Q@0I6AT092@T03Lg=`1:BTX0A4A40;>c/`15ADD0
8B4Q03Lg=`0n?Sh0EUIF04E5A@1IFET0:BTY01dM7@14A4@0Bd];07AdM00^;Rh0KVi^03@d=00Q8B40
<S8b06ATI00h>3P0<C4a03Lg=`0[:b/0=SHf055AD@1jNWX0=CDe02HV9P14A4@0CDe=05]KF`1iNGT0
LW9b01HF5P1EEED0MWIf04I6AP1ZJVX0Y:BT02l_;`0L71`0?Shn07MgM`1ADE40F5QH04U9B@0N7Qh0
IFEU07moO`1?Cdl0LG5a04Q8B00R8R80<c<c07emO@1lO7`06a/K02/[:`0l?3`0:BTY04e=C@1>CTh0
L71`03De=@1BDU80=3@d02LW9`18B4P0IVIV065QH@0];Bd0K6a/0410@00j>SX0V9RH06m_K`0W9bL0
@d=306QXJ00];Bd0D51@0::RXP2TY:@09bLW03dm?@1QHF40ADE508F5Q@2RXZ800P0Y:BT0o`1:BTX0
O7al05YJFP23Ph<0EEEE03<c<`19BDT0CTi>04a<C01KFe/0QHF502l_;`0X:2P0DU9B0861P@1EEED0
MgMg03Lg=`0V9RH0CDe=07inOP0Y:BT0BDU901DE5@0_;bl0HV9R092@T00o?cl0@d=305eMG@0V9RH0
De=C08N7Q`0[:b/0De=C051@D00f=SH0Bd];08N7Q`1=CDd0;2`/03dm?@0[:b/0KVi^0;Zj^P1NGUh0
7alO06MWI`1FEUH0BDU908n?S`2;Rh/0:2PX02<S8`1LG5`0I6AT06QXJ02OWil0L71`03<c<`1CDe<0
HV9R07IfMP1iNGT0SHf=07=cL`0X:2P0=SHf065QH@29RHT0IfMW096AT@19BDT09bLW03Hf=P1NGUh0
LW9b05UIF@25QHD0I6AT02XZ:P0_;bl0Kfm_05UIF@1DE5@0JVYZ03Ph>00U9BD0:BTY07QhN01NGUh0
ATI605mOG`0Y:BT0<c<c0451@@1XJ6P0?clo03Lg=`1CDe<0B4Q805=CD`1PH600M7Ad02<S8`0V9RH0
=SHf04I6AP1NGUh0F5QH08V9R@0W9bL0=3@d05aLG01=CDd0Ng]k06i^KP1FEUH0ATI604U9B@1^KVh0
Cdm?0410@01TI6@0OWin069RHP1/K6`0LG5a069RHP1WIfL0PX:207YjNP1WIfL0FEUI04e=C@20P800
FEUI03Ph>00n?Sh0@d=303Ph>01DE5@0@d=3069RHP0j>SX0F5QH03`l?01GEeL0KFe]03hn?P1bLW80
Ph>309:BTP1VIVH0S8b<08F5Q@2ZZZX0N7Qh05YJFP1DE5@0JFUY03hn?P1dM7@0ATI605UIF@1@D500
ADE504];B`1LG5`0>CTi03/k>`1UIFD0=cLg03/k>`1RHV80<C4a051@D01lO7`0HV9R065QH@1=CDd0
IVIV07MgM`1/K6`0DU9B03hn?P1JFUX0CTi>03dm?@13@d<0EeMG06ATI01?Cdl0HV9R06IVIP1FEUH0
>c/k04i>CP1RHV80>c/k05]KF`12@T80DU9B04];B`0d=3@0;Bd]04Y:BP0f=SH09bLW03/k>`0b<S80
9BDU03@d=01<C4`09bLW03<c<`0^;Rh0?Cdm04=3@`0P8200>c/k04i>CP1ADE40<30`0410@01BDU80
C4a<02/[:`11@D40?Cdm0492@P10@400BDU903dm?@1MGEd0LG5a06ATI01;Bd/0Fe]K07QhN02UYJD0
Shn?071`L01IFET0Ogmo09VIV@1ZJVX0A4A405UIF@1@D500B4Q803/k>`1VIVH0H61P06EUI@00HP1d
M7@0IVIV04e=C@1RHV80NGUi09NGU`2YZJT0EeMG04];B`1kNg/0A4A4075aL@17AdL0C4a<06a/K010
@400?Cdm059BDP16ATH0@T9204=3@`23Ph<0Shn?08j>SP1gMgL0Jf][06IVIP14A4@0LW9b03lo?`15
ADD0KFe]03`l?01[Jf/0QHF502XZ:P1bLW80MWIf038b<P14A4@0B4Q802TY:@1^KVh0;2`/07alO00i
>CT0?Shn0451@@0H61P0?3`l04i>CP0o?cl0@d=304Y:BP13@d<0HF5Q02@T900g=cL0AdM702/[:`0j
>SX0@d=305eMG@1EEED0N7Qh05]KF`0S8b<0;2`/0410@01:BTX0Bd];01lO7`1;Bd/0DU9B03Hf=P1j
NWX0JFUY02h^;P0g=cL0<C4a059BDP1>CTh0EEEE05MGE`1KFe/0HF5Q05IFEP1QHF405ADE055AD@1M
GEd0?3`l04=3@`0n?Sh0DU9B05eMG@0h>3P0ADE50P1:BTX00`1CDe<0BTY:04A4A00204E5A@0;03lo
?`1RHV80D51@05QHF01YJFT0VIVI06a/K010@400HV9R04i>CP1PH6000P1UIFD0?01=CDd0ATI606IV
IP1RHV80BTY:04U9B@28R8P0Bd];06a/K01GEeL0RHV903hn?P1<C4`0@41003Ph>01EEED0<30`05=C
D`1@D500@T9208:2PP13@d<0Bd];04M7A`1<C4`0CDe=07EeM@1BDU80L71`02HV9P0o?cl0FUYJ04i>
CP2^[Zh0RXZ:03`l?01HF5P0Hf=S05QHF01[Jf/0?clo04e=C@1MGEd0ATI605UIF@0[:b/0?Shn028R
8P1gMgL0De=C04M7A`1cLg<0D51@04m?C`1FEUH0LG5a07AdM01oOgl0JFUY0::RXP;ooooo0000D@21
PH40C4a<05YJFP2OWil0FUYJ07=cL`1;Bd/0BDU909FEU@1jNWX0@T9205EEE@1;Bd/0F5QH07YjNP19
BDT08b<S04U9B@12@T80KFe]07IfMP1@D500<c<c04=3@`1EEED0EeMG05UIF@2FUYH0Bd];02/[:`0o
?cl0EUIF08^;R`2YZJT0UiNG020P800V9RH0M7Ad06][J`1YJFT0WinO038b<P0V9RH09BDU05eMG@1@
D500L71`08B4Q00E5AD09bLW030`<01@D500>3Ph08f=S@1EEED08b<S04U9B@1_Kfl0?clo02`/;015
ADD092@T02/[:`1ADE40N7Qh02<S8`0i>CT0=SHf02l_;`0c<c<0O7al0492@P0G5aL0<S8b03dm?@0l
?3`0Jf][09JFUP0E5AD09RHV02h^;P0205IFEP0M09>CT`1hN7P08b<S0410@01GEeL0EUIF03lo?`1b
LW80F5QH01@D500S8b<0GEeM06IVIP0e=CD0J6QX04i>CP0H61P0820P06EUI@1]KFd0=CDe079bLP0c
<c<06a/K02DU9@1^KVh0EUIF04M7A`1LG5`00P0O7al0o`0n?Sh0JVYZ02LW9`0o?cl0@d=302PX:01L
G5`0KVi^051@D00H61P0;bl_03lo?`0T92@0De=C0;2`/01aLG405ADE02/[:`1:BTX0?Cdm05iNGP2O
Wil0=cLg024Q8@0i>CT0GemO05]KF`1@D500M7Ad02h^;P0a<C40GemO07=cL`0c<c<0CTi>08b<S00J
6QX0=SHf05]KF`1QHF40<C4a05IFEP1CDe<0:BTY0492@P10@400<S8b05YJFP0Y:BT0:2PX075aL@2;
Rh/0:BTY02/[:`0a<C40F5QH059BDP26QXH0Kfm_01dM7@14A4@0JVYZ07AdM01BDU80W9bL03lo?`0P
82009RHV0861P@24Q8@0DE5A0:NWY`1>CTh07AdM02d];@1bLW80BTY:07emO@1`L700<C4a03<c<`0m
?Cd0Q8B406EUI@26QXH0K6a/01LG5`0i>CT0P82006=SH`0_;bl0GemO034a<@0k>c/0IFEU06=SH`0_
;bl0C4a<04i>CP0/;2`0GEeM09bLW01QHF40=CDe06i^KP0Z:RX0EeMG0;Vi^@2FUYH08R8R055AD@1I
FET0G5aL09fMW@0`<300;Bd]04];B`2>SXh0Hf=S09:BTP1WIfL0;Rh^05]KF`21PH40AdM707UiN@24
Q8@0:b/[03De=@1dM7@0Kfm_07YjNP1UIFD05ADE02l_;`1?Cdl0JFUY05=CD`2EUID0<30`02DU9@15
ADD0XZ:R07UiN@1OGel0E5AD02DU9@0k>c/0ADE506EUI@1:BTX0CDe=06MWI`0I6AT0@41005=CD`1H
F5P0=SHf05QHF01@D5009RHV04A4A01SHf<0OGem03Ph>00i>CT0>SXj03De=@1QHF40Ti>C06MWI`0W
9bL0=cLg03<c<`16ATH0NGUi0:2PX01BDU80820P02PX:00l?3`0F5QH06ATI024Q8@0B4Q802DU9@1;
Bd/0@d=303Hf=P1PH600PH6102`/;00V9RH0GUiN059BDP0j>SX0?clo05mOG`0K6a/0;bl_04m?C`1A
DE40D51@04E5A@1GEeL0EEEE07YjNP1GEeL0?Shn06YZJP2BTY80NWYj06i^KP1:BTX0M7Ad08f=S@1/
K6`0B4Q806i^KP28R8P0QhN70;no_`2?Shl0QXJ607UiN@1/K6`0OGem051@D018B4P0F5QH051@D00f
=SH0EeMG04Q8B01ZJVX0Cdm?06i^KP18B4P0EeMG07]kN`16ATH0PX:20:2PX02BTY80Ti>C09ZJVP2<
S8`0UIFE07MgM`18B4P0D51@06UYJ@1LG5`0R8R804=3@`005P1SHf<0F5QH03Xj>P1BDU80FEUI02LW
9`13@d<0OWin0451@@12@T80Ng]k03Ti>@1CDe<0Lg=c05MGE`1YJFT0DE5A07MgM`1:BTX0@D5105]K
F`15ADD2055AD@3504E5A@1UIFD0MWIf04U9B@1LG5`0Fe]K04I6AP24Q8@0FUYJ061PH01jNWX0@410
05ADE00m?Cd0>c/k07YjNP11@D408R8R02l_;`14A4@09bLW02h^;P0h>3P0=cLg0492@P1IFET0;Rh^
03hn?P0d=3@0>3Ph059BDP0Z:RX0@D5103lo?`1MGEd0AdM704i>CP0o?cl0A4A404];B`1EEED0@T92
04E5A@1<C4`0FUYJ05IFEP1VIVH0=cLg05ADE01=CDd0F5QH05IFEP19BDT0JVYZ06m_K`1dM7@0LW9b
06][J`1ZJVX0ADE505IFEP0c<c<0AdM704A4A01KFe/0<c<c055AD@24Q8@0Ph>307IfMP2_[jl0NWYj
08F5Q@1lO7`0IVIV05YJFP1_Kfl0FEUI06MWI`0b<S80<C4a05]KF`1@D500F5QH05EEE@1?Cdl0BTY:
03Hf=P1ADE40MGEe0:NWY`1LG5`0A4A405aLG01]KFd0EeMG05]KF`1hN7P0RHV90451@@1HF5P0YjNW
04];B`25QHD0Ogmo05IFEP1>CTh0De=C03lo?`1ZJVX0<c<c07YjNP0o?cl0HF5Q05YJFP0B4Q80A4A4
05ADE00K6a/0D51@04M7A`11@D40Hf=S018B4P1<C4`0=CDe03Ph>01GEeL0CDe=05eMG@0h>3P0?Cdm
04I6AP0O7al0<C4a04m?C`1mOGd0IFEU02LW9`1?Cdl0EeMG03Ti>@1XJ6P0Bd];01/K6`1<C4`05QHF
03/k>`0g=cL0D51@05UIF@0h>3P0BTY:05mOG`1NGUh0C4a<06YZJP23Ph<0EEEE03dm?@0k>c/0?Shn
05=CD`17AdL0820P05mOG`1CDe<0HF5Q03Xj>P1?Cdl0@d=304E5A@19BDT0I6AT06=SH`1kNg/0>3Ph
06EUI@1aLG40?Shn05UIF@1KFe/0S8b<07AdM01cLg<0E5AD03Ti>@1=CDd0Ph>3071`L01/K6`0Kfm_
079bLP2@T900F5QH07inOP1KFe/00P1;Bd/0;P0V9RH0EUIF02HV9P1lO7`0CTi>0410@016ATH0<c<c
05YJFP0P8200FEUI05QHF01jNWX0AdM705UIF@1JFUX0A4A4061PH00m?Cd0MgMg06m_K`19BDT0IFEU
04m?C`0c<c<0BDU90451@@1<C4`0D51@038b<P0m?Cd0@D51055AD@0c<c<0CTi>059BDP1:BTX0EEEE
07AdM01hN7P0EUIF05aLG028R8P0Kfm_08>3P`1/K6`2ooooo`0000l0_kno04M7A`1DE5@0Ti>C08Z:
RP2j^[X0Bd];04M7A`1XJ6P0Ogmo09^KV`1mOGd09BDU04E5A@1@D5000P1ZJVX06`2UYJD0<c<c02<S
8`1ADE40VIVI05UIF@2SXj<0Q8B4030`<017AdL0M7Ad07YjNP1IFET0F5QH01lO7`0Y:BT0Jf][09BD
U01SHf<0E5AD05=CD`0P8200?Shn055AD@1SHf<0;Bd]0492@P0203Lg=`3o04e=C@2=SHd0BTY:020P
8017AdL09BDU038b<P25QHD0Ti>C03Xj>P13@d<0IFEU0451@@10@400S8b<04];B`0N7Qh0BDU904];
B`0i>CT0MGEe08^;R`0F5QH0:b/[0410@01GEeL0De=C07alO01RHV806a/K03<c<`18B4P0GEeM05YJ
FP1eMGD09bLW02TY:@0m?Cd0HF5Q03Xj>P0c<c<0NGUi03/k>`0H61P0?Cdm05QHF00[:b/0:BTY05=C
D`0P82007alO07EeM@1TI6@05aLG01XJ6P0m?Cd0>CTi030`<01oOgl0E5AD01HF5P0W9bL0=SHf05AD
E020P800Rh^;030`<00b<S80820P04=3@`1@D500PH610820P00I6AT0<c<c04U9B@1QHF40A4A405iN
GP1`L7005ADE02LW9`1>CTh0PX:206IVIP0l?3`0Cdm?02TY:@0X:2P0@d=305EEE@0E5AD0=3@d0410
@00];Bd0>SXj06EUI@15ADD071`L03Lg=`17AdL0=3@d06ATI02a/K40;Bd]02<S8`1RHV80EUIF04U9
B@2IVIT0];Bd01`L700h>3P0@D51079bLP2n_[h0>c/k0410@00f=SH0Fe]K051@D01QHF40J6QX02<S
8`1IFET0DU9B07MgM`1=CDd0Cdm?071`L00b<S80>SXj05mOG`1UIFD0?clo04e=C@13@d<09RHV03dm
?@1^KVh0K6a/02h^;P14A4@0<S8b02l_;`1PH600Shn?05YJFP0Z:RX0A4A404=3@`1WIfL0QXJ609RH
V00a<C40=3@d055AD@0j>SX0Hf=S0:JVYP17AdL05QHF04m?C`1lO7`0@D5108F5Q@1kNg/07AdM0451
@@1KFe/0EeMG06=SH`2a/K40<C4a01dM7@1PH600WIfM05=CD`1`L700EUIF03/k>`1LG5`0Fe]K02h^
;P1>CTh09BDU02LW9`1/K6`0Rh^;03hn?P13@d<0A4A403<c<`0j>SX0LG5a04E5A@1IFET0GEeM02DU
9@1UIFD0V9RH04e=C@1;Bd/0E5AD03Xj>P10@400Ph>306][J`0[:b/0ATI603Ph>01CDe<0K6a/08:2
PP0Y:BT0=3@d03`l?013@d<0BDU907QhN02c/k<0<S8b02XZ:P1GEeL0E5AD04U9B@2ATI40Shn?0492
@P0V9RH0EeMG06][J`1@D500MWIf075aL@0n?Sh0>CTi08:2PP2WYjL0Cdm?06YZJP18B4P0;bl_0492
@P22PX80NWYj03Ph>01SHf<0HV9R01TI6@18B4P0E5AD06e]K@0W9bL0;bl_000[0492@P0V9RH0BTY:
07QhN01jNWX0:RXZ04A4A01CDe<0=SHf059BDP2IVIT0De=C02PX:01@D500E5AD03`l?01NGUh0RXZ:
0861P@2;Rh/0Kfm_04A4A01LG5`0GEeM06=SH`19BDT0?Shn04];B`1RHV80Fe]K04a<C01LG5`0O7al
07UiN@1eMGD0Ogmo08>3P`1IFET0AdM70820P01<C4`0B4Q803lo?`0203dm?@0405iNGP1YJFT0EeMG
04i>CP80D51@07H0JFUY05ADE00o?cl0FEUI07moO`1KFe/0Bd];061PH01eMGD0Ph>306=SH`15ADD0
B4Q804E5A@0o?cl0FUYJ04m?C`1MGEd0Cdm?03dm?@1LG5`0FEUI03Ti>@17AdL0F5QH04E5A@19BDT0
HV9R0451@@1DE5@0JVYZ06ATI01cLg<0KFe]07]kN`1DE5@0CDe=05mOG`1<C4`0HV9R05MGE`1MGEd0
Lg=c08N7Q`1EEED0EeMG05mOG`15ADD0UYJF04E5A@19BDT0R8R804i>CP1/K6`0?3`l04M7A`23Ph<0
KVi^0451@@14A4@0DE5A03Ph>00d=3@0@T9204e=C@1;Bd/0GemO04Y:BP1<C4`0:b/[0451@@1JFUX0
=cLg04U9B@1?Cdl0G5aL051@D01DE5@0C4a<055AD@1EEED0Fe]K04U9B@1DE5@0BTY:05IFEP13@d<0
FEUI05EEE@1JFUX0IFEU0820P01eMGD0Ogmo08B4Q01[Jf/0HF5Q06a/K01dM7@0Hf=S04I6AP1@D500
?clo051@D016ATH0J6QX04];B`1GEeL0TY:B09nOW`1KFe/0CDe=061PH01bLW80M7Ad07QhN02:RXX0
MGEe0P19BDT01`0k>c/0F5QH05aLG00a<C40ATI604E5A@13@d<00P0l?3`04P1VIVH0DE5A05YJFP1Q
HF40IVIV061PH00m?Cd0EUIF05mOG`1nOWh0HV9R04m?C`1RHV80T92@05iNGP2QXJ40PX:204I6AP80
GUiN01/0=CDe06YZJP1;Bd/0GEeM03Ti>@14A4@0@d=3030`<013@d<0EEEE02TY:@1?Cdl0CDe=055A
D@1QHF408B4Q03Xj>P10@400FEUI055AD@1RHV80Jf][030`<01<C4`0I6AT020P800f=SH00P15ADD0
K019BDT0:b/[07EeM@1bLW80?Cdm06ATI017AdL08R8R02TY:@0d=3@0DE5A03De=@1DE5@0?clo03Hf
=P1?Cdl0FEUI075aL@10@400Bd];04e=C@0_;bl0FEUI05QHF011@D40H61P03Hf=P0X:2P0IfMW04];
B`18B4P0BDU906ATI013@d<0BDU9055AD@1BDU80?Shn05aLG01[Jf/0Zj^[0861P@1;Bd/0JFUY04Y:
BP1SHf<0=SHf0861P@1cLg<0@410059BDP1MGEd0Cdm?05ADE01hN7P0DE5A04Q8B00i>CT0EUIF04i>
CP1KFe/0DE5A05YJFP1oOgl0FUYJ07alO01SHf<0<S8b05EEE@15ADD0DU9B02d];@1OGel0Cdm?08n?
S`0e=CD0JFUY02TY:@12@T80Fe]K03Ph>01oOgl0KVi^04a<C01^KVh0I6AT04U9B@1=CDd0<30`04m?
C`1NGUh0<c<c04Q8B00R8R80KVi^04];B`1FEUH0EEEE05IFEP1MGEd0BTY:04i>CP1KFe/0R8R804a<
C01ADE40G5aL0:JVYP;ooooo0000o`2RXZ80HF5Q07alO01;Bd/0C4a<071`L01^KVh0F5QH09BDU00m
?Cd0GUiN08b<S016ATH0ADE505YJFP0V9RH0ATI609^KV`1bLW80;Rh^04i>CP0m?Cd0<C4a07MgM`2K
Vi/0:b/[034a<@16ATH0?Cdm08Z:RP2;Rh/0:b/[01HF5P0];Bd0JFUY05iNGP2EUID0/K6a01dM7@0]
;Bd0ATI606][J`1?Cdl0X:2P06i^KP0M7Ad0>c/k06][J`1PH600ATI60820P00X:2P0;2`/04U9B@1k
Ng/0IVIV06EUI@1_Kfl0820P02TY:@1:BTX0L71`05ADE01gMgL08b<S02DU9@0m?Cd0GEeM051@D00R
8R80LG5a01dM7@12@T80@d=305]KF`0];Bd0>c/k03Xj>P0c<c<0ATI606i^KP1<C4`07AdM02XZ:P0i
>CT0>3Ph04Y:BP2YZJT0GemO01lO7`0T92@0>c/k04i>CP1EEED0^[Zj03De=@0J6QX0:b/[05EEE@13
@d<0IVIV0:FUY@0P82008B4Q02`/;01NGUh0@d=305aLG01EEED06ATI038b<P1SHf<0D51@03/k>`1Q
HF40;Rh^02LW9`0o?cl0@d=302/[:`0Y:BT0D51@02`/;00U9BD0Kfm_07inOP0h>3P08R8R03hn?P0m
?Cd0<C4a05iNGP1cLg<07alO03Hf=P1@D500DE5A03Ph>01cLg<0IfMW02HV9P15ADD0=cLg06MWI`1Z
JVX0MgMg05=CD`0e=CD0@41004Q8B01>CTh0>c/k07YjNP0R8R80<C4a04=3@`1XJ6P0>CTi04m?C`15
ADD0;bl_08b<S027QhL0:b/[03dm?@0k>c/092@T05aLG02QXJ40CDe=03@d=01HF5P0EEEE03lo?`1e
MGD0[jn_030`<00V9RH0ADE505QHF011@D40T92@0;Fe]@0m?Cd08b<S06=SH`1dM7@0DE5A08j>SP1Z
JVX09RHV05IFEP24Q8@0MgMg075aL@2GUiL0<S8b020P801`L700Ti>C07EeM@1dM7@0TI6A030`<00L
71`0Jf][08b<S00m?Cd0A4A4034a<@0`<300@T9207UiN@10@400@d=303/k>`0N7Qh0@d=3079bLP1/
K6`0=3@d03lo?`0b<S80De=C07moO`1GEeL0=CDe05IFEP0l?3`0CTi>09ZJVP0_;bl06QXJ04Y:BP1N
GUh0?Cdm07moO`1_Kfl0:RXZ03Xj>P17AdL0DU9B07UiN@2a/K40=SHf0492@P1GEeL0?3`l04e=C@1C
De<08R8R03@d=01ADE40OWin03dm?@00A022PX80;Rh^02l_;`1JFUX0Lg=c069RHP17AdL0IfMW03Xj
>P0a<C40G5aL0861P@1ZJVX0?clo06][J`0g=cL0<c<c05EEE@2ZZZX0N7Qh03lo?`1RHV80E5AD030`
<024Q8@0XZ:R055AD@0k>c/0KFe]04m?C`1SHf<0MWIf04Q8B00P8200>SXj06][J`1JFUX0DU9B06][
J`2CTi<0=CDe02/[:`1=CDd0EUIF05YJFP1NGUh0X:2P024Q8@0_;bl0?3`l08^;R`19BDT0KVi^05]K
F`0P8200BTY:04m?C`1FEUH0C4a<05QHF013@d<0:BTY03Hf=P1CDe<0Fe]K06UYJ@1`L700Fe]K0P1S
Hf<0@01]KFd0D51@0451@@1gMgL0Ng]k07emO@1WIfL0PX:207]kN`1WIfL0UiNG09nOW`2IVIT0Hf=S
05YJFP1cLg<0FUYJ05QHF01<C4`0?Cdm02LW9`1oOgl0C4a<06UYJ@13@d<0K6a/0451@@1=CDd0GemO
03Lg=`1/K6`0Fe]K09FEU@1SHf<0RHV909ZJVP2RXZ80MWIf061PH01?Cdl0LW9b04Q8B01aLG40@410
0492@P1ADE40<C4a04M7A`16ATH0?3`l03lo?`1>CTh0>SXj03Ti>@1HF5P0;Rh^03lo?`1NGUh0ADE5
04M7A`1GEeL0DE5A06UYJ@1LG5`2059BDP0D05YJFP1<C4`0Cdm?05IFEP23Ph<0Ng]k04i>CP1SHf<0
G5aL065QH@1UIFD0IfMW05QHF00b<S80E5AD04m?C`1BDU80Fe]K04];B`0a<C4204E5A@0R030`<012
@T80>3Ph03/k>`15ADD0De=C02`/;014A4@09RHV0451@@1=CDd0?Cdm0410@01GEeL0De=C0451@@17
AdL0DU9B0410@00h>3P0D51@04e=C@1GEeL0DU9B05QHF01=CDd0KVi^05UIF@1GEeL0D51@06MWI`1`
L700SXj>09ZJVP80HV9R07T0Ogmo06MWI`1kNg/0?clo05IFEP17AdL0FUYJ04I6AP1gMgL0G5aL06EU
I@1cLg<0Ng]k05mOG`22PX80U9BD09:BTP2DU9@0C4a<03Hf=P1>CTh0@d=304a<C01BDU80:b/[06EU
I@17AdL0Jf][0451@@14A4@0@D5104I6AP1XJ6P0EeMG08F5Q@1FEUH0?Cdm04m?C`19BDT0HV9R038b
<P0g=cL0FUYJ03lo?`11@D40GemO02PX:02=SHd0Q8B404I6AP10@400BDU903<c<`1NGUh0>c/k071`
L014A4@0HV9R05QHF00c<c<0@D5104];B`0/;2`0G5aL05=CD`1<C4`0HF5Q02XZ:P0n?Sh0ADE503De
=@0n?Sh0@d=304a<C016ATH0IFEU05iNGP0N7Qh0EeMG03hn?P1CDe<0ADE501hN7P1GEeL0Bd];03Lg
=`1eMGD0EUIF01XJ6P0_;bl09BDU03/k>`0_;bl0@410034a<@1?Cdl0FUYJ07]kN`2:RXX0@T9205]K
F`1]KFd092@T030`<00o?cl0<30`04U9B@1VIVH0@d=305MGE`1FEUH0M7Ad03`l?018B4P0>CTi055A
D@0k>c/0>SXj06i^KP1]KFd0?Shn0080DE5A0180?Shn05iNGP1BDU80S8b<071`L01dM7@0C4a<04Y:
BP1EEED0GemO05YJFP1=CDd0LW9b03lo?`1NGUh0B4Q80820P01SHf<207inOP0^03dm?@1>CTh0Bd];
07EeM@20P800?3`l061PH00a<C40D51@02TY:@2:RXX0A4A405=CD`0o?cl0OGem0451@@1NGUh0MGEe
04U9B@1iNGT0Jf][04M7A`2UYJD0Kfm_04a<C015ADD0>SXj06MWI`1IFET0@T9204];B`0];Bd0AdM7
01dM7@1dM7@0CDe=03/k>`1aLG40FUYJ04];B`1FEUH0Lg=c05QHF01SHf<0PH61075aL@;ooooo0000
3`1aLG40Kfm_0;>c/`1HF5P0AdM704m?C`1HF5P0R8R80<71`@19BDT0?Shn06i^KP1HF5P0MGEe06AT
I00202DU9@0507EeM@1lO7`0DE5A07]kN`15ADD00P18B4P0o`19BDT0?3`l06m_K`2RXZ806QXJ03Ti
>@1lO7`0IVIV034a<@16ATH0BDU903Ti>@0j>SX0OGem06IVIP0m?Cd0GemO01lO7`0a<C40BDU905]K
F`0l?3`0ATI606MWI`0e=CD0<c<c05mOG`19BDT0:BTY03dm?@0e=CD0;bl_04E5A@1QHF408b<S01/K
6`0c<c<0<S8b03Xj>P1gMgL0EUIF01XJ6P14A4@0BDU9071`L019BDT0];Bd02h^;P0O7al0820P03De
=@18B4P0Shn?07UiN@0=3@d08B4Q03`l?01CDe<0D51@08R8R01PH6006QXJ02XZ:P0o?cl0K6a/0410
@01JFUX0B4Q801/K6`0f=SH0CDe=051@D00N7Qh0DU9B03De=@0Z:RX0=CDe06ATI00n?Sh0:RXZ05]K
F`0X:2P0=SHf04M7A`1TI6@06QXJ028R8P0^;Rh0=cLg05iNGP29RHT0@T9202@T900W9bL0?Cdm0451
@@1FEUH0SXj>03@d=00Y:BT0@41003lo?`1@D500CTi>06e]K@0f=SH05ADE05=CD`1GEeL0?3`l04];
B`1eMGD0:2PX034a<@0k>c/0Kfm_04I6AP1>CTh0Lg=c01lO7`0o?cl0GemO069RHP0P8200B4Q806QX
J010@400JFUY07inOP10@4008R8R04m?C`0l?3`0Cdm?06][J`1DE5@06QXJ04m?C`1fMWH0Hf=S0:6Q
X@1QHF407alO04];B`1?Cdl0FEUI05iNGP2JVYX0De=C02DU9@0Y:BT0Jf][07inOP0l?3`0HF5Q03@d
=00Z:RX0<S8b065QH@2;Rh/0?Cdm07UiN@0Y:BT0;bl_03Ti>@1;Bd/0>SXj03`l?01;Bd/07alO03/k
>`1kNg/0NWYj02d];@0b<S80B4Q804e=C@1bLW80Y:BT03lo?`0P8200?clo065QH@1^KVh0Ogmo05EE
E@0E5AD0?3`l04i>CP1<C4`0WYjN08B4Q00I6AT0BDU905ADE019BDT0GUiN09>CT`0a<C409BDU07Ui
N@1`L700?Cdm075aL@0Z:RX0>c/k05=CD`1TI6@09RHV07AdM00b<S80:b/[05IFEP1/K6`0=cLg04a<
C019BDT08R8R05=CD`1jNWX0Lg=c05ADE01dM7@07alO05mOG`2^[Zh0GEeM02PX:00i>CT0<C4a03Lg
=`26QXH0Q8B403@d=00];Bd0@d=305=CD`1XJ6P0Rh^;0451@@0K6a/0=cLg04m?C`1dM7@0K6a/0:6Q
X@1@D500;Rh^04A4A01JFUX0RHV9061PH01kNg/0A4A401lO7`009@0`<300S8b<09bLW01UIFD0W9bL
03Ph>01<C4`0OWin09:BTP19BDT0NGUi09jNWP1>CTh0;Rh^04I6AP1^KVh0C4a<04M7A`1VIVH0@410
03De=@1GEeL0EUIF0492@P17AdL0F5QH024Q8@0e=CD0AdM709BDU01EEED0=cLg05QHF00M7Ad08R8R
05UIF@2][Jd00P0j>SX0gP11@D40DE5A061PH01?Cdl0=cLg05mOG`1FEUH0QXJ606][J`1ADE40M7Ad
07MgM`1PH600>SXj05eMG@2:RXX0LW9b0:n_[`1ZJVX0WIfM06][J`1BDU80VIVI059BDP1CDe<0DE5A
05=CD`0m?Cd0LW9b0451@@1kNg/0B4Q807IfMP0m?Cd0EEEE06=SH`10@400RXZ:06YZJP2BTY80Ph>3
09>CT`23Ph<0SHf=07YjNP1GEeL0B4Q807QhN01?Cdl0Q8B4055AD@15ADD0IfMW03lo?`1EEED0DU9B
030`<01;Bd/0HV9R03Hf=P0b<S80Jf][04a<C01FEUH0LW9b051@D01[Jf/0EEEE06IVIP1<C4`0@D51
05]KF`0k>c/0>3Ph0492@P1ADE40Fe]K07]kN`10@400ATI605EEE@15ADD0MGEe03/k>`15ADD0K6a/
03@d=01FEUH0;bl_02TY:@1TI6@0Bd];02<S8`0[:b/0@41002XZ:P0/;2`0<S8b03dm?@0k>c/0CTi>
034a<@0l?3`05ADE03De=@1JFUX0;bl_03hn?P0[:b/0Fe]K04U9B@1@D500>c/k0492@P17AdL0De=C
0492@P17AdL0B4Q804m?C`1JFUX0F5QH04Q8B01HF5P0EEEE06UYJ@1iNGT0U9BD07emO@1ZJVX0MgMg
06i^KP29RHT0KFe]04U9B@1@D500B4Q8051@D01?Cdl0Jf][04Y:BP1TI6@0Jf][07moO`1[Jf/0UYJF
09BDU02=SHd0W9bL04i>CP19BDT0KVi^05UIF@1[Jf/0=SHf02`/;01CDe<0:b/[06QXJ01=CDd0E5AD
03hn?P0a<C40>CTi04];B`1>CTh0I6AT05YJFP1IFET0GEeM07UiN@1;Bd/0B4Q806=SH`12@T80?Shn
06MWI`0T92@0HF5Q07AdM01NGUh0?Shn04i>CP0Y:BT0Ng]k02TY:@1kNg/0@T9203lo?`19BDT0<C4a
03Ph>015ADD09bLW03Ti>@1:BTX0AdM705MGE`0_;bl0@T9203Lg=`0d=3@0DU9B08F5Q@2<S8`0>c/k
04I6AP0n?Sh07alO03Hf=P12@T80Ng]k05mOG`0Y:BT0Fe]K05UIF@0Z:RX0E5AD03Hf=P0N7Qh0Fe]K
02@T9080<30`05L0EEEE02XZ:P0];Bd0>SXj055AD@1EEED0=SHf04a<C01:BTX0>c/k05eMG@1QHF40
@T9204];B`11@D40<30`05ADE011@D40@T92038b<P10@4008R8R03`l?00m?Cd0;bl_04E5A@12@T80
9RHV06i^KP1>CTh0?Cdm05iNGP0o?cl0HV9R04A4A01SHf<0EUIF04E5A@1<C4`0M7Ad06=SH`1CDe<0
N7Qh0492@P1GEeL0;2`/07inOP1EEED0<S8b04Y:BP12@T80E5AD034a<@1ZJVX0FEUI03Lg=`1]KFd0
>SXj069RHP0f=SH0BDU904];B`1eMGD0D51@0:VYZ@1YJFT0EEEE09JFUP1:BTX0Q8B406e]K@0n?Sh0
CTi>04U9B@1CDe<0DE5A03hn?P1?Cdl0ADE504];B`1eMGD0<30`04];B`0i>CT0EEEE06UYJ@1/K6`0
0P1ZJVX01`1bLW80NWYj09JFUP1ZJVX0Fe]K05MGE`2IVIT00_ooool000120820P01<C4`0GUiN09nO
W`1TI6@0M7Ad03lo?`17AdL0P82008V9R@1>CTh0F5QH02PX:01VIVH0NGUi03lo?`0^;Rh0D51@03De
=@0_;bl0LW9b0:NWY`0b<S80?Cdm04E5A@0c<c<0GUiN0:n_[`1NGUh092@T0492@P0h>3P0IVIV0:RX
Z01EEED06ATI02DU9@0i>CT0BTY:06IVIP2j^[X0@T9201/K6`1HF5P0De=C03/k>`23Ph<0WinO02l_
;`0C4a<0DE5A06][J`0j>SX0MGEe02@T900X:2P0>SXj079bLP1[Jf/0<C4a04I6AP0H61P09RHV04U9
B@1eMGD0:RXZ0P19BDT0HP0L71`0;bl_05QHF01WIfL0=SHf05UIF@0o?cl05aLG051@D02JVYX0>CTi
02@T901@D5007AdM02<S8`1QHF40QXJ601dM7@0J6QX0A4A404Q8B01RHV80O7al06QXJ00C4a<071`L
04I6AP1XJ6P0EEEE08b<S01RHV805ADE020P801XJ6P0De=C0492@P1_Kfl09RHV02<S8`0m?Cd0De=C
04];B`1bLW80Jf][00l?3`0h>3P09bLW05YJFP0n?Sh0De=C03De=@0K6a/0BDU906UYJ@1_Kfl0@T92
04A4A015ADD06QXJ05aLG01aLG40PX:202h^;P0g=cL0@T9203Ti>@17AdL0Ti>C02HV9P0O7al0:b/[
04M7A`0e=CD0MgMg08R8R00O7al0:RXZ04A4A01DE5@0GUiN07=cL`2TY:@07QhN03Lg=`1UIFD0MWIf
05aLG02IVIT0CDe=028R8P1=CDd0K6a/03Hf=P1ZJVX0BDU902HV9P1SHf<0XZ:R0P12@T80H@1TI6@0
:2PX03@d=01hN7P0Ph>303Ti>@16ATH0De=C04U9B@1IFET0MgMg06=SH`0S8b<0>c/k02h^;P1JFUX0
DE5A0;6a/@1RHV809RHV05ADE01:BTX0;2`/06i^KP1jNWX09bLW03Hf=P0`<300I6AT03Ti>@1[Jf/0
GEeM038b<P0m?Cd0BTY:09^KV`1MGEd0Shn?03dm?@0U9BD0DE5A07AdM00X:2P0ADE503/k>`0G5aL0
D51@08V9R@1FEUH0>SXj06ATI00N7Qh0?3`l09FEU@1]KFd08R8R04m?C`0j>SX0<c<c0820P01FEUH0
;bl_05ADE00_;bl0Fe]K0:b/[01ZJVX06a/K03lo?`1PH600Fe]K09:BTP1nOWh08b<S038b<P1>CTh0
EeMG06QXJ01lO7`0;bl_028R8P1FEUH0N7Qh05=CD`1kNg/09RHV03lo?`1@D500Ph>306ATI01bLW80
Fe]K01LG5`1JFUX0F5QH06=SH`0`<3000P1FEUH0500J6QX0EEEE079bLP1YJFT0CDe=0861P@1cLg<0
8b<S05ADE02:RXX0MWIf02`/;013@d<0C4a<03De=@1:BTX0TI6A09RHV00f=SH0A4A40P0_;bl0_@1;
Bd/0R8R8069RHP0[:b/0@D5103Xj>P10@400GUiN08j>SP0e=CD09RHV03<c<`1FEUH0;bl_06e]K@2Q
XJ40=3@d01<C4`0g=cL0GUiN04E5A@27QhL0S8b<03@d=00h>3P0C4a<06i^KP16ATH0G5aL07=cL`1B
DU80Rh^;06=SH`10@400Fe]K05IFEP1YJFT0C4a<03De=@25QHD0WinO06EUI@10@400Cdm?06EUI@2A
TI40L71`06UYJ@23Ph<0F5QH04M7A`1NGUh0GEeM04e=C@12@T80CTi>04A4A01NGUh0DE5A05EEE@1=
CDd0ADE505QHF01]KFd0EEEE051@D01OGel0N7Qh05YJFP1=CDd0GEeM075aL@1kNg/0E5AD04E5A@1:
BTX0Cdm?0451@@1IFET0DE5A05aLG01QHF40ADE505aLG01HF5P0<30`0492@P1aLG40DU9B04i>CP1c
Lg<0<S8b04A4A01BDU80CDe=07MgM`1mOGd0KFe]04m?C`1EEED0OGem05EEE@1?Cdl0Bd];08N7Q`2C
Ti<0Vi^K05MGE`1:BTX0KVi^04Q8B02EUID0BDU9059BDP23Ph<0E5AD051@D00g=cL0B4Q806MWI`1>
CTh0:RXZ03De=@16ATH0=SHf03Lg=`0d=3@0DU9B04a<C01WIfL0:b/[0410@00I6AT0?clo05iNGP0c
<c<0ADE504=3@`1HF5P0Bd];04m?C`18B4P0>SXj04E5A@1@D500DE5A061PH01TI6@0Hf=S04A4A01W
IfL0Bd];04e=C@1?Cdl0EeMG065QH@2;Rh/0MWIf06=SH`26QXH0Fe]K069RHP1FEUH0ADE504a<C015
ADD0DU9B04M7A`1TI6@0Fe]K069RHP1iNGT0YZJV051@D01QHF40Jf][071`L02EUID0HV9R07AdM01j
NWX0?clo05IFEP0f=SH0ADE506=SH`0[:b/0GUiN04e=C@0204A4A01<02l_;`1;Bd/0ADE507UiN@1Q
HF40?Shn04e=C@0[:b/0EUIF06e]K@1NGUh0Hf=S0451@@0m?Cd0EeMG03De=@1iNGT0O7al05IFEP1P
H600N7Qh0451@@1oOgl0@T9206MWI`0o?cl0>3Ph04m?C`0?3`l0?clo05MGE`0A4A40@41005ADE01:
BTX0IfMW01DE5@0`<300?clo038b<P1DE5@0BDU904e=C@0j>SX0Bd];04e=C@12@T80M7Ad04];B`1A
DE40DU9B03Lg=`20P800M7Ad03Lg=`1BDU80?Shn01<C4`0P82008B4Q03dm?@0h>3P0EeMG05IFEP0i
>CT0BTY:09>CT`2d];@0A4A404m?C`1=CDd0:BTY02l_;`0[:b/0<30`05IFEP80@T9200@0H61P05=C
D`1BDU80?3`l0P14A4@04P1EEED0>CTi03`l?01YJFT0J6QX03Xj>P1aLG40Cdm?038b<P1YJFT0>3Ph
079bLP10@400Z:RX06=SH`1CDe<0BDU906YZJP80BTY:03H0FUYJ03lo?`1<C4`0>c/k07inOP0i>CT0
GUiN06YZJP1_Kfl0QHF504a<C01QHF40Bd];01DE5@1BDU80=CDe04m?C`0Z:RX0PX:205=CD`1lO7`0
Cdm?0861P@1GEeL0BDU906MWI`1:BTX0bLW90:^[Z`1MGEd0KFe]05QHF01SHf<0HV9R03De=@1:BTX0
?Cdm03Lg=`1;Bd/0=CDe04a<C00/;2`0IfMW05QHF01IFET0NGUi04U9B@1KFe/0OGem07MgM`1DE5@0
DU9B07inOP1]KFd2ooooo`0002@0T92@055AD@1>CTh0FUYJ06e]K@2NWYh0ADE503Lg=`1lO7`0MGEe
08V9R@25QHD0<C4a0410@01gMgL0G5aL065QH@1nOWh0:b/[03De=@1DE5@0Vi^K05MGE`1cLg<0@d=3
01TI6@0a<C40HV9R07inOP1IFET0JVYZ02DU9@0P8200DU9B09NGU`1ADE4205aLG00U01PH600_;bl0
IfMW071`L00S8b<0IfMW02XZ:P0G5aL0>CTi07MgM`1PH600?Shn05iNGP0Z:RX0>SXj05mOG`1WIfL0
<S8b05MGE`13@d<0Cdm?05mOG`1JFUX08R8R01LG5`0c<c<0@d=303De=@22PX80JVYZ01dM7@0H61P0
;bl_069RHP19BDT0LW9b04e=C@02020P803b02LW9`17AdL0Cdm?09BDU00S8b<061PH0451@@1TI6@0
ADE503dm?@1_Kfl0:b/[01/K6`19BDT0F5QH03Hf=P1CDe<0OGem01LG5`0^;Rh0B4Q805ADE00F5QH0
=3@d04a<C00S8b<0>CTi051@D014A4@05aLG03`l?00_;bl0=SHf05mOG`1jNWX0;bl_02`/;01DE5@0
<c<c04I6AP1jNWX0DE5A010@400M7Ad0?Shn05YJFP1IFET0P82007UiN@0I6AT06a/K04A4A02HV9P0
DU9B0:^[Z`1ZJVX03`l?02@T901[Jf/0Fe]K03`l?01VIVH0<S8b01@D500g=cL0UiNG06MWI`0`<300
GUiN03Ph>00H61P0D51@06][J`13@d<0?clo05MGE`0U9BD0@d=305YJFP1OGel092@T04Q8B014A4@0
C4a<06ATI00l?3`09bLW04=3@`1CDe<0ADE509^KV`2PX:00:2PX03@d=010@400PH6105mOG`2ZZZX0
[Jf]03Ti>@0o?cl0GUiN07YjNP1TI6@0Ogmo08F5Q@0b<S80;Bd]07YjNP2SXj<0FEUI06e]K@0j>SX0
9BDU04U9B@2DU9@0JFUY04Y:BP1kNg/0Bd];02h^;P20P800O7al03De=@0k>c/0?3`l02d];@12@T80
NGUi05QHF00M7Ad0?Shn04a<C017AdL0HV9R0861P@0V9RH0=SHf04Y:BP1HF5P0J6QX0:b/[015ADD0
:2PX06ATI026QXH0@D5108R8R00c<c<0?Cdm05QHF01?Cdl0=3@d08:2PP0W9bL09BDU09ZJVP2][Jd0
<c<c05MGE`0i>CT0=CDe0451@@1XJ6P0:b/[059BDP0f=SH0>SXj05aLG01[Jf/0CTi>059BDP1MGEd0
;bl_04U9B@1JFUX0CTi>038b<P1LG5`0:b/[0451@@1YJFT0R8R803dm?@11@D40EUIF04=3@`1JFUX0
MWIf0:NWY`1CDe<0=3@d051@D00h>3P0<30`09^KV`31`L40GUiN02TY:@1PH600R8R8065QH@1iNGT0
VIVI03Hf=P0k>c/0KVi^0861P@1gMgL0SHf=02h^;P0V9RH0GUiN071`L020P800?Shn05EEE@18B4P0
61PH04I6AP1dM7@0D51@0451@@0h>3P0ADE5034a<@0k>c/0IVIV08b<S00a<C40DE5A030`<00S8b<0
ATI60:ZZZP22PX80=cLg0492@P1FEUH0:2PX06MWI`2IVIT206e]K@1705QHF013@d<0HF5Q079bLP1a
LG40DU9B04I6AP1IFET0Fe]K07emO@1NGUh0LW9b08:2PP1bLW80UYJF08N7Q`29RHT0HV9R04];B`24
Q8@0EUIF06ATI01>CTh0FEUI04a<C01SHf<0@410079bLP14A4@0J6QX03lo?`1@D500Hf=S03Hf=P1m
OGd0FEUI08F5Q@1EEED0TY:B08b<S02JVYX0NWYj05iNGP0n?Sh0Fe]K03Ti>@1ZJVX0?3`l03<c<`1B
DU80@41004];B`15ADD08B4Q03lo?`1NGUh0?Shn03Ph>01EEED0<c<c03Xj>P1]KFd0IVIV05EEE@11
@D40Cdm?061PH01OGel0Bd];03Ph>01EEED00`1:BTX0[01[Jf/0Kfm_04m?C`1^KVh0Jf][07YjNP1m
OGd0MgMg05QHF00`<300E5AD04e=C@1DE5@0Hf=S03hn?P0h>3P0EEEE04E5A@0h>3P0BTY:03@d=00k
>c/0?Cdm05QHF00^;Rh0?3`l028R8P0m?Cd0>c/k02<S8`0_;bl0AdM70451@@0`<300?Shn04E5A@0`
<300ATI605ADE01BDU80FEUI03De=@1LG5`0K6a/06ATI01OGel0Hf=S051@D01`L700VIVI0:b/[02N
WYh0EUIF06QXJ01cLg<0I6AT079bLP1>CTh0EUIF03dm?@1LG5`0@T92079bLP1BDU80Jf][069RHP1a
LG40ADE506MWI`2:RXX0V9RH0:RXZ01YJFT0EEEE061PH01CDe<0H61P03<c<`0Z:RX0>SXj02d];@1F
EUH0BDU9055AD@16ATH0@410055AD@17AdL0Ogmo06EUI@15ADD0FEUI03Ti>@1XJ6P0@41004e=C@1/
K6`0>3Ph04i>CP1PH6005QHF09RHV02VYZH0@41003lo?`1ADE40@d=308F5Q@0o?cl0M7Ad04];B`1<
C4`0D51@02PX:011@D40C4a<02DU9@1?Cdl0H61P03lo?`1=CDd071`L03Ph>00o?cl0A4A405MGE`1H
F5P0IVIV02h^;P1?Cdl0De=C02TY:@0c<c<0BTY:055AD@1FEUH0<c<c04e=C@1:BTX0:RXZ05mOG`1H
F5P09BDU03`l?00T92@0>3Ph02h^;P19BDT0A4A404];B`10@400EEEE06ATI012@T80F5QH05=CD`0H
61P0=SHf04E5A@13@d<0EeMG05QHF01JFUX0EeMG04];B`1YJFT0>3Ph03Lg=`0a<C40CTi>03Hf=P0j
>SX205=CD`0_02TY:@1DE5@0?3`l051@D01NGUh0>3Ph06e]K@0Q8B40I6AT04a<C00j>SX0CDe=08>3
P`1?Cdl0?Cdm06MWI`0[:b/0DE5A034a<@1YJFT0=CDe03@d=00k>c/0<c<c055AD@0a<C40U9BD07=c
L`0H61P0H61P03@d=018B4P0>SXj05YJFP15ADD0H61P07inOP2RXZ80KFe]07EeM@2:RXX0CTi>06m_
K`1JFUX0De=C08F5Q@0c<c<00P1:BTX0300b<S80EEEE03hn?P0k>c/0D51@01HF5P0d=3@07AdM07If
MP18B4P0AdM705QHF080BDU900H0EUIF06=SH`19BDT0F5QH06][J`22PX82ooooo`000P26QXH0D@2^
[Zh0?Cdm05EEE@1FEUH0KFe]07QhN02?Shl0AdM705YJFP1fMWH0DE5A05YJFP1ZJVX0=cLg04=3@`1L
G5`0A4A402LW9`1YJFT0ATI604e=C@1MGEd0DU9B02HV9P0f=SH0?Cdm0451@@12@T80Kfm_028R8P0M
7Ad0?Shn04i>CP1EEED0OGem07AdM00L71`08b<S04Y:BP16ATH0C4a<0:^[Z`0h>3P05ADE01lO7`17
AdL0KFe]05eMG@2UYJD0=3@d03`l?01;Bd/0JVYZ03dm?@2@T900De=C01XJ6P0k>c/0EEEE0451@@17
AdL0JVYZ020P800Y:BT0=CDe071`L00g=cL0Bd];05MGE`0X:2P0;Rh^05QHF01YJFT09bLW05EEE@17
AdL0:2PX034a<@1bLW80K6a/02PX:00203Xj>P2503dm?@16ATH0WIfM05EEE@0I6AT0D51@02l_;`16
ATH0DE5A09VIV@0c<c<071`L04];B`18B4P0<S8b05aLG01cLg<07AdM02DU9@12@T80FUYJ03`l?01f
MWH0=CDe01LG5`0l?3`0ADE502d];@16ATH0IVIV01hN7P0[:b/0GEeM08>3P`1@D500>c/k065QH@0U
9BD0@T92075aL@2?Shl0Jf][0410@01<C4`0:b/[03`l?01TI6@0IfMW01`L700Q8B40@T9204U9B@16
ATH0PX:204a<C00C4a<061PH059BDP15ADD0E5AD0::RXP11@D403Ph>02`/;01RHV80D51@06YZJP2:
RXX06a/K02h^;P10@400H61P03De=@1[Jf/0BDU9038b<P1`L700[Zj^051@D02;Rh/0Lg=c02HV9P0e
=CD0Rh^;05=CD`0i>CT0GemO03Ti>@0O7al0A4A406UYJ@1OGel0<S8b05eMG@0b<S80<C4a07inOP1k
Ng/0?3`l03lo?`1>CTh0;bl_04A4A02OWil0LG5a02XZ:P13@d<0AdM706=SH`1lO7`0W9bL03dm?@0_
;bl0EUIF04m?C`1JFUX0QhN709RHV00L71`0<30`06][J`1EEED0IFEU08J6QP13@d<07AdM05aLG020
P800Cdm?055AD@1EEED07AdM04];B`0207]kN`3o05iNGP1XJ6P0=3@d02d];@1YJFT0Kfm_03@d=01L
G5`0?clo04];B`1iNGT0BDU902LW9`1SHf<0GemO05=CD`28R8P0LW9b02DU9@14A4@0ATI603`l?01b
LW80GEeM01PH6017AdL0EEEE04A4A01bLW80Xj>S024Q8@0n?Sh0Ng]k06QXJ01DE5@0W9bL03lo?`0Y
:BT0Bd];0861P@1:BTX0JVYZ071`L00W9bL0;bl_051@D01eMGD0Fe]K04e=C@1CDe<0=3@d02TY:@14
A4@0LG5a07=cL`16ATH0HF5Q0410@00d=3@0A4A406IVIP1cLg<0I6AT09:BTP0h>3P0>CTi06YZJP2>
SXh0<30`03@d=01^KVh0FEUI0492@P2JVYX0Ph>303Ph>00Q8B40@d=3030`<01KFe/0H61P06QXJ00M
7Ad0>c/k04=3@`1_Kfl0De=C0:>SX`1PH6006QXJ034a<@1BDU80BDU903hn?P1XJ6P0BDU903Hf=P10
@400CDe=04i>CP1GEeL0ADE50492@P1HF5P0B4Q8096AT@1fMWH0BDU907MgM`1bLW80Lg=c04U9B@1/
K6`0Rh^;08:2PP2c/k<0K6a/09bLW01bLW80C4a<0:FUY@1TI6@0IVIV04Y:BP1cLg<0BDU907=cL`1A
DE40JVYZ04=3@`1BDU80BTY:05QHF01/K6`0BDU908R8R01OGel0O7al07emO@2QXJ40PX:20:b/[022
PX80FEUI03/k>`1QHF40AdM707YjNP14A4@0@41006][J`11@D40DU9B04I6AP0R8R80C4a<06m_K`1<
C4`0@D510861P@0f=SH0A4A407MgM`1<C4`0J6QX059BDP1LG5`0ADE504=3@`1FEUH0=SHf04E5A@11
@D40CTi>05mOG`2CTi<0AdM704a<C01KFe/0A4A406a/K00c<c<0@T92065QH@0i>CT0EUIF03/k>`0g
=cL0Kfm_04M7A`0o?cl0?3`l04I6AP0e=CD0:BTY0410@00j>SX0?Shn055AD@11@D40@d=301dM7@0k
>c/0GEeM02`/;015ADD0<30`05aLG00h>3P0ATI602l_;`0h>3P0ATI605QHF00/;2`0DU9B04A4A01?
Cdl0@410059BDP0j>SX0@D5106QXJ01OGel0Hf=S08:2PP1bLW80OGem08b<S01[Jf/0Ph>305aLG01d
M7@0IFEU04e=C@1UIFD0GUiN061PH01gMgL0HF5Q08f=S@2NWYh0JVYZ07IfMP1jNWX0LW9b08F5Q@10
@400Bd];04U9B@0];Bd0@T92034a<@0[:b/0KFe]001L04=3@`1QHF40De=C05QHF011@D40FEUI075a
L@1GEeL0IfMW05=CD`12@T80DU9B061PH01RHV80BDU904Y:BP1FEUH0D51@08:2PP1jNWX0410@069R
HP1nOWh0?Shn06QXJ01^KVh0=CDe06][J`0Z:RX0RXZ:03`l?01ADE40HV9R03@d=01DE5@0Fe]K03Hf
=P1ADE40FUYJ03dm?@1=CDd0:BTY0492@P0_;bl0<S8b05IFEP1MGEd0G5aL04U9B@1SHf<0D51@00h>
3P0d=3@0ATI6075aL@1QHF40<30`07moO`1cLg<09bLW05QHF01:BTX08R8R04=3@`0d=3@0?Shn04I6
AP22PX80Fe]K03dm?@0o?cl0GemO06a/K00h>3P0LG5a06][J`0i>CT0Hf=S06MWI`0Z:RX0B4Q803De
=@1@D500AdM704];B`1<C4`0@D5103De=@16ATH0Fe]K03Ti>@1;Bd/205]KF`0Q02`/;01TI6@0;bl_
04M7A`1eMGD0A4A407UiN@18B4P0/;2`07IfMP1ADE40<30`07AdM01BDU80EEEE071`L010@400NWYj
02/[:`1WIfL0=SHf03Ti>@1CDe<0I6AT079bLP0g=cL0FUYJ059BDP0S8b<0GemO03dm?@1GEeL0HV9R
00<0JFUY01X0H61P08>3P`1UIFD0C4a<07MgM`10@400QhN706EUI@0m?Cd0IFEU02l_;`1VIVH0EEEE
020P800k>c/0=SHf05UIF@1aLG40820P02l_;`0c<c<0MWIf05eMG@1jNWX0J6QX05EEE@80HV9R00D0
GemO05=CD`1;Bd/0J6QX08F5Q@02ooooo`0000T0Ogmo05mOG`2NWYh0GUiN04];B`1HF5P0?3`l06][
J`2d];@00P1DE5@0o`1WIfL0?clo06IVIP2BTY80=CDe03Lg=`1MGEd0FUYJ04M7A`2[Zj/0TY:B020P
8017AdL0Hf=S04];B`2RXZ80YJFU020P800m?Cd0MWIf08B4Q01QHF40Ti>C04I6AP0^;Rh0BTY:07=c
L`0m?Cd0Kfm_07]kN`0Q8B409RHV05]KF`1nOWh08B4Q03lo?`0k>c/0;Rh^02d];@1NGUh0HV9R03Xj
>P16ATH06QXJ02l_;`1DE5@0OWin03Lg=`1:BTX0DU9B03<c<`0g=cL0Q8B404i>CP0R8R80=3@d03/k
>`1GEeL0N7Qh08>3P`0K6a/06ATI03lo?`10@400@D5106m_K`2BTY8061PH03@d=00f=SH0Lg=c05EE
E@1nOWh0QHF501@D500Q8B40D51@09JFUP18B4P0^[Zj04A4A00H61P0C4a<04i>CP1^KVh0;2`/09^K
V`0];Bd05QHF04=3@`20P800BTY:02TY:@1CDe<09BDU03dm?@1]KFd0HF5Q030`<00e=CD0Bd];02PX
:01MGEd0KFe]03<c<`0M7Ad0=CDe03hn?P0a<C40Rh^;0:n_[`0Q8B40;Bd]03Ti>@1KFe/0?clo06UY
J@2KVi/08b<S01hN7P0m?Cd0Lg=c04Q8B01NGUh0UIFE02<S8`0[:b/0CTi>06EUI@19BDT0EEEE05UI
F@0Z:RX0<c<c07IfMP22PX80<C4a05QHF01WIfL09RHV04Y:BP1gMgL0ATI602/[:`1CDe<092@T03Lg
=`1FEUH0D51@020P801HF5P0DU9B03@d=02<S8`0RXZ:02LW9`0[:b/0J6QX06ATI01UIFD0ZJVY05IF
EP0U9BD0=cLg06EUI@1/K6`0LG5a0820P00n?Sh07alO02h^;P1UIFD0C4a<055AD@1iNGT07alO01`L
7015ADD0Y:BT0410@01EEED0F5QH01lO7`0i>CT0FEUI05aLG00_;bl0GEeM04=3@`0a<C40@D5107al
O01=CDd0>3Ph06UYJ@0X:2P0<S8b07UiN@2KVi/0:BTY03Hf=P15ADD0F5QH07AdM02IVIT0?clo02XZ
:P19BDT0@D5107UiN@3;bl/0AdM702TY:@1<C4`0B4Q805MGE`2EUID0@410034a<@1BDU80J6QX04e=
C@2VYZH0GUiN02h^;P1RHV80K6a/06MWI`1nOWh0@d=3038b<P1[Jf/0F5QH03lo?`1PH600GEeM02h^
;P1FEUH0PH6106i^KP0m?Cd0De=C028R8P11@D40I6AT07AdM00a<C40E5AD03Lg=`0n?Sh0G5aL06YZ
JP17AdL0:BTY04M7A`008010@400:RXZ05mOG`2<S8`0C4a<02<S8`0/;2`0@d=305IFEP1GEeL0P820
05IFEP0R8R80;Rh^038b<P1>CTh0JVYZ0<c<c015ADD0=3@d04A4A01hN7P0Hf=S07QhN02JVYX0@D51
0492@P1TI6@0QHF5059BDP1hN7P0MWIf0P0Y:BT09P1XJ6P0OGem03hn?P19BDT0E5AD01dM7@0a<C40
EEEE09bLW01DE5@0>3Ph030`<00X:2P0=CDe04m?C`1cLg<08b<S03Ti>@0g=cL0EeMG07moO`1KFe/0
>CTi05iNGP18B4P0IFEU05eMG@1ADE40QXJ608f=S@2e]KD0EeMG07IfMP2BTY80PH610;>c/`1dM7@0
Shn?0P1lO7`00`1^KVh0De=C05mOG`0205IFEP1R04Y:BP1CDe<0Fe]K05eMG@15ADD0B4Q806QXJ01c
Lg<0EUIF04=3@`1OGel0K6a/069RHP1_Kfl0K6a/07emO@27QhL0J6QX04U9B@18B4P0EEEE04e=C@1R
HV80Cdm?05iNGP1KFe/0@41004];B`16ATH06a/K03/k>`1GEeL0C4a<04Q8B01ZJVX0ATI605=CD`1b
LW80DU9B07EeM@1ZJVX0Lg=c05MGE`1VIVH0LW9b055AD@1=CDd0ATI6061PH01XJ6P0YjNW05=CD`0c
<c<0Lg=c04M7A`24Q8@0AdM705IFEP1cLg<0F5QH05MGE`0m?Cd0?3`l06IVIP1@D5009bLW03Lg=`19
BDT0?Cdm03@d=00e=CD0ATI60492@P1FEUH0<30`04I6AP0/;2`0@410069RHP0i>CT0C4a<0410@01P
H600?clo04a<C014A4@0FEUI04A4A01YJFT0ADE5061PH019BDT0Jf][04a<C01bLW80ADE505eMG@17
AdL204e=C@1M05YJFP1aLG40ADE505mOG`1YJFT0L71`069RHP1FEUH0FEUI0451@@1CDe<0?Shn05EE
E@16ATH0C4a<07IfMP1iNGT0@D5106QXJ01iNGT0YJFU0:b/[00i>CT0Fe]K055AD@0`<300FUYJ02h^
;P16ATH0De=C04I6AP1FEUH0ATI6059BDP17AdL0?clo04E5A@0n?Sh0N7Qh065QH@1NGUh0EEEE02/[
:`1PH600Cdm?05=CD`1IFET0=cLg03Hf=P1<C4`08B4Q071`L023Ph<0CTi>03<c<`1<C4`09bLW07If
MP0X:2P0H61P02d];@0g=cL0D51@020P800e=CD0@d=301@D500j>SX0E5AD04=3@`1IFET092@T034a
<@17AdL0BTY:059BDP1RHV80IfMW03lo?`1BDU80E5AD03@d=01?Cdl0Bd];04Q8B01FEUH0<C4a07Ad
M01NGUh0;Bd]075aL@1OGel07alO0080?Shn05L0CTi>02HV9P1FEUH0>CTi03@d=00h>3P0R8R80;Rh
^00k>c/0EeMG04m?C`0N7Qh0?Cdm04I6AP13@d<0I6AT05iNGP14A4@0EUIF05MGE`1<C4`0ATI605EE
E@17AdL0EUIF04=3@`1KFe/0HF5Q05MGE`0a<C40Ogmo059BDP0i>CT0Fe]K02h^;P1GEeL09bLW06YZ
JP1UIFD0AdM703De=@1RHV80B4Q8069RHP1IFET0=CDe04Y:BP0h>3P0Jf][04Q8B00];Bd0?3`l03/k
>`1FEUH0C4a<06MWI`1TI6@08B4Q05MGE`0k>c/0Hf=S0451@@1OGel0EeMG07UiN@1VIVH0SXj>079b
LP1HF5P0N7Qh06m_K`2d];@0OWin0451@@1HF5P0=CDe05mOG`1JFUX0?Cdm04M7A`1<C4`0?clo04i>
CP1=CDd0EUIF0451@@1`L7000P1CDe<02@1BDU80D51@061PH00k>c/0@d=305MGE`1DE5@0LW9b07al
O002ooooo`000<<0Z:RX04m?C`1OGel0Lg=c08F5Q@2GUiL0Bd];04e=C@27QhL0VYZJ08V9R@1RHV80
<S8b03hn?P1aLG40E5AD05mOG`1[Jf/0:2PX030`<01>CTh0Ph>304Q8B01GEeL0?clo02/[:`0h>3P0
GEeM0820P015ADD0Jf][02DU9@0i>CT0ATI605=CD`0R8R80JVYZ05aLG00i>CT0IfMW06a/K00e=CD0
;Rh^06EUI@0d=3@0CTi>09nOW`26QXH0:2PX0410@01HF5P0?3`l05mOG`2SXj<0<C4a02PX:01;Bd/0
FUYJ0451@@2;Rh/0QhN701PH6012@T80B4Q8055AD@1DE5@0VYZJ04E5A@0Q8B40?3`l04i>CP0`<300
?Cdm06YZJP0Z:RX08b<S03dm?@1DE5@0DE5A02LW9`1lO7`07alO02d];@1CDe<0J6QX020P800];Bd0
BDU902@T900g=cL0EeMG06UYJ@0F5QH09BDU04=3@`0g=cL0A4A40820P02=SHd03Ph>01/K6`1LG5`0
GEeM04M7A`1ZJVX0:b/[01/K6`1BDU80QXJ6059BDP1UIFD0GUiN02HV9P0U9BD0EEEE05]KF`0];Bd0
HF5Q02d];@0U9BD0<C4a06YZJP1kNg/0>CTi05eMG@0`<3007alO02/[:`1KFe/0MGEe034a<@1BDU80
;Bd]020P800R8R80IVIV04i>CP0R8R80?clo03Ti>@0G5aL0HF5Q08j>SP0`<300:2PX05EEE@1?Cdl0
HV9R07UiN@2>SXh08b<S034a<@29RHT0E5AD05mOG`2a/K40I6AT00d=3@1NGUh0L71`05=CD`2WYjL0
:b/[03dm?@1YJFT0QXJ606EUI@1WIfL0LG5a01TI6@11@D40J6QX0:b/[014A4@0FUYJ05EEE@0H61P0
CTi>05]KF`1XJ6P0;bl_03Ti>@0^;Rh0=CDe07EeM@1lO7`0@T9201TI6@0];Bd0B4Q804e=C@1HF5P0
IVIV01dM7@0g=cL00`1<C4`0;02GUiL0GEeM02<S8`19BDT0E5AD0492@P1]KFd0Xj>S02HV9P0U9BD0
Fe]K08^;R`1BDU80EEEE04Q8B00N7Qh0@D5107IfMP1@D500CTi>06IVIP0T92@0:RXZ07]kN`2>SXh0
?3`l07]kN`0h>3P07alO05mOG`1[Jf/0<30`065QH@0G5aL0@41005MGE`1OGel0;2`/05YJFP0e=CD0
?Shn09NGU`23Ph<0@4100P1KFe/0WP0g=cL0UiNG09ZJVP0a<C40A4A405=CD`1>CTh0EeMG09RHV01H
F5P0:b/[055AD@1CDe<0Fe]K09>CT`1dM7@06a/K06a/K029RHT0QXJ605YJFP2>SXh0UiNG01lO7`0l
?3`0GemO08V9R@1BDU80PX:208j>SP0R8R80<S8b04i>CP1XJ6P0B4Q805YJFP1GEeL0<c<c04E5A@1/
K6`0V9RH04a<C01aLG40;Rh^038b<P0h>3P0K6a/09NGU`0l?3`0A4A405UIF@0X:2P0>3Ph07MgM`1j
NWX0?Shn03De=@0o?cl0@41004I6AP2@T900>c/k02PX:00m?Cd0F5QH075aL@29RHT0M7Ad01`L7017
AdL0LW9b06][J`1:BTX0MWIf08>3P`1HF5P0Fe]K05mOG`1FEUH0F5QH04];B`2HV9P0Lg=c05MGE`2b
/[80d];B0;Jf]P1BDU80GemO0861P@2ZZZX0Ph>305=CD`26QXH0J6QX04Q8B02KVi/0DU9B07MgM`19
BDT0IfMW05]KF`1kNg/0HF5Q08:2PP13@d<0Hf=S0451@@1YJFT0N7Qh0451@@1gMgL0ATI60861P@22
PX80Shn?08V9R@25QHD0MWIf05QHF00h>3P0Fe]K04A4A01NGUh0>SXj02d];@1HF5P0@d=304a<C00o
?cl0<30`04I6AP1=CDd0De=C04M7A`1ADE40=CDe03`l?01LG5`0FUYJ05IFEP1ADE40F5QH079bLP1X
J6P0DE5A03hn?P1CDe<0ADE505MGE`1>CTh0K6a/065QH@15ADD0LG5a05]KF`1^KVh0GUiN0P1TI6@0
D`12@T80G5aL04M7A`1DE5@0RHV905=CD`0`<300>SXj04Q8B012@T80;Bd]028R8P0n?Sh0>c/k04A4
A00J6QX0@D5101DE5@0[:b/0Cdm?030`<010@400<c<c04i>CP11@D40CDe=038b<P12@T80@D5105UI
F@11@D40FUYJ05=CD`1QHF40BTY:07IfMP1>CTh0HV9R04];B`1DE5@0AdM704m?C`2HV9P0I6AT06QX
J02:RXX0Ng]k07QhN01VIVH0LG5a04=3@`1SHf<0ADE506=SH`1GEeL0Lg=c07moO`2GUiL0@d=306EU
I@1`L700GemO07MgM`19BDT0IVIV079bLP0k>c/0R8R801dM7@0S8b<0Jf][05mOG`1mOGd0@41004Q8
B01>CTh0=SHf04M7A`16ATH0X:2P06EUI@0c<c<0De=C0080G5aL09D0?Cdm05YJFP1]KFd0ADE503/k
>`1LG5`0=cLg08j>SP2VYZH0Fe]K04];B`1RHV80ADE508n?S`0f=SH0NWYj030`<010@400Cdm?02DU
9@0m?Cd0Bd];01hN7P0_;bl0DU9B04];B`1NGUh07alO034a<@0^;Rh08B4Q03`l?019BDT0De=C04A4
A01]KFd0EEEE024Q8@0k>c/0BTY:07inOP1SHf<0=3@d05]KF`18B4P08B4Q04];B`1BDU809bLW04E5
A@0c<c<0?clo03hn?P1SHf<0@d=304a<C011@D40GemO07QhN01FEUH0XJ6Q08>3P`0h>3P0B4Q803Hf
=P0i>CT0AdM703hn?P0i>CT0?Shn0410@015ADD0<c<c04=3@`0_;bl0BTY:02d];@0l?3`0D51@04i>
CP0a<C40J6QX03<c<`0l?3`0G5aL03hn?P1VIVH0?3`l06m_K`1hN7P0Jf][06IVIP1JFUX0JFUY06MW
I`2:RXX0HV9R06e]K@12@T80KVi^04e=C@1QHF40FEUI03Ph>01EEED0<C4a06i^KP20P800De=C05mO
G`1?Cdl0E5AD03hn?P1QHF40K6a/06IVIP1?Cdl0QHF505EEE@22PX80YZJV05IFEP1fMWH0DE5A069R
HP2?Shl0Cdm?05=CD`1BDU80?clo06UYJ@0m?Cd0B4Q804I6AP0Z:RX0<c<c038b<P1aLG40D51@065Q
H@1cLg<0M7Ad06QXJ01JFUX0FEUI06m_K`24Q8@0Lg=c09:BTP02ooooo`000240HF5Q05EEE@1aLG40
A4A404];B`1ZJVX0CTi>04E5A@1mOGd0@41007alO02GUiL0=CDe03Lg=`1eMGD0<c<c06QXJ02ZZZX0
ADE503Xj>P1DE5@0GemO05YJFP2ATI40M7Ad02HV9P0k>c/0?Shn06e]K@1cLg<0UIFE01lO7`0i>CT0
0P1FEUH0o`19BDT0WinO09NGU`0A4A40=CDe06ATI01:BTX0DE5A08b<S01HF5P07AdM04U9B@27QhL0
A4A4055AD@1YJFT09bLW030`<01GEeL0LG5a04M7A`1]KFd0<c<c030`<00f=SH0IFEU04A4A00U9BD0
H61P02d];@12@T80DU9B065QH@0O7al0<30`05ADE013@d<0@D51096AT@19BDT06a/K03Xj>P0c<c<0
CTi>05ADE02i^KT0=CDe01XJ6P0];Bd0JFUY04m?C`1KFe/0SXj>02TY:@0K6a/0D51@07inOP0j>SX0
FEUI07emO@0U9BD08b<S059BDP1TI6@09bLW04I6AP1mOGd08R8R03@d=01FEUH0E5AD03Ti>@18B4P0
?Cdm01dM7@1mOGd0[Jf]04=3@`11@D40Cdm?03`l?00f=SH0MGEe06UYJ@0H61P0;Rh^04];B`0i>CT0
FUYJ0:j^[P1gMgL07QhN02XZ:P17AdL0Bd];05YJFP2UYJD0KVi^01dM7@0g=cL0>c/k07moO`1HF5P0
Shn?061PH00I6AT06QXJ05IFEP1SHf<0=cLg07UiN@0P82008b<S05EEE@1/K6`0CTi>0492@P1ZJVX0
<c<c03De=@1mOGd0ZJVY02l_;`0l?3`0A4A403Ti>@25QHD0OGem01lO7`1ADE40GemO03Ph>01SHf<0
Zj^[03Lg=`0P8200@T9207=cL`1:BTX0Ogmo09fMW@0U9BD0<c<c04m?C`22PX80Cdm?07EeM@1OGel0
4a<C04];B`1cLg<0NGUi04=3@`2OWil0>SXj01`L701LG5`0O7al03Ph>017AdL0Lg=c02l_;`0i>CT0
UIFE09>CT`0n?Sh0HV9R04m?C`0Z:RX0<S8b09bLW01FEUH07alO03Ph>00l?3`0:BTY07=cL`1]KFd0
>SXj03`l?00h>3P08b<S07UiN@2n_[h0=SHf02d];@19BDT0E5AD0410@02i^KT0DE5A01`L701:BTX0
DU9B05ADE02KVi/092@T01/K6`13@d<0FEUI04M7A`2IVIT0;Rh^04A4A01TI6@0J6QX04e=C@1TI6@0
ATI602TY:@1DE5@0RHV904Y:BP1lO7`0M7Ad03Ph>01NGUh0GEeM06QXJ00o?cl0M7Ad03@d=017AdL0
N7Qh07YjNP0b<S80BTY:05EEE@0Q8B40@d=305eMG@2>SXh0GEeM03Ti>@1KFe/0<C4a05ADE01QHF40
M7Ad04m?C`0T92@0Jf][04=3@`17AdL0GemO08N7Q`0f=SH0BTY:055AD@1BDU80GUiN09RHV01`L700
9RHV04A4A000O01MGEd0UYJF07AdM01oOgl0N7Qh024Q8@0[:b/0A4A405IFEP1LG5`0Lg=c03/k>`0L
71`0;bl_04i>CP1jNWX0=3@d07=cL`1HF5P08b<S04=3@`1ZJVX0@41002h^;P1FEUH0<C4a02XZ:P0h
>3P0MWIf08F5Q@1=CDd0ADE5055AD@29RHT0TI6A08^;R`1hN7P0I6AT05aLG01_Kfl0M7Ad04i>CP1O
Gel0Jf][05=CD`2c/k<0R8R80:n_[`1dM7@0C4a<07EeM@17AdL0N7Qh05YJFP1PH600@d=307IfMP1P
H600KVi^04e=C@1fMWH0HV9R05]KF`2BTY80BTY:09fMW@1FEUH0Ti>C08>3P`2QXJ40/k>c0<_;b`29
RHT0LW9b04a<C027QhL0DU9B0820P01MGEd0Cdm?07UiN@1KFe/0G5aL04a<C00[:b/0EUIF06m_K`1A
DE40<30`06][J`0n?Sh0AdM705eMG@0b<S80FUYJ061PH01MGEd0Bd];03hn?P1;Bd/0@D5103`l?00`
<300ADE504e=C@1dM7@0B4Q804a<C01@D500@T9205EEE@0g=cL0?Cdm04a<C015ADD0C4a<04E5A@0d
=3@0EeMG065QH@0i>CT0BTY:05MGE`0g=cL203dm?@3N03Hf=P0h>3P0BTY:03lo?`1<C4`0<30`03Xj
>P1ADE40<c<c03Xj>P0m?Cd0Bd];04E5A@10@400:b/[04M7A`1:BTX0D51@04m?C`14A4@0?clo051@
D01XJ6P0HF5Q04M7A`1MGEd0G5aL03hn?P1IFET0PX:209jNWP1ZJVX0G5aL08N7Q`2>SXh0O7al069R
HP1XJ6P0Bd];05ADE00l?3`0Cdm?04];B`1QHF40QHF509RHV01ADE40QhN709>CT`1jNWX0WinO04m?
C`1;Bd/0CDe=01/K6`0n?Sh06a/K02/[:`1ZJVX0=cLg05MGE`14A4@0BTY:03dm?@1FEUH0GEeM04m?
C`1ADE40CTi>03Ph>01=CDd0;bl_05UIF@0n?Sh0@41004M7A`0d=3@0?clo04Y:BP0M7Ad0DE5A06QX
J00n?Sh0Fe]K069RHP0/;2`0GemO04=3@`2:RXX0=cLg04e=C@1LG5`08B4Q0410@019BDT0:BTY04m?
C`1DE5@0Bd];05QHF00f=SH0Bd];038b<P0^;Rh0@d=306=SH`1FEUH09BDU03Xj>P18B4P0410@02TY
:@0/;2`0@41004e=C@0T92@0XJ6Q05iNGP0R8R80Kfm_05EEE@0L71`0FEUI034a<@0o?cl0?3`l06AT
I01@D500@41003dm?@1/K6`0OGem038b<P1>CTh0Cdm?01dM7@1bLW80De=C02TY:@18B4P0H61P059B
DP1?Cdl0EeMG061PH016ATH0DU9B04=3@`1JFUX0?Cdm03lo?`1MGEd0AdM703@d=01[Jf/0;Bd]02`/
;01;Bd/0ADE508V9R@18B4P0JFUY05YJFP1SHf<0;bl_07QhN01^KVh0EeMG071`L013@d<0LG5a04=3
@`2PX:00KFe]03Lg=`11@D40Bd];05]KF`1:BTX0R8R808:2PP14A4@0De=C03De=@1ADE40D51@0861
P@1:BTX0Lg=c05eMG@27QhL0EEEE04I6AP1KFe/0@d=307QhN00b<S80@d=305ADE00/;2`0WIfM06i^
KP0i>CT0BDU904E5A@1ADE40G5aL05YJFP1FEUH0;bl_051@D01SHf<0F5QH055AD@1gMgL0Jf][04I6
AP17AdL0LW9b06m_K`24Q8@0/k>c0_ooool0001n06EUI@1[Jf/0b<S804i>CP1CDe<0KVi^071`L022
PX80TY:B05MGE`1CDe<0TI6A065QH@2ATI40][Jf02XZ:P16ATH0Cdm?03Hf=P1QHF40/[:b038b<P0_
;bl0<C4a079bLP1?Cdl0K6a/07=cL`0Q8B40C4a<09JFUP1^KVh0@D5107inOP0k>c/092@T0820P02O
Wil0?3`l03<c<`0f=SH092@T03lo?`26QXH0D51@01TI6@0Y:BT0>c/k04I6AP2BTY80]kNg030`<00e
=CD0Bd];03`l?01LG5`0XZ:R04Y:BP0R8R80=CDe02`/;01YJFT0JVYZ08b<S00M7Ad0=cLg04I6AP18
B4P0>CTi06][J`1JFUX08B4Q04A4A00n?Sh0@41004a<C021PH40Kfm_018B4P0o?cl0EeMG04Y:BP1A
DE40FUYJ03`l?00P8200ATI605eMG@1<C4`0BTY:069RHP0/;2`0>3Ph04E5A@1cLg<0;Bd]02TY:@11
@D40;bl_02<S8`0h>3P0RXZ:03`l?00I6AT0>SXj03@d=01EEED0P82003Hf=P0I6AT071`L04Q8B00o
?cl0G5aL08:2PP0J6QX0CDe=04];B`1gMgL0<C4a071`L02JVYX06ATI020P801UIFD0ZZZZ0P19BDT0
A`1eMGD08b<S030`<01SHf<0Ph>302HV9P1:BTX0EEEE02XZ:P0T92@0EEEE07alO00M7Ad0:b/[03Xj
>P0c<c<0?3`l0820P01:BTX05aLG03lo?`1=CDd0@T9205=CD`1jNWX0<C4a024Q8@1ADE40PX:204e=
C@1lO7`0BDU904I6AP1EEED0FEUI04E5A@2PX:00@D51030`<01:BTX0Cdm?07EeM@1JFUX0R8R80451
@@0Z:RX0<c<c06=SH`1VIVH0EeMG07MgM`0o?cl0>c/k04e=C@1/K6`0BTY:03Ti>@1/K6`0;2`/02XZ
:P1TI6@0P820034a<@0g=cL0E5AD03Ph>01PH600Vi^K03Ph>00P8200@T920080AdM700@0MGEe0:JV
YP0m?Cd0?Cdm0P1CDe<0601QHF40NWYj01`L700M7Ad0;Bd]0861P@1QHF40NWYj05iNGP0V9RH0>3Ph
055AD@1[Jf/0De=C05mOG`0Y:BT08B4Q079bLP23Ph<0@T9205YJFP0Y:BT0?Cdm04i>CP80@D5104H0
JFUY03De=@0m?Cd0PX:205=CD`0O7al0AdM7034a<@19BDT0P82006a/K00K6a/0ADE50451@@0k>c/0
JFUY08n?S`0X:2P0<30`05MGE`1:BTX0De=C0:NWY`1OGel0:b/[05]KF`1FEUH0?3`l08Z:RP2MWId0
<C4a02DU9@1GEeL0S8b<06QXJ01ADE40Ng]k02HV9P0];Bd0A4A409VIV@2j^[X0IVIV09jNWP12@T80
;2`/05aLG02>SXh0CTi>06UYJ@1NGUh06QXJ04E5A@1EEED0Lg=c04A4A01LG5`0MWIf01HF5P0f=SH0
HV9R06QXJ00f=SH0=cLg05QHF00R8R80;bl_07emO@29RHT09RHV0P0e=CD0;P1HF5P0DU9B07emO@1B
DU807alO03Hf=P0l?3`0F5QH055AD@2?Shl0ATI602XZ:P0k>c/0C4a<04Y:BP1KFe/0GemO03@d=012
@T80>c/k06=SH`1JFUX0DE5A07UiN@2NWYh0QXJ605iNGP1^KVh0T92@07IfMP2QXJ40EUIF09fMW@2@
T900Jf][08V9R@14A4@0IfMW05IFEP1/K6`0BTY:07EeM@1`L700OGem0492@P1JFUX2055AD@2807=c
L`18B4P0I6AT07moO`1cLg<0Hf=S07YjNP2;Rh/0U9BD06UYJ@1<C4`0EEEE05YJFP17AdL0FEUI05EE
E@16ATH0I6AT04A4A01ZJVX0BDU902/[:`0i>CT0EeMG055AD@0m?Cd0I6AT04U9B@1BDU80IfMW04a<
C01_Kfl0IfMW06UYJ@1RHV80GUiN071`L010@400DU9B05ADE01CDe<0FUYJ0:n_[`1OGel0GUiN08B4
Q01:BTX0V9RH04A4A01<C4`0JVYZ04Q8B01FEUH0Cdm?03Ti>@1NGUh0?clo02d];@0Y:BT0?3`l03hn
?P0V9RH0:BTY04a<C014A4@0CDe=02LW9`1GEeL08b<S03Ti>@1FEUH0>CTi03`l?00k>c/0CTi>04=3
@`1<C4`0>CTi04m?C`1CDe<0GEeM038b<P1>CTh0>c/k04Q8B00j>SX0HF5Q03hn?P15ADD0BTY:03`l
?01:BTX0ADE5069RHP20P800MWIf061PH01LG5`0Cdm?055AD@14A4@0?Cdm05eMG@1@D500EeMG04M7
A`1RHV80UIFE09>CT`1UIFD0IVIV07EeM@1YJFT0SXj>05iNGP2RXZ80MgMg034a<@1DE5@0;Rh^02/[
:`1oOgl0CTi>05MGE`1NGUh0DU9B03`l?01;Bd/0@d=304A4A01QHF40GUiN05=CD`1RHV80@41007Ee
M@80AdM701@0GemO02TY:@0c<c<0K6a/024Q8@1`L700Ph>304i>CP0^;Rh0De=C03/k>`1UIFD0@D51
04e=C@0Y:BT0;bl_03`l?00Y:BT0D51@04i>CP80=cLg07L0E5AD05EEE@1VIVH09bLW02l_;`12@T80
@d=304];B`1RHV80M7Ad03/k>`1>CTh0EeMG028R8P1>CTh0@D5104a<C015ADD08B4Q04i>CP0_;bl0
=SHf0;Bd]020P8007alO038b<P0n?Sh0NWYj04M7A`1lO7`0C4a<05eMG@0n?Sh0N7Qh09>CT`0c<c<0
S8b<07alO00R8R80=cLg04=3@`16ATH0GEeM04E5A@0i>CT0FEUI05EEE@0f=SH0>3Ph05EEE@0c<c<0
?clo04Y:BP19BDT0DU9B0492@P0c<c<0UYJF05eMG@1;Bd/0MGEe04A4A01`L7007alO06MWI`1/K6`0
SXj>05UIF@1gMgL0GEeM065QH@27QhL0FEUI08>3P`15ADD0I6AT04e=C@14A4@0=CDe03Ph>01@D500
9RHV05iNGP1dM7@0DU9B07inOP17AdL0LW9b0492@P1?Cdl0Fe]K07UiN@1KFe/0SHf=059BDP1gMgL0
NWYj04Y:BP35aLD0J6QX06][J`2DU9@0=3@d03/k>`0j>SX0E5AD075aL@1FEUH0E5AD05YJFP17AdL0
EEEE03`l?01LG5`0D51@05aLG01QHF40FUYJ05IFEP0204Y:BP0405mOG`1@D500Hf=S08J6QP;ooooo
0000Z@20P800DU9B06EUI@1_Kfl0FEUI05]KF`19BDT0C4a<08n?S`1PH600FEUI06=SH`0d=3@0?Shn
08>3P`1FEUH0ADE5069RHP0n?Sh0GUiN08^;R`1cLg<09BDU03hn?P1@D500FEUI08F5Q@1/K6`08R8R
038b<P0n?Sh0HV9R06UYJ@2KVi/0=cLg02XZ:P0k>c/0IVIV06i^KP1cLg<0E5AD01TI6@0B4Q80Cdm?
07QhN013@d<0Ng]k0492@P0N7Qh07alO071`L01bLW80GUiN07alO00];Bd0>3Ph03<c<`1UIFD0A4A4
071`L01HF5P05QHF0492@P1]KFd0BDU902XZ:P1IFET0ATI6024Q8@1JFUX0WIfM038b<P0c<c<0Fe]K
034a<@0f=SH0Lg=c09JFUP0M7Ad0:2PX05=CD`1BDU80F5QH08f=S@1HF5P04Q8B024Q8@1TI6@0DU9B
05QHF02l_;`0@T9201/K6`0e=CD0PX:206UYJ@1]KFd0ZZZZ02TY:@0J6QX0=cLg061PH017AdL0@T92
04A4A00<30`0<c<c0451@@1FEUH0;2`/05ADE01:BTX0:BTY03Lg=`1BDU80BTY:02d];@1;Bd/0@410
02TY:@1DE5@0SXj>0492@P0W9bL0<c<c0492@P1@D500GUiN09BDU00];Bd07AdM03Ph>01VIVH0:RXZ
07QhN02YZJT07AdM01@D5019BDT0LW9b0451@@24Q8@0Kfm_01XJ6P1=CDd0GEeM08b<S00n?Sh0][Jf
06UYJ@0`<300EeMG08J6QP1PH600:2PX07=cL`0i>CT0?3`l079bLP24Q8@0AdM708N7Q`19BDT0;bl_
06][J`2IVIT0?clo04M7A`1GEeL00P0j>SX0_@2LW9`0Rh^;03<c<`16ATH0Cdm?03Ph>01BDU80XJ6Q
05aLG00R8R80ATI605eMG@15ADD0Shn?092@T00Y:BT092@T059BDP1VIVH0I6AT08N7Q`23Ph<09RHV
03Lg=`1KFe/0L71`05eMG@2QXJ40ATI602PX:00];Bd0Fe]K05MGE`1EEED0Ph>303lo?`0Y:BT0KFe]
0861P@0[:b/0JFUY03dm?@0];Bd0GUiN08F5Q@0d=3@0A4A403Xj>P1;Bd/0GemO09FEU@1?Cdl0<S8b
04A4A013@d<0EEEE08n?S`0g=cL0<c<c05mOG`18B4P0KFe]0861P@1FEUH0:BTY075aL@1OGel0De=C
09^KV`0^;Rh0:RXZ06MWI`1UIFD0Cdm?08R8R01bLW808B4Q065QH@2NWYh0LW9b03hn?P1`L7008B4Q
030`<01]KFd0PH6104M7A`23Ph<0?3`l03Hf=P0h>3P0P82008^;R`1BDU80Cdm?04I6AP0U9BD0EUIF
07AdM01^KVh0<30`055AD@0n?Sh0;Rh^03<c<`1hN7P0OGem02HV9P0d=3@0?3`l03Ti>@1`L700Ti>C
03@d=00X:2P0CTi>04a<C01LG5`0PH610<O7a`1GEeL06a/K03dm?@1lO7`0Ph>304U9B@1_Kfl0;2`/
034a<@14A4@0OGem05=CD`20P800L71`01`L700_;bl0FEUI06][J`0e=CD0IfMW04];B`0P8200<S8b
051@D01iNGT0?3`l03Xj>P18B4P0F5QH06ATI01]KFd0>SXj05mOG`1SHf<0UIFE06][J`1fMWH0ZJVY
0:2PX02SXj<0BDU904Y:BP2HV9P0`<300<;2`P1oOgl0TY:B071`L019BDT0RHV9059BDP2;Rh/0De=C
07=cL`18B4P0R8R8059BDP26QXH0@d=305EEE@0o?cl0Lg=c08f=S@12@T80W9bL07AdM02TY:@0SHf=
08J6QP020<30`00E08j>SP1]KFd0EEEE09JFUP15ADD0O7al04];B`15ADD0MWIf03Hf=P1]KFd0HF5Q
04m?C`13@d<0H61P06QXJ01:BTX0OWin03<c<`12@T80M7Ad0080GemO08@0EUIF051@D01^KVh0Fe]K
05UIF@18B4P0GemO06MWI`1/K6`0KFe]0861P@1XJ6P0MGEe08J6QP1/K6`0MgMg04Q8B01KFe/0JVYZ
03dm?@1PH600@41002XZ:P1PH600ADE503Hf=P17AdL0Cdm?03Xj>P0h>3P0=cLg03Ph>00k>c/0FEUI
03<c<`18B4P0:b/[0492@P1EEED0>CTi04A4A012@T80DU9B02h^;P1;Bd/0?clo03Lg=`0l?3`0CTi>
03Ph>01FEUH0BDU906=SH`13@d<0Jf][04e=C@1SHf<0Bd];05]KF`1^KVh0HV9R0:JVYP1OGel0H61P
09BDU01]KFd0M7Ad051@D01JFUX0?clo05iNGP0n?Sh0Kfm_06QXJ02:RXX0QHF509FEU@1GEeL0P820
08V9R@27QhL0Vi^K08F5Q@19BDT0JFUY03Ti>@1YJFT0?clo03De=@1^KVh0@T9204a<C00n?Sh0DE5A
05=CD`1KFe/0EUIF06MWI`2KVi/0MGEe03`l?01:BTX0A4A4075aL@1MGEd0IfMW06EUI@0d=3@0<C4a
079bLP0I6AT0JFUY07emO@1FEUH0=CDe06QXJ00n?Sh0NGUi02XZ:P1^KVh0:RXZ028R8P17AdL0:RXZ
03Hf=P0n?Sh092@T02l_;`1BDU80=cLg04i>CP0L71`202`/;00:02DU9@0c<c<0AdM705EEE@0o?cl0
FUYJ05mOG`0g=cL0@D5103dm?@80G5aL06/0;Rh^05iNGP17AdL092@T04e=C@1CDe<092@T04M7A`0m
?Cd0@d=30451@@1JFUX0=SHf0410@014A4@0D51@06MWI`0g=cL0CTi>05MGE`0W9bL0<c<c04Y:BP0m
?Cd0CDe=0451@@1KFe/0AdM705eMG@1:BTX0@D5103`l?00Y:BT0Bd];03Ph>00j>SX0CDe=04M7A`0h
>3P0HV9R04I6AP0i>CT0GemO04A4A02a/K40=cLg08V9R@1nOWh0N7Qh04U9B@1OGel0GUiN04=3@`1V
IVH0?3`l03Xj>P0i>CT0Ph>305ADE01gMgL0MWIf0492@P1dM7@0<C4a07moO`20P800ADE505eMG@0j
>SX0@D5103`l?01dM7@0ADE505aLG01@D500NWYj06UYJ@1ADE40CDe=04a<C01hN7P0>SXj051@D01F
EUH0@41004Y:BP0l?3`0=3@d0492@P0m?Cd0>SXj04U9B@0[:b/0?Cdm02d];@1IFET0DE5A05QHF01F
EUH0IVIV04m?C`1KFe/0IVIV06][J`1CDe<0Q8B408b<S002ooooo`000340/;2`04m?C`1KFe/0JVYZ
07AdM01kNg/0BDU904a<C01hN7P0UYJF08B4Q02SXj<0;bl_0492@P1NGUh0Lg=c06MWI`2DU9@07alO
03lo?`1BDU80RXZ:04m?C`2DU9@0@D51038b<P1oOgl0MGEe03Ph>01iNGT0GemO02PX:01CDe<0UIFE
07MgM`0[:b/0QXJ603`l?00S8b<0KVi^0:ZZZP1<C4`0=SHf03De=@0];Bd0<c<c08V9R@2KVi/0<S8b
0080>SXj02X0<c<c04a<C01/K6`0=CDe02DU9@19BDT0>CTi05=CD`2ATI40HV9R01/K6`0L71`0?3`l
03Xj>P1QHF40YJFU04A4A00f=SH092@T04U9B@1<C4`0L71`09ZJVP0h>3P09BDU02/[:`1MGEd0Cdm?
05mOG`1dM7@061PH03Ph>017AdL0DU9B030`<00h>3P0H61P01TI6@0V9RH0C4a<06UYJ@0U9BD203dm
?@0c02LW9`1>CTh0GemO04U9B@0C4a<0=cLg03hn?P0e=CD0F5QH08:2PP0Y:BT06QXJ03Xj>P1LG5`0
Bd];09NGU`1bLW80:b/[024Q8@13@d<0@41004i>CP2HV9P0>CTi02HV9P0k>c/0O7al09FEU@1UIFD0
TY:B03`l?00V9RH0F5QH05MGE`1DE5@0;2`/05=CD`0c<c<0=cLg03/k>`1EEED0G5aL034a<@22PX80
;Rh^01TI6@0n?Sh0LW9b02HV9P0L71`0Bd];0080;Rh^08/0QHF509jNWP0S8b<0:BTY05MGE`16ATH0
EeMG0:VYZ@1JFUX06a/K0451@@1YJFT0LG5a0<o?c`11@D40A4A404e=C@1/K6`0Bd];09>CT`2KVi/0
7alO02TY:@1XJ6P0O7al03hn?P1dM7@0Jf][030`<00d=3@0EeMG07MgM`0j>SX0EeMG03Hf=P0E5AD0
?clo09jNWP1eMGD0;2`/05eMG@0Y:BT0:2PX05IFEP23Ph<0?3`l03Ti>@1GEeL0>3Ph04U9B@2:RXX0
HV9R02TY:@0e=CD0?3`l05UIF@1hN7P0WinO030`<00];Bd0ADE503/k>`13@d<0VIVI05MGE`0^;Rh0
C4a<06][J`0n?Sh0Hf=S07YjNP0U9BD0BTY:06i^KP1dM7@0HV9R06QXJ00F5QH0ADE507MgM`1QHF40
Cdm?07=cL`0Q8B40<30`08B4Q01VIVH0CTi>071`L00^;Rh0A4A406YZJP1_Kfl0:b/[04M7A`0c<c<0
=SHf05]KF`24Q8@0?3`l04A4A01:BTX0?Cdm06EUI@1[Jf/0@T92030`<017AdL0?Cdm061PH037alL0
Hf=S01lO7`0j>SX0?Cdm04Q8B01NGUh0][Jf07moO`0W9bL0>c/k04=3@`1KFe/0A4A407QhN01JFUX0
6a/K03lo?`1;Bd/0JFUY04=3@`1fMWH0GemO02DU9@1IFET0V9RH07=cL`1QHF40SXj>00809RHV0<P0
KVi^06][J`1iNGT0DU9B075aL@1ZJVX07alO05eMG@28R8P0EEEE03Xj>P1GEeL0<30`01TI6@1?Cdl0
LG5a02TY:@0R8R80Cdm?03dm?@0h>3P0MGEe07=cL`0U9BD09RHV02l_;`12@T80IVIV07alO01cLg<0
E5AD06ATI01WIfL0ADE505mOG`1HF5P0X:2P07moO`1eMGD0Zj^[0;Ng]`2b/[80LG5a07moO`1gMgL0
IfMW06e]K@24Q8@0TI6A06][J`1@D500K6a/04E5A@1PH600BTY:071`L01BDU80JVYZ05ADE01ZJVX0
EeMG08N7Q`1[Jf/0IVIV0:BTY01<C4`0V9RH07inOP2:RXX0Ogmo0;6a/@2o_kl0`l?309RHV01^KVh0
EEEE09FEU@1FEUH0Ph>306IVIP11@D40OWin04m?C`1gMgL0Fe]K03lo?`14A4@0JVYZ05MGE`0`<300
MGEe02d];@0j>SX0JVYZ04=3@`1HF5P0B4Q805iNGP1QHF40Bd];05EEE@0a<C40DE5A059BDP18B4P0
DE5A09:BTP1LG5`0HV9R06MWI`13@d<0HF5Q04a<C019BDT0IfMW0410@01UIFD0C4a<03Ph>01_Kfl0
B4Q802XZ:P0l?3`0@d=303@d=00k>c/0?Cdm04=3@`0/;2`0De=C04Q8B01@D5006QXJ03Ti>@1RHV80
>3Ph04=3@`15ADD0Jf][03Ph>01EEED0E5AD05eMG@0o?cl0EEEE03hn?P1<C4`0?Shn04e=C@1<C4`0
De=C0410@01=CDd0HF5Q06=SH`1jNWX0UiNG0:VYZ@1gMgL0KVi^0;Vi^@2=SHd0JFUY04];B`1PH600
B4Q805ADE00l?3`0HV9R04Q8B01dM7@0RHV909nOW`20P800YJFU08N7Q`1=CDd0FEUI051@D01_Kfl0
JFUY04E5A@1^KVh0AdM7038b<P1PH600ATI606e]K@1;Bd/0?Shn03<c<`1>CTh0JVYZ055AD@25QHD0
Lg=c05EEE@1SHf<0Q8B408J6QP80?Cdm09<0I6AT03Xj>P0Y:BT0KVi^02`/;01aLG40Shn?05=CD`14
A4@0F5QH03/k>`1eMGD0<30`061PH00X:2P0:b/[05YJFP0R8R80>CTi04M7A`0J6QX0@T9206ATI00k
>c/0DU9B01`L700k>c/08B4Q02LW9`0g=cL0EEEE06ATI00Z:RX0A4A404e=C@0I6AT0<c<c03Xj>P0l
?3`0DE5A03<c<`1RHV80>3Ph03`l?028R8P0IVIV01hN7P1KFe/0>SXj04];B`0i>CT0RXZ:06EUI@19
BDT0FEUI06MWI`28R8P0ATI605eMG@1JFUX0<c<c05MGE`1[Jf/0;bl_04a<C01FEUH0FEUI059BDP1O
Gel0G5aL04A4A011@D40<S8b04E5A@0g=cL0@T9206UYJ@11@D40=CDe06][J`0Z:RX0>3Ph05IFEP0m
?Cd0KFe]03hn?P1LG5`0H61P071`L00_;bl0N7Qh06=SH`1YJFT0PH6104M7A`1BDU80;Rh^06MWI`1@
D500@41003/k>`11@D40A4A403lo?`2;Rh/0N7Qh04Y:BP1ZJVX0:b/[061PH00/;2`0DU9B04U9B@1R
HV80EUIF06UYJ@1HF5P0LW9b05ADE01>CTh0LW9b02l_;`1@D500Hf=S030`<01@D500=cLg03Ph>01;
Bd/0?Shn0410@01:BTX0?Cdm051@D00o?cl0KVi^05IFEP1TI6@0EUIF08B4Q01RHV80Cdm?04M7A`2J
VYX0BTY:06][J`2IVIT00_ooool0000=07=cL`1MGEd0WYjN04A4A01=CDd0EeMG069RHP1`L700JVYZ
03`l?01<C4`0MgMg06EUI@0205iNGP2:03Ti>@16ATH0MGEe05=CD`1:BTX0G5aL03Hf=P1=CDd0KFe]
07moO`0[:b/0?Cdm04U9B@1EEED0P820071`L00E5AD0:BTY0451@@1LG5`0B4Q80<[:bP1JFUX07AdM
02d];@1ADE40@T920861P@1^KVh0410@02h^;P0f=SH0SXj>06a/K02;Rh/0B4Q801HF5P1<C4`0Kfm_
0492@P0];Bd0PX:202DU9@0>3Ph0HF5Q08R8R01DE5@0DU9B061PH00m?Cd08B4Q079bLP1jNWX0>c/k
05aLG01:BTX09BDU03Lg=`1?Cdl0@d=3030`<015ADD0<C4a02d];@0e=CD0F5QH03Lg=`0U9BD0@D51
03/k>`1<C4`0JVYZ07IfMP0R8R808B4Q03Ph>01JFUX0HF5Q08:2PP1mOGd05aLG034a<@13@d<0IFEU
03Hf=P2DU9@0@d=302DU9@0a<C40DU9B06a/K01HF5P0OGem01HF5P0`<300>c/k05eMG@1HF5P0FEUI
061PH00K6a/08R8R059BDP1ZJVX0;Bd]03Lg=`1EEED0<30`061PH01jNWX0DU9B01lO7`0Z:RX0CDe=
01`L701;Bd/0U9BD04e=C@0=3@d0?Cdm04e=C@1EEED0Bd];0<;2`P1;Bd/05ADE0492@P1`L700@D51
04I6AP1ZJVX08B4Q020P801DE5@0N7Qh06ATI01;Bd/0NWYj0P0`<300o`1aLG40SXj>03/k>`16ATH0
;Bd]02DU9@1UIFD0Hf=S028R8P1VIVH0?clo03<c<`0l?3`0VIVI08^;R`0_;bl0JVYZ04E5A@0d=3@0
J6QX07moO`0W9bL0ADE504=3@`1?Cdl0Kfm_08J6QP1DE5@071`L03/k>`1DE5@0?clo05]KF`2c/k<0
CDe=01`L701GEeL0FEUI04M7A`1UIFD0/K6a02DU9@0R8R80LW9b069RHP0o?cl0F5QH0451@@0M7Ad0
@T9209fMW@1OGel0EEEE05iNGP0Y:BT08b<S05]KF`1gMgL0@41004M7A`1=CDd0@d=306ATI02<S8`0
=SHf03lo?`1VIVH0>3Ph071`L02h^;P0F5QH0492@P1PH600;2`/04m?C`2e]KD0A4A401lO7`1GEeL0
GUiN055AD@2ZZZX0@41003<c<`1?Cdl0KFe]06YZJP1nOWh0Bd];024Q8@16ATH0F5QH0451@@1YJFT0
M7Ad01hN7P0f=SH0IVIV065QH@1XJ6P0T92@0451@@0`<300?Cdm07alO00l?3`0GemO04A4A00Q8B40
:RXZ034a<@1WIfL0De=C04Y:BP19BDT05ADE030`<01ADE40KVi^0492@P0j>SX0GemO02`/;00d=3@0
JFUY09>CT`0/;2`0@T9205QHF00h>3P0GEeM09BDU01PH6009bLW05QHF023Ph<0HF5Q05ADE02GUiL0
SHf=020P800g=cL0K6a/069RHP17AdL0T92@03<c<`0h>3P09bLW055AD@1OGel0>SXj07IfMP0f=SH0
:2PX034a<@1IFET0CDe=03lo?`1_Kfl09bLW01/K6`0k>c/0IFEU06YZJP23Ph<0LG5a05=CD`1fMWH0
GemO07alO01cLg<0G5aL08B4Q02YZJT0OWin03lo?`1>CTh0Ph>3079bLP2e]KD0JVYZ0:BTY02UYJD0
R8R809:BTP14A4@0NWYj0861P@1fMWH0AdM707]kN`22PX80Ogmo04U9B@1:BTX0ATI605]KF`1eMGD0
@d=3075aL@2UYJD0QHF5051@D01TI6@0SHf=0<[:bP1YJFT0AdM7075aL@1XJ6P0@d=3055AD@1OGel0
OWin075aL@1FEUH0KVi^07emO@1DE5@0De=C05mOG`18B4P0?Shn079bLP18B4P0A4A4069RHP1@D500
KVi^06QXJ01VIVH0IfMW04a<C01TI6@0@d=3059BDP1ADE40IfMW06QXJ024Q8@0JVYZ06MWI`1^KVh0
IFEU07=cL`12@T80A4A4055AD@1GEeL0E5AD04Y:BP0l?3`0FUYJ05aLG0008P0h>3P0>c/k0451@@14
A4@0=cLg02DU9@1HF5P0@410051@D00X:2P0DU9B020P800l?3`0H61P0410@00b<S80>CTi05mOG`1D
E5@0EEEE04E5A@1IFET0C4a<05mOG`0b<S80F5QH04M7A`1RHV80ADE5079bLP11@D40F5QH059BDP1C
De<205UIF@0608R8R01UIFD0KVi^0820P01_Kfl0K6a/0P1HF5P02P0l?3`0JVYZ05MGE`1VIVH0AdM7
08B4Q02PX:00UYJF04E5A@1NGUh207MgM`0;09>CT`1eMGD0RXZ:08V9R@13@d<0C4a<04i>CP0o?cl0
SHf=04I6AP18B4P00P1?Cdl02P0n?Sh0HF5Q04U9B@0o?cl0J6QX065QH@14A4@0CDe=0410@01SHf<2
04U9B@2C05]KF`0e=CD0CDe=0820P00U9BD0K6a/08>3P`1?Cdl0FUYJ06][J`0d=3@0L71`03lo?`21
PH40:BTY024Q8@18B4P0=3@d04m?C`1EEED05QHF02d];@1CDe<0@D5105iNGP0G5aL0:BTY02`/;00W
9bL0:2PX04e=C@1SHf<0:2PX04=3@`1FEUH07alO03lo?`0k>c/0?Shn04Q8B00X:2P0MGEe02`/;00K
6a/0/k>c07QhN00I6AT0@D510492@P1PH600>SXj05IFEP0d=3@0AdM703Xj>P20P800QhN7034a<@1c
Lg<0GEeM010@400d=3@0Bd];03hn?P1SHf<0DE5A05QHF01NGUh0L71`05QHF013@d<0ATI603De=@1?
Cdl0>CTi03lo?`1CDe<0>SXj02d];@21PH40>SXj0492@P1WIfL0=CDe0820P00N7Qh0SXj>08:2PP21
PH40B4Q806IVIP1;Bd/0HF5Q08N7Q`0c<c<0GEeM02d];@2NWYh0G5aL04I6AP11@D40>c/k05ADE00P
8200GEeM06UYJ@0[:b/0DE5A03Ti>@1ADE40<c<c06i^KP1?Cdl0GEeM06QXJ01IFET0F5QH03`l?00h
>3P0EEEE09RHV01/K6`0M7Ad04E5A@18B4P0P820069RHP0o?cl0ATI603Xj>P1^KVh0JVYZ05iNGP13
@d<0?Shn06ATI01HF5P0Jf][04m?C`1:BTX0EUIF07UiN@1HF5P0HV9R04U9B@27QhL0Zj^[00;ooooo
0000:@1^KVh0EUIF0861P@1dM7@0CTi>05QHF01NGUh0NGUi08^;R`0j>SX0@D5104m?C`1KFe/0P820
09nOW`0U9BD0@41004e=C@18B4P0IfMW0:>SX`0[:b/0<C4a04];B`2CTi<0GEeM096AT@1GEeL0:BTY
065QH@1XJ6P09BDU05aLG01^KVh09bLW02/[:`26QXH0VYZJ034a<@1eMGD0FEUI0080:BTY0;l0LW9b
06ATI00R8R80=CDe02XZ:P0S8b<0EUIF0861P@0m?Cd0=CDe051@D015ADD0EUIF09VIV@1@D5006ATI
04I6AP14A4@0@41006ATI01YJFT092@T01/K6`0n?Sh0CDe=051@D01cLg<0@d=301hN7P0k>c/0=3@d
0492@P1FEUH0SHf=07AdM00U9BD0?Shn04A4A01KFe/0NGUi0::RXP0c<c<07alO04i>CP1UIFD0C4a<
06UYJ@1]KFd07alO01dM7@1?Cdl0LW9b04=3@`1KFe/0Lg=c01XJ6P0[:b/0B4Q805]KF`0Y:BT0<C4a
04=3@`0M7Ad0DU9B07MgM`0n?Sh092@T03dm?@0f=SH0;Bd]08^;R`2i^KT0:b/[01dM7@0T92@0@D51
0410@01gMgL0P82001/K6`0S8b<0AdM706i^KP1=CDd0PH6109fMW@0h>3P0?clo04Q8B01QHF40@D51
05MGE`1VIVH08R8R01dM7@15ADD0EeMG02HV9P0a<C40Cdm?038b<P0[:b/0De=C03Xj>P0U9BD0AdM7
04I6AP0_;bl0@d=309nOW`1>CTh08R8R0410@015ADD0FUYJ071`L01@D5008R8R03Xj>P1FEUH0BTY:
0:JVYP1=CDd0;2`/04Y:BP1ADE40HV9R06e]K@2m_Kd0>SXj028R8P1HF5P0M7Ad0451@@24Q8@0TY:B
04E5A@0W9bL0JVYZ09BDU016ATH0AdM706=SH`0_;bl0>3Ph04E5A@1lO7`0?Shn0820P01@D500:RXZ
030`<01QHF40Cdm?0451@@1PH600=SHf03Ph>025QHD0T92@02HV9P0^;Rh0Cdm?02`/;01JFUX0Vi^K
02HV9P0a<C40E5AD04Y:BP18B4P0Rh^;06m_K`0I6AT0Bd];07]kN`17AdL0Bd];09VIV@0f=SH0@T92
07alO01=CDd0GUiN06YZJP0T92@0;bl_07UiN@1GEeL0BDU907UiN@0204E5A@1A05MGE`1<C4`0>3Ph
07QhN010@400ADE506ATI01EEED0<c<c08:2PP0n?Sh0<S8b08N7Q`2NWYh0?3`l03/k>`0n?Sh0A4A4
03dm?@28R8P0JFUY02`/;01>CTh0<c<c055AD@1hN7P0XZ:R04M7A`0b<S80C4a<0451@@10@400MGEe
0;:b/P1<C4`09bLW05ADE016ATH0E5AD05eMG@2][Jd0:b/[03@d=01OGel0NWYj04a<C01hN7P0KVi^
03Lg=`11@D40MgMg0:>SX`19BDT0X:2P07inOP0];Bd0=cLg05EEE@2FUYH0GEeM05=CD`1NGUh08B4Q
03<c<`1ZJVX0L71`02XZ:P1>CTh0<C4a03Lg=`16ATH0IVIV0492@P0L71`0<30`03Hf=P13@d<0C4a<
08B4Q01CDe<06ATI0080A4A403L0DE5A05QHF01^KVh0Cdm?05ADE01ZJVX0WYjN06i^KP1?Cdl0Y:BT
0=[JfP2XZ:P0Bd];04e=C@24Q8@0UiNG07emO@2SXj<0TY:B04E5A@0h>3P0B4Q804m?C`1=CDd0<30`
051@D017AdL0IfMW04Q8B01>CTh0>SXj04=3@`0_;bl0Jf][06QXJ00n?Sh0CTi>04Q8B01MGEd0HV9R
07=cL`1jNWX0KFe]06MWI`1=CDd0@D5106YZJP19BDT0Hf=S03hn?P0_;bl0DE5A0492@P1=CDd0@410
0080>CTi01@0ATI604e=C@0m?Cd0@41002<S8`0W9bL0F5QH07AdM018B4P0>CTi03Xj>P1SHf<0KVi^
03lo?`0^;Rh0DU9B061PH00o?cl0<c<c05MGE`80OWin02h0GemO0492@P1[Jf/0O7al06UYJ@1=CDd0
<c<c04M7A`1DE5@0MGEe05mOG`12@T80;bl_05ADE00m?Cd0>CTi04M7A`0k>c/0=SHf03De=@1EEED0
:b/[0492@P0R8R80BDU904A4A00W9bL0=cLg05aLG01JFUX0<C4a04];B`1?Cdl0@D5103dm?@1<C4`0
ATI605YJFP1GEeL0Hf=S04E5A@1]KFd0Hf=S06UYJ@1KFe/0NWYj0P1kNg/0K`2LW9`0HF5Q06a/K023
Ph<0IVIV05iNGP1FEUH0Fe]K03Hf=P1PH600?Shn06e]K@1GEeL0WIfM0:n_[`2d];@0IFEU075aL@2C
Ti<0];Bd0:6QX@1^KVh0MgMg07IfMP0Y:BT0Kfm_08Z:RP2JVYX0N7Qh04A4A01>CTh0F5QH05=CD`1A
DE40IFEU04e=C@1gMgL0T92@05mOG`0h>3P0FUYJ06YZJP1hN7P0CDe=05]KF`1oOgl0Hf=S028R8P1M
GEd0Bd];08>3P`28R8P0De=C03<c<`1KFe/0ATI607=cL`0a<C40E5AD02PX:00_;bl0Cdm?034a<@0o
?cl0ATI601TI6@1>CTh0Fe]K02h^;P13@d<06a/K03lo?`0L71`0=CDe02h^;P15ADD0DE5A02PX:01=
CDd0C4a<02TY:@1HF5P0?Cdm04m?C`1EEED0820P05QHF00Q8B40410@04e=C@1FEUH05aLG04i>CP0i
>CT0C4a<03`l?01[Jf/0A4A405EEE@10@400Bd];06ATI00Z:RX0PH6107inOP0Q8B40BTY:04];B`0i
>CT0Cdm?04=3@`0204a<C00^065QH@1LG5`0=SHf03<c<`0Y:BT0B4Q803Hf=P0i>CT0Hf=S0410@00]
;Bd0KFe]020P800e=CD0GUiN02@T901oOgl0<S8b06=SH`1VIVH0KFe]03Xj>P1/K6`0BDU905IFEP1`
L700CDe=08B4Q00Q8B40Jf][04m?C`0l?3`0A4A404I6AP1:BTX07alO0:NWY`26QXH0=cLg059BDP0V
9RH0C4a<04I6AP1DE5@0FEUI06IVIP80F5QH01l0N7Qh06MWI`1?Cdl0EEEE08b<S01KFe/0QXJ606AT
I00f=SH0@D510410@018B4P0EEEE04=3@`1:BTX0?3`l02l_;`1=CDd0DU9B06YZJP1BDU80F5QH05iN
GP23Ph<0IFEU04e=C@1/K6`0ZJVY05MGE`1iNGT0PX:200;ooooo0000o`2LW9`0H61P06QXJ021PH40
OGem08>3P`0n?Sh0Hf=S08n?S`1_Kfl0T92@08>3P`0f=SH0CDe=06UYJ@1SHf<0DE5A06EUI@0^;Rh0
?3`l05iNGP24Q8@0?3`l08N7Q`0i>CT0;Bd]03lo?`1FEUH0;bl_0492@P1EEED0?3`l04e=C@1cLg<0
=cLg024Q8@18B4P0@D5103dm?@1]KFd0OGem01lO7`0R8R80=3@d07=cL`1SHf<0WYjN04U9B@0Z:RX0
>CTi05ADE018B4P0GUiN07moO`0S8b<09RHV03hn?P1RHV80@T9208j>SP1QHF405ADE030`<01DE5@0
B4Q806=SH`29RHT0=cLg02`/;017AdL0KVi^02LW9`0_;bl0GEeM01lO7`0V9RH0EUIF08B4Q00b<S80
8R8R03`l?00V9RH0>c/k07YjNP2;Rh/07AdM03Lg=`12@T809BDU03dm?@28R8P0?Shn02<S8`0m?Cd0
?3`l03Xj>P1JFUX0QhN702XZ:P0C4a<0?Shn061PH00`<300Jf][07IfMP0I6AT0820P061PH01aLG40
Cdm?07moO`0o?cl071`L04E5A@1CDe<0T92@05ADE01`L7006ATI02<S8`0o?cl0IfMW05QHF00h>3P0
I6AT03Hf=P0/;2`0DU9B08j>SP19BDT07AdM0492@P0b<S80<C4a04i>CP29RHT0=3@d02PX:018B4P0
AdM702h^;P23Ph<0YjNW01/K6`0P8200>c/k04A4A01SHf<0YZJV07AdM00M7Ad0A4A405MGE`1PH600
Bd];06m_K`0X:2P0;bl_04U9B@1YJFT0F5QH05UIF@0P8200=CDe07inOP2[Zj/0>c/k05mOG`0n?Sh0
;Bd]05IFEP2BTY80EEEE02/[:`0i>CT0B4Q803<c<`2EUID0VIVI02d];@0V9RH0>SXj04i>CP19BDT0
K6a/079bLP0W9bL0;bl_04];B`1>CTh0AdM70;:b/P1gMgL092@T04Q8B010@400?Cdm06QXJ02UYJD0
A4A402DU9@1EEED0Lg=c03/k>`19BDT0OGem02HV9P0m?Cd0S8b<06UYJ@1CDe<0UYJF030`<00M7Ad0
F5QH0861P@0o?cl0@d=30492@P0W9bL0@d=3096AT@1^KVh0=3@d05MGE`0U9BD0Lg=c08n?S`10@400
?Cdm06EUI@0j>SX0CDe=0:BTY01QHF40?Shn06UYJ@18B4P0De=C07moO`15ADD0:RXZ06i^KP1PH600
D51@075aL@0f=SH08B4Q05UIF@21PH40@d=306QXJ01GEeL0<30`04m?C`00;P1XJ6P0U9BD065QH@2Z
ZZX0<C4a02<S8`1dM7@0VYZJ04Y:BP1JFUX0GemO03lo?`0W9bL0BDU907MgM`29RHT0?3`l06MWI`0i
>CT071`L03Ti>@1XJ6P0O7al03Ph>01YJFT0<30`02HV9P0g=cL0KVi^020P8010@400E5AD02TY:@1N
GUh0UYJF075aL@0`<30092@T04i>CP1?Cdl0A4A409bLW02HV9P092@T02/[:`14A4@205]KF`0Y0:FU
Y@1LG5`061PH0451@@1DE5@0FUYJ04m?C`2HV9P0HV9R01lO7`19BDT0BTY:0861P@1:BTX0Shn?06m_
K`1QHF40FEUI06ATI013@d<0K6a/096AT@21PH40OWin075aL@10@400EUIF06EUI@1TI6@0QXJ607in
OP1FEUH0D51@03Xj>P1[Jf/0PH6105UIF@1eMGD0?3`l06=SH`19BDT00P1VIVH0F01`L700FEUI07em
O@17AdL0De=C03Xj>P0o?cl0GemO04a<C01`L700Fe]K06m_K`24Q8@0];Bd0:FUY@2^[Zh0S8b<05eM
G@1@D500M7Ad065QH@1XJ6P0Cdm?0492@P1fMWH0DE5A05EEE@1ADE40Bd];04m?C`1ZJVX0G5aL034a
<@1gMgL0820P02d];@1QHF40De=C05iNGP17AdL0De=C05UIF@0e=CD0AdM702TY:@18B4P0@D5104M7
A`16ATH0Ogmo05UIF@1;Bd/0GemO04Y:BP1IFET0<C4a02l_;`0n?Sh0<30`0492@P0m?Cd07AdM04Q8
B00j>SX09bLW02PX:00_;bl0?Cdm02d];@0Q8B40>c/k034a<@0k>c/0:RXZ0410@00E5AD0<30`04i>
CP0c<c<08b<S01dM7@0j>SX0=cLg03lo?`0`<300>c/k03Ph>00l?3`203/k>`2J04E5A@17AdL0Fe]K
051@D00c<c<0Bd];05eMG@1fMWH0NGUi07alO01aLG40Jf][06YZJP22PX80MWIf04i>CP1NGUh0Hf=S
04i>CP1LG5`0@T9206MWI`1lO7`0Q8B40:NWY`2ZZZX0ATI608n?S`1bLW80J6QX07inOP1CDe<0HV9R
07inOP1:BTX0HF5Q08n?S`2WYjL0C4a<05EEE@1_Kfl0D51@0410@011@D40H61P06m_K`1RHV80H61P
05IFEP10@400HV9R04I6AP1LG5`0@D51034a<@1?Cdl0De=C02d];@18B4P05ADE08B4Q02b/[80IVIV
03Xj>P1BDU80@T9207AdM018B4P0I6AT04=3@`0T92@0BDU902HV9P0k>c/0ATI603Lg=`0c<c<0C4a<
03Xj>P1CDe<09RHV02XZ:P0];Bd09BDU02XZ:P1IFET0EeMG02/[:`10@400ATI601LG5`0a<C40;Bd]
03lo?`15ADD06ATI06a/K00L71`0410@07]kN`1VIVH03@d=051@D00j>SX0C4a<034a<@1/K6`0<C4a
0451@@0i>CT0HF5Q071`L00e=CD0@d=304e=C@0N7Qh0?clo05IFEP0b<S80DE5A04I6AP1OGel0E5AD
07YjNP1JFUX0BDU90451@@0i>CT0CTi>03hn?P17AdL0EUIF04i>CP0g=cL0JFUY02LW9`0k>c/0F5QH
02d];@2>SXh0=cLg079bLP1QHF40IFEU02h^;P1mOGd0KFe]06IVIP1YJFT0Cdm?05ADE00n?Sh0RXZ:
079bLP80=SHf02h0Kfm_05mOG`0J6QX0C4a<03Xj>P0^;Rh0K6a/04E5A@1IFET0EEEE05MGE`18B4P0
GEeM06m_K`1QHF40MgMg04e=C@0g=cL0=SHf075aL@0j>SX0Lg=c03hn?P0K6a/0E5AD03Ti>@0];Bd0
@D5102<S8`1OGel0Bd];04a<C015ADD0=3@d051@D01RHV80KFe]05ADE01QHF40I6AT0:6QX@1JFUX0
GEeM05UIF@28R8P0/K6a0_ooool0002m08j>SP1@D500HV9R04Q8B01ZJVX0I6AT04I6AP1MGEd0De=C
0410@02FUYH0TI6A030`<00l?3`0@d=303/k>`2>SXh0UIFE02l_;`12@T80Cdm?04Q8B01FEUH0];Bd
04I6AP0m?Cd0CDe=04i>CP1FEUH0[Jf]07=cL`0c<c<0D51@065QH@1IFET0EeMG0;6a/@1EEED09RHV
04M7A`1QHF40?3`l05iNGP1IFET0:b/[03dm?@1^KVh0MgMg051@D01`L700?Cdm038b<P0m?Cd0I6AT
05=CD`1:BTX0Ogmo01hN7P0V9RH0C4a<06ATI00L71`0>SXj04U9B@0U9BD0@d=306m_K`1FEUH07QhN
03@d=010@400DU9B06a/K01mOGd0:RXZ01LG5`0b<S80E5AD05IFEP1QHF40Ogmo01`L700P8200C4a<
08B4Q00l?3`0Fe]K04I6AP0S8b<0:b/[04];B`1jNWX0@D5108N7Q`0j>SX05ADE038b<P1QHF40Cdm?
0451@@1LG5`0<30`01lO7`0i>CT0KVi^061PH00Z:RX0BTY:02LW9`0O7al0FUYJ06=SH`0O7al0@D51
055AD@11@D40EUIF09VIV@0l?3`061PH0451@@15ADD0=CDe05UIF@2a/K40AdM701/K6`0f=SH0IfMW
05YJFP1ZJVX0Zj^[03Xj>P0K6a/0B4Q807UiN@1EEED0@d=307inOP0e=CD0820P04M7A`2RXZ80KFe]
04a<C01TI6@0=SHf02@T901lO7`0Ti>C02h^;P0l?3`0LW9b02XZ:P1PH600MGEe05YJFP0J6QX0?clo
04Y:BP1UIFD0U9BD02<S8`0W9bL0DU9B07emO@1JFUX0TY:B0410@00N7Qh0De=C07UiN@1XJ6P0CDe=
08f=S@0o?cl07alO03Ti>@1jNWX0L71`055AD@25QHD0Ti>C024Q8@1?Cdl0RXZ:05UIF@1=CDd0P820
00809bLW0?l0OGem092@T015ADD0>c/k059BDP0M7Ad0BDU909VIV@26QXH0?Cdm04Q8B01=CDd0>c/k
04m?C`2LW9`0A4A402LW9`1<C4`0Fe]K05IFEP2MWId0Fe]K02@T900m?Cd0GEeM05iNGP1GEeL0OWin
02DU9@0^;Rh0MGEe05aLG01MGEd0QHF502DU9@0];Bd0Fe]K079bLP1BDU80SXj>02HV9P11@D40B4Q8
04=3@`1UIFD0S8b<020P800m?Cd0JVYZ071`L017AdL0KFe]03Hf=P1<C4`0MWIf05mOG`11@D40EEEE
065QH@0c<c<0@D5108B4Q00m?Cd0:b/[05iNGP17AdL0>CTi06a/K01UIFD0:BTY03`l?01LG5`0F5QH
055AD@24Q8@0F5QH01XJ6P0U9BD0?Cdm05EEE@13@d<0SXj>05IFEP0O7al0?3`l05=CD`1>CTh0DU9B
0;no_`1>CTh0?clo05eMG@1PH600?Shn05IFEP29RHT07AdM02PX:01YJFT0Lg=c05UIF@0e=CD0HF5Q
05ADE00O7al0A4A408:2PP1CDe<0Cdm?055AD@0G5aL06QXJ059BDP1UIFD08b<S02`/;01QHF40;Rh^
02DU9@1IFET0P82002`/;00b<S80EUIF02l_;`0R8R80M7Ad08Z:RP1CDe<0LG5a08J6QP1ZJVX0?Cdm
04Y:BP1_Kfl0Hf=S05YJFP29RHT0MWIf08^;R`0o?cl0BDU907=cL`2JVYX0Rh^;065QH@1bLW80EEEE
03Ti>@1?Cdl0B4Q805iNGP1VIVH0Fe]K059BDP1eMGD0LG5a05aLG01GEeL0HF5Q03`l?01CDe<0FEUI
03lo?`1CDe<0Kfm_05mOG`1CDe<0HV9R06][J`2;Rh/0J6QX0451@@1HF5P0E5AD038b<P1?Cdl0C4a<
05EEE@1[Jf/0=SHf04m?C`1@D500@41002/[:`12@T80ATI603lo?`1NGUh0@41004a<C01JFUX0H61P
07alO02:RXX0Jf][06MWI`1?Cdl0FUYJ03dm?@1EEED0CDe=065QH@1SHf<0TI6A07EeM@1SHf<0Rh^;
04a<C01_Kfl0BTY:0492@P18B4P0>c/k059BDP12@T80<S8b069RHP1NGUh0>3Ph0492@P0d=3@0CDe=
03De=@0S8b<0Fe]K04U9B@1ADE406QXJ04i>CP0O7al0A4A4059BDP11@D40=CDe03lo?`1CDe<0@410
051@D017AdL0CTi>05eMG@1QHF40BTY:065QH@1ADE40EeMG030`<01GEeL0?3`l03Xj>P1<C4`0F5QH
05UIF@1QHF4001l0JVYZ07IfMP1YJFT0I6AT04m?C`19BDT0E5AD03dm?@0^;Rh0BDU904Y:BP17AdL0
BDU905QHF02RXZ80UYJF04];B`28R8P0I6AT079bLP29RHT0DE5A08n?S`22PX80ATI606ATI01RHV80
=CDe04m?C`0h>3P0@4100080IFEU00X0ADE504e=C@0o?cl0D51@06][J`1aLG40D51@05MGE`16ATH0
NWYj0P0o?cl0M@1RHV80?3`l051@D01:BTX07alO04e=C@1cLg<0IVIV03/k>`1XJ6P0>CTi07moO`14
A4@0K6a/02h^;P0P8200E5AD05YJFP1BDU80EeMG028R8P0`<300C4a<04];B`1QHF40=CDe030`<00h
>3P0<S8b04U9B@0e=CD0CTi>02l_;`11@D40Bd];02XZ:P1SHf<0ADE505ADE01IFET07alO05ADE00a
<C404Q8B04U9B@1CDe<04Q8B03Ph>00j>SX0De=C03dm?@1TI6@0<S8b06EUI@12@T80K6a/08j>SP0X
:2P0G5aL05]KF`0L71`0BDU905QHF01?Cdl0NWYj04i>CP1BDU80Cdm?06e]K@18B4P0?clo04];B`0h
>3P0?Cdm04m?C`1>CTh0GEeM04M7A`1JFUX0Rh^;04Q8B01>CTh0J6QX020P801YJFT06ATI09>CT`1e
MGD0R8R804a<C01eMGD0GemO07AdM01bLW80E5AD06QXJ016ATH0Rh^;06YZJP1/K6`0D51@05EEE@1K
Fe/0;Bd]08R8R01RHV80?3`l04m?C`0e=CD0E5AD02d];@1FEUH0D51@05UIF@1XJ6P0UYJF07inOP02
04];B`0B034a<@2?Shl0EeMG07EeM@1MGEd0;Bd]04Q8B011@D40>c/k04Y:BP0k>c/0HF5Q05eMG@0k
>c/0<c<c051@D01/K6`0De=C0P1aLG401P1gMgL0IVIV061PH01?Cdl0Jf][04m?C`80PX:20_ooool0
000?07YjNP1hN7P0/[:b04A4A01FEUH0K6a/07EeM@33`l<0Ng]k0410@019BDT0NWYj075aL@2/[:`0
Jf][0080>CTi02P0LW9b07emO@1YJFT0JVYZ03De=@0l?3`0Ng]k07UiN@0l?3`0NGUi03dm?@0K6a/0
EeMG06QXJ00V9RH0E5AD069RHP0[:b/0;bl_06YZJP1_Kfl09BDU04i>CP0e=CD0;Bd]06m_K`1kNg/0
7AdM01lO7`0o?cl0A4A405QHF024Q8@0?Cdm02HV9P0[:b/0?Shn04M7A`1HF5P0Xj>S0P0X:2P0d`0c
<c<0G5aL04U9B@23Ph<0Ng]k02XZ:P0U9BD0?Shn06e]K@13@d<0J6QX03@d=00J6QX0:BTY06e]K@1X
J6P0?3`l06ATI00b<S80:2PX03Ti>@1RHV80F5QH0451@@1EEED092@T02/[:`0m?Cd0GUiN02h^;P0h
>3P0>c/k02LW9`1FEUH0KVi^06=SH`0Y:BT0=SHf04Y:BP0];Bd0KFe]0;6a/@1;Bd/0820P030`<014
A4@0@T9205]KF`2NWYh092@T01lO7`13@d<0Jf][03hn?P1mOGd0YZJV01/K6`0l?3`0BDU906EUI@0]
;Bd0GUiN04e=C@0/;2`0=SHf05ADE01oOgl092@T05iNGP23Ph<0<c<c02TY:@1>CTh0Cdm?01TI6@1<
C4`0DU9B02`/;00l?3`0NGUi05EEE@0O7al0:b/[059BDP1>CTh0?3`l09:BTP0e=CD09bLW034a<@1P
H600HV9R07AdM02NWYh0;bl_03/k>`1]KFd0R8R805iNGP1bLW80ATI60410@020P800E5AD03Ti>@1@
D5007alO04=3@`1]KFd0YJFU03Lg=`0l?3`0EEEE04=3@`0k>c/0Ng]k07=cL`0c<c<0=CDe04U9B@0_
;bl0=cLg07YjNP1[Jf/0<S8b02PX:01HF5P0EUIF05MGE`2XZ:P0=SHf01XJ6P0k>c/0CDe=04m?C`1m
OGd0Rh^;03De=@0c<c<0E5AD05iNGP15ADD0SXj>08b<S00U9BD0B4Q806a/K01HF5P0G5aL07IfMP0K
6a/0@41007UiN@1ZJVX0Fe]K08J6QP1?Cdl0;bl_05=CD`1RHV80;bl_0410@028R8P0=CDe02h^;P1e
MGD0ADE504Q8B00m?Cd0<c<c05aLG021PH40@T9203@d=01HF5P0<30`07inOP2_[jl0=CDe02LW9`1W
IfL0ADE507QhN030`<00Bd];03@d=01EEED0EeMG05EEE@24Q8@0MWIf03Lg=`18B4P0IVIV06][J`1E
EED0RXZ:03@d=00e=CD0@T9205aLG015ADD0QhN707=cL`0a<C40Bd];04Y:BP2JVYX0GemO04M7A`1M
GEd00P0d=3@06P1PH600OGem03dm?@18B4P0J6QX02<S8`0`<300G5aL07inOP0d=3@0F5QH05aLG00Q
8B40<30`08N7Q`1PH600:RXZ04I6AP1ADE40C4a<03hn?P24Q8@0O7al02l_;`0[:b/0C4a<0P1DE5@0
?@2NWYh0<c<c01/K6`1=CDd0F5QH04m?C`1FEUH0UIFE03Xj>P0L71`0CDe=079bLP1:BTX0@T9206MW
I`0P82006ATI04e=C@1cLg<0IfMW069RHP1VIVH0ATI605]KF`1HF5P0S8b<07alO01UIFD0Ogmo08f=
S@2?Shl0DE5A04i>CP1=CDd0@d=3092@T01mOGd0Ph>307AdM014A4@0EEEE05YJFP1KFe/0@d=305EE
E@1NGUh0H61P04Q8B01;Bd/0@41005ADE00h>3P0G5aL061PH00l?3`0Bd];04U9B@1HF5P0L71`08J6
QP1hN7P00P1mOGd0E`1;Bd/0?Cdm05QHF01@D500FEUI0410@00P8200CDe=04a<C013@d<0?Cdm03Lg
=`16ATH0Ng]k04U9B@0j>SX0E5AD02d];@0`<300GEeM079bLP1:BTX0@D5104A4A01SHf<0P82005eM
G@1:BTX0Cdm?05=CD`19BDT0>c/k065QH@1iNGT0IfMW06IVIP1XJ6P0FEUI05ADE01?Cdl0@D5104e=
C@0n?Sh0BDU907UiN@1GEeL0>3Ph0410@01KFe/0;2`/02h^;P0g=cL0;bl_03Lg=`0Y:BT0DU9B01hN
7P0i>CT05QHF0492@P1CDe<0;bl_03<c<`1:BTX0EUIF02/[:`16ATH0FEUI03Ti>@0[:b/0ATI605=C
D`1ADE40C4a<05YJFP17AdL0IFEU05mOG`1JFUX0ATI606i^KP22PX80U9BD0:FUY@1PH600GemO0861
P@0205UIF@2j04Q8B01DE5@0?Shn05]KF`0n?Sh0IFEU05ADE01dM7@0KFe]059BDP0n?Sh0HF5Q05UI
F@2JVYX0TI6A055AD@1QHF40GEeM03Xj>P1IFET0IfMW04e=C@1CDe<0@T92065QH@11@D40?3`l05aL
G013@d<0BTY:055AD@2n_[h0H61P0492@P1DE5@0@d=305eMG@1TI6@0GemO06a/K01@D500JFUY06i^
KP1KFe/0HF5Q08N7Q`1<C4`0@41006i^KP1;Bd/0P82005QHF01/K6`0>SXj02d];@1?Cdl0Bd];03<c
<`17AdL0=SHf03@d=01<C4`0B4Q805ADE00g=cL0:b/[04=3@`0n?Sh0:RXZ04I6AP1HF5P0@410055A
D@1MGEd0@T9204=3@`15ADD0A4A4069RHP1IFET0I6AT02l_;`13@d<0KVi^06a/K012@T80<S8b04i>
CP0j>SX0DE5A05eMG@1DE5@0B4Q804a<C01LG5`0K6a/05EEE@2FUYH0TY:B03Xj>P17AdL0DE5A04E5
A@1KFe/0>c/k06][J`1=CDd0IfMW03Lg=`0j>SX0?Cdm02d];@13@d<0@D5104M7A`1KFe/0E5AD0410
@029RHT0>SXj0492@P1KFe/0;Rh^07emO@12@T80K6a/06e]K@2@T900EeMG08V9R@1TI6@0C4a<0:VY
Z@19BDT0HV9R05UIF@2h^;P0I6AT04Q8B012@T80D51@0410@016ATH0KFe]061PH015ADD0Fe]K04A4
A01LG5`0@D510820P00l?3`0De=C059BDP1?Cdl0L71`06=SH`1hN7P0BTY:08V9R@1ADE40FEUI04I6
AP15ADD0PH61069RHP0m?Cd0@d=303Xj>P16ATH0CDe=03Xj>P10@400ATI6055AD@1NGUh0H61P05aL
G02:RXX0LW9b065QH@1VIVH0KVi^059BDP1[Jf/0Z:RX0_ooool00005069RHP1EEED0FUYJ05eMG@1N
GUh00P1>CTh0T029RHT0Y:BT05iNGP1RHV80C4a<05=CD`1IFET0I6AT03<c<`0f=SH0>c/k04];B`1V
IVH0K6a/02l_;`0h>3P0FEUI061PH01KFe/0UYJF08^;R`0O7al0BTY:04];B`1FEUH0Ph>30:n_[`0a
<C40=3@d05ADE01FEUH0Lg=c0;Rh^01mOGd06QXJ04I6AP1MGEd0B4Q806IVIP2UYJD0=CDe03Hf=P19
BDT0D51@04E5A@1UIFD0GUiN02HV9P0Z:RX0@41004Y:BP0f=SH0GEeM02PX:00a<C40D51@065QH@0`
<300=CDe06MWI`0Y:BT0<c<c04];B`1GEeL07AdM034a<@0k>c/0;bl_03Xj>P1lO7`0KFe]01HF5P0Y
:BT0>3Ph05ADE01RHV80YZJV03dm?@0T92@0ATI605QHF013@d<0Ti>C07]kN`0X:2P0=3@d04Y:BP14
A4@0>3Ph05IFEP1oOgl07alO038b<P0g=cL0KVi^0492@P20P800GUiN01lO7`0U9BD0Cdm?07EeM@0X
:2P0L71`04M7A`0M7Ad0ATI606i^KP1=CDd0<C4a05]KF`0h>3P0=CDe07YjNP20P800820P02h^;P15
ADD0Hf=S04];B`1jNWX0V9RH02PX:010@400E5AD0820P00m?Cd0RXZ:08j>SP0Z:RX08R8R03De=@1<
C4`0CTi>06i^KP1/K6`061PH02HV9P0Z:RX0@D51034a<@1]KFd0BDU9018B4P80AdM70?P0>3Ph02TY
:@1cLg<0;bl_02DU9@1/K6`0DE5A03dm?@19BDT0CTi>05EEE@1dM7@0;Bd]02PX:013@d<0PX:2059B
DP2?Shl0RHV902h^;P0X:2P0?Shn07EeM@1>CTh0Ph>308F5Q@0`<300820P03Lg=`1fMWH0Fe]K0820
P02ATI40=3@d03<c<`1WIfL0PX:203@d=029RHT0AdM703Lg=`14A4@0Lg=c0410@00m?Cd0M7Ad02XZ
:P0/;2`0>CTi05aLG015ADD0@d=30<?3``0g=cL0?3`l0861P@0l?3`0?clo06IVIP1?Cdl0FEUI0:6Q
X@26QXH0:RXZ0451@@10@400DE5A05iNGP37alL0BTY:0451@@1JFUX0DU9B07MgM`1jNWX06ATI03/k
>`1EEED0EUIF06IVIP2NWYh0:BTY0451@@1VIVH0De=C05iNGP1]KFd092@T03Xj>P1kNg/0KVi^03dm
?@22PX80:BTY02<S8`1JFUX0Xj>S04i>CP1RHV80E5AD028R8P18B4P0PH6108B4Q00k>c/0NGUi03De
=@0Q8B40E5AD07EeM@1:BTX08b<S04a<C017AdL0DE5A04a<C01_Kfl0@T92038b<P1DE5@0BTY:034a
<@1jNWX0VIVI02/[:`0l?3`0B4Q80492@P1GEeL0^KVi092@T00[:b/0>c/k04A4A01>CTh0F5QH09JF
UP2>SXh06QXJ038b<P11@D40DU9B04E5A@1mOGd0G5aL01LG5`13@d<0DE5A05ADE00d=3@0ADE502PX
:00N7Qh0:b/[04E5A@1XJ6P0;Rh^0492@P0c<c<092@T04E5A@13@d<0@T9201XJ6P0h>3P0=CDe0:ZZ
ZP2NWYh0QXJ604A4A01MGEd0Lg=c071`L01/K6`0L71`04M7A`1NGUh0F5QH059BDP1/K6`0FUYJ06e]
K@2@T900OWin08B4Q01HF5P0EUIF06EUI@0j>SX0GEeM05QHF01BDU80>3Ph04e=C@1;Bd/0CDe=04m?
C`1@D500=CDe04M7A`1>CTh0>c/k05MGE`1NGUh0De=C03hn?P1ADE40L71`0;6a/@21PH40B4Q805EE
E@1>CTh0@d=303hn?P0j>SX0>3Ph04];B`12@T80>SXj04i>CP11@D40?clo04m?C`18B4P0>CTi04Y:
BP16ATH0E5AD04i>CP19BDT0Cdm?06a/K01EEED0Cdm?04I6AP11@D40>c/k04M7A`0/;2`0@41004m?
C`1NGUh0F5QH04i>CP1EEED0E5AD05EEE@80AdM701l0>c/k03@d=00m?Cd0?clo01XJ6P1<C4`0E5AD
034a<@0_;bl0:b/[04E5A@0V9RH0:RXZ04];B`0c<c<0@d=302`/;010@4008B4Q02@T9018B4P0@410
02h^;P0G5aL0@D5104A4A00k>c/08b<S03Xj>P13@d<0BDU90080>c/k08h0>3Ph04Y:BP1UIFD0Cdm?
03<c<`0f=SH0C4a<05eMG@1dM7@0P82007=cL`1NGUh0EUIF06YZJP1cLg<0?3`l03Hf=P12@T80=SHf
04A4A017AdL0BDU905YJFP1MGEd0TI6A06a/K01;Bd/0QhN705iNGP0o?cl0?Shn04=3@`1<C4`0G5aL
0451@@1jNWX0KFe]02h^;P1RHV80=SHf04A4A012@T80?3`l02l_;`1IFET0EeMG05ADE016ATH0?Cdm
04E5A@1JFUX0N7Qh05iNGP0S8b<0;bl_065QH@1?Cdl0L71`05mOG`0c<c<0MWIf0:ZZZP1PH600@410
05UIF@1QHF40RHV905QHF01`L700JFUY0451@@1_Kfl0ADE50451@@1<C4`0F5QH05ADE01CDe<0>SXj
05EEE@17AdL0ADE504A4A00g=cL0=SHf059BDP1?Cdl0:2PX04m?C`1GEeL05QHF03lo?`0c<c<0>c/k
059BDP0N7Qh0EeMG05UIF@0<30`0HF5Q075aL@0E5AD09bLW03lo?`0l?3`0>CTi059BDP1WIfL0CTi>
065QH@1cLg<0PX:205=CD`18B4P0Cdm?01/K6`1ZJVX0LG5a03Xj>P1YJFT0EeMG06m_K`1;Bd/0KFe]
05=CD`1=CDd0@T9204E5A@1IFET0A4A4069RHP2DU9@0Kfm_04Y:BP2ATI408b<S04=3@`1OGel0<C4a
08V9R@13@d<0Lg=c0P1kNg/05P0`<300XJ6Q07MgM`1cLg<0R8R806a/K01bLW80@D5107EeM@1WIfL0
A4A40451@@1DE5@0<c<c02h^;P0h>3P0=3@d03lo?`1HF5P0:2PX05]KF`0f=SH204=3@`0R06YZJP1C
De<0J6QX05eMG@1XJ6P0V9RH04I6AP1dM7@0IfMW05iNGP1hN7P0=CDe03<c<`1:BTX0?clo04e=C@1E
EED0>SXj0451@@0i>CT0E5AD04m?C`1NGUh0T92@07moO`1OGel0[Jf]07AdM01WIfL0K6a/0;6a/@1O
Gel0SXj>0:b/[0;ooooo0000602DU9@0D51@05QHF01YJFT0[Jf]07moO`0c<c<0LG5a09fMW@1LG5`0
ZJVY06i^KP11@D40CTi>06][J`1:BTX0EEEE04e=C@0W9bL0K6a/08>3P`17AdL0LG5a09bLW080=3@d
0=l0LW9b07]kN`0n?Sh0HF5Q04e=C@0L71`0EeMG09ZJVP1RHV80ATI605=CD`0_;bl092@T05EEE@2N
WYh0DE5A04m?C`1OGel06a/K02/[:`1XJ6P0IfMW02l_;`1<C4`0?Cdm028R8P1QHF40OGem038b<P1:
BTX0IfMW05UIF@0j>SX0Shn?03lo?`0F5QH0@D5105UIF@1TI6@0HF5Q0;Ng]`13@d<0:RXZ04U9B@12
@T80GEeM0:n_[`2m_Kd08B4Q03Hf=P0i>CT0ATI605ADE01mOGd0>SXj02PX:01<C4`0GemO06UYJ@0e
=CD0ATI603De=@0T92@0;bl_061PH01MGEd0=CDe07IfMP0m?Cd0:2PX071`L02FUYH0<S8b02/[:`15
ADD0<30`03Ti>@2:RXX0SHf=024Q8@0_;bl0<30`06MWI`1<C4`0UiNG04U9B@0E5AD0=cLg05mOG`1_
Kfl0O7al08R8R00n?Sh06a/K06QXJ01eMGD0@41005aLG02?Shl0<c<c01/K6`1KFe/0JVYZ0451@@1N
GUh0YJFU02/[:`0];Bd0AdM707IfMP0n?Sh0=SHf04I6AP0^;Rh06ATI07]kN`2l_;`0D51@028R8P1=
CDd0:BTY02l_;`2GUiL0]KFe02HV9P0];Bd0ADE503Xj>P1KFe/0c/k>05mOG`0W9bL0?Cdm05]KF`27
QhL0QHF501LG5`18B4P0H61P04a<C018B4P0OGem04Y:BP0O7al0DU9B071`L01<C4`092@T065QH@0h
>3P06ATI04I6AP1]KFd0CTi>03Lg=`1FEUH0;bl_02LW9`1^KVh0Y:BT04M7A`0Z:RX0=cLg03hn?P15
ADD0T92@08>3P`0P8200=cLg04a<C01:BTX0FEUI0:BTY01EEED0:2PX04Q8B01BDU80FEUI07YjNP2W
YjL09bLW04m?C`29RHT0Cdm?06QXJ02_[jl0:b/[03Lg=`1YJFT0TI6A04A4A01[Jf/0CDe=02PX:00m
?Cd0JVYZ07IfMP1:BTX0K6a/02HV9P1MGEd0Lg=c03`l?01PH600KFe]02PX:00m?Cd0OGem06EUI@1F
EUH0GUiN02h^;P19BDT0LG5a05mOG`0];Bd0FEUI04M7A`1`L700];Bd03lo?`0Q8B40>c/k0080DE5A
08h0UYJF08J6QP0U9BD0>c/k05UIF@1`L700Jf][0;Vi^@1XJ6P07alO03lo?`1DE5@0EeMG06a/K02^
[Zh0GemO02TY:@1ADE40Cdm?05UIF@1/K6`0`l?303lo?`0h>3P0@D5106][J`1^KVh0I6AT09BDU00]
;Bd0;2`/04=3@`23Ph<0BDU904e=C@1LG5`0;Rh^030`<01CDe<0G5aL03<c<`0d=3@0NGUi02d];@11
@D40FEUI06EUI@0k>c/09bLW05aLG019BDT0Fe]K07IfMP1JFUX04a<C02d];@1:BTX0E5AD04a<C02=
SHd0Ng]k01/K6`0m?Cd0BDU9069RHP0i>CT0MGEe04=3@`15ADD0Fe]K07UiN@1OGel0?clo0492@P1?
Cdl0F5QH05UIF@1]KFd0][Jf07emO@13@d<0ADE505UIF@28R8P0HV9R055AD@1VIVH0H61P051@D01G
EeL0BDU905MGE`1<C4`0De=C04m?C`1NGUh0JFUY06ATI00l?3`0BTY:03Xj>P20P800IVIV034a<@1<
C4`0L71`06][J`1DE5@0GUiN08V9R@2XZ:P0IVIV0410@01ADE40C4a<03lo?`1EEED0CDe=05UIF@1U
IFD0@41005ADE01VIVH0E5AD02@T900c<c<0B4Q804e=C@1MGEd08R8R034a<@1>CTh0Cdm?04i>CP12
@T808b<S03De=@1<C4`0CTi>04m?C`0i>CT0?Shn0P1BDU80<`1>CTh0EeMG06ATI01PH600D51@04Y:
BP0m?Cd0?Shn04I6AP1>CTh0@d=304E5A@0e=CD0>3Ph03/k>`0f=SH0>CTi030`<00g=cL09bLW02PX
:010@400ADE503Ti>@0U9BD0<S8b020P800e=CD0>c/k03<c<`0];Bd0=CDe03lo?`0i>CT0?3`l04=3
@`0k>c/0@D5103dm?@0n?Sh0GemO05iNGP1MGEd0;bl_04a<C01?Cdl0B4Q804U9B@1WIfL0N7Qh09FE
U@0208f=S@0807QhN01LG5`0C4a<03dm?@0_;bl0@41002@T9012@T8204U9B@1^04Y:BP1DE5@0?Shn
05]KF`1@D500FEUI04I6AP20P800MWIf04m?C`2KVi/0N7Qh03<c<`10@400C4a<04i>CP1@D500:b/[
03<c<`1fMWH0I6AT059BDP18B4P0@d=3051@D02c/k<0L71`06UYJ@1BDU80;2`/03/k>`1ADE40BDU9
04Y:BP11@D40U9BD0:2PX00k>c/0C4a<08B4Q01KFe/0GUiN0820P018B4P0NGUi06=SH`2][Jd0>CTi
01lO7`1@D500BDU905]KF`1YJFT0:RXZ02h^;P18B4P0BTY:06=SH`0K6a/09bLW04Y:BP0n?Sh0EUIF
06QXJ01`L700?clo051@D01KFe/0<30`04];B`11@D40?3`l05IFEP0_;bl0IfMW04U9B@0n?Sh0GemO
05]KF`0N7Qh0C4a<04A4A015ADD0>SXj05]KF`1DE5@0LG5a061PH01]KFd0O7al02h^;P1[Jf/0IfMW
01TI6@0`<300DE5A07=cL`2HV9P0EEEE05iNGP1UIFD0Rh^;038b<P0i>CT0HF5Q03Ph>013@d<0F5QH
04I6AP1@D50204e=C@0<0:^[Z`13@d<0Ng]k07inOP0F5QH0JFUY01DE5@25QHD0NGUi07EeM@1;Bd/0
J6QX0P1VIVH0=P1cLg<0?3`l04];B`0c<c<0Jf][06QXJ019BDT0ATI608n?S`1LG5`0;Rh^04m?C`0b
<S80>CTi059BDP17AdL0NWYj04=3@`1BDU80=CDe03dm?@1NGUh0JVYZ096AT@1SHf<0Ogmo09:BTP1n
OWh0N7Qh08n?S`22PX80@d=304];B`1MGEd0JVYZ07=cL`16ATH0?Cdm03hn?P0g=cL0DU9B06ATI01S
Hf<0HV9R07moO`1bLW80NGUi08>3P`2][Jd0Fe]K09:BTP1;Bd/0Hf=S0;Rh^0;ooooo00009P2GUiL0
DE5A07emO@10@400KFe]0;Bd]01QHF40FUYJ04U9B@0c<c<0Fe]K07IfMP0h>3P0CDe=04];B`15ADD0
EEEE0:2PX00j>SX0=CDe05IFEP0n?Sh0HV9R0861P@0^;Rh06QXJ03lo?`1PH600NGUi07IfMP1EEED0
5QHF02DU9@1>CTh0GEeM06ATI02^[Zh0?clo0P0Y:BT0o`1ZJVX0GUiN08N7Q`1kNg/08R8R04A4A016
ATH0B4Q804U9B@1kNg/0;Rh^01<C4`0m?Cd0LG5a05QHF01dM7@0cLg=01dM7@0a<C40LW9b06][J`19
BDT0J6QX03dm?@0T92@0@D5105]KF`1<C4`0;Rh^05IFEP0h>3P05ADE06ATI02PX:00EEEE01LG5`1@
D500ATI601`L701HF5P0PX:2024Q8@0[:b/0BTY:03dm?@1>CTh0UiNG04];B`0U9BD09bLW03`l?01E
EED0Hf=S0;Ng]`1LG5`05ADE02`/;01KFe/0FUYJ06][J`1gMgL0<c<c01LG5`0e=CD0IfMW055AD@1N
GUh0NGUi01`L700T92@0Cdm?06QXJ00i>CT0FUYJ06e]K@0@4100>CTi08j>SP1HF5P05QHF05eMG@0i
>CT0;Rh^05=CD`2TY:@0E5AD01@D501>CTh0EeMG03lo?`1]KFd0YJFU04a<C00U9BD0De=C04Y:BP1P
H600LW9b08n?S`0f=SH0;bl_04=3@`1YJFT0QXJ606e]K@2KVi/0>c/k01`L700a<C40Kfm_04E5A@1l
O7`0KFe]02DU9@0T92@0I6AT08b<S00f=SH0OWin02TY:@0k>c/0Ti>C03dm?@0e=CD0BDU9038b<P11
@D40HV9R0861P@0k>c/0;2`/05ADE00n?Sh0=CDe08:2PP2LW9`0;2`/03@d=01?Cdl0EEEE06ATI02@
T900?Cdm01lO7`0X:2P0?clo04Y:BP1/K6`0TY:B01TI6@0U9BD0;bl_06][J`10@400G5aL05]KF`0T
92@0;Bd]04];B`1NGUh0:BTY04e=C@11@D408R8R04M7A`1_Kfl0@d=30451@@1EEED0:2PX05IFEP1P
H600Bd];02d];@1TI6@0>3Ph04e=C@2ZZZX0NGUi01dM7@0c<c<0E5AD03`l?01`L700SXj>02@T900k
>c/0BDU90410@02e]KD0WIfM02PX:00];Bd0HV9R061PH02CTi<0SXj>03Hf=P0k>c/0FUYJ05MGE`1h
N7P0[Zj^0451@@0f=SH0HF5Q06IVIP14A4@0J6QX02TY:@0W9bL0?Shn08J6QP1:BTX0EeMG06m_K`0Y
:BT09BDU04i>CP1hN7P0>SXj03Ph>011@D409bLW02/[:`1HF5P0Xj>S03`l?01<C4`0EeMG01`L700f
=SH0LW9b06UYJ@0U9BD0Cdm?03lo?`0l?3`0BTY:08F5Q@19BDT07alO04E5A@10@400DE5A09VIV@2@
T900:2PX01XJ6P1ADE40NWYj04Y:BP1iNGT0dm?C03lo?`00D@0`<300IVIV04i>CP1=CDd0Cdm?07in
OP0o?cl09bLW059BDP1^KVh0Cdm?05MGE`1nOWh0;Bd]01dM7@11@D40DE5A03<c<`0j>SX0Kfm_01<C
4`0d=3@0MGEe05eMG@2<S8`0SXj>05QHF019BDT0FUYJ08J6QP1/K6`0CDe=04U9B@1IFET0IfMW08R8
R01HF5P0CTi>08>3P`1[Jf/0/;2`09RHV02FUYH0QXJ605QHF01ZJVX0KFe]05mOG`1IFET0HV9R071`
L01lO7`0GemO06ATI01;Bd/0FUYJ0492@P19BDT0Kfm_038b<P1JFUX0EEEE06IVIP1bLW80RXZ:09BD
U02<S8`0NGUi059BDP1:BTX0K6a/04I6AP1KFe/0EeMG02h^;P1VIVH0A4A4055AD@17AdL0GEeM0410
@00204A4A00?03Ti>@1?Cdl0<C4a034a<@1LG5`0Jf][04a<C012@T80?3`l065QH@1cLg<0Bd];02h^
;P1>CTh0GemO0080A4A402P0EUIF0861P@2?Shl0DU9B02<S8`0g=cL0DE5A04];B`0i>CT09BDU03Ti
>@1>CTh0IFEU05iNGP0m?Cd0@41005=CD`0_;bl0<S8b03Ti>@0W9bL0<c<c02d];@1:BTX09RHV02d]
;@0O7al0@41005EEE@0k>c/0ATI605=CD`1IFET09BDU0410@01EEED0>3Ph02DU9@0f=SH0<S8b0P0i
>CT0;@0n?Sh0ATI60492@P1>CTh0A4A404e=C@15ADD0IFEU09RHV01XJ6P0<C4a03lo?`1LG5`0Lg=c
03Lg=`0L71`0=cLg0410@00g=cL0=3@d0410@01`L700IFEU05]KF`1MGEd0Bd];09nOW`1BDU80@T92
04M7A`16ATH0?3`l05IFEP0g=cL0B4Q805YJFP1OGel0K6a/05=CD`1IFET0>c/k038b<P0e=CD0K6a/
06MWI`0205eMG@0K04=3@`0o?cl0DE5A06=SH`1KFe/0D51@07YjNP2GUiL0BDU90410@01<C4`0820P
06MWI`2j^[X0EUIF038b<P1@D500A4A407=cL`1:BTX0EeMG04];B`0R8R80C4a<03Ph>00X:2P0?Cdm
00<0CDe=0380;Bd]03`l?00k>c/0>3Ph04a<C00k>c/0<c<c051@D018B4P0F5QH0820P01cLg<0CTi>
04];B`1JFUX0MWIf08R8R01<C4`0L71`03<c<`0^;Rh0QHF506m_K`0K6a/08B4Q03<c<`1=CDd0@410
051@D01<C4`0B4Q8055AD@1WIfL0M7Ad0410@026QXH0Ogmo03<c<`1:BTX0C4a<04E5A@1bLW80JFUY
06a/K014A4@0Fe]K04I6AP0i>CT0=SHf03Ti>@80ATI601X0DU9B06=SH`1ZJVX0HV9R09:BTP0g=cL0
?clo04e=C@0h>3P0QhN7038b<P26QXH0Ng]k09NGU`1PH600KVi^05iNGP1ADE40Ti>C03lo?`1FEUH0
:RXZ05EEE@18B4P0PX:2065QH@80BDU902`0@T92079bLP1ADE40@T9203Lg=`0S8b<0?Cdm034a<@1`
L700EUIF061PH01dM7@0IfMW08>3P`1UIFD0/[:b07]kN`24Q8@0GemO05=CD`1UIFD0DE5A06QXJ01;
Bd/0<S8b0492@P15ADD0FUYJ04I6AP0c<c<0?Cdm05eMG@1aLG40G5aL08V9R@1UIFD0PX:206m_K`1M
GEd0HF5Q0:2PX01WIfL0OWin0<;2`P;ooooo0000NP2=SHd0T92@0;:b/P11@D40Bd];08Z:RP1ZJVX0
YjNW07EeM@10@400AdM707EeM@1EEED0[Zj^05YJFP0i>CT0?clo04i>CP1MGEd0OGem08J6QP0K6a/0
HV9R061PH01FEUH0Cdm?0:BTY00b<S80<c<c07AdM01iNGT0D51@09BDU01@D500=SHf06m_K`1WIfL0
Lg=c05=CD`1RHV805QHF02LW9`14A4@0HV9R03<c<`11@D40GemO03<c<`11@D40IVIV06=SH`0_;bl0
?Shn04Y:BP0^;Rh0FEUI0:>SX`1QHF40;Bd]05mOG`11@D40@4100:f][@1aLG40820P02TY:@1BDU80
FUYJ06e]K@1aLG40<C4a02d];@0L71`0D51@0820P019BDT0Jf][04a<C00G5aL0<C4a05=CD`1GEeL0
?Cdm08b<S00P8200:BTY038b<P1iNGT0EeMG06m_K`1HF5P09bLW01hN7P0m?Cd0JVYZ038b<P13@d<0
Bd];014A4@1BDU80P82003Hf=P0S8b<0<S8b03Lg=`0];Bd0Hf=S09ZJVP0_;bl05ADE03lo?`1;Bd/0
=3@d07]kN`2[Zj/08B4Q01<C4`0c<c<0DU9B03`l?02`/;00J6QX0P0W9bL0S`1>CTh0LG5a03`l?02`
/;00GUiN01hN7P0d=3@0CDe=05mOG`0`<300K6a/08J6QP0G5aL0ATI606m_K`1XJ6P09RHV071`L01H
F5P061PH0492@P28R8P0H61P01dM7@13@d<0=SHf02/[:`1dM7@0RXZ:02@T900V9RH0@41004i>CP1<
C4`0b<S803Hf=P0V9RH0LW9b03lo?`1/K6`0LW9b02<S8`0Y:BT0?Shn09NGU`1bLW80MgMg09>CT`0Y
:BT0?clo04E5A@2>SXh0A4A405IFEP1QHF404a<C038b<P1NGUh0KFe]03De=@1ADE40J6QX01hN7P0j
>SX0Q8B404];B`0Z:RX0ADE503Ti>@0Y:BT0De=C07inOP0T92@09BDU05ADE00m?Cd0?Shn08B4Q01X
J6P0;Bd]04Y:BP1XJ6P0=CDe06MWI`1oOgl0<C4a030`<01PH600IFEU06ATI02YZJT0Cdm?018B4P1?
Cdl0MgMg06EUI@1ADE40Ogmo034a<@0_;bl0UIFE0492@P1RHV80?clo02<S8`14A4@0T92@03Lg=`0o
?cl0F5QH02LW9`0/;2`0GemO05MGE`0m?Cd0JFUY03<c<`0b<S80L71`04e=C@0f=SH0F5QH02DU9@1D
E5@0U9BD06IVIP0O7al0<S8b04Y:BP0k>c/0VYZJ08:2PP0o?cl0=CDe04m?C`1CDe<0@T9207AdM01o
Ogl09BDU03Lg=`0h>3P0GEeM0080J6QX05h0Vi^K02<S8`0[:b/0K6a/06i^KP0/;2`0Ogmo04=3@`0Z
:RX0=SHf06a/K01hN7P0<c<c07AdM010@400<S8b03Xj>P1jNWX0GEeM02PX:011@D40@T9203Xj>P12
@T80GemO06IVIP0_;bl0BTY:0410@01:BTX0NGUi09BDU018B4P0;Rh^03Lg=`0h>3P09BDU05=CD`2K
Vi/0>c/k020P800/;2`0A4A404=3@`1LG5`0TY:B02XZ:P0E5AD0ATI607UiN@1LG5`0Jf][06IVIP14
A4@0GemO05eMG@1oOgl0O7al07AdM02UYJD0^;Rh0:j^[P20P800NGUi08f=S@2DU9@0W9bL08V9R@1h
N7P0KFe]07UiN@1gMgL0BTY:05ADE01RHV80EeMG04M7A`1UIFD0KFe]06=SH`1GEeL0NWYj061PH01K
Fe/0NWYj059BDP1ZJVX0PH6107MgM`1hN7P0TY:B08N7Q`3:b/X0UiNG0P1CDe<0@01[Jf/0HV9R071`
L01OGel0@41008:2PP1<C4`0GEeM05QHF023Ph<0De=C05eMG@1EEED0?3`l08:2PP0`<300>SXj06MW
I`1ADE40MGEe05IFEP1RHV80GEeM04];B`1>CTh0<c<c05=CD`11@D40D51@04U9B@20P800De=C04Y:
BP1TI6@0A4A4055AD@10@400Cdm?05MGE`0e=CD0@d=304m?C`0S8b<0Cdm?04Y:BP0`<300=3@d02<S
8`0f=SH08R8R01dM7@10@400;bl_03/k>`0L71`0@d=301@D500^;Rh0Cdm?03<c<`0X:2P0?clo04e=
C@0o?cl203Ph>00i04M7A`0i>CT0B4Q804M7A`12@T80?Shn04e=C@1IFET0Bd];02DU9@0b<S80I6AT
04];B`17AdL0?3`l04=3@`1?Cdl0G5aL04A4A00o?cl0<C4a030`<00b<S809RHV04A4A00l?3`0BTY:
03Lg=`1IFET0MGEe06][J`0^;Rh0;Bd]03@d=01KFe/0IFEU04e=C@2=SHd0S8b<02`/;01;Bd/0DU9B
04M7A`0j>SX0>CTi030`<01MGEd0L71`03De=@0h>3P0;Bd]04E5A@1/K6`0JFUY06YZJP1TI6@0>c/k
0080@41006/0=cLg04];B`13@d<0QXJ607YjNP0L71`0PH610<_;b`1UIFD0<c<c05]KF`0o?cl0RHV9
05iNGP1gMgL0>CTi02XZ:P1_Kfl0?clo03hn?P1@D500?3`l05IFEP1EEED0=3@d04U9B@0[:b/0?3`l
02/[:`0j>SX0@41005EEE@1LG5`0=SHf03lo?`0j>SX07alO03/k>`1:BTX0?3`l059BDP0m?Cd0JFUY
065QH@0I6AT0B4Q805IFEP0U9BD0;bl_04A4A010@400ADE5055AD@1@D500DU9B05]KF`1VIVH0Shn?
03/k>`1EEED0HF5Q03Ti>@13@d<0CTi>055AD@1iNGT0IVIV092@T019BDT0I6AT0451@@1CDe<0C4a<
04];B`1PH600CTi>04Y:BP2@T900TI6A05=CD`2CTi<0?Cdm05EEE@1LG5`0=CDe08N7Q`12@T80LW9b
05mOG`1_Kfl0B4Q80:2PX01VIVH0EUIF08>3P`1>CTh0KFe]05IFEP30`<00JFUY0451@@13@d<0FEUI
04E5A@1DE5@0OGem05=CD`0204A4A00W02DU9@0n?Sh0C4a<06=SH`1UIFD0GUiN06e]K@1<C4`0R8R8
05ADE033`l<0Jf][05eMG@1NGUh0EUIF07QhN00V9RH0<c<c04Q8B010@400CDe=02XZ:P0^;Rh0ADE5
030`<00S8b<0ATI605YJFP1eMGD0MgMg06UYJ@2/[:`0OWin0861P@1fMWH0/[:b05QHF01cLg<0cLg=
00;ooooo0000EP1DE5@0G5aL0861P@2=SHd0VIVI06ATI01;Bd/0FEUI07moO`1;Bd/0JVYZ04M7A`0b
<S80?clo06EUI@0a<C40BDU902d];@0c<c<0CDe=07YjNP18B4P0@d=305ADE00l?3`0A4A409BDU01V
IVH0;Bd]04Y:BP14A4@0E5AD06i^KP1`L700820P03Lg=`0o?cl0AdM707QhN02d];@0BTY:02@T9012
@T80Bd];06ATI01fMWH0QXJ601PH601:BTX0JVYZ055AD@1dM7@0IVIV08:2PP0F5QH0CDe=08f=S@1d
M7@0CTi>09BDU00a<C408R8R04Y:BP2NWYh0CDe=04E5A@2<S8`0;Rh^02LW9`1PH600Rh^;04E5A@1A
DE40GemO02HV9P0n?Sh0?clo061PH00U9BD0?Shn03Lg=`0m?Cd0BTY:09>CT`1DE5@09BDU0P17AdL0
7P0l?3`0DE5A06YZJP0W9bL06a/K03Lg=`1EEED0C4a<07inOP1dM7@08B4Q01<C4`18B4P0JFUY04M7
A`1fMWH0>CTi01/K6`0g=cL0Fe]K075aL@0b<S80MGEe02PX:00A4A40@T9206m_K`1FEUH09RHV05AD
E0809BDU01<0ADE505YJFP0/;2`0@D5105iNGP0Q8B40@T920:FUY@1XJ6P08b<S02l_;`1:BTX0=3@d
055AD@2YZJT0[Jf]02XZ:P0K6a/0?Shn0080ATI600/0]kNg09>CT`0O7al0:b/[04e=C@1CDe<0D51@
09JFUP13@d<0;bl_04E5A@0207MgM`0K06IVIP20P8009BDU03Ph>01NGUh0G5aL04U9B@1HF5P0=cLg
04=3@`1mOGd0JVYZ02h^;P1OGel0;Bd]03Ph>01YJFT0N7Qh03`l?00J6QX0;Rh^03Lg=`1:BTX0LW9b
0;6a/@15ADD0820P0080DU9B00X0Bd];08N7Q`2[Zj/0;bl_02<S8`1MGEd0D51@04Y:BP2BTY80=cLg
0P0j>SX0SP1^KVh0GUiN05MGE`1dM7@08b<S03/k>`1GEeL0LG5a03lo?`21PH40HV9R024Q8@1=CDd0
F5QH03/k>`0l?3`0IVIV02DU9@15ADD0Ti>C08R8R015ADD0EUIF05MGE`0n?Sh0HF5Q09fMW@1=CDd0
>3Ph04e=C@1<C4`0IfMW069RHP0/;2`0@d=305QHF01JFUX0Kfm_0;no_`0o?cl0=CDe04e=C@1ZJVX0
A4A40:6QX@11@D40;Rh^05MGE`1QHF40F5QH0;Ng]`0g=cL08B4Q05YJFP1bLW80FEUI07MgM`1EEED0
6QXJ04I6AP1OGel0EUIF03hn?P2<S8`0>c/k04I6AP1FEUH0Shn?0451@@0g=cL0G5aL03dm?@11@D40
@d=306a/K01iNGT0:b/[04i>CP0e=CD0@41005=CD`1JFUX05aLG02d];@18B4P0@410065QH@2;Rh/0
EEEE01PH600c<c<0DU9B03`l?018B4P0Ogmo051@D00H61P0?clo065QH@1LG5`0ADE508j>SP1IFET0
3@d=034a<@18B4P0GUiN04i>CP1`L700>c/k01lO7`0X:2P0GEeM09:BTP17AdL0CTi>02HV9P0J6QX0
9bLW04e=C@1MGEd0<S8b04i>CP17AdL0Lg=c08^;R`2WYjL0OGem07MgM`1cLg<0MGEe06QXJ01TI6@0
JFUY0;6a/@20P800@d=30451@@1TI6@0EeMG08R8R02=SHd209:BTP0;05]KF`29RHT0EUIF03`l?01H
F5P0L71`04e=C@20P800G5aL06ATI00n?Sh00P1;Bd/0C@1_Kfl0MWIf02d];@1ADE40Q8B408J6QP1]
KFd0Ogmo09nOW`30`<00M7Ad04E5A@1OGel0CTi>03<c<`0k>c/0C4a<05EEE@1CDe<0A4A4059BDP1P
H600D51@02/[:`0i>CT0D51@06ATI01NGUh0Bd];05=CD`1oOgl0MGEe08j>SP24Q8@0Kfm_079bLP1K
Fe/0K6a/05ADE01[Jf/0EUIF06e]K@1^KVh0N7Qh07UiN@1mOGd0LG5a05]KF`1ZJVX0DU9B0451@@1R
HV80J6QX051@D01EEED0@D5105EEE@1IFET0B4Q805=CD`18B4P0DU9B03@d=00[:b/0EeMG04A4A010
@400<c<c04U9B@0O7al0>3Ph04m?C`0n?Sh0;2`/055AD@1CDe<0CDe=0080?3`l00h0ADE504M7A`12
@T80=3@d05=CD`1OGel0D51@03Xj>P1PH600C4a<04M7A`1=CDd0@d=303hn?P80DU9B00D0Bd];05]K
F`1JFUX0EeMG03`l?00204=3@`1:02h^;P1>CTh0Bd];05EEE@1CDe<0Kfm_09NGU`2EUID0Fe]K07Qh
N01OGel0GEeM07MgM`0n?Sh09BDU03@d=00Z:RX0=CDe04Y:BP0h>3P0FEUI04A4A012@T80>3Ph04Y:
BP1?Cdl0H61P051@D01_Kfl0WYjN07MgM`0];Bd0<30`0451@@1JFUX0Lg=c05UIF@1ZJVX0@4100:f]
[@2ZZZX0=CDe05UIF@2;Rh/0EeMG05YJFP1cLg<0=cLg059BDP1;Bd/0W9bL03Lg=`0L71`0>3Ph034a
<@0W9bL0?Cdm03De=@12@T80A4A4038b<P10@4009BDU02/[:`0d=3@0@41003Ti>@1lO7`0MGEe03/k
>`1NGUh0De=C03@d=01?Cdl203lo?`0N05aLG01GEeL0MGEe03`l?00U9BD0DU9B05EEE@0M7Ad0@d=3
04a<C00o?cl0@T9206EUI@1QHF40GemO061PH01lO7`0SHf=04M7A`1NGUh0J6QX03/k>`1VIVH0NGUi
05QHF01RHV80B4Q8061PH00h>3P0L71`0P0m?Cd09P1=CDd0>CTi04m?C`16ATH0@T92055AD@1HF5P0
De=C09:BTP0W9bL0L71`05aLG00J6QX0KFe]01dM7@1lO7`0Lg=c07EeM@1<C4`0L71`07MgM`1jNWX0
SXj>07AdM02BTY80G5aL069RHP1=CDd0EUIF04Y:BP1jNWX0?clo03@d=01RHV80=CDe05YJFP22PX80
?Cdm0P1:BTX0901LG5`0CTi>07AdM01MGEd0GemO07=cL`11@D40^KVi05]KF`1IFET0EEEE04M7A`23
Ph<09BDU04];B`1IFET0ATI605eMG@0/;2`0<S8b03Xj>P1ADE40;2`/051@D01LG5`0JFUY0820P01Q
HF40MgMg0820P03:b/X0V9RH08n?S`2ATI40T92@0;Bd]0;ooooo0000I@25QHD0DU9B06ATI01ADE40
Ogmo06IVIP0o?cl0Bd];06QXJ01gMgL0X:2P07IfMP0b<S80AdM703/k>`1SHf<0Z:RX05MGE`0];Bd0
J6QX05iNGP1ADE40[Zj^0::RXP0c<c<0Cdm?06EUI@1KFe/0I6AT0:b/[016ATH0;2`/05aLG028R8P0
ADE504i>CP1SHf<0820P034a<@2BTY80YjNW04a<C01/K6`0?Shn01`L701GEeL0MWIf04=3@`0Q8B40
DE5A02XZ:P0^;Rh0IfMW08N7Q`0j>SX0@d=304I6AP0W9bL0:2PX08N7Q`1[Jf/08B4Q03@d=00l?3`0
@T9205aLG02;Rh/0C4a<01dM7@0_;bl0@41004];B`1eMGD0YjNW034a<@0U9BD0>CTi03hn?P1:BTX0
Ng]k08:2PP0G5aL0@41004];B`1BDU80Cdm?08J6QP0o?cl06a/K03Ti>@1=CDd0DU9B030`<01mOGd0
:RXZ02l_;`1=CDd0De=C01XJ6P0];Bd0B4Q80080;2`/0:X0I6AT06UYJ@0P8200:2PX0410@015ADD0
>c/k08R8R00j>SX05ADE02PX:01GEeL0M7Ad05QHF02@T900?3`l01<C4`1;Bd/0GEeM034a<@1:BTX0
GEeM02HV9P0A4A40C4a<08>3P`12@T80Cdm?05aLG00a<C409RHV03Lg=`29RHT0HV9R02d];@1@D500
6a/K03Lg=`1:BTX0GUiN02l_;`12@T80KVi^01DE5@0Q8B40L71`08N7Q`0H61P0ADE50492@P0_;bl0
@41008N7Q`0h>3P0;bl_04U9B@1BDU80Hf=S05iNGP0W9bL09BDU065QH@1[Jf/0Hf=S096AT@0e=CD0
9BDU04M7A`2EUID0JFUY079bLP1^KVh0:BTY02PX:013@d<0MgMg0;6a/@1=CDd0XZ:R02XZ:P0b<S80
IFEU09BDU022PX80De=C05IFEP0Y:BT0A4A4069RHP1kNg/0:BTY0492@P1;Bd/0?Shn05]KF`2IVIT0
Kfm_01dM7@1;Bd/0BDU903Ti>@2DU9@0]kNg04Q8B010@400F5QH05MGE`1kNg/0V9RH03lo?`0V9RH0
GemO09bLW01@D500Shn?05mOG`0e=CD0CTi>08f=S@1aLG40TI6A05EEE@0[:b/0V9RH08b<S016ATH0
GEeM05EEE@0O7al0H61P0;no_`1]KFd0GEeM061PH00Z:RX0?3`l06i^KP1aLG40DE5A06EUI@0o?cl0
AdM7096AT@1jNWX0@T92065QH@13@d<0<C4a04];B`1mOGd0=3@d04I6AP1VIVH0GEeM06MWI`2?Shl0
Bd];024Q8@0m?Cd0BDU906ATI026QXH0TY:B03Xj>P0Z:RX0G5aL03Xj>P1HF5P0GEeM08f=S@80=CDe
0?<0BTY:05UIF@15ADD0MWIf0:2PX00j>SX0<30`05YJFP1VIVH0ATI606][J`1cLg<09RHV03Ti>@1;
Bd/0MWIf03dm?@13@d<0GUiN02`/;00];Bd0Hf=S07=cL`0m?Cd0?3`l04M7A`0d=3@0BDU905mOG`1/
K6`08b<S02TY:@19BDT0=SHf06ATI02NWYh0DU9B01XJ6P0V9RH0ATI605UIF@1CDe<0UYJF05EEE@2N
WYh0UIFE07=cL`1JFUX0F5QH07=cL`1hN7P0JFUY05UIF@2`/;00ZZZZ0:FUY@1GEeL0C4a<09:BTP1]
KFd0[jn_08^;R`1mOGd0Shn?05YJFP1VIVH0Jf][04i>CP1EEED0KFe]07QhN01eMGD0EUIF07EeM@1A
DE40EEEE065QH@1@D500WYjN04I6AP1ZJVX0QXJ607alO025QHD0RXZ:0;Vi^@3@d=00VIVI04U9B@1J
FUX0PH6104A4A01ADE40GUiN03Ti>@1iNGT0AdM706IVIP1ADE40PX:204E5A@1<C4`0FUYJ03Ph>01i
NGT0>3Ph03De=@1QHF40Fe]K05MGE`0j>SX0?Shn07QhN024Q8@0BDU9038b<P1ADE40K6a/04I6AP0f
=SH0Fe]K07MgM`1oOgl0FUYJ038b<P1GEeL0Ng]k03@d=01@D500;bl_034a<@1@D500AdM705QHF00i
>CT09bLW04E5A@0K6a/09BDU034a<@0Y:BT0<30`02d];@12@T809BDU03/k>`0Q8B40@T92059BDP0m
?Cd0ADE505iNGP1KFe/0>CTi055AD@1FEUH0BTY:038b<P1IFET0EeMG04a<C011@D40F5QH04U9B@1>
CTh0IVIV05IFEP1>CTh0ATI606ATI01BDU80J6QX04e=C@1IFET0LW9b05YJFP1>CTh0ATI605=CD`0a
<C40I6AT03/k>`1LG5`0B4Q805UIF@1>CTh0KFe]065QH@1mOGd0Bd];06m_K`28R8P0@D5105eMG@1V
IVH0:BTY06i^KP1VIVH0>SXj04Y:BP1<C4`0FEUI04Q8B014A4@0:BTY051@D021PH40KVi^05UIF@1R
HV80C4a<05UIF@1PH600Hf=S04=3@`1RHV80Ph>302/[:`16ATH0@d=302TY:@2>SXh0kNg]06=SH`0S
8b<0@T9204A4A02LW9`0DE5A07MgM`1ADE40>SXj07IfMP0f=SH0<30`04a<C00i>CT0JVYZ04M7A`0b
<S80ATI603dm?@1@D5000P14A4@0:`0D51@0?clo04];B`1=CDd0U9BD04U9B@0e=CD0IVIV05=CD`1:
BTX0G5aL03Xj>P1EEED0AdM702HV9P29RHT0RXZ:01/K6`0/;2`0=cLg04];B`17AdL0C4a<04E5A@1@
D500E5AD05YJFP1_Kfl0Cdm?06ATI01RHV808b<S02PX:010@400GEeM08^;R`1JFUX0IFEU04I6AP1`
L700Bd];04e=C@1QHF400P1BDU80B@1eMGD0Hf=S05iNGP1UIFD0EEEE09ZJVP1=CDd0EEEE06a/K00P
8200I6AT02TY:@2FUYH0Y:BT07moO`1OGel0M7Ad0820P01]KFd0TY:B06ATI02HV9P0DE5A09NGU`1/
K6`0JVYZ06ATI01RHV80LG5a04e=C@1`L700EEEE0410@01:BTX0A4A406UYJ@12@T80FUYJ02h^;P1D
E5@0C4a<06YZJP1XJ6P0BTY:06QXJ01CDe<0EEEE05eMG@1PH600Vi^K03<c<`1;Bd/0EUIF04e=C@1T
I6@0?clo03/k>`1<C4`0?Cdm04A4A01YJFT0KFe]05YJFP1lO7`0GEeM075aL@1RHV80JFUY05EEE@1m
OGd0EUIF06=SH`2k^k/00_ooool0002J08B4Q02<S8`0XJ6Q04I6AP1BDU80NGUi05]KF`1lO7`0=cLg
03`l?01aLG40S8b<05iNGP1eMGD0?3`l030`<014A4@0QHF503lo?`1dM7@0HV9R028R8P0n?Sh0IfMW
0451@@0`<300BTY:02HV9P0S8b<0IFEU06ATI00M7Ad0=3@d03`l?013@d<0Ti>C07alO00_;bl06QXJ
04=3@`18B4P0H61P0:NWY`1>CTh061PH030`<016ATH0=cLg05aLG02IVIT09bLW01TI6@1<C4`0M7Ad
0492@P1mOGd0`l?3020P800V9RH0De=C06MWI`1ADE40KVi^061PH00T92@0D51@07MgM`1dM7@0A4A4
08:2PP0a<C40=CDe0410@01KFe/0LW9b038b<P1lO7`0<S8b02h^;P1:BTX0L71`04=3@`0l?3`0J6QX
02HV9P0m?Cd0De=C069RHP0N7Qh0B4Q803Xj>P0m?Cd0=cLg096AT@1nOWh07AdM03lo?`1WIfL0ADE5
06QXJ02=SHd092@T01lO7`1EEED0O7al0410@01JFUX0OGem014A4@0R8R80EUIF06m_K`0i>CT0GEeM
05IFEP0A4A40<C4a05=CD`1MGEd0?3`l05YJFP0d=3@0:RXZ04U9B@1lO7`0F5QH02/[:`16ATH0C4a<
01dM7@1ZJVX0VIVI03`l?00Q8B40ADE504M7A`0`<300GEeM08B4Q00c<c<08B4Q05iNGP1WIfL0<C4a
07EeM@2NWYh09bLW01dM7@1BDU80WYjN03Lg=`1fMWH0ATI602DU9@<0E5AD04`0BTY:07inOP0Y:BT0
=SHf05aLG011@D40DE5A05aLG00H61P0?3`l055AD@0l?3`071`L02l_;`1SHf<08R8R03Hf=P2KVi/0
GUiN01dM7@0_;bl0ADE503lo?`1BDU80ZZZZ04A4A00U9BD0=cLg05mOG`1MGEd0K6a/0:j^[P0/;2`0
>SXj04=3@`1aLG40CTi>0:FUY@2CTi<08b<S04I6AP1QHF40JVYZ04Q8B02KVi/0E5AD04e=C@1UIFD0
OWin05MGE`1WIfL0GUiN01`L7014A4@0SXj>06QXJ00d=3@0E5AD03Hf=P0i>CT0NGUi07moO`0/;2`0
IVIV059BDP0j>SX0GemO08b<S00d=3@0ADE503lo?`0[:b/0M7Ad08B4Q00N7Qh0>SXj0P1HF5P0:@1g
MgL0Vi^K02TY:@0o?cl0ADE505aLG022PX80_kno065QH@0N7Qh0GemO06m_K`1IFET0U9BD04e=C@0a
<C40ADE505mOG`0m?Cd0LW9b08F5Q@0O7al0CTi>06=SH`1^KVh0=CDe05mOG`1CDe<09bLW04M7A`1d
M7@0IVIV030`<02[Zj/0De=C03De=@0j>SX0M7Ad06YZJP0X:2P0Jf][0080@4100100AdM708:2PP19
BDT0;bl_055AD@0n?Sh0:b/[06ATI02YZJT0BTY:02PX:01>CTh0C4a<04Y:BP1lO7`0Y:BT0P0W9bL0
9`1=CDd0HF5Q071`L01gMgL0UIFE028R8P0M7Ad0AdM706i^KP1;Bd/0ADE509:BTP0l?3`09BDU03lo
?`1RHV80:2PX04Q8B011@D406QXJ01/K6`0k>c/0LW9b04Q8B01HF5P0LG5a065QH@1ADE40GEeM07Ad
M02/[:`0Z:RX0;Vi^@2UYJD0/k>c05IFEP1=CDd0S8b<08R8R0020;2`/01809VIV@1oOgl0DU9B0861
P@1WIfL0E5AD05EEE@1UIFD0ATI604e=C@13@d<0IFEU05iNGP1mOGd0IVIV059BDP2][Jd0DU9B079b
LP2:RXX0MgMg09nOW`2^[Zh0WIfM0<?3``2JVYX0Fe]K05iNGP1BDU80ATI605YJFP1WIfL0@T9207Yj
NP11@D40K6a/04a<C025QHD0AdM7055AD@1UIFD0?Cdm08V9R@0_;bl0=SHf06i^KP1FEUH0M7Ad0410
@01ZJVX0IFEU05MGE`1FEUH0:2PX05iNGP1BDU80KVi^04I6AP2FUYH0K6a/07=cL`2MWId0BTY:06=S
H`1VIVH0@T9205]KF`0f=SH0A4A405mOG`0c<c<0H61P0P0l?3`09P1;Bd/0;2`/02/[:`0h>3P0:RXZ
059BDP0h>3P0EEEE03Xj>P16ATH0:BTY0451@@1]KFd0=SHf034a<@14A4@0J6QX03dm?@1>CTh0AdM7
04e=C@0l?3`0D51@04U9B@1>CTh0C4a<05IFEP1>CTh0Fe]K0451@@19BDT0D51@04];B`12@T80=CDe
03dm?@1HF5P0N7Qh0P1YJFT0^`1;Bd/0GemO04m?C`13@d<0G5aL06MWI`1VIVH0Jf][06m_K`2JVYX0
UYJF07MgM`2[Zj/0J6QX05MGE`1gMgL0N7Qh075aL@2>SXh0<S8b04Y:BP20P800E5AD06YZJP1:BTX0
B4Q807EeM@1fMWH0DE5A06IVIP13@d<0J6QX05UIF@2@T900SHf=06IVIP10@400Kfm_055AD@18B4P0
DU9B03Ph>02OWil0V9RH01lO7`1HF5P0SXj>04i>CP0a<C40FEUI03Ph>01?Cdl0@D5109RHV015ADD0
3Ph>02h^;P0_;bl0ADE506IVIP0W9bL0;Rh^03De=@0_;bl0ADE501XJ6P0c<c<0;bl_03lo?`17AdL0
TY:B07=cL`0d=3@0>CTi04A4A00Y:BT0A4A404E5A@1DE5@0MWIf05IFEP1eMGD0LG5a030`<00i>CT0
DE5A02HV9P1:BTX0C4a<02DU9@0f=SH0C4a<0451@@1MGEd0H61P06EUI@1eMGD0=cLg07YjNP2OWil0
Bd];06ATI025QHD0C4a<04e=C@1gMgL0U9BD03`l?01WIfL0H61P05=CD`1@D500DU9B06e]K@18B4P0
Cdm?065QH@1YJFT0Lg=c0;Vi^@0S8b<0Cdm?05iNGP1>CTh0Kfm_04I6AP1RHV80MWIf06a/K00a<C40
MGEe061PH01iNGT0d];B08>3P`2<S8`0I6AT0:JVYP1^KVh0W9bL05ADE01ZJVX0GemO065QH@1_Kfl0
?Shn05=CD`16ATH0;Bd]03lo?`0S8b<0N7Qh03/k>`1_Kfl0EeMG07=cL`2CTi<0GEeM0:ZZZP1PH600
GemO05]KF`1ADE40SHf=05EEE@2@T900IfMW03`l?01CDe<0FUYJ06QXJ01@D500B4Q803/k>`16ATH0
HV9R08B4Q02>SXh0Lg=c0;jn_P2KVi/0UiNG08:2PP2ZZZX0D51@069RHP3:b/X00_ooool0003o05AD
E01GEeL0TY:B055AD@1bLW80Fe]K07YjNP3<c<`0KFe]03Hf=P1EEED0D51@08:2PP2l_;`0ADE503Hf
=P0_;bl0BTY:04Q8B02m_Kd0S8b<02XZ:P0i>CT0@41006QXJ02;Rh/0XZ:R02TY:@0Q8B40Fe]K069R
HP1MGEd0QhN706m_K`0H61P0<S8b0492@P1>CTh0>CTi07IfMP0S8b<0:BTY03Ph>01]KFd0;bl_06IV
IP1XJ6P0;bl_03Ph>01gMgL0TI6A03`l?00j>SX0I6AT028R8P0i>CT0HV9R04U9B@0[:b/0G5aL03/k
>`0W9bL0FEUI06e]K@0P8200;Rh^065QH@0l?3`0>3Ph06i^KP1?Cdl08R8R03/k>`11@D40H61P03dm
?@1^KVh0HV9R01hN7P0[:b/0EUIF06e]K@1HF5P0RXZ:01XJ6P0];Bd0G5aL08F5Q@11@D40PX:207If
MP0N7Qh09BDU05=CD`1gMgL0<C4a05QHF00g=cL06ATI03De=@17AdL0BDU901lO7`0f=SH0<c<c02TY
:@1:BTX0EUIF02`/;00F5QH0=cLg020P800N7Qh0T92@09VIV@0D51@0:2PX055AD@0f=SH0CDe=0;Rh
^02WYjL07alO04U9B@1EEED0DE5A04=3@`2_[jl0U9BD01DE5@0f=SH0>3Ph055AD@16ATH0Ph>306a/
K00J6QX0:b/[04];B`1KFe/0<C4a07EeM@1LG5`05QHF0451@@1UIFD0D51@02`/;01DE5@09RHV03dm
?@1SHf<0Lg=c02DU9@0a<C40?Shn03`l?01=CDd0Ph>303De=@0k>c/0?clo04U9B@1fMWH0NGUi01`L
700[:b/0LW9b06=SH`1BDU80Ph>307]kN`0N7Qh0:RXZ05ADE02KVi/0F5QH06i^KP1eMGD0<C4a02TY
:@1EEED0R8R803Hf=P1<C4`0LW9b02l_;`0o?cl0M7Ad04U9B@0_;bl0M7Ad030`<00K6a/0A4A407em
O@14A4@09BDU06UYJ@0V9RH0@D5105IFEP1TI6@0;bl_05EEE@1ADE40<30`08:2PP2DU9@0BTY:03/k
>`1=CDd0@d=3059BDP2g]kL0ADE501dM7@12@T80J6QX04];B`2WYjL0De=C02DU9@0/;2`0HF5Q04];
B`25QHD0KFe]01PH601?Cdl0Ogmo0410@02=SHd0S8b<030`<01FEUH0RXZ:05aLG01@D500LG5a01PH
6011@D40T92@08:2PP1IFET0HF5Q01hN7P0[:b/0HF5Q09ZJVP0n?Sh0?3`l02d];@0g=cL0Bd];001J
07MgM`1JFUX0<C4a05iNGP0o?cl0ATI606IVIP1dM7@09RHV03<c<`1ADE40BTY:04=3@`2<S8`0G5aL
01LG5`0_;bl0AdM705YJFP1CDe<0Jf][03Ph>00];Bd0@d=305aLG01DE5@0H61P06][J`0^;Rh0:b/[
03Hf=P1DE5@0FEUI05YJFP1RHV80BDU901XJ6P0n?Sh0I6AT069RHP1:BTX0De=C03@d=00M7Ad0@410
05]KF`0n?Sh0:b/[055AD@0_;bl0;Bd]03lo?`1]KFd0CDe=024Q8@1>CTh0>CTi03De=@1;Bd/0MGEe
024Q8@0L71`0;Rh^055AD@1EEED0PH610:JVYP1UIFD0Lg=c04e=C@1ZJVX0GemO051@D01mOGd0TI6A
08N7Q`2KVi/0YZJV0:FUY@2BTY80WinO05QHF01`L700Ogmo05IFEP1TI6@0Fe]K04=3@`0g=cL0Bd];
0P1HF5P02`15ADD0Bd];04E5A@1KFe/0A4A406m_K`26QXH0FUYJ05mOG`1QHF40HV9R0080I6AT0540
KVi^0;^k^`1]KFd0>3Ph05YJFP0d=3@0<c<c04E5A@11@D40@d=306IVIP18B4P0BTY:04=3@`1OGel0
HF5Q06EUI@1@D500?Shn07=cL`18B4P0GEeM07=cL`1=CDd0MgMg04Y:BP1^KVh0J6QX04i>CP1IFET0
<C4a06IVIP1?Cdl0M7Ad06MWI`1^KVh0JVYZ07QhN01gMgL0Ng]k06a/K01JFUX0=CDe071`L00k>c/0
?clo079bLP0i>CT0GUiN059BDP1<C4`0B4Q803lo?`0h>3P0=SHf02`/;01EEED0<C4a04i>CP0[:b/0
@d=302HV9P18B4P0L71`03/k>`0b<S80CDe=05aLG01GEeL0C4a<051@D01DE5@0ADE505eMG@1CDe<0
IFEU04Y:BP1VIVH0ADE50820P016ATH00P1>CTh07P13@d<0IfMW0410@01/K6`0@D5104Y:BP1^KVh0
AdM702l_;`18B4P0AdM702PX:01CDe<0A4A405=CD`14A4@0FUYJ06i^KP1OGel0B4Q805IFEP13@d<0
I6AT08F5Q@1PH600];Bd0;^k^`18B4P0I6AT09:BTP80JVYZ03T0DU9B06MWI`1FEUH0@D5102XZ:P1R
HV80EEEE075aL@1>CTh0X:2P04=3@`16ATH0Cdm?07=cL`1/K6`0LG5a07inOP0g=cL0@41004M7A`0N
7Qh0OGem0=SHf01=CDd0<c<c06IVIP0e=CD0L71`03<c<`1NGUh0?Shn014A4@1;Bd/0:BTY030`<017
AdL0=cLg0492@P0l?3`0@D51051@D00J6QX0=3@d03`l?013@d<04a<C04Y:BP1KFe/0@d=306UYJ@1L
G5`0?Shn07MgM`17AdL0=SHf04U9B@0h>3P00P1;Bd/0>`0M7Ad0E5AD05ADE00P8200=SHf04E5A@0i
>CT0?clo06IVIP1?Cdl09BDU03`l?027QhL0Vi^K04U9B@0k>c/0C4a<04U9B@1GEeL0HF5Q051@D01I
FET0DE5A06EUI@0_;bl0LG5a038b<P1:BTX0C4a<03`l?01DE5@0@T9205UIF@2>SXh0MGEe05ADE01X
J6P0AdM7059BDP1RHV805QHF07EeM@0H61P0Jf][07IfMP1eMGD0PX:20:j^[P2=SHd0JVYZ08Z:RP1=
CDd0Rh^;04Y:BP2][Jd0LG5a05MGE`1<C4`0MgMg0080I6AT02/0QHF505aLG01KFe/0EEEE02`/;01I
FET0<C4a06i^KP1@D500Q8B4061PH01oOgl0Shn?06m_K`2BTY80Ph>309bLW029RHT0UYJF08N7Q`1M
GEd0FUYJ05QHF01JFUX0EeMG05eMG@27QhL0BDU904];B`0h>3P0ZJVY07AdM01WIfL0c/k>05=CD`1a
LG40WIfM0=3@d01eMGD0UYJF08j>SP23Ph<0VIVI00;ooooo00008`1NGUh0IfMW06UYJ@1QHF40[Jf]
07emO@18B4P0IVIV07emO@1PH600LW9b04M7A`0j>SX0JFUY07QhN01=CDd0IfMW038b<P0/;2`0BDU9
07moO`11@D40CTi>04=3@`0K6a/0E5AD05QHF01@D500<c<c06e]K@0e=CD09bLW08J6QP2DU9@0>CTi
0080A4A407T0>CTi04I6AP2PX:00JVYZ02HV9P1OGel0@D510410@01iNGT0QHF501`L700g=cL0Bd];
07EeM@1[Jf/0IVIV06MWI`0V9RH0EeMG08V9R@1_Kfl0ATI609^KV`18B4P05aLG04M7A`1mOGd0Hf=S
055AD@2ATI407AdM01hN7P10@400QXJ605UIF@1]KFd0S8b<024Q8@0_;bl0>c/k06MWI`0`<300HV9R
05IFEP0L71`0Bd];05YJFP0f=SH08B4Q03Lg=`0b<S809bLW06YZJP1`L7005aLG02`/;00o?cl0FUYJ
04A4A027QhL0Bd];00`<300V9RH0>SXj051@D00h>3P0Q8B405iNGP0?3`l0=CDe05EEE@1JFUX0>CTi
09FEU@0i>CT05QHF030`<01GEeL0FEUI03Xj>P1lO7`071`L01lO7`0h>3P0Jf][03Ti>@13@d<0D51@
01dM7@0h>3P0BTY:07]kN`10@400<30`05UIF@0Q8B40DU9B09ZJVP2VYZH0B4Q802l_;`0i>CT0@T92
04A4A029RHT0WinO01/K6`0g=cL0BDU904A4A022PX80KFe]030`<00_;bl0EeMG06m_K`1DE5@0Rh^;
08B4Q00>3Ph0@4100080EEEE04H0Ogmo0410@00T92@0=CDe06ATI01ZJVX0=cLg08Z:RP0f=SH05ADE
04E5A@2?Shl0EeMG02LW9`18B4P0=CDe03<c<`1:BTX0QHF50451@@0b<S80DU9B0451@@0/;2`0Hf=S
09VIV@15ADD0;bl_05=CD`13@d<0DU9B09BDU01SHf<07AdM034a<@1=CDd0Ogmo065QH@30`<00<C4a
03Ti>@1CDe<0EEEE03/k>`1`L700Jf][01XJ6P0j>SX0MgMg05EEE@15ADD0DU9B03lo?`0i>CT0QHF5
09FEU@15ADD0FUYJ03Ph>00l?3`0N7Qh08R8R011@D40AdM704];B`0];Bd0KVi^09fMW@1;Bd/0@T92
0P0Z:RX0:@1/K6`0VIVI0451@@0c<c<0@D5103<c<`1cLg<0XZ:R02DU9@0Y:BT0D51@05QHF01LG5`0
T92@02/[:`0/;2`0E5AD06=SH`1dM7@0MGEe04i>CP0G5aL0De=C06EUI@1?Cdl0KVi^0;fm_@0];Bd0
71`L05UIF@1FEUH0>c/k07QhN02EUID0;2`/01TI6@1FEUH0Ng]k030`<01CDe<0T92@0080;Bd]04`0
BTY:055AD@0[:b/0G5aL079bLP0W9bL09RHV0820P01_Kfl08B4Q03`l?01DE5@06a/K03Lg=`21PH40
Ph>302/[:`0c<c<0F5QH02d];@1?Cdl0[Jf]06MWI`0J6QX0:2PX0451@@0e=CD0C4a<0:NWY`1@D500
6a/K03@d=01CDe<0Lg=c06UYJ@2j^[X0Cdm?02<S8`0m?Cd0?clo051@D00f=SH0B4Q802h^;P1ADE40
OGem0:RXZ01IFET0OGem04i>CP1jNWX0OGem071`L02a/K40Rh^;0:>SX`1:BTX0ADE505IFEP1IFET0
RHV908N7Q`2:RXX0NWYj03Ph>01cLg<0I6AT04m?C`1=CDd0JVYZ08Z:RP1fMWH0BTY:05=CD`1VIVH0
UYJF0P15ADD0201RHV80Lg=c07alO01VIVH0E5AD07]kN`20P800TY:B0P2:RXX0=P1GEeL0?3`l04];
B`12@T80CTi>05IFEP0a<C40EEEE04M7A`1JFUX0@D5104i>CP17AdL0ADE505QHF013@d<0EUIF03<c
<`0_;bl0Fe]K05YJFP1]KFd0M7Ad059BDP1RHV80FUYJ05UIF@1?Cdl0E5AD059BDP1GEeL0@41008N7
Q`23Ph<0Kfm_09:BTP18B4P0FUYJ04a<C00Z:RX0HV9R06YZJP12@T80IVIV03Hf=P1:BTX0=3@d03<c
<`0h>3P09BDU03dm?@0R8R805aLG03lo?`80ADE508h09BDU03dm?@0R8R80>c/k04U9B@12@T80>3Ph
04A4A01EEED0>3Ph0410@015ADD0BDU903hn?P16ATH0B4Q807IfMP1_Kfl0H61P04E5A@29RHT0BTY:
051@D01FEUH0De=C07]kN`1BDU80O7al04e=C@1HF5P0Ogmo05UIF@0l?3`0BTY:06i^KP0b<S80Lg=c
04E5A@1KFe/0A4A40820P02RXZ80YjNW07emO@1lO7`0G5aL07emO@28R8P0D51@04Y:BP16ATH0HV9R
08f=S@1UIFD0@D5104I6AP13@d<0>c/k06e]K@1LG5`0<c<c07QhN01JFUX0H61P03Hf=P21PH40CTi>
05MGE`1EEED0JVYZ0492@P0d=3@0GemO03/k>`1PH600Lg=c0410@01oOgl0`l?305IFEP0T92@0EeMG
03Xj>P1eMGD0=cLg08R8R01NGUh04A4A06][J`1CDe<0Cdm?06e]K@0k>c/0@D5102l_;`0k>c/0DU9B
04=3@`1BDU80<S8b02TY:@0:2PX0JVYZ05mOG`0_;bl0FEUI055AD@0Q8B40@D5103Ti>@1CDe<0D51@
034a<@1ADE40?Shn01dM7@1YJFT0M7Ad02TY:@0l?3`0=CDe04i>CP0l?3`0AdM704I6AP1JFUX0KFe]
04Y:BP1IFET0820P07EeM@1_Kfl0=CDe04I6AP1JFUX0H61P09>CT`1UIFD0OWin034a<@1cLg<0Cdm?
0P1KFe/0B`1;Bd/0KFe]06=SH`1UIFD0HF5Q069RHP1@D500^;Rh038b<P2ATI40M7Ad03/k>`1bLW80
ATI608n?S`2<S8`0TI6A05UIF@1@D500BDU904];B`31`L40N7Qh09ZJVP1@D500^k^k05mOG`22PX80
CTi>0:JVYP1RHV80F5QH06][J`0j>SX0D51@03dm?@0/;2`0C4a<04Y:BP1dM7@0@D5108N7Q`1ADE40
>SXj04a<C01jNWX0SXj>079bLP27QhL0I6AT059BDP1?Cdl0>CTi03dm?@1?Cdl0>3Ph04I6AP11@D40
?Cdm05eMG@1CDe<0GUiN05EEE@1[Jf/0SHf=08N7Q`24Q8@0a<C408:2PP2PX:00UIFE0;bl_02d];@0
UIFE0;^k^`02ooooo`000=H0PH61071`L025QHD0ATI606EUI@1bLW80@D51069RHP15ADD0C4a<09:B
TP17AdL0=SHf0451@@16ATH0@41007alO012@T808b<S03Xj>P1IFET0E5AD07UiN@1mOGd06ATI034a
<@19BDT0F5QH07AdM02WYjL0<30`02@T900k>c/0GEeM04I6AP22PX80Jf][01lO7`0N7Qh0C4a<06MW
I`1FEUH0Z:RX03hn?P0L71`0De=C07AdM016ATH0EeMG09ZJVP0G5aL0:b/[069RHP1aLG40AdM704i>
CP1RHV80>SXj04i>CP1HF5P0J6QX02h^;P17AdL0@d=3038b<P19BDT0UIFE05IFEP0R8R80>3Ph02<S
8`0m?Cd0IFEU0;^k^`1LG5`09RHV05IFEP0_;bl0>c/k08n?S`2LW9`09BDU02h^;P1ADE40CTi>05AD
E01iNGT0Fe]K01TI6@0i>CT0Bd];03dm?@25QHD0YjNW02`/;00R8R80F5QH08J6QP0d=3@0E5AD06QX
J00W9bL092@T0492@P1OGel0;Bd]02@T901FEUH08B4Q02`/;01mOGd0GEeM01PH600c<c<0=cLg04Y:
BP1NGUh0T92@02h^;P0R8R80@d=304I6AP1HF5P0Ogmo07inOP0O7al09RHV05QHF01UIFD0E5AD0410
@02FUYH06ATI024Q8@12@T80De=C06MWI`1QHF40GEeM02@T900V9RH0F5QH07alO00`<300IVIV06e]
K@0X:2P0@4100:RXZ01aLG40<c<c079bLP1DE5@09RHV05mOG`2i^KT0MgMg02d];@1<C4`0<30`07mo
O`2HV9P09RHV03@d=011@D40CTi>04e=C@2l_;`0NWYj01PH600`<300CTi>06IVIP1EEED0[Jf]04=3
@`0N7Qh0?Cdm05YJFP1HF5P0CDe=09BDU00W9bL0>3Ph030`<015ADD0A4A404a<C02IVIT05aLG03@d
=017AdL0J6QX04=3@`1cLg<0DU9B01lO7`0h>3P0JFUY06i^KP14A4@0RHV903@d=00^;Rh0SXj>0;>c
/`1?Cdl0D51@04U9B@0Z:RX0GemO0;Zj^P19BDT0=cLg0P1RHV80A`2ATI40Xj>S04A4A00K6a/0J6QX
07AdM01NGUh0RXZ:06ATI00O7al0>3Ph065QH@1KFe/0OGem03@d=00I6AT0;bl_07QhN01@D500DE5A
05IFEP0U9BD0BTY:05iNGP0o?cl0EeMG08V9R@0b<S80AdM70861P@1RHV80>CTi07inOP0n?Sh0:b/[
06IVIP1oOgl0:BTY03Xj>P1RHV80?clo04i>CP1gMgL0IVIV02/[:`1;Bd/0B4Q802TY:@0l?3`0R8R8
05iNGP0_;bl0=3@d03lo?`0/;2`0@T9208^;R`0n?Sh0:2PX0451@@0n?Sh0A4A406i^KP2c/k<0>SXj
03Hf=P0n?Sh0K6a/06ATI01kNg/0Ti>C0080:2PX03H0Cdm?0861P@1HF5P0EUIF07inOP0X:2P08B4Q
04Q8B02ATI40=cLg06i^KP1CDe<0820P02XZ:P0k>c/0IFEU02XZ:P0b<S80C4a<02/[:`0W9bL0D51@
05iNGP0M7Ad0>3Ph05YJFP0/;2`0KFe]0:FUY@1NGUh0IfMW08B4Q02YZJT0HV9R0861P@1FEUH0N7Qh
07moO`1lO7`0R8R809FEU@2<S8`0FUYJ071`L02EUID0Fe]K0:2PX02>SXh0QhN709FEU@1>CTh0HF5Q
06=SH`1?Cdl204a<C0090451@@1UIFD0DU9B04m?C`0j>SX0BDU905=CD`11@D40LG5a0080CTi>03D0
Jf][06UYJ@1jNWX0UYJF07]kN`2g]kL0PH6105UIF@15ADD0<S8b05]KF`1eMGD0FUYJ03Ti>@1oOgl0
HF5Q07UiN@16ATH0Jf][07AdM028R8P0IVIV03Lg=`1hN7P0<c<c03dm?@1PH600<C4a04m?C`1;Bd/0
CTi>055AD@0b<S80<C4a03Ph>01EEED0@T9205UIF@1MGEd0NWYj05EEE@1>CTh0JFUY05aLG01QHF40
IfMW03Ti>@1?Cdl0@T9204E5A@1PH600A4A405mOG`0204e=C@0<0451@@0k>c/0@41003Ph>00[:b/0
BDU9038b<P14A4@0?clo0492@P0a<C40<30`0P1ADE40c@0j>SX0@T9205QHF01?Cdl0B4Q80492@P1>
CTh0BDU904i>CP0h>3P0EeMG04Q8B01@D500Cdm?06QXJ01WIfL0GUiN04a<C01?Cdl0Ph>308f=S@25
QHD0ATI605ADE01dM7@0FEUI04=3@`15ADD0EUIF05=CD`1MGEd0>c/k065QH@26QXH0W9bL0:f][@2U
YJD0MGEe07moO`1aLG40De=C06m_K`1QHF40DE5A06][J`0a<C40IfMW0:^[Z`1RHV80IfMW06e]K@1A
DE40P820065QH@0g=cL0H61P07YjNP27QhL0EEEE09ZJVP1JFUX0M7Ad04a<C02WYjL0GUiN059BDP1T
I6@0IfMW0:6QX@2>SXh0<30`06a/K02PX:00L71`04m?C`1YJFT0Cdm?08V9R@1SHf<0ZJVY05MGE`0E
5AD0=cLg02`/;00c<c<0Bd];04=3@`0`<300:b/[03/k>`1VIVH05aLG028R8P0i>CT0BTY:01HF5P2G
UiL0Ogmo03De=@1EEED0@D5103Lg=`1hN7P0@D5103Xj>P10@400=CDe08J6QP1<C4`051@D04A4A01G
EeL061PH04U9B@0n?Sh0=CDe03/k>`1WIfL0FEUI03`l?01=CDd0HV9R07]kN`0c<c<0Cdm?06EUI@0^
;Rh0J6QX09>CT`11@D40CTi>06=SH`1lO7`0>3Ph07MgM`10@400B4Q806ATI01?Cdl0C4a<06a/K01_
Kfl0WinO08Z:RP18B4P0HV9R02HV9P16ATH0EEEE03Hf=P2>SXh0@D51071`L01MGEd0DE5A04a<C02G
UiL0QXJ606ATI01ZJVX0CDe=07QhN01RHV80W9bL04E5A@1DE5@0>3Ph07=cL`13@d<0IfMW06UYJ@0/
;2`0NGUi05aLG00o?cl0G5aL02XZ:P1<C4`0;bl_0492@P17AdL0>3Ph04a<C01^KVh0UYJF05=CD`1?
Cdl0NWYj09VIV@2TY:@0D51@04I6AP1?Cdl0H61P06a/K017AdL0?Shn03lo?`1IFET0<c<c05QHF01V
IVH0P82009RHV01]KFd00P2EUID01P2BTY80IVIV09VIV@1OGel0LW9b0=KFeP;ooooo0000ZP2RXZ80
^k^k09^KV`15ADD0EUIF06IVIP1aLG40SXj>03De=@0m?Cd0L71`05QHF01^KVh0MWIf028R8P0g=cL0
?3`l0492@P0k>c/0MWIf04A4A00R8R80De=C06MWI`0c<c<0H61P069RHP0X:2P0:RXZ09nOW`1oOgl0
9BDU05UIF@0c<c<08B4Q05mOG`25QHD0@d=3038b<P17AdL06ATI03/k>`2LW9`0HV9R020P800^;Rh0
CTi>03dm?@1EEED0];Bd02XZ:P0L71`0?clo05=CD`0e=CD0UIFE0;fm_@0I6AT0=SHf069RHP1eMGD0
Cdm?09fMW@2ATI406QXJ03Hf=P1[Jf/0EEEE05aLG01eMGD092@T02TY:@15ADD0EeMG07inOP0b<S80
QHF504a<C00C4a<0<S8b06a/K00n?Sh0H61P06ATI00G5aL0=cLg055AD@2ZZZX0DU9B04];B`0j>SX0
:BTY059BDP1fMWH0DE5A03`l?013@d<0?clo04];B`1iNGT0QhN7020P800[:b/0ADE5051@D018B4P0
HV9R09VIV@0L71`061PH03Xj>P1]KFd0Cdm?08b<S020P800:BTY04A4A01XJ6P0JFUY059BDP2[Zj/0
KFe]01`L7019BDT0KFe]05eMG@0X:2P0G5aL04E5A@0b<S80E5AD08R8R01GEeL07AdM04i>CP1DE5@0
ATI605IFEP1]KFd0=3@d02PX:01KFe/0C4a<03De=@2@T900Ph>3030`<00/;2`0Lg=c07AdM01<C4`0
M7Ad0492@P0Z:RX0?clo08F5Q@1UIFD0O7al05mOG`0V9RH0CTi>0:b/[01[Jf/0I6AT06EUI@0E5AD0
?Cdm06UYJ@1kNg/0EEEE0P1MGEd0RP0];Bd0<30`059BDP2<S8`0;Bd]04e=C@1ADE40;Bd]03lo?`1^
KVh0OWin02PX:01@D500@T9203dm?@1gMgL0WIfM04i>CP0c<c<0De=C05iNGP1`L700RXZ:09FEU@0K
6a/0:BTY0492@P1;Bd/0I6AT0<O7a`1]KFd08R8R02/[:`19BDT0E5AD07emO@2ATI40:b/[0492@P1E
EED0EUIF051@D02?Shl0HV9R04E5A@1]KFd0K6a/038b<P1RHV80ADE501dM7@18B4P0OGem04E5A@16
ATH0=3@d02`/;02?Shl0M7Ad02h^;P1QHF40ATI603@d=01gMgL0TY:B0451@@16ATH0EeMG02l_;`1P
H600^;Rh05YJFP0_;bl0A4A406YZJP1JFUX0XZ:R04m?C`0S8b<0D51@05UIF@1PH600NWYj07alO00M
7Ad0?3`l06QXJ01?Cdl0H61P0:f][@1nOWh06a/K03Lg=`15ADD0D51@06e]K@2ZZZX0IFEU02LW9`0e
=CD0De=C07AdM01=CDd0QhN702TY:@0d=3@0Bd];04m?C`1VIVH0Fe]K08N7Q`0c<c<0=CDe055AD@1K
Fe/0?Cdm02d];@0i>CT0>3Ph03dm?@1@D500K6a/02<S8`0W9bL0=CDe03`l?01DE5@0GemO07alO00G
5aL0;Bd]04i>CP1JFUX0@d=305aLG02;Rh/06a/K01`L7080GEeM00h0?Shn079bLP2>SXh09RHV01hN
7P1JFUX0UYJF07inOP1hN7P0R8R805eMG@28R8P0Ng]k08:2PP80WIfM01`0IfMW08b<S01WIfL0GUiN
08B4Q01JFUX0G5aL08R8R02TY:@0WIfM07UiN@1ADE40Jf][05aLG00n?Sh0HV9R05MGE`17AdL0HV9R
05=CD`1QHF40D51@05]KF`1/K6`0KVi^09VIV@1VIVH0EEEE0P1oOgl0H`1cLg<0Kfm_09:BTP2PX:00
OWin04=3@`1;Bd/061PH02LW9`10@400Bd];051@D01QHF40@T9205]KF`1;Bd/0GUiN0492@P15ADD0
D51@04A4A01LG5`0E5AD05eMG@1PH600@D51075aL@21PH40Hf=S05ADE015ADD0ATI605=CD`1<C4`0
@d=305EEE@1;Bd/0EeMG04e=C@1TI6@0K6a/07alO01jNWX0F5QH03Xj>P1[Jf/0ADE504M7A`1OGel0
<C4a0451@@1LG5`0CTi>03Lg=`16ATH0HF5Q02/[:`0b<S80FUYJ04m?C`1>CTh0>c/k0410@00_;bl0
=3@d04U9B@0h>3P09RHV03Hf=P15ADD0ATI603@d=00b<S80CDe=06EUI@18B4P0;bl_05EEE@1<C4`0
DU9B03dm?@1IFET0ADE5059BDP1EEED0Fe]K05aLG01DE5@0HV9R04m?C`1CDe<0N7Qh059BDP0g=cL0
?Shn04a<C00[:b/0BDU9038b<P0205ADE00d071`L027QhL0SXj>096AT@2_[jl0JVYZ04i>CP26QXH0
N7Qh04a<C021PH40I6AT06][J`2RXZ80FUYJ05iNGP1^KVh0CTi>08>3P`1lO7`0>3Ph05]KF`1CDe<0
DU9B0492@P1hN7P0PX:20861P@1:BTX0U9BD05iNGP1:BTX0NWYj03hn?P11@D40C4a<02TY:@1JFUX0
MgMg04a<C00m?Cd0HF5Q04=3@`1HF5P0ATI605]KF`1`L7009BDU04=3@`1;Bd/0?Shn05QHF080@D51
07d0DU9B03/k>`1DE5@0:RXZ02l_;`0W9bL0?3`l020P801;Bd/0CTi>05EEE@1hN7P0H61P028R8P0m
?Cd0C4a<06][J`1cLg<0@41004e=C@11@D40:b/[071`L02;Rh/0=SHf02TY:@10@400C4a<03hn?P0o
?cl0C4a<04A4A01=CDd0De=C08>3P`0[:b/0J6QX07moO`0b<S80<c<c04a<C01ZJVX0L71`05QHF01T
I6@0:2PX05UIF@15ADD0AdM705=CD`1<C4`0ATI604A4A01JFUX0EUIF05aLG01lO7`0YZJV02PX:029
RHT0ATI601HF5P1BDU807alO08n?S`1kNg/0Ph>305EEE@16ATH0BDU903`l?01/K6`0?clo09nOW`1<
C4`0WIfM05=CD`1eMGD0A4A4071`L00o?cl0De=C06ATI00^;Rh0>CTi02d];@0R8R80@41002/[:`1=
CDd0B4Q804I6AP1RHV80@4100820P01lO7`0TY:B05EEE@1FEUH0OWin04a<C025QHD0@41004M7A`16
ATH0=SHf05]KF`0k>c/0ADE503@d=014A4@0;2`/06IVIP1WIfL0L71`07]kN`1oOgl0XJ6Q079bLP1i
NGT0N7Qh09VIV@1aLG40Fe]K092@T002ooooo`000500JFUY07=cL`2^[Zh0G5aL07AdM01?Cdl0IVIV
0;Rh^01bLW80C4a<07IfMP0n?Sh0PH6108n?S`1=CDd0<c<c059BDP18B4P0IfMW08:2PP1KFe/08B4Q
03<c<`1GEeL0G5aL0:2PX01aLG409BDU03Ph>01MGEd0GUiN05IFEP2_[jl0?clo02`/;00Z:RX0HV9R
06ATI01kNg/0OWin02@T900P8200;Bd]07UiN@18B4P0MgMg05]KF`0X:2P0=SHf05aLG01PH600;2`/
075aL@0n?Sh05aLG03De=@1MGEd0DE5A03De=@1UIFD08B4Q02/[:`1ADE40RHV903/k>`1>CTh0L71`
024Q8@1NGUh0VIVI04M7A`0H61P0=CDe04U9B@0i>CT0<C4a06a/K01cLg<04Q8B02`/;080B4Q802X0
QXJ607AdM00C4a<092@T04Q8B01UIFD0Fe]K08b<S02BTY804A4A04e=C@1ZJVX0DU9B04Q8B01NGUh0
>3Ph01HF5P16ATH0Lg=c04a<C00g=cL0OWin04i>CP0[:b/0CTi>07alO01PH600=cLg05mOG`0V9RH0
9BDU051@D01SHf<0=3@d030`<01BDU80:RXZ05mOG`1jNWX0M7Ad02<S8`0];Bd204e=C@1L05QHF02g
]kL0TY:B01TI6@0`<300KFe]07]kN`1@D500YjNW0:2PX00I6AT0@d=308B4Q01`L700DU9B08f=S@0n
?Sh0@T92055AD@1fMWH0DE5A065QH@1ZJVX071`L05QHF01aLG40U9BD04Y:BP1FEUH0GEeM02l_;`1A
DE40N7Qh03@d=01_Kfl0EEEE038b<P1FEUH0V9RH06UYJ@0];Bd0EeMG05]KF`0R8R80K6a/08R8R00`
<3009BDU05]KF`1bLW80=SHf09nOW`2EUID05aLG02LW9`1OGel0F5QH04e=C@2@T900KVi^02<S8`1Q
HF40I6AT04e=C@1GEeL0Rh^;03Ph>015ADD0EUIF08n?S`1MGEd0MgMg07emO@0P8200=CDe06YZJP2/
[:`0;Bd]061PH00l?3`09bLW04E5A@2IVIT0F5QH04A4A01GEeL0>3Ph04E5A@1aLG40IVIV034a<@1<
C4`205QHF01T07emO@1EEED09bLW04I6AP1=CDd0C4a<08f=S@16ATH08R8R04U9B@2PX:00C4a<09ZJ
VP15ADD0@D5104I6AP1RHV80Jf][079bLP1XJ6P0=cLg05=CD`1eMGD0BTY:05EEE@1DE5@05aLG03/k
>`1ZJVX0NGUi03Xj>P1aLG40=SHf020P801RHV80R8R804i>CP1:BTX0IfMW02h^;P0Y:BT0IFEU08f=
S@12@T80C4a<06MWI`0U9BD0=cLg07AdM028R8P08b<S038b<P1FEUH0=SHf06a/K02=SHd0CDe=01XJ
6P1?Cdl0E5AD03Ph>01ZJVX0`/;206MWI`0E5AD0Cdm?06=SH`19BDT0FEUI096AT@1IFET07alO04m?
C`1ZJVX0AdM705eMG@1cLg<092@T03<c<`18B4P0JVYZ04M7A`0b<S80De=C02HV9P0S8b<0@d=3069R
HP1eMGD0;bl_04M7A`0W9bL0>c/k05ADE022PX80?Cdm02<S8`1;Bd/0>SXj08N7Q`80P8200540Ph>3
05]KF`1ZJVX0IVIV04E5A@17AdL0I6AT051@D01PH600C4a<05ADE01kNg/0Zj^[09jNWP1_Kfl0Ti>C
092@T024Q8@0LW9b06EUI@1FEUH0DU9B05UIF@17AdL0OWin05]KF`1VIVH0FUYJ055AD@1BDU80ATI6
08B4Q01TI6@0De=C07inOP1GEeL0RXZ:08>3P`2BTY80KFe]07]kN`1LG5`0CDe=06QXJ00m?Cd0BDU9
05eMG@0X:2P0G5aL04E5A@1QHF40ATI604i>CP18B4P0CTi>061PH01@D500IfMW03Ti>@0b<S80GemO
06IVIP1NGUh0=cLg04e=C@1oOgl0JFUY05]KF`0j>SX0I6AT04U9B@1TI6@0Bd];07emO@1lO7`0UYJF
09^KV`1=CDd0FEUI06YZJP1=CDd00P1MGEd05016ATH0C4a<03/k>`1>CTh0@D5103@d=00e=CD07QhN
0451@@0N7Qh05aLG03/k>`0[:b/0BTY:028R8P14A4@0<C4a030`<01]KFd0ADE50P13@d<0901MGEd0
ATI605=CD`14A4@0@D5102h^;P0o?cl0=cLg069RHP1WIfL0G5aL03hn?P21PH40G5aL055AD@1GEeL0
De=C07EeM@1UIFD0K6a/04E5A@0i>CT0J6QX05YJFP12@T80@41003Hf=P0[:b/0D51@03Ti>@1DE5@0
EUIF0861P@2RXZ80U9BD05IFEP80F5QH02l0AdM708B4Q01jNWX0BDU908N7Q`1GEeL0IfMW09ZJVP2N
WYh0TI6A059BDP14A4@0IVIV06EUI@1>CTh0F5QH08Z:RP2JVYX0Fe]K07emO@1RHV80BDU904A4A01i
NGT0Lg=c055AD@1hN7P0Bd];05MGE`1QHF40>3Ph051@D026QXH0UIFE04M7A`1LG5`0ATI605MGE`1g
MgL0J6QX06a/K00K6a/0@d=306ATI012@T80De=C0410@00204A4A01l038b<P13@d<0>c/k03Ph>014
A4@0AdM701TI6@1CDe<0GUiN02`/;01=CDd0A4A401TI6@14A4@0>SXj03@d=01CDe<09RHV07moO`1:
BTX01`L703Lg=`1EEED061PH02TY:@0_;bl0<30`04Y:BP12@T80F5QH05YJFP1NGUh0BTY:07inOP0e
=CD0CDe=05aLG00f=SH0<C4a04M7A`18B4P0IVIV06e]K@1cLg<0G5aL06ATI014A4@0DE5A05UIF@1;
Bd/0>c/k04a<C01JFUX0EEEE069RHP16ATH0I6AT04m?C`0h>3P0EEEE0451@@2<S8`0<30`051@D01?
Cdl0De=C03Xj>P1>CTh0DE5A04i>CP2JVYX0GemO09RHV01aLG40KFe]04];B`1QHF40>CTi06ATI01>
CTh0LG5a06e]K@0];Bd0ATI603Hf=P0R8R80A4A405IFEP1aLG40ADE505ADE01@D500@d=30410@01J
FUX0Zj^[06UYJ@1?Cdl0R8R8055AD@2KVi/0C4a<04A4A01DE5@0@D5106ATI016ATH0@D5103`l?01C
De<0@T9207emO@1fMWH0L71`09^KV`2=SHd0ZJVY0;Vi^@2g]kL0LW9b0:>SX`1WIfL0De=C0;>c/`;o
oooo0000BP1UIFD0DE5A069RHP1fMWH0[Zj^04a<C01;Bd/0I6AT075aL@21PH40^;Rh04];B`0l?3`0
MWIf07=cL`1]KFd0XJ6Q030`<00_;bl0E5AD06=SH`1ADE40PX:204Q8B00c<c<0ATI608J6QP1@D500
H61P09FEU@0^;Rh08b<S069RHP21PH40>SXj04U9B@0Y:BT0;2`/04i>CP1iNGT0AdM7038b<P1EEED0
;Rh^03/k>`1^KVh0N7Qh02LW9`0m?Cd0?3`l06a/K00o?cl0ZZZZ06m_K`0];Bd0=cLg05MGE`1IFET0
IFEU08F5Q@0_;bl0820P04U9B@13@d<0BDU906YZJP30`<007AdM01hN7P1RHV80YZJV04I6AP2IVIT0
QHF50P0Z:RX0o`1PH600OWin03lo?`29RHT0?Cdm01DE5@0[:b/0Bd];051@D00K6a/0Fe]K03Lg=`0Y
:BT0>3Ph07=cL`0n?Sh0;Rh^03lo?`0e=CD09RHV069RHP1WIfL06a/K02/[:`15ADD0?Cdm03Ph>01Y
JFT0>3Ph01dM7@0];Bd0@T9205ADE01@D500Xj>S02l_;`0J6QX0;Rh^05=CD`0l?3`0Lg=c0;Vi^@0Z
:RX0;bl_051@D01gMgL0F5QH06ATI02:RXX09BDU02`/;01;Bd/0KFe]04U9B@1<C4`0Lg=c02XZ:P0b
<S80EeMG09BDU017AdL0@D5103hn?P0a<C40<S8b07UiN@1nOWh07QhN03Ti>@14A4@0>SXj05mOG`2h
^;P0GUiN01/K6`17AdL0F5QH05]KF`2VYZH0Ogmo02PX:010@400Fe]K04A4A036a/H0FUYJ03Ph>01<
C4`0HF5Q05=CD`1HF5P0YJFU06UYJ@0K6a/0D51@05aLG01OGel0@D5108j>SP0n?Sh06QXJ04U9B@2?
Shl0>SXj04a<C01oOgl0;2`/01TI6@1MGEd0JFUY034a<@0g=cL0IfMW02HV9P0b<S80Rh^;07=cL`0O
7al0EEEE04Y:BP0h>3P0RXZ:0;fm_@0a<C40;Bd]04e=C@25QHD0AdM70::RXP1^KVh09bLW03@d=020
P800ATI606MWI`1kNg/071`L02/[:`1HF5P0EEEE04m?C`1gMgL0ADE5030`<01SHf<0R8R8069RHP1c
Lg<0HF5Q03Hf=P1eMGD0Lg=c034a<@1DE5@0=3@d03De=@21PH40Vi^K02h^;P18B4P0ATI602@T901O
Gel0F5QH02PX:01IFET0JFUY03lo?`2BTY80MWIf02`/;00f=SH0HF5Q04M7A`1<C4`0X:2P07MgM`0M
7Ad0C4a<05YJFP0o?cl0RHV90=7Ad@0a<C409bLW05]KF`1gMgL0F5QH065QH@2[Zj/07AdM01LG5`1<
C4`0Ng]k04M7A`1GEeL0Ng]k018B4P0K6a/0Bd];06e]K@0j>SX0M7Ad06IVIP0T92@0<C4a04m?C`1k
Ng/0?Cdm04Q8B01BDU80<c<c03/k>`1QHF40RHV902PX:00k>c/0H61P03@d=00Y:BT0CDe=04m?C`0J
6QX0>CTi04Y:BP0a<C40>SXj0820P00j>SX09BDU03@d=010@400LW9b04e=C@26QXH0>3Ph01DE5@0o
?cl0K6a/06=SH`0h>3P0Ti>C05MGE`19BDT0DU9B04i>CP15ADD0H61P04I6AP1OGel0HF5Q06ATI02V
YZH0Rh^;09nOW`00U`1GEeL0GemO08>3P`1EEED0EeMG06e]K@1_Kfl0Lg=c04m?C`1WIfL0GUiN051@
D01FEUH0EeMG055AD@1QHF40Hf=S06a/K01:BTX0I6AT07IfMP15ADD0Rh^;075aL@1LG5`0R8R8071`
L02TY:@0P82009fMW@2ATI40TY:B05EEE@1@D500?3`l03hn?P1ADE40J6QX03Xj>P27QhL0EEEE07Mg
M`1?Cdl0M7Ad06=SH`18B4P0LG5a03Ph>02BTY80@T9203Ph>01GEeL0?3`l06MWI`13@d<0CDe=069R
HP15ADD0@T92034a<@1MGEd0EEEE04i>CP19BDT0K6a/04U9B@16ATH0MWIf04e=C@1HF5P0E5AD04M7
A`1VIVH0@T92038b<P1GEeL0@D5104I6AP0m?Cd0>SXj04i>CP0b<S80C4a<02TY:@0];Bd0C4a<02d]
;@0k>c/0=SHf04=3@`0^;Rh0@D5105EEE@13@d<0;2`/038b<P11@D40?clo03hn?P0g=cL0?clo04A4
A01GEeL0?clo05IFEP0o?cl0De=C05YJFP1BDU80@D5104i>CP0k>c/0CDe=06i^KP2KVi/0S8b<04U9
B@1;Bd/0TY:B06i^KP14A4@0>CTi04E5A@0m?Cd0DE5A02`/;01GEeL0GemO06MWI`1IFET0KVi^071`
L01eMGD0Lg=c05YJFP1aLG40IFEU07moO`2?Shl0EEEE05iNGP1[Jf/0BTY:04A4A01>CTh0B4Q805YJ
FP1WIfL0;2`/03lo?`10@4000P18B4P0@P1FEUH0FUYJ075aL@1>CTh0M7Ad04m?C`1UIFD0N7Qh05=C
D`1@D500Fe]K055AD@1GEeL0XJ6Q079bLP0];Bd0FUYJ055AD@1PH600FUYJ06ATI01fMWH08b<S05eM
G@0o?cl0;Bd]04];B`1BDU80=SHf04Y:BP0T92@0@41002XZ:P0g=cL0;2`/03Xj>P0B4Q80B4Q806AT
I00h>3P0E5AD05MGE`0_;bl0BTY:04e=C@15ADD0KVi^03Hf=P2k^k/0PX:201DE5@1FEUH0Hf=S01HF
5P0o?cl0>CTi03Ph>015ADD0BDU90492@P16ATH0EUIF05UIF@1_Kfl07AdM065QH@80Lg=c05H0:RXZ
04A4A01ADE40FEUI06ATI01cLg<0ATI6061PH01QHF40C4a<0451@@1;Bd/0GEeM04I6AP1=CDd0N7Qh
06IVIP0o?cl0TI6A04=3@`1:BTX0@d=302`/;01GEeL0=CDe059BDP18B4P0Jf][05ADE02CTi<0F5QH
04A4A02LW9`0OGem0:2PX02OWil0WIfM08J6QP1[Jf/0<c<c05MGE`12@T80Fe]K05MGE`0A4A40ADE5
03@d=00X:2P0@d=303Lg=`13@d<0De=C061PH01ADE40O7al05QHF01UIFD0SHf=04E5A@1;Bd/0P820
05aLG02<S8`0NGUi08F5Q@1@D500@T9205UIF@1FEUH0IfMW06IVIP1@D5008B4Q04m?C`1_Kfl0PH61
096AT@2QXJ40alO709ZJVP2][Jd0Jf][0;2`/02PX:00PX:20:JVYP;ooooo0000101kNg/0[Jf]07al
O01<C4`206YZJP3F06IVIP1iNGT0=cLg04M7A`1LG5`0AdM703`l?01@D500<C4a03dm?@1JFUX0IfMW
030`<01<C4`0?Cdm02DU9@1@D500IfMW01dM7@12@T80=cLg030`<01NGUh0Z:RX0451@@0U9BD0@D51
0410@01?Cdl0O7al03`l?00F5QH0;bl_04a<C00_;bl0GemO09^KV`0^;Rh0:b/[04e=C@1>CTh0?3`l
08B4Q02<S8`061PH03Ph>01IFET0SXj>08F5Q@2FUYH0/K6a03<c<`0T92@0JFUY05UIF@0g=cL0/[:b
065QH@0V9RH0BTY:07AdM01GEeL0:RXZ05ADE00_;bl0=3@d069RHP21PH40<c<c02/[:`11@D40:RXZ
03`l?01oOgl0OWin02d];@17AdL0BTY:02LW9`13@d<0X:2P0492@P0T92@0?Cdm0451@@1LG5`0J6QX
09BDU00g=cL08b<S02l_;`1XJ6P0FEUI06ATI01VIVH09BDU03Ti>@0j>SX0HV9R03<c<`1`L700JFUY
014A4@11@D40Lg=c05IFEP0U9BD0C4a<0410@00V9RH0;2`/05]KF`17AdL0:2PX05eMG@0f=SH07QhN
04m?C`29RHT0=cLg01lO7`12@T80?Cdm03Ph>01JFUX0WYjN03dm?@0M7Ad0@d=306a/K01EEED0LW9b
0:JVYP0a<C40:b/[0410@01VIVH0GemO08^;R`10@4006a/K034a<@22PX80PH6103Lg=`1SHf<07alO
02TY:@13@d<0T92@06QXJ01=CDd0IVIV02<S8`1DE5@0PH6104Y:BP1?Cdl0I6AT01dM7@0d=3@0R8R8
0<71`@1YJFT0ATI6071`L00^;Rh0:RXZ092@T020P8007alO03<c<`1JFUX0BDU905YJFP2>SXh0@d=3
01@D500e=CD0I6AT04I6AP1dM7@0Ng]k01dM7@0Y:BT0Hf=S0820P01>CTh0M7Ad06IVIP0M7Ad0=SHf
06m_K`1TI6@0FEUI06UYJ@0e=CD09BDU055AD@2>SXh0FEUI06IVIP1MGEd092@T03Lg=`1mOGd0EEEE
02HV9P1WIfL0AdM703Lg=`24Q8@0UIFE028R8P80BDU90:<0Fe]K08Z:RP2@T900:RXZ05aLG01UIFD0
I6AT07YjNP0e=CD0:BTY034a<@1hN7P0HV9R08Z:RP1aLG40820P05IFEP1VIVH0=SHf08V9R@2HV9P0
:b/[04Q8B023Ph<0EUIF04M7A`1hN7P0<30`03<c<`1RHV80Ti>C0410@01:BTX0BDU902d];@11@D40
MWIf09NGU`0o?cl0JVYZ04A4A00_;bl0=cLg07IfMP1KFe/0ATI605YJFP11@D40:RXZ04A4A02QXJ40
;Bd]02`/;012@T80AdM704I6AP2EUID0]kNg02l_;`0W9bL0=cLg069RHP1OGel0N7Qh0:FUY@0S8b<0
;2`/04Y:BP1IFET0C4a<06IVIP2;Rh/07AdM03De=@0c<c<0>3Ph02h^;P1:BTX0HV9R014A4@0_;bl0
<C4a04m?C`0];Bd0Fe]K05QHF00C4a<0<30`04=3@`1<C4`071`L02`/;01;Bd/04a<C01lO7`1;Bd/0
I6AT06=SH`1cLg<0UYJF05=CD`2?Shl0EeMG07AdM02:RXX0MgMg09fMW@2:RXX0Ng]k0861P@2>SXh0
NGUi06QXJ02WYjL0UYJF08j>SP1oOgl0MGEe071`L01IFET0?Shn04A4A015ADD0=cLg03Ph>01CDe<0
H61P03lo?`1>CTh0>CTi05IFEP2CTi<0E5AD04i>CP1VIVH0T92@07]kN`1oOgl0L71`0;2`/02DU9@0
@D5104i>CP0L71`0<30`04e=C@1ADE40@d=306YZJP1QHF40GemO04a<C01TI6@0K6a/05aLG01QHF40
@41008b<S01>CTh0ATI606=SH`1:BTX0Ogmo0080FUYJ01T0Ogmo06UYJ@1SHf<0=3@d05UIF@1:BTX0
GemO05UIF@1nOWh0Hf=S05QHF01nOWh0Kfm_08B4Q01iNGT0DU9B09JFUP1IFET0=CDe07]kN`0_;bl0
@d=304Q8B00m?Cd0<c<c0080B4Q802h0:b/[02d];@1PH600<30`04U9B@0f=SH0CTi>02l_;`0i>CT0
E5AD04];B`0a<C40?Cdm051@D01EEED0AdM70410@01CDe<0FUYJ055AD@0];Bd0G5aL04a<C01IFET0
@41005IFEP0n?Sh0BTY:05YJFP1MGEd0I6AT04e=C@1NGUh0C4a<04Q8B01FEUH0CTi>03Hf=P0a<C40
@D5103Hf=P0i>CT0<C4a04e=C@1ZJVX0I6AT0P2>SXh07`2NWYh0_;bl08b<S011@D40C4a<051@D016
ATH0IVIV0451@@0n?Sh0JFUY07MgM`1ZJVX0>CTi02HV9P1BDU80D51@04A4A01IFET0De=C07UiN@1=
CDd0De=C05YJFP1QHF40ADE5079bLP1RHV80ADE506ATI01=CDd00P19BDT0?00A4A40MgMg0<[:bP2=
SHd0@D5105MGE`1=CDd0QhN705ADE01QHF40JVYZ01lO7`17AdL0H61P03<c<`1=CDd0>c/k03De=@1Z
JVX0>SXj0410@00[:b/0;bl_02LW9`1:BTX0?3`l07alO01gMgL0@D5104e=C@1GEeL0C4a<0861P@1E
EED0AdM705ADE00Z:RX0@d=304];B`0k>c/0IFEU05UIF@0e=CD0<c<c04i>CP0l?3`0?Cdm06e]K@1Q
HF40CTi>069RHP1BDU80KFe]02LW9`1BDU80Hf=S04Q8B011@D40Lg=c04M7A`80DE5A0540KFe]02`/
;01LG5`0?Cdm03lo?`0d=3@0@41004Y:BP0l?3`0EeMG07]kN`21PH40Fe]K08n?S`0S8b<0BTY:059B
DP0f=SH0GEeM04I6AP1UIFD0GUiN05IFEP0_;bl0IFEU06YZJP1SHf<0SHf=05QHF02MWId0Cdm?0820
P01UIFD0H61P06YZJP2JVYX0>c/k06MWI`1TI6@09bLW07IfMP1ZJVX0ADE504I6AP1JFUX0C4a<04i>
CP1HF5P0ATI604E5A@1;Bd/0GEeM08N7Q`1eMGD0YJFU08:2PP1PH600G5aL04M7A`10@400A4A404Y:
BP1IFET0:b/[03Hf=P11@D40J6QX030`<02=SHd0KFe]08B4Q02i^KT0MgMg07inOP2l_;`0^k^k07Qh
N01oOgl0L71`0820P02QXJ400_ooool0000@06][J`2DU9@0/;2`0451@@1PH600D51@08j>SP2o_kl0
BTY:03lo?`1XJ6P0CTi>06QXJ02:RXX0<30`04I6AP80EeMG02L0J6QX0;Bd]01CDe<0:RXZ03/k>`1L
G5`0C4a<0:6QX@1kNg/07alO02l_;`1QHF40HV9R05mOG`2:RXX0GUiN02d];@0m?Cd0IFEU02d];@1G
EeL0HV9R01dM7@0g=cL0Q8B408V9R@0o?cl0HV9R05iNGP0N7Qh0EUIF09jNWP0o?cl0<c<c06i^KP0k
>c/09RHV06MWI`32`/800P0];Bd03`0i>CT0<S8b04M7A`2OWil0IfMW02<S8`0i>CT0K6a/07=cL`1Q
HF40PX:201PH600];Bd0@D5105QHF00208F5Q@0E09:BTP0R8R80<c<c03Hf=P1ADE40BTY:09JFUP1a
LG40:BTY02l_;`1`L700WYjN05=CD`1]KFd0FEUI02HV9P1EEED0J6QX079bLP0c<c<0EeMG0080<c<c
05X0IVIV0820P00h>3P071`L04e=C@14A4@0>CTi09FEU@3?cll0C4a<01@D500o?cl0CDe=03hn?P2<
S8`0LW9b02@T900m?Cd0@41004Q8B01GEeL0VYZJ05EEE@0E5AD0=SHf05=CD`1FEUH0>SXj07AdM00_
;bl0;Rh^03@d=01<C4`0Cdm?03Ti>@2OWil0J6QX02<S8`0k>c/0D51@04Q8B00o?cl0I6AT03Ti>@0Q
8B40JVYZ08B4Q00i>CT0=SHf03Ti>@1GEeL0FUYJ09ZJVP1HF5P07AdM04A4A01QHF40HV9R06ATI01m
OGd0;2`/055AD@2RXZ80Kfm_08b<S02m_Kd0:BTY02DU9@1?Cdl0SHf=07inOP1/K6`0Ng]k02PX:00S
8b<0Bd];08>3P`1MGEd0AdM706m_K`0H61P0BDU907MgM`1WIfL0<c<c05ADE01YJFT0820P030`<01]
KFd20410@02Z05aLG00l?3`0BDU908>3P`1gMgL0;Rh^04A4A01/K6`0C4a<07QhN02FUYH0D51@02l_
;`16ATH0GUiN0410@02BTY80Xj>S02/[:`0V9RH0@d=306m_K`1DE5@0/k>c06MWI`0U9BD0IFEU0:NW
Y`1FEUH0MGEe03Lg=`0R8R80C4a<08J6QP15ADD0R8R803Lg=`0[:b/0L71`06e]K@16ATH0De=C04U9
B@0Q8B40EeMG0861P@0];Bd0A4A404a<C00X:2P0IVIV0:NWY`1NGUh0@D5104A4A013@d<0GemO09^K
V`0l?3`0:BTY04I6AP1dM7@0LG5a08f=S@1cLg<08B4Q03`l?011@D40MGEe04m?C`2XZ:P0FUYJ02TY
:@0m?Cd0Bd];05=CD`1JFUX0W9bL04M7A`10@400GEeM07MgM`0o?cl0@41005IFEP0S8b<0:RXZ04];
B`2OWil0F5QH03hn?P1TI6@0:RXZ03<c<`1CDe<0MgMg04i>CP0c<c<0Bd];038b<P0c<c<0@T9206AT
I00h>3P07alO06EUI@0m?Cd0?Shn05mOG`25QHD0>c/k01hN7P12@T80A4A403Lg=`1lO7`0[:b/02`/
;00P8200DU9B05iNGP1GEeL0J6QX09>CT`0E5AD0;2`/04e=C@1HF5P0WinO08^;R`21PH40OGem075a
L@28R8P0Ogmo07EeM@1gMgL0IFEU09:BTP1iNGT0CTi>075aL@1bLW80KVi^06MWI`28R8P0[Zj^08Z:
RP1EEED0Q8B407=cL`1DE5@0EUIF05eMG@0o?cl0Cdm?05IFEP1HF5P0DU9B05EEE@1@D500=CDe06][
J`1LG5`0CDe=07moO`1XJ6P0O7al08R8R02@T90208B4Q01=03De=@0a<C40;Rh^02LW9`12@T80GUiN
03Lg=`1OGel0BDU905YJFP1ADE40Cdm?0492@P0[:b/0DU9B05=CD`1>CTh0<c<c03/k>`1PH600KFe]
06=SH`1=CDd0AdM705UIF@2@T900DU9B030`<01>CTh0M7Ad04=3@`0a<C40?Cdm06ATI02:RXX0FUYJ
03De=@13@d<0Lg=c07YjNP1gMgL0LW9b06IVIP1ZJVX0@d=305=CD`1RHV80H61P04I6AP1;Bd/0GUiN
04I6AP0g=cL0ADE503/k>`1<C4`0>SXj03dm?@1CDe<0Cdm?07QhN01ADE40GemO06=SH`1TI6@0>SXj
055AD@1:BTX0B4Q80451@@1:BTX0?Shn06i^KP1/K6`0IVIV04A4A022PX800P1BDU80T00e=CD0?3`l
05IFEP1RHV80GUiN06EUI@1HF5P0J6QX05]KF`1IFET0DU9B03Xj>P0_;bl0EUIF04i>CP1@D500CTi>
06YZJP2>SXh0NGUi04E5A@1ADE40HV9R04i>CP1WIfL0MgMg09NGU`2KVi/0EUIF04a<C01GEeL0Bd];
0451@@0n?Sh0?clo05EEE@0l?3`0?clo04Y:BP1DE5@0PH6106e]K@26QXH0Kfm_04e=C@0l?3`0CTi>
07AdM028R8P0PX:204e=C@1OGel0H61P03hn?P1`L700Xj>S06e]K@0Y:BT0F5QH03<c<`1ZJVX0De=C
04];B`1`L700:2PX071`L01=CDd07alO030`<016ATH0@d=305=CD`0[:b/0=cLg02TY:@10@400AdM7
04];B`0[:b/0ADE504i>CP0a<C40C4a<051@D00/;2`0=CDe03/k>`0m?Cd0KFe]02h^;P1hN7P0D51@
00d=3@1NGUh0K6a/02<S8`0_;bl0?Cdm03hn?P1>CTh0C4a<05YJFP1=CDd0GUiN09:BTP2KVi/0GUiN
04E5A@1FEUH0FEUI06ATI01nOWh0ADE506QXJ01PH600KFe]03hn?P1@D500BDU905IFEP16ATH0CDe=
05IFEP1TI6@0GUiN05UIF@1XJ6P0EeMG08j>SP1@D500T92@079bLP0U9BD0H61P02@T9027QhL0Ng]k
05iNGP1TI6@0F5QH05YJFP1[Jf/0WYjN06MWI`80JVYZ0380[:b/06UYJ@1PH600L71`06m_K`1IFET0
Ph>3069RHP0l?3`0ADE505YJFP0o?cl0Bd];02LW9`1TI6@0=3@d05iNGP18B4P0DU9B04i>CP1oOgl0
XZ:R055AD@14A4@0K6a/075aL@1kNg/0B4Q805UIF@1@D500@41005MGE`1RHV80Fe]K04U9B@1QHF40
De=C0;Jf]P2?Shl0Ti>C0;2`/02/[:`0aLG508:2PP2;Rh/0GEeM0:6QX@2SXj<0MgMg09RHV0;ooooo
0000o`1ADE40N7Qh0:n_[`25QHD0TI6A04Q8B01MGEd0_kno09>CT`1XJ6P0ZJVY04A4A01UIFD0ZJVY
08F5Q@1HF5P0WinO05UIF@18B4P0T92@09VIV@0o?cl0Kfm_03@d=00g=cL0EUIF06a/K00a<C40=3@d
04U9B@0`<300?3`l092@T01NGUh0=cLg059BDP11@D40;Bd]07EeM@1/K6`07QhN02`/;01IFET0CDe=
0492@P2:RXX0OWin03<c<`0U9BD0Bd];08N7Q`1GEeL0/K6a04Y:BP0V9RH0>SXj05eMG@1DE5@0TY:B
08:2PP0B4Q80:2PX0492@P1FEUH0=SHf08Z:RP13@d<07QhN02l_;`1CDe<0DE5A03@d=01EEED0:2PX
02LW9`1mOGd0Ti>C06MWI`0Z:RX0MgMg038b<P0K6a/0C4a<07YjNP0T92@0;Bd]055AD@0j>SX0GEeM
07MgM`1VIVH05aLG03/k>`1PH600BTY:07YjNP2ATI40?3`l024Q8@1EEED0SXj>06=SH`1TI6@0Xj>S
055AD@0Y:BT0@T9205UIF@1cLg<0P82009ZJVP1:BTX08b<S05QHF02TY:@0>c/k04m?C`1JFUX08B4Q
04M7A`1/K6`0[jn_0492@P14A4@0ATI606IVIP1;Bd/0Zj^[096AT@0K6a/0@41005=CD`1@D500Lg=c
08n?S`2RXZ809bLW03Xj>P1;Bd/0BDU907YjNP1dM7@0?3`l02DU9@0m?Cd0HV9R04=3@`1WIfL0Jf][
01dM7@1?Cdl0IVIV0;2`/01gMgL0QhN703Xj>P0Z:RX0GemO08F5Q@0n?Sh0KVi^03Ti>@0`<300DU9B
09VIV@1cLg<09BDU04];B`0`<300AdM706IVIP1eMGD0>CTi03Lg=`1PH600EeMG07AdM02=SHd0YjNW
03@d=00W9bL0BDU906ATI01JFUX0P82006=SH`0X:2P0:b/[055AD@19BDT0FEUI08n?S`0Z:RX0:2PX
06QXJ01VIVH0C4a<0861P@20P800>c/k0492@P2ATI40];Bd06ATI02NWYh0>3Ph03hn?P1:BTX0MWIf
05eMG@1<C4`0Kfm_02HV9P15ADD0N7Qh0:6QX@0e=CD0NGUi05IFEP1PH600_[jn08V9R@1:BTX0Hf=S
03hn?P0e=CD0VYZJ06IVIP0f=SH0@410034a<@1UIFD0ZJVY06UYJ@0[:b/0?Cdm04i>CP15ADD0[jn_
092@T00V9RH0CTi>08V9R@1eMGD0NWYj071`L00];Bd09RHV059BDP1PH600IFEU09BDU00[:b/0;Rh^
05QHF000E`2:RXX0EeMG06e]K@1nOWh092@T02h^;P1MGEd0LW9b03Xj>P14A4@0B4Q802DU9@0h>3P0
I6AT06e]K@0L71`0>3Ph04i>CP1?Cdl0De=C08F5Q@14A4@08B4Q02LW9`15ADD0IVIV06ATI02<S8`0
@T92020P8011@D40E5AD04E5A@1[Jf/0SHf=03hn?P0Q8B40?Cdm04e=C@1TI6@0A4A408Z:RP1?Cdl0
;Bd]04M7A`1[Jf/0EUIF05ADE022PX80;Rh^03De=@11@D40Fe]K05QHF01EEED0HV9R01dM7@0/;2`0
A4A407AdM019BDT0>SXj07QhN00Z:RX0D51@05EEE@1UIFD0FUYJ06IVIP18B4P0GEeM07=cL`2:RXX0
QhN707alO01hN7P0LG5a07moO`1GEeL0Cdm?06EUI@1CDe<0IFEU06UYJ@1KFe/0HF5Q05mOG`02055A
D@03051@D01GEeL0EeMG0080De=C00h0EUIF07IfMP1MGEd0B4Q806ATI01UIFD0JVYZ07QhN01^KVh0
Q8B409ZJVP2DU9@0/k>c0:FUY@80AdM70440IfMW059BDP1RHV80LW9b03Lg=`24Q8@0EeMG06i^KP1B
DU80M7Ad06MWI`0g=cL0L71`0410@02BTY80@D5103/k>`1QHF40Bd];061PH00g=cL0>c/k05UIF@1B
DU80AdM7028R8P1CDe<0BDU904e=C@0j>SX0JFUY051@D019BDT0LW9b04Q8B01<C4`0GUiN04A4A01@
D500@41002d];@1FEUH0F5QH04m?C`0_;bl0;2`/04U9B@0g=cL0=SHf01LG5`0c<c<0BDU902HV9P12
@T80ADE504Y:BP0j>SX0>c/k05eMG@16ATH0=CDe038b<P1=CDd0ADE504U9B@0204I6AP0c05=CD`1M
GEd0CTi>05MGE`18B4P0DU9B069RHP1SHf<0FUYJ05IFEP0e=CD0C4a<06=SH`1iNGT0Lg=c03Xj>P17
AdL0F5QH03dm?@0n?Sh0>3Ph03De=@0g=cL0;Bd]02PX:00o?cl0?Cdm04A4A01:BTX0Hf=S06UYJ@21
PH40V9RH07EeM@1`L700JVYZ03Ti>@1KFe/0HF5Q055AD@2<S8`0IFEU055AD@1@D500A4A405]KF`1Q
HF40EeMG04i>CP1TI6@0LW9b0080Bd];0P1GEeL0:@1FEUH0Ph>305EEE@0_;bl0EUIF0451@@0i>CT0
FUYJ03<c<`1/K6`0_[jn06i^KP0i>CT0GEeM05aLG02UYJD0D51@04e=C@1DE5@08B4Q0410@011@D40
9BDU03`l?00`<3009RHV05aLG01:BTX0E5AD03/k>`15ADD0:2PX02/[:`0@4100G5aL055AD@1:BTX0
HV9R04];B`0a<C40Bd];0080BTY:06`0MgMg0451@@2c/k<0VYZJ02h^;P1@D500JFUY02`/;00l?3`0
?Cdm03Ph>01@D500F5QH05MGE`1ADE40KFe]059BDP1OGel09bLW03Ti>@1BDU80D51@03De=@1CDe<0
@d=304i>CP1<C4`0T92@05iNGP1DE5@0DE5A04Q8B00k>c/0Fe]K061PH011@D40E5AD05iNGP1VIVH0
ATI609VIV@0o?cl0ATI605=CD`0n?Sh0Hf=S0410@01DE5@0EeMG06QXJ01QHF40J6QX05UIF@1DE5@0
SXj>05EEE@23Ph<0FUYJ0;Zj^P2DU9@0Q8B405MGE`1MGEd0=CDe05MGE`1NGUh0ADE505=CD`16ATH0
>SXj05=CD`18B4P0K6a/03Xj>P17AdL0?Shn09:BTP1kNg/0MGEe08>3P`1>CTh0JFUY07]kN`1@D500
KVi^07MgM`26QXH0I6AT05EEE@1jNWX0H61P07IfMP1VIVH0MGEe03dm?@1]KFd0Kfm_08N7Q`2o_kl0
LG5a07inOP2/[:`0Ti>C04e=C@1QHF40MgMg05=CD`2DU9@2ooooo`000=40HV9R05]KF`1QHF40Cdm?
09VIV@1XJ6P0BDU905mOG`1VIVH0GEeM09RHV00m?Cd0:b/[04a<C01GEeL0@T920:ZZZP0o?cl0;2`/
0451@@1YJFT0Lg=c08F5Q@1;Bd/0:2PX0410@01?Cdl0E5AD07UiN@2SXj<07QhN03hn?P1CDe<0Lg=c
07QhN02i^KT0=3@d02d];@11@D40Cdm?04a<C01^KVh0OGem01`L700_;bl0;2`/05EEE@0f=SH0G5aL
05MGE`0S8b<0>CTi05EEE@1PH6007AdM061PH01^KVh08R8R05UIF@2LW9`0D51@02l_;`14A4@0<30`
03Xj>P21PH40LW9b01hN7P0`<300=SHf059BDP1TI6@0RHV904A4A00F5QH05aLG03hn?P1hN7P0Fe]K
0;no_`0Y:BT0;Bd]02@T9012@T80A4A4055AD@26QXH0820P01LG5`1ADE40Fe]K02l_;`1BDU80W9bL
04E5A@0];Bd0BDU905YJFP0E5AD0PX:204a<C00R8R80;Bd]06EUI@26QXH0=cLg04a<C01CDe<08B4Q
038b<P1/K6`0BDU902HV9P0c<c<0A4A404I6AP2NWYh0NGUi01`L700[:b/0A4A408j>SP1JFUX0Ph>3
06i^KP0`<300=3@d071`L02>SXh0C4a<07inOP28R8P0<S8b02l_;`1gMgL0Vi^K04=3@`1MGEd0M7Ad
02LW9`0j>SX0PX:206QXJ00o?cl0OWin05eMG@0W9bL0Kfm_0:VYZ@16ATH09BDU05aLG00a<C40>CTi
09jNWP2c/k<0ATI602XZ:P1OGel0ADE508f=S@1PH600:RXZ03Lg=`1BDU80OWin05ADE02f][H0F5QH
01TI6@1]KFd0Ogmo05EEE@1jNWX0e]KF038b<P0W9bL0C4a<0:VYZ@2KVi/0E5AD071`L00g=cL0;Bd]
065QH@1gMgL0<30`04m?C`1gMgL05aLG04A4A026QXH0KVi^03@d=01HF5P0=3@d034a<@1PH600XJ6Q
03Xj>P0e=CD0A4A4030`<019BDT0U9BD08J6QP0];Bd0@d=3059BDP0207=cL`0S0:VYZ@0V9RH0>3Ph
04i>CP1gMgL0HV9R0:>SX`1gMgL09RHV05MGE`1kNg/0IFEU0;:b/P0l?3`08b<S061PH01XJ6P0EEEE
079bLP0d=3@071`L05mOG`2b/[80EUIF05=CD`0n?Sh092@T0410@01lO7`0EeMG05EEE@2DU9@0@D51
05iNGP1hN7P00P1:BTX01`11@D40>CTi061PH027QhL0Jf][02PX:01=CDd00P12@T80@`1cLg<0TI6A
03Hf=P0f=SH0B4Q8071`L01NGUh0Lg=c08b<S00V9RH0;Bd]04E5A@1mOGd0BDU907]kN`2>SXh07AdM
0492@P17AdL0Bd];04M7A`1SHf<0GUiN01`L701EEED0HF5Q05aLG00T92@0O7al03`l?00e=CD0CDe=
08>3P`1^KVh09RHV0451@@1KFe/07alO02d];@1JFUX0I6AT01XJ6P0l?3`0AdM702/[:`0_;bl0J6QX
06IVIP0V9RH0@D5104U9B@0a<C40G5aL0;no_`10@4006a/K030`<00k>c/0?Shn05]KF`3Bd]80Bd];
071`L01_Kfl0KFe]05]KF`1PH6000P1FEUH0;01?Cdl0D51@07MgM`2/[:`0SXj>04Y:BP1NGUh0LW9b
07inOP2VYZH0PX:207inOP2FUYH0N7Qh09VIV@1/K6`0@41005YJFP1KFe/0@d=305IFEP1?Cdl0BTY:
0492@P14A4@0<30`04I6AP1nOWh0Cdm?03lo?`1OGel0YZJV07emO@1KFe/0K6a/0;2`/02@T900AdM7
03dm?@0o?cl0<C4a03/k>`1>CTh0ATI60P1HF5P02@1=CDd0@T9205QHF01UIFD0GEeM05iNGP12@T80
NWYj061PH002065QH@0/04i>CP1_Kfl0HF5Q05UIF@1KFe/0IFEU06YZJP0k>c/0Hf=S051@D01XJ6P0
GEeM07moO`1IFET0De=C08B4Q01ZJVX0L71`07=cL`1>CTh0JFUY065QH@15ADD0M7Ad03/k>`1FEUH0
BDU903De=@0n?Sh0>CTi03dm?@0A4A40:RXZ05IFEP0c<c<0Fe]K04A4A01ADE40DU9B04M7A`1XJ6P0
Cdm?03<c<`1=CDd205eMG@0T04Y:BP14A4@0E5AD07=cL`1SHf<0ADE506m_K`1CDe<0HF5Q03Xj>P1Q
HF40AdM704Q8B015ADD0EEEE05YJFP1@D500EEEE04Q8B01GEeL0Bd];03De=@11@D40Fe]K0492@P0e
=CD0<30`04E5A@1DE5@0F5QH06IVIP1`L700N7Qh06ATI02>SXh0VIVI0P1CDe<0>01NGUh0@D5105YJ
FP1?Cdl0IfMW07emO@1HF5P0FEUI05ADE017AdL0KVi^055AD@1<C4`0GEeM04E5A@1OGel0I6AT06][
J`1hN7P0Lg=c03lo?`1IFET0De=C04m?C`1XJ6P0Bd];06YZJP1MGEd04Q8B071`L038b<P0OGem03Hf
=P1@D500;Rh^04m?C`10@400ATI606ATI00<30`0ATI603Hf=P0_;bl0?clo03dm?@0Z:RX0DE5A05mO
G`1_Kfl07QhN038b<P0];Bd0<S8b02TY:@2ATI40Hf=S0P0f=SH0L@1JFUX0EeMG08>3P`1CDe<0<c<c
04i>CP10@400IVIV05IFEP0d=3@0FEUI05eMG@0T92@0:BTY0410@00f=SH0@D5106=SH`26QXH0A4A4
04M7A`1lO7`0UYJF04A4A00i>CT0=3@d03dm?@1YJFT0PH6104=3@`1GEeL0CTi>05IFEP15ADD0F5QH
04U9B@18B4P0>c/k04E5A@1:BTX0>c/k051@D02IVIT0QXJ603hn?P1MGEd0<c<c05=CD`1PH600?clo
06UYJ@15ADD0HV9R06IVIP1?Cdl0LW9b08R8R01LG5`0Bd];05iNGP1IFET0S8b<05eMG@29RHT0EEEE
05aLG01aLG40P82004e=C@1VIVH0Jf][02<S8`1_Kfl0JFUY0492@P1KFe/0=SHf07=cL`1:BTX0Ph>3
03Lg=`17AdL0;bl_06YZJP2FUYH0XZ:R0;Jf]P2UYJD0Ph>308F5Q@15ADD0BDU904I6AP0a<C40BTY:
03hn?P1DE5@0=3@d05IFEP0`<300ZZZZ071`L01^KVh0X:2P09:BTP2KVi/0/;2`0;Zj^P1YJFT0RHV9
07alO01JFUX0YJFU00;ooooo0000o`1dM7@0YJFU09^KV`19BDT0OWin08f=S@2?Shl0Z:RX03/k>`1_
Kfl0SXj>06IVIP2KVi/0Ogmo03Xj>P17AdL0L71`09RHV01;Bd/0IVIV038b<P0n?Sh0EeMG07MgM`0g
=cL0Hf=S05QHF00K6a/0De=C08j>SP17AdL0;Rh^05=CD`0Q8B40;2`/06ATI01oOgl09BDU04a<C00e
=CD0:b/[0410@02UYJD0E5AD01hN7P15ADD0A4A405MGE`1kNg/0OWin01/K6`0X:2P0CDe=05eMG@16
ATH0QXJ608b<S00U9BD0<C4a04M7A`1ADE40Hf=S07EeM@0N7Qh0@D51069RHP1WIfL0DU9B07inOP1i
NGT06QXJ02`/;019BDT0S8b<04];B`1^KVh0JFUY01hN7P1?Cdl0GUiN06EUI@0/;2`0EUIF03Ph>00U
9BD0DE5A05aLG01XJ6P0:BTY03Xj>P0l?3`0BTY:06QXJ026QXH0:BTY02d];@1=CDd0EEEE04=3@`2B
TY80Xj>S01`L700f=SH0DE5A05UIF@19BDT0Q8B409ZJVP0<30`0:RXZ030`<00m?Cd0EeMG08>3P`1/
K6`071`L03hn?P1GEeL0;2`/02l_;`1<C4`0;Rh^02l_;`19BDT0OGem04];B`0/;2`0I6AT03Hf=P0[
:b/0B4Q807IfMP0Y:BT06a/K04A4A017AdL0?Shn07moO`2JVYX0:b/[01XJ6P1RHV80MWIf04i>CP2G
UiL0@T9202<S8`0Y:BT0JFUY07QhN017AdL0XZ:R03<c<`0X:2P0>c/k0:NWY`2DU9@0CTi>0820P00S
8b<0?Shn0:f][@1SHf<0GUiN06e]K@0O7al0AdM704Q8B01dM7@0<S8b03Xj>P0m?Cd0;Bd]04E5A@1a
LG40QhN702`/;00h>3P0?3`l04i>CP1ADE40W9bL0410@00R8R80L71`06a/K01BDU80MWIf0;Jf]P0[
:b/07AdM06YZJP1]KFd0DU9B0;Ng]`14A4@061PH020P801]KFd0FUYJ079bLP1nOWh07QhN0451@@0o
?cl0GUiN03Ph>01EEED0IFEU01dM7@1FEUH0F5QH059BDP12@T80VYZJ030`<00Y:BT0N7Qh08V9R@0S
8b<0Cdm?034a<@13@d<0I6AT06QXJ00h>3P0Ng]k03<c<`1KFe/0YZJV05=CD`0T92@0C4a<04Y:BP1n
OWh0WinO05EEE@0N7Qh0C4a<051@D01?Cdl0P82009BDU00];Bd0=cLg07]kN`1EEED0LW9b05ADE00_
;bl0DU9B06=SH`26QXH0H61P08V9R@00M00n?Sh0=cLg07IfMP1nOWh0IVIV05IFEP2WYjL0>SXj03/k
>`1^KVh0O7al02XZ:P0l?3`0J6QX02l_;`0c<c<0F5QH08Z:RP0l?3`0<30`04Y:BP0/;2`0?3`l071`
L02MWId0:b/[02<S8`1VIVH0BDU904e=C@1cLg<0HF5Q02<S8`0[:b/0KVi^06][J`15ADD0KFe]09^K
V`0[:b/07AdM04Y:BP1gMgL0ATI606UYJ@25QHD061PH02<S8`19BDT0FUYJ02h^;P1EEED0KFe]01`L
700H61P0CDe=06i^KP0U9BD0Cdm?04M7A`0G5aL07AdM04];B`1UIFD0Ph>307MgM`1NGUh0C4a<08j>
SP1iNGT0QhN706QXJ01GEeL0GUiN065QH@1iNGT0C4a<05IFEP1RHV80MgMg08J6QP1VIVH0M7Ad075a
L@1;Bd/0H61P06QXJ01KFe/0C4a<06a/K01UIFD0OGem04];B`0g=cL0?Shn04=3@`1ADE40:2PX05mO
G`1SHf<0CDe=06][J`1PH600OGem06m_K`21PH40Ng]k07emO@0b<S808b<S03`l?00[:b/0AdM706=S
H`0l?3`0?Shn0P17AdL01`0i>CT0>SXj038b<P0[:b/0C4a<03dm?@15ADD00P0X:2P0]01;Bd/0F5QH
03/k>`0m?Cd0=CDe04e=C@1IFET0ADE503Ph>013@d<0Hf=S03hn?P0d=3@0>c/k06UYJ@24Q8@0EEEE
03`l?01<C4`0KVi^08j>SP1KFe/0CDe=05=CD`1IFET0Hf=S079bLP1TI6@0C4a<0410@00j>SX0FUYJ
02`/;00[:b/0=cLg03Ti>@1?Cdl0ATI60410@00o?cl0E5AD05EEE@0_;bl0?3`l06][J`1LG5`0>c/k
0492@P1:BTX0?3`l03lo?`1?Cdl0?Cdm06EUI@1YJFT0ADE504I6AP1[Jf/0Ng]k06i^KP1:BTX0Cdm?
06YZJP1]KFd0PX:2059BDP15ADD0HV9R04Q8B01PH600CDe=04a<C00`<300AdM703Lg=`16ATH0<30`
05aLG02NWYh0PH6105aLG02TY:@0Ph>305mOG`1]KFd0KVi^06e]K@2=SHd0@D5105]KF`1WIfL0HV9R
059BDP14A4@0BDU905aLG01=CDd0Cdm?04];B`1?Cdl0IfMW05eMG@1<C4`0DE5A04=3@`1QHF40IFEU
075aL@1MGEd0K6a/06ATI026QXH0QHF505aLG01EEED0UYJF07moO`0b<S80JVYZ04];B`1XJ6P0BTY:
04E5A@1[Jf/0>c/k05]KF`0d=3@09BDU03lo?`0d=3@0<c<c05EEE@0l?3`0EEEE02d];@0[:b/092@T
059BDP0K6a/0>3Ph03lo?`0m?Cd0C4a<03lo?`0[:b/0>SXj055AD@10@400Fe]K04I6AP1YJFT0IVIV
01dM7@1]KFd0OWin028R8P0S8b<0ATI604U9B@1PH600@d=305=CD`0i>CT0ADE503`l?017AdL0;bl_
02XZ:P15ADD0GemO03Lg=`1ADE40IFEU0820P01cLg<0GEeM05]KF`1_Kfl0=3@d0492@P80DE5A01H0
F5QH05IFEP1:BTX0A4A4059BDP17AdL0QhN706UYJ@2GUiL0N7Qh02h^;P1>CTh0=CDe07]kN`1bLW80
De=C03Ti>@1>CTh0BDU904];B`1aLG40?3`l0P1IFET0601hN7P0EeMG07AdM01WIfL0PH6104M7A`1C
De<0Bd];03De=@1ADE40De=C03Lg=`0n?Sh0<c<c04U9B@0M7Ad0CTi>04];B`1SHf<0EUIF09^KV`2U
YJD0?Cdm04A4A080?clo00l0IVIV04E5A@1XJ6P0D51@03Lg=`1IFET0GEeM09JFUP1EEED0D51@02DU
9@1_Kfl0QhN708n?S`2NWYh00P2d];@01`2BTY80Rh^;071`L02CTi<0LG5a04];B`27QhL00_ooool0
003o04i>CP1dM7@0U9BD04Y:BP1TI6@0@41005EEE@2;Rh/0@T920410@01;Bd/0>CTi04a<C01nOWh0
AdM703/k>`18B4P0ATI605=CD`2?Shl0?clo02LW9`0n?Sh0AdM705]KF`22PX80KFe]01XJ6P0^;Rh0
JVYZ069RHP1OGel0QhN702DU9@0S8b<0FEUI08f=S@18B4P0WinO06YZJP0R8R80:RXZ05IFEP1^KVh0
AdM708f=S@18B4P0<c<c04i>CP1JFUX0>c/k05EEE@2`/;00<C4a03Hf=P1cLg<0K6a/03`l?01OGel0
KFe]01hN7P1ADE40WIfM08F5Q@0R8R80BDU904I6AP0Y:BT0EEEE0:2PX01<C4`0:2PX04a<C011@D40
CDe=06a/K029RHT0;2`/03Hf=P1;Bd/0CDe=07QhN02h^;P0LW9b01lO7`0W9bL0EeMG06][J`1XJ6P0
^[Zj05MGE`0B4Q80>SXj06i^KP1dM7@0GEeM0<O7a`0/;2`09RHV0451@@1RHV80IVIV030`<02JVYX0
=3@d02l_;`1JFUX0RXZ:05YJFP0k>c/0Lg=c034a<@0_;bl0L71`07=cL`0E5AD0=3@d04Y:BP15ADD0
Fe]K09bLW00n?Sh0:BTY04Y:BP1CDe<0JFUY05YJFP2l_;`0C4a<01lO7`17AdL0Ph>306i^KP1?Cdl0
_[jn03/k>`0P8200D51@05aLG010@400@d=3096AT@0N7Qh0B4Q805iNGP1FEUH0:RXZ04I6AP1ADE40
:RXZ05UIF@1YJFT0EUIF02<S8`1EEED0=3@d04=3@`1YJFT0WYjN02l_;`0g=cL0@D51059BDP1nOWh0
T92@024Q8@0j>SX0J6QX05QHF01DE5@0SHf=08N7Q`0K6a/0A4A405UIF@1TI6@0E5AD092@T02JVYX0
<S8b04e=C@14A4@0KFe]0410@02BTY80=cLg03De=@0d=3@0EUIF08F5Q@1>CTh0PH61038b<P1<C4`0
Ogmo07IfMP0b<S80>CTi04];B`0m?Cd0H61P09bLW01;Bd/0:BTY05IFEP1<C4`0BTY:07YjNP2][Jd0
B4Q803Hf=P1@D500A4A406YZJP3?cll0Cdm?01TI6@1NGUh0MGEe04Y:BP27QhL0DE5A02HV9P1?Cdl0
Ogmo04];B`2][Jd0;Bd]03Hf=P1XJ6P0G5aL03Xj>P1`L700<C4a02HV9P1ZJVX0KVi^024Q8@1@D500
<C4a02TY:@1KFe/0Shn?04U9B@1?Cdl0De=C02<S8`1lO7`0OWin02DU9@0a<C40CTi>03De=@12@T80
Ogmo001J06a/K00E5AD0?3`l051@D018B4P0CDe=092@T01hN7P07AdM03Xj>P1OGel0B4Q807IfMP24
Q8@0:2PX00`<300e=CD0NGUi04I6AP1/K6`0RHV902@T900V9RH0BDU908j>SP1bLW80Ph>308f=S@19
BDT0=CDe08B4Q02;Rh/0;Rh^06MWI`2NWYh0B4Q803Hf=P1RHV80Vi^K06MWI`0f=SH0N7Qh03Ph>00i
>CT0E5AD08J6QP13@d<08b<S065QH@0];Bd0>SXj05eMG@1iNGT09BDU01hN7P0b<S80@41003lo?`25
QHD0T92@028R8P0P8200<30`05=CD`1VIVH0JFUY08b<S01VIVH0V9RH04a<C01_Kfl0O7al06UYJ@2Z
ZZX0Ti>C0;Bd]01ADE40GUiN05EEE@1ZJVX0TI6A08j>SP29RHT0UYJF05ADE01TI6@0GUiN055AD@1@
D500G5aL0P1KFe/0<`1;Bd/0ATI604i>CP1EEED0J6QX02`/;01cLg<0R8R807UiN@2OWil0MWIf0:2P
X02<S8`0XJ6Q0=WIf@33`l<0?clo04=3@`1cLg<0@D510492@P1kNg/0@41006ATI01GEeL0IfMW04M7
A`1BDU80H61P03`l?01lO7`0=SHf07AdM017AdL0@d=3061PH00d=3@0I6AT055AD@14A4@0@d=302l_
;`13@d<0;bl_04U9B@0e=CD0@T920451@@1VIVH0>CTi01lO7`02059BDP0K05]KF`12@T8071`L03Xj
>P12@T80=3@d05UIF@0Q8B40<S8b030`<00Z:RX0@41003Xj>P12@T807alO02/[:`0o?cl0<S8b03/k
>`13@d<0BTY:0451@@0_;bl0DU9B03Ph>00];Bd07alO0080?3`l0100?Cdm03<c<`0g=cL0?3`l04m?
C`1>CTh0Cdm?04a<C01DE5@0GUiN055AD@0_;bl0@41003dm?@1OGel0Fe]K0P1XJ6P0:018B4P0E5AD
04a<C016ATH0GemO05IFEP1?Cdl0CTi>059BDP0o?cl0FEUI0492@P1nOWh0F5QH079bLP1EEED0J6QX
06IVIP1ADE40EeMG069RHP11@D40Cdm?05ADE01BDU80LG5a05]KF`1@D500GEeM04U9B@24Q8@0J6QX
03lo?`16ATH0EUIF06QXJ01GEeL0GemO06YZJP1WIfL204U9B@0l0492@P1=CDd0PH6104];B`17AdL0
F5QH01LG5`1LG5`0_Kfm08j>SP0[:b/0BDU906e]K@2:RXX0Hf=S05mOG`1]KFd09BDU03<c<`0^;Rh0
=3@d04=3@`1=CDd0;bl_04Y:BP1DE5@0GUiN03lo?`1=CDd0@41003Lg=`0B4Q80Cdm?04a<C00f=SH0
H61P059BDP0];Bd0ADE504Q8B00m?Cd0EEEE03<c<`1kNg/0LW9b02TY:@19BDT0E5AD01TI6@0k>c/0
BTY:02h^;P10@400DU9B065QH@1ADE40Hf=S05ADE01OGel0FEUI0`1HF5P03P17AdL0Cdm?03Hf=P1B
DU80FUYJ06MWI`0a<C40FEUI03/k>`15ADD0=CDe04i>CP1TI6@0>SXj0P1<C4`05@1LG5`0AdM708j>
SP0c<c<0@41005UIF@17AdL0FEUI04M7A`1eMGD0E5AD059BDP1GEeL0O7al06a/K01PH600C4a<03Hf
=P1/K6`0>3Ph07QhN002079bLP0I05ADE01HF5P0ATI606e]K@1PH6006ATI06m_K`1XJ6P0>SXj04m?
C`0N7Qh0De=C04Q8B01fMWH0?Shn0861P@15ADD0B4Q8071`L014A4@0Jf][06ATI01GEeL0I6AT04U9
B@0205=CD`0D05IFEP1[Jf/0DE5A05EEE@1@D500MGEe04U9B@1lO7`0LW9b08R8R02LW9`0I6AT07=c
L`2l_;`0b<S805mOG`1dM7@0[Jf]06m_K`2LW9`2ooooo`0002P0FUYJ059BDP1cLg<0I6AT0:^[Z`18
B4P0EEEE06a/K02@T900WYjN09:BTP0i>CT0Bd];04e=C@1LG5`0NGUi09VIV@0Q8B40>c/k059BDP1S
Hf<0ADE507AdM00o?cl09bLW03dm?@1WIfL0>c/k05eMG@1BDU80<c<c0451@@21PH40Rh^;03Ti>@1>
CTh0>CTi02TY:@1jNWX0WYjN0P0`<300UP0n?Sh0;2`/055AD@31`L40Jf][01DE5@0e=CD0?clo03hn
?P1LG5`0VIVI07MgM`0M7Ad0B4Q806m_K`1@D500L71`08R8R00_;bl0<c<c061PH02IVIT0C4a<08:2
PP0M7Ad0:b/[059BDP1SHf<0Shn?055AD@2NWYh08R8R02HV9P1EEED0BTY:03De=@15ADD0Fe]K02`/
;00M7Ad0EUIF06QXJ00V9RH0>CTi05MGE`0T92@0;2`/05QHF01mOGd05aLG030`<01@D500=SHf03`l
?01iNGT0FUYJ01LG5`0[:b/0=SHf03Xj>P1FEUH0`L7106QXJ00G5aL0<c<c04m?C`1aLG40Rh^;0:JV
YP0U9BD0?Shn05QHF01UIFD0C4a<07=cL`1GEeL07QhN04E5A@1RHV80F5QH03Lg=`2JVYX0CDe=02l_
;`1@D500K6a/06i^KP0U9BD0C4a<05eMG@0n?Sh0=3@d09ZJVP2EUID0=CDe04e=C@1DE5@0<c<c05QH
F02j^[X0MGEe02<S8`1>CTh0FEUI04U9B@23Ph<0[:b/02PX:010@400IVIV06YZJP1nOWh0][Jf04U9
B@0V9RH0>SXj08b<S01ZJVX0V9RH03<c<`0K6a/0H61P071`L01?Cdl0?3`l09^KV`0[:b/0=SHf07al
O029RHT0PH6108Z:RP1cLg<0>CTi03/k>`20P800Vi^K05IFEP0g=cL0GemO03<c<`1@D500S8b<06YZ
JP0X:2P0?3`l03hn?P1EEED0EUIF0;Zj^P80=cLg05D0Cdm?06e]K@1GEeL0Shn?06ATI00^;Rh0IVIV
09JFUP1`L700BTY:08J6QP1:BTX0;Rh^069RHP2a/K40Ogmo04m?C`1nOWh0;bl_0451@@1KFe/0L71`
04U9B@2HV9P0<S8b04Q8B01>CTh0J6QX0451@@1TI6@0:b/[03hn?P2LW9`0Kfm_04A4A01_Kfl0@d=3
061PH02[Zj/0Y:BT07AdM01<C4`0FEUI055AD@2^[Zh0SXj>01PH6015ADD0JVYZ05iNGP1mOGd0M7Ad
020P8019BDT0H61P04A4A01lO7`0];Bd02<S8`0Q8B40P8200;Vi^@15ADD0MgMg071`L00a<C40D51@
04];B`2:RXX0>CTi05eMG@1YJFT0;2`/055AD@26QXH0OWin01`L701BDU80;2`/04Y:BP1MGEd0U9BD
05MGE`0O7al0?Shn00<0>CTi05d0GUiN04U9B@0W9bL0DU9B04Q8B013@d<0R8R80:f][@18B4P09bLW
03De=@1<C4`0KFe]06UYJ@2HV9P0?3`l03@d=013@d<0F5QH06e]K@1:BTX0]kNg03hn?P0];Bd0BTY:
05aLG01JFUX0DU9B07moO`0M7Ad0=SHf03`l?01VIVH0BDU903dm?@1MGEd0820P07MgM`21PH40MWIf
04i>CP1eMGD0E5AD07MgM`2LW9`0PX:20::RXP2EUID0/K6a09:BTP2FUYH0MGEe0<30`037alL0SHf=
08N7Q`2BTY80SHf=09>CT`26QXH0DU9B07alO01UIFD0KFe]08F5Q@1`L700I6AT051@D01PH600Fe]K
04];B`2GUiL0Ng]k05ADE025QHD0PH6109BDU02>SXh0[:b/0=gMg@3<c<`0@d=303/k>`18B4P0<S8b
05iNGP20P800@d=306UYJ@1XJ6P0I6AT04M7A`1HF5P00P1MGEd08`1kNg/0=cLg07YjNP1RHV80EeMG
06i^KP17AdL0QHF505]KF`1CDe<0@T920451@@1bLW80@D51069RHP1HF5P0D51@04U9B@1WIfL0D51@
05=CD`25QHD0C4a<059BDP1EEED0BTY:05aLG01RHV80@41007]kN`0j>SX0EEEE04I6AP0c<c<0@410
0080AdM700h08R8R02XZ:P1JFUX0@T9206=SH`18B4P0DU9B05IFEP0o?cl0Fe]K0492@P13@d<0EEEE
05MGE`80@d=30=00=CDe03Hf=P0c<c<0ATI602/[:`1<C4`0BTY:04Q8B00U9BD0Bd];034a<@11@D40
;bl_038b<P14A4@0FEUI04M7A`0k>c/0@d=304U9B@0o?cl0BTY:059BDP0c<c<092@T03/k>`1FEUH0
C4a<069RHP26QXH0YZJV09fMW@2OWil0gMgM0:ZZZP1SHf<0JVYZ07emO@1EEED0R8R807inOP1BDU80
S8b<08R8R01XJ6P0IfMW06QXJ01?Cdl0=cLg04M7A`1cLg<0<30`03lo?`1?Cdl0Hf=S06MWI`1_Kfl0
BTY:06][J`1UIFD0?clo055AD@1MGEd0P82008Z:RP0@4100ATI60>;RhP2b/[80Bd];06a/K00j>SX0
DU9B05ADE01<C4`0F5QH01PH601@D500B4Q802HV9P0k>c/0>CTi02XZ:P1ADE40;Rh^04I6AP0X:2P0
;bl_02`/;01=CDd0@T9204e=C@1HF5P0>CTi04Y:BP1VIVH0@D5106EUI@1ADE40>c/k04Q8B01:BTX0
S8b<07moO`0[:b/0HV9R06YZJP0R8R80:BTY04M7A`0l?3`0BDU906ATI01/K6`0=CDe04U9B@12@T80
F5QH05eMG@0];Bd0=CDe04a<C018B4P0LW9b03De=@1EEED0L71`04e=C@0b<S80M7Ad04i>CP1KFe/0
F5QH05]KF`1OGel0EeMG05ADE01bLW80OWin02XZ:P1YJFT0>CTi04m?C`1LG5`0<c<c07EeM@0/;2`0
HF5Q05MGE`1PH600=cLg04e=C@15ADD0C4a<05UIF@16ATH0DE5A0410@02GUiL0I6AT09:BTP29RHT0
Zj^[04U9B@1:BTX0?Shn01XJ6P0];Bd0=SHf030`<01OGel0ADE506MWI`18B4P0P82004M7A`1KFe/0
7alO08R8R02[Zj/0H61P08R8R01aLG40HV9R09ZJVP1:BTX0Bd];05EEE@0o?cl0Hf=S05ADE01IFET0
IVIV06][J`0g=cL0][Jf08b<S01lO7`0]KFe08n?S`26QXH0RXZ:09>CT`1nOWh0P820061PH01KFe/0
LG5a0_ooool0001508f=S@2>SXh0H61P05IFEP20P800JFUY05UIF@1/K6`0A4A407EeM@2CTi<0FUYJ
04I6AP1IFET0:RXZ05eMG@2EUID0BTY:03hn?P1>CTh0?Shn04I6AP1oOgl0De=C02XZ:P0i>CT0?Cdm
04Y:BP2a/K40LG5a02TY:@0X:2P0Cdm?08n?S`1cLg<0SHf=04=3@`0T92@0?clo07inOP1FEUH0NWYj
07UiN@0Z:RX09BDU06m_K`26QXH0Bd];071`L021PH40410@05MGE`1KFe/0CDe=03Lg=`1UIFD0EUIF
01dM7@1SHf<0KVi^04E5A@0o?cl0BTY:020P8019BDT0Hf=S05aLG00L71`0>3Ph0080@D5100`0Bd];
07=cL`1fMWH06a/K03De=@19BDT0CDe=07inOP2:RXX0?clo01LG5`0d=3@205EEE@2^09jNWP31`L40
7AdM01DE5@0l?3`0Lg=c04U9B@1kNg/0ZJVY02@T900P8200Jf][07alO01KFe/0Z:RX08F5Q@0M7Ad0
8b<S06MWI`27QhL0?Cdm055AD@0m?Cd06a/K04];B`12@T80?Cdm038b<P1HF5P0<30`0492@P1VIVH0
Fe]K01dM7@0d=3@0DE5A03Ti>@1MGEd0QHF508J6QP0U9BD0B4Q805YJFP1WIfL0C4a<07IfMP1mOGd0
;2`/0492@P1PH600U9BD0:2PX024Q8@0PX:203<c<`0Y:BT0EUIF08n?S`1YJFT0UYJF03/k>`0Z:RX0
De=C08j>SP1eMGD0D51@07UiN@0g=cL0?clo08>3P`26QXH0;2`/05=CD`1UIFD0@T9207UiN@1bLW80
92@T04m?C`1QHF40GemO06e]K@2VYZH0JVYZ024Q8@1=CDd0K6a/065QH@1lO7`0`/;206EUI@0M7Ad0
@T9207AdM02BTY80Jf][0;Zj^P0S8b<0<c<c07EeM@1bLW80I6AT08B4Q01[Jf/0:2PX04Q8B020P800
EEEE04e=C@28R8P0<30`03`l?018B4P0K6a/03hn?P0l?3`0G5aL03dm?@10@400G5aL0820P00c<c<0
=CDe0410@01[Jf/0De=C07]kN`0T92@0<C4a03hn?P0i>CT0A4A40<30`01MGEd0;Bd]06ATI01>CTh0
F5QH0820P00n?Sh09bLW061PH01QHF40OGem07YjNP11@D408B4Q05eMG@2n_[h0_Kfm0:ZZZP1mOGd0
G5aL06a/K01QHF40A4A407alO01>CTh0=3@d05eMG@29RHT0?3`l05ADE01ZJVX0:BTY04i>CP27QhL0
Fe]K03<c<`1UIFD0ATI605ADE01dM7@0XJ6Q0P0m?Cd01@1RHV80ADE505=CD`1kNg/0WYjN0080:RXZ
00h0GUiN0820P01ADE40UIFE069RHP0Z:RX0@D5105=CD`1cLg<0IVIV07]kN`1VIVH0;Rh^04];B`80
EEEE05/0KFe]09NGU`1KFe/051@D03<c<`20P800M7Ad05eMG@1YJFT0NGUi030`<00T92@0I6AT05MG
E`0S8b<0=3@d059BDP0<30`0:BTY06e]K@1ZJVX09RHV04M7A`0d=3@0:BTY04M7A`1RHV80=3@d01XJ
6P1:BTX0<C4a02/[:`17AdL0NWYj02DU9@2JVYX0TI6A06e]K@1GEeL0[Zj^065QH@1_Kfl0MWIf06UY
J@2>SXh0][Jf09bLW01HF5P0E5AD04I6AP1<C4`0LW9b06i^KP26QXH0O7al04I6AP1FEUH0IVIV06=S
H`0n?Sh0BDU907=cL`1oOgl0DE5A07UiN@1BDU80Fe]K04M7A`0V9RH0DE5A06MWI`1VIVH0D51@04A4
A01^KVh0Ti>C0861P@2QXJ40PX:205UIF@19BDT0>CTi03/k>`1>CTh0JVYZ05EEE@1[Jf/0HV9R05=C
D`18B4P0DE5A0080ATI60500FUYJ051@D01WIfL0BTY:04m?C`1PH600C4a<071`L01bLW80JFUY04i>
CP1DE5@0HF5Q03Ph>01IFET0G5aL06=SH`1;Bd/0LG5a07QhN01iNGT0Ogmo04m?C`1HF5P0J6QX04A4
A01CDe<0E5AD04Q8B01_Kfl0ATI605iNGP1=CDd0@D5104A4A013@d<0CTi>03Ti>@0W9bL0ATI60451
@@1XJ6P0Bd];05UIF@1HF5P0?3`l06QXJ00l?3`0EEEE04i>CP1FEUH0ATI604Q8B00o?cl0AdM704I6
AP1HF5P0?3`l06m_K`1ADE40I6AT0410@01ZJVX0?Shn05YJFP18B4P0@D5105QHF016ATH0EEEE02<S
8`0b<S80?Cdm03De=@1<C4`0>CTi03/k>`0f=SH0?3`l02`/;080@d=30180F5QH03Ti>@1>CTh0?clo
05UIF@1@D500Fe]K07alO01ADE40GEeM06IVIP1/K6`0OGem06i^KP15ADD0@T9203/k>`0T92@204M7
A`0F03Ph>012@T80<30`04U9B@1?Cdl0@41003dm?@0n?Sh0EeMG05iNGP1XJ6P0Ogmo08b<S01hN7P0
@T9205iNGP0k>c/0BDU9096AT@1cLg<09RHV04E5A@80Fe]K00h0J6QX06ATI01IFET06a/K04I6AP0d
=3@09BDU04I6AP0];Bd0<30`04a<C00`<300De=C02<S8`80=cLg07L0?3`l034a<@1aLG40Jf][05]K
F`1RHV80AdM702<S8`0f=SH0A4A403lo?`1JFUX0AdM706][J`1PH600;2`/0451@@1UIFD08R8R02`/
;015ADD0:2PX04E5A@17AdL0N7Qh05MGE`1lO7`0EUIF07QhN01]KFd0BTY:06UYJ@1ZJVX0ADE50861
P@1>CTh0LG5a061PH01eMGD0AdM705YJFP0/;2`0Bd];03Lg=`11@D40BTY:0451@@1:BTX0D51@05AD
E01ADE40YJFU06MWI`29RHT0L71`02PX:01DE5@0@d=307alO01FEUH0DU9B05EEE@1SHf<0CTi>0410
@01fMWH0<S8b05UIF@0f=SH0R8R806QXJ01PH600Fe]K05ADE00g=cL0HV9R08F5Q@1ADE40A4A405AD
E010@400@d=303Xj>P1gMgL0;Rh^05aLG01JFUX0Y:BT04Y:BP1BDU80GemO04i>CP1BDU80HF5Q038b
<P1MGEd0?clo05EEE@1CDe<0AdM706UYJ@1LG5`0TI6A05eMG@1VIVH0D51@06a/K02IVIT0UIFE08R8
R02?Shl0][Jf0:2PX02VYZH0YJFU09fMW@1TI6@0GEeM09>CT`02ooooo`0003L0QhN70::RXP2IVIT0
CTi>07EeM@1kNg/0RXZ:0:JVYP0n?Sh0AdM706][J`23Ph<0O7al08^;R`12@T80DE5A05QHF01BDU80
IVIV08V9R@0`<3009bLW04Q8B01VIVH0ADE508J6QP10@400;2`/02TY:@1@D500A4A404m?C`1BDU80
4a<C0492@P1HF5P0>CTi01lO7`1BDU80?clo02HV9P1GEeL0S8b<02DU9@0N7Qh0D51@04I6AP0Z:RX0
L71`0:n_[`0/;2`0<C4a05iNGP1:BTX0>c/k0080NGUi0?l06ATI04=3@`1?Cdl0@410075aL@1oOgl0
820P02/[:`19BDT0Ph>305aLG01eMGD0JFUY01/K6`0b<S80Ng]k08f=S@1ADE40P82005UIF@0V9RH0
@D5107MgM`1;Bd/0@d=307emO@0h>3P08b<S04Y:BP29RHT0JFUY03Hf=P1JFUX0820P01LG5`1:BTX0
SXj>05EEE@0T92@0Cdm?034a<@0/;2`0L71`09NGU`0U9BD0:BTY0410@00h>3P0HV9R09:BTP26QXH0
5ADE03Ti>@1IFET0Fe]K071`L02CTi<0HV9R01/K6`0m?Cd0ATI605UIF@1hN7P0[:b/024Q8@0a<C40
?clo06e]K@1BDU80EeMG09:BTP0K6a/0ADE504Y:BP1NGUh0C4a<04=3@`2MWId0<c<c034a<@1aLG40
NGUi03lo?`0k>c/0HF5Q03`l?013@d<0UiNG07=cL`0Z:RX0@T9205IFEP1@D500G5aL09jNWP0^;Rh0
=CDe04A4A01[Jf/0G5aL08B4Q02DU9@0<c<c05ADE02DU9@0BDU909>CT`1kNg/0=CDe03Ph>01bLW80
KFe]03/k>`1^KVh0JFUY01XJ6P1=CDd0I6AT07alO00m?Cd0I6AT06EUI@0T92@0CDe=069RHP1bLW80
<c<c05iNGP10@400?clo0:2PX02MWId09bLW02TY:@1CDe<0=SHf05IFEP2_[jl0RXZ:02<S8`0];Bd0
G5aL06=SH`1eMGD0Vi^K03<c<`0o?cl0BTY:06m_K`1[Jf/0Q8B407emO@0H61P0GEeM0861P@1LG5`0
KFe]0820P00U9BD0?Shn09jNWP2ZZZX0BDU905QHF00P8200@41005IFEP1ADE40?clo07]kN`0W9bL0
@d=30:6QX@2BTY80<S8b061PH00e=CD0>SXj07UiN@29RHT0;Rh^065QH@1NGUh0>c/k0:>SX`2=SHd0
;bl_05aLG01`L700HF5Q08J6QP1EEED0:2PX03Hf=P1oOgl0Fe]K065QH@2f][H0De=C04a<C01TI6@0
Y:BT05]KF`2NWYh0`l?304a<C00c<c<0IFEU092@T01GEeL0I6AT096AT@0M7Ad0<30`04a<C01XJ6P0
<30`04m?C`1NGUh0820P03/k>`1CDe<0K6a/038b<P0X:2P0EEEE01XJ6P1ADE40SXj>08J6QP0W9bL0
<c<c069RHP0`<300;2`/07QhN02FUYH0;bl_02@T901;Bd/0B4Q804I6AP1dM7@0WinO01TI6@0G5aL0
@D5105UIF@1hN7P0U9BD05]KF`0J6QX07alO04A4A01MGEd003D0>c/k0:2PX01]KFd07alO04Y:BP1F
EUH0?Cdm05iNGP1bLW80V9RH092@T02EUID0R8R807moO`2=SHd0TY:B05]KF`1JFUX0KFe]09RHV02W
YjL0JVYZ06e]K@2`/;00/K6a0<C4a02ATI40DU9B065QH@1NGUh0D51@05YJFP1@D500H61P06i^KP1K
Fe/0H61P05YJFP1<C4`0Fe]K055AD@22PX80IFEU03De=@1jNWX0HF5Q08J6QP1OGel0UIFE09bLW01[
Jf/0@T9204A4A002051@D00[03dm?@1DE5@0=SHf04Q8B01OGel0Cdm?03De=@0i>CT0D51@04=3@`1@
D5009bLW03dm?@1@D500DU9B04Q8B00g=cL0EUIF08V9R@1KFe/0@d=303Lg=`1>CTh0E5AD04Q8B013
@d<0D51@06][J`1IFET0<c<c02XZ:P13@d<0CDe=04U9B@14A4@08b<S03/k>`13@d<0>CTi06QXJ01Q
HF40Fe]K05aLG00204=3@`1703<c<`19BDT0;Rh^02l_;`17AdL0@d=304A4A01JFUX0IVIV0492@P0d
=3@0ADE506][J`1:BTX0=SHf0451@@1CDe<0DE5A03lo?`0a<C40=cLg04E5A@12@T80FEUI04a<C01G
EeL0Cdm?065QH@1>CTh0F5QH04Q8B01;Bd/0KFe]04a<C01[Jf/0;2`/04];B`18B4P0:b/[059BDP10
@400@T920451@@1EEED0?Cdm05EEE@1UIFD0TY:B07QhN02FUYH0Jf][08F5Q@28R8P0=SHf03/k>`1D
E5@0F5QH075aL@18B4P09BDU05ADE01IFET0CTi>05YJFP0k>c/0HF5Q04i>CP10@400EUIF02DU9@12
@T800P1BDU80F01GEeL0A4A404m?C`1;Bd/0A4A40451@@1IFET0HV9R061PH023Ph<0CDe=05eMG@3=
cLd0Ti>C01hN7P15ADD0CDe=07emO@1PH600GemO07=cL`0E5AD0?3`l03De=@18B4P0Jf][0451@@0R
8R80D51@03De=@1?Cdl0=CDe04];B`0b<S80@T9201HF5P0h>3P0EUIF02/[:`0^;Rh0De=C02d];@1@
D500@T92030`<01:BTX0?Shn0:n_[`2LW9`0B4Q805QHF01NGUh0;Rh^03De=@18B4P0>3Ph04Y:BP1T
I6@0N7Qh04];B`1GEeL0Bd];04Y:BP1ADE40?Shn03Ph>01HF5P0C4a<05EEE@0g=cL0Cdm?04e=C@0j
>SX0<c<c04i>CP0c<c<0@d=303<c<`17AdL0FEUI03Hf=P1JFUX0Q8B408J6QP12@T80CTi>0410@00n
?Sh204m?C`0707AdM01=CDd0EEEE05EEE@1:BTX0<C4a06a/K0020492@P0^05iNGP0l?3`0QhN703hn
?P24Q8@0A4A405eMG@1QHF40^;Rh075aL@1=CDd0C4a<02DU9@1RHV80Rh^;0451@@18B4P0:b/[05IF
EP0G5aL0L71`05]KF`1;Bd/0<c<c07AdM02ATI40L71`09ZJVP2ZZZX0QXJ608B4Q01FEUH0E5AD05MG
E`1UIFD0OWin04I6AP1?Cdl0GemO09>CT`1XJ6P0KFe]09ZJVP2WYjL0UiNG0820P080YJFU00H0UYJF
06e]K@1iNGT0K6a/07MgM`31`L42ooooo`0005/0EEEE065QH@2][Jd0Ph>309:BTP13@d<0CDe=08:2
PP1gMgL0QhN707AdM00i>CT0Kfm_08V9R@1:BTX0Fe]K07IfMP0S8b<0D51@092@T01XJ6P0@41005EE
E@0b<S80@41006e]K@1SHf<08B4Q03De=@0l?3`0:b/[05QHF02/[:`0De=C02DU9@1KFe/0MGEe059B
DP2VYZH0QHF502PX:00V9RH0CDe=07EeM@1:BTX0YZJV04i>CP0g=cL07QhN03lo?`1:BTX0SXj>0;>c
/`0j>SX0ADE504I6AP15ADD0AdM709NGU`1mOGd07alO04a<C028R8P0>c/k02/[:`1LG5`0BTY:03Hf
=P1HF5P0H61P038b<P0[:b/0JVYZ03Ti>@0_;bl0B4Q805iNGP0H61P0<c<c05ADE01?Cdl0AdM709ZJ
VP1^KVh0820P03lo?`1:BTX0HF5Q07MgM`2;Rh/0;Bd]00809RHV00@0C4a<07EeM@1;Bd/0V9RH0P0Y
:BT0FP17AdL0KFe]0410@018B4P0Hf=S01<C4`0g=cL0S8b<0820P00o?cl0De=C06QXJ00^;Rh0BTY:
08Z:RP2JVYX0@41005YJFP12@T80:BTY05UIF@1aLG40FUYJ02XZ:P1?Cdl0=cLg05YJFP2;Rh/0^KVi
05]KF`0M7Ad0A4A403lo?`19BDT0GemO0<G5a@0m?Cd08B4Q04I6AP20P800JVYZ08J6QP2HV9P0@T92
04M7A`1ADE40Kfm_04e=C@1WIfL0RHV9020P801;Bd/0WIfM07EeM@1NGUh0Ti>C03hn?P0Y:BT0Hf=S
08:2PP0k>c/0Jf][0451@@0/;2`0JFUY08j>SP0f=SH0>3Ph05eMG@1BDU80EeMG0<K6aP2l_;`0De=C
02LW9`1SHf<0C4a<04Y:BP2o_kl0`L7103Ph>00j>SX0EUIF055AD@1KFe/0_kno04Y:BP0P8200<30`
07MgM`80LG5a07h0MGEe03Hf=P10@400I6AT0:2PX01;Bd/0Cdm?03Hf=P0W9bL0CTi>08F5Q@23Ph<0
?clo04Y:BP0b<S80BDU9061PH02CTi<0EUIF04A4A01FEUH0B4Q805MGE`2DU9@0@T92030`<019BDT0
?3`l06m_K`2[Zj/0Bd];02LW9`1NGUh0G5aL04m?C`2GUiL0<C4a02@T9017AdL0J6QX07alO02MWId0
CDe=03Xj>P1GEeL0KVi^05YJFP21PH40Bd];02HV9P1KFe/0LG5a06a/K02j^[X0RHV902XZ:P1YJFT0
];Bd04E5A@1RHV80JVYZ03@d=00^;Rh0IFEU07QhN013@d<0MWIf05ADE00a<C40:b/[07IfMP1TI6@0
9BDU05]KF`0n?Sh0?clo05=CD`29RHT0Hf=S02TY:@1JFUX0<c<c03`l?02=SHd0`/;203hn?P0[:b/0
A4A405eMG@0o?cl0SHf=0:^[Z`0^;Rh0=cLg05mOG`1jNWX0ADE507AdM02FUYH0>c/k0451@@17AdL0
BTY:05eMG@1GEeL0UIFE01dM7@0m?Cd0D51@04E5A@0^;Rh0Bd];06e]K@0S8b<0:2PX071`L01RHV80
<S8b04e=C@11@D406a/K02HV9P1FEUH0Ph>302`/;00V9RH204M7A`0f06m_K`1nOWh0F5QH04M7A`1a
LG40Bd];06IVIP1bLW80Fe]K08Z:RP24Q8@0ZJVY065QH@1VIVH0Jf][06EUI@2<S8`0HV9R04];B`2?
Shl0FUYJ07QhN024Q8@0FEUI04I6AP1<C4`0IVIV0:BTY01nOWh0KVi^06IVIP1DE5@0XJ6Q04=3@`1=
CDd0F5QH04A4A01fMWH0QXJ607YjNP1hN7P0TY:B08b<S01gMgL0=CDe05EEE@18B4P0@T9203lo?`1j
NWX0Cdm?06YZJP22PX80IVIV0P1EEED02`1QHF40@d=308>3P`0b<S80Ng]k0451@@0j>SX0F5QH04];
B`1gMgL0Bd];0080Cdm?0=h0@T9206IVIP0Z:RX0EeMG04U9B@1NGUh0>3Ph069RHP1:BTX0>c/k04Y:
BP0o?cl0EeMG059BDP0h>3P0>CTi05YJFP1_Kfl0HV9R03Lg=`0c<c<0IFEU065QH@0U9BD0:b/[06QX
J00c<c<07alO03lo?`19BDT0@41003De=@0m?Cd0=SHf02TY:@1BDU80?Cdm04];B`0d=3@0>CTi04Y:
BP1;Bd/08R8R03`l?01PH600<c<c02HV9P1<C4`0Ng]k04E5A@0W9bL0CTi>0410@01HF5P0ADE505IF
EP18B4P0@T9205iNGP0n?Sh0DU9B04M7A`0m?Cd0ADE504=3@`17AdL0Bd];04i>CP0m?Cd0HV9R08b<
S025QHD0Ph>30:j^[P2EUID0]KFe08B4Q00d=3@0HF5Q051@D01?Cdl0K6a/06i^KP1ADE40L71`07Ui
N@1SHf<0JFUY05=CD`1JFUX0@41003/k>`1FEUH0=cLg04U9B@1LG5`0FUYJ071`L01GEeL0FEUI06UY
J@1HF5P0B4Q8051@D016ATH0Hf=S08^;R`0/;2`0JFUY0;2`/02<S8`0CTi>071`L01QHF40De=C05IF
EP1OGel0HF5Q02d];@1CDe<0Cdm?02LW9`0Q8B40=cLg03lo?`1<C4`0>c/k051@D00i>CT0;Bd]03dm
?@1EEED0@d=306a/K01hN7P0>SXj04I6AP1DE5@0?Cdm06YZJP1CDe<0=cLg04];B`0f=SH0BTY:04e=
C@0C4a<0Fe]K06IVIP0X:2P071`L04M7A`0a<C40B4Q802d];@1DE5@0=CDe05MGE`19BDT0X:2P071`
L00f=SH0BDU9059BDP0_;bl0De=C04=3@`1HF5P0IfMW03Lg=`17AdL0I6AT04=3@`1:BTX0C4a<04Q8
B00o?cl0D51@05MGE`0o?cl0FEUI030`<01WIfL0EeMG06e]K@1bLW8071`L04M7A`0];Bd0Ng]k05IF
EP1?Cdl0=3@d04i>CP1ADE40J6QX08V9R@0_;bl0FUYJ04E5A@2TY:@0H61P08b<S017AdL0ATI603Xj
>P10@400Fe]K01@D500];Bd0HF5Q03Ti>@1QHF40:BTY05UIF@0m?Cd0Kfm_05]KF`1>CTh0FUYJ08>3
P`2ATI4203hn?P0J05IFEP0f=SH0D51@034a<@19BDT0A4A402`/;01QHF40BTY:05iNGP1mOGd0MWIf
03hn?P1kNg/0QhN709:BTP2IVIT0I6AT08F5Q@2`/;00a<C408>3P`2:RXX0MGEe061PH01jNWX2oooo
o`000:@0LW9b06i^KP1BDU80GUiN0:f][@1XJ6P0BDU904a<C01OGel0PX:20<;2`P0o?cl0>c/k071`
L02<S8`0NGUi075aL@0m?Cd0<C4a05QHF01^KVh0M7Ad09bLW00W9bL0<c<c05IFEP24Q8@0DE5A07]k
N`0_;bl0ADE50451@@26QXH0];Bd07emO@2c/k<09bLW03dm?@1XJ6P0LW9b02l_;`1GEeL0JVYZ01/K
6`0^;Rh0JVYZ08V9R@11@D40CDe=02l_;`0U9BD0A4A409FEU@1nOWh0>3Ph05QHF00l?3`0ATI608^;
R`2ZZZX0@T92034a<@1QHF40I6AT05YJFP2NWYh0>c/k02LW9`0c<c<0AdM705IFEP2<S8`0clo?02/[
:`0^;Rh0Cdm?04Y:BP0o?cl0UYJF09bLW00d=3@0<C4a065QH@2<S8`0DE5A07YjNP1gMgL09bLW02HV
9P1FEUH0Fe]K02LW9`15ADD0Fe]K02l_;`0o?cl0De=C03lo?`0S8b<0K6a/04A4A00i>CT0QHF508R8
R00g=cL07AdM04A4A01MGEd0GUiN07inOP1]KFd08B4Q02HV9P1GEeL0EUIF05aLG029RHT0@D5101`L
7014A4@0N7Qh08N7Q`16ATH0VYZJ04m?C`0^;Rh0?clo0;^k^`2j^[X0>3Ph07YjNP1BDU808R8R04I6
AP2UYJD0`L7103`l?01VIVH0=cLg01<C4`1CDe<0[jn_0:BTY00];Bd0N7Qh038b<P0o?cl0F5QH0:>S
X`1?Cdl0:BTY05EEE@1;Bd/0JVYZ09^KV`1ZJVX061PH02l_;`1eMGD0JFUY0;>c/`0a<C40:RXZ04I6
AP80UYJF0</0OWin09>CT`0J6QX0>CTi07inOP2BTY80GUiN055AD@2RXZ80@T9203lo?`19BDT0OWin
051@D01IFET0U9BD02TY:@10@400P8200::RXP0k>c/0Fe]K06=SH`0^;Rh0HV9R07IfMP15ADD0:b/[
06m_K`1>CTh0De=C09RHV01oOgl0:b/[03Hf=P1VIVH0IFEU06=SH`2[Zj/0ADE503Hf=P1@D500EEEE
05]KF`2HV9P0Ti>C03dm?@1YJFT0RXZ:0451@@19BDT0U9BD03Ph>00R8R80S8b<08n?S`12@T80GEeM
04];B`0/;2`0GemO06a/K01EEED0Q8B402d];@14A4@0F5QH0861P@0j>SX0C4a<04];B`0d=3@0SHf=
06m_K`0d=3@0ADE503Hf=P0c<c<0OGem09bLW012@T80>c/k04E5A@1[Jf/0W9bL0:j^[P0e=CD0=SHf
05]KF`18B4P0BDU90:j^[P2?Shl0=CDe0410@01?Cdl0N7Qh051@D02WYjL0MGEe02HV9P14A4@0DE5A
06ATI013@d<0[:b/06QXJ00T92@0?Cdm06EUI@1GEeL0A4A405QHF01DE5@0:b/[03Xj>P26QXH0Cdm?
02XZ:P1CDe<0E5AD02LW9`1KFe/0YZJV05aLG00O7al0EeMG034a<@0P8200EUIF0:RXZ01HF5P07AdM
034a<@0n?Sh0ATI605QHF02UYJD0ADE5018B4P12@T80KVi^04e=C@1eMGD0GemO02@T900l?3`0>SXj
03@d=00n?Sh0L71`079bLP0Q8B40XJ6Q08^;R`1OGel0Cdm?0:6QX@1cLg<0PX:208j>SP1PH600Xj>S
0;:b/P2m_Kd0I6AT09^KV`20P800JVYZ0::RXP2SXj<0NGUi08b<S02:RXX0MGEe05QHF01KFe/0J6QX
06ATI01WIfL0Rh^;07AdM01OGel0O7al051@D02e]KD0CDe=05UIF@1mOGd0?Cdm09NGU`1TI6@0TI6A
06][J`2@T900LW9b06ATI00g=cL0Bd];03Ph>00l?3`0>c/k061PH00204A4A00V04e=C@19BDT0DE5A
05=CD`14A4@0?Shn079bLP1GEeL0OGem04I6AP15ADD0N7Qh05=CD`2QXJ40IFEU05eMG@1KFe/0DU9B
07MgM`0a<C40KVi^07=cL`1UIFD0@T9206m_K`1ZJVX0L71`06i^KP1;Bd/0D51@071`L01SHf<0L71`
05YJFP0_;bl0Bd];03dm?@1;Bd/203lo?`80@D5100d0D51@03Xj>P0S8b<0BDU904=3@`1UIFD0E5AD
059BDP0k>c/0BDU906IVIP1<C4`0FUYJ0080CDe=0=80B4Q805EEE@1LG5`0>SXj02TY:@1HF5P0?Cdm
05UIF@0i>CT0CTi>03De=@1>CTh0E5AD07=cL`16ATH0@41006a/K02DU9@0M7Ad02h^;P0Q8B40ADE5
05mOG`0o?cl0>SXj04];B`17AdL0C4a<04i>CP1FEUH0MWIf07]kN`2UYJD0T92@07MgM`1LG5`0M7Ad
03`l?01TI6@0K6a/05MGE`1bLW80NGUi06ATI01mOGd0Hf=S04I6AP0h>3P08B4Q05IFEP1WIfL0=cLg
03lo?`1VIVH0QXJ605EEE@1=CDd0E5AD04m?C`1JFUX0IFEU05]KF`1:BTX0IVIV06i^KP0e=CD0@D51
02LW9`0e=CD0WYjN08N7Q`0/;2`0;Bd]05UIF@1^KVh0JFUY06MWI`1VIVH06ATI03`l?00g=cL0820P
03De=@0Z:RX06ATI04=3@`0[:b/0BTY:03Lg=`0j>SX0ADE504];B`0/;2`0>c/k04m?C`1:BTX0E5AD
07MgM`16ATH0?Cdm0451@@1;Bd/0MgMg05MGE`1TI6@0EeMG020P801=CDd0KVi^02/[:`0R8R80ADE5
0410@01EEED0?Cdm061PH013@d<0N7Qh03Lg=`1@D500=cLg03Xj>P23Ph<0N7Qh03dm?@1=CDd0@d=3
05YJFP1LG5`0D51@05eMG@0b<S80ATI604a<C00`<300?3`l0492@P1;Bd/0EUIF051@D01JFUX0@D51
0:>SX`1cLg<0ATI605YJFP0i>CT0Fe]K03/k>`1NGUh0>3Ph06QXJ01DE5@0EEEE05=CD`17AdL0QHF5
05=CD`1WIfL0De=C0;Fe]@1LG5`0D51@059BDP1FEUH0De=C06MWI`2JVYX09bLW02DU9@1IFET0?Cdm
0820P01BDU80LG5a04=3@`1JFUX0MGEe04];B`1/K6`0IFEU08^;R`1TI6@0BTY:05iNGP10@400E5AD
03@d=01@D500G5aL0451@@1aLG40DU9B06ATI023Ph<0SXj>055AD@1jNWX0WinO0;6a/@2XZ:P0O7al
09ZJVP1nOWh0T92@0:JVYP2<S8`0Lg=c06i^KP29RHT2ooooo`0006d0MgMg0=GEe@1NGUh0Fe]K05aL
G02;Rh/0Ogmo07]kN`14A4@0HF5Q07=cL`1nOWh0IfMW04a<C00];Bd0MWIf061PH00a<C40BTY:06AT
I00[:b/0?clo06=SH`1BDU808B4Q05MGE`0_;bl0EEEE05QHF01?Cdl071`L0492@P1KFe/0HV9R05]K
F`2YZJT0GUiN02d];@18B4P0FEUI05eMG@21PH40NGUi01hN7P0`<300FEUI04i>CP1TI6@0WYjN06MW
I`0R8R80BDU907QhN01eMGD0OWin06a/K00c<c<0?Cdm05=CD`2?Shl0Hf=S07moO`21PH4092@T03Ti
>@1=CDd0Jf][0410@01DE5@0A4A401TI6@0o?cl0TI6A06][J`0a<C40GEeM02`/;00L71`0C4a<08B4
Q00l?3`0@d=305EEE@0/;2`0@d=3092@T01mOGd0820P01hN7P1>CTh0?Cdm04Q8B02NWYh0UiNG01XJ
6P1;Bd/0NGUi05YJFP1DE5@0a/K609:BTP0D51@0>3Ph07AdM01NGUh0KVi^08f=S@12@T80=cLg0080
EUIF0;L0>3Ph05=CD`2i^KT0De=C02/[:`1XJ6P0PX:20492@P1@D500K6a/02/[:`1GEeL0L71`0861
P@0^;Rh0<30`05QHF01SHf<0EEEE08>3P`1GEeL06ATI024Q8@1?Cdl0SHf=07EeM@2JVYX0ATI601`L
700o?cl0TY:B0:n_[`1GEeL0]KFe04=3@`0_;bl0E5AD08j>SP1=CDd0?clo051@D00Z:RX0<S8b08n?
S`2XZ:P0@D51065QH@1GEeL0<S8b07AdM01UIFD0:RXZ06i^KP1GEeL0>3Ph071`L02[Zj/0JFUY01/K
6`0l?3`0Bd];06QXJ028R8P0^KVi055AD@0[:b/0DE5A07IfMP1]KFd0QhN70;fm_@0^;Rh05QHF05AD
E02NWYh0F5QH08f=S@2EUID0;Rh^02HV9P1^KVh0Lg=c04A4A02UYJD0?clo03Lg=`0m?Cd0M7Ad05aL
G01dM7@0MGEe0410@00f=SH0@D5106MWI`1?Cdl0HF5Q05ADE00R8R80ADE504M7A`1>CTh0E5AD09NG
U`11@D40Kfm_0<o?c`1VIVH0<C4a059BDP1ADE40B4Q80::RXP1BDU80;Rh^0451@@1BDU80IVIV09^K
V`1?Cdl09BDU04I6AP2CTi<0R8R809RHV01/K6`0;bl_051@D01OGel0Cdm?08:2PP1<C4`0>3Ph05]K
F`2HV9P0UiNG08j>SP1XJ6P07AdM04];B`2MWId0Hf=S04e=C@2TY:@0C4a<02`/;01FEUH0VYZJ04m?
C`15ADD0J6QX02XZ:P0i>CT0NGUi09>CT`0M7Ad0;2`/04E5A@0i>CT0EUIF08Z:RP2NWYh0;bl_03De
=@1ADE40@d=304U9B@28R8P0FEUI02DU9@0Q8B40Fe]K05YJFP1ZJVX0PH610410@00I6AT0<C4a07Ad
M02;Rh/0IfMW0<;2`P13@d<00P0i>CT0A01PH600OWin04Q8B01bLW8092@T02PX:00];Bd0ADE504];
B`0W9bL0BTY:03hn?P0H61P0@d=3075aL@0n?Sh0820P04E5A@0S8b<07AdM03De=@1/K6`0<S8b069R
HP1aLG40EUIF04M7A`1bLW80H61P06e]K@1KFe/0EEEE08N7Q`1ZJVX0T92@05eMG@2<S8`0HF5Q08N7
Q`2<S8`0OWin08n?S`1hN7P0Hf=S071`L01DE5@0CDe=05aLG01?Cdl0KFe]079bLP1XJ6P0EEEE079b
LP1WIfL0/k>c0451@@1KFe/0OGem04M7A`2NWYh0KFe]09jNWP1[Jf/0UiNG0:FUY@2CTi<0=CDe0P1H
F5P0K`1TI6@0=cLg07IfMP1;Bd/0DU9B06=SH`1?Cdl0IfMW05mOG`1XJ6P0>SXj08B4Q00h>3P0GemO
03`l?00o?cl0P8200861P@1hN7P0C4a<059BDP1OGel0EEEE04Y:BP0W9bL0EUIF055AD@1HF5P0?Cdm
06IVIP1>CTh0@41006=SH`18B4P0BDU905eMG@0o?cl0BDU904];B`0i>CT0NGUi04U9B@1CDe<0EEEE
069RHP1@D500BDU905=CD`0h>3P0>SXj04A4A00i>CT0ATI6030`<00h>3P0:RXZ030`<01RHV80A4A4
05YJFP0i>CT0AdM704A4A01;Bd/0>CTi02TY:@0a<C40D51@04U9B@1FEUH0ATI606YZJP1@D500R8R8
03Xj>P1GEeL0CDe=04];B`1JFUX0@d=3061PH012@T80Cdm?0492@P14A4@0BTY:03dm?@17AdL0EUIF
055AD@15ADD0FEUI0:BTY01EEED0>3Ph06MWI`2PX:00ZZZZ07QhN00^;Rh0CTi>06ATI022PX80U9BD
03Ph>00/;2`0BTY:07moO`24Q8@0ATI6028R8P0204A4A02O02TY:@1<C4`0=3@d0492@P1@D500AdM7
06QXJ028R8P0H61P05IFEP1@D500Bd];06][J`1eMGD0C4a<06QXJ00;2`/07QhN0;fm_@1nOWh06a/K
03lo?`10@400I6AT05ADE015ADD0D51@00`<3019BDT0ADE504A4A01RHV80<c<c02PX:01>CTh09bLW
04Y:BP0O7al0>SXj02d];@1JFUX0BTY:0492@P1QHF40@41003Hf=P1^KVh0<30`04Q8B01CDe<0>SXj
0492@P18B4P0MGEe079bLP1BDU80D51@061PH00m?Cd0>CTi04i>CP0k>c/0=SHf03Xj>P1SHf<0>SXj
02TY:@11@D40MgMg04m?C`0e=CD0<C4a04U9B@0W9bL0?Shn051@D00k>c/0E5AD055AD@19BDT0@D51
02@T9010@400=3@d04A4A01>CTh0=3@d059BDP1PH600Hf=S0410@018B4P0@d=305MGE`1QHF40>CTi
08B4Q01MGEd0FEUI03dm?@14A4@0De=C07]kN`1ADE40EeMG08F5Q@17AdL0Ogmo06][J`2VYZH0ATI6
05iNGP1;Bd/0Fe]K06=SH`1IFET0FUYJ04A4A01=CDd0Hf=S04E5A@1ADE40=3@d07inOP0l?3`0CDe=
06m_K`1/K6`0FEUI06MWI`2>SXh0?Cdm04Y:BP16ATH0?Shn059BDP0o?cl0IVIV065QH@1[Jf/0NGUi
075aL@2=SHd0VYZJ07alO01mOGd0VYZJ0:>SX`2NWYh0Ti>C09bLW02i^KT0WYjN0:FUY@21PH40UIFE
05]KF`1lO7`0]KFe00;ooooo0000?`1GEeL0QXJ609fMW@1?Cdl0GUiN05QHF01kNg/0UYJF03Ph>012
@T80Hf=S06YZJP1kNg/0WIfM02XZ:P1<C4`0EUIF04];B`1gMgL0PH6102`/;00Y:BT0L71`07=cL`1O
Gel0]KFe02`/;00h>3P0JVYZ06=SH`0n?Sh0HF5Q06=SH`0K6a/0A4A4071`L01TI6@0KFe]0:2PX01U
IFD05aLG05ADE01bLW80Bd];065QH@31`L40?clo02DU9@1KFe/0SHf=034a<@1FEUH0?3`l03<c<`14
A4@0Ogmo04Q8B00];Bd0EEEE04I6AP0c<c<0Kfm_08j>SP02034a<@0c04m?C`0_;bl0GUiN0;Fe]@1J
FUX0;Bd]03@d=01BDU80De=C07=cL`2[Zj/0=3@d01/K6`0k>c/0JFUY03Ph>029RHT0fMWI05aLG00Q
8B40AdM706][J`0o?cl0CTi>09VIV@1=CDd03`l?04];B`20P800E5AD059BDP1hN7P0=SHf028R8P1o
Ogl0YjNW06][J`1gMgL0FUYJ02DU9@0a<C40Ti>C05UIF@0L71`0@d=305mOG`0o?cl0Fe]K0;Bd]011
@D407alO0080?3`l05T0DU9B06i^KP2[Zj/0=3@d02DU9@1NGUh0RXZ:0:6QX@1]KFd0RXZ:01dM7@1G
EeL0S8b<0861P@0o?cl0EeMG07MgM`0N7Qh0BDU905mOG`1NGUh0>CTi06YZJP0k>c/08R8R04Q8B02@
T900Jf][01lO7`1XJ6P0?Shn04e=C@22PX80GemO024Q8@0^;Rh0AdM704Q8B00l?3`0/;2`0820P00Q
8B40FEUI05aLG014A4@0/K6a079bLP0J6QX0;2`/07EeM@30`<00IFEU08F5Q@1HF5P0820P0492@P2P
X:00^;Rh06ATI01DE5@0B4Q801lO7`1_Kfl0Q8B4065QH@13@d<0Ogmo03De=@0k>c/0E5AD08f=S@1B
DU80FUYJ05MGE`0o?cl0DU9B08f=S@2EUID0A4A405=CD`0X:2P0BTY:071`L02][Jd0GemO02`/;01:
BTX0>3Ph05MGE`020:2PX02[02/[:`1:BTX0@D5105ADE029RHT0`/;205QHF00[:b/0Lg=c06QXJ01]
KFd0Ogmo03dm?@0/;2`0BDU907emO@1?Cdl0LW9b02PX:01CDe<0L71`07IfMP1@D500EeMG03<c<`0k
>c/0NGUi07]kN`0k>c/0FUYJ04A4A00W9bL0IFEU05eMG@0d=3@0GUiN038b<P19BDT0/;2`096AT@0R
8R80=SHf04E5A@1@D500Cdm?0:n_[`1RHV80;bl_03dm?@1JFUX0C4a<0861P@2QXJ40<c<c02<S8`1K
Fe/0Shn?05MGE`1VIVH0VYZJ02@T9011@D40FEUI0820P00n?Sh0I6AT07=cL`0Z:RX0Cdm?065QH@1O
Gel0:BTY04I6AP1RHV808B4Q05ADE01kNg/0O7al02d];@0d=3@0Bd];02<S8`1KFe/0SHf=06YZJP0T
92@0ATI603`l?00b<S80H61P07MgM`1;Bd/092@T04];B`19BDT0>3Ph065QH@1nOWh0JFUY01XJ6P0[
:b/0>CTi05UIF@0m?Cd0LG5a02XZ:P0H61P0>c/k0410@00f=SH0I6AT08J6QP21PH40Kfm_08b<S01B
DU80Ng]k09>CT`1RHV80VIVI08n?S`2WYjL0QXJ60:BTY022PX80OGem09BDU01QHF40FEUI05mOG`1A
DE40EUIF03lo?`1ADE40Jf][05UIF@1EEED0IfMW09FEU@1^KVh0KFe]03dm?@2;Rh/0GemO06m_K`1`
L700ADE507QhN021PH40NGUi06i^KP2>SXh0/[:b0<C4a016ATH0BDU90410@00o?cl0Bd];06QXJ01;
Bd/0De=C06][J`1=CDd0Jf][069RHP1dM7@0CDe=08f=S@17AdL0PH610080@T9204d0OGem04m?C`2?
Shl0H61P07AdM01BDU80CDe=07=cL`0W9bL0LG5a05mOG`1hN7P0F5QH07UiN@1?Cdl0IFEU06i^KP1J
FUX0FEUI06e]K@1:BTX0Kfm_07=cL`0f=SH0LG5a06e]K@1VIVH0D51@03De=@1@D500FEUI04=3@`15
ADD0?clo061PH00n?Sh0IVIV04];B`0f=SH0Bd];04U9B@1`L700AdM7061PH014A4@0Bd];03hn?P1?
Cdl0CDe=04=3@`0j>SX0IVIV04A4A01/K6`0A4A405]KF`15ADD0JFUY03hn?P1PH600GUiN06a/K01Y
JFT0Kfm_06e]K@0h>3P0De=C05ADE01MGEd0CTi>0492@P1DE5@0>c/k05IFEP14A4@0AdM705QHF002
079bLP1V07UiN@1LG5`0BDU905ADE00j>SX0@41004i>CP13@d<0EUIF06UYJ@1>CTh0E5AD05=CD`14
A4@0DU9B038b<P1YJFT0Bd];03lo?`1VIVH0?Shn05]KF`1SHf<0HV9R07UiN@0o?cl0@T9203lo?`1j
NWX0Fe]K05=CD`1TI6@0P8200:2PX00Q8B4071`L0=gMg@1lO7`04a<C07=cL`1NGUh0P820069RHP1G
EeL0I6AT028R8P25QHD0BTY:02@T900g=cL08B4Q059BDP1TI6@0>3Ph04U9B@0j>SX0AdM703<c<`1U
IFD0=cLg04Q8B01_Kfl0<c<c04M7A`1cLg<0BDU9069RHP1;Bd/0:b/[0492@P0/;2`0F5QH05YJFP0K
6a/0D51@07UiN@0_;bl08B4Q0451@@0^;Rh0BTY:059BDP2BTY80=CDe04A4A00i>CT0Ng]k071`L00Y
:BT0?Cdm05QHF00[:b/0EeMG051@D00];Bd0CDe=0492@P1NGUh0EUIF03Xj>P1:BTX0ATI60P17AdL0
B@0`<300ADE503lo?`1?Cdl0>SXj05EEE@0f=SH0D51@05UIF@0_;bl0=cLg03Ph>01OGel0:b/[05eM
G@1GEeL0JVYZ05QHF010@400MWIf03<c<`1gMgL0ADE50=?Cd`28R8P0TY:B06i^KP1nOWh0TI6A04=3
@`1aLG40@D5103lo?`1^KVh0=CDe05aLG00e=CD0J6QX03/k>`0o?cl0GUiN06EUI@1XJ6P0HF5Q09JF
UP1OGel0Ng]k05mOG`1KFe/0JVYZ03lo?`1JFUX0FEUI0410@01ZJVX0Shn?08F5Q@1kNg/0Lg=c06QX
J02MWId0W9bL0:f][@2g]kL0J6QX07=cL`2VYZH0iNGU05EEE@1ADE40Ph>307AdM01]KFd00_ooool0
003o05mOG`1XJ6P0/[:b09:BTP2HV9P0@T92061PH028R8P0Xj>S08V9R@1gMgL0@D51059BDP21PH40
E5AD07EeM@1:BTX0<30`04A4A01kNg/0I6AT03dm?@1dM7@0:2PX03dm?@1JFUX0Hf=S020P8019BDT0
<C4a03<c<`19BDT0Ng]k05MGE`10@400GemO02l_;`10@400QHF506UYJ@0V9RH0=CDe03Hf=P0`<300
N7Qh0<?3``1:BTX0:b/[04M7A`1:BTX0A4A409ZJVP2EUID0:RXZ02`/;01CDe<0M7Ad05aLG02a/K40
C4a<02HV9P0/;2`0LW9b07EeM@1iNGT0[:b/02TY:@0P8200=cLg05ADE00X:2P0Ogmo092@T00X:2P0
=CDe05eMG@1VIVH0<C4a06YZJP1TI6@08B4Q02h^;P1LG5`0Jf][02@T901dM7@0E5AD0410@013@d<0
QhN707MgM`0O7al0BTY:065QH@0_;bl0D51@07MgM`0n?Sh0<S8b0492@P1?Cdl0D51@0:NWY`2][Jd0
:2PX03`l?01]KFd0QXJ6061PH02JVYX0N7Qh01/K6`15ADD0GEeM07YjNP1IFET0[Jf]03Hf=P0_;bl0
A4A406=SH`1MGEd0=CDe07AdM013@d<0@410071`L02;Rh/0LW9b02PX:018B4P0FUYJ055AD@1VIVH0
VIVI05IFEP0Z:RX0EEEE05eMG@1FEUH0UIFE07moO`0`<3006ATI069RHP1VIVH0EeMG0;bl_01HF5P0
9BDU059BDP1kNg/0@41008:2PP2OWil0G5aL01TI6@1PH600^[Zj055AD@26QXH0>c/k02l_;`1?Cdl0
M7Ad04U9B@12@T80GEeM02d];@1[Jf/0GUiN05=CD`0R8R80;Rh^06a/K012@T80D51@0;Zj^P2OWil0
;Bd]03Ti>@1kNg/0De=C06MWI`3Cdm<0F5QH01dM7@0k>c/0LW9b04U9B@2WYjL0YZJV034a<@0];Bd0
Ng]k0:n_[`18B4P0O7al034a<@0W9bL0@41008>3P`1lO7`0B4Q805UIF@0L71`0B4Q804U9B@1jNWX0
@D5106EUI@17AdL09bLW05mOG`1YJFT0Ph>3059BDP1`L7008b<S051@D02VYZH0MGEe02LW9`1?Cdl0
;bl_03lo?`2VYZH0HV9R02DU9@0n?Sh0Fe]K075aL@2=SHd0CTi>02HV9P1CDe<0Jf][05QHF02CTi<0
BDU903Xj>P1?Cdl0De=C05UIF@3@d=00HF5Q020P800m?Cd0Jf][03Xj>P1eMGD0SXj>02<S8`1?Cdl0
DE5A001A05YJFP17AdL0J6QX0861P@0b<S80?clo075aL@1/K6`0=cLg07EeM@14A4@0;Rh^04e=C@1Z
JVX0ATI602@T9013@d<08R8R04E5A@1ADE40RHV90492@P0M7Ad0EUIF05aLG01RHV80JVYZ06ATI00U
9BD0;Bd]05YJFP1IFET0Cdm?09>CT`29RHT0:RXZ024Q8@1ADE40I6AT04M7A`1mOGd0Kfm_020P800[
:b/0JFUY08j>SP18B4P0Rh^;065QH@0W9bL07QhN05MGE`2][Jd0OWin03lo?`1XJ6P08B4Q0410@01;
Bd/0DU9B01hN7P0k>c/0<C4a02/[:`23Ph<0UIFE059BDP15ADD0Q8B406MWI`1nOWh0Kfm_04m?C`1n
OWh0WIfM0:VYZ@1ZJVX0Kfm_05ADE01HF5P0LG5a0080JVYZ0300V9RH05=CD`1bLW80N7Qh051@D01L
G5`0@D5104e=C@1CDe<0EeMG06ATI01SHf<0B4Q805=CD`0k>c/0@D51061PH00l?3`0FUYJ0492@P1[
Jf/0KFe]08Z:RP2>SXh0NGUi04i>CP1BDU80?Shn04A4A013@d<0EEEE04I6AP0m?Cd0Bd];04Y:BP1B
DU80@41003hn?P0f=SH0E5AD05aLG01[Jf/0@d=304I6AP1_Kfl0Lg=c08b<S01OGel205]KF`0906][
J`1UIFD0;bl_06ATI01gMgL0EeMG03hn?P1QHF40JVYZ0080NGUi0P1:BTX0k@1kNg/0JFUY07=cL`1a
LG40DE5A08Z:RP17AdL0IFEU06][J`1<C4`0@d=304U9B@15ADD0Bd];038b<P16ATH0@D5104U9B@1?
Cdl0AdM704=3@`15ADD0FEUI04Y:BP1=CDd0H61P05YJFP0o?cl0BDU905ADE01?Cdl0F5QH06EUI@1<
C4`0M7Ad055AD@1SHf<0Bd];08n?S`13@d<0DU9B05EEE@1<C4`0Kfm_06MWI`2QXJ40@T9205]KF`1`
L700DE5A06YZJP1:BTX0KFe]04I6AP1EEED0=cLg06i^KP1`L700MWIf06MWI`2ZZZX0Ph>307=cL`1b
LW80A4A406ATI01WIfL0?Cdm06QXJ01/K6`0Jf][07MgM`1^KVh0C4a<06i^KP19BDT0FUYJ04Q8B00W
9bL0EUIF04M7A`12@T80KVi^04i>CP1PH600FUYJ06MWI`1>CTh0GemO04M7A`1kNg/0E5AD02DU9@0h
>3P09BDU02`/;03?cll0PX:2030`<01^KVh0D51@09BDU01RHV80ATI603dm?@0>3Ph0?3`l038b<P0U
9BD0A4A402HV9P0O7al0>c/k02LW9`0i>CT0BDU907AdM013@d<0ADE503@d=00i>CT0De=C03Lg=`1G
EeL0LG5a03Xj>P1>CTh0@41003`l?01CDe<0AdM709NGU`2EUID0:2PX06IVIP2@T900<S8b055AD@1b
LW80>CTi04Q8B00i>CT0JVYZ030`<01DE5@0Cdm?09NGU`1bLW80EEEE08R8R01dM7@0=SHf03Xj>P15
ADD0Fe]K07=cL`1OGel0F5QH0492@P0g=cL0Fe]K04M7A`0m?Cd0@d=304Y:BP1YJFT0ADE504m?C`0Q
8B40I6AT069RHP1JFUX0Q8B402`/;01=CDd0@T9206IVIP1MGEd0H61P05MGE`1iNGT0JFUY04i>CP1E
EED0<S8b07inOP1BDU80i^KV06m_K`21PH40H61P04m?C`1OGel0?3`l09RHV01KFe/0@T9206a/K01I
FET0T92@06MWI`2h^;P0JVYZ05IFEP1RHV80QhN707EeM@29RHT0PH6104E5A@1;Bd/0HF5Q0451@@1G
EeL0Hf=S07=cL`1GEeL0A4A405mOG`1EEED0K6a/06i^KP1UIFD0Ogmo0<G5a@2_[jl0YZJV0;6a/@2=
SHd0TY:B07UiN@1hN7P0JFUY06a/K02a/K40PH610:2PX002ooooo`000:<0NWYj0:JVYP1MGEd0JFUY
0:FUY@1HF5P0H61P06UYJ@1EEED0H61P08J6QP16ATH0De=C04M7A`14A4@0MgMg075aL@0W9bL0:RXZ
04=3@`1GEeL0Shn?08f=S@13@d<09bLW03`l?01]KFd0GEeM08F5Q@11@D40:BTY03Xj>P1ADE40EeMG
07=cL`3Fe]H0:BTY02PX:01BDU80R8R804M7A`1fMWH0Q8B401hN7P0f=SH0P82008>3P`1;Bd/0WYjN
02h^;P0`<300C4a<0:JVYP1hN7P0KFe]07YjNP0e=CD09RHV04m?C`2OWil0FEUI04=3@`1CDe<08B4Q
05eMG@2RXZ80GEeM02l_;`1EEED0>c/k01lO7`24Q8@0a/K603/k>`0X:2P0>SXj030`<011@D40VIVI
06i^KP0e=CD0>3Ph04e=C@13@d<0EeMG0;Fe]@2DU9@051@D034a<@1BDU80KFe]05ADE02XZ:P0VIVI
02/[:`0m?Cd0B4Q8051@D00h>3P0Lg=c038b<P0Q8B40BDU909ZJVP1cLg<0@D5106QXJ00g=cL08R8R
05EEE@2ATI40D51@02d];@1gMgL0?3`l02`/;01cLg<0Hf=S02@T900b<S80>3Ph05]KF`1MGEd0VYZJ
05iNGP0U9BD0:RXZ06][J`1aLG40IVIV0:f][@1`L700;Bd]03Ph>01aLG40IfMW0451@@1RHV80<c<c
02/[:`1ZJVX0UIFE06i^KP1ADE40K6a/04a<C00S8b<0N7Qh0;:b/P1MGEd0BTY:05mOG`0Z:RX0=SHf
0861P@1kNg/0?Cdm05=CD`1;Bd/0LW9b09FEU@0d=3@0;bl_0080ADE50:<0@41009jNWP2c/k<0:BTY
03Lg=`2KVi/0L71`03dm?@1nOWh0VIVI0410@01@D500Fe]K07IfMP1JFUX0QXJ60:>SX`0Z:RX0A4A4
0:b/[038b<P0?Shn06QXJ017AdL0?3`l06=SH`1aLG40AdM702XZ:P1KFe/0@d=304U9B@1CDe<0N7Qh
03lo?`1CDe<0IfMW03/k>`1KFe/0/K6a055AD@0U9BD0@d=3065QH@12@T80Shn?05EEE@0G5aL0<S8b
07emO@1QHF40F5QH08b<S00S8b<0<c<c071`L02=SHd0EUIF08Z:RP0k>c/092@T071`L02:RXX0Hf=S
05eMG@0K6a/0GemO069RHP2VYZH0D51@09JFUP0j>SX0BDU907emO@1kNg/09RHV04I6AP0f=SH0=3@d
07inOP2g]kL0D51@04e=C@0n?Sh0;Bd]06QXJ02CTi<0@D51038b<P1]KFd0B4Q804];B`20P800^KVi
034a<@0h>3P0CTi>04e=C@1QHF40YZJV09NGU`0S8b<0Fe]K05eMG@1LG5`0KFe]0:2PX016ATH0:2PX
055AD@1KFe/0FUYJ061PH02ATI40FEUI02@T901:BTX0Cdm?04U9B@0n?Sh0IFEU055AD@0V9RH0>c/k
08J6QP1^KVh0RXZ:092@T01BDU80820P05mOG`2:RXX0EEEE03dm?@14A4@0<S8b01dM7@1NGUh0UiNG
03Ti>@0U9BD0=3@d03hn?P1:BTX0FEUI08N7Q`0[:b/09bLW04e=C@0f=SH0?3`l09BDU01nOWh08b<S
05YJFP1QHF40I6AT059BDP1VIVH0ADE505aLG01PH600C4a<0080DE5A0:D0Ogmo06EUI@26QXH0Ogmo
06UYJ@2GUiL0PH6108J6QP25QHD0LW9b07]kN`1SHf<0HV9R06i^KP1MGEd0OWin092@T01aLG40B4Q8
06m_K`1TI6@0WIfM06QXJ01FEUH0T92@055AD@2KVi/0FUYJ092@T02JVYX0Y:BT09BDU01jNWX0HV9R
05]KF`1GEeL0KVi^04=3@`1aLG40BDU904M7A`22PX80Bd];06EUI@1OGel0LW9b03lo?`1eMGD0>CTi
055AD@0f=SH0=CDe05mOG`0g=cL0C4a<03hn?P1KFe/0?Cdm03@d=011@D40;Bd]05MGE`17AdL0D51@
03dm?@1QHF40=SHf038b<P1UIFD0DE5A04Q8B01WIfL0?3`l04];B`16ATH0<c<c05aLG01OGel0IFEU
069RHP0j>SX0De=C03/k>`0g=cL0>SXj03/k>`0b<S80<30`03<c<`10@400C4a<03/k>`0Z:RX0De=C
04A4A019BDT06a/K038b<P0k>c/0@d=302h^;P0k>c/0BTY:05=CD`1IFET0EeMG04E5A@1PH600IVIV
07MgM`1MGEd0FUYJ05=CD`1?Cdl0OWin07MgM`2CTi<0HF5Q055AD@1[Jf/0BTY:05IFEP15ADD0L71`
051@D01EEED0<C4a06][J`2^[Zh0XJ6Q061PH02g]kL0W9bL08B4Q01mOGd0:b/[055AD@1XJ6P0:BTY
04Y:BP1JFUX0BDU906EUI@1gMgL0Cdm?075aL@0m?Cd0DU9B051@D00e=CD0NWYj02h^;P10@400NGUi
059BDP1lO7`0BTY:07EeM@1XJ6P0KVi^04A4A00o?cl0E5AD04Q8B01;Bd/00P0Q8B401P32`/80[:b/
028R8P0l?3`0<c<c0410@080De=C08D0CTi>01DE5@19BDT0>CTi03`l?01CDe<0<c<c02LW9`15ADD0
;2`/04A4A00f=SH0;Bd]030`<00l?3`0?clo07UiN@2VYZH0A4A403hn?P1ADE40D51@06QXJ01CDe<0
92@T02XZ:P0^;Rh0@41004i>CP0T92@0=cLg06EUI@0M7Ad071`L03/k>`0X:2P0=cLg055AD@20P800
:BTY02d];@0f=SH0Q8B406=SH`0R8R80?3`l04E5A@0b<S80BDU90492@P0X:2P0=cLg03`l?019BDT0
=SHf02HV9P0b<S807AdM030`<01:BTX0;2`/04A4A019BDT0CDe=04I6AP1LG5`0J6QX05ADE01LG5`0
:b/[07=cL`1GEeL0LW9b05EEE@1MGEd0?clo04U9B@0c<c<0D51@06EUI@0P8200EUIF03hn?P2MWId0
J6QX07UiN@1?Cdl0Ogmo096AT@1XJ6P0TY:B05EEE@1^KVh0SHf=04=3@`1>CTh0CDe=05YJFP10@400
?clo05IFEP2d];@0GemO061PH01`L700LW9b09:BTP1dM7@0GEeM06][J`0h>3P0AdM704Q8B01SHf<0
IFEU05iNGP1QHF40PX:208f=S@1mOGd0Lg=c08n?S`29RHT0Zj^[09fMW@2][Jd0Ph>309>CT`27QhL0
QXJ606i^KP1fMWH0PH6100;ooooo0000g`1RHV80dM7A08:2PP17AdL0PH6106m_K`2UYJD0TI6A04I6
AP1YJFT0NWYj05aLG038b<P0N7Qh02h^;P1nOWh0Q8B403lo?`1MGEd0HF5Q02DU9@0m?Cd0Ogmo071`
L01=CDd0Fe]K01/K6`0a<C40;bl_05UIF@0W9bL0LW9b051@D00V9RH0@T9203hn?P0b<S80=3@d04I6
AP0e=CD0;Bd]03De=@1EEED0=CDe05QHF01CDe<0?clo03Xj>P1XJ6P0D51@02LW9`0d=3@0FUYJ0492
@P1KFe/0Vi^K030`<00Z:RX0>c/k05=CD`1[Jf/0JVYZ08B4Q00E5AD0:2PX07IfMP1IFET0OGem09nO
W`0n?Sh0:BTY03dm?@2;Rh/0L71`07=cL`2ATI409BDU01PH6017AdL0JVYZ038b<P1>CTh0RHV901dM
7@0L71`0B4Q807EeM@13@d<0=cLg06ATI00/;2`09RHV06ATI01fMWH071`L03Hf=P17AdL0DU9B05]K
F`1kNg/0A4A401hN7P0X:2P0Fe]K07YjNP1WIfL0YZJV03De=@0P8200ATI607YjNP27QhL0GEeM0:b/
[00f=SH07alO05iNGP1hN7P0@T9205IFEP1LG5`071`L03<c<`1[Jf/0QHF505ADE00o?cl0IfMW01lO
7`10@400IVIV079bLP19BDT0Hf=S07UiN@0Q8B40B4Q80:j^[P1/K6`08B4Q030`<01HF5P0=CDe08b<
S02`/;00@41001/K6`0o?cl0NGUi05IFEP1hN7P0NGUi02LW9`0X:2P0GUiN07]kN`1>CTh0ZJVY07in
OP0o?cl0U9BD0820P00n?Sh0JVYZ07EeM@0W9bL0?clo0;Rh^02;Rh/0@D5106m_K`11@D408B4Q05=C
D`2b/[80GUiN02PX:01RHV80AdM704];B`1KFe/0UiNG04M7A`0O7al0D51@06ATI02CTi<0Xj>S06e]
K@0R8R80?Shn06=SH`1EEED0R8R80;6a/@1?Cdl0E5AD05MGE`1kNg/0E5AD07alO02>SXh0:RXZ04];
B`24Q8@0Kfm_034a<@1?Cdl0ADE504e=C@19BDT0GEeM03Xj>P1<C4`0GEeM04=3@`19BDT0MWIf06e]
K@0h>3P0IFEU0492@P19BDT00P1UIFD0:P0^;Rh0B4Q8034a<@19BDT0XZ:R03lo?`0Z:RX0EeMG04E5
A@1;Bd/0[Jf]06MWI`0O7al0MWIf08Z:RP1FEUH0GemO02HV9P0`<300AdM708V9R@1/K6`0KFe]04m?
C`0X:2P0?Cdm05iNGP1eMGD0Cdm?09jNWP0R8R80?Cdm04a<C01YJFT0<c<c05EEE@1QHF408B4Q04I6
AP1XJ6P0UiNG04I6AP80EeMG0;D0;Rh^05eMG@1EEED0Fe]K02@T9017AdL0F5QH02<S8`10@400I6AT
07inOP0g=cL0C4a<04];B`0[:b/0KVi^0:JVYP1LG5`06QXJ03Hf=P1=CDd0BDU909:BTP39bLT0I6AT
02l_;`0a<C40Cdm?05]KF`1hN7P0T92@03lo?`0a<C40<S8b06QXJ01DE5@0KVi^07EeM@1IFET06a/K
04Y:BP1IFET0C4a<04=3@`1SHf<0?Cdm01`L701IFET0UYJF05aLG01MGEd0KVi^08R8R029RHT0J6QX
051@D01ZJVX0YjNW07AdM01YJFT0JVYZ0:>SX`2[Zj/0^k^k0:j^[P1kNg/0Ph>305aLG01DE5@0Lg=c
04E5A@1VIVH0BTY:04=3@`1LG5`0CDe=04i>CP19BDT0Hf=S04a<C01KFe/0>CTi05mOG`1ADE40De=C
06QXJ00h>3P0FEUI07EeM@1TI6@0E5AD05eMG@2@T900ZJVY04e=C@1>CTh0BTY:04A4A00m?Cd0Cdm?
0451@@18B4P0Kfm_06ATI01EEED0FEUI0820P021PH40TI6A04Q8B023Ph<0ADE503dm?@1iNGT0@d=3
08N7Q`17AdL0M7Ad04a<C010@400KFe]03lo?`24Q8@0DU9B061PH01iNGT0LG5a04=3@`1LG5`0HV9R
07AdM01nOWh0NWYj04];B`1gMgL0OWin03De=@1_Kfl0AdM703dm?@1>CTh0<c<c02`/;01ADE40>SXj
04];B`0e=CD0C4a<03Xj>P1<C4`0DU9B051@D01>CTh0>SXj075aL@1FEUH0IFEU04I6AP1:BTX0EEEE
05YJFP1=CDd0Cdm?03lo?`1SHf<0=cLg05iNGP17AdL0DU9B02l_;`1DE5@0ATI6051@D01SHf<0Ng]k
07IfMP1NGUh0MWIf05MGE`21PH40QHF50080FUYJ03X0Bd];06YZJP17AdL0FUYJ03lo?`1QHF40LW9b
08B4Q01ADE40SHf=07moO`2IVIT0Ng]k02h^;P1FEUH0IVIV030`<018B4P0?Shn055AD@1[Jf/0T92@
05mOG`1cLg<0E5AD04E5A@0b<S80;bl_05UIF@0_;bl0;Bd]06IVIP1CDe<0MWIf03lo?`1_Kfl0B4Q8
04m?C`0n?Sh0DE5A07AdM01=CDd0De=C02h^;P0;2`/0EUIF08J6QP0P8200Bd];05ADE01NGUh0DE5A
065QH@1bLW806QXJ0492@P0l?3`0;2`/0P12@T80J`0O7al0?Cdm02h^;P1@D500<c<c038b<P15ADD0
<S8b03Hf=P0V9RH0ADE503dm?@1>CTh0EeMG02/[:`0X:2P0>CTi02@T900c<c<0;bl_05eMG@1XJ6P0
<30`05=CD`2RXZ80:2PX01`L700n?Sh08b<S03dm?@0`<300EUIF02<S8`0f=SH0D51@0:>SX`1jNWX0
:RXZ04Q8B01:BTX0:BTY06][J`19BDT0:2PX04I6AP0d=3@0@D51038b<P0k>c/0A4A402l_;`0j>SX0
=CDe02@T9017AdL0E5AD08:2PP0U9BD0@T9203Xj>P1HF5P0OGem034a<@0d=3@0<S8b03lo?`17AdL0
IfMW05mOG`1LG5`0ADE504Y:BP1OGel092@T07YjNP1=CDd0fm_K07IfMP26QXH0G5aL07IfMP2RXZ80
G5aL06a/K011@D40?Shn04a<C00/;2`0FUYJ04Q8B01`L700DU9B051@D01cLg<0V9RH07emO@21PH40
P82004I6AP0f=SH0B4Q802l_;`1EEED0=cLg05]KF`18B4P0=cLg0080C4a<0140Hf=S07UiN@1>CTh0
IfMW096AT@2RXZ80WIfM0:VYZ@1nOWh0NWYj05UIF@2ATI40JVYZ06EUI@1nOWh0FEUI06a/K002oooo
o`0008P0DU9B096AT@2j^[X0Rh^;07AdM01<C4`0Hf=S09:BTP1ADE40M7Ad04U9B@0h>3P0DE5A06=S
H`0e=CD0ADE504I6AP19BDT0De=C07emO@0V9RH08b<S04Y:BP0d=3@0NGUi09FEU@0W9bL07QhN02@T
9014A4@0ATI608B4Q01aLG407AdM03`l?01DE5@0;Rh^06][J`2h^;P0LG5a01DE5@10@400De=C034a
<@2IVIT0[:b/02@T900d=3@0H61P069RHP1_Kfl0T92@03hn?P17AdL0=cLg05YJFP1PH600;bl_08B4
Q00T92@0:BTY07AdM01eMGD0ADE504m?C`1[Jf/05ADE04M7A`2;Rh/0?Shn01/K6`0e=CD0ADE502<S
8`1IFET0X:2P02d];@0G5aL0>3Ph061PH012@T80U9BD0::RXP0S8b<07AdM020P801@D500S8b<08F5
Q@2l_;`071`L02/[:`1YJFT0EEEE03`l?02:RXX0MWIf01LG5`0_;bl0KFe]08Z:RP0c<c<0EeMG065Q
H@0X:2P0IFEU092@T01bLW80:BTY06ATI00m?Cd09BDU05QHF02ATI40ADE502LW9`15ADD0>CTi06UY
J@26QXH0LG5a01lO7`0P8200D51@07]kN`1aLG40Xj>S06UYJ@0U9BD0:BTY055AD@2BTY80GEeM08^;
R`2`/;00?Shn0P0j>SX0:02=SHd0De=C05mOG`1CDe<0;Bd]04e=C@1ADE40KVi^04U9B@1jNWX0=CDe
02LW9`0o?cl0MGEe03De=@10@400C4a<03<c<`0Y:BT0GEeM0820P00U9BD0BTY:04I6AP1oOgl0J6QX
05iNGP0X:2P0:BTY07moO`1`L700UiNG0:NWY`1@D500>CTi04U9B@21PH40TI6A06i^KP2IVIT203Ti
>@1n05MGE`1gMgL0QHF5051@D02QXJ408b<S03`l?01SHf<0GEeM03dm?@1IFET0KVi^03Ti>@0n?Sh0
GEeM07YjNP0T92@0G5aL03<c<`0g=cL0HV9R0:n_[`1dM7@06a/K055AD@17AdL0Bd];0:6QX@2?Shl0
92@T05=CD`1=CDd0BTY:06MWI`2@T900=SHf030`<01XJ6P0Kfm_06a/K02VYZH0@41003Ti>@1KFe/0
Hf=S06YZJP2DU9@0<C4a03Ti>@1KFe/0CTi>071`L01mOGd0=CDe03hn?P1lO7`0Jf][04E5A@1lO7`0
=cLg06YZJP1^KVh0EeMG02@T901;Bd/0Hf=S07MgM`2=SHd0KFe]020P800o?cl0Cdm?030`<017AdL0
WIfM04Q8B00W9bL0F5QH04];B`12@T80SXj>0:BTY00X:2P0<S8b04m?C`1NGUh0ATI609RHV02GUiL0
6a/K03@d=01VIVH0MWIf03/k>`27QhL0[Jf]02DU9@10@400EeMG05IFEP14A4@0De=C05YJFP0K6a/0
71`L06a/K02YZJT0>CTi07IfMP1QHF4092@T03hn?P1VIVH0PH6102LW9`1EEED0=3@d028R8P0h>3P0
KFe]06UYJ@0`<300>c/k02<S8`0f=SH0?Shn0P1jNWX06@0[:b/0<S8b02XZ:P0d=3@0IfMW092@T015
ADD05aLG02`/;01HF5P0A4A408n?S`2IVIT0DU9B055AD@1jNWX0GUiN06][J`1SHf<0>CTi04m?C`1h
N7P0L71`06m_K`29RHT00P2GUiL09P2;Rh/0Ng]k05YJFP2EUID0FEUI08F5Q@1^KVh0EEEE07YjNP1H
F5P0K6a/05YJFP1WIfL0NGUi0820P019BDT0Hf=S05QHF011@D40GUiN0451@@1^KVh0CTi>0861P@1d
M7@0R8R808>3P`1^KVh0CTi>05aLG012@T80@41003`l?01WIfL0IFEU06MWI`2;Rh/0HV9R0P1NGUh0
o`1UIFD0=SHf05]KF`12@T80Jf][05EEE@1DE5@0IFEU04Y:BP1UIFD0AdM706EUI@0o?cl0>3Ph051@
D00l?3`0FUYJ04a<C01IFET0?Shn06IVIP1EEED0U9BD07]kN`12@T80@D5106YZJP1@D500HF5Q0820
P012@T80U9BD04M7A`1IFET0J6QX0410@00n?Sh0AdM704e=C@1CDe<0:BTY03hn?P1=CDd0ADE505AD
E01EEED0A4A403dm?@1;Bd/0>3Ph055AD@1?Cdl0@d=30451@@15ADD0DE5A04];B`1OGel0De=C03hn
?P1WIfL0GEeM07=cL`15ADD0PH6106QXJ01QHF40ADE503Lg=`1DE5@0O7al05aLG011@D40Cdm?069R
HP1?Cdl0?clo0451@@17AdL0@d=304A4A01IFET0GUiN08b<S02DU9@0V9RH09jNWP28R8P0Bd];07If
MP1;Bd/0EEEE065QH@1?Cdl0NGUi07IfMP1mOGd0P82006][J`1@D500Fe]K05=CD`1>CTh0A4A403Xj
>P1FEUH0BDU903`l?01QHF40N7Qh05eMG@1=CDd0GUiN06MWI`1NGUh0@D5104a<C01PH600E5AD06QX
J01GEeL0<S8b071`L02<S8`092@T08>3P`1LG5`0DU9B04I6AP1CDe<0Jf][030`<01;Bd/0G5aL03`l
?01<C4`0?Shn038b<P1CDe<0>CTi03hn?P0k>c/0:BTY03@d=00n?Sh0@T9203hn?P1QHF40<C4a04M7
A`1WIfL0@D5103dm?@0i>CT0>3Ph05=CD`0d=3@0HF5Q07=cL`0a<C40=SHf05]KF`0X:2P09BDU04=3
@`0X:2P0>SXj038b<P1GEeL06a/K03hn?P14A4@0EUIF03Ti>@0K6a/0BDU904e=C@0G5aL0;bl_03Lg
=`19BDT0Fe]K034a<@0e=CD0<C4a0410@015ADD0>3Ph03Hf=P0e=CD0BTY:069RHP0i>CT0Bd];02d]
;@1BDU80>3Ph04I6AP1gMgL0=CDe05ADE00a<C40>c/k02/[:`13@d<0>CTi05MGE`1<C4`0K6a/0820
P01<C4`0MWIf05]KF`2YZJT0G5aL05ADE00c<c<0@T9206MWI`14A4@0Ti>C04a<C014A4@0EUIF04Q8
B01lO7`0CDe=07MgM`1JFUX0/K6a08Z:RP1SHf<0AdM707QhN027QhL0De=C05]KF`1QHF40ATI604a<
C00d=3@0B4Q804M7A`0o?cl0G5aL04i>CP1mOGd0O7al06MWI`1`L700WinO09VIV@2CTi<0YZJV0:6Q
X@00203;bl/0GUiN06MWI`1QHF40GUiN06IVIP1bLW80SHf=0_ooool0003o04m?C`1WIfL0SHf=0;:b
/P2CTi<0AdM704e=C@1]KFd0KVi^0<c<c01[Jf/0>CTi04m?C`1BDU80CDe=09NGU`1XJ6P0:b/[034a
<@1^KVh0H61P04I6AP1YJFT0;Bd]04U9B@1[Jf/0MWIf04e=C@1?Cdl05ADE03Xj>P1NGUh0EUIF02/[
:`1UIFD0Jf][01dM7@0d=3@0KFe]07emO@1;Bd/0GemO03`l?00M7Ad0BTY:09NGU`1>CTh0=cLg05EE
E@0g=cL0JFUY079bLP16ATH09RHV03`l?01GEeL0Hf=S08J6QP2OWil08R8R01LG5`1LG5`0MgMg05AD
E023Ph<0Ti>C028R8P0P8200Hf=S06i^KP15ADD0/k>c0:>SX`0O7al0@d=305UIF@1KFe/0AdM70:VY
Z@1CDe<0<C4a03`l?01]KFd0CDe=04Q8B01FEUH08R8R02/[:`11@D40LW9b03hn?P0I6AT0H61P02LW
9`0R8R80QXJ60820P00O7al05ADE03`l?013@d<0Fe]K0:JVYP1FEUH08R8R03Ti>@1MGEd0JFUY05QH
F02TY:@0ATI601lO7`1?Cdl0[Jf]0:2PX00n?Sh0MgMg02d];@0_;bl0Jf][09ZJVP1=CDd0DU9B051@
D00Y:BT0=CDe07]kN`2@T900IfMW04A4A01_Kfl0>SXj03lo?`1MGEd0X:2P05MGE`0_;bl0CTi>03<c
<`17AdL0S8b<092@T00m?Cd0AdM705YJFP1IFET0GemO0;^k^`2/[:`0;Rh^04a<C01GEeL0;Rh^06a/
K02ATI40:RXZ02l_;`11@D40KVi^0410@01iNGT05aLG038b<P1GEeL0M7Ad0492@P15ADD0FEUI03<c
<`17AdL0IVIV05UIF@0c<c<0EUIF08>3P`0];Bd0IFEU09ZJVP1KFe/0;Bd]05aLG01SHf<0=3@d05UI
F@36a/H0GEeM02PX:01LG5`0EeMG05QHF01nOWh0YZJV02d];@0j>SX0JFUY0861P@1mOGd0[jn_05UI
F@0k>c/0CDe=06a/K01oOgl0T92@0<K6aP10@400ATI607MgM`2GUiL0GEeM0820P018B4P07AdM06=S
H`2VYZH0CTi>04Q8B01cLg<09bLW061PH02BTY80QhN704];B`2KVi/0>3Ph0492@P2RXZ80O7al02LW
9`1RHV80;2`/04A4A02FUYH0JFUY038b<P1XJ6P0D51@04=3@`2GUiL0KVi^03<c<`1VIVH0Lg=c06=S
H`2CTi<0BDU9024Q8@29RHT0TI6A04U9B@2=SHd0TY:B034a<@0i>CT0FUYJ001105]KF`1CDe<0WIfM
06a/K00I6AT0ADE507QhN01JFUX0@d=307moO`19BDT0=SHf0492@P20P800D51@06MWI`1VIVH08b<S
02d];@13@d<0G5aL0410@00/;2`0EUIF02TY:@11@D40LG5a07QhN00V9RH0;Rh^03/k>`19BDT0@d=3
08V9R@2MWId09bLW01dM7@18B4P0GemO0451@@2:RXX0EEEE02`/;00U9BD0ADE506a/K024Q8@0MWIf
02XZ:P0R8R80?clo04U9B@1UIFD0>3Ph07EeM@0f=SH0;2`/01lO7`1ADE40NGUi03Ti>@1@D5006ATI
02LW9`18B4P00`1_Kfl0E`1gMgL0HV9R079bLP2<S8`0D51@05YJFP2@T900W9bL07]kN`2TY:@0MgMg
05IFEP2>SXh0Ng]k06QXJ02>SXh0FEUI07inOP1MGEd0K6a/06=SH`1?Cdl0IVIV06][J`1IFET0B4Q8
059BDP1IFET0JVYZ04Q8B01:BTX0EUIF04Y:BP1WIfL0HV9R075aL@26QXH0Vi^K09FEU@2[Zj/0FEUI
05]KF`19BDT0DU9B05QHF01fMWH0ADE503Xj>P1_Kfl0Hf=S065QH@1;Bd/0G5aL05EEE@1/K6`0B4Q8
05EEE@0a<C40?clo06QXJ01RHV80Q8B404M7A`1eMGD0De=C05MGE`1JFUX0;bl_05]KF`1OGel0E5AD
04I6AP1MGEd0ATI604=3@`1TI6@0BDU904M7A`1_Kfl0L71`05YJFP1FEUH0IFEU06i^KP0k>c/0AdM7
04];B`0203hn?P0E02l_;`0X:2P0@T9203<c<`0R8R80<C4a0492@P1EEED0ATI602/[:`0`<300AdM7
03Xj>P19BDT0>c/k03lo?`0n?Sh0CDe=05=CD`14A4@0<30`0080DE5A05D0EUIF03Ti>@1SHf<0GUiN
07inOP1>CTh0G5aL04I6AP1=CDd0Ogmo0::RXP29RHT0ADE504a<C01ZJVX0KFe]06=SH`1?Cdl0Jf][
05YJFP1WIfL0<S8b05EEE@2YZJT0NGUi04M7A`1RHV80J6QX07AdM01cLg<0J6QX08J6QP1^KVh0BDU9
05YJFP1`L700KVi^075aL@1/K6`0DE5A051@D00g=cL0KFe]04m?C`0^;Rh0IfMW04];B`1PH600M7Ad
04M7A`1/K6`0AdM706][J`1mOGd0Fe]K05IFEP1RHV80BTY:04I6AP1ZJVX0=CDe05ADE01gMgL0MWIf
03Lg=`1:BTX0CTi>05MGE`1FEUH0F5QH051@D00C4a<0A4A4051@D00i>CT0DU9B038b<P0_;bl0C4a<
03@d=01=CDd0@d=3030`<013@d<0A4A40080=cLg01`0G5aL02h^;P1/K6`0O7al0492@P0m?Cd0;2`/
024Q8@0k>c/0;Rh^05mOG`1VIVH0<30`04A4A01lO7`0:2PX01`L700f=SH07alO03lo?`0d=3@0CTi>
02d];@1<C4`0=cLg06MWI`1=CDd08R8R0P1`L7003P0Q8B40<c<c03<c<`0W9bL0ATI602d];@17AdL0
=SHf03Ti>@1=CDd0=CDe03`l?00d=3@0=CDe0P0j>SX07@18B4P0<C4a06EUI@0o?cl0ADE506][J`0k
>c/0R8R8055AD@14A4@0Cdm?05ADE014A4@0IfMW05mOG`1GEeL0RXZ:055AD@1bLW80?clo06][J`1O
Gel0I6AT02h^;P1cLg<0Ng]k06e]K@2=SHd0CDe=0080C4a<02L0;Bd]04e=C@12@T80KVi^06EUI@1Q
HF40IVIV07=cL`11@D40IVIV06QXJ00e=CD0AdM707inOP29RHT0Lg=c03Ph>015ADD0BDU906][J`1h
N7P0A4A404];B`1hN7P0d];B08F5Q@1gMgL0ZZZZ08^;R`1nOWh0H61P07alO01KFe/0I6AT06i^KP1O
Gel0Kfm_0861P@1VIVH00_ooool0003o07IfMP2KVi/0CTi>05IFEP1BDU80JVYZ05]KF`1<C4`0KVi^
059BDP1VIVH0De=C07alO017AdL0=SHf06=SH`1EEED0=SHf03Ti>@13@d<0De=C05eMG@24Q8@0C4a<
02h^;P1KFe/0AdM703Xj>P1bLW80Cdm?03Xj>P12@T80EeMG03dm?@1DE5@0Kfm_02/[:`0d=3@0EUIF
05MGE`12@T80Lg=c05EEE@0Z:RX0FEUI07=cL`1MGEd0GemO06a/K00k>c/0;bl_06=SH`1kNg/0E5AD
06EUI@1/K6`08B4Q05ADE01lO7`0KVi^05eMG@1]KFd0IFEU03Xj>P0o?cl0T92@051@D00f=SH0LG5a
04U9B@0c<c<0CDe=07AdM00m?Cd0@T9206m_K`1;Bd/0C4a<05mOG`1ZJVX0=SHf05aLG01GEeL0ATI6
08b<S01mOGd0=SHf05UIF@10@400CTi>06][J`23Ph<0RXZ:02<S8`1eMGD0De=C04e=C@1/K6`0GemO
06YZJP0`<300JFUY04E5A@0n?Sh0HV9R0820P01>CTh0=3@d04E5A@1aLG40EEEE02LW9`1_Kfl0I6AT
04A4A01YJFT0Hf=S03hn?P19BDT0A4A4065QH@10@400G5aL0861P@1ADE40;bl_04i>CP1bLW80GUiN
09FEU@2KVi/0GemO04Y:BP13@d<0PX:207]kN`1XJ6P0MgMg05MGE`0k>c/0H61P08>3P`1NGUh0XJ6Q
06][J`16ATH0GemO04Y:BP1fMWH0GUiN069RHP1SHf<0?Cdm05ADE02ATI40?clo02<S8`1QHF40IFEU
05]KF`2KVi/0=SHf03Ph>01mOGd0GEeM03dm?@2DU9@0UIFE030`<00n?Sh0FUYJ06EUI@14A4@0S8b<
07alO01=CDd0FUYJ06QXJ01DE5@0H61P096AT@1^KVh0HV9R07MgM`1kNg/0OGem07UiN@2_[jl0E5AD
0451@@1PH600RXZ:05QHF016ATH0IFEU05mOG`1EEED0P82009nOW`1EEED0@D5106MWI`1PH600DU9B
07]kN`1BDU80BDU906m_K`11@D40B4Q809jNWP1^KVh0CTi>071`L01OGel0L71`08B4Q01NGUh0?clo
07UiN@1]KFd0@D5106i^KP1/K6`0B4Q805YJFP1dM7@0Kfm_06IVIP2TY:@0Fe]K04i>CP22PX80Ti>C
06MWI`1oOgl0N7Qh06MWI`29RHT0EeMG04i>CP22PX80De=C04e=C@1IFET0IfMW03De=@1KFe/0M7Ad
05ADE01PH600Ogmo069RHP1FEUH0Bd];002S04i>CP1GEeL0K6a/06ATI01:BTX0H61P04Q8B010@400
NGUi09NGU`1KFe/0@D5105eMG@11@D40BTY:06EUI@1eMGD0S8b<06m_K`1SHf<0?clo05]KF`1aLG40
V9RH04M7A`0_;bl0Jf][07IfMP17AdL0MgMg09:BTP16ATH0=3@d05YJFP2CTi<0I6AT04M7A`1`L700
Fe]K05mOG`14A4@0MGEe04U9B@0`<300Bd];04E5A@16ATH0R8R806EUI@0^;Rh0HF5Q06UYJ@0n?Sh0
QHF50:j^[P1/K6`0=3@d03/k>`1?Cdl0Hf=S03hn?P1PH600De=C05QHF01MGEd0O7al08F5Q@1EEED0
F5QH05]KF`1LG5`0Lg=c08R8R01QHF40Kfm_04E5A@1FEUH0EeMG04U9B@0m?Cd0Bd];061PH01bLW80
FEUI06ATI01aLG40G5aL03@d=016ATH0@41003Ti>@0f=SH0?3`l055AD@0h>3P09BDU03lo?`24Q8@0
QXJ6051@D00a<C40?clo03hn?P10@400GEeM0410@01DE5@0J6QX02/[:`0_;bl0;Bd]03<c<`12@T80
GEeM04U9B@0k>c/0?clo03De=@0j>SX0?Shn04Q8B01aLG40RXZ:04=3@`0k>c/0<c<c02l_;`0n?Sh0
A4A404i>CP1oOgl0RHV906QXJ00f=SH0?3`l03dm?@1;Bd/0A4A40410@01@D500CTi>051@D023Ph<0
R8R805eMG@1<C4`0DE5A04Y:BP12@T80A4A403Ti>@1ADE40CDe=07AdM027QhL0E5AD04a<C01=CDd0
<S8b059BDP20P800DU9B05MGE`0203<c<`0502l_;`0[:b/071`L03`l?01DE5@00P1kNg/0;@1KFe/0
PH6107]kN`19BDT0ADE503hn?P15ADD0@d=304];B`1BDU80MgMg092@T02KVi/0GUiN04U9B@18B4P0
MWIf08N7Q`1QHF40OWin04e=C@1RHV80FUYJ04Y:BP1JFUX0IVIV059BDP0m?Cd0A4A40820P01MGEd0
L71`096AT@2DU9@0UiNG0:FUY@31`L40QhN7061PH01YJFT0SXj>05=CD`26QXH0MWIf05iNGP0205=C
D`0^055AD@1BDU80<C4a03lo?`16ATH0?3`l079bLP1LG5`0C4a<04U9B@1`L700D51@03/k>`0l?3`0
:2PX02`/;00O7al0;Rh^04e=C@1EEED0Kfm_07AdM01/K6`0Y:BT08:2PP13@d<0K6a/06m_K`1iNGT0
LG5a07AdM01fMWH0IfMW07inOP1hN7P0DE5A06IVIP1DE5@0Ogmo06EUI@0c<c<0@41003hn?P0Z:RX0
>CTi03`l?080EUIF04D0JVYZ05iNGP1_Kfl0MgMg07IfMP1NGUh0;Rh^06a/K02;Rh/0T92@096AT@1g
MgL0H61P05MGE`1_Kfl0Bd];04Q8B01HF5P0CDe=065QH@1MGEd0SXj>06IVIP1:BTX0=3@d0492@P18
B4P0?Shn04a<C00c<c<0820P02DU9@0];Bd0?Cdm05YJFP16ATH0De=C03De=@1UIFD0BDU9034a<@0/
;2`09BDU03Xj>P2ATI40MgMg08V9R@25QHD0TI6A09FEU@1>CTh0HF5Q02h^;P0/;2`0?3`l05YJFP1n
OWh0J6QX0451@@1FEUH0I6AT04m?C`1:BTX0>c/k06UYJ@1dM7@0JFUY05mOG`1gMgL00P1YJFT05`2<
S8`0N7Qh08F5Q@2EUID0O7al07QhN01`L700Ng]k06YZJP1bLW80LG5a05UIF@1FEUH0Fe]K06QXJ02^
[Zh0UYJF07IfMP29RHT0K6a/04i>CP1QHF40Hf=S0080M7Ad00@0IFEU06a/K01jNWX0P8200P1kNg/0
201aLG40LW9b059BDP1nOWh0OGem061PH01cLg<0KVi^0P1dM7@01023Ph<0NGUi05aLG01QHF42oooo
o`0008<0H61P09ZJVP1?Cdl0BTY:04A4A025QHD0@d=304m?C`25QHD0;Bd]04m?C`1kNg/0QhN7051@
D017AdL0I6AT03Ti>@12@T80CDe=04I6AP2;Rh/0C4a<06UYJ@1^KVh0;Bd]07IfMP1>CTh0<30`06QX
J01mOGd0I6AT04I6AP14A4@0;bl_03<c<`1jNWX0Bd];04i>CP19BDT0;2`/04E5A@1gMgL0L71`02/[
:`25QHD0D51@03dm?@1>CTh0BTY:04I6AP0];Bd0PX:206i^KP0o?cl0DE5A03dm?@0K6a/0De=C075a
L@15ADD0UIFE06m_K`0j>SX0:b/[04a<C02TY:@0Jf][02`/;01UIFD0=CDe03Xj>P24Q8@0QXJ604E5
A@1DE5@0VIVI05ADE01BDU80PH6107QhN01;Bd/0R8R807QhN00J6QX0VIVI05=CD`0o?cl0[Jf]05=C
D`0T92@0K6a/09fMW@1XJ6P08B4Q0<30`00^;Rh0=cLg09^KV`2HV9P0Kfm_03De=@32`/80?3`l01PH
601bLW80A4A401<C4`0^;Rh0?Shn07AdM019BDT0820P07QhN00f=SH0<C4a079bLP1PH600=SHf04a<
C00g=cL0PX:205iNGP0Y:BT0EeMG04a<C01>CTh0QhN706m_K`0O7al0UIFE05aLG00207emO@0I03<c
<`1:BTX0FUYJ05EEE@2>SXh0X:2P059BDP15ADD0E5AD05IFEP2SXj<0GemO05EEE@18B4P0=3@d06=S
H`1`L700GemO0861P@0];Bd0IFEU0;:b/P15ADD0>3Ph06m_K`02071`L01n08n?S`0k>c/0EeMG09ZJ
VP1GEeL08R8R04m?C`2FUYH0IVIV04E5A@1YJFT0G5aL03dm?@1kNg/0GUiN03Xj>P1KFe/0TI6A05QH
F02UYJD0R8R805QHF01hN7P0VIVI05iNGP1;Bd/0RHV90:6QX@1FEUH0MWIf07=cL`2HV9P0C4a<05]K
F`26QXH0VIVI04a<C022PX80a/K608B4Q016ATH0R8R80:RXZ016ATH0EEEE03hn?P0b<S80PX:204M7
A`1IFET0Q8B403<c<`1fMWH0QHF505MGE`2<S8`0JVYZ03Hf=P1_Kfl0_Kfm06MWI`0d=3@0Q8B406AT
I01KFe/0GemO08B4Q01KFe/0HF5Q0<o?c`2;Rh/0DU9B07AdM024Q8@0R8R805ADE02/[:`0T92@0:VY
Z@1jNWX0AdM707QhN02;Rh/0M7Ad061PH01`L700ADE507IfMP2/[:`0OGem04Y:BP1HF5P0SXj>0820
P00`<300Kfm_08F5Q@24Q8@0CTi>05mOG`1ZJVX0KVi^05YJFP2e]KD0RHV90410@01OGel0E5AD0492
@P0o?cl0NWYj04];B`2:RXX0`l?307MgM`1HF5P0MgMg07QhN01mOGd08B4Q03/k>`1UIFD0C4a<03Lg
=`2HV9P0TI6A0P0i>CT05P1UIFD0UYJF04A4A00U9BD0AdM706m_K`1aLG40?3`l0:FUY@23Ph<0=3@d
059BDP1IFET0>CTi0:BTY026QXH0AdM709:BTP1fMWH0<c<c07alO02<S8`204=3@`0E05UIF@1JFUX0
P82003Hf=P0];Bd0QHF50:FUY@2a/K40ZZZZ07IfMP1BDU80:RXZ020P800Q8B40<S8b092@T02CTi<0
Lg=c024Q8@0I6AT04Q8B00803Ph>0P0=3@d06@0i>CT0@41005QHF02FUYH0XJ6Q04Y:BP11@D40>CTi
03Xj>P0i>CT0>SXj03dm?@1>CTh0J6QX0:f][@2FUYH0AdM70410@00l?3`0:RXZ01<C4`0];Bd0MWIf
01/K6`0A4A400P0E5AD06@0M7Ad05QHF014A4@0C4a<07alO04Y:BP1YJFT0DU9B038b<P0Z:RX0;Rh^
02l_;`2EUID0]kNg05eMG@0J6QX071`L01lO7`0W9bL0<S8b04=3@`2CTi<0eMGE0<C4a01EEED00P0O
7al02@0P8200:2PX02DU9@0R8R80=3@d02PX:01/K6`0[:b/03/k>`0202XZ:P0_01lO7`0Z:RX0AdM7
061PH01HF5P0=SHf02<S8`0f=SH0Q8B406EUI@1FEUH0GemO06e]K@2d];@0Y:BT08R8R01JFUX0:RXZ
01<C4`0^;Rh0F5QH05eMG@17AdL0KFe]05]KF`1mOGd0^KVi09VIV@1=CDd0BDU905EEE@1gMgL0UIFE
06YZJP1UIFD0Bd];0:BTY020P800Q8B402@T900L71`0820P06YZJP2?Shl0GUiN0:FUY@1fMWH00P1Y
JFT09@2>SXh0Z:RX069RHP15ADD0V9RH0=GEe@26QXH0Xj>S0<_;b`32`/80_[jn0<o?c`39bLT0`/;2
0<[:bP3Bd]80YjNW09JFUP1NGUh0<30`01`L700K6a/0;Bd]04Y:BP1;Bd/07alO01LG5`0h>3P0WIfM
09RHV02>SXh0I6AT04Y:BP1hN7P061PH01XJ6P0G5aL01P0E5AD0D01CDe<0d];B0;2`/01bLW80_kno
059BDP0Q8B40820P02PX:00g=cL0Bd];07MgM`33`l<0^k^k06a/K01MGEd0>3Ph04Q8B03Lg=`0Ng]k
01`L700b<S80=SHf01`L700Q8B4071`L01dM7@0T92@0>CTi04a<C01dM7@0ZZZZ0=_Kf`30`<00TY:B
0;Jf]P3Ng]h0_Kfm0;>c/`2h^;P0R8R806][J`1?Cdl0?Cdm03@d=00`<300:BTY02XZ:P0/;2`0UYJF
0;fm_@1CDe<0B4Q8028R8P0/;2`0IfMW03lo?`0k>c/0@T9205MGE`17AdL0<S8b030`<01NGUh0JFUY
04M7A`1fMWH0G5aL05IFEP0n?Sh0ATI608N7Q`2_[jl0Zj^[08>3P`1NGUh0Jf][0;Vi^@1QHF406ATI
0P0E5AD09@0L71`0@T9208n?S`1KFe/0D51@02l_;`1^KVh0HF5Q01`L700S8b<0BDU907AdM023Ph<0
OWin09VIV@2VYZH0ZJVY0<?3``2^[Zh0WinO0:^[Z`22PX80U9BD09:BTP2TY:@0`L7108j>SP1eMGD0
PH6106UYJ@2CTi<0_[jn0=oOg`3Jf]X0fm_K0:JVYP1VIVH00P1IFET05`1MGEd0EeMG065QH@1cLg<0
U9BD0;Vi^@2][Jd0b<S80;no_`1XJ6P0DE5A06=SH`0b<S807AdM02<S8`0V9RH0HV9R07UiN@1gMgL0
U9BD08:2PP1KFe/07AdM00;ooooo00007`1FEUH0R8R8055AD@1:BTX0=cLg04e=C@0/;2`0De=C06e]
K@0`<300=SHf05eMG@1WIfL0BTY:05EEE@0k>c/05aLG04m?C`19BDT0C4a<05EEE@0/;2`0S8b<07Mg
M`0];Bd0IFEU01/K6`0_;bl0GUiN08N7Q`1fMWH00P1BDU80@P0Y:BT09RHV069RHP1;Bd/0IFEU04E5
A@0D51@061PH04E5A@1UIFD08b<S08J6QP0G5aL0=SHf038b<P16ATH01`L7020P801QHF40I6AT03Ph
>01]KFd0Lg=c01`L700c<c<0EUIF03/k>`2KVi/0W9bL0410@00L71`0;bl_07QhN017AdL0Cdm?07mo
O`0l?3`07alO03Ph>01EEED0>3Ph07UiN@2f][H0FUYJ02/[:`1KFe/0C4a<03Ph>01oOgl0PH6103/k
>`2][Jd0EEEE02DU9@1lO7`0Fe]K02l_;`1dM7@0R8R803/k>`1:BTX0`/;2059BDP0W9bL0MGEe08J6
QP80=3@d0=@0YZJV04];B`0L71`0P82004a<C00T92@0:RXZ03Lg=`1iNGT0@D5101dM7@1aLG40A4A4
02/[:`1NGUh0:2PX04Y:BP1ADE40;Rh^07MgM`1UIFD0@T92061PH01>CTh0<C4a05UIF@2:RXX0GUiN
08V9R@1CDe<0EEEE079bLP1<C4`0EEEE06][J`1CDe<0KFe]07IfMP1[Jf/0BDU9069RHP1EEED0VIVI
05]KF`1IFET0JVYZ051@D01JFUX0MGEe075aL@1oOgl0DE5A06YZJP34a<@0@T92034a<@1`L700Kfm_
06a/K02=SHd0?Cdm05EEE@2=SHd0Ng]k030`<01@D500XZ:R06][J`12@T80IVIV08:2PP13@d<0P820
07UiN@1NGUh0L71`04Y:BP14A4@0TI6A09RHV01cLg<0T92@09FEU@2;Rh/0Jf][08V9R@2FUYH0ATI6
06a/K01bLW80WYjN05MGE`1IFET0T92@08F5Q@16ATH0V9RH0=KFeP2CTi<0DE5A08Z:RP2^[Zh0D51@
07AdM01QHF40>SXj071`L015ADD0G5aL07]kN`0i>CT0PX:208^;R`1SHf<0Z:RX06ATI00l?3`0WIfM
0:^[Z`0l?3`0;Bd]09RHV01SHf<0J6QX06ATI01GEeL0<C4a06i^KP3<c<`0Ti>C079bLP2QXJ40R8R8
065QH@12@T80a<C40:FUY@2:RXX0U9BD04i>CP1lO7`0UIFE06i^KP1EEED0Ng]k04U9B@1cLg<0YZJV
08R8R018B4P0GemO08b<S01kNg/09RHV07IfMP2FUYH0OGem04m?C`1kNg/0L71`06m_K`1<C4`0Vi^K
08V9R@19BDT0Fe]K06ATI01BDU80@T9207]kN`1SHf<0QXJ60<;2`P1`L700FEUI07=cL`1WIfL0OWin
024Q8@0o?cl0NGUi05EEE@0d=3@0TY:B09>CT`0o?cl0<C4a0:JVYP2RXZ80IfMW02<S8`15ADD0M7Ad
02l_;`0];Bd0U9BD08^;R`0`<300B4Q806a/K00l?3`0W9bL07alO019BDT0TY:B071`L01NGUh0LG5a
0:VYZ@1:BTX0BDU909BDU080Jf][01@07alO03Lg=`2GUiL0VIVI0:f][@2WYjL0HV9R07]kN`1KFe/0
AdM7069RHP2ZZZX0Q8B405YJFP2VYZH0CDe=04M7A`0W9bL05ADE018B4P803@d=00L03`l?06m_K`1Y
JFT0@41005YJFP0B4Q803@d=00@03Ph>06/0410@01<C4`0O7al0S8b<06QXJ00l?3`0;Bd]03`l?00Z
:RX07AdM06IVIP1?Cdl05aLG010@400C4a<04A4A01XJ6P0M7Ad04a<C014A4@0>3Ph04a<C02@T901H
F5P0Ng]k06IVIP0d=3@0;Rh^07moO`22PX80TY:B01dM7@0F5QH08B4Q02LW9`0Y:BT0BTY:07IfMP3D
e=@0eMGE0<;2`P21PH40CTi>03@d=00S8b<07QhN01lO7`0c<c<0?clo08>3P`2EUID0J6QX034a<@0g
=cL0AdM705EEE@15ADD07alO01HF5P0G5aL05ADE01LG5`0X:2P0I6AT05MGE`1/K6`0CTi>09JFUP2;
Rh/0G5aL02/[:`25QHD0R8R805EEE@0];Bd07QhN01dM7@0X:2P0820P051@D02d];@0YJFU06i^KP1X
J6P0KVi^092@T038b<P0`L7106MWI`1BDU80L71`02LW9`19BDT0EeMG02DU9@0I6AT0>3Ph096AT@2m
_Kd0][Jf09>CT`1NGUh0FUYJ05iNGP1ZJVX0LG5a09>CT`020<k>cP0?08n?S`2:RXX0UIFE0;:b/P2_
[jl0P820065QH@1KFe/0Ph>30:BTY02h^;P0bl_;034a<@0G5aL051@D00806ATI00`0:BTY04a<C015
ADD07AdM02PX:02f][H0VIVI09FEU@1fMWH0PX:203Ph>00F5QH201DE5@804a<C100E5AD02P1:BTX0
Ng]k06MWI`27QhL0[Jf]07alO01^KVh0DE5A03Lg=`16ATH203Lg=`0=0861P@2e]KD0GemO038b<P18
B4P0[:b/0=kNgP2HV9P05aLG01dM7@0d=3@0:2PX02HV9P0201dM7@0A02HV9P0h>3P0CDe=051@D027
QhL0c/k>0;no_`3Hf=P0j^[Z0>WYj@2HV9P0Zj^[07EeM@1XJ6P0Jf][07IfMP1^KVh00P1bLW808P28
R8P0U9BD0;bl_03IfMT0g]kN08Z:RP1?Cdl0EUIF06EUI@0a<C408b<S04E5A@1fMWH0LW9b02HV9P0X
:2P0:b/[06MWI`1kNg/0OWin04m?C`1>CTh0O7al08V9R@2ATI40[Zj^08b<S019BDT0?clo06MWI`1J
FUX0C4a<08Z:RP0X:2P201DE5@0_01PH600Z:RX0TY:B05ADE01fMWH0?clo04M7A`31`L40Rh^;08Z:
RP21PH40Lg=c0;Bd]01[Jf/0D51@0492@P1kNg/0/;2`04a<C01nOWh0DU9B03hn?P1;Bd/0DU9B0410
@00d=3@0=cLg051@D01=CDd0Ng]k0=oOg`3De=@0Xj>S0;Zj^P3Kfm/0eMGE0<C4a02JVYX0BTY:024Q
8@0K6a/0820P02<S8`0a<C40KVi^06QXJ032`/800P2VYZH03@1GEeL07alO01lO7`0N7Qh08b<S020P
800W9bL0LW9b0;:b/P3:b/X0d=3@0:n_[`1GEeL00_ooool0003o06IVIP1OGel0DU9B05EEE@11@D40
L71`03/k>`16ATH0MWIf034a<@1TI6@0OWin03lo?`0b<S80NWYj07=cL`0_;bl0<S8b0410@01PH600
EEEE01<C4`1JFUX0HV9R03Hf=P27QhL0:RXZ02d];@1JFUX0DE5A0451@@1NGUh0MGEe05EEE@0e=CD0
DE5A02PX:01FEUH0HF5Q0451@@0f=SH0J6QX03hn?P0I6AT0IVIV04];B`0_;bl06a/K04m?C`0d=3@0
8b<S07=cL`0h>3P09BDU03/k>`19BDT0:BTY02h^;P16ATH0;bl_05EEE@1LG5`0IFEU03/k>`0l?3`0
QHF502DU9@0Y:BT0GUiN059BDP0i>CT0EEEE05iNGP0_;bl0CTi>08^;R`1LG5`0C4a<06m_K`1^KVh0
Bd];079bLP26QXH0EEEE096AT@1iNGT0<c<c09bLW01=CDd0>c/k08^;R`1mOGd0FEUI01dM7@2>SXh0
ADE502LW9`2?Shl0Lg=c034a<@0_;bl0YJFU01lO7`0E5AD0QXJ609nOW`0Y:BT0;Rh^03<c<`1`L700
DU9B024Q8@1_Kfl0Cdm?03<c<`1`L700?Shn04U9B@1EEED0A4A407]kN`1YJFT0AdM7069RHP1_Kfl0
B4Q806QXJ02CTi<0Jf][08^;R`1[Jf/0M7Ad07MgM`0o?cl0BTY:07emO@1JFUX0NGUi07alO01_Kfl0
@D5106m_K`1GEeL0XZ:R06QXJ01GEeL0KVi^05YJFP1PH600MgMg06MWI`2QXJ40I6AT06EUI@32`/80
BTY:03Ti>@1hN7P0TY:B08B4Q02<S8`0?3`l05UIF@29RHT0QHF503<c<`1>CTh0VIVI06a/K016ATH0
MWIf08Z:RP17AdL0OWin06m_K`1UIFD0LG5a07YjNP1@D500MWIf08b<S01^KVh0TI6A09VIV@2=SHd0
K6a/08f=S@2^[Zh0Jf][07]kN`2IVIT0_kno07QhN01KFe/0R8R8092@T012@T80Jf][0<O7a`24Q8@0
E5AD09BDU02MWId0AdM708F5Q@1GEeL0>3Ph07]kN`1KFe/0XZ:R09RHV017AdL0Ph>307AdM00c<c<0
X:2P0861P@1FEUH0W9bL0;6a/@1@D500:BTY06m_K`19BDT0E5AD05YJFP1?Cdl0>SXj05YJFP2f][H0
N7Qh06QXJ02UYJD0MGEe04U9B@11@D40d=3@0<W9b@2:RXX0Jf][04A4A01kNg/0Rh^;06a/K01[Jf/0
E5AD04A4A01aLG40VIVI06YZJP1EEED0YJFU0:BTY01[Jf/07QhN001K06QXJ01bLW80;Rh^02DU9@2A
TI40RXZ:06a/K00l?3`0Lg=c08Z:RP1FEUH0MGEe09JFUP1^KVh0CTi>079bLP1ZJVX0RXZ:0=CDe02N
WYh0Fe]K07inOP1TI6@0Kfm_02DU9@1`L700Z:RX05eMG@0V9RH0RXZ:08B4Q00f=SH0=3@d07alO02I
VIT0E5AD02h^;P1EEED0K6a/0861P@0e=CD0WYjN0820P00`<300CDe=07MgM`0i>CT0V9RH04a<C00`
<300R8R807UiN@1EEED0N7Qh08>3P`16ATH09RHV06YZJP2CTi<0QHF503@d=00V9RH0R8R809JFUP1d
M7@0DU9B06IVIP2k^k/0aLG50861P@22PX80T92@09NGU`2YZJT0UYJF09>CT`1GEeL0<c<c02DU9@0O
7al061PH014A4@0>3Ph0M7Ad0:JVYP27QhL0O7al014A4@0@41003`l?00h>3P0200d=3@0=00`<300?
3`l04a<C06EUI@1CDe<0ADE502LW9`1GEeL0?Cdm04U9B@2WYjL0=cLg01HF5P0201@D50804a<C00<0
7QhN00h>3P0@41000P0@41008P0C4a<051@D01/K6`1;Bd/0OGem06IVIP29RHT0P8200<k>cP0m?Cd0
6a/K034a<@0k>c/0B4Q80:>SX`2d];@0`/;206e]K@1bLW80W9bL0:FUY@1gMgL0E5AD04e=C@1<C4`0
D51@05YJFP2i^KT0Ti>C08R8R01JFUX0D51@02LW9`0C4a<201DE5@3X01TI6@0S8b<092@T02HV9P0R
8R80=cLg05UIF@1<C4`0@T9208b<S01lO7`0T92@04];B`1cLg<0Cdm?024Q8@0K6a/0;Rh^059BDP1i
NGT0S8b<08^;R`2b/[80EeMG01dM7@0X:2P0@d=307AdM02ZZZX0^k^k06QXJ024Q8@0I6AT02`/;00K
6a/0K6a/04Q8B00n?Sh0BDU909:BTP2f][H0b/[:09FEU@1CDe<0CDe=075aL@2SXj<0Y:BT08:2PP1F
EUH0KFe]0;Zj^P3:b/X0UiNG09nOW`2`/;00UYJF07IfMP1KFe/0Rh^;0:j^[P2ZZZX0WYjN03`l?00G
5aL04a<C01DE5@0D51@05ADE02d];@1CDe<0CDe=061PH038b<P0T92@0::RXP2GUiL0];Bd01dM7@0E
5AD04a<C01@D500E5AD05QHF01TI6@0N7Qh0=CDe05=CD`1hN7P0BDU9069RHP2YZJT0O7al03Xj>P17
AdL0Hf=S09:BTP1iNGT0FUYJ04a<C01VIVH0bLW909VIV@2;Rh/0fMWI0>KViP3QhN40`<3004i>CP0O
7al0<S8b04=3@`19BDT0?3`l04Y:BP1FEUH0DU9B05IFEP1mOGd0_;bl0;Zj^P1LG5`0XJ6Q0>WYj@3S
hn<0f][J0<K6aP2i^KT0ZZZZ09:BTP1iNGT0K6a/069RHP1TI6@0HV9R06EUI@1PH600Ng]k0:j^[P2>
SXh0SHf=09RHV01VIVH0820P01hN7P0T92@0IVIV03/k>`0g=cL0;2`/04a<C01>CTh0JFUY09ZJVP2_
[jl0L71`06QXJ024Q8@0Z:RX0=?Cd`1lO7`0PH6107MgM`16ATH09RHV02<S8`0c<c<0Ng]k02DU9@0E
5AD06QXJ01`L702<S8`0IFEU05=CD`1bLW80NGUi0=WIf@3Hf=P0XZ:R04M7A`1NGUh0DU9B03hn?P0e
=CD0A4A409bLW02XZ:P0G5aL08:2PP0P8200:BTY028R8P0I6AT05aLG024Q8@0T92@0:BTY05YJFP2=
SHd0clo?0<O7a`2CTi<0ZJVY0=WIf@3:b/X0U9BD06QXJ02?Shl0/k>c0820P00k>c/09RHV02h^;P1_
Kfl0PH610<?3``2PX:00WIfM02d];@0S8b<0;2`/02DU9@0];Bd092@T03/k>`1YJFT0];Bd0=?Cd`2b
/[80Lg=c05aLG0;ooooo0000o`1ZJVX0VIVI04a<C00j>SX0@41007emO@10@400BDU906e]K@0X:2P0
:BTY079bLP1mOGd0AdM703Xj>P1NGUh0<S8b02TY:@0N7Qh0ADE506][J`0m?Cd0DU9B02l_;`0U9BD0
K6a/03dm?@0i>CT0Jf][05mOG`14A4@0@D5105UIF@0j>SX0<c<c06UYJ@13@d<0CDe=05IFEP10@400
ATI607IfMP1ZJVX0:2PX0861P@1]KFd0?Cdm038b<P10@400:RXZ02HV9P1bLW80MWIf0451@@1ADE40
F5QH034a<@0e=CD0HV9R04];B`1iNGT0GEeM06][J`11@D40JFUY0;fm_@1JFUX0>3Ph065QH@14A4@0
?3`l05EEE@1YJFT0AdM7071`L02SXj<0GUiN04a<C01VIVH0QXJ604=3@`2ATI40RXZ:05=CD`1cLg<0
NGUi03De=@29RHT0A4A4065QH@2d];@0TI6A05iNGP0W9bL0_Kfm055AD@0W9bL0Shn?08R8R01=CDd0
>CTi0:ZZZP0];Bd05QHF06IVIP1dM7@0?clo034a<@0`<300JVYZ03hn?P10@400Ti>C04];B`0`<300
KFe]03Xj>P19BDT0IVIV04e=C@2BTY80MgMg04m?C`1]KFd0KVi^04];B`1VIVH0TY:B06i^KP24Q8@0
KFe]079bLP1hN7P0DU9B06ATI01aLG40EUIF07EeM@1/K6`0L71`04Y:BP1^KVh0DE5A08b<S01VIVH0
Jf][08>3P`1CDe<0SHf=07QhN01GEeL0NWYj05IFEP1@D500^;Rh059BDP0g=cL0M7Ad08n?S`1nOWh0
Rh^;03Hf=P1OGel0TY:B07EeM@0`<300BDU908j>SP0j>SX0J6QX0;>c/`2NWYh0BDU907AdM01NGUh0
K6a/07AdM02:RXX0GEeM08J6QP2ATI40QXJ609fMW@2JVYX0TY:B06YZJP2:RXX0_[jn05]KF`1[Jf/0
Shn?0:^[Z`1VIVH0Cdm?08B4Q02OWil0Hf=S08b<S03Cdm<0NGUi05EEE@2YZJT0X:2P0410@01KFe/0
EEEE03<c<`1QHF40C4a<07EeM@2?Shl0Cdm?07QhN01ADE40@d=30:BTY01[Jf/0DE5A07inOP2FUYH0
GemO03@d=023Ph<0EEEE04Q8B01^KVh0H61P04];B`1^KVh0c/k>07IfMP1QHF40ZJVY07IfMP1:BTX0
;bl_08J6QP2SXj<0V9RH07alO014A4@0MGEe05YJFP1IFET0Ogmo059BDP0n?Sh0HV9R08j>SP0f=SH0
<C4a06ATI01bLW80BTY:01hN7P00H01^KVh0BDU906IVIP1:BTX0G5aL06=SH`1JFUX0=3@d05iNGP1U
IFD0=3@d08:2PP2UYJD0HF5Q04A4A01TI6@0E5AD06i^KP2j^[X0PH6104M7A`1gMgL0M7Ad07QhN00Y
:BT0?3`l065QH@0g=cL09BDU08B4Q01VIVH0:2PX02l_;`1YJFT0MWIf02PX:00U9BD0HV9R07]kN`1V
IVH0?3`l0:2PX01OGel08R8R05=CD`1GEeL0<C4a07YjNP1cLg<0>3Ph09RHV02BTY80DU9B0<C4a01/
K6`0BDU9030`<01ADE40Jf][07UiN@1:BTX0>CTi0:FUY@2BTY80UiNG05]KF`1OGel0]kNg08J6QP11
@D40:RXZ038b<P1QHF40S8b<05aLG01/K6`0L71`06][J`1SHf<0G5aL05IFEP11@D40J6QX0:f][@2W
YjL0a/K609^KV`1?Cdl0AdM703`l?00];Bd0:RXZ02h^;P0`<300>CTi04Y:BP80VYZJ00d0TY:B06EU
I@1SHf<0IVIV0<30`03;bl/0;2`/01<C4`0D51@03Ph>010@400E5AD0:RXZ0080410@01004a<C00h>
3P0A4A405ADE014A4@0@41009bLW075aL@32`/80][Jf0=?Cd`2`/;00M7Ad06MWI`1[Jf/0Rh^;0P3H
f=P0PP3De=@0D51@03Hf=P0X:2P0AdM707alO02JVYX0Lg=c04U9B@0h>3P0NWYj0<;2`P2>SXh0OWin
04m?C`0C4a<05ADE014A4@0B4Q806a/K03Lg=`0Y:BT0:2PX01TI6@0B4Q804a<C024Q8@1XJ6P0CTi>
09ZJVP2UYJD0_[jn0:n_[`1[Jf/0J6QX06EUI@1]KFd0IFEU04A4A010@400>3Ph02l_;`0h>3P0GemO
038b<P0F5QH071`L02`/;018B4P0N7Qh05YJFP2h^;P0Ph>304Y:BP0e=CD0?clo0:>SX`1WIfL0HV9R
07moO`2a/K40bl_;0;2`/02CTi<0R8R80820P01iNGT0KFe]06ATI010@400@d=309:BTP2c/k<0bLW9
0=[JfP2YZJT0JVYZ051@D01]KFd0Fe]K04A4A01[Jf/0Ogmo07IfMP0S8b<05ADE01<C4`0D51@05ADE
01HF5P1_Kfl0Shn?04M7A`22PX80Xj>S0;jn_P3Bd]80bLW902d];@0e=CD0?3`l03Ti>@0o?cl0?Cdm
03/k>`0f=SH0;bl_03Xj>P1iNGT0IVIV08>3P`35aLD0b/[:09RHV01hN7P0Rh^;08f=S@1]KFd0HV9R
03/k>`12@T80Y:BT09ZJVP3@d=00bLW90:BTY00e=CD0AdM70::RXP1fMWH203Ti>@0P07IfMP2b/[80
][Jf0;Bd]02`/;00XJ6Q08n?S`2BTY80`/;206e]K@2h^;P0jNWY0=3@d02=SHd0YJFU0;Rh^02>SXh0
EeMG03@d=00U9BD092@T02DU9@0V9RH0:2PX02d];@0g=cL0@D5107MgM`21PH40YZJV06IVIP0];Bd2
01hN7P0Y03hn?P0g=cL0>c/k06ATI01XJ6P0Ph>30:n_[`30`<00[Jf]05QHF01SHf<0IFEU0:RXZ02M
WId0U9BD0:b/[01TI6@0=3@d02TY:@0U9BD0:BTY06=SH`26QXH05aLG01XJ6P0R8R80WIfM0<;2`P2c
/k<0bLW90=OGe`3Rh^80RHV903dm?@1<C4`0Cdm?03Xj>P0`<300=3@d04a<C02][Jd00P2ZZZX0:`0h
>3P05ADE01DE5@0E5AD05QHF01LG5`0F5QH0820P028R8P0S8b<0U9BD0;>c/`2?Shl0C4a<09jNWP1R
HV80AdM707MgM`2HV9P0Ti>C09jNWP31`L40bLW90;:b/P2;Rh/0Y:BT0<71`@2m_Kd0H61P06IVIP1n
OWh0ADE50451@@15ADD0B4Q8079bLP1mOGd0U9BD0:f][@1eMGD0OGem08R8R01WIfL00_ooool0003o
065QH@2MWId0CTi>051@D016ATH0Ti>C04=3@`18B4P0TY:B06a/K00a<C40GEeM06YZJP14A4@0@410
04i>CP0_;bl0BDU904Y:BP19BDT0RXZ:04I6AP1HF5P0EEEE034a<@1dM7@0=SHf03hn?P1eMGD0NGUi
05iNGP1DE5@0GemO03Ti>@13@d<0OGem04E5A@1<C4`0B4Q801@D5015ADD0UYJF07IfMP0e=CD0Shn?
05mOG`0k>c/0=CDe0451@@0Z:RX0;Rh^07QhN01RHV80@410051@D01MGEd0=3@d04A4A01jNWX0?clo
07]kN`1OGel0C4a<02LW9`0];Bd0LW9b05IFEP0n?Sh0H61P02DU9@0c<c<0UYJF08^;R`12@T80Ng]k
0:n_[`1PH600C4a<08J6QP27QhL0>c/k096AT@24Q8@0?3`l04i>CP26QXH0<S8b0820P016ATH0=3@d
0861P@23Ph<0Hf=S02PX:030`<00EeMG03@d=02/[:`0WYjN06e]K@0l?3`0ZJVY03hn?P0S8b<0MWIf
05QHF00j>SX0:2PX02l_;`1TI6@0@d=302HV9P1YJFT0GemO03Ti>@25QHD0=CDe04E5A@1UIFD0B4Q8
08R8R01<C4`0EeMG07YjNP1TI6@0@d=306=SH`22PX80ATI607EeM@1IFET0GUiN06IVIP1DE5@0PX:2
07UiN@1:BTX0KVi^06m_K`1PH600IVIV07AdM01=CDd0SXj>05QHF01IFET0OWin05=CD`1oOgl0NGUi
06][J`2=SHd0EEEE04m?C`30`<00EUIF03dm?@2CTi<0P82007emO@2:RXX0?clo08n?S`31`L40PX:2
038b<P15ADD0VIVI05=CD`11@D40L71`08f=S@11@D40NWYj0451@@1VIVH0QHF508R8R01JFUX0PX:2
07emO@1XJ6P0^KVi0<O7a`2SXj<0JVYZ07YjNP2^[Zh0Ng]k079bLP1nOWh0][Jf06EUI@1/K6`0Z:RX
0;>c/`1HF5P0SXj>0=GEe@1BDU80<C4a08f=S@2e]KD0BDU907inOP1HF5P0@d=3079bLP1=CDd0JVYZ
08J6QP1=CDd0P82006IVIP1GEeL0YJFU06e]K@0^;Rh0H61P096AT@1LG5`0=CDe08Z:RP1GEeL0@T92
08N7Q`28R8P0FEUI07UiN@3=cLd0Q8B4061PH02c/k<0QhN705mOG`11@D40Z:RX09JFUP2TY:@0KVi^
0410@01cLg<0DE5A05IFEP1YJFT0E5AD03lo?`1TI6@0UIFE06i^KP11@D40KVi^08n?S`1;Bd/0;2`/
001I09ZJVP1HF5P0Kfm_04m?C`1`L700OWin05IFEP10@400IVIV07MgM`0h>3P0BDU9065QH@0e=CD0
BDU906EUI@1RHV80UiNG0<K6aP1CDe<0CDe=09NGU`2WYjL0S8b<03Hf=P1PH600R8R805MGE`0Y:BT0
Ti>C061PH00O7al0=SHf05UIF@1bLW808b<S02/[:`1<C4`0LG5a04a<C01MGEd0[:b/07AdM00T92@0
ATI606e]K@0g=cL0Ph>306e]K@0d=3@0R8R807AdM01IFET0cLg=08n?S`0l?3`0<c<c04m?C`1UIFD0
MgMg02d];@0e=CD0PX:2096AT@1;Bd/0ZJVY0;Jf]P1NGUh0GemO07UiN@1IFET0KVi^09:BTP1nOWh0
QXJ608B4Q01_Kfl0EUIF04Y:BP11@D40ATI605mOG`1kNg/0`/;20;Rh^03EeMD0c/k>0861P@1MGEd0
0P1GEeL03`1JFUX0GEeM06ATI01dM7@0R8R80<_;b`3Cdm<0a<C40;Fe]@2k^k/0bLW90=;BdP36a/H0
=SHf01<C4`0201@D500Z010@400E5AD0AdM701DE5@0A4A403Ph>00l?3`0A4A405QHF01DE5@0A4A40
3Ph>01/K6`1hN7P0RHV90<g=c@3MgMd0_kno0:VYZ@2UYJD0dM7A0<c<c03>c/h0bLW90<G5a@2c/k<0
Shn?07emO@1WIfL0I6AT06i^KP2GUiL0/K6a0=cLg02c/k<0FUYJ04I6AP19BDT0:RXZ01LG5`0A4A40
820P0P0M7Ad00`0H61P051@D01DE5@0301DE5@0k02`/;022PX80PH610:j^[P3;bl/0cLg=096AT@1X
J6P0BDU903Ph>00/;2`08b<S01HF5P0G5aL04a<C01DE5@0b<S80EUIF02/[:`0I6AT07AdM03@d=01>
CTh0Ng]k08B4Q00i>CT0HF5Q08b<S023Ph<0IfMW034a<@0o?cl0DU9B08B4Q02i^KT0_kno0::RXP1P
H600L71`09BDU02KVi/0WinO09VIV@29RHT0UIFE09jNWP2;Rh/0`/;207IfMP0h>3P071`L038b<P11
@D409RHV04U9B@1UIFD0LG5a07emO@0Q8B400`0C4a<03`0F5QH0GemO0:b/[01cLg<0RXZ:0<G5a@3E
eMD0emOG0=;BdP0j>SX06QXJ01LG5`0E5AD051@D01DE5@0201HF5P1/01DE5@1EEED0DU9B04a<C02Y
ZJT0Zj^[04];B`2ATI40UiNG0861P@2BTY80Vi^K0:NWY`2GUiL0/;2`0<C4a033`l<0iNGU0;bl_00[
:b/05aLG01HF5P0U9BD0NWYj09ZJVP29RHT0a/K608f=S@1OGel0>3Ph02d];@0W9bL0<30`04];B`2I
VIT0X:2P0<W9b@3Bd]80bl_;0:j^[P2JVYX0TI6A06m_K`1DE5@0<30`02XZ:P0];Bd0:BTY02LW9`0Y
:BT0<C4a03<c<`0_;bl0C4a<08n?S`2c/k<0BTY:05IFEP0W9bL0820P03Lg=`1JFUX0BTY:096AT@2M
WId0Ph>307emO@2EUID0_kno09:BTP22PX80VYZJ0;Bd]01=CDd0F5QH04Y:BP1aLG40<C4a02h^;P0a
<C40>c/k0410@01jNWX0KFe]03/k>`1/K6`0c/k>0<c<c02UYJD0^k^k0>OWi`3QhN40V9RH069RHP1W
IfL0@41003dm?@1OGel0SXj>0;no_`3Bd]80fMWI09fMW@0J6QX05ADE01LG5`0E5AD05QHF0P0G5aL0
900I6AT08B4Q03lo?`2RXZ80PX:205YJFP1/K6`0PH6101`L700H61P06QXJ020P800c<c<0Jf][092@
T02h^;P0]KFe0<c<c03Ogml0cLg=0:FUY@2ZZZX0EEEE0:NWY`2FUYH0Hf=S07=cL`2<S8`0Ph>30:2P
X02FUYH0OGem06i^KP2ZZZX0F5QH06i^KP;ooooo0000o`1NGUh0UiNG04e=C@1KFe/0AdM707emO@0m
?Cd0EeMG09^KV`1]KFd0;bl_07IfMP2@T900ATI603dm?@0c<c<051@D03Ti>@0f=SH0G5aL06=SH`0^
;Rh0RXZ:05UIF@0n?Sh0P82001hN7P1CDe<0TY:B07YjNP1PH600Hf=S06i^KP1?Cdl0@D51071`L013
@d<0Bd];06ATI00m?Cd0<c<c071`L01]KFd0<30`092@T00P8200>SXj02/[:`13@d<06ATI04];B`2C
Ti<0GemO03Ti>@1>CTh0@D51018B4P0h>3P0JVYZ0492@P1mOGd0R8R808F5Q@14A4@0ADE509^KV`1B
DU80>c/k05aLG00e=CD092@T03lo?`1KFe/0:2PX06m_K`2d];@0D51@05MGE`2:RXX0R8R8038b<P27
QhL0P82005iNGP0i>CT0O7al02`/;01]KFd0CTi>04E5A@2ZZZX0X:2P051@D00X:2P0[Zj^03hn?P0o
?cl0UIFE09RHV01PH600GEeM0;^k^`1DE5@0<30`07alO01BDU80;Bd]03`l?01EEED0MgMg06a/K00j
>SX0Ng]k06IVIP0h>3P0Ph>302`/;01<C4`0EEEE0451@@2PX:00K6a/05ADE01[Jf/0J6QX03dm?@1I
FET0QHF505UIF@1nOWh0G5aL04i>CP1WIfL0D51@061PH01gMgL0@41005QHF01nOWh0KVi^05EEE@1Q
HF40AdM708f=S@1@D500QHF507MgM`1:BTX0Rh^;06i^KP1NGUh0RXZ:03`l?017AdL0X:2P04=3@`1I
FET0Xj>S07emO@1bLW80VIVI02l_;`1ZJVX0Y:BT07alO00h>3P0FUYJ0:JVYP1ZJVX0BDU907YjNP2@
T900A4A407moO`1]KFd0G5aL06EUI@1jNWX0EUIF07alO01aLG40EEEE07YjNP26QXH0RXZ:069RHP1o
Ogl0[Jf]07UiN@21PH40S8b<096AT@0`<300Bd];07moO`29RHT0ATI608^;R`2b/[80LW9b05QHF02H
V9P0UiNG065QH@2<S8`0=cLg03Xj>P2>SXh0CTi>06EUI@1TI6@0=3@d06a/K01fMWH0GemO092@T02L
W9`0E5AD0820P02e]KD0De=C03Ph>02EUID0Fe]K03dm?@18B4P0EeMG059BDP28R8P0d=3@096AT@1G
EeL0XZ:R0;Jf]P24Q8@0G5aL0;no_`2XZ:P0^KVi08>3P`16ATH0RXZ:06IVIP1^KVh0Rh^;01lO7`0X
:2P0CDe=09BDU01JFUX0B4Q80820P02;Rh/0<C4a020P8000G@1`L700DU9B02PX:00d=3@0T92@08V9
R@0h>3P0=3@d069RHP1kNg/0?clo07YjNP1oOgl05aLG03Xj>P1VIVH0L71`07moO`3Cdm<0L71`03Xj
>P1PH600FUYJ04i>CP0U9BD0B4Q806a/K01WIfL0;Bd]08j>SP1MGEd07alO03Lg=`1DE5@0O7al03Ti
>@0_;bl0E5AD069RHP1MGEd0=cLg06QXJ01PH6008B4Q04U9B@1WIfL0<C4a08^;R`1SHf<0@D510:VY
Z@1YJFT0I6AT0=3@d02ATI40<C4a03hn?P1ZJVX0TI6A07EeM@0X:2P0:b/[08j>SP2KVi/0?Cdm096A
T@2FUYH0Jf][05IFEP1mOGd0ZJVY0;^k^`1^KVh0;Bd]02DU9@13@d<0Lg=c09fMW@20P800GemO05AD
E01^KVh0PX:20;Bd]023Ph<0UIFE0<c<c02TY:@0?3`l034a<@0`<300;Rh^02l_;`02034a<@0G04Q8
B02LW9`0Zj^[07inOP1_Kfl0U9BD05ADE01UIFD0Shn?06a/K00I6AT05ADE01<C4`0>3Ph07QhN09NG
U`0U9BD04Q8B00l?3`0>3Ph04a<C01HF5P0>3Ph00P0A4A404@0P8200Jf][03dm?@2>SXh0ZJVY038b
<P0];Bd0>SXj0;Rh^02`/;00bl_;0:n_[`1cLg<0GEeM05YJFP1UIFD0J6QX0080JFUY00h0Rh^;0:BT
Y03GemL0SXj>02`/;00V9RH0>c/k02LW9`1=CDd0A4A401`L700D51@05ADE014A4@804a<C00h04A4A
01<C4`0E5AD051@D04];B`3EeMD0/[:b0<K6aP2i^KT0Ogmo04e=C@0d=3@06ATI01DE5@804a<C03H0
4Q8B01PH600F5QH05aLG0492@P1GEeL0:b/[01/K6`0f=SH0HV9R09BDU01RHV80;Bd]05ADE01JFUX0
DU9B05QHF01dM7@0F5QH04Q8B01?Cdl0QXJ609:BTP2FUYH0GEeM028R8P0T92@0?clo08n?S`2o_kl0
aLG508>3P`0n?Sh0>CTi07=cL`25QHD0De=C01TI6@0J6QX0>c/k01lO7`0V9RH0Cdm?04E5A@1RHV80
Ng]k02DU9@0F5QH05ADE02l_;`12@T80Y:BT0:b/[01dM7@20;Bd]00i0:JVYP2o_kl0NWYj02LW9`0E
5AD051@D01DE5@0F5QH05aLG01DE5@0`<300IFEU03Hf=P1XJ6P0[jn_05aLG00X:2P0JVYZ08B4Q019
BDT0@41001/K6`0U9BD0?Shn07=cL`31`L40hN7Q0>[ZjP29RHT0@T9204M7A`0n?Sh0@T92055AD@1o
Ogl0];Bd05]KF`1NGUh0JVYZ03dm?@0h>3P0>c/k04Y:BP1>CTh0HV9R0<_;b`3Cdm<0eMGE0;bl_01e
MGD0MgMg05QHF01SHf<0D51@03De=@0/;2`0<30`0080:BTY00L0:b/[034a<@0i>CT0Bd];05ADE01a
LG40V9RH0080GemO02h0D51@01lO7`0h>3P0IfMW06][J`23Ph<0R8R809VIV@2[Zj/0^;Rh0;Zj^P2S
Xj<0HF5Q075aL@22PX80@D51059BDP1LG5`0PH6104U9B@0b<S80=CDe0410@01EEED0WIfM0<W9b@2J
VYX0Fe]K04U9B@2MWId0J6QX05IFEP2YZJT0g]kN0<c<c02/[:`0WinO0:2PX02i^KT0WIfM079bLP1j
NWX0b<S80=[JfP27QhL05aLG0P0E5AD201HF5P0;01LG5`0J6QX06a/K01lO7`1eMGD0OWin06=SH`1H
F5P0TI6A02PX:00E5AD00`0G5aL0600E5AD05aLG01TI6@0^;Rh0EEEE0;Jf]P3Fe]H0aLG508F5Q@2@
T900[jn_0<30`035aLD0X:2P071`L019BDT0EUIF0:6QX@28R8P0Ng]k09:BTP1lO7`0QHF5069RHP;o
oooo0000o`1ZJVX0J6QX04m?C`1CDe<0ADE5075aL@0b<S80@D5107QhN01HF5P0:BTY06IVIP0h>3P0
?clo06YZJP1lO7`0>SXj03Ti>@11@D40H61P05aLG00T92@0HV9R06EUI@1=CDd0NGUi01`L700[:b/0
IfMW06a/K01BDU80P82008n?S`1HF5P0C4a<06e]K@0];Bd0GEeM07alO011@D40@d=309^KV`1;Bd/0
8B4Q07MgM`0g=cL0<c<c02@T901?Cdl06ATI024Q8@1XJ6P0?3`l03Lg=`1WIfL0HF5Q03De=@0l?3`0
F5QH03Ti>@27QhL0Y:BT08B4Q016ATH0BDU908j>SP0j>SX0F5QH08j>SP1BDU80CTi>05EEE@1RHV80
:BTY05=CD`2YZJT0Jf][069RHP1oOgl0Ng]k03lo?`2f][H0WIfM06a/K00b<S80?Cdm02<S8`1_Kfl0
NWYj061PH02h^;P0];Bd018B4P0X:2P0UYJF069RHP0Z:RX0TY:B09jNWP0N7Qh0:b/[0861P@1KFe/0
;Bd]08>3P`2XZ:P0Hf=S02@T900W9bL0HF5Q06=SH`1IFET0YJFU06MWI`0b<S80MGEe061PH01XJ6P0
LW9b02TY:@28R8P0KFe]06QXJ01bLW80<c<c034a<@1ZJVX0RHV905mOG`1^KVh0A4A405eMG@23Ph<0
EeMG071`L01^KVh0A4A406m_K`2SXj<0LW9b05mOG`1@D500<S8b08j>SP1YJFT0Q8B4055AD@0V9RH0
K6a/09>CT`1OGel0][Jf038b<P0V9RH0ZJVY07=cL`0o?cl0Rh^;06ATI01OGel0VYZJ04I6AP1mOGd0
^;Rh05=CD`0U9BD0=SHf071`L014A4@0Fe]K09fMW@20P800;bl_07=cL`1LG5`0HF5Q07=cL`1UIFD0
DE5A08n?S`2=SHd0LG5a08b<S01lO7`0IFEU05ADE02<S8`0`/;2096AT@2DU9@0/[:b0;2`/01TI6@0
BTY:0861P@2BTY80BDU909BDU033`l<0J6QX06YZJP2=SHd0TY:B03dm?@1SHf<0DU9B02<S8`1FEUH0
ADE506UYJ@1eMGD0@D5104a<C01LG5`0ATI608>3P`1/K6`0HF5Q09jNWP2f][H0M7Ad03`l?029RHT0
Cdm?0492@P1IFET0CTi>03Ti>@1]KFd0Z:RX08>3P`1>CTh0P82007moO`1hN7P0GEeM0<c<c03>c/h0
`/;206i^KP0b<S80MgMg07QhN01UIFD0R8R805YJFP0m?Cd0H61P0:2PX01ZJVX0C4a<07YjNP1hN7P0
@D5102l_;`00=`1kNg/0AdM705eMG@1=CDd0I6AT07]kN`1YJFT0=cLg051@D01VIVH0;Rh^06QXJ01f
MWH0AdM704m?C`1HF5P0JVYZ051@D037alL0H61P04];B`20P800JVYZ06a/K00^;Rh0BDU906MWI`1T
I6@0>3Ph08f=S@1VIVH0=3@d03Xj>P1?Cdl0QhN704=3@`0_;bl0GUiN06QXJ01bLW80@41007EeM@1L
G5`0;Rh^08>3P`26QXH0;Rh^07YjNP0c<c<09BDU079bLP1cLg<0IFEU0<k>cP1[Jf/00P0G5aL07`0]
;Bd0Bd];06a/K00];Bd09bLW08R8R01lO7`0ADE506YZJP11@D40DE5A07MgM`2/[:`0`/;20;jn_P2T
Y:@0MgMg05iNGP1@D500GEeM09>CT`2`/;00SHf=0;jn_P2?Shl0GemO0;>c/`1DE5@0;Rh^09:BTP1I
FET00P0B4Q8200l?3`0Q010@400A4A403Ph>01HF5P17AdL0Xj>S05=CD`15ADD0DE5A01LG5`0E5AD0
?3`l0;:b/P0j>SX05aLG014A4@0=3@d0=3@d09ZJVP1;Bd/0BDU904E5A@0`<300:2PX010@400>3Ph0
8b<S01HF5P1ADE40VYZJ08V9R@1nOWh0QhN70080=3@d01/0IVIV09>CT`12@T80];Bd0<;2`P2KVi/0
O7al03De=@0Z:RX0=SHf0492@P17AdL0@D5104Q8B02l_;`0[Jf]03`l?00R8R80>SXj01LG5`0^;Rh0
>3Ph00h>3P0?3`l04a<C014A4@0@41000P0C4a<01@0E5AD04a<C01<C4`0P8200bl_;0080/;2`00D0
[jn_08R8R00c<c<0820P01@D5002014A4@0o00l?3`0@41005QHF01TI6@0H61P06ATI04A4A01OGel0
:BTY03lo?`1RHV80NGUi07EeM@1WIfL0@T9202h^;P0P82007AdM02PX:00`<300=cLg02XZ:P1WIfL0
T92@03hn?P1WIfL0DE5A01hN7P0M7Ad0:BTY07=cL`2GUiL0?Cdm02h^;P0`<300EUIF08B4Q01KFe/0
:2PX01`L700n?Sh09BDU01dM7@0`<300FUYJ03`l?01OGel0MgMg04A4A00a<C40@d=308R8R02KVi/0
>CTi02TY:@2;Rh/0cLg=0;:b/P1nOWh0P82007EeM@0Y:BT04a<C00<05ADE02807alO05eMG@0f=SH0
EEEE09fMW@1GEeL09RHV02PX:014A4@0E5AD030`<013@d<06a/K02DU9@0V9RH0?Cdm06IVIP2RXZ80
g=cL08B4Q00n?Sh0ATI603Xj>P0i>CT0<c<c0492@P2ATI40:2PX05UIF@2^[Zh0Shn?06ATI012@T80
:BTY0P0I6AT0302HV9P0e=CD0<_;b`3GemL0VYZJ0:VYZ@1dM7@0@T9204=3@`0K6a/07QhN02/[:`80
8B4Q03P08b<S028R8P0G5aL05aLG01hN7P1<C4`0O7al09jNWP1>CTh0SXj>07inOP2[Zj/0U9BD09jN
WP2?Shl0XZ:R07moO`1bLW80Fe]K07=cL`33`l<0DE5A034a<@11@D40EeMG05EEE@1OGel0DU9B02/[
:`0T92@0<C4a07QhN032`/80][Jf0;Vi^@12@T806a/K01`L700^;Rh0S8b<07AdM02CTi<0a/K60=?C
d`37alL0][Jf0820P01BDU80EEEE0:2PX032`/80Rh^;06m_K`2VYZH0<S8b01@D50805ADE00X06ATI
01hN7P0P8200<S8b06EUI@2`/;00Jf][06QXJ02LW9`0@D510P0E5AD06`0F5QH05aLG01TI6@0G5aL0
5QHF01DE5@0G5aL08B4Q0:2PX02a/K40d];B0:ZZZP2@T900^;Rh0;bl_034a<@0RXZ:04Y:BP18B4P0
[:b/0:^[Z`23Ph<0RHV905YJFP1TI6@0Jf][04i>CP02ooooo`000100Kfm_07AdM01;Bd/0DU9B04M7
A`1iNGT0@41004=3@`1_Kfl0@41002l_;`1YJFT0L71`034a<@0V9RH0C4a<0P0/;2`0c`0K6a/0AdM7
05]KF`12@T80G5aL02PX:016ATH0IfMW02`/;00g=cL0QhN703Ti>@0b<S80AdM706=SH`1NGUh0GemO
07MgM`0Z:RX0BTY:051@D00W9bL0CTi>09FEU@1MGEd09RHV0861P@1CDe<0?clo01hN7P1=CDd0=CDe
02TY:@1oOgl0EUIF02l_;`14A4@0EUIF03/k>`0d=3@0AdM702LW9`19BDT0H61P06MWI`0m?Cd0EEEE
09bLW00/;2`0<30`05MGE`0e=CD0GUiN08J6QP1PH6008B4Q055AD@2DU9@0JFUY07alO02>SXh0Cdm?
02l_;`1]KFd0PX:204a<C012@T80KFe]028R8P1RHV80DU9B075aL@3;bl/0[:b/04e=C@0L71`0V9RH
051@D00X:2P0TY:B08f=S@0n?Sh0>CTi0:6QX@1KFe/0=SHf08R8R01cLg<0E5AD02h^;P0e=CD0KVi^
07QhN00n?Sh0LG5a07MgM`0k>c/0LG5a05=CD`0o?cl0P820069RHP2:RXX0I6AT07alO026QXH0I6AT
03@d=01HF5P0NWYj05YJFP1cLg<0:2PX03Ph>01RHV80BTY:07alO01]KFd08b<S0492@P1/K6`0EUIF
06EUI@1hN7P0<c<c07IfMP1@D500IFEU07MgM`1>CTh0B4Q807inOP1OGel0Q8B405ADE00n?Sh0Ph>3
04e=C@11@D40U9BD07=cL`1MGEd0T92@04U9B@2BTY80/;2`07emO@0g=cL0>3Ph08:2PP1FEUH0A4A4
06][J`1oOgl0?Cdm05iNGP1;Bd/0P82008f=S@13@d<0A4A409nOW`2LW9`0MGEe08J6QP35aLD0IVIV
03lo?`1cLg<0/K6a051@D01ZJVX0TY:B0:6QX@1KFe/0J6QX0:NWY`24Q8@0Bd];09VIV@2k^k/0F5QH
07inOP2[Zj/0YZJV04=3@`1]KFd0C4a<020P801;Bd/0E5AD08N7Q`1aLG40?3`l04M7A`1NGUh0De=C
06i^KP1FEUH0CTi>07AdM02[Zj/0Kfm_03Ti>@2:RXX0GUiN0492@P0206m_K`0Q05EEE@2@T900^k^k
06YZJP1@D500Xj>S07inOP1EEED0=3@d09BDU02?Shl0W9bL08Z:RP0l?3`0Hf=S07UiN@1XJ6P0Ogmo
05ADE00l?3`0E5AD08N7Q`1NGUh0@D5106ATI02CTi<0LG5a03hn?P2DU9@0G5aL06m_K`17AdL0GUiN
0080MGEe03<0Bd];06QXJ024Q8@0BDU906][J`1VIVH0Lg=c06ATI02<S8`0U9BD08J6QP37alL0UIFE
05=CD`28R8P0^;Rh09>CT`0e=CD0C4a<06ATI00Z:RX0=SHf07emO@1WIfL0@T92034a<@16ATH0P820
02XZ:P17AdL0Shn?09FEU@1SHf<0?Shn06a/K01>CTh07AdM05MGE`1/K6`0=3@d08R8R01UIFD0<C4a
09^KV`1dM7@0N7Qh0=?Cd`1PH600@d=3034a<@1FEUH00P1bLW808@0g=cL0:RXZ07EeM@1lO7`0G5aL
05YJFP0b<S80;2`/02d];@1iNGT0cLg=0=?Cd`2g]kL0MGEe04a<C010@400>c/k059BDP2>SXh0O7al
0;6a/@25QHD0Rh^;09^KV`1JFUX0=3@d075aL@1JFUX05aLG01DE5@0I6AT08b<S01HF5P0200h>3P06
01<C4`0M7Ad0UIFE065QH@1UIFD0=CDe0P0A4A40;`0K6a/0Vi^K08f=S@0O7al051@D01lO7`1VIVH0
9RHV01@D500E5AD0:2PX07MgM`1_Kfl06a/K018B4P0O7al0ADE50:BTY03AdM40gMgM0<;2`P3<c<`0
S8b<08F5Q@33`l<0F5QH05mOG`1VIVH07alO02TY:@1:BTX0Jf][05YJFP0c<c<071`L02XZ:P0U9BD0
:2PX06YZJP2a/K40QXJ60410@00o?cl04a<C01DE5@15ADD05QHF00803Ph>00D051@D01TI6@0G5aL0
5ADE01@D500201DE5@0801hN7P2BTY80YjNW08F5Q@1cLg<0BTY:02<S8`0G5aL400h>3P804A4A05l0
51@D01`L700I6AT07AdM04m?C`1dM7@0P8200;Jf]P1LG5`0GUiN03`l?00V9RH06ATI01DE5@0F5QH0
71`L020P800S8b<0<C4a08F5Q@1PH600FEUI04];B`1XJ6P0<c<c01hN7P0L71`0JFUY092@T00m?Cd0
:RXZ02PX:013@d<0UIFE09jNWP1YJFT0@D5104E5A@0h>3P07AdM02HV9P1^KVh0:2PX02/[:`11@D40
MGEe09fMW@1RHV80MWIf07emO@0Z:RX0Bd];06IVIP3:b/X0YZJV0820P01XJ6P0KVi^09>CT`1VIVH0
71`L01HF5P0I6AT0K6a/04a<C01BDU80Ng]k08^;R`0N7Qh07AdM051@D01HF5P0EeMG03Lg=`1`L700
ADE5055AD@0g=cL0>3Ph05QHF02`/;00^;Rh09RHV00g=cL0<c<c034a<@0_;bl0<30`02`/;02MWId0
;Bd]03Ph>01ADE40LW9b06MWI`0201DE5@0?01<C4`0U9BD0^KVi0<_;b`3De=@0f][J04Y:BP0b<S80
?Cdm028R8P0Z:RX0?clo01`L700I6AT051@D00D05ADE0400;bl_05MGE`1oOgl0c<c<08>3P`2CTi<0
_Kfm08f=S@1QHF40YjNW06m_K`0h>3P092@T01lO7`0U9BD0;bl_06UYJ@2@T900=SHf02`/;01KFe/0
F5QH06ATI018B4P0@T9208F5Q@2NWYh0L71`05mOG`2XZ:P0NWYj02d];@0^;Rh0:RXZ028R8P1ADE40
]KFe09:BTP2k^k/0/[:b09:BTP1EEED0CTi>08n?S`30`<00N7Qh030`<00I6AT09BDU06=SH`28R8P0
:b/[02LW9`0k>c/0Fe]K07YjNP2@T900WIfM0<k>cP2g]kL0WYjN08J6QP2o_kl07AdM0`0E5AD201LG
5`0H01DE5@0G5aL05QHF01TI6@1QHF40S8b<0451@@2b/[80][Jf0::RXP2SXj<0_;bl0:NWY`2YZJT0
/k>c0:^[Z`37alL0Lg=c04i>CP1IFET0LG5a06m_K`1VIVH0EeMG0_ooool0000G06YZJP2JVYX0DE5A
04A4A013@d<0R8R804I6AP15ADD0WYjN07alO00U9BD0I6AT06a/K00e=CD0;2`/05mOG`0k>c/0B4Q8
04I6AP1IFET0NGUi04=3@`1YJFT00P1:BTX0K`1hN7P0:BTY03`l?02<S8`0KVi^05YJFP1FEUH0HF5Q
03De=@16ATH0K6a/04=3@`1DE5@0EeMG038b<P0/;2`0GemO04Y:BP0];Bd0V9RH04Q8B01;Bd/0?Cdm
04];B`0b<S80<C4a07YjNP1BDU80=CDe04m?C`1@D500>c/k04Q8B01@D500=CDe06ATI01ZJVX0GemO
03<c<`16ATH0RXZ:055AD@0h>3P0J6QX04E5A@0d=3@0BTY:05iNGP0_;bl08B4Q07inOP1FEUH0K6a/
09BDU025QHD0?Cdm09ZJVP1fMWH0EeMG03Xj>P1_Kfl0:BTY05mOG`1DE5@0C4a<0;6a/@2FUYH0KFe]
02<S8`31`L40G5aL06QXJ02j^[X0XJ6Q05iNGP12@T80XZ:R06IVIP0Y:BT0OWin07=cL`0b<S80C4a<
06MWI`2:RXX0QhN703Xj>P1mOGd0F5QH04A4A02;Rh/0GUiN03Xj>P1/K6`0Bd];0:6QX@1bLW80JFUY
05mOG`1UIFD0@d=308:2PP1gMgL0DU9B079bLP1KFe/0CDe=065QH@1:BTX0EeMG07inOP0203lo?`1;
06IVIP1]KFd0HF5Q07EeM@1:BTX0NWYj05IFEP1dM7@0PH6105MGE`1@D500IVIV06=SH`2@T900Cdm?
04a<C01RHV80?3`l05YJFP2i^KT0[jn_07alO02YZJT0@41007QhN02c/k<0OWin03hn?P1GEeL0WinO
05eMG@18B4P0MGEe09>CT`15ADD0OGem05iNGP1BDU80IFEU07=cL`1ADE40PH61071`L01IFET0PX:2
09FEU@1aLG40H61P0:2PX02c/k<0MWIf0861P@2IVIT0Rh^;02XZ:P0o?cl0O7al07IfMP0o?cl0TY:B
0:^[Z`15ADD0EEEE05aLG029RHT0CTi>07moO`10@400Bd];07=cL`0o?cl0F5QH05]KF`0j>SX0L71`
0080CDe=0:`0JFUY07MgM`0[:b/0FEUI09^KV`1aLG40=SHf08N7Q`0n?Sh0C4a<08J6QP1mOGd0Bd];
08n?S`2h^;P0LW9b06QXJ03=cLd0`<3006YZJP1<C4`0[:b/0:BTY02][Jd0QhN703Xj>P1_Kfl0MWIf
071`L023Ph<0IfMW038b<P1HF5P0T92@06i^KP1<C4`0HF5Q08F5Q@0W9bL0;Rh^09JFUP22PX80Kfm_
04A4A01JFUX0QHF502PX:00j>SX0LW9b07IfMP14A4@0KFe]05aLG00W9bL0GemO096AT@2CTi<0OWin
0<C4a02XZ:P0DU9B08Z:RP2HV9P0UYJF02l_;`18B4P0Hf=S08>3P`1CDe<0];Bd079bLP17AdL0;Bd]
03Ph>02GUiL0@D5102LW9`1HF5P0P82006IVIP1BDU80KFe]05iNGP0W9bL0HF5Q04m?C`0O7al0Jf][
06IVIP0e=CD0YJFU06m_K`19BDT0][Jf0820P01PH600>CTi06YZJP1jNWX0Ogmo038b<P0/;2`0P820
09JFUP28R8P0JVYZ03Hf=P0^;Rh0;2`/05YJFP2NWYh0cLg=07emO@0M7Ad05ADE01@D500A4A403`l?
010@401MGEd0/[:b09^KV`1GEeL0GEeM07YjNP0n?Sh0HV9R06=SH`0G5aL05ADE01<C4`0K6a/05aLG
010@400a<C408b<S01/K6`1YJFT0Kfm_08n?S`0a<C404A4A00h>3P0C4a<0DU9B0;>c/`14A4@092@T
07]kN`0`<300410@01<C4`0@41005aLG01dM7@0n?Sh0GemO07AdM02EUID0R8R80;^k^`3Hf=P0clo?
0;fm_@37alL0a/K60<k>cP2KVi/0BTY:06UYJ@0B4Q802PX:0P0=3@d01@0@4100:2PX04m?C`1OGel0
?Shn00808b<S00T0=cLg0:NWY`1nOWh0TY:B05EEE@0C4a<051@D02TY:@0e=CD00`0>3Ph04P0@4100
4A4A018B4P0G5aL04Q8B01<C4`0Z:RX0OGem0::RXP27QhL0Jf][03`l?00P8200410@00h>3P0D51@0
4A4A01<C4`805ADE00`04a<C01/K6`0M7Ad05aLG02d];@26QXH0c<c<0>;RhP3Ng]h0d=3@08^;R`0T
92@201`L700M02PX:00J6QX06QXJ01hN7P1CDe<0;Bd]01HF5P19BDT0JVYZ04a<C01SHf<08R8R01dM
7@0m?Cd0KFe]02`/;00T92@08B4Q04i>CP3:b/X0a<C405MGE`0n?Sh0G5aL03hn?P0i>CT0Hf=S0;Fe
]@1XJ6P00P0_;bl03P17AdL0TI6A09JFUP26QXH0>CTi04M7A`1aLG40K6a/079bLP2IVIT0LG5a055A
D@1MGEd0H61P0P2EUID08P1/K6`0SHf=05]KF`1LG5`0FEUI08j>SP0X:2P06a/K01hN7P15ADD0ZJVY
069RHP0h>3P0L71`02d];@1:BTX09RHV0410@00h>3P0TI6A0::RXP3:b/X0AdM702PX:00Y:BT0<C4a
03Ti>@0g=cL0QHF5061PH01cLg<0De=C04M7A`1:BTX201DE5@1G02HV9P2FUYH0a/K60=WIf@2XZ:P0
V9RH0:f][@1WIfL0:b/[01hN7P0I6AT0CTi>051@D00];Bd0:b/[028R8P0L71`07AdM01`L700T92@0
EeMG061PH02WYjL0Shn?0:FUY@3IfMT0eMGE0;Ng]`3<c<`0NGUi02/[:`0V9RH09BDU020P800U9BD0
;Rh^03lo?`1OGel0KVi^03@d=01@D500Lg=c08F5Q@2RXZ80^k^k08F5Q@1KFe/0BTY:06QXJ03@d=00
?Cdm01LG5`0O7al0GEeM07alO01HF5P0MgMg0<k>cP2d];@0Z:RX08F5Q@1aLG40bLW909jNWP0c<c<0
6ATI01LG5`0K6a/07QhN02PX:02ATI40cLg=0;jn_P2_[jl0W9bL08Z:RP26QXH0T92@0=CDe037alL0
W9bL07]kN`2?Shl0EEEE02TY:@0V9RH07alO00@05ADE01H06QXJ04i>CP1nOWh0:RXZ079bLP32`/80
W9bL09NGU`2d];@0/[:b0:BTY02a/K40];Bd0=OGe`2NWYh0>SXj04=3@`1;Bd/0G5aL09nOW`2QXJ40
YZJV0_ooool0000M061PH02ATI40D51@05]KF`17AdL0Jf][04Y:BP1YJFT0/K6a08B4Q00^;Rh0M7Ad
08R8R01:BTX0CDe=05YJFP0X:2P0@41003/k>`1LG5`0GEeM03hn?P1bLW80ADE505IFEP1`L700:2PX
03lo?`1VIVH00P1?Cdl0201]KFd0JFUY03dm?@1SHf<0P820055AD@1DE5@0L71`0P0j>SX0501OGel0
CTi>038b<P2LW9`0?clo03Xj>P0d=3@0@D5101hN7P0n?Sh0OGem04a<C00i>CT0EUIF03Ph>00Z:RX0
ATI604Y:BP0^;Rh0L71`0P1[Jf/0_00o?cl0CDe=0861P@0m?Cd0>3Ph06YZJP1@D500EUIF04a<C01W
IfL0?Cdm02@T901WIfL0Kfm_079bLP26QXH0Ogmo03Ph>02OWil0Ng]k065QH@18B4P0@d=303Ph>01d
M7@0FUYJ04i>CP2_[jl0YZJV02PX:00k>c/0alO7079bLP0n?Sh0X:2P08j>SP0a<C40>3Ph0:FUY@1Z
JVX0=CDe07moO`27QhL0<c<c02DU9@0_;bl0HF5Q05mOG`0W9bL0JVYZ03lo?`0P8200EeMG04i>CP0k
>c/0GemO02<S8`1gMgL0IfMW06e]K@1WIfL0=cLg03Hf=P1ZJVX0OWin05QHF01XJ6P0<C4a065QH@1n
OWh0De=C06IVIP1WIfL0?Shn06YZJP2<S8`0J6QX06IVIP1TI6@0B4Q809NGU`1SHf<0O7al05]KF`0h
>3P0MGEe075aL@1BDU80UYJF02d];@1EEED0Rh^;0410@00g=cL0TY:B08Z:RP1TI6@0QHF504Y:BP24
Q8@0]KFe04i>CP0i>CT0EUIF07UiN@1JFUX0A4A406UYJ@1TI6@0ATI608f=S@1WIfL0GUiN06][J`1J
FUX0IVIV0;Rh^02EUID0GEeM09^KV`2MWId0>3Ph03hn?P1fMWH0VYZJ05QHF01nOWh0XZ:R09:BTP1F
EUH0B4Q8092@T01PH600Cdm?0:2PX02c/k<0G5aL08j>SP1PH600J6QX06ATI020P800E5AD024Q8@1E
EED0?clo061PH01ADE40;Bd]05=CD`1XJ6P0Jf][05=CD`1<C4`0=CDe07alO02RXZ80CTi>051@D02R
XZ80BDU904Q8B01IFET0@D5103lo?`2KVi/0[Jf]05ADE016ATH0IFEU08V9R@20P800HV9R0=OGe`3K
fm/0_Kfm08:2PP13@d<0T92@08J6QP1`L700U9BD03<c<`0W9bL0EUIF08^;R`1SHf<0FEUI0P2>SXh0
C`1LG5`0:2PX08F5Q@1OGel0=3@d04A4A02@T900M7Ad07QhN011@D40I6AT07alO018B4P0I6AT075a
L@1IFET0KFe]05eMG@27QhL0MGEe0;Fe]@2PX:00?3`l07YjNP2;Rh/0KVi^02l_;`1bLW80[jn_08J6
QP19BDT0XJ6Q08R8R00W9bL0?clo08>3P`2VYZH0EUIF02l_;`1KFe/0NWYj03/k>`1WIfL0ZJVY07Mg
M`0_;bl0GemO05UIF@0V9RH0L71`05=CD`1@D500`/;20861P@1NGUh0dM7A09FEU@1GEeL0ATI607mo
O`1kNg/0Jf][034a<@19BDT0Zj^[0:2PX02o_kl0RXZ:04Q8B00g=cL0<c<c08>3P`1nOWh0/k>c03dm
?@0E5AD04A4A018B4P0>3Ph00P0=3@d0300C4a<0V9RH08B4Q01gMgL0E5AD096AT@1gMgL0FEUI06i^
KP0H61P06ATI01@D50<05ADE01P0;2`/06MWI`0R8R80?Cdm09BDU035aLD0GemO01/K6`0@41003Ph>
02l_;`2KVi/0_[jn09FEU@22PX80BTY:05iNGP1RHV80M7Ad07UiN@26QXH0OWin06ATI018B4P203`l
?00:0<71`@3Jf]X0Rh^;03dm?@2;Rh/0_kno0=?Cd`2EUID0L71`03De=@@03@d=01803Ph>00d=3@0=
3@d05QHF03hn?P1QHF40F5QH04A4A025QHD0Q8B4096AT@2=SHd0Fe]K02@T900G5aL0=cLg01HF5P0=
3@d300h>3P0<00d=3@0C4a<05ADE01DE5@0j>SX0Hf=S0:f][@31`L40YZJV03Lg=`0];Bd05aLG0P0I
6AT0QP0G5aL04a<C018B4P0>3Ph0410@01<C4`0M7Ad05ADE059BDP39bLT0g=cL0<[:bP2PX:00ZJVY
06i^KP17AdL0Cdm?04Y:BP1BDU80Cdm?051@D01_Kfl0FUYJ01`L700G5aL07alO04e=C@1IFET0JFUY
04E5A@0M7Ad0=cLg05UIF@0Y:BT092@T020P801GEeL0I6AT0:n_[`2/[:`0B4Q805iNGP1oOgl0WIfM
0:n_[`2IVIT0RXZ:07AdM01ADE40HF5Q0:b/[021PH40];Bd05EEE@1^KVh0ATI60410@011@D40<c<c
04m?C`1XJ6P0FUYJ059BDP1FEUH0Ph>30=kNgP3=cLd0BTY:061PH02KVi/0BDU901XJ6P0H61P071`L
03lo?`37alL0_[jn0:BTY02VYZH08b<S01/K6`0W9bL0?Shn02d];@1HF5P0YJFU0=CDe01/K6`0;bl_
03De=@18B4P0IFEU07alO02OWil0N7Qh06m_K`1YJFT0?clo061PH00N7Qh0ADE50820P01BDU80Fe]K
0<71`@2:RXX0ADE5061PH02NWYh0Jf][02@T900K6a/0@T9205mOG`0e=CD09bLW02XZ:P0W9bL0;Bd]
03Lg=`19BDT0Ph>307alO02`/;00d=3@0;bl_031`L40fm_K0<O7a`3De=@0N7Qh038b<P0M7Ad08B4Q
0P0[:b/07P0S8b<0:b/[0492@P1eMGD0OGem061PH039bLT0_[jn09NGU`1gMgL0BTY:04e=C@1cLg<0
emOG0>7Qh@2@T900=SHf05eMG@29RHT0Zj^[09RHV013@d<0e=CD0<C4a03>c/h0][Jf0<S8b01MGEd0
9RHV01PH60805ADE00P05aLG01XJ6P0S8b<0I6AT0;Vi^@1GEeL0<C4a02HV9P80820P00@0;Rh^0;Zj
^P1_Kfl0GEeM0P1VIVH07P2CTi<0HV9R03dm?@0];Bd09bLW02@T900I6AT0:RXZ069RHP1mOGd0C4a<
059BDP2MWId0SHf=0;Rh^01eMGD0bLW908:2PP1`L700ZJVY07alO02f][H0[jn_04i>CP1hN7P0Vi^K
09nOW`2LW9`0Q8B406e]K@;ooooo0000301SHf<0Kfm_055AD@1FEUH0B4Q807AdM00j>SX0>CTi07Qh
N01PH600;2`/06IVIP80;bl_0?l0AdM705UIF@0Y:BT0<S8b02`/;01PH600G5aL03<c<`1EEED0;Rh^
06EUI@1`L700<30`0451@@20P800<c<c03Hf=P1/K6`0L71`0451@@1TI6@0Fe]K03<c<`1KFe/0K6a/
03@d=00f=SH0Hf=S01/K6`0T92@0OGem04A4A00e=CD0;Bd]05YJFP0c<c<0;2`/07alO00/;2`0?Cdm
07]kN`1FEUH0=CDe04U9B@0a<C40:b/[06m_K`23Ph<0K6a/04A4A01;Bd/0Ng]k02TY:@1GEeL0SXj>
05YJFP1QHF40@D5104m?C`0b<S80FUYJ0:2PX01jNWX0LG5a06e]K@1>CTh0@T9208V9R@1jNWX0CDe=
04];B`0X:2P05ADE04a<C01JFUX0BTY:0<C4a01lO7`09bLW01LG5`1fMWH0DE5A03@d=02MWId0WYjN
01XJ6P0P8200PH6106IVIP0f=SH0NWYj08N7Q`0h>3P0>c/k0410@01jNWX0I6AT02LW9`1UIFD0ADE5
02TY:@1^KVh0?Shn03`l?01]KFd0B4Q808B4Q01NGUh0Fe]K05YJFP1_Kfl0ADE507IfMP2=SHd0HV9R
075aL@1BDU80ATI607emO@1=CDd0HF5Q08F5Q@0l?3`0@D5106][J`1UIFD0HV9R05iNGP17AdL0NGUi
051@D01mOGd0OWin05ADE02BTY80PX:205QHF02=SHd0BTY:04=3@`1VIVH0D51@03dm?@2;Rh/0MWIf
0410@02>SXh0@T9208b<S02WYjL0MgMg04Q8B01OGel0SHf=05eMG@0k>c/0HV9R08F5Q@0o?cl0G5aL
03Lg=`1MGEd0J6QX04a<C015ADD0MgMg08R8R01MGEd0XZ:R09JFUP1`L700MgMg09RHV02LW9`0Fe]K
08b<S031`L40ZZZZ06=SH`1?Cdl0XJ6Q0410@00i>CT0NGUi0:JVYP1KFe/0UIFE06UYJ@2FUYH0?clo
069RHP1?Cdl0;Bd]06][J`19BDT0VYZJ07alO00n?Sh0Fe]K04];B`0X:2P0Cdm?08J6QP1RHV80UYJF
0:ZZZP1@D500:b/[06i^KP1IFET0Bd];05aLG00i>CT08b<S07UiN@2TY:@0GEeM05mOG`2YZJT0PX:2
04a<C00Q8B40Jf][0861P@2;Rh/0Fe]K02XZ:P1VIVH0B4Q806i^KP2d];@0Jf][02d];@1MGEd0Ph>3
038b<P0[:b/0AdM705]KF`0l?3`0:b/[06ATI00h>3P0C4a<030`<00k>c/0D51@05=CD`0n?Sh0LG5a
05ADE00m?Cd0UiNG09^KV`1^KVh003`0QHF506QXJ01fMWH0MGEe0=CDe02h^;P0Jf][08b<S02EUID0
IFEU01lO7`10@400MWIf09:BTP1BDU80HF5Q06UYJ@0];Bd08R8R02l_;`1aLG40EUIF02XZ:P1LG5`0
QXJ603lo?`0n?Sh0EUIF04Q8B00[:b/0S8b<07EeM@0a<C40N7Qh04a<C00f=SH0UYJF05mOG`1hN7P0
e]KF0820P00W9bL0@41009jNWP2l_;`0Kfm_02PX:00N7Qh0De=C08>3P`2j^[X0CTi>04I6AP1bLW80
Ti>C09JFUP1cLg<0VIVI02LW9`0E5AD201<C4`0e010@400?3`l03@d=010@401hN7P0>3Ph020P8013
@d<0M7Ad0<c<c026QXH0MgMg03@d=00L71`05ADE01<C4`0@410051@D01DE5@1CDe<0VYZJ09FEU@2K
Vi/0UIFE07YjNP1^KVh0LG5a06e]K@1mOGd0W9bL0=cLg03EeMD0cLg=0;Zj^P2XZ:P0SHf=07emO@1/
K6`0IVIV04U9B@0f=SH0?Cdm05]KF`2TY:@0d=3@0<71`@0e=CD0IFEU0820P01hN7P0a/K60<30`01o
Ogl00P0@4100100?3`l03Ph>00h>3P0@410400h>3P0@014A4@0m?Cd0UiNG0:RXZ02?Shl0Z:RX059B
DP1SHf<0MWIf04M7A`0o?cl0A4A401TI6@0>3Ph03@d=010@40803Ph>04H0410@05]KF`2>SXh0TI6A
0=GEe@3IfMT0YJFU07]kN`1@D500<S8b04=3@`0n?Sh0>c/k034a<@0S8b<061PH01@D500>3Ph04a<C
030`<02UYJD0][Jf0<G5a@1dM7@0a<C40:f][@2;Rh/0RHV90861P@1/K6`0Jf][06a/K00k>c/0;bl_
04e=C@0V9RH05ADE01TI6@0Z:RX0GEeM06i^KP1IFET09RHV03hn?P1;Bd/0<30`034a<@0j>SX0J6QX
0492@P1GEeL0f][J0=cLg034a<@0Y:BT08Z:RP1OGel0CDe=04];B`1OGel0SXj>0:FUY@2TY:@0QHF5
08R8R022PX80?clo03dm?@0i>CT0:2PX0P0G5aL02P0g=cL0EUIF05mOG`15ADD0?clo0::RXP2o_kl0
Q8B407YjNP1YJFT201`L701L01PH600P8200H61P05=CD`1:BTX0KVi^0<;2`P1DE5@08B4Q02d];@0d
=3@09bLW03/k>`1mOGd0a<C40;Ng]`1GEeL0E5AD0451@@0`<300<S8b04E5A@1mOGd092@T055AD@13
@d<0HF5Q075aL@26QXH0ADE504M7A`0N7Qh0LG5a08Z:RP0l?3`0?Shn059BDP2KVi/0LW9b01lO7`0`
<300?Cdm06i^KP0];Bd08R8R02/[:`0d=3@0<30`02TY:@15ADD0NWYj0::RXP2HV9P0RHV90<71`@2d
];@0Shn?06YZJP2][Jd0J6QX02TY:@0Q8B40820P01dM7@0Q8B40:b/[03@d=01PH600Y:BT0<_;b`2I
VIT0M7Ad09RHV02PX:00R8R809BDU02VYZH0dm?C06UYJ@1GEeL0PX:20<c<c02FUYH0][Jf0:b/[00d
=3@0/k>c0<O7a`3GemL0^k^k06=SH`0G5aL201HF5P806ATI02h05aLG01dM7@0X:2P0SXj>06UYJ@0G
5aL05ADE01PH600K6a/07AdM03Lg=`2EUID0De=C05ADE01<C4`0Q8B405iNGP1^KVh0>CTi06a/K01k
Ng/0RHV9075aL@1LG5`0C4a<05iNGP19BDT0EeMG051@D00n?Sh0Rh^;05aLG030`<00KVi^04U9B@1m
OGd0X:2P0:BTY02a/K40YZJV05aLG00`<300<c<c03/k>`2VYZH0F5QH0_ooool0001Z069RHP1ZJVX0
BDU904m?C`13@d<0UIFE04a<C013@d<0YjNW08Z:RP0Y:BT0MgMg08n?S`0n?Sh0;bl_065QH@0[:b/0
<c<c03@d=00h>3P0GEeM05IFEP1CDe<08b<S04M7A`1QHF40;bl_03/k>`1bLW80I6AT04=3@`1?Cdl0
G5aL02l_;`1OGel0KFe]03De=@19BDT0EEEE03De=@0j>SX0D51@04E5A@0a<C40Ng]k02d];@14A4@0
<C4a04];B`0];Bd0:b/[07]kN`13@d<0?3`l04Y:BP0d=3@0;Rh^0451@@0h>3P09RHV05mOG`1CDe<0
IFEU0451@@1>CTh0S8b<03/k>`0];Bd0J6QX05ADE01cLg<0A4A404a<C00V9RH09BDU061PH01ADE40
GEeM06=SH`1ZJVX0=3@d08Z:RP2@T900Fe]K05MGE`12@T80820P06=SH`15ADD0?3`l0:RXZ01UIFD0
@d=302@T902a/K40BTY:04M7A`2WYjL0TI6A02`/;00];Bd0WIfM05eMG@0_;bl0LW9b08^;R`80@d=3
0200A4A408F5Q@1aLG40<S8b06i^KP1OGel0=CDe06i^KP16ATH0@T9206YZJP1ADE40Ti>C05]KF`1>
CTh0IVIV08:2PP1>CTh0R8R809>CT`1[Jf/0Lg=c06QXJ01BDU80QXJ604Q8B01CDe<0QXJ604Y:BP1>
CTh0Kfm_06YZJP80G5aL07H0Cdm?096AT@1:BTX0MgMg07moO`1?Cdl0Hf=S065QH@1PH600Shn?04m?
C`1MGEd0IVIV03lo?`0d=3@0RXZ:07EeM@0g=cL0Ogmo04U9B@2MWId0[Jf]06YZJP1<C4`0K6a/09bL
W01ADE40?Cdm07YjNP2@T900ATI6061PH00h>3P0IVIV06MWI`1jNWX0IVIV0861P@23Ph<0J6QX0;:b
/P2OWil0R8R809NGU`2XZ:P0YJFU03dm?@1CDe<0Q8B408Z:RP1FEUH0LG5a0;Jf]P1PH600AdM70:NW
Y`2LW9`0@41007inOP2?Shl0SXj>04U9B@1UIFD0I6AT02l_;`1PH6009bLW059BDP1kNg/0?3`l06EU
I@1NGUh0Bd];03Ti>@1OGel0Bd];09NGU`2EUID0KFe]03Ti>@2BTY80FUYJ04a<C01XJ6P0I6AT04Y:
BP1[Jf/0RHV905mOG`1EEED0/k>c07EeM@12@T80=SHf0:2PX02RXZ80Jf][04i>CP0/;2`0Jf][03hn
?P14A4@0GUiN05IFEP0n?Sh0JFUY08Z:RP1>CTh0<C4a05=CD`1BDU809RHV04U9B@2CTi<0CDe=06e]
K@0g=cL0B4Q80P1JFUX0AP1GEeL0S8b<05]KF`0W9bL0ADE5059BDP16ATH0MgMg06ATI00l?3`0@D51
07UiN@27QhL0Fe]K09JFUP2/[:`0OGem02l_;`1:BTX0QXJ6075aL@1>CTh0G5aL06e]K@0m?Cd0:BTY
03dm?@29RHT0C4a<02`/;01mOGd0X:2P05mOG`17AdL0GemO0451@@0R8R80OWin04a<C00^;Rh0SXj>
06MWI`11@D40ZZZZ0492@P0c<c<0Vi^K09:BTP1FEUH0=cLg05iNGP1KFe/0JVYZ03/k>`0W9bL0JVYZ
09:BTP2RXZ80UYJF09ZJVP2QXJ40]kNg07YjNP2VYZH0Ti>C01lO7`0F5QH05ADE01@D500>3Ph2010@
400g01<C4`1RHV80<S8b01LG5`0H61P0?clo0=7Ad@2n_[h0Q8B407=cL`1SHf<06a/K01lO7`0a<C40
>c/k06e]K@20P800RHV90861P@1oOgl0J6QX05IFEP18B4P0BDU90451@@2GUiL0clo?0=SHf02m_Kd0
RHV904a<C013@d<0<S8b02`/;00Q8B40?Shn06=SH`1[Jf/0S8b<06][J`0/;2`0De=C0;no_`1:BTX0
_;bl09NGU`1JFUX0[:b/0;^k^`0n?Sh03@d=014A4@0?3`l03Ph>00l?3`0200h>3P1W00l?3`0>3Ph0
3Ph>00h>3P0@41005aLG05MGE`29RHT0SXj>05aLG025QHD0KVi^07alO02DU9@0RXZ:04A4A00N7Qh0
6QXJ01LG5`0E5AD05aLG01DE5@19BDT0[Zj^0<o?c`30`<00jNWY0=?Cd`37alL0aLG50:RXZ01iNGT0
GEeM05MGE`1EEED0D51@055AD@1@D500=3@d03Hf=P1aLG40FEUI034a<@1fMWH0[jn_0:FUY@1nOWh0
@T9203lo?`0l?3`0>CTi03hn?P0o?cl0GemO059BDP0];Bd0BDU901lO7`0G5aL06QXJ038b<P1/K6`0
E5AD05QHF01SHf<0MGEe06MWI`1@D500UYJF09jNWP0n?Sh0JFUY0=;BdP1mOGd0EEEE07MgM`10@400
?3`l03hn?P1?Cdl0FUYJ07inOP3IfMT0_;bl0:BTY02UYJD0Zj^[0492@P0c<c<09BDU01/K6`0H61P0
5ADE01/K6`0V9RH0ATI605aLG01]KFd0M7Ad0<;2`P2?Shl0Q8B402TY:@0201XJ6P0B02d];@1;Bd/0
EeMG06IVIP1>CTh0>CTi04];B`16ATH0EeMG02PX:00f=SH0?3`l05=CD`26QXH0TI6A0<k>cP0[:b/0
71`L0P0J6QX02P0O7al09BDU05mOG`0^;Rh0?Cdm05EEE@1mOGd0VIVI04Q8B00Y:BT201LG5`0g03dm
?@2c/k<0CDe=04e=C@1OGel0UiNG08:2PP2DU9@0?clo02h^;P18B4P071`L01LG5`0E5AD05QHF01XJ
6P0I6AT0:BTY07moO`2RXZ80KFe]07MgM`2k^k/0FUYJ07]kN`1bLW80R8R80;Rh^01XJ6P0:BTY02<S
8`0O7al07AdM020P800`<300FUYJ0;Bd]01VIVH0H61P0<O7a`2i^KT0W9bL06UYJ@1nOWh0d=3@059B
DP0Q8B409bLW02h^;P14A4@0TY:B0<W9b@2WYjL0IVIV0=GEe@020=gMg@040<;2`P1CDe<05ADE01HF
5P805aLG0P0I6AT06`0L71`0<30`09>CT`0o?cl05aLG01/K6`0I6AT06a/K02LW9`1LG5`0OGem05EE
E@1;Bd/0DE5A07=cL`1PH600@41005ADE01@D500][Jf07UiN@1[Jf/09BDU061PH012@T80<30`034a
<@02030`<00@05aLG01KFe/0OGem071`L012@T80JFUY03`l?00m?Cd0PX:207YjNP0T92@071`L02TY
:@0^;Rh0Lg=c02h^;P;ooooo0000U01YJFT0VYZJ055AD@1GEeL0@d=309bLW01=CDd0BDU90:FUY@2;
Rh/0;Rh^07UiN@2@T900@410030`<01XJ6P09bLW03Ti>@14A4@0FUYJ07EeM@1=CDd0I6AT04I6AP1`
L700MgMg03/k>`11@D40NGUi07MgM`1CDe<0IfMW06ATI00k>c/0GemO07moO`19BDT0GEeM05]KF`0e
=CD0Bd];05iNGP1@D500>c/k08n?S`0m?Cd0@D5103dm?@1ADE40;bl_02d];@1eMGD0Cdm?03hn?P1K
Fe/0>3Ph02h^;P0c<c<0:b/[038b<P1aLG40DU9B06MWI`0h>3P0DU9B09JFUP1>CTh0@D5107IfMP1N
GUh0NWYj04A4A01MGEd0CTi>034a<@1mOGd0EEEE04i>CP1YJFT0Ogmo0451@@2OWil0QXJ605UIF@1m
OGd0IfMW03<c<`1/K6`0@D5103hn?P2c/k<0L71`059BDP0Q8B40YZJV03dm?@1=CDd0W9bL08B4Q01;
Bd/0?Cdm0:BTY01aLG40?clo0820P02[Zj/0?3`l04U9B@1?Cdl0Ogmo04U9B@0a<C40RXZ:07EeM@0l
?3`0LW9b04U9B@1TI6@0Shn?05ADE02<S8`0Hf=S05iNGP1iNGT0QhN7055AD@1kNg/0T92@06i^KP20
P800Hf=S06QXJ01jNWX0C4a<07IfMP2NWYh0Cdm?051@D01gMgL0DE5A07=cL`1aLG40EUIF092@T015
ADD0U9BD08n?S`1@D50206EUI@2[04M7A`1mOGd0D51@07AdM01UIFD0<S8b04Y:BP2LW9`0KVi^03Xj
>P1kNg/0;bl_05EEE@2<S8`0KVi^0492@P1TI6@0Shn?038b<P1JFUX0W9bL09VIV@14A4@0N7Qh02PX
:010@400G5aL06YZJP1TI6@0Shn?07UiN@1=CDd0UiNG0:2PX01iNGT0P8200;Zj^P2b/[80M7Ad06UY
J@2QXJ40QhN703/k>`1GEeL0UiNG07=cL`1=CDd0^KVi08^;R`0a<C40GemO05EEE@1eMGD0@T92079b
LP1?Cdl0DU9B07UiN@0k>c/0KVi^075aL@0h>3P0Q8B405mOG`1>CTh0?clo06UYJ@0W9bL0Jf][096A
T@1JFUX0<c<c08Z:RP18B4P0GemO096AT@1PH600?clo071`L02RXZ80L71`05aLG03De=@0c/k>06AT
I016ATH0[jn_0;Rh^02NWYh0GemO04E5A@2DU9@0JVYZ065QH@1bLW80@41003Xj>P1oOgl0T92@06EU
I@0g=cL0DE5A06MWI`0W9bL09RHV05eMG@1EEED0I6AT03hn?P12@T80JFUY02/[:`16ATH0Rh^;06][
J`0i>CT0FEUI05MGE`0g=cL0RXZ:07YjNP1GEeL0J6QX08V9R@2ATI40EUIF0;:b/P3Cdm<0UIFE030`
<01<C4`0Q8B403dm?@0d=3@0AdM704U9B@0];Bd09bLW03Ti>@1gMgL0:b/[01hN7P1KFe/0Ng]k04M7
A`1EEED0Zj^[08b<S00];Bd0OGem04M7A`0G5aL0CTi>06=SH`10@400WinO04E5A@0o?cl0/[:b06QX
J01>CTh0?Shn08N7Q`21PH40JVYZ02DU9@1>CTh0V9RH0:2PX02;Rh/0F5QH0080FEUI00P0JVYZ0;Fe
]@3@d=00VYZJ03Ti>@1FEUH0<30`02d];@80<S8b03@08b<S028R8P1ZJVX0@T9205EEE@1eMGD0UIFE
09VIV@2m_Kd0bLW903Hf=P0`<300^KVi0;fm_@2g]kL0SXj>05ADE013@d<0PH610:n_[`1_Kfl0P820
034a<@0Z:RX0<C4a05]KF`1LG5`0TI6A0;Rh^02JVYX0SHf=0410@00X:2P06QXJ01dM7@0`<300R8R8
08n?S`1RHV80:2PX01TI6@0/;2`0F5QH0:VYZ@2TY:@0[Jf]0:2PX028R8P0X:2P0:n_[`1IFET03Ph>
0P0=3@d0100>3Ph03@d=00d=3@0=3@d300h>3P0L018B4P0A4A405ADE02PX:020P800:2PX0410@02R
XZ80]KFe0:NWY`2JVYX0W9bL09FEU@1/K6`0EEEE02`/;00O7al0:BTY04M7A`1lO7`0[:b/0:VYZ@31
`L40c/k>0861P@1/K6`0b/[:04U9B@805ADE02T05aLG018B4P0>3Ph0410@01HF5P0a<C40LG5a08:2
PP0Q8B405QHF065QH@2ATI40];Bd09BDU01?Cdl0>SXj02h^;P0U9BD0<30`03`l?01KFe/0O7al05=C
D`0X:2P0?Shn024Q8@0J6QX071`L0492@P2NWYh0`L7109RHV02WYjL0ZJVY08N7Q`2o_kl0WinO05QH
F030`<00NGUi01`L7002020P800B01PH600F5QH07AdM01hN7P0P82008b<S08F5Q@35aLD0ZZZZ059B
DP31`L40GUiN020P800J6QX06a/K01XJ6P0L71`07AdM0P0L71`03@0];Bd0CDe=07YjNP3GemL0^k^k
09jNWP1@D5007AdM03Ph>01LG5`0Ph>304U9B@0J6QX00P0E5AD05`0G5aL0A4A402LW9`1GEeL0FUYJ
06e]K@1FEUH0?3`l0:JVYP2n_[h0HV9R01hN7P0L71`06ATI01hN7P0M7Ad0=CDe05YJFP0g=cL0QHF5
09bLW01ZJVX09bLW00805ADE02h09RHV092@T03Fe]H0e]KF09^KV`1]KFd0FUYJ07AdM02OWil0YjNW
04A4A00n?Sh07QhN01LG5`0F5QH05aLG01TI6@0Q8B40LG5a0:VYZ@2HV9P0GEeM07inOP2:RXX0CDe=
065QH@2c/k<0MGEe0:VYZ@1lO7`0HF5Q02XZ:P0N7Qh07alO02<S8`0b<S80J6QX0:6QX@1MGEd0K6a/
09FEU@21PH40[jn_0:6QX@31`L40MGEe0P0N7Qh07`0U9BD0:RXZ02h^;P1=CDd0MgMg0;^k^`3Fe]H0
ZJVY0>3Ph03Jf]X0]kNg08F5Q@0T92@05ADE01`L700J6QX05ADE01`L700K6a/0>c/k08Z:RP0`<300
71`L01/K6`0M7Ad0<30`04Q8B02?Shl0NGUi05iNGP1ADE400P1UIFD07P1TI6@0GUiN04U9B@1YJFT0
BDU903@d=00Y:BT0?clo07emO@0e=CD0?3`l038b<P0U9BD0<C4a08>3P`1eMGD0Fe]K06UYJ@1HF5P0
LG5a03Ph>00Z:RX0CDe=08F5Q@0g=cL07QhN02d];@1DE5@0ZZZZ03Xj>P;ooooo0000o`1XJ6P0W9bL
04i>CP1?Cdl0CDe=08B4Q018B4P0AdM707AdM00T92@0;bl_07IfMP1nOWh0>3Ph02`/;01ZJVX09bLW
03Xj>P1;Bd/0J6QX06i^KP0k>c/0KFe]04=3@`1gMgL0Lg=c03<c<`1FEUH0Ogmo06m_K`1EEED0M7Ad
069RHP0e=CD0IFEU07=cL`15ADD0HV9R04E5A@0R8R80ATI605aLG01DE5@0?Shn0:^[Z`0R8R80C4a<
03`l?018B4P08b<S0410@01fMWH0CDe=0451@@18B4P0;bl_02DU9@1BDU80@T9203De=@1WIfL0D51@
04A4A00c<c<0JVYZ0:n_[`16ATH0ADE506m_K`0e=CD0IFEU08:2PP1hN7P0CTi>02h^;P1mOGd0BDU9
0492@P1/K6`0MgMg0410@02e]KD0J6QX02/[:`1=CDd0Cdm?02<S8`1dM7@0OGem059BDP2l_;`0MgMg
04i>CP0T92@0]KFe05]KF`0g=cL0Ph>307IfMP0g=cL0A4A40<S8b01`L7007AdM05QHF01/K6`0CDe=
051@D021PH40TY:B05iNGP0];Bd0Jf][04Y:BP0h>3P0P82003Xj>P0i>CT0Hf=S04e=C@2[Zj/0ATI6
04U9B@1WIfL0EUIF065QH@2d];@0O7al03lo?`1UIFD0CTi>09>CT`2?Shl0=CDe04E5A@1OGel0@410
07]kN`2NWYh0AdM704Q8B01@D500CDe=09ZJVP1@D500HV9R055AD@0W9bL0RHV907alO01=CDd0MgMg
02l_;`1OGel0X:2P04A4A00`<300LW9b061PH01;Bd/0OGem03hn?P1ZJVX0W9bL05YJFP17AdL0Ogmo
0:JVYP1LG5`0<c<c06QXJ01_Kfl0Bd];08B4Q01NGUh0DE5A05eMG@1_Kfl0GUiN0;2`/01cLg<0GUiN
0;:b/P27QhL0<C4a03Ti>@2/[:`0^KVi07MgM`1SHf<0Y:BT0:FUY@1XJ6P0IVIV09FEU@1DE5@0DE5A
0<30`02:RXX0?clo0861P@1YJFT0QhN704A4A01`L700H61P03Ph>020P800B4Q806a/K01LG5`0;Rh^
08R8R01dM7@0EEEE0451@@1FEUH0;Rh^07UiN@1nOWh0EEEE02DU9@1`L700?clo04M7A`1EEED0>3Ph
02d];@1`L700Xj>S06EUI@0n?Sh0Vi^K096AT@29RHT0FEUI0;no_`2XZ:P0];Bd07QhN00V9RH0GUiN
06IVIP1SHf<0PH6105YJFP0e=CD0JFUY09NGU`1^KVh0>c/k04a<C01NGUh0BDU902TY:@0207=cL`0=
06e]K@0c<c<0?3`l07inOP1NGUh0A4A408F5Q@1ZJVX0?clo061PH01?Cdl09BDU05iNGP0207EeM@1c
065QH@2UYJD0WYjN03@d=02<S8`0OGem0820P00^;Rh0B4Q808V9R@1^KVh0E5AD06][J`0m?Cd09bLW
03dm?@1eMGD0YJFU071`L00U9BD0EUIF06UYJ@0A4A40>SXj05MGE`1DE5@09RHV07EeM@1=CDd09BDU
06QXJ01WIfL0@T920:VYZ@1PH600@D510;Zj^P1PH600>c/k03`l?01jNWX0M7Ad069RHP0J6QX08b<S
0492@P1lO7`0TY:B04];B`1IFET0L71`06YZJP36a/H0][Jf0;Fe]@2VYZH0D51@02@T900M7Ad0;bl_
03Ti>@1?Cdl0BTY:09>CT`2;Rh/0JVYZ04U9B@0m?Cd0@T9207emO@1gMgL0SHf=08F5Q@2_[jl0K6a/
05=CD`1HF5P0ATI602`/;00Q8B40=CDe02XZ:P2MWId0NGUi071`L01NGUh0DU9B05UIF@1_Kfl0X:2P
0<[:bP2VYZH0VIVI08R8R017AdL0A4A404Q8B021PH40IfMW04Y:BP1?Cdl0G5aL05QHF016ATH0QHF5
0;bl_01LG5`0ZZZZ09FEU@0l?3`0OGem07AdM00C4a<03@d=00h>3P0300d=3@803Ph>03H04a<C00h>
3P0A4A404a<C010@400M7Ad0LW9b01lO7`0E5AD0820P05ADE02IVIT0b/[:0;Bd]02KVi/0[:b/0;fm
_@2DU9@0BTY:0410@013@d<0DE5A0<;2`P3Cdm<0U9BD08^;R`2SXj<0PH6108b<S023Ph<0EEEE02LW
9`0E5AD04Q8B014A4@0@41003Ph>010@400X:2P0MWIf01XJ6P0I6AT0FUYJ07IfMP2?Shl0FUYJ071`
L01YJFT0EEEE03<c<`0X:2P0;Rh^04m?C`1SHf<205eMG@0602d];@13@d<09bLW01LG5`0`<300RXZ:
0P2SXj<03028R8P0KVi^038b<P1dM7@0PH610;^k^`2OWil0ATI601TI6@0G5aL05ADE01HF5P805ADE
00`06QXJ01`L700U9BD0GUiN0:>SX`1PH600Bd];09^KV`0g=cL071`L01XJ6P0L71`201/K6`0?01`L
700K6a/06QXJ01LG5`0S8b<0Cdm?0:2PX02CTi<0SHf=08Z:RP1aLG40N7Qh07EeM@0e=CD071`L00@0
5ADE00h08B4Q04A4A00m?Cd0OWin059BDP0S8b<0>CTi0;Jf]P3IfMT0c/k>08F5Q@1QHF40C4a<03lo
?`80=CDe03/0_;bl09BDU02e]KD0Lg=c07YjNP0I6AT05ADE030`<02?Shl0N7Qh04e=C@22PX80X:2P
07MgM`19BDT0ADE505iNGP2EUID0[jn_061PH00X:2P05aLG01PH600J6QX09bLW08Z:RP1mOGd0UIFE
09NGU`14A4@0:b/[04];B`1/K6`0Q8B40;fm_@2d];@0WIfM0:f][@1cLg<0IfMW04];B`1OGel0AdM7
04e=C@21PH40S8b<05mOG`2XZ:P0NWYj06i^KP1EEED0TY:B0;2`/014A4@0:BTY020P800S8b<0;2`/
04Q8B00207=cL`0<0::RXP39bLT0NWYj07moO`3Cdm<0_;bl09ZJVP2?Shl0Bd];01/K6`0H61P06ATI
0P0M7Ad0;019BDT0S8b<020P800M7Ad0:2PX0410@01?Cdl0Kfm_0:RXZ02VYZH0QhN7071`L018B4P0
6QXJ01TI6@1=CDd0CTi>04m?C`1QHF40>c/k030`<025QHD0>CTi034a<@0T92@08b<S02/[:`16ATH0
L71`04Y:BP1KFe/0NWYj079bLP1fMWH0>3Ph02l_;`0k>c/0Lg=c06YZJP0c<c<0BDU90451@@1ADE40
Jf][0_ooool0001<05iNGP23Ph<0EeMG05EEE@10@400KVi^04a<C01TI6@0ZJVY06MWI`0S8b<0HV9R
05aLG00j>SX0?3`l04E5A@0/;2`0E5AD0492@P1FEUH0>SXj02/[:`1WIfL0>CTi06m_K`0n?Sh06a/K
0451@@1DE5@0K6a/04m?C`1cLg<0De=C02@T901=CDd0EUIF04=3@`1cLg<0?clo02@T9017AdL0GEeM
04Y:BP0f=SH0Vi^K03Ph>011@D40>CTi05QHF00W9bL08b<S05]KF`18B4P0>c/k05ADE00c<c<08b<S
02l_;`0g=cL0:b/[061PH01FEUH0?Shn02LW9`0n?Sh0KVi^03Ti>@15ADD0Kfm_0410@013@d<0KFe]
05aLG013@d<0=3@d07inOP80AdM701D0EeMG04A4A00b<S80TY:B06e]K@0l?3`0GEeM03Lg=`0[:b/0
QHF506a/K010@400UYJF08R8R00V9RH0A4A409FEU@1@D500=SHf09ZJVP26QXH00P0M7Ad0N`1kNg/0
GUiN02h^;P1MGEd0Ng]k020P801?Cdl0K6a/0820P01XJ6P0<30`07YjNP10@4008R8R05iNGP0d=3@0
=SHf04m?C`0m?Cd0QhN705eMG@1<C4`0H61P05=CD`0i>CT0IFEU07UiN@1EEED0D51@03Ph>01IFET0
LW9b04U9B@1=CDd0L71`03Ph>019BDT0HV9R05QHF01UIFD0Bd];03lo?`1gMgL0?3`l06EUI@1cLg<0
BTY:08j>SP1JFUX0DU9B069RHP12@T80Jf][07YjNP11@D40>CTi07alO01UIFD0;bl_07IfMP0i>CT0
NGUi092@T01KFe/0=SHf04Q8B01jNWX0EeMG03<c<`1kNg/0E5AD02PX:01/K6`0HF5Q05YJFP1[Jf/0
@T9205eMG@2][Jd0TY:B06IVIP2k^k/0Q8B406i^KP1YJFT0ZJVY0:RXZ01]KFd0IVIV0:ZZZP2a/K40
KVi^06YZJP2FUYH0IVIV06QXJ03Bd]80Y:BT04i>CP24Q8@0MWIf06UYJ@1[Jf/0RHV906=SH`0_;bl0
FUYJ03hn?P1/K6`0N7Qh03`l?01nOWh0NWYj04i>CP1:BTX0HV9R05ADE02BTY80SXj>069RHP0e=CD0
UYJF04i>CP0205]KF`0[0451@@0h>3P0Jf][09NGU`1IFET0BTY:0;Ng]`1nOWh0JFUY0451@@36a/H0
X:2P06][J`1HF5P0=3@d06MWI`12@T80GEeM07UiN@1TI6@0@D5107AdM028R8P0GEeM04Q8B01]KFd0
IFEU04];B`0^;Rh0QhN7092@T01TI6@0FUYJ05mOG`22PX80G5aL04I6AP2>SXh0K6a/03lo?`1`L700
KFe]03Ti>@0205UIF@0g05=CD`1oOgl0d];B0:b/[01NGUh0UIFE069RHP1ZJVX08B4Q07alO03:b/X0
R8R806=SH`1^KVh0A4A401TI6@0[:b/0@D5108F5Q@1NGUh08R8R055AD@1CDe<0CTi>0410@01HF5P0
DE5A02<S8`1cLg<0F5QH02`/;01jNWX0?3`l03Ti>@29RHT0K6a/03lo?`2^[Zh0JFUY01/K6`12@T80
ZJVY0:^[Z`1LG5`0<C4a03Hf=P1@D500QhN708F5Q@1<C4`0Bd];04Y:BP21PH40KVi^0410@0020820
P00402l_;`0J6QX05aLG01@D50804a<C03@092@T06=SH`1RHV80CDe=03Ti>@0^;Rh0:2PX04M7A`0S
8b<0Fe]K09bLW02/[:`0Rh^;03De=@0O7al0;bl_020P800G5aL03`l?01XJ6P1jNWX0OGem04m?C`0d
=3@0;2`/02PX:00n?Sh0NGUi0<C4a02d];@0X:2P0;jn_P1GEeL0:BTY02d];@20P800PX:206a/K01=
CDd0>SXj02<S8`0K6a/0;Rh^09nOW`1^KVh0_;bl04m?C`0L71`0DU9B07moO`0Y:BT03Ph>1P0=3@d0
B@0@41003Ph>00h>3P0@41004A4A04E5A@1oOgl0AdM701TI6@0E5AD05QHF020P801FEUH0WYjN0;bl
_02^[Zh0/;2`0:NWY`2HV9P0ATI6034a<@1`L700`/;20;>c/`23Ph<0Cdm?09VIV@2OWil0OWin08f=
S@17AdL0HF5Q05iNGP1EEED0?Shn02HV9P0J6QX051@D01LG5`2CTi<0<S8b04A4A01`L700QXJ606e]
K@0L71`05QHF01PH600Z:RX0F5QH05UIF@0g=cL0<S8b05eMG@1GEeL0B4Q805aLG00f=SH0A4A405iN
GP21PH40R8R80:FUY@1fMWH0Ogmo04m?C`0i>CT0:b/[06i^KP1TI6@0QXJ604e=C@0T92@01@0E5AD0
700G5aL06QXJ02<S8`1PH600YjNW07MgM`13@d<0DE5A03@d=00H61P071`L01PH600G5aL071`L01XJ
6P0I6AT05QHF01PH600L71`0;Bd]07UiN@2BTY80V9RH09:BTP3:b/X0IVIV02l_;`0Q8B4201DE5@2:
01<C4`0E5AD05ADE01DE5@0a<C40>3Ph04Q8B00i>CT09bLW04M7A`36a/H0/;2`0;:b/P0m?Cd0@T92
05IFEP1WIfL0Ph>309jNWP3Rh^80gMgM09nOW`1aLG40MGEe01hN7P1IFET0Q8B404Q8B00Y:BT0@D51
03dm?@0`<300D51@069RHP1>CTh0@T9204a<C027QhL0[Zj^07]kN`0[:b/08B4Q04Y:BP2BTY80H61P
05QHF02PX:00Zj^[09nOW`1^KVh0LW9b07alO020P800R8R808F5Q@1lO7`0S8b<09VIV@1PH600Rh^;
0:RXZ02a/K40Z:RX0:2PX02_[jl0TY:B09BDU01RHV80F5QH0820P032`/80C4a<03Xj>P1@D500CDe=
04A4A01MGEd0T92@08Z:RP1NGUh0MgMg0:j^[P0_;bl0?Cdm07inOP35aLD0alO709RHV02MWId0EEEE
034a<@0k>c/0AdM704Q8B01TI6@0TI6A02/[:`1=CDd0Kfm_0861P@1hN7P0[jn_0<[:bP1jNWX0JFUY
02@T900G5aL05ADE01LG5`0O7al0KFe]03dm?@1BDU80I6AT05MGE`2<S8`0?Cdm02d];@0J6QX08b<S
03Lg=`0j>SX09BDU02l_;`0g=cL0GEeM07AdM021PH40EEEE03@d=00b<S80Hf=S096AT@26QXH0Hf=S
02TY:@0M7Ad0:b/[0_ooool0003g06EUI@1]KFd0BTY:05ADE011@D40Lg=c0451@@15ADD0RHV9065Q
H@0R8R80H61P03Xj>P0[:b/0E5AD05eMG@0T92@0=3@d03De=@1VIVH0B4Q801dM7@1IFET0<30`0:6Q
X@1PH6009bLW03/k>`1TI6@0BDU904A4A026QXH0L71`03hn?P1JFUX0@D5102PX:01EEED0De=C02h^
;P1:BTX0HF5Q02l_;`0[:b/0O7al03`l?00^;Rh0;bl_061PH00a<C40=3@d06MWI`0/;2`0B4Q8071`
L01BDU80=3@d03<c<`0];Bd0:BTY07inOP1jNWX0Hf=S02XZ:P1:BTX0S8b<03Hf=P1WIfL0SHf=05aL
G00m?Cd0TI6A05=CD`0W9bL0>SXj08F5Q@1UIFD0BDU904a<C01;Bd/0ADE509bLW01IFET0:b/[05QH
F01?Cdl08B4Q07AdM01PH600<S8b07alO01KFe/0?3`l028R8P2QXJ40>3Ph02l_;`2FUYH0WinO038b
<P0V9RH0YJFU06MWI`0_;bl0IfMW09bLW00k>c/0?Cdm05iNGP1gMgL0LG5a03@d=01cLg<0E5AD038b
<P1ZJVX0:b/[03Lg=`1CDe<0ADE508Z:RP1DE5@0BDU905mOG`1eMGD0Bd];07alO021PH40EeMG06AT
I01PH600Lg=c0820P015ADD0DU9B0861P@1ADE40De=C06][J`1JFUX0Fe]K05UIF@1@D500Ng]k04U9
B@1lO7`0SXj>04i>CP1jNWX0LG5a06QXJ02=SHd0F5QH07=cL`1`L700A4A403Ph>01jNWX0KVi^04E5
A@20P800ADE509fMW@2][Jd0P8200451@@1ADE40R8R803`l?01CDe<0^KVi09^KV`17AdL0G5aL02`/
;01YJFT0M7Ad07inOP1SHf<0/[:b08b<S01gMgL0a<C40:JVYP2;Rh/0Ogmo08R8R02/[:`0P82009RH
V03=cLd0];Bd06][J`1/K6`0UIFE04Y:BP1JFUX0]KFe07MgM`12@T80X:2P0:>SX`24Q8@0?Cdm05MG
E`1BDU80:2PX06=SH`1BDU80P82008b<S01:BTX0PX:206MWI`17AdL0FEUI06e]K@1=CDd0Shn?09nO
W`1IFET0HF5Q0<30`01QHF40DE5A061PH011@D40BDU908n?S`2e]KD0Kfm_05=CD`33`l<0QhN706IV
IP13@d<0a/K60;^k^`1oOgl0F5QH03@d=01NGUh0ADE506IVIP2OWil0HF5Q04=3@`0207IfMP0/01dM
7@0c<c<0D51@05ADE01;Bd/0CDe=0:2PX02>SXh0BTY:034a<@18B4P0MWIf05EEE@0k>c/0T92@03hn
?P0e=CD0LG5a07MgM`0o?cl0J6QX04A4A00W9bL0E5AD08R8R02:RXX0JFUY096AT@1XJ6P0B4Q801<C
4`1=CDd0QHF504i>CP1@D500Ogmo055AD@0S8b<0=3@d04A4A01YJFT0ADE5020P801DE5@205aLG01K
04];B`1DE5@0FEUI038b<P2?Shl0HV9R02PX:01`L700DU9B03@d=02<S8`0K6a/03`l?02a/K40Jf][
04Y:BP0b<S80FEUI06QXJ01iNGT0=CDe03Ti>@1ADE40PH6108N7Q`1<C4`0B4Q805]KF`1]KFd0=CDe
07inOP2EUID0G5aL06m_K`0`<3006a/K01DE5@0G5aL04Q8B014A4@0k>c/0?clo03<c<`0n?Sh0:2PX
03`l?00d=3@04Q8B08>3P`27QhL0SHf=0;Rh^02ATI40@D5101lO7`0Y:BT0:b/[0492@P1XJ6P0WIfM
04i>CP0H61P07QhN01`L700S8b<08B4Q04a<C039bLT0a<C40<G5a@3=cLd0i>CT0=gMg@3Rh^80fMWI
08b<S01LG5`0JVYZ07QhN020P800UYJF08N7Q`2b/[80J6QX03@d=01?Cdl07QhN0492@P1dM7@0FEUI
014A4@0200d=3@0400`<300=3@d03@d=00d=3@803Ph>02803`l?018B4P0^;Rh0>c/k018B4P19BDT0
CDe=01<C4`0@41005ADE01LG5`16ATH0OWin0;^k^`2RXZ80]kNg0=3@d032`/80ZJVY079bLP0e=CD0
9BDU061PH02TY:@0T92@09fMW@1lO7`0UYJF04];B`14A4@0:RXZ030`<00h>3P0EUIF0`1WIfL08`2b
/[80YJFU0;fm_@2DU9@0NWYj07MgM`16ATH0:BTY01XJ6P0I6AT05ADE01XJ6P1:BTX0EUIF03/k>`18
B4P0A4A40492@P1QHF40Fe]K08b<S030`<00QXJ60<30`01?Cdl0F5QH06i^KP1HF5P07QhN06][J`2C
Ti<0ATI603dm?@16ATH092@T00<05ADE00l05QHF01LG5`0E5AD061PH03@d=02;Rh/0O7al04=3@`19
BDT0DE5A01PH600G5aL06ATI01DE5@0L71`00`0I6AT0E@0G5aL06a/K01XJ6P15ADD0a<C40=7Ad@2^
[Zh0XJ6Q03Ti>@0Y:BT06ATI01DE5@0C4a<05QHF01DE5@0G5aL05ADE01LG5`1QHF40AdM704E5A@0d
=3@0KFe]09:BTP2EUID0CTi>01`L700J6QX07AdM020P800V9RH0EEEE0<_;b`3Kfm/0bLW90:j^[P2O
Wil0XJ6Q07YjNP0[:b/09BDU03/k>`0];Bd07QhN020P800R8R80:b/[03hn?P1>CTh0B4Q805UIF@1O
Gel0XZ:R0:6QX@2^[Zh0/k>c05eMG@14A4@0HF5Q0:>SX`11@D40>3Ph04m?C`1/K6`0OGem08:2PP26
QXH0Ogmo09FEU@2a/K40c<c<0;Bd]02e]KD0]kNg0;no_`30`<00emOG0=GEe@2l_;`0U9BD0861P@1l
O7`0^KVi079bLP0P82000P0M7Ad0800Q8B40<c<c079bLP2m_Kd0CDe=038b<P1nOWh0NGUi020P800g
=cL0>c/k0:BTY02k^k/0MWIf07]kN`24Q8@0Lg=c05=CD`1[Jf/0L71`0::RXP2NWYh0OWin07moO`2?
Shl0UiNG06][J`1mOGd0[:b/07UiN@0`<3006QXJ0`0E5AD02P0G5aL0C4a<05QHF00o?cl0Hf=S0=3@
d01RHV80@T9202PX:00P820202XZ:P0A01lO7`0X:2P09bLW03De=@1JFUX0K6a/07]kN`1ZJVX0Q8B4
0820P01mOGd0/k>c0<c<c02ATI40?Shn03Lg=`0/;2`00_ooool0003o06MWI`2[Zj/0CDe=06=SH`13
@d<0V9RH05EEE@1IFET0VYZJ06e]K@0T92@0MgMg08>3P`0/;2`09BDU055AD@0V9RH0:RXZ024Q8@1?
Cdl0F5QH03hn?P1SHf<07alO06e]K@1OGel0:b/[04Q8B01ZJVX0@41003Ti>@1jNWX0IFEU03De=@1D
E5@0Hf=S03lo?`1HF5P0DU9B03De=@1EEED0I6AT038b<P0o?cl0UIFE04M7A`12@T80@d=305]KF`0_
;bl0=cLg05aLG00S8b<0>c/k0451@@19BDT0;bl_02h^;P1BDU80;bl_05iNGP18B4P0C4a<02l_;`1<
C4`0QHF502d];@0e=CD0Jf][05UIF@0a<C40XZ:R05MGE`0Z:RX0:2PX07IfMP17AdL0>3Ph05iNGP1W
IfL0ADE50:2PX01RHV80;2`/07AdM01YJFT0:RXZ07EeM@1=CDd0:BTY07emO@1NGUh0@d=302`/;02W
YjL0ATI6069RHP2h^;P0VIVI05]KF`0b<S80[Zj^06a/K00];Bd0IFEU08n?S`15ADD0?Shn06=SH`2=
SHd0AdM702l_;`2:RXX0L71`03`l?01gMgL0;bl_04U9B@1RHV80?Shn08V9R@15ADD0IFEU08>3P`1c
Lg<0FEUI06e]K@1cLg<0Cdm?08^;R`1RHV80KVi^075aL@1<C4`0MWIf08f=S@1;Bd/0D51@06e]K@1D
E5@0M7Ad07inOP1EEED0SXj>03dm?@1KFe/0LG5a04e=C@0m?Cd0ADE503/k>`1`L700GUiN07UiN@1k
Ng/0ATI604U9B@2VYZH0Ng]k059BDP1aLG40>3Ph05aLG02CTi<0M7Ad03/k>`1@D500Shn?055AD@0a
<C40GUiN07AdM010@400M7Ad02d];@1iNGT0PX:207EeM@1ZJVX0][Jf071`L01UIFD0^k^k0:JVYP25
QHD0OWin0:2PX02@T900D51@05IFEP2e]KD0[Zj^06MWI`27QhL0Xj>S06=SH`1^KVh0clo?08>3P`0e
=CD0Jf][0:2PX022PX80@d=3075aL@1FEUH0?3`l07IfMP14A4@0Ph>3096AT@1:BTX0P820075aL@0k
>c/0MGEe079bLP16ATH0P8200:NWY`1KFe/0BTY:0:JVYP1ADE40HV9R0:FUY@12@T80;Bd]05UIF@2M
WId0R8R8055AD@2o_kl0MWIf07moO`0^;Rh0U9BD0;no_`2b/[80Ogmo03/k>`1WIfL0:BTY03Ph>01j
NWX0Ogmo04M7A`2SXj<0W9bL06=SH`11@D40EeMG05mOG`0V9RH08b<S001807inOP1lO7`0IFEU02l_
;`0l?3`0MgMg04E5A@1>CTh0UiNG06QXJ014A4@0HV9R06i^KP1?Cdl0JVYZ04e=C@1FEUH0KFe]09JF
UP23Ph<0Fe]K08B4Q01iNGT0Ph>303Hf=P1BDU80Ng]k024Q8@0f=SH0Ng]k07QhN01DE5@0?clo04I6
AP1`L700=SHf03@d=02?Shl0V9RH05QHF01JFUX0DU9B04M7A`0O7al0Jf][04i>CP0[:b/0Ph>305]K
F`0a<C40PH6104U9B@0^;Rh0];Bd0:JVYP1dM7@0?Shn07=cL`1UIFD0H61P03Ph>01_Kfl0O7al08R8
R02n_[h0CTi>04I6AP1XJ6P0?Cdm09>CT`1nOWh0B4Q80P14A4@0?01UIFD0>CTi01TI6@0F5QH05ADE
01TI6@1?Cdl0ATI602HV9P0e=CD0?clo04m?C`0M7Ad0ADE504I6AP0`<300<C4a05aLG02g]kL0b<S8
0:NWY`2KVi/0VYZJ0=WIf@3Bd]80O7al01/K6`0M7Ad06ATI01DE5@0Q8B40820P07]kN`29RHT08b<S
051@D02[Zj/0f][J0=gMg@3Kfm/0_;bl09JFUP1gMgL0Hf=S04I6AP0j>SX0;2`/02HV9P0X:2P0S8b<
02/[:`0`<300>SXj03Lg=`1]KFd0MGEe01@D500>3Ph03@d=00`<30D03@d=04X03Ph>024Q8@1ZJVX0
:b/[00l?3`0D51@0Q8B4061PH019BDT0?3`l05=CD`2SXj<0RHV90:RXZ01cLg<0LW9b0:FUY@3AdM40
PX:202/[:`0Y:BT06ATI03Ti>@1dM7@0R8R805aLG01VIVH0MGEe06a/K01KFe/0BDU903`l?00`<300
:BTY02LW9`0Y:BT0;Bd]09>CT`2`/;00WinO0:JVYP3Cdm<0>CTi01hN7P0`<300@T9203De=@0N7Qh0
5aLG01PH600Q8B40D51@05UIF@17AdL0H61P06EUI@2o_kl0^KVi0;^k^`3>c/h0gMgM08^;R`1>CTh0
Ogmo09:BTP1/K6`0T92@0;Ng]`1IFET0K6a/03dm?@0_;bl0:RXZ01LG5`805ADE01d05aLG01DE5@0E
5AD06ATI05ADE01MGEd0E5AD06e]K@2<S8`0Fe]K03Ti>@0c<c<08B4Q01/K6`0J6QX05aLG01DE5@0F
5QH06ATI02HV9P1UIFD0g]kN0=[JfP3GemL0e]KF0::RXP1HF5P08b<S01PH600401DE5@1101LG5`0E
5AD0:BTY06QXJ01>CTh0GemO0;6a/@1OGel0YjNW02LW9`0J6QX061PH01dM7@0P8200Cdm?08f=S@0j
>SX0O7al08^;R`2HV9P0`l?30;Fe]@0S8b<0:2PX0451@@0M7Ad06ATI01/K6`0O7al08B4Q02<S8`0P
8200<C4a04Q8B01WIfL0Bd];06i^KP33`l<0/K6a09^KV`20P800RXZ:0<30`02JVYX0GEeM04];B`1A
DE40Jf][05IFEP12@T80H61P08f=S@1BDU80B4Q80820P03=cLd0^k^k08f=S@2^[Zh0Y:BT0;Zj^P2m
_Kd0`/;20;Bd]02`/;000P3Fe]H09P0e=CD08b<S028R8P0Q8B407AdM01hN7P0h>3P0MgMg05YJFP0n
?Sh0/k>c03lo?`0S8b<0ATI605=CD`2BTY80EEEE04A4A01_Kfl0TI6A0;bl_03GemL0Shn?051@D03;
bl/0VIVI05ADE00e=CD08b<S02PX:00e=CD0>CTi06a/K00e=CD09RHV01LG5`0E5AD05aLG0P0E5AD0
700k>c/0?Shn05UIF@13@d<0Xj>S07UiN@0b<S806a/K02/[:`0X:2P09BDU01DE5@0K6a/06ATI02PX
:01OGel0PH6107EeM@1LG5`0[Jf]0;^k^`2@T900YJFU0<c<c02i^KT0XJ6Q09ZJVP29RHT2ooooo`00
06X0KFe]0:^[Z`1=CDd0AdM704=3@`1dM7@0CDe=04U9B@1cLg<0?3`l03hn?P2=SHd0PX:202h^;P0/
;2`0KVi^02TY:@13@d<0>SXj05MGE`0d=3@0<c<c07=cL`0_;bl0TI6A03Xj>P0];Bd0I6AT06i^KP1V
IVH0DU9B09^KV`1SHf<0>3Ph07EeM@22PX80FEUI05QHF018B4P09bLW065QH@20P800G5aL04E5A@2U
YJD061PH04I6AP12@T80Cdm?01hN7P1ADE40RHV903Xj>P11@D40@41003Xj>P0`<300E5AD06=SH`13
@d<0JVYZ055AD@1:BTX0?3`l06m_K`2WYjL0BDU905ADE020P800:RXZ034a<@28R8P0L71`03<c<`0/
;2`0Q8B404E5A@11@D40Kfm_07]kN`0l?3`0SXj>05EEE@0P8200BDU906MWI`0a<C40Ogmo05UIF@0k
>c/0ATI606ATI01BDU80<C4a0:VYZ@0e=CD0:b/[06YZJP1cLg<0EeMG02PX:02UYJD0Kfm_0410@01A
DE40QhN70P11@D40R`1lO7`0RXZ:07UiN@0k>c/0M7Ad05iNGP0b<S80Rh^;03lo?`0e=CD0JFUY04Q8
B02=SHd0CTi>03Ti>@1OGel0IFEU04a<C01iNGT0DE5A03dm?@1/K6`0EeMG08V9R@1dM7@0>CTi051@
D01mOGd0@T9204i>CP1^KVh0DE5A059BDP1JFUX0EUIF08R8R01EEED0M7Ad07QhN01@D500Kfm_05AD
E01BDU80MWIf04a<C026QXH0[:b/0410@00_;bl0OGem08B4Q01EEED0SHf=04A4A01aLG40_;bl08B4
Q011@D40CTi>09>CT`1MGEd0?clo07QhN029RHT0@D5107UiN@1>CTh0FUYJ06IVIP1SHf<0JFUY0;jn
_P1hN7P0IVIV0<G5a@2OWil0SXj>08V9R@2b/[80Ng]k06MWI`1]KFd0c/k>08f=S@1?Cdl0Rh^;0:RX
Z01LG5`0V9RH0=WIf@1iNGT0@D5106ATI02=SHd0EUIF04a<C02EUID0H61P034a<@1YJFT0>c/k07Ui
N@1OGel0ADE50<71`@2BTY80D51@08V9R@1fMWH06ATI069RHP2OWil0FUYJ06QXJ02GUiL0@T9204I6
AP1ZJVX0F5QH03lo?`1aLG40^;Rh08:2PP1KFe/0bl_;0;>c/`1_Kfl0>3Ph08N7Q`1eMGD0OWin07If
MP0m?Cd0O7al05MGE`1XJ6P0PH610451@@0i>CT00P2BTY80O01LG5`0?Cdm069RHP0m?Cd0@D5102l_
;`23Ph<0MWIf05=CD`0`<300ADE507YjNP0];Bd0;bl_0861P@1`L700C4a<06][J`1eMGD0BDU909ZJ
VP22PX80N7Qh07AdM02TY:@0UiNG07alO02RXZ80V9RH07UiN@0a<C40MgMg0:ZZZP0i>CT0CDe=05]K
F`1EEED0Bd];059BDP1EEED0QXJ603Ti>@0M7Ad0CDe=05MGE`1DE5@0J6QX09bLW01^KVh0<C4a079b
LP11@D409RHV06m_K`1ADE40:BTY06i^KP1@D5008B4Q08N7Q`2?Shl0HF5Q03@d=01`L700Hf=S059B
DP0J6QX0>SXj05UIF@1iNGT0fMWI08R8R01XJ6P0L71`0::RXP1LG5`0?clo03hn?P0X:2P0?3`l03dm
?@1XJ6P0?clo01XJ6P0E5AD05aLG051@D01<C4`0;Bd]02PX:014A4@0;2`/03lo?`1<C4`0;bl_01lO
7`0M7Ad07QhN03Hf=P2c/k<0alO70<C4a03@d=00dm?C0;no_`1@D5005aLG01`L700Q8B405QHF01/K
6`0G5aL0MGEe02`/;00A4A40410@020P802l_;`0VIVI03`l?00P82005ADE018B4P0>3Ph200`<3006
00d=3@0820P03@d=06a/K02FUYH0<30`0P0n?Sh01@1SHf<0JVYZ03De=@0?3`l020P800803@d=04l0
2PX:00d=3@0<30`030`<010@401eMGD0SXj>030`<00g=cL0@d=3034a<@0L71`0<S8b04Q8B01nOWh0
alO704E5A@1?Cdl06a/K02DU9@1GEeL0X:2P034a<@0`<300ATI605MGE`17AdL07QhN02TY:@1@D500
H61P059BDP27QhL0?Shn04m?C`1>CTh0AdM703Ti>@0_;bl0:BTY03/k>`2NWYh0][Jf08Z:RP2<S8`0
^[Zj03Xj>P0C4a<05ADE01TI6@0U9BD0>3Ph03lo?`0Y:BT05aLG01DE5@0f=SH0QhN70:VYZ@32`/80
^k^k0>;RhP3EeMD0b/[:09fMW@2FUYH0PX:208R8R01SHf<0HF5Q09^KV`2j^[X0Hf=S0451@@0Y:BT0
=3@d02l_;`0i>CT092@T00806ATI01h061PH01DE5@0E5AD0?Shn061PH01VIVH0Hf=S02d];@0Q8B40
9RHV03@d=00k>c/0@d=303hn?P0d=3@07alO01LG5`0J6QX0<S8b09JFUP34a<@0`l?30;Bd]02`/;00
[Zj^0;no_`2k^k/0MWIf030`<00G5aL401DE5@0701HF5P1`L700RHV90;jn_P3?cll0GUiN0::RXP02
01`L700E01hN7P0Y:BT0BTY:08B4Q00];Bd08b<S06i^KP2XZ:P0[:b/0<C4a039bLT0TI6A04Q8B00N
7Qh06ATI028R8P0Y:BT0:2PX02d];@0h>3P0@T920080A4A404@0<S8b03dm?@1OGel0`L710<G5a@2D
U9@0W9bL0<G5a@2[Zj/0^k^k08J6QP2DU9@0YjNW05ADE00c<c<0C4a<05=CD`1BDU80G5aL04];B`1C
De<0SXj>09FEU@2a/K40Xj>S09fMW@2i^KT0YjNW08R8R01KFe/0AdM706m_K`2g]kL0=CDe028R8P0M
7Ad071`L01dM7@0P8200=CDe06YZJP1iNGT0GUiN09bLW00V9RH0;Rh^05mOG`2>SXh0`l?308b<S00l
?3`0;Rh^02TY:@10@400YZJV04e=C@0a<C40Y:BT03Lg=`0F5QH06ATI02`/;00o?cl0F5QH01XJ6P1D
E5@0?3`l02PX:0D05ADE01`0;2`/02d];@1;Bd/0EUIF08V9R@2BTY80=cLg02h^;P0W9bL0:RXZ01dM
7@0E5AD06QXJ02`/;01JFUX0UYJF0<O7a`2JVYX0O7al0<_;b`2h^;P0[jn_09^KV`2TY:@0GEeM06MW
I`2@T900TI6A0_ooool0000]069RHP1kNg/0D51@06=SH`10@400LG5a04I6AP1RHV80XZ:R05IFEP0V
9RH0IVIV06YZJP0U9BD0:2PX03hn?P0^;Rh0E5AD03<c<`1=CDd0<S8b02d];@1HF5P0820P09NGU`1Q
HF40:2PX0492@P1DE5@0Bd];05IFEP2XZ:P0MWIf02@T901JFUX0L71`04];B`1/K6`0ATI602`/;01<
C4`0LG5a03lo?`0j>SX0X:2P0080B4Q809/0>c/k06ATI00U9BD0:RXZ05IFEP14A4@0AdM705IFEP1L
G5`0=SHf03Ph>01HF5P0>3Ph07MgM`1RHV80<C4a028R8P16ATH0QXJ60410@01>CTh0RXZ:06QXJ018
B4P0P82005EEE@12@T80@41008j>SP1MGEd0Bd];05iNGP1EEED0@41009FEU@1dM7@0>CTi05EEE@1A
DE40>3Ph07emO@1]KFd0HV9R07moO`1]KFd0@41002XZ:P2][Jd0J6QX02TY:@2@T900Ng]k03Lg=`0Q
8B40^;Rh07inOP16ATH0Hf=S092@T00L71`0BDU906a/K01oOgl0O7al03`l?02CTi<0@D5102LW9`2=
SHd0I6AT03`l?01KFe/0<S8b09nOW`1SHf<0BTY:051@D00T92@0@41008J6QP2<S8`0C4a<05YJFP0h
>3P0OGem08j>SP1?Cdl0IfMW04U9B@0`<300Hf=S08b<S01SHf<0KFe]05YJFP1TI6@0WinO06ATI01c
Lg<0L71`03hn?P2BTY80IFEU05QHF01oOgl0@D5105=CD`2<S8`0HF5Q0451@@2@T900Rh^;06a/K02J
VYX0ATI608B4Q02h^;P0P82004];B`1KFe/0Vi^K05IFEP1XJ6P0[:b/075aL@12@T80P82006=SH`1g
MgL0MWIf038b<P1BDU80/;2`09bLW01jNWX0bl_;09ZJVP0j>SX0RHV90<o?c`2`/;00JFUY08f=S@3H
f=P0PH610451@@1mOGd0Q8B4030`<01gMgL0aLG506a/K01;Bd/0MWIf09fMW@0204m?C`2<08>3P`1a
LG4092@T04Y:BP0f=SH0Shn?07]kN`0m?Cd0MGEe06IVIP0h>3P0WYjN08:2PP1@D500QhN70:b/[00e
=CD0DE5A0:6QX@1PH600DU9B06EUI@0M7Ad08B4Q06QXJ02i^KT0Jf][04E5A@2OWil0PH61079bLP19
BDT0_;bl0<W9b@2g]kL0HV9R03Hf=P1ZJVX0JFUY07QhN02QXJ40IfMW03dm?@2;Rh/0PH6103<c<`19
BDT0Ogmo06i^KP1IFET0=cLg07MgM`1fMWH0=SHf05=CD`25QHD0S8b<03<c<`0_;bl0JFUY06][J`1=
CDd0KVi^079bLP0h>3P0L71`065QH@13@d<0FUYJ0;Zj^P2i^KT0/;2`07emO@1SHf<0<C4a01TI6@1H
F5P0PH6107=cL`1OGel0GUiN04m?C`0P8200DE5A08V9R@2TY:@0KVi^02HV9P18B4P0DE5A01LG5`1;
Bd/0J6QX06UYJ@0_;bl0IfMW069RHP0X:2P0QhN705ADE00^;Rh0RHV906ATI00Y:BT0U9BD09>CT`0l
?3`0:2PX06YZJP1SHf<0HF5Q02l_;`1<C4`0BTY:075aL@3=cLd0e=CD0<g=c@2TY:@0FUYJ038b<P0[
:b/0?Cdm02DU9@0P8200=CDe0410@01UIFD0EUIF02<S8`0F5QH0De=C03dm?@0M7Ad0ADE50410@00o
?cl0B4Q802l_;`0L71`201hN7P0A01dM7@16ATH0UiNG04U9B@0a<C40<c<c0:b/[032`/80R8R8020P
800N7Qh06a/K01DE5@0A4A40;Rh^055AD@0B4Q800`0@41003P2CTi<0CTi>01dM7@0D51@05ADE01<C
4`0=3@d01PH600d=3@0<30`02PX:00d=3@0];Bd0Fe]K0P1nOWh01P2o_kl0][Jf06EUI@1bLW807AdM
00l?3`803Ph>0`0=3@d0200?3`l0EeMG075aL@0h>3P0;bl_02<S8`0Q8B406a/K0P0G5aL08`0E5AD0
=CDe08^;R`1gMgL0Ogmo01/K6`0L71`0De=C09nOW`1ADE40FEUI04Y:BP0O7al04a<C01TI6@0G5aL0
6ATI02l_;`1ADE40IVIV055AD@0O7al0?clo04m?C`1XJ6P0WIfM08J6QP1ADE40TI6A0;6a/@2_[jl0
A4A403`l?01iNGT07AdM00<05ADE02L06ATI020P800W9bL0=cLg02d];@0S8b<0:b/[0<S8b03<c<`0
emOG0=gMg@3Hf=P0`<3009bLW02>SXh0V9RH09nOW`2:RXX0Ogmo0<O7a`2i^KT0AdM7034a<@0Y:BT0
=CDe02d];@0d=3@0?3`l03<c<`0P820061PH01LG5`0M7Ad0>3Ph06QXJ024Q8@0PH6101hN7P0M7Ad0
0P0J6QX05@0I6AT07AdM02DU9@0b<S80CDe=04Q8B00c<c<0KVi^07inOP1aLG40Rh^;0:2PX03EeMD0
[:b/055AD@15ADD0NGUi0;6a/@2LW9`0Cdm?01lO7`0201DE5@1501LG5`1EEED0];Bd0<G5a@31`L40
/;2`0;Ng]`1JFUX0?3`l04M7A`1IFET0Rh^;02TY:@0Z:RX0@T9205eMG@2MWId0SXj>0;jn_P2l_;`0
[Zj^05aLG00Y:BT0:2PX04A4A01OGel0G5aL05iNGP13@d<0:b/[02DU9@0_;bl0=cLg03lo?`1IFET0
T92@07UiN@1BDU80EUIF08:2PP2WYjL0Y:BT05EEE@18B4P0G5aL02/[:`0I6AT0<C4a03Lg=`0L71`0
:b/[04];B`1@D500EUIF07=cL`2@T900b<S80:j^[P30`<00RHV908f=S@12@T809bLW05EEE@2KVi/0
G5aL01hN7P0U9BD08R8R00808B4Q01d0?clo07alO02:RXX0WIfM07EeM@0c<c<0>CTi04e=C@1/K6`0
WIfM03Lg=`17AdL0KVi^06][J`15ADD0GUiN07EeM@1PH600Ng]k03<c<`0E5AD07alO03Xj>P1HF5P0
71`L01TI6@0b<S80HV9R02DU9@0501DE5@0L02PX:00_;bl0C4a<0451@@2CTi<0YZJV08N7Q`1<C4`0
DU9B03hn?P12@T80IVIV07inOP27QhL0QHF50:f][@2?Shl0a<C40=?Cd`2BTY80Xj>S09bLW02:RXX0
Hf=S02h^;P0`<300?Cdm04m?C`;ooooo0000H`1ZJVX0O7al04];B`1QHF40?clo06UYJ@0g=cL0CTi>
08f=S@1NGUh09bLW07MgM`1QHF40<c<c04U9B@1^KVh0:b/[04I6AP0e=CD0HF5Q061PH00i>CT0@T92
00h>3P2:RXX0GemO02l_;`1>CTh0G5aL01XJ6P0_;bl0Hf=S08n?S`0i>CT0EUIF03Ti>@0f=SH0I6AT
05UIF@0`<300FUYJ07inOP0F5QH0<30`0861P@15ADD0>3Ph02<S8`1BDU809RHV02h^;P1LG5`05ADE
03Ti>@1XJ6P0K6a/051@D00i>CT0=cLg02DU9@1RHV80N7Qh06MWI`0j>SX0AdM708F5Q@0/;2`0H61P
09BDU01cLg<0AdM707inOP12@T809RHV04=3@`2LW9`0F5QH04e=C@1MGEd0ADE502l_;`1hN7P0OWin
03`l?01?Cdl0IfMW02/[:`17AdL0Bd];06UYJ@1PH600MgMg04U9B@0];Bd0[Zj^06ATI00[:b/0TI6A
09RHV00203Lg=`2e0<O7a`21PH40@41007emO@2[Zj/0CTi>03@d=01?Cdl0Kfm_05]KF`0i>CT0X:2P
07MgM`0j>SX0M7Ad055AD@1EEED0MgMg04E5A@2ATI40FEUI04];B`1[Jf/0JFUY0492@P1TI6@0Ph>3
061PH01lO7`0GEeM06m_K`1UIFD0CDe=08^;R`2=SHd0@d=304Q8B01VIVH0CTi>08f=S@1PH600De=C
08N7Q`15ADD0Q8B4096AT@11@D40TY:B05IFEP0h>3P0OWin06ATI01jNWX0WYjN04I6AP1;Bd/0ZJVY
07alO01ADE40O7al055AD@2JVYX0aLG507EeM@0c<c<0AdM707]kN`0d=3@0?clo06MWI`1fMWH0>3Ph
06EUI@0Z:RX0J6QX07QhN01<C4`0AdM709nOW`1TI6@0NWYj0=7Ad@2][Jd0FEUI07YjNP2d];@0K6a/
0410@025QHD0a<C409VIV@1FEUH0RXZ:0:2PX01MGEd0S8b<0<o?c`1BDU80BTY:08J6QP2VYZH0QHF5
03lo?`1SHf<0Jf][02LW9`1BDU80=3@d08N7Q`1lO7`0?Cdm071`L01VIVH0?Cdm08F5Q@1oOgl0BTY:
07EeM@2d];@0K6a/04m?C`1PH600?Shn059BDP1MGEd0=CDe02PX:01>CTh0RHV906YZJP18B4P0[Jf]
079bLP1QHF409bLW08n?S`2XZ:P0WIfM07YjNP0k>c/0HF5Q03Hf=P12@T80Rh^;079bLP0e=CD0Ng]k
07QhN00M7Ad0;bl_04i>CP1WIfL0F5QH03Lg=`1]KFd0OWin04=3@`0];Bd0?clo07MgM`16ATH0:BTY
07AdM00`<300;Bd]06ATI020P800BDU909>CT`1]KFd09RHV03/k>`1fMWH0VIVI08n?S`2`/;00b<S8
08Z:RP0];Bd0Cdm?079bLP0205=CD`0Y061PH01QHF40?3`l03dm?@15ADD0L71`05iNGP0L71`0@410
05=CD`1ADE40CDe=065QH@1NGUh0<S8b0820P01HF5P08b<S07YjNP0h>3P0:RXZ06UYJ@1BDU80820P
07inOP2OWil09BDU03/k>`2YZJT0ZZZZ07QhN00e=CD0D51@04];B`1bLW80eMGE0=[JfP3AdM40L71`
04=3@`0i>CT00P0e=CD0:P0T92@0820P01hN7P0l?3`0?Shn05mOG`1lO7`0D51@09JFUP1QHF40A4A4
04a<C01CDe<0@D5101hN7P0K6a/09BDU028R8P0g=cL0BDU9092@T01<C4`09BDU01/K6`0F5QH0@T92
0;^k^`2BTY80HF5Q024Q8@0B4Q804a<C01PH6018B4P08B4Q014A4@0?3`l0410@018B4P21PH40BTY:
01XJ6P805ADE01803Ph>00X:2P0<30`03@d=00H61P0<30`05ADE010@401MGEd0NWYj0:f][@22PX80
M7Ad09VIV@2LW9`0GUiN02HV9P0?3`l200`<30803`l?00@0@d=305ADE00R8R806ATI0P0E5AD07@0G
5aL05ADE01DE5@0O7al0CDe=08R8R02IVIT0RHV907UiN@1NGUh0IVIV0;Zj^P2c/k<0T92@02LW9`0J
6QX04a<C018B4P0K6a/05aLG01DE5@0F5QH07AdM04Y:BP1oOgl08B4Q01LG5`0S8b<0=cLg0080JFUY
00d08b<S09bLW03>c/h0VIVI02XZ:P0W9bL0QHF504e=C@0P82005ADE01LG5`0D51@05ADE00806ATI
01<07alO03Ph>01/K6`0]KFe0=kNgP2^[Zh0`l?30=KFeP2ZZZX0P82008n?S`2>SXh0V9RH09FEU@2m
_Kd0bl_;08R8R021PH40ADE50080:b/[0100<C4a03Ph>00j>SX0@d=304e=C@0[:b/08R8R05=CD`1B
DU80TI6A08:2PP2CTi<08B4Q01`L700J6QX071`L0P0J6QX0AP0G5aL071`L01dM7@0l?3`0^KVi07If
MP1UIFD0Kfm_0;Jf]P2c/k<0dm?C0:f][@2@T900P82005]KF`17AdL0Jf][0:2PX02_[jl0IFEU02h^
;P0V9RH0Cdm?08Z:RP3Bd]80_[jn0:ZZZP21PH40CDe=03/k>`10@400Ogmo04M7A`1?Cdl0DU9B04i>
CP0k>c/0?Cdm08n?S`3?cll0WIfM0:j^[P2j^[X0K6a/06QXJ01ADE40<S8b01`L700S8b<0=SHf04E5
A@1BDU80BDU903lo?`1NGUh0Ti>C09ZJVP1UIFD0N7Qh08f=S@2SXj<0Zj^[0<W9b@1hN7P0?clo03/k
>`0S8b<09BDU04I6AP0Y:BT201DE5@0b01LG5`1LG5`0KFe]09nOW`1jNWX0Vi^K09ZJVP2@T900MGEe
03Ti>@1DE5@0<C4a05IFEP1/K6`0SXj>01lO7`0J6QX0:RXZ055AD@1>CTh0AdM705EEE@2KVi/0/K6a
079bLP14A4@0E5AD0492@P2EUID0I6AT020P800L71`08b<S03hn?P1QHF40J6QX0:6QX@2n_[h0TY:B
0820P01;Bd/0C4a<0861P@0Z:RX05ADE01XJ6P0N7Qh0PH6103`l?00G5aL401DE5@0L04E5A@0k>c/0
Cdm?03Xj>P2RXZ80`<300<[:bP32`/80VYZJ0:^[Z`2YZJT0]kNg0<O7a`3<c<`0cLg=0:>SX`13@d<0
V9RH0;bl_01kNg/0Rh^;09^KV`27QhL0<C4a02LW9`0V9RH0ADE506MWI`;ooooo00001P1aLG40Z:RX
051@D01SHf<0>c/k08>3P`80Cdm?05T0TI6A06ATI00Z:RX0IfMW03@d=00W9bL0B4Q805YJFP0Z:RX0
9RHV01DE5@1:BTX0G5aL03Lg=`1ZJVX0<30`09:BTP1PH600<S8b06ATI01jNWX0M7Ad05YJFP1fMWH0
H61P03Lg=`1EEED0K6a/059BDP1VIVH0<S8b02/[:`1KFe/0JVYZ034a<@11@D40SHf=03Xj>P0o?cl0
>SXj04i>CP0R8R80=SHf05]KF`0S8b<0=cLg0410@01GEeL0AdM704A4A00Z:RX09bLW06=SH`1]KFd0
EeMG03Xj>P1DE5@0SHf=024Q8@1MGEd0Rh^;071`L016ATH0Ogmo04a<C00U9BD0:BTY08f=S@1:BTX0
CDe=05mOG`1kNg/0=3@d07MgM`1_Kfl0@D5106][J`1cLg<0=CDe08R8R01YJFT0J6QX075aL@1lO7`0
GEeM02l_;`2ZZZX0<S8b03hn?P0207YjNP0`04a<C00n?Sh0/[:b05mOG`0f=SH0EEEE08F5Q@1?Cdl0
=CDe059BDP1[Jf/0JFUY03Lg=`25QHD0MWIf03Xj>P1aLG40>CTi03De=@1^KVh0Bd];08R8R00];Bd0
?Cdm06QXJ01KFe/0@D5105eMG@1?Cdl0>c/k07QhN01LG5`0Ng]k05aLG00a<C40FEUI08:2PP1<C4`0
A4A4061PH015ADD0E5AD06EUI@1XJ6P0VIVI05IFEP1WIfL0RHV90P1>CTh01P1?Cdl0?clo06e]K@1;
Bd/0QhN70::RXP80<c<c0440OGem06e]K@1NGUh0MgMg03Lg=`1TI6@0/;2`075aL@0h>3P0EUIF08Z:
RP19BDT0C4a<07alO02;Rh/0=CDe051@D00j>SX0IfMW069RHP0m?Cd0C4a<09>CT`1`L700GemO0:BT
Y02HV9P0JFUY09nOW`39bLT0WinO065QH@26QXH0eMGE09JFUP1NGUh0ZJVY0;Jf]P1ZJVX0UIFE0=3@
d01/K6`0HV9R0<;2`P38b<P0P82004Y:BP1UIFD0P82002XZ:P1ADE40>CTi08^;R`1lO7`0Bd];0:VY
Z@1gMgL0ADE50:NWY`2?Shl0EUIF08Z:RP2`/;00PH6104Q8B00205EEE@2;07UiN@2DU9@0ATI6038b
<P1HF5P0Y:BT07AdM01<C4`0Y:BT061PH01MGEd0<c<c08R8R01iNGT0RHV907QhN00e=CD0IVIV04e=
C@1ZJVX0MgMg05iNGP0j>SX0Ph>309>CT`1<C4`0?Shn04e=C@1KFe/0E5AD06UYJ@2TY:@0Q8B404M7
A`0n?Sh0Cdm?079bLP0e=CD08b<S07=cL`1GEeL0AdM705ADE01XJ6P0AdM70;jn_P2IVIT0LG5a05eM
G@2ATI40UYJF03dm?@1aLG40TY:B07UiN@0X:2P0C4a<06=SH`17AdL0IfMW09^KV`2BTY80E5AD05EE
E@15ADD0H61P03Hf=P0K6a/0@T9207AdM018B4P0ATI605mOG`0o?cl0Bd];09JFUP1hN7P09RHV07al
O01HF5P08B4Q05aLG019BDT09bLW06IVIP2=SHd0De=C020P800o?cl0Hf=S07MgM`0k>c/0GEeM04m?
C`1OGel0/;2`0;jn_P37alL0KVi^03De=@0^;Rh0:BTY02HV9P0M7Ad08B4Q01lO7`0T92@0De=C04U9
B@11@D40UYJF0<g=c@3<c<`0LW9b075aL@0l?3`09RHV01/K6`0O7al0B4Q805YJFP1GEeL0D51@08F5
Q@0[:b/07AdM01LG5`0F5QH0@D510<G5a@2BTY80GUiN071`L00g=cL05ADE02TY:@0m?Cd06ATI01<C
4`0200h>3P0701<C4`22PX80>SXj01LG5`0D51@03Ph>00l?3`0200`<30<03@d=0P0>3Ph0901IFET0
f=SH0;no_`2VYZH0XZ:R07MgM`28R8P0PX:205aLG00c<c<04A4A00`<300F5QH0Lg=c06IVIP0M7Ad0
5aLG01DE5@0A4A405ADE010@400C4a<05ADE02d];@1@D500LG5a092@T01oOgl0IFEU09RHV02`/;00
WYjN08b<S00M7Ad051@D018B4P804a<C00<05ADE01LG5`0E5AD00P0G5aL04`0Q8B40WinO0:6QX@1e
MGD0GEeM05iNGP1[Jf/0T92@09bLW03Ph>00gmoO0;>c/`0c<c<09BDU05ADE01^KVh0=3@d030`<00Q
8B400P0E5AD06P0F5QH061PH01`L701MGEd0UiNG0:FUY@2ZZZX0U9BD08F5Q@2MWId0QHF508B4Q01`
L700O7al07IfMP1OGel0RXZ:0:BTY01PH600W9bL05eMG@18B4P0BTY:03Xj>P0c<c<0<S8b0P0k>c/0
GP1FEUH0A4A404];B`1]KFd0`<300:RXZ02TY:@0<c<c01PH600I6AT05aLG01TI6@0H61P071`L01TI
6@0K6a/0Bd];08j>SP2@T900[Jf]07IfMP1hN7P0/[:b0<S8b01aLG40>c/k03<c<`1GEeL0O7al07=c
L`16ATH0CDe=096AT@3;bl/0YjNW08Z:RP3;bl/0^KVi0::RXP30`<00[Jf]04E5A@1=CDd0SXj>04U9
B@0f=SH0:b/[01dM7@0G5aL05QHF01dM7@1PH600dm?C09fMW@2f][H0/;2`08n?S`0X:2P08B4Q03@d
=00b<S80=CDe02l_;`0M7Ad06ATI01`L700M7Ad0820P07alO02c/k<0LW9b04i>CP1UIFD0WIfM05IF
EP2MWId0KFe]03/k>`0d=3@0=CDe03@d=00H61P05aLG01HF5P0H61P05aLG04Y:BP1VIVH0IfMW030`
<016ATH0GEeM04];B`1RHV8203De=@0E05=CD`1>CTh0E5AD08f=S@1]KFd0;bl_038b<P15ADD0AdM7
05EEE@16ATH0Z:RX07emO@2l_;`0QHF504I6AP1GEeL0TY:B05aLG00V9RH07QhN008071`L00X0820P
034a<@2EUID0g=cL0;bl_03IfMT0^;Rh0=GEe@2IVIT06QXJ0P0F5QH0900I6AT0NGUi04M7A`0U9BD0
5ADE01HF5P0E5AD08b<S06MWI`1lO7`0SXj>0:ZZZP2d];@0e=CD0<K6aP2j^[X0WYjN075aL@1TI6@0
L71`06ATI01CDe<0Ogmo08N7Q`2@T900_;bl09FEU@2^[Zh0][Jf0<W9b@1YJFT09bLW02PX:00n?Sh0
HF5Q06ATI0;ooooo0000o`1bLW80YjNW055AD@1WIfL0@D51092@T01>CTh0DU9B08N7Q`1CDe<0?3`l
0820P01UIFD07alO02`/;01QHF40;2`/03hn?P0/;2`0HF5Q05]KF`0`<300N7Qh03Ph>02SXj<0IFEU
03lo?`2:RXX0S8b<075aL@1JFUX0R8R805MGE`11@D40QhN708F5Q@1IFET0I6AT034a<@0b<S80RHV9
08:2PP14A4@0@d=309>CT`0b<S80BDU902l_;`12@T808R8R05=CD`1jNWX0>CTi0451@@16ATH0@410
03hn?P1RHV80FEUI04E5A@1OGel0C4a<02l_;`0i>CT0L71`09VIV@0k>c/0BTY:0861P@1>CTh0?Shn
0::RXP1cLg<0=CDe02d];@25QHD0;Bd]04];B`1nOWh0M7Ad02d];@1]KFd0A4A402DU9@14A4@0Kfm_
03Ph>025QHD0<C4a02l_;`1>CTh0RXZ:05YJFP0d=3@0[Jf]06EUI@0S8b<0S8b<096AT@0i>CT0?3`l
0<;2`P28R8P0BDU906YZJP2HV9P0I6AT03dm?@1BDU80Hf=S07UiN@0m?Cd0UIFE06m_K`0m?Cd0PH61
065QH@1=CDd0Lg=c04M7A`2=SHd0Fe]K04M7A`1WIfL0GemO03dm?@1LG5`0Ogmo0492@P1lO7`0Fe]K
07QhN01RHV80C4a<07MgM`2?Shl0BDU904=3@`1VIVH0GEeM06UYJ@1FEUH0Hf=S09BDU01KFe/0N7Qh
08^;R`16ATH0DE5A04A4A016ATH0GUiN04I6AP2@T900ZJVY02h^;P13@d<0VIVI06i^KP1NGUh0RHV9
055AD@1WIfL0][Jf07=cL`0g=cL0IVIV09VIV@17AdL0E5AD06a/K01nOWh0FEUI07MgM`1GEeL0O7al
075aL@1OGel0Jf][0:n_[`2>SXh0UYJF0<W9b@2KVi/0MGEe0:RXZ03AdM40[jn_06EUI@2:RXX0c/k>
059BDP1VIVH0Z:RX0:JVYP19BDT0QHF50<30`01BDU80?3`l06i^KP2@T900JFUY04a<C01aLG40JVYZ
04i>CP2?Shl0BDU908J6QP1FEUH0<c<c05mOG`1VIVH0AdM70:BTY01PH600>3Ph09^KV`2SXj<0LW9b
038b<P1MGEd0>CTi0492@P1TI6@0EeMG03/k>`1?Cdl0WinO06m_K`1IFET0_Kfm0<O7a`2>SXh0D51@
0;Rh^02a/K40_;bl079bLP1;Bd/0^;Rh07inOP1mOGd0Lg=c051@D011@D40V9RH09NGU`1EEED0?Cdm
04A4A01;Bd/09BDU02/[:`00K01[Jf/0NGUi04i>CP13@d<0ADE506YZJP0U9BD07alO07MgM`1KFe/0
E5AD05EEE@1:BTX08b<S06][J`1IFET0CTi>05UIF@2>SXh0QHF505aLG022PX80Ph>307QhN00W9bL0
BTY:06=SH`0V9RH0:b/[05EEE@28R8P0EUIF059BDP16ATH0CDe=034a<@0^;Rh0Cdm?08V9R@17AdL0
?clo05eMG@0c<c<0<C4a07=cL`1LG5`0:2PX06e]K@1RHV80:2PX06a/K01aLG40<C4a06UYJ@2GUiL0
?Cdm02<S8`1?Cdl0LW9b05EEE@0h>3P0GemO04m?C`1[Jf/0@D510:ZZZP33`l<0UIFE04];B`0_;bl0
:2PX01lO7`0L71`07AdM01`L700M7Ad09RHV04Y:BP0m?Cd0PX:20<;2`P34a<@0NWYj096AT@17AdL0
DE5A051@D019BDT0=cLg04Q8B01:BTX0Ogmo08R8R00b<S80=cLg055AD@1SHf<0QHF50:BTY03<c<`0
IVIV0492@P1XJ6P0PH6108^;R`0P82007alO01/K6`803`l?03806ATI08J6QP0];Bd05aLG010@400C
4a<03`l?01<C4`0>3Ph02PX:00T92@0=3@d03Ph>01/K6`2PX:00VYZJ08V9R@1]KFd0T92@0;Vi^@26
QXH0XZ:R03Hf=P0n?Sh0?Cdm04m?C`1fMWH0_kno03@d=00B4Q804A4A00h>3P0A4A403Ph>01DE5@0N
7Qh0<C4a04M7A`1@D500=3@d01/K6`1@D500ADE508F5Q@2SXj<0IFEU06e]K@0_;bl04A4A00d=3@80
3Ph>07H05ADE01PH600E5AD05aLG01PH601CDe<0[Zj^07MgM`1JFUX0J6QX08b<S029RHT0UIFE08Z:
RP3Hf=P0dm?C0;6a/@0e=CD092@T03/k>`0f=SH051@D01LG5`0Z:RX0=cLg02@T900N7Qh05aLG01`L
701YJFT0U9BD0:BTY02j^[X0Ti>C06m_K`2>SXh0DE5A04A4A01TI6@0G5aL03dm?@0g=cL0>CTi08J6
QP1KFe/0G5aL05=CD`0U9BD0;Rh^04U9B@12@T80?Cdm03Ti>@0h>3P0?3`l07IfMP2@T900/K6a0=7A
d@30`<00Y:BT07emO@0I6AT071`L01LG5`0I6AT05aLG01TI6@0J6QX09BDU075aL@1YJFT0GemO07in
OP1OGel0Cdm?0;Zj^P2l_;`0TY:B04I6AP0i>CT0;bl_03Lg=`1>CTh0Hf=S06MWI`1HF5P0R8R80=;B
dP3Ph>00inOW08:2PP2^[Zh0[Jf]055AD@1?Cdl0Q8B402l_;`0I6AT061PH01TI6@0J6QX05QHF01LG
5`0[:b/0@D510:2PX02CTi<0WIfM07QhN02>SXh0AdM704=3@`0f=SH08b<S01dM7@0I6AT06QXJ0P0G
5aL03P0M7Ad0;2`/04a<C02a/K40NGUi07YjNP12@T80K6a/04e=C@1?Cdl0;2`/0451@@0j>SX0;2`/
0P0F5QH301DE5@1B020P800i>CT0DU9B051@D00i>CT0=cLg059BDP0n?Sh0Ph>306UYJ@1MGEd0Bd];
06ATI02:RXX0^k^k0<o?c`2EUID0QhN709BDU02HV9P0YjNW0;bl_03=cLd0Kfm_07moO`2JVYX0DU9B
09BDU01mOGd0Bd];028R8P0N7Qh071`L01dM7@0V9RH0Hf=S0;6a/@2HV9P0[Jf]0<K6aP2GUiL0bLW9
09FEU@22PX80>SXj01XJ6P0I6AT0Cdm?08N7Q`1NGUh0=cLg03dm?@1RHV80RXZ:0:NWY`2KVi/0XZ:R
08j>SP2JVYX0bLW90<k>cP2[Zj/0[:b/04m?C`0^;Rh0>SXj059BDP1^KVh0RHV908^;R`2OWil0^;Rh
0<k>cP3@d=00f][J0<W9b@2EUID0>c/k0451@@1ZJVX0MGEe05MGE`;ooooo0000901TI6@0RHV904i>
CP16ATH0?3`l07UiN@19BDT0DU9B07]kN`11@D409BDU069RHP1FEUH07alO02`/;00m?Cd0?3`l05aL
G00d=3@0H61P03Xj>P0e=CD0Kfm_030`<02IVIT0=cLg02/[:`1EEED0GemO05YJFP1>CTh0RXZ:04m?
C`0X:2P0H61P06YZJP80IfMW06408B4Q028R8P1@D500Kfm_04A4A016ATH0WYjN030`<013@d<0>3Ph
03dm?@0N7Qh0=3@d05YJFP0g=cL0ADE504a<C01NGUh0BDU90492@P1BDU80@D5105mOG`1:BTX0=cLg
02PX:01<C4`0J6QX03<c<`1?Cdl0M7Ad03<c<`0`<300M7Ad05IFEP0d=3@0;Bd]09:BTP0m?Cd0ATI6
05YJFP1[Jf/09BDU07MgM`1kNg/0?Shn04];B`1MGEd0=SHf07inOP1?Cdl0EEEE07AdM02;Rh/0Bd];
03<c<`2i^KT0N7Qh02DU9@27QhL0Ogmo01/K6`1SHf<0ZZZZ0820P00o?cl0Jf][09NGU`1@D500Jf][
0:2PX02HV9P0MgMg03/k>`1lO7`0G5aL04e=C@2>SXh0GemO059BDP1_Kfl0De=C0:^[Z`1[Jf/0BDU9
06=SH`1BDU80L71`0:>SX`23Ph<0ADE506][J`19BDT0TY:B07YjNP1?Cdl0Ph>30080FEUI09H0SHf=
092@T01SHf<0IVIV05UIF@23Ph<0/K6a06ATI01mOGd0Lg=c04a<C02MWId0Jf][04e=C@1RHV80=3@d
07YjNP2k^k/0CDe=04Q8B02KVi/0MGEe06MWI`1nOWh0FEUI05aLG02j^[X0L71`05aLG02LW9`0WinO
04];B`1LG5`0IfMW05]KF`0d=3@0LW9b05iNGP1eMGD0HF5Q04M7A`1nOWh0^[Zj08n?S`2PX:00`<30
08^;R`0n?Sh0Rh^;0:NWY`2<S8`0ATI609NGU`38b<P0M7Ad055AD@2n_[h0[:b/05ADE027QhL0a/K6
05MGE`1EEED0O7al0;Jf]P21PH40C4a<06YZJP1VIVH0A4A406IVIP0l?3`0P82008B4Q011@D40NWYj
08j>SP1ADE40ZJVY07IfMP10@400OGem09nOW`1/K6`071`L02d];@0l?3`0Cdm?069RHP13@d<0:b/[
06=SH`26QXH0HV9R0451@@23Ph<0H61P0861P@1<C4`0bLW90:f][@2d];@0Lg=c02/[:`1TI6@0MWIf
079bLP1ZJVX0F5QH02PX:01]KFd0VIVI06IVIP12@T80A4A406=SH`1DE5@0@41006YZJP1nOWh0BDU9
04E5A@17AdL0IFEU01lO7`15ADD0WinO07EeM@1CDe<0FEUI05]KF`12@T80OWin04Y:BP18B4P0Hf=S
07alO01iNGT0GemO0::RXP2QXJ40OGem02/[:`1MGEd0PX:20492@P1NGUh0EUIF07QhN01TI6@204a<
C00V05mOG`1?Cdl08R8R04E5A@1]KFd0FEUI03dm?@1dM7@0Cdm?03hn?P1fMWH0<c<c024Q8@1bLW80
@d=302LW9`1TI6@0Jf][02/[:`1<C4`0SHf=04U9B@0b<S80EeMG07IfMP1WIfL0<c<c07YjNP1XJ6P0
OGem03De=@28R8P0dm?C0<K6aP2i^KT0FUYJ03Ph>00R8R8201/K6`80820P02007AdM02/[:`1YJFT0
XZ:R0:^[Z`2KVi/0aLG50:6QX@1MGEd0B4Q804I6AP12@T80:2PX02/[:`1lO7`0^KVi096AT@1gMgL0
IFEU04=3@`0^;Rh09RHV02`/;01[Jf/0Z:RX069RHP0m?Cd0C4a<09NGU`0N7Qh0410@01<C4`803@d=
00L07AdM06][J`0V9RH0410@00l?3`0=3@d03`l?00<03@d=01X020P800d=3@0E5AD0RXZ:06MWI`0O
7al0;Bd]05iNGP1UIFD0RHV90;:b/P2i^KT0NGUi05mOG`2EUID0]KFe0;Zj^P2ZZZX0UIFE04I6AP0Z
:RX0:BTY03Hf=P0m?Cd0ADE503lo?`80;bl_00`05ADE01<C4`0A4A408B4Q06UYJ@1JFUX0PH6108V9
R@1SHf<0DU9B01lO7`0@410200h>3P0E014A4@0G5aL05ADE02<S8`1aLG40W9bL06i^KP0e=CD0<30`
02h^;P0f=SH0EEEE06ATI00h>3P0Rh^;0;no_`2>SXh0KVi^01hN7P0d=3@0<S8b0080410@03804A4A
01LG5`0a<C40HV9R04m?C`1fMWH0NWYj04A4A01hN7P0QXJ607QhN01gMgL0QhN701lO7`0H61P09BDU
03/k>`1NGUh0@4100451@@1/K6`0G5aL069RHP1TI6@0DU9B03/k>`0_;bl0?Shn04Y:BP0o?cl0B4Q8
04U9B@2FUYH0dm?C09>CT`1WIfL0U9BD09RHV027QhL0FEUI02LW9`0J6QX071`L01XJ6P0H61P07AdM
061PH01gMgL0S8b<05=CD`80F5QH01T0Shn?04=3@`0Y:BT0IfMW04m?C`0Q8B4071`L03<c<`1LG5`0
Cdm?06m_K`34a<@0^KVi0<c<c03Ph>00hN7Q09>CT`3Fe]H0[:b/038b<P0h>3P0HF5Q03/k>`0T92@0
6ATI00805aLG02405QHF01`L700j>SX09bLW07alO01fMWH0Shn?08Z:RP2BTY80<c<c02HV9P0I6AT0
6QXJ01`L700J6QX06a/K01TI6@0M7Ad0;2`/051@D01UIFD0=3@d06e]K@1kNg/0J6QX05UIF@1MGEd0
A4A402PX:00d=3@0?Cdm024Q8@0L71`0100E5AD07`0R8R80@T9205YJFP14A4@0@d=304e=C@1hN7P0
J6QX05]KF`0X:2P0?3`l07EeM@2^[Zh0a<C40;jn_P3<c<`0GEeM07EeM@2@T900LG5a07]kN`1`L700
U9BD0<k>cP2SXj<0[jn_0;bl_039bLT0OWin03De=@0R8R800P0S8b<0700n?Sh0J6QX0:VYZ@1WIfL0
@d=308J6QP2][Jd0K6a/06ATI01BDU80C4a<06m_K`1MGEd0De=C05EEE@3>c/h0`L7109fMW@1nOWh0
HV9R071`L02:RXX0O7al06MWI`1ZJVX0EUIF0<G5a@2f][H209jNWP0C07IfMP1]KFd0PX:2065QH@0o
?cl0=SHf03@d=00/;2`0FUYJ09FEU@2YZJT0b<S80<?3``2c/k<0^KVi09ZJVP2NWYh0B4Q801lO7`02
ooooo`000540NWYj09bLW01:BTX0KVi^03hn?P1gMgL0C4a<055AD@2SXj<0NGUi03`l?020P800MGEe
024Q8@0d=3@0G5aL024Q8@1:BTX0;2`/069RHP0n?Sh0:BTY06i^KP0g=cL0P82006IVIP19BDT0EeMG
07EeM@1_Kfl0B4Q80:6QX@1TI6@0=3@d07moO`25QHD0HV9R07YjNP0l?3`0<30`05IFEP1]KFd092@T
03lo?`2EUID0EEEE06EUI@1;Bd/0ADE502XZ:P0o?cl0IVIV03`l?01FEUH0QHF506i^KP1=CDd0@T92
04m?C`19BDT0XJ6Q07IfMP0m?Cd0:RXZ06ATI01WIfL0;Rh^04i>CP1oOgl0I6AT0410@027QhL0Bd];
02h^;P0c<c<0YJFU05ADE01SHf<0De=C051@D00[:b/00P1fMWH08@0o?cl0ADE505UIF@1lO7`0S8b<
03Xj>P1ADE40PX:2092@T014A4@0@4100;fm_@22PX809bLW08R8R01lO7`08B4Q03Ti>@2b/[80Ogmo
03`l?01cLg<0R8R804M7A`0^;Rh0ATI606EUI@1bLW80=3@d079bLP1NGUh0=SHf07AdM00204Q8B03o
05ADE00n?Sh0NGUi055AD@13@d<0E5AD02l_;`0g=cL0HV9R06e]K@11@D40K6a/04U9B@1kNg/0KVi^
0492@P1^KVh0OGem0410@01:BTX0L71`051@D01NGUh0ATI605iNGP2GUiL0I6AT06UYJ@1aLG40Bd];
08f=S@1_Kfl0C4a<06MWI`1OGel0PH6109FEU@1EEED0Bd];09FEU@1WIfL0OWin09NGU`1>CTh0FUYJ
0;Rh^01>CTh0>c/k05aLG02RXZ80C4a<05eMG@1XJ6P0OGem03Ti>@1XJ6P0BDU907AdM01QHF40C4a<
05YJFP28R8P0SHf=0:RXZ034a<@0M7Ad06UYJ@2m_Kd0aLG509FEU@1WIfL0WinO0<O7a`23Ph<0GEeM
0;Rh^02[Zj/0FEUI08n?S`3Cdm<0RXZ:075aL@2MWId0_kno07AdM01<C4`0J6QX06][J`0_;bl0D51@
03<c<`1oOgl0P82004A4A01eMGD0L71`04E5A@2ZZZX0NWYj05ADE02ZZZX0WIfM06a/K00N7Qh092@T
03Lg=`1GEeL0IFEU04a<C00e=CD0FEUI08Z:RP1aLG40E5AD09fMW@1hN7P0J6QX03Ti>@2f][H0T92@
0:2PX01mOGd0>CTi06m_K`24Q8@0MWIf07moO`1VIVH0:BTY06][J`2XZ:P0J6QX03lo?`1MGEd0R8R8
05MGE`13@d<0JFUY07emO@1;Bd/0EUIF079bLP1iNGT0A4A4024Q8@25QHD0GEeM04m?C`1EEED0LW9b
04a<C01mOGd0HV9R05ADE01QHF40ZZZZ08R8R01cLg<0a/K60<S8b01VIVH07AdM055AD@1mOGd0FEUI
06MWI`1aLG40NWYj04A4A01@D500GEeM07IfMP1iNGT0;bl_04e=C@1_Kfl0?Shn0410@02;Rh/0HF5Q
04A4A02CTi<0JVYZ02d];@1/K6`0Fe]K01dM7@1<C4`0HV9R03De=@0l?3`0VYZJ03dm?@0b<S80NWYj
0:2PX01lO7`08B4Q051@D01GEeL0MWIf03Lg=`28R8P0f=SH0=CDe02g]kL0]KFe0::RXP2:RXX0KFe]
055AD@0h>3P0;Rh^038b<P1GEeL0/K6a0<;2`P2FUYH0_;bl0<C4a02OWil0O7al07]kN`29RHT0LG5a
0451@@1HF5P0IfMW05aLG00c<c<0?Shn03/k>`0_;bl0:BTY02d];@0R8R806QXJ05ADE028R8P0?Shn
01LG5`1HF5P0HF5Q01DE5@0B4Q804A4A00d=3@0G5aL0GemO01hN7P0=3@d02PX:00P8200?3`l010@4
008030`<01T0410@020P801/K6`0CTi>01/K6`0P82009RHV01LG5`15ADD0FEUI0;>c/`37alL0b<S8
0<O7a`2m_Kd0T92@05ADE00V9RH0C4a<09RHV01mOGd0>3Ph02DU9@0I6AT05QHF00805ADE09D07AdM
01DE5@0D51@04Q8B01PH600m?Cd0R8R809RHV02/[:`0GEeM03Ph>014A4@061PH00h>3P0@41003`l?
01dM7@12@T80U9BD06i^KP1KFe/09bLW01XJ6P0K6a/05aLG01TI6@0O7al0F5QH02<S8`0a<C40WIfM
0;Bd]01cLg<0B4Q802l_;`0g=cL03Ph>01LG5`0N7Qh0820P02TY:@1/K6`0b<S80=7Ad@24Q8@0Y:BT
09>CT`26QXH0EeMG07MgM`0d=3@05QHF01DE5@0n?Sh092@T04A4A01EEED0A4A406IVIP1dM7@0EeMG
07UiN@1OGel0:RXZ02d];@0g=cL0BTY:05=CD`0a<C40OWin0;Fe]@28R8P0IFEU02LW9`2ATI40_;bl
06ATI01@D500LG5a04Q8B00P82006a/K01TI6@0j>SX0VIVI07alO01kNg/0D51@06QXJ02<S8`0>3Ph
01LG5`0E5AD06ATI06MWI`1IFET0:BTY038b<P0`<300A4A40:2PX03Bd]80_[jn0;Vi^@38b<P0g]kN
0;Vi^@3IfMT0a/K603hn?P11@D407QhN01dM7@0`<300DE5A034a<@0];Bd0>3Ph05iNGP1MGEd06QXJ
04a<C01RHV80YJFU09RHV02@T900>SXj01PH600I6AT071`L01dM7@0L71`07alO034a<@12@T80F5QH
04e=C@0U9BD0:2PX03dm?@2;Rh/0TI6A07MgM`2][Jd0CTi>02/[:`0a<C40?Cdm02d];@0202`/;015
01TI6@0V9RH0<c<c04A4A02:RXX0RHV904U9B@18B4P0Ng]k08>3P`1nOWh0IFEU03Hf=P0a<C40=cLg
092@T02_[jl0clo?0<g=c@2o_kl0U9BD07inOP1HF5P0EEEE06][J`2VYZH0fm_K0:ZZZP2i^KT0S8b<
0;6a/@2UYJD0G5aL02`/;010@400DU9B04m?C`1aLG40Hf=S02<S8`1<C4`0Ng]k06=SH`2MWId0Ng]k
05MGE`1:BTX0?Cdm04I6AP10@400NWYj0=SHf02e]KD0@41003Hf=P1:BTX0JFUY0<S8b02l_;`0YjNW
06][J`1YJFT0^KVi04Y:BP0h>3P0Bd];05IFEP21PH4092@T00806ATI0P0Q8B402P0W9bL0>SXj07mo
O`28R8P0/;2`0;no_`2PX:00S8b<0;Fe]@17AdL201lO7`;ooooo0000_@1lO7`0PH61051@D01`L700
?Cdm06][J`1>CTh0M7Ad0:b/[01`L700?3`l07inOP1GEeL0;bl_05MGE`1[Jf/09bLW04U9B@12@T80
LG5a05UIF@0f=SH0HF5Q03<c<`1fMWH0IVIV05QHF01DE5@0Kfm_03Ph>01GEeL0UiNG07moO`0d=3@0
LW9b04Q8B00j>SX0KVi^05ADE00c<c<0FEUI07alO00L71`0=SHf07inOP1ADE40De=C034a<@1:BTX0
8R8R03Hf=P1MGEd06QXJ03@d=01IFET0D51@0410@015ADD0<c<c038b<P1EEED0D51@04=3@`0W9bL0
H61P06MWI`0Z:RX0Ogmo09BDU01hN7P0?clo0861P@12@T80;Rh^05MGE`2<S8`0DE5A05YJFP1;Bd/0
Hf=S034a<@1RHV80OWin03dm?@15ADD0AdM702l_;`1[Jf/0AdM7051@D01nOWh0UiNG02LW9`0c<c<0
XJ6Q075aL@0U9BD0Q8B40820P00a<C40A4A40<71`@1mOGd0>3Ph07moO`2VYZH0IVIV04i>CP1QHF40
O7al08N7Q`0i>CT0MgMg06IVIP15ADD0Ti>C05QHF016ATH0M7Ad05aLG02FUYH0GemO03Xj>P1QHF40
De=C04A4A01nOWh0MWIf03/k>`1_Kfl0EeMG08f=S@1aLG40>c/k06a/K02:RXX0CTi>05IFEP27QhL0
EEEE05IFEP1hN7P0KVi^09bLW01TI6@0HV9R0861P@1CDe<0MWIf04i>CP17AdL0J6QX06EUI@2SXj<0
ZJVY03Hf=P12@T80WIfM0820P01RHV80QhN703lo?`1ADE40[jn_075aL@19BDT0M7Ad0:>SX`13@d<0
EUIF07EeM@1mOGd0?clo05mOG`10@400M7Ad05aLG011@D40Hf=S08:2PP2ATI40YZJV0;Bd]028R8P0
OWin0<C4a035aLD0WinO06m_K`020<K6aP2O08:2PP1YJFT0_;bl096AT@0j>SX0Ogmo0<G5a@1MGEd0
Jf][09VIV@2SXj<0C4a<04e=C@1^KVh0EeMG03@d=01=CDd0=3@d08^;R`1iNGT0BTY:071`L01ADE40
<30`09BDU01NGUh0DE5A0<71`@2][Jd0AdM702/[:`0m?Cd0>c/k06MWI`1[Jf/0:BTY02d];@1FEUH0
UIFE08J6QP1ADE40WinO06][J`1iNGT0>c/k0:f][@2i^KT0]KFe08V9R@0h>3P0KFe]07MgM`1ZJVX0
WinO07YjNP17AdL0RHV90:FUY@0l?3`0>c/k05QHF01XJ6P0?clo05MGE`2?Shl0O7al04m?C`0j>SX0
G5aL069RHP11@D40;bl_09^KV`12@T80?Cdm05UIF@1PH600ADE5096AT@21PH40EUIF03Ph>01XJ6P0
N7Qh04m?C`2h^;P0XJ6Q07QhN00Y:BT0AdM707EeM@0f=SH0P8200:n_[`2JVYX0>SXj03/k>`1SHf<0
R8R806ATI00j>SX0KVi^08J6QP17AdL0=3@d07YjNP0o?cl0=cLg07inOP28R8P0=SHf075aL@1TI6@0
71`L04Y:BP1_Kfl0D51@03Lg=`2JVYX0Cdm?02PX:01ADE40LG5a07emO@0j>SX0H61P04M7A`1VIVH0
CDe=0:RXZ03Fe]H0YJFU04a<C014A4@0Fe]K08N7Q`2h^;P0c<c<0<_;b`2o_kl0[jn_0<;2`P3Cdm<0
eMGE0=WIf@3Hf=P0];Bd05EEE@14A4@0>CTi03<c<`0[:b/0<c<c05IFEP1@D500:b/[01LG5`0C4a<0
4A4A00<03Ph>02P03@d=00h>3P0@4100Bd];06i^KP13@d<0;Bd]05mOG`13@d<04Q8B01LG5`0=3@d0
51@D065QH@0V9RH030`<00/;2`092@T030`<01<C4`0>3Ph03@d=01DE5@1LG5`0Bd];01LG5`0H61P0
9BDU01LG5`0D51@05ADE01TI6@2VYZH0cLg=0<_;b`33`l<0]KFe08j>SP1RHV80AdM70P0[:b/0101a
LG40TI6A04=3@`0G5aL501DE5@1H01LG5`0J6QX06ATI055AD@2JVYX0OGem0820P01]KFd0>c/k03Ph
>00o?cl03`l?00d=3@0C4a<0QXJ609RHV01>CTh0FUYJ01`L700J6QX06ATI01XJ6P0F5QH06ATI01/K
6`16ATH0<C4a01dM7@1WIfL0c<c<06e]K@2:RXX0Hf=S06MWI`10@400=CDe030`<00a<C40>CTi06EU
I@1VIVH0WIfM0:NWY`2o_kl0QXJ608^;R`24Q8@0Hf=S04A4A00I6AT05aLG04E5A@0];Bd08B4Q04i>
CP1=CDd0Cdm?08b<S01DE5@0IfMW05IFEP0^;Rh05QHF01LG5`0I6AT0=cLg07]kN`1DE5@0Q8B409VI
V@1gMgL0NWYj09:BTP3=cLd0N7Qh02<S8`0g=cL0IVIV08J6QP1KFe/0:RXZ08J6QP24Q8@0UYJF06EU
I@26QXH0X:2P03@d=0@05ADE02H0:2PX04U9B@1EEED0=3@d02d];@0S8b<0K6a/06e]K@1KFe/0_kno
0=CDe03YjNT0eMGE06UYJ@1WIfL0<30`03Lg=`0K6a/071`L038b<P1hN7P0De=C03Hf=P0d=3@0=CDe
05ADE00O7al0<C4a07IfMP1mOGd0V9RH08>3P`0f=SH061PH01`L700O7al0:2PX03@d=080?Shn01/0
C4a<03lo?`0g=cL0<c<c02DU9@0];Bd0I6AT092@T02NWYh0ZZZZ06m_K`23Ph<0OWin0:JVYP2g]kL0
Y:BT06QXJ01ADE40E5AD05EEE@1nOWh0`<300:b/[01lO7`0IFEU04=3@`1/K6`00P1bLW80B@1<C4`0
=CDe04e=C@2BTY80Z:RX0:ZZZP1NGUh0];Bd0;Jf]P34a<@0^[Zj0:6QX@2a/K40`L710<S8b02c/k<0
_[jn0;no_`2RXZ80QXJ60::RXP2;Rh/0NWYj05aLG01lO7`0Kfm_02HV9P10@400FEUI03<c<`13@d<0
E5AD07YjNP2KVi/0HV9R05iNGP1IFET0IFEU0;>c/`2o_kl0JVYZ05QHF01YJFT0Rh^;08V9R@2YZJT0
LG5a0;jn_P26QXH0^KVi0:>SX`0`<300;bl_04m?C`0m?Cd0;Bd]01XJ6P0F5QH061PH01DE5@0I6AT0
820P02l_;`1UIFD0S8b<07=cL`2`/;00[jn_092@T02BTY808R8R01`L700O7al00_ooool0000]07]k
N`19BDT0Cdm?06YZJP0l?3`0E5AD02HV9P0k>c/0Lg=c05EEE@0d=3@0H61P01@D500C4a<07AdM03lo
?`0U9BD071`L01@D500Y:BT0=cLg02LW9`1>CTh09BDU05eMG@1LG5`0Cdm?04I6AP1BDU80Bd];04I6
AP2GUiL0OGem02h^;P1WIfL0NGUi04Y:BP1OGel0ADE502h^;P1HF5P0OWin04Y:BP1EEED0RHV90080
AdM70?l0?3`l03Xj>P0L71`0;2`/04Q8B00^;Rh0C4a<05EEE@1QHF40?clo03`l?01>CTh0Fe]K07em
O@1WIfL0ATI602@T901NGUh0GemO02@T900j>SX0KVi^05aLG00n?Sh0OWin04U9B@0Y:BT0=SHf09:B
TP14A4@0DU9B04Y:BP1ZJVX0?Cdm06i^KP1cLg<0>CTi051@D01VIVH0ADE507inOP0g=cL0D51@09>C
T`2NWYh0@d=303@d=02TY:@0FUYJ02TY:@22PX80R8R803hn?P1QHF40/k>c07EeM@0b<S80MGEe08N7
Q`15ADD0EEEE06YZJP20P800G5aL038b<P2=SHd0GEeM05IFEP2TY:@0Fe]K05EEE@21PH40KFe]0:JV
YP1YJFT0C4a<06UYJ@1EEED0CDe=08F5Q@1TI6@0B4Q807YjNP1QHF40Zj^[06EUI@12@T80Ogmo079b
LP1IFET0K6a/07MgM`15ADD0GemO06QXJ01TI6@0UIFE05ADE01cLg<0Rh^;04e=C@2=SHd0F5QH03hn
?P1OGel0ADE509RHV02l_;`0:b/[04I6AP2VYZH0OGem06MWI`1aLG40@D5106MWI`2j^[X0MgMg05IF
EP2NWYh0Ti>C03Ti>@1XJ6P0R8R806EUI@1OGel0RHV90451@@26QXH0K6a/04m?C`1^KVh0UIFE07Qh
N02CTi<0_kno07EeM@1^KVh0_Kfm0<?3``1NGUh0B4Q80;^k^`2GUiL0ADE506YZJP2UYJD0Ogmo03lo
?`29RHT0bLW9059BDP20P800VIVI0:^[Z`1NGUh0Bd];061PH01GEeL0DE5A06QXJ00j>SX0Rh^;07Ad
M01=CDd0R8R8065QH@12@T80VYZJ03`l?00_;bl0ZZZZ08V9R@13@d<0=CDe02HV9P0N7Qh0J6QX07Mg
M`13@d<0:b/[03`l?01eMGD0LW9b04];B`2^[Zh0LG5a06QXJ00k>c/0WIfM07alO02QXJ40PH610410
@02<S8`0GEeM04m?C`1nOWh0F5QH03Hf=P1bLW80SHf=04A4A00g=cL0CDe=055AD@0k>c/0?Shn05MG
E`1dM7@0GemO04];B`1IFET0HV9R03Xj>P19BDT0V9RH06EUI@19BDT0EeMG05aLG013@d<0IFEU06UY
J@1[Jf/0EEEE092@T02<S8`0JFUY0;fm_@2BTY80NGUi02TY:@19BDT0OGem05iNGP1IFET0EUIF08R8
R01TI6@0@41005MGE`1kNg/0@41002LW9`15ADD0De=C059BDP0c<c<0Ogmo0410@00i>CT0MGEe08:2
PP0h>3P002`0NGUi071`L00Q8B40Bd];05iNGP0b<S80DU9B0;>c/`1LG5`0=3@d05mOG`1`L700NGUi
03hn?P1^KVh0@T9207UiN@2GUiL0F5QH06YZJP2j^[X0IfMW03De=@0W9bL092@T034a<@1?Cdl0SHf=
0:ZZZP2e]KD0c/k>0=[JfP3Fe]H0d=3@0<o?c`1fMWH0;bl_02XZ:P13@d<0GUiN04U9B@1QHF40C4a<
010@40<03Ph>0P0=3@d300h>3P803@d=04803`l?05UIF@1UIFD0ATI602HV9P1ZJVX0>3Ph00h>3P0=
3@d04a<C06][J`0];Bd030`<00T92@0<30`03@d=010@400=3@d05QHF061PH011@D4051@D01LG5`0M
7Ad07QhN018B4P0C4a<06ATI02h^;P36a/H0/k>c08B4Q02RXZ80OGem08J6QP21PH40IFEU06UYJ@1Q
HF40@41004i>CP2=SHd0MWIf02XZ:P0G5aL05ADE01LG5`0O7al0;2`/02PX:016ATH0?Cdm09ZJVP30
`<00De=C05QHF01SHf<0=3@d0451@@0O7al051@D03<c<`1JFUX0GEeM0492@P0O7al201XJ6P0[01PH
600G5aL061PH01LG5`0N7Qh0<C4a04=3@`0S8b<0J6QX0<c<c037alL0c/k>0=GEe@3:b/X0YjNW08J6
QP1hN7P0Lg=c07AdM01oOgl0SXj>09bLW02f][H0dM7A0=KFeP37alL0ZZZZ06EUI@22PX80@d=304M7
A`2>SXh0;2`/01hN7P0[:b/0GemO04M7A`1jNWX0JFUY05]KF`0i>CT0ADE501LG5`0201DE5@0H01LG
5`0k>c/0clo?0;2`/02m_Kd0UIFE02XZ:P0I6AT0GemO08j>SP0Z:RX07alO02<S8`1HF5P0UiNG0;>c
/`2][Jd0UIFE08Z:RP2BTY80SHf=030`<00^;Rh05ADE0P0G5aL08P0E5AD05QHF01LG5`1<C4`0F5QH
03`l?00n?Sh0R8R805MGE`19BDT0@4100:BTY03WinL0]KFe05=CD`1eMGD0HF5Q06ATI019BDT0CDe=
04Y:BP0[:b/07AdM01TI6@0K6a/06ATI02/[:`0d=3@07alO08b<S01MGEd0];Bd08^;R`1aLG4202TY
:@1[02h^;P0`<300<S8b0492@P1EEED0:b/[01dM7@0l?3`09RHV02<S8`0Q8B40<S8b0;2`/032`/80
XZ:R04M7A`1LG5`0QXJ607EeM@1YJFT0N7Qh0:BTY02l_;`0VIVI07moO`1^KVh0YJFU092@T02m_Kd0
R8R805=CD`1KFe/0Jf][04i>CP1=CDd0PH610:>SX`2VYZH0Y:BT03Xj>P0f=SH0De=C03Xj>P1KFe/0
UIFE08j>SP3<c<`0Zj^[0;no_`1mOGd0alO70:2PX02_[jl0WIfM0:2PX02m_Kd0`/;20:NWY`27QhL0
@D5105ADE01_Kfl0;bl_01dM7@0W9bL0Cdm?07=cL`3=cLd0f=SH0=7Ad@2n_[h0a/K60=3@d02^[Zh0
H61P079bLP1lO7`0CTi>04M7A`1>CTh0OGem09ZJVP2j^[X0gmoO0:VYZ@1=CDd0AdM704a<C01DE5@0
:b/[01lO7`0L71`06ATI01`L700J6QX092@T04m?C`1HF5P0SXj>061PH01]KFd0_;bl0::RXP2XZ:P0
;2`/02LW9`0a<C400_ooool0001[07inOP1YJFT0@41004m?C`0n?Sh0MWIf03hn?P1@D500Lg=c03Ti
>@0e=CD0KVi^04m?C`0M7Ad0>SXj069RHP0Y:BT0D51@02l_;`1gMgL0I6AT028R8P1RHV80?3`l0820
P01XJ6P0Bd];05ADE01:BTX0F5QH055AD@2FUYH0IfMW02l_;`1dM7@0N7Qh05YJFP1OGel0:b/[02d]
;@1bLW80MGEe0410@01XJ6P0Kfm_0451@@1<C4`0EEEE05=CD`0I6AT0>3Ph06IVIP0i>CT0G5aL07em
O@1NGUh0=cLg05ADE01BDU80CTi>0:JVYP23Ph<0?Cdm02XZ:P1cLg<0KFe]03De=@1>CTh0OGem069R
HP15ADD0V9RH04m?C`0X:2P0?Cdm08J6QP0f=SH0Cdm?065QH@1[Jf/0ADE509FEU@1XJ6P0<30`05eM
G@1DE5@0Ph>307UiN@0S8b<0@T9208N7Q`2CTi<0?3`l03/k>`2KVi/0Cdm?020P8026QXH0SHf=03<c
<`17AdL0/;2`08N7Q`15ADD0QXJ60:6QX@1LG5`00P19BDT0G`1bLW80R8R803Xj>P23Ph<0HF5Q0410
@01lO7`0Bd];0492@P1EEED0H61P09>CT`19BDT0?Cdm04];B`0c<c<0Cdm?09:BTP1BDU80@41006e]
K@19BDT0OWin05UIF@11@D40J6QX06YZJP15ADD0FEUI06e]K@1?Cdl0D51@04m?C`1aLG40QXJ605iN
GP1lO7`0JFUY04];B`1oOgl0C4a<04];B`1SHf<0FEUI07MgM`2RXZ80De=C0451@@2QXJ40M7Ad0820
P02=SHd0@d=305ADE02f][H0FUYJ05ADE01lO7`0SXj>04A4A01GEeL0Kfm_065QH@17AdL0RXZ:04U9
B@1UIFD0FEUI0492@P28R8P0YJFU07YjNP2=SHd0W9bL051@D01CDe<0alO70;fm_@2ATI40DE5A0;no
_`2QXJ40K6a/05]KF`2RXZ80KFe]03Ti>@2=SHd0dM7A06MWI`2MWId0YZJV0:VYZ@1VIVH0EUIF0080
IFEU0400:RXZ05YJFP19BDT0T92@059BDP14A4@0Kfm_05aLG014A4@0Ti>C059BDP1:BTX0]kNg096A
T@1:BTX0B4Q803De=@0S8b<0HF5Q05]KF`0c<c<09BDU0410@01^KVh0H61P03hn?P2=SHd0SXj>06i^
KP1<C4`0`<3009nOW`2^[Zh0Bd];02d];@1[Jf/0G5aL06m_K`2CTi<0MWIf03Ti>@1oOgl0VYZJ059B
DP0g=cL0D51@05iNGP14A4@0@41006ATI01`L700GEeM04I6AP1KFe/0JFUY024Q8@1LG5`0YjNW06a/
K015ADD0EeMG07QhN01@D500JVYZ0P1SHf<0>01FEUH0R8R808J6QP1ZJVX0`<300:BTY01hN7P0:RXZ
05YJFP2OWil0Kfm_05UIF@1?Cdl0KVi^028R8P1BDU80VIVI0:6QX@1JFUX0<c<c04m?C`1OGel0DU9B
03@d=02OWil0D51@03Ti>@1]KFd0GEeM02l_;`25QHD0MGEe028R8P1GEeL0Ogmo05UIF@0L71`0Lg=c
04Q8B00`<300Hf=S065QH@1DE5@0;Rh^08j>SP1TI6@0TY:B05ADE012@T80=SHf0:j^[P1oOgl0BTY:
02l_;`0U9BD07alO0P0Q8B400`0c<c<0CDe=09^KV`020=KFeP0=0=GEe@2_[jl0>CTi01PH600];Bd0
;bl_03`l?01OGel0A4A402HV9P0?3`l03@d=00h>3P0200d=3@0500`<300=3@d03@d=00d=3@0<30`0
0P0=3@d0AP0C4a<0GUiN065QH@13@d<0=3@d075aL@0_;bl03@d=01XJ6P1`L700<c<c00l?3`0=3@d0
30`<00h>3P0=3@d05ADE05eMG@0n?Sh06a/K01LG5`0E5AD09bLW01<C4`0F5QH06ATI03Xj>P2TY:@0
ZJVY02<S8`0@4100De=C07moO`0k>c/0Shn?07IfMP1UIFD0FUYJ02`/;00N7Qh09bLW06MWI`2^[Zh0
L71`0410@00g=cL0B4Q80410@019BDT08B4Q04i>CP2m_Kd0/k>c05=CD`0o?cl0Kfm_06MWI`16ATH0
A4A402`/;00d=3@0>SXj01XJ6P0O7al07AdM01`L700N7Qh06QXJ01LG5`0I6AT201XJ6P0:02XZ:P1F
EUH0:RXZ06e]K@2WYjL0Rh^;0<;2`P3Ph>00H61P01`L70805ADE01/0:BTY03lo?`0o?cl0ADE507in
OP2i^KT0bLW90:^[Z`2?Shl0F5QH0410@00m?Cd0=cLg03Ti>@1oOgl0DE5A01dM7@0O7al0>CTi05AD
E01OGel0OWin05ADE00d=3@0@T9203Hf=P0E5AD00P0F5QH05P0/;2`0K6a/05aLG01PH600ADE5024Q
8@0F5QH07AdM0:f][@0l?3`0820P01lO7`0M7Ad0<S8b0<S8b037alL0d=3@0<o?c`2NWYh09BDU02<S
8`0M7Ad601DE5@0C01PH601@D500PX:205UIF@3@d=00K6a/04I6AP15ADD0^[Zj0>CTi03Ng]h0/K6a
06QXJ02LW9`0<30`038b<P0k>c/0;Rh^01hN7P0201`L700:01PH600J6QX06a/K034a<@0L71`0WIfM
079bLP2c/k<0X:2P06QXJ080=CDe06/0@d=305mOG`1KFe/0ATI601lO7`0I6AT09bLW02d];@0Q8B40
7QhN04Y:BP2?Shl0dm?C0;Jf]P37alL0e=CD0;Fe]@2RXZ80/k>c09RHV02_[jl0ZJVY0:ZZZP2MWId0
Vi^K09FEU@2a/K40/;2`0:n_[`2QXJ40/k>c075aL@0_;bl0820P02TY:@2<S8`0`L710<_;b`1VIVH0
<S8b04M7A`18B4P0:b/[038b<P1NGUh0ZZZZ07moO`2YZJT0^;Rh06e]K@1`L700MWIf08R8R01`L700
VIVI0<_;b`3:b/X0fMWI06QXJ014A4@0R8R80410@00P82007alO02LW9`1JFUX0RXZ:0=_Kf`3GemL0
[Zj^07QhN02YZJT0_[jn0:6QX@1>CTh0Hf=S06m_K`1WIfL0K6a/07IfMP1jNWX0UiNG0;>c/`2ATI40
ZJVY06UYJ@1kNg/0EeMG04I6AP0m?Cd07AdM01lO7`0L71`0820P02d];@0n?Sh0Ogmo0;:b/P2][Jd0
_[jn09ZJVP34a<@0`L710<K6aP1GEeL0Bd];06ATI002ooooo`0006/0QHF508J6QP19BDT0EEEE03Ti
>@1_Kfl0ATI606=SH`2HV9P0GUiN03Hf=P1jNWX0E5AD03Ti>@1FEUH0>c/k02d];@1KFe/0:BTY05aL
G00a<C408R8R06ATI00c<c<0Ng]k03De=@0j>SX0Cdm?05]KF`1>CTh0Jf][09nOW`1TI6@09RHV05eM
G@15ADD0B4Q807alO00V9RH09BDU05IFEP1RHV80:b/[069RHP1^KVh0>CTi04I6AP0g=cL0H61P01LG
5`0X:2P0FUYJ02HV9P0f=SH0D51@04m?C`0c<c<0?Shn02d];@0o?cl0OWin069RHP0c<c<07alO05]K
F`14A4@0;2`/071`L01hN7P0E5AD0410@01jNWX0EeMG02d];@1?Cdl0Rh^;03De=@13@d<0BDU905YJ
FP0m?Cd0N7Qh07alO00j>SX0CDe=04E5A@1QHF40Hf=S0451@@1MGEd0QXJ607EeM@0j>SX0@4100:RX
Z01[Jf/08B4Q08R8R02MWId0DU9B05ADE02e]KD0QHF50492@P2:RXX0YZJV05IFEP02051@D01N06UY
J@1oOgl0=3@d09:BTP1WIfL0ADE507inOP1?Cdl0BTY:06YZJP1]KFd0UYJF06=SH`11@D40DU9B04=3
@`0g=cL0QHF506YZJP1;Bd/0PH6105mOG`2IVIT0G5aL04Q8B01PH600P82005EEE@1FEUH0M7Ad05AD
E01=CDd0>3Ph055AD@23Ph<0GEeM07YjNP1mOGd0EUIF09NGU`1EEED0DE5A06QXJ01UIFD0WinO0:NW
Y`1?Cdl0?clo0:BTY01bLW80JVYZ08F5Q@0m?Cd0FUYJ0::RXP1SHf<0I6AT07emO@2=SHd0A4A405]K
F`1_Kfl0IVIV065QH@2;Rh/0AdM706e]K@1EEED0=cLg07IfMP2;Rh/0TI6A0;:b/P2ZZZX0EEEE061P
H03;bl/0^[Zj08n?S`1>CTh0a/K609nOW`23Ph<0Fe]K09VIV@1[Jf/0?Shn09BDU02n_[h0M7Ad08n?
S`2ZZZX0/[:b05UIF@80H61P08d0G5aL03<c<`1<C4`0@D5108R8R01TI6@0C4a<06EUI@1FEUH0@d=3
09bLW01ADE40HF5Q0;no_`2?Shl0DE5A0820P01QHF40;bl_065QH@1ZJVX0?Shn03`l?01LG5`0MWIf
05UIF@18B4P0OGem05eMG@1BDU80@d=30<G5a@2TY:@0Ti>C06UYJ@0f=SH0JFUY05IFEP1eMGD0UIFE
065QH@0k>c/0TY:B096AT@0c<c<0EeMG096AT@1jNWX0AdM703hn?P1TI6@0MWIf04i>CP1VIVH0PH61
07]kN`18B4P0NWYj0:j^[P1OGel0CDe=05ADE01gMgL0DU9B06YZJP1IFET0FUYJ0820P02l_;`0SHf=
06m_K`2XZ:P0[:b/05iNGP16ATH0SXj>0:BTY01HF5P0DE5A04Y:BP1eMGD0>3Ph03<c<`1<C4`0IfMW
05aLG00W9bL0DU9B06ATI00`<300CTi>0:6QX@1^KVh0>3Ph07QhN014A4@092@T08R8R01:BTX05aLG
0492@P1QHF40DE5A01TI6@29RHT0;Rh^034a<@1hN7P0IVIV05eMG@0M7Ad0EEEE06YZJP25QHD0@d=3
03hn?P0f=SH0G5aL0:f][@1CDe<0<30`01dM7@0O7al07AdM02`/;01CDe<0GUiN05IFEP2NWYh0clo?
0=GEe@2>SXh0=SHf028R8P0m?Cd0>SXj05iNGP0k>c/05aLG01DE5@0B4Q800P0>3Ph:00d=3@0n014A
4@1nOWh0HF5Q07=cL`1=CDd0WYjN02HV9P0M7Ad0W9bL06m_K`0@41002PX:00h>3P0=3@d05aLG06QX
J00g=cL06QXJ01TI6@0E5AD06a/K01XJ6P0G5aL09BDU04i>CP19BDT0HV9R03@d=0092@T03@d=030`
<023Ph<0Jf][04a<C00[:b/07alO04Q8B01JFUX0;Rh^01`L700P8200B4Q804a<C00e=CD0@d=304U9
B@10@4007QhN01<C4`0g=cL0F5QH06MWI`2GUiL0FEUI03Ph>01mOGd0TI6A09ZJVP1[Jf/0<S8b01LG
5`0C4a<201DE5@0R01LG5`0Q8B409bLW01hN7P0J6QX06a/K01XJ6P0l?3`0C4a<07QhN020P800J6QX
0<71`@2@T900d];B05ADE01EEED0?Cdm04a<C00m?Cd08B4Q01/K6`0L71`07AdM079bLP2?Shl0a/K6
08j>SP1GEeL0;Rh^028R8P0X:2P09RHV02DU9@80?Cdm02807QhN01/K6`1BDU80Cdm?08:2PP1JFUX0
>3Ph03Hf=P1JFUX09BDU01DE5@0G5aL0FEUI03Ph>015ADD09bLW05ADE00];Bd05QHF01TI6@37alL0
UYJF02`/;00Z:RX0>CTi09^KV`2m_Kd0`l?30=;BdP2k^k/0<c<c02<S8`0b<S807alO1P0E5AD09@0F
5QH061PH04U9B@2n_[h0emOG06m_K`2;Rh/0_;bl0:ZZZP3Fe]H0^[Zj0<G5a@3Jf]X0[jn_02/[:`0X
:2P0:RXZ024Q8@0M7Ad06QXJ01TI6@0G5aL06ATI01`L700`<300=CDe0;2`/02?Shl0Z:RX0;fm_@1/
K6`0@41005]KF`1FEUH0@T9201lO7`0H61P00P0I6AT0G`0k>c/09RHV020P800n?Sh0FEUI0;Rh^02L
W9`0`/;20>CTi03WinL0c/k>0<S8b033`l<0VIVI055AD@0_;bl08b<S020P800T92@0<c<c05aLG02S
Xj<0Y:BT0;Vi^@35aLD0UIFE02/[:`0M7Ad09BDU07MgM`2c/k<0X:2P0861P@1<C4`0Lg=c07AdM00k
>c/0GEeM07UiN@1mOGd0P82008n?S`2>SXh0JFUY04Y:BP10@400>SXj06m_K`2RXZ80a<C40;Fe]@2R
XZ80Lg=c01dM7@1LG5`092@T02LW9`0[:b/0=SHf09NGU`3AdM40_Kfm0<O7a`2l_;`0Shn?0:6QX@2B
TY80/K6a07=cL`1FEUH0;Bd]01TI6@0E5AD061PH01/K6`1=CDd0HV9R075aL@2TY:@0Q8B406QXJ01_
Kfl0CTi>04Y:BP0W9bL071`L02@T901;Bd/0GemO07MgM`2QXJ40]KFe0;:b/P2n_[h0`/;20080a/K6
00@0alO70<71`@1[Jf/0:b/[0_ooool0003709BDU02EUID0C4a<07IfMP0l?3`0IfMW03Hf=P1@D500
SXj>05QHF00m?Cd0Ogmo04e=C@0[:b/0@D5104Q8B00P8200Cdm?03`l?024Q8@0EeMG02HV9P19BDT0
:BTY075aL@1DE5@0>3Ph04Y:BP1FEUH0>SXj055AD@2>SXh0KVi^02d];@1ADE40GemO04U9B@1EEED0
@410030`<01JFUX0JVYZ01dM7@12@T80E5AD03hn?P1ADE40EEEE04U9B@0L71`0:2PX05UIF@0n?Sh0
AdM704E5A@1CDe<0?clo04Q8B01;Bd/0CTi>09BDU01:BTX0;Rh^020P801QHF40?clo02HV9P17AdL0
N7Qh06m_K`13@d<0Q8B404a<C00W9bL0>c/k06e]K@0j>SX0DU9B03Ti>@1VIVH0>SXj08Z:RP1`L700
>CTi03lo?`1DE5@0WIfM06ATI00c<c<0IVIV09VIV@1gMgL0=cLg04];B`26QXH0Fe]K01hN7P28R8P0
]KFe04i>CP1FEUH0_Kfm08R8R014A4@0QhN70:VYZ@1KFe/0Cdm?051@D01mOGd0J6QX0451@@2VYZH0
IFEU0492@P1cLg<0ADE505MGE`1MGEd0IfMW08j>SP1NGUh0A4A405QHF015ADD0=cLg09BDU01ZJVX0
De=C07inOP1ZJVX0UYJF079bLP1?Cdl0I6AT08F5Q@1IFET0DE5A07QhN01EEED0Cdm?05ADE01SHf<0
RHV906ATI022PX80Q8B4055AD@1kNg/0?clo05ADE01dM7@0Hf=S0:f][@2GUiL08b<S03lo?`2YZJT0
MgMg075aL@24Q8@0=CDe07UiN@2RXZ80EUIF075aL@1lO7`0S8b<04M7A`1ZJVX0TY:B06QXJ01YJFT0
PX:204I6AP1oOgl0I6AT04];B`1kNg/0Shn?096AT@2XZ:P0[:b/06=SH`1bLW80a/K60;6a/@29RHT0
D51@07]kN`2ZZZX0LW9b055AD@2RXZ80JFUY03<c<`28R8P0]kNg05IFEP0209nOW`2>0:BTY011@D40
QHF509RHV01DE5@0<30`04m?C`10@400PX:206ATI019BDT0GUiN0410@014A4@0Xj>S06i^KP1LG5`0
WIfM08n?S`0`<300RHV906YZJP0^;Rh0FEUI069RHP0O7al0;Bd]07]kN`2VYZH0IVIV04Y:BP2HV9P0
O7al06EUI@1>CTh0aLG50:NWY`2SXj<0KVi^03De=@1VIVH0FEUI07MgM`2f][H0K6a/0451@@2VYZH0
XZ:R028R8P0[:b/0DU9B05iNGP0a<C40DE5A07IfMP20P8008b<S04M7A`24Q8@0M7Ad03hn?P25QHD0
^;Rh03Ph>01IFET0QXJ606a/K014A4@0Fe]K05EEE@0P8200DU9B08B4Q01[Jf/0IVIV0;Rh^02e]KD0
G5aL02PX:01KFe/0SHf=05IFEP1>CTh0Cdm?08J6QP12@T80>c/k07=cL`1fMWH0FEUI02LW9`1NGUh0
KVi^055AD@0/;2`0TY:B04Q8B00e=CD0MWIf055AD@0^;Rh0QhN706YZJP0N7Qh0BDU905eMG@0a<C40
7AdM08Z:RP0O7al08R8R05eMG@1nOWh0G5aL03/k>`1PH600=CDe07]kN`1MGEd0?clo038b<P0^;Rh0
UYJF06UYJ@12@T808B4Q01`L700M7Ad07alO03Xj>P0n?Sh0B4Q807YjNP3:b/X0c<c<061PH00c<c<0
?Cdm04=3@`1^KVh0?Shn01DE5@<04A4A00@05ADE018B4P0E5AD03Ph>0P0=3@d0@`071`L02@T900d=
3@0<30`01PH600d=3@0<30`08B4Q08N7Q`1dM7@0MGEe07UiN@2UYJD0V9RH0=gMg@2c/k<0>3Ph01@D
500E5AD0<c<c07MgM`0/;2`06ATI01/K6`0G5aL06QXJ01/K6`0D51@0<30`05QHF00Y:BT05ADE07=c
L`0C4a<03@d=00h>3P0U9BD0:b/[07QhN01=CDd08b<S01XJ6P0K6a/0;Rh^05eMG@14A4@09RHV02XZ
:P1:BTX0AdM702h^;P0D51@0410@00h>3P0E5AD05aLG01/K6`0c<c<0=SHf08^;R`1XJ6P0Vi^K0=?C
d`3Fe]H0P82001DE5@0A4A400P0C4a<07`0@41005ADE01DE5@0E5AD05QHF01LG5`0K6a/0820P051@
D023Ph<0UiNG061PH00g=cL0Ng]k0:JVYP2j^[X0EEEE02XZ:P1mOGd0F5QH020P800I6AT06a/K01dM
7@0N7Qh0Kfm_09fMW@2o_kl0S8b<05QHF00a<C400P0L71`202DU9@0I02TY:@0o?cl0>CTi01/K6`1>
CTh0Fe]K07alO01XJ6P0CTi>03<c<`0g=cL0H61P01dM7@0k>c/0EUIF04I6AP0b<S8071`L04i>CP0^
;Rh06a/K02h^;P2FUYH0dm?C0;fm_@020<O7a`0;0>;RhP3?cll0d];B0<o?c`2BTY80?3`l03hn?P1L
G5`0@D5101lO7`0I6AT0100E5AD0500F5QH06ATI01/K6`1kNg/0Rh^;0:ZZZP30`<00Ti>C09ZJVP1o
Ogl0CDe=065QH@25QHD0][Jf03`l?00Z:RX08R8R01`L700H61P071`L0`0K6a/0:@0I6AT07AdM03Xj
>P2MWId0][Jf0:NWY`2PX:00_Kfm069RHP0[:b/0<c<c055AD@0Z:RX05aLG01PH600Q8B40D51@02d]
;@1=CDd0=CDe03Xj>P2;Rh/0=cLg05UIF@3Hf=P0^[Zj08Z:RP1MGEd0ATI604m?C`0Q8B4071`L01dM
7@0O7al071`L01dM7@0a<C40TI6A06MWI`2?Shl0^[Zj0080O7al0180IfMW06IVIP2FUYH0OGem04M7
A`1eMGD0Z:RX0;no_`2m_Kd0Shn?09:BTP1eMGD0Q8B406e]K@1VIVH0H61P079bLP1cLg<204Y:BP0H
05UIF@2>SXh0Hf=S05MGE`1IFET0VIVI051@D01FEUH07alO02<S8`1RHV80[jn_0;Fe]@2CTi<0KFe]
0861P@1EEED0=SHf03hn?P1/K6`0Q8B403@d=00J6QX05QHF0P0E5AD0700G5aL06QXJ03Lg=`1HF5P0
Bd];07moO`2=SHd0Lg=c07alO027QhL0LW9b04M7A`0b<S80Bd];07]kN`2ATI40MGEe05aLG01SHf<0
[Jf]0:FUY@35aLD0`/;20;no_`2WYjL0S8b<05eMG@0Q8B42ooooo`0002h0P82006UYJ@1@D500MWIf
03Ph>021PH40DE5A05mOG`2?Shl0EUIF04M7A`2KVi/0Jf][02<S8`0o?cl0GemO02`/;00o?cl09RHV
061PH01=CDd0:2PX061PH00b<S80W9bL05UIF@0R8R80DU9B05mOG`1>CTh0HF5Q09:BTP1cLg<0:b/[
05YJFP1XJ6P0NGUi05iNGP1?Cdl0=SHf06][J`1iNGT0=cLg05UIF@1MGEd0?clo0P1ADE40]P18B4P0
8b<S051@D01hN7P0=cLg04Y:BP10@400DE5A04U9B@1YJFT0BTY:04a<C02<S8`0D51@03hn?P0];Bd0
Q8B406QXJ00d=3@0FUYJ0861P@1^KVh0@T9209jNWP1HF5P0;Rh^03/k>`1UIFD09bLW059BDP13@d<0
FUYJ04m?C`24Q8@0H61P03Xj>P15ADD0GUiN0<C4a01MGEd0:2PX05QHF02YZJT0X:2P0410@013@d<0
Lg=c04];B`0M7Ad0RHV90::RXP1=CDd0E5AD0:RXZ01BDU809BDU07emO@2VYZH0HF5Q06IVIP1XJ6P0
PH610451@@0R8R80MWIf06=SH`0l?3`0PH6103De=@1aLG40IFEU06=SH`2BTY80DE5A075aL@23Ph<0
FEUI03Lg=`2[Zj/0=cLg06m_K`1nOWh0Jf][08^;R`1?Cdl0MWIf09ZJVP2;Rh/0H61P05ADE01UIFD0
C4a<07]kN`1NGUh0GEeM07QhN018B4P0Xj>S09>CT`1:BTX0KVi^03lo?`1EEED0R8R805IFEP2LW9`0
Vi^K02DU9@1RHV80`<3008V9R@1[Jf/0FEUI059BDP2`/;00ZZZZ05]KF`1[Jf/0OGem05IFEP0f=SH0
KVi^07QhN01LG5`0Cdm?08B4Q00V9RH0G5aL075aL@1VIVH0Lg=c0820P00l?3`0VIVI0;>c/`2<S8`0
Ph>30<k>cP2ATI40>3Ph03dm?@1MGEd0Vi^K05QHF01ADE40WYjN08>3P`15ADD0Ph>30;:b/P1_Kfl0
Vi^K0:BTY02`/;00E5AD05EEE@1HF5P0=SHf02/[:`1;Bd/0?Shn092@T022PX80EUIF05aLG01EEED0
B4Q80:2PX01VIVH0AdM70:ZZZP2NWYh0Cdm?09FEU@1MGEd0:BTY079bLP1hN7P0;Bd]03dm?@1;Bd/0
JFUY0P18B4P0M01^KVh0E5AD06][J`0m?Cd0[jn_0=KFeP2f][H0O7al02PX:01^KVh0BTY:05IFEP2;
Rh/0B4Q8038b<P2m_Kd0XZ:R04U9B@0g=cL0FUYJ07=cL`0b<S80?3`l06EUI@24Q8@0@T9204U9B@1K
Fe/0Kfm_028R8P2:RXX0^k^k03/k>`0m?Cd0De=C04Q8B00j>SX0GEeM04A4A013@d<0FEUI09JFUP1N
GUh0@d=308:2PP28R8P0HF5Q05ADE02<S8`0Y:BT03De=@1VIVH0KFe]07]kN`0l?3`0CDe=0:2PX02E
UID0IFEU04A4A01PH600IVIV0410@00j>SX0Zj^[06=SH`0^;Rh0IVIV04m?C`0M7Ad0JFUY06QXJ00U
9BD0B4Q8061PH01MGEd06ATI071`L016ATH0820P04];B`1<C4`0FEUI03Ph>01bLW80?Cdm07YjNP1c
Lg<0EeMG03dm?@0b<S80CTi>0:VYZ@1;Bd/09BDU028R8P1NGUh0;Bd]02XZ:P0a<C40?Shn09jNWP35
aLD0_Kfm07moO`19BDT0Bd];06IVIP0f=SH05ADE010@400C4a<04A4A010@400D51@04A4A0P0?3`l0
200E5AD07AdM010@400<30`03@d=00`<300:2PX0410@0P0C4a<0:`11@D40VIVI0:RXZ02e]KD0bLW9
0=OGe`34a<@0b<S80:FUY@2SXj<0VIVI0:VYZ@0_;bl08B4Q020P800G5aL04a<C01PH600K6a/0=3@d
055AD@0L71`03@d=02d];@1WIfL0820P02HV9P0k>c/0I6AT03De=@1XJ6P0FEUI02PX:00G5aL05ADE
01LG5`0Q8B40K6a/0:6QX@1ZJVX0De=C01TI6@0A4A400P0>3Ph04@0@41005aLG01DE5@0E5AD0<c<c
02l_;`0^;Rh0^[Zj0<k>cP2][Jd0a/K606a/K00J6QX04Q8B014A4@0C4a<051@D00805ADE01T051@D
01DE5@0G5aL09BDU05EEE@1gMgL0L71`07EeM@1>CTh071`L02DU9@1ZJVX0^k^k08b<S00U9BD0BTY:
05QHF00Z:RX071`L01/K6`0L71`0:BTY08>3P`3>c/h0WIfM0080<C4a0440E5AD04a<C00V9RH071`L
020P800X:2P09bLW04Q8B00V9RH0>3Ph07EeM@2c/k<0X:2P0;Ng]`1CDe<0=SHf06IVIP2ATI40O7al
03De=@1ADE407AdM01/K6`13@d<0LW9b05MGE`1;Bd/0]KFe0=CDe03MgMd0PH6106QXJ02j^[X0^;Rh
0:ZZZP30`<00X:2P06i^KP0^;Rh07alO01dM7@0f=SH0De=C01/K6`0M7Ad0820P01lO7`0Q8B406QXJ
01`L7025QHD0ZJVY0<K6aP31`L40_kno0;Fe]@10@4007alO01`L7019BDT0FEUI09^KV`0i>CT07AdM
01TI6@0201/K6`0U01dM7@0L71`08B4Q02l_;`1@D500LW9b0;>c/`3Bd]80d=3@0:b/[01HF5P05ADE
01@D500E5AD06QXJ07]kN`1LG5`0F5QH0:f][@2c/k<0P82003<c<`0F5QH0C4a<04E5A@0Q8B40CTi>
09VIV@0Q8B4071`L04Q8B01fMWH0JFUY06][J`0o?cl0:b/[028R8P0201lO7`0/04M7A`25QHD0WinO
06IVIP1nOWh0Jf][06IVIP2@T900d];B09fMW@0/;2`0<C4a04E5A@2KVi/0h>3P0>;RhP3;bl/0NWYj
08N7Q`1RHV80D51@04U9B@1ADE40M7Ad03lo?`0V9RH0>c/k0410@011@D40DU9B04];B`1HF5P0Ph>3
0:FUY@1?Cdl0?clo08^;R`2XZ:P0Ph>307]kN`1PH600KVi^08F5Q@0g=cL201DE5@0501LG5`0n?Sh0
@T9202`/;00G5aL00`0E5AD06`0I6AT08B4Q04E5A@0h>3P0FEUI09>CT`25QHD0UiNG0;Fe]@39bLT0
][Jf08J6QP1lO7`0H61P04U9B@0l?3`0>CTi04E5A@2:RXX0Vi^K0;Rh^029RHT0Z:RX09jNWP28R8P0
LW9b04i>CP02ooooo`000;D0O7al09FEU@1:BTX0LG5a03Xj>P2=SHd0DU9B069RHP1TI6@09BDU04U9
B@1fMWH0EUIF02HV9P11@D40BDU9055AD@1cLg<0=CDe07EeM@1;Bd/0=CDe07]kN`0h>3P0Vi^K03Ti
>@0h>3P0Shn?08N7Q`19BDT0CTi>09:BTP1LG5`0?clo0:JVYP22PX80L71`069RHP0R8R80:2PX096A
T@2JVYX0F5QH065QH@24Q8@09BDU05eMG@1>CTh0@41000/;2`0j>SX0H61P03@d=016ATH0?3`l02LW
9`0K6a/0Cdm?05aLG00o?cl0SXj>04A4A00?3`l07QhN08R8R02ATI40>CTi06=SH`1PH6008b<S034a
<@2_[jl0O7al02h^;P0j>SX0LW9b01/K6`1KFe/0MGEe05=CD`10@400NGUi055AD@0c<c<0GUiN04i>
CP2YZJT0EUIF02LW9`15ADD0QXJ607=cL`0j>SX0BDU906IVIP0f=SH0@D5108n?S`2EUID0Bd];061P
H02c/k<0G5aL03@d=01iNGT0Ti>C03Ph>01=CDd0CTi>07EeM@1`L700=CDe096AT@1CDe<0@T9208Z:
RP1UIFD0Hf=S05eMG@1RHV80Q8B403Hf=P0h>3P0Bd];03dm?@0d=3@0YjNW04m?C`1DE5@0L71`06AT
I01^KVh0CDe=03dm?@1RHV80KVi^05ADE01GEeL0HV9R03Xj>P19BDT0A4A404Q8B01nOWh0EUIF05iN
GP1nOWh0@D5105mOG`1;Bd/0BDU906QXJ01EEED0WinO0:ZZZP11@D40=3@d09FEU@1]KFd0Lg=c06e]
K@0a<C40WIfM09>CT`1BDU80MGEe071`L027QhL0B4Q805QHF01aLG40IfMW03`l?02CTi<0EeMG06IV
IP1_Kfl0J6QX07=cL`27QhL0KFe]0080NGUi06@0EeMG07EeM@35aLD0W9bL07=cL`0m?Cd0YJFU09:B
TP1>CTh0F5QH0:VYZ@1iNGT0A4A407]kN`2g]kL0GEeM07moO`2MWId0Rh^;04M7A`1kNg/0O7al0451
@@0i>CT0C4a<03Lg=`20P800Fe]K05IFEP24Q8@0G5aL055AD@2][Jd0?Shn03Xj>P2JVYX0UYJF04e=
C@2b/[80NWYj02DU9@1JFUX0IFEU03lo?`18B4P0F5QH0:JVYP1EEED0=3@d08R8R01BDU80H61P02XZ
:P1oOgl0QhN7096AT@19BDT0=SHf07]kN`1aLG40OGem092@T01OGel0@4100;Zj^P2QXJ40A4A405eM
G@2CTi<0RHV903lo?`1>CTh0IVIV07emO@0k>c/0JFUY09:BTP1lO7`0<30`069RHP2;Rh/0B4Q8055A
D@1XJ6P0@41003Lg=`1GEeL0EUIF05ADE028R8P0/k>c08F5Q@1CDe<0T92@08^;R`17AdL0:2PX05QH
F01]KFd0>SXj0P1;Bd/0?P1eMGD09BDU02`/;01lO7`0V9RH07]kN`0f=SH0D51@05aLG00d=3@09BDU
0861P@1=CDd0;bl_05aLG01OGel09bLW07QhN01VIVH092@T04I6AP1/K6`0Ogmo02XZ:P2BTY80?Shn
020P8014A4@0C4a<04m?C`0S8b<0LW9b07inOP2HV9P0TI6A09VIV@1fMWH0F5QH03hn?P35aLD0Xj>S
09bLW021PH40VYZJ07emO@1aLG40O7al0;6a/@2ZZZX0_kno0;jn_P2o_kl0SXj>071`L00o?cl05ADE
01@D500A4A407QhN01LG5`0C4a<07alO0P0A4A40<`0C4a<0GEeM069RHP0L71`04A4A01DE5@0C4a<0
4Q8B01LG5`0K6a/0;2`/03Ph>01nOWh0/K6a0;Vi^@37alL0W9bL08b<S01cLg<0FEUI0:FUY@3?cll0
Xj>S03<c<`0R8R805ADE01/K6`0P82009BDU059BDP1<C4`07QhN034a<@0b<S80ATI603<c<`0k>c/0
;Rh^01DE5@0K6a/0>c/k02h^;P2?Shl0:BTY01`L700E5AD06ATI01XJ6P0k>c/0QXJ6024Q8@0201/K
6`05014A4@0>3Ph03Ph>01DE5@0I6AT00P0E5AD0300S8b<0@D5101XJ6P2IVIT0F5QH04I6AP2IVIT0
QXJ603`l?00G5aL04a<C01DE5@804a<C06X07QhN01`L700d=3@0F5QH071`L01DE5@0;Bd]03@d=010
@400>SXj01/K6`0J6QX0>CTi08N7Q`35aLD0KVi^05IFEP1LG5`0De=C03Ph>00J6QX07AdM02`/;02Y
ZJT0i>CT0:>SX`0m?Cd071`L02/[:`15ADD0A4A404U9B@0j>SX0<30`02LW9`0`<300Bd];038b<P2O
Wil0/k>c09BDU02e]KD0Rh^;05YJFP1:BTX0cLg=07]kN`1IFET0@d=302TY:@0W9bL0H61P06YZJP2E
UID0PH6106i^KP3;bl/0Z:RX0:j^[P15ADD0Y:BT07UiN@1:BTX0MWIf092@T022PX80L71`02DU9@0M
7Ad07QhN028R8P0V9RH0:2PX01TI6@0H61P071`L02DU9@1bLW80Zj^[0;Rh^02UYJD0_Kfm0:BTY00c
<c<08B4Q01dM7@0L71`0:BTY061PH02h^;P0HF5Q02DU9@0_;bl0=SHf03hn?P1DE5@0CTi>05MGE`1M
GEd0FEUI061PH03Lg=`0^KVi0<K6aP2m_Kd0DU9B100E5AD0A01aLG40[Zj^09JFUP2c/k<0`L7106][
J`0I6AT0:2PX05UIF@0T92@07AdM05=CD`1GEeL05ADE01@D500G5aL0;2`/0;Rh^02_[jl0SHf=07al
O01iNGT0QHF508B4Q02[Zj/0I6AT03Xj>P2FUYH0^KVi0;2`/037alL0cLg=0=gMg@0j>SX07AdM01lO
7`16ATH0[jn_0<k>cP3Kfm/0`L710=;BdP2i^KT0SXj>07UiN@1QHF40Kfm_06YZJP0X:2P0A4A402`/
;00C4a<05aLG03<c<`1>CTh0G5aL08F5Q@2SXj<0eMGE0;6a/@1_Kfl0IFEU04U9B@1LG5`0@D5103/k
>`1UIFD071`L0P0E5AD01@0C4a<09RHV04m?C`0e=CD05aLG00<05ADE00d06ATI01`L700k>c/0<C4a
03@d=01OGel0`<300;Jf]P2][Jd0V9RH06QXJ01EEED0=cLg0080=SHf00`0=3@d03Ph>011@D40RXZ:
09bLW01YJFT0IFEU09jNWP1;Bd/0NGUi08F5Q@1oOgl2ooooo`0001T0R8R809BDU01:BTX0IFEU04A4
A02IVIT0Bd];069RHP1PH600;Rh^04Q8B01lO7`0CDe=02DU9@11@D405QHF02XZ:P1ADE409bLW04e=
C@0@4100;Bd]05QHF00[:b/0M7Ad008071`L0380FEUI07MgM`10@400@d=308:2PP1CDe<07alO05aL
G01/K6`0EEEE05iNGP0S8b<06a/K05YJFP1YJFT0@41005]KF`1LG5`0<c<c04i>CP0[:b/0D51@01`L
700i>CT0J6QX02l_;`1=CDd0?Shn05iNGP12@T80C4a<04I6AP13@d<0ZZZZ06m_K`0m?Cd07AdM06YZ
JP1RHV80<S8b06QXJ01KFe/0<c<c02/[:`1lO7`0I6AT02LW9`0j>SX0Ogmo02XZ:P80?3`l03h0?Cdm
04=3@`2EUID0L71`02l_;`0n?Sh0?Cdm08n?S`1`L700E5AD069RHP2HV9P0NGUi03/k>`1>CTh0J6QX
05]KF`0K6a/0IFEU07AdM00h>3P0Fe]K0:6QX@1hN7P0BTY:07MgM`2DU9@0BDU904m?C`14A4@0LW9b
08:2PP0i>CT0V9RH04Q8B00i>CT0OGem05MGE`1[Jf/0DE5A08:2PP2IVIT0FEUI04a<C01CDe<0D51@
03dm?@2QXJ40EeMG05QHF01ZJVX0KVi^0:2PX01XJ6P0F5QH075aL@1dM7@0De=C05mOG`2=SHd0GemO
05aLG080FEUI0980V9RH06IVIP1eMGD0HV9R03Lg=`22PX80De=C055AD@1LG5`0@T9208>3P`2[Zj/0
EeMG04E5A@2`/;00DE5A069RHP1fMWH0?Cdm0:6QX@2OWil0BTY:04i>CP1UIFD0Ogmo0492@P1JFUX0
Kfm_06ATI012@T80WIfM06ATI01eMGD0PX:205aLG01mOGd0Ph>30861P@2XZ:P0SXj>04Q8B026QXH0
`<300:^[Z`1hN7P0F5QH0<;2`P1jNWX0@T9206MWI`2XZ:P0L71`055AD@2YZJT0_kno071`L02PX:00
Y:BT07EeM@0c<c<0TI6A08F5Q@0m?Cd0=3@d06ATI012@T80LW9b03Hf=P1<C4`0MWIf03lo?`17AdL0
UiNG07EeM@1GEeL0Vi^K08^;R`0d=3@0T92@07EeM@0a<C40FUYJ061PH01;Bd/0ATI605QHF02YZJT0
Jf][03hn?P1mOGd0HF5Q075aL@1;Bd/0a/K60;:b/P2^[Zh0IVIV024Q8@1QHF40RXZ:08R8R02c/k<0
OWin04M7A`36a/H0VIVI03`l?00i>CT0Fe]K07emO@0n?Sh0E5AD06i^KP1cLg<0<30`03dm?@1YJFT0
NGUi02l_;`19BDT0Ogmo0451@@17AdL0Jf][05iNGP18B4P0I6AT04a<C00[:b/0FUYJ08F5Q@1_Kfl0
@D5108b<S02NWYh0NGUi038b<P1]KFd0SXj>04e=C@1?Cdl0EEEE09ZJVP1XJ6P0De=C0:j^[P80MWIf
06`0:BTY051@D01VIVH0Kfm_02h^;P2;Rh/0FEUI02/[:`1VIVH0QhN703Hf=P1gMgL0GEeM02XZ:P1I
FET0NWYj07=cL`0k>c/0^[Zj03Xj>P0N7Qh0?3`l059BDP1IFET0?clo061PH00h>3P0Ng]k05QHF01R
HV80OWin07UiN@1fMWH0clo?09nOW`1hN7P0EEEE06ATI01WIfL0FEUI0451@@0m?Cd0RXZ:0:FUY@31
`L40_[jn0:2PX01LG5`06ATI01DE5@0C4a<0410@01<C4`0E5AD04a<C010@400A4A404a<C01`L701h
N7P0@41002/[:`0d=3@0A4A4059BDP1CDe<0EUIF06MWI`1ZJVX0IfMW05IFEP2?Shl0SHf=0;Vi^@2A
TI40GUiN05aLG00b<S80[:b/09RHV02b/[80W9bL05eMG@1UIFD0EeMG05QHF01jNWX0B4Q803lo?`12
@T80;2`/02TY:@1;Bd/04Q8B00l?3`0A4A403Ph>010@400F5QH07QhN07AdM017AdL08R8R01HF5P0E
5AD05aLG03dm?@1XJ6P201LG5`0501hN7P0I6AT03Ph>00h>3P0J6QX00P0E5AD0400F5QH05aLG04=3
@`0a<C40WYjN0451@@18B4P0[:b/0=7Ad@29RHT0Kfm_04i>CP0m?Cd0>3Ph03Hf=P15ADD206ATI00V
0451@@0X:2P05QHF01/K6`0a<C40=3@d03lo?`0I6AT05aLG02l_;`1>CTh0clo?09NGU`2][Jd0TI6A
061PH01FEUH0;bl_02/[:`24Q8@0aLG50=SHf03<c<`0WYjN03/k>`0V9RH0;bl_01DE5@0Q8B40C4a<
05MGE`0g=cL0=3@d04a<C00i>CT0;Bd]06e]K@2@T90205eMG@0Y08b<S02][Jd0d];B0<30`02MWId0
F5QH05IFEP1YJFT0T92@09>CT`1mOGd0ADE5034a<@2GUiL0=CDe06m_K`39bLT0f][J092@T01GEeL0
TI6A08J6QP1:BTX0UiNG09>CT`0Y:BT06a/K01`L700K6a/071`L01dM7@0I6AT08b<S071`L01XJ6P0
G5aL0<G5a@2ATI40`l?305ADE00M7Ad00P0L71`0200M7Ad0;bl_03<c<`2LW9`0`/;209JFUP1`L700
Fe]K0P1<C4`01P17AdL0@41003De=@0h>3P0UIFE0=?Cd`80`l?300L0f=SH0;Zj^P1SHf<07alO024Q
8@1ADE40G5aL0080;Bd]02l0ADE504A4A01OGel07alO06UYJ@0o?cl08B4Q03Lg=`1BDU80=CDe01DE
5@0D51@06ATI03De=@19BDT06ATI01dM7@0Q8B409bLW03Xj>P2=SHd0M7Ad02HV9P0L71`0Kfm_0=[J
fP3;bl/0WinO0<71`@2][Jd0B4Q801dM7@0W9bL0PH610:VYZ@1YJFT0`<3009BDU03;bl/0_Kfm0;6a
/@2UYJD0/K6a0=GEe@2GUiL0@d=302l_;`0201DE5@0A01<C4`0E5AD0;bl_05ADE01nOWh0Vi^K0<o?
c`2OWil0CTi>038b<P0d=3@0E5AD02l_;`0d=3@0DU9B01DE5@0D51@00P0E5AD0100L71`0Bd];04];
B`0I6AT301DE5@0K01TI6@0Q8B40BDU902`/;00c<c<0AdM70=3@d02b/[80[:b/06e]K@1XJ6P0H61P
030`<00b<S80<c<c030`<00e=CD0?Shn0:6QX@2SXj<0IFEU09RHV02BTY80<S8b05IFEP2GUiL0W9bL
00;ooooo0000JP1[Jf/0NWYj04e=C@0f=SH0?3`l07=cL`0o?cl0HV9R08n?S`1:BTX0HF5Q08J6QP11
@D40<S8b05ADE01=CDd08b<S05ADE00X:2P0H61P034a<@0R8R80GEeM038b<P1^KVh0C4a<020P801I
FET0NGUi04e=C@19BDT0WIfM06e]K@0_;bl0Jf][05UIF@18B4P0PH6104m?C`0e=CD0MgMg065QH@0]
;Bd0I6AT06m_K`15ADD0BDU9034a<@1FEUH08R8R0410@01bLW808B4Q03Lg=`0o?cl0De=C03`l?01:
BTX0=CDe03Xj>P1kNg/0KFe]04];B`0/;2`0Q8B405ADE00l?3`0P82007AdM01/K6`0@D5109bLW01O
Gel0;Rh^055AD@28R8P0?3`l04Y:BP10@400<30`03De=@23Ph<0I6AT03Lg=`0k>c/0DE5A07IfMP1b
LW80BTY:08R8R02TY:@0K6a/03dm?@1QHF40S8b<06=SH`0`<300Shn?08:2PP19BDT0HV9R0:b/[01k
Ng/0E5AD07AdM02;Rh/204Y:BP3_04U9B@1WIfL0Kfm_0451@@2e]KD0HF5Q03/k>`1aLG40@d=3079b
LP1GEeL0HF5Q08:2PP16ATH0CDe=059BDP0e=CD0?Cdm0::RXP1?Cdl0E5AD05QHF01KFe/0R8R8065Q
H@1OGel0KVi^05YJFP18B4P0I6AT07alO01JFUX0I6AT0451@@1=CDd0Ogmo06MWI`2IVIT0QXJ604e=
C@2ATI40Cdm?07=cL`29RHT0H61P092@T02WYjL0DE5A04E5A@2h^;P0RHV906YZJP1hN7P0Bd];092@
T02TY:@0DU9B05IFEP1QHF40LG5a055AD@1hN7P0Q8B404=3@`0i>CT0MWIf04a<C02>SXh0NWYj04I6
AP28R8P0SXj>08>3P`2e]KD0Rh^;03hn?P1oOgl0^k^k09bLW01SHf<0Rh^;0<?3``2ATI40?Cdm059B
DP2CTi<0=CDe03Ti>@1^KVh0^k^k075aL@2a/K40`L7109^KV`1=CDd0GUiN07MgM`0m?Cd09bLW04=3
@`0d=3@0T92@05eMG@1;Bd/0Ogmo05IFEP0m?Cd0TI6A06MWI`1SHf<0Xj>S08^;R`1<C4`0Vi^K06][
J`0a<C40EUIF05=CD`0[:b/0Cdm?07]kN`2_[jl0IVIV03Ti>@1_Kfl0GEeM06][J`17AdL0e=CD0<G5
a@2m_Kd0Ph>302@T901TI6@0C4a<05IFEP23Ph<0QhN704Y:BP3:b/X0ZJVY06i^KP15ADD0L71`08Z:
RP12@T80FUYJ06=SH`26QXH0GUiN04e=C@1gMgL0QHF50492@P0k>c/0HF5Q04Q8B01?Cdl0GEeM06][
J`19BDT0HF5Q04e=C@1EEED0MWIf0::RXP2ATI40?clo08Z:RP2][Jd0NGUi03Xj>P1cLg<0Shn?04U9
B@1<C4`0De=C07inOP1OGel0DE5A0::RXP2NWYh0Fe]K01`L701<C4`0Jf][07MgM`0`<300QHF505UI
F@0a<C40V9RH08N7Q`0_;bl0OWin06IVIP0Z:RX0@d=307inOP2BTY80DE5A08R8R019BDT092@T05UI
F@2EUID0K6a/05YJFP20P800@T9207]kN`25QHD0WinO07AdM01>CTh0F5QH09VIV@32`/80H61P03@d
=00U9BD0@41002d];@0W9bL071`L06a/K029RHT0/K6a0;Zj^P3;bl/0V9RH04Q8B00N7Qh05aLG01TI
6@0Q8B40<S8b0410@01JFUX00P1UIFD08`1gMgL0Rh^;08N7Q`1YJFT0De=C04=3@`0n?Sh0>CTi0451
@@13@d<0B4Q803lo?`0/;2`0;Rh^09VIV@1oOgl0c/k>06MWI`27QhL0YjNW0;Rh^01LG5`0VIVI0=;B
dP2FUYH0QhN707UiN@2SXj<0JFUY01PH600I6AT05aLG010@400j>SX0>c/k0080410@01@03Ph>00d=
3@0>3Ph051@D01LG5`0c<c<0Ogmo02DU9@0G5aL05ADE01LG5`1=CDd0=cLg01@D500E5AD06ATI024Q
8@0C4a<04Q8B01@D50@05ADE01@0:b/[04I6AP2UYJD0@D5104A4A01hN7P0W9bL07=cL`1NGUh0>SXj
03@d=011@D40EeMG0820P02`/;00;Bd]01/K6`0F5QH05aLG024Q8@80<S8b01/0FUYJ03De=@18B4P0
JFUY07emO@27QhL0AdM706=SH`1PH600ZZZZ0::RXP2EUID0/k>c0=CDe02MWId0GUiN06UYJ@2TY:@0
YZJV09jNWP24Q8@0:BTY01dM7@0G5aL07alO05ADE01EEED00P1;Bd/08@0n?Sh0];Bd0:j^[P1OGel0
EUIF04Q8B02XZ:P0hN7Q0=KFeP2d];@0[:b/0:VYZ@24Q8@0F5QH05]KF`2VYZH0PX:204i>CP2@T900
=CDe02d];@2@T900]kNg09nOW`2`/;00UIFE07EeM@0b<S80@41006IVIP2KVi/0>CTi01`L700201LG
5`8071`L03H07AdM02HV9P15ADD0WIfM0<k>cP39bLT0`l?3092@T00U9BD061PH01`L700O7al0:2PX
02XZ:P3Bd]80g=cL0::RXP1>CTh0>3Ph02DU9@0P82008B4Q020P800S8b<0Fe]K07inOP2HV9P0inOW
0=WIf@37alL0dm?C0<[:bP2ZZZX0XJ6Q05iNGP16ATH0=3@d03dm?@0X:2P07QhN07UiN@1oOgl0TY:B
03hn?P1kNg/0/k>c09nOW`11@D405ADE01TI6@0`<300B4Q801HF5P0C4a<2014A4@805ADE01X0;Bd]
04E5A@0K6a/0820P07AdM028R8P0PX:2061PH01EEED0^;Rh0:FUY@2KVi/0MWIf09>CT`17AdL0D51@
09RHV02WYjL0TY:B0861P@2GUiL0ZJVY0:n_[`2LW9`0UYJF07EeM@805ADE010051@D01<C4`0E5AD0
5aLG02HV9P1?Cdl0KVi^0:>SX`1_Kfl07AdM02@T900a<C40?clo02PX:00k>c/0F5QH100E5AD08P0H
61P0?Cdm07YjNP1<C4`07QhN01LG5`0E5AD06a/K03De=@2KVi/0De=C03`l?01^KVh0^;Rh07YjNP19
BDT0N7Qh05IFEP1iNGT0@d=302d];@0^;Rh0;bl_03De=@1QHF40YjNW08^;R`2>SXh0`l?30;Zj^P27
QhL0S8b<0;Vi^@3@d=02ooooo`000?l0JFUY08R8R01@D500De=C03Xj>P1cLg<0>3Ph05=CD`26QXH0
B4Q8061PH02?Shl0F5QH02DU9@0m?Cd0C4a<02<S8`0e=CD0<C4a07IfMP1CDe<0=3@d06MWI`0k>c/0
MWIf05IFEP0P8200BDU905QHF00_;bl0>CTi07=cL`1YJFT0:BTY069RHP19BDT0;Bd]05ADE01HF5P0
=3@d08F5Q@1VIVH0:BTY04I6AP1eMGD0@41004m?C`0n?Sh0GemO01hN7P11@D40HV9R03Lg=`10@400
=CDe05IFEP0g=cL0ATI60410@01<C4`0Vi^K0861P@1<C4`0:RXZ08F5Q@1RHV80:RXZ065QH@1PH600
GemO03hn?P2QXJ40@D5102/[:`17AdL0MgMg038b<P12@T80>c/k04Q8B00o?cl0QhN705]KF`0d=3@0
A4A407alO01UIFD0MGEe055AD@29RHT0ZJVY069RHP0e=CD0DU9B06ATI01JFUX0=cLg09fMW@2GUiL0
A4A406][J`2c/k<0MGEe04Q8B02=SHd0UYJF04m?C`1QHF40MWIf07MgM`1DE5@0<c<c08B4Q01FEUH0
>SXj07UiN@0o?cl0LW9b05eMG@1LG5`0FUYJ03Xj>P1]KFd0JFUY05=CD`0d=3@0Shn?03Hf=P1bLW80
Kfm_06][J`1oOgl0?Cdm05mOG`20P800Kfm_0410@018B4P0E5AD04E5A@1QHF40EUIF04m?C`1`L700
AdM706QXJ020P800BTY:07AdM00a<C40BDU906i^KP1ADE40WinO0:RXZ00`<300E5AD0;Bd]01hN7P0
JFUY05ADE01MGEd0Vi^K09FEU@18B4P0EEEE05UIF@1DE5@0>SXj05=CD`23Ph<0FUYJ03Hf=P1_Kfl0
<S8b05ADE01/K6`0@410079bLP1fMWH0J6QX0;Rh^02TY:@0Hf=S08b<S02n_[h0KVi^03`l?01FEUH0
/k>c08b<S01:BTX0MWIf0;Ng]`1]KFd0=SHf07YjNP2SXj<0Fe]K0::RXP2e]KD0SHf=0451@@1eMGD0
MWIf03hn?P0a<C40?Shn02HV9P1lO7`0@d=3055AD@2:RXX0CTi>0492@P1kNg/0;Rh^04a<C02QXJ40
OGem04m?C`2d];@0Fe]K03De=@1lO7`0J6QX03hn?P17AdL0HF5Q09RHV01CDe<0D51@0:>SX`2IVIT0
MGEe02d];@2TY:@0Shn?0:2PX019BDT08R8R065QH@26QXH0LG5a09>CT`1UIFD0Bd];0=3@d02RXZ80
F5QH04Q8B01dM7@0SHf=0492@P20P80000l0TI6A09FEU@1^KVh0D51@07QhN022PX80?Cdm05ADE020
P800IVIV05MGE`1VIVH0LG5a05=CD`1kNg/00P12@T80F@1iNGT0UIFE08Z:RP0j>SX0OWin0;Bd]01c
Lg<0=SHf06m_K`2;Rh/0@d=303hn?P14A4@0O7al03Lg=`1ADE40^;Rh06MWI`14A4@08R8R06m_K`2X
Z:P0MWIf03@d=01mOGd0>3Ph02d];@1`L700Ogmo03<c<`1`L700RHV903Ti>@13@d<0Q8B408n?S`1:
BTX0XZ:R04A4A00V9RH0:BTY051@D01VIVH0EUIF08Z:RP10@400N7Qh06i^KP1lO7`0JVYZ04a<C018
B4P0E5AD0;bl_03@d=00Shn?05EEE@1FEUH0B4Q804A4A00i>CT0X:2P07]kN`2][Jd0alO70;2`/02F
UYH0YJFU09NGU`2NWYh0XJ6Q09ZJVP28R8P0NWYj05iNGP1<C4`0ADE506MWI`2HV9P0Kfm_04U9B@1?
Cdl0BTY:0492@P0h>3P0:2PX01/K6`0E5AD05QHF00805aLG01H0;2`/0;Zj^P3Jf]X0g]kN0=;BdP3N
g]h0f=SH0<S8b035aLD0eMGE0=WIf@3GemL0g=cL0=WIf@0g=cL04A4A010@400>3Ph06ATI05]KF`0R
8R804A4A100>3Ph02P0B4Q803`l?01dM7@2`/;00=SHf028R8P0G5aL061PH051@D00[:b/201DE5@05
01`L700U9BD0;bl_02HV9P0G5aL00P0E5AD0TP0F5QH05ADE01XJ6P1GEeL0SHf=055AD@1JFUX0ZJVY
03dm?@10@400DE5A01XJ6P0E5AD08b<S04M7A`0d=3@0<C4a05]KF`0U9BD06ATI01/K6`1JFUX0IVIV
08J6QP1nOWh0>SXj05EEE@1CDe<0J6QX07=cL`16ATH0NWYj05MGE`13@d<0NWYj0=3@d03Ng]h0`L71
0492@P0O7al09BDU03Hf=P19BDT0HF5Q05]KF`0b<S80;Rh^02PX:00a<C407AdM03@d=01iNGT0P820
0<o?c`3Hf=P0[:b/03lo?`0g=cL0Bd];08Z:RP3IfMT0inOW0>WYj@3Ng]h0GemO06YZJP1ADE40=CDe
05mOG`0o?cl0HV9R0:2PX01XJ6P0BTY:07inOP1^KVh0HV9R09ZJVP3<c<`0ZZZZ05QHF00n?Sh0=3@d
05QHF026QXH0DU9B01hN7P0L71`05ADE01PH600^;Rh0F5QH08J6QP37alL0fMWI0=KFeP3<c<`0YJFU
04Y:BP0d=3@07alO02HV9P0Y:BT0R8R809ZJVP34a<@0hN7Q05YJFP0U9BD07alO02@T900S8b<0:2PX
069RHP1iNGT0>SXj0:FUY@3Ogml0f][J0;Rh^02?Shl0TI6A09VIV@2b/[80^KVi08V9R@17AdL0820P
01hN7P0W9bL0N7Qh0<71`@21PH40Xj>S09NGU`2XZ:P0b<S8061PH01?Cdl08B4Q05iNGP0E5AD0410@
01DE5@0C4a<051@D0P0E5AD06`0L71`0;Rh^01LG5`1:BTX0I6AT024Q8@0^;Rh0a<C407]kN`1eMGD0
aLG506e]K@2j^[X0]kNg09BDU01WIfL0YZJV08f=S@2SXj<0PH6108F5Q@2RXZ80QHF50492@P1/K6`0
DU9B01TI6@0401DE5@0>01LG5`0O7al0ATI606e]K@1DE5@0EeMG02TY:@0S8b<0?3`l03lo?`0X:2P0
BDU904A4A00D51@301DE5@0D01HF5P0W9bL0IVIV079bLP0Y:BT0;2`/03dm?@1bLW80M7Ad07inOP24
Q8@0XJ6Q0:JVYP1^KVh0?Shn034a<@1?Cdl0NWYj06e]K@1/K6`202l_;`0<04A4A01]KFd0IFEU05iN
GP1QHF40UiNG07inOP1@D500JFUY0:6QX@2i^KT0c<c<0_ooool0001=06IVIP1UIFD0DE5A06i^KP0m
?Cd0SHf=04M7A`1?Cdl0Q8B40492@P1]KFd0TY:B06UYJ@0W9bL0BDU906ATI00];Bd0EUIF02TY:@1T
I6@0C4a<0492@P1@D500820P06YZJP1DE5@07AdM0410@01CDe<0@d=302h^;P1jNWX0I6AT02DU9@1K
Fe/0H61P04Y:BP1ADE40Cdm?03Ph>02FUYH0IVIV038b<P1<C4`0Lg=c0492@P1?Cdl0Bd];05aLG00P
8200EeMG06=SH`0e=CD0Bd];04A4A01?Cdl0>SXj05eMG@1;Bd/0ATI607moO`1[Jf/0@d=303Ti>@2X
Z:P0N7Qh02h^;P1[Jf/0Hf=S06UYJ@10@400Z:RX06IVIP0`<300Bd];06m_K`0];Bd00P1@D5007P14
A4@0@D5109:BTP0n?Sh0=CDe06MWI`1`L700A4A407MgM`0k>c/0LG5a08^;R`1mOGd0=cLg05mOG`1^
KVh0Cdm?04a<C02IVIT0Q8B40492@P27QhL0`<30061PH00a<C40IVIV08V9R@0j>SX0A4A4055AD@80
Jf][00X0?Cdm08>3P`10@400D51@08B4Q01PH600R8R805IFEP21PH40Ogmo0P1:BTX01@1RHV80EEEE
04=3@`2?Shl0@D510080HV9R06L0P82009VIV@1JFUX0De=C071`L01OGel0EUIF06UYJ@24Q8@0GEeM
05YJFP0j>SX0IVIV08V9R@1WIfL0M7Ad06][J`11@D40L71`055AD@1/K6`0GemO04=3@`2RXZ80/[:b
055AD@12@T80/k>c04];B`1cLg<0H61P04Q8B02f][H0Lg=c03lo?`1LG5`0IFEU079bLP15ADD0HV9R
0820P01NGUh0EUIF07inOP1;Bd/0J6QX07EeM@14A4@0KFe]06=SH`1NGUh0XJ6Q069RHP12@T80Shn?
0<g=c@22PX80EUIF08j>SP2k^k/0@41003Lg=`1hN7P0WinO05eMG@11@D40SHf=07=cL`1>CTh0Q8B4
0;bl_01gMgL0>CTi07emO@1hN7P0@D5106e]K@1WIfL0?clo08b<S00g=cL0HF5Q09NGU`1HF5P0A4A4
07MgM`0h>3P0@D5108B4Q01OGel0AdM70861P@0g=cL0:BTY05IFEP11@D40;Rh^04a<C01/K6`0Xj>S
03Lg=`0/;2`0De=C0080HF5Q0700BDU90;bl_02EUID0Z:RX055AD@0T92@0K6a/07UiN@1`L700LG5a
05]KF`13@d<0dm?C09RHV01;Bd/0CDe=07UiN@1MGEd0;bl_055AD@1>CTh0MWIf059BDP1@D500IFEU
06i^KP0X:2P0?Shn07]kN`1HF5P0EeMG065QH@11@D40>CTi04A4A019BDT0Cdm?06e]K@2GUiL0QhN7
04A4A01ZJVX0TY:B06m_K`0Y:BT0JFUY08B4Q010@400<C4a06EUI@2=SHd0@41004Y:BP25QHD0M7Ad
0410@00O7al0Bd];06a/K01_Kfl0=cLg07QhN018B4P0;Rh^07EeM@25QHD0=SHf079bLP1mOGd0?3`l
04=3@`25QHD0MWIf05ADE02g]kL0De=C02l_;`0a<C40C4a<06QXJ01MGEd0OGem03lo?`24Q8@0GUiN
04Y:BP0o?cl0<c<c02h^;P1<C4`0Rh^;0=GEe@3De=@0];Bd0;Jf]P2/[:`0Xj>S0;Rh^039bLT0_Kfm
0=WIf@2o_kl0CDe=01lO7`2ATI40`/;2075aL@0j>SX0<S8b02/[:`0^;Rh0=3@d0P0b<S80201eMGD0
X:2P06i^KP0l?3`0:RXZ01TI6@0D51@04A4A0`0D51@02P0E5AD04a<C014A4@0C4a<0VIVI0=WIf@3Q
hN40b/[:0<71`@2d];@20;>c/`0=0;6a/@2JVYX0QHF5096AT@2l_;`0Zj^[03De=@0E5AD0410@03De
=@1@D5005aLG01DE5@0300h>3P0;010@400?3`l0410@01dM7@3=cLd0ZZZZ051@D01:BTX0=cLg07Ad
M00K6a/00P0E5AD01@0K6a/07QhN02/[:`13@d<0?Cdm00805aLG0P0E5AD02@0G5aL0QHF507EeM@1b
LW80Shn?06][J`12@T80A4A403hn?P0201DE5@2502DU9@0O7al09bLW01/K6`0N7Qh0>SXj03Hf=P0a
<C40A4A409jNWP2XZ:P0;bl_01dM7@0g=cL0>3Ph04U9B@1`L7005QHF02h^;P0i>CT0JVYZ075aL@3@
d=00fMWI059BDP0P82008B4Q02DU9@0M7Ad071`L02LW9`0P8200=CDe02XZ:P0Y:BT0<30`03Hf=P0e
=CD0B4Q80=SHf03Ph>00b/[:0<g=c@2WYjL0MGEe07AdM038b<P0`<300<K6aP2:RXX0X:2P096AT@12
@T80<C4a055AD@0O7al06ATI03`l?028R8P0OGem08J6QP2[Zj/0>SXj03Lg=`0o?cl0[Zj^08:2PP2A
TI40LG5a0451@@1?Cdl0CDe=08N7Q`1fMWH0=3@d03/k>`1@D500JFUY096AT@2TY:@0]kNg0=cLg03:
b/X0Hf=S03Lg=`1[Jf/0CDe=04m?C`1=CDd0Ti>C08n?S`0c<c<0IVIV0=kNgP3Lg=`0WYjN0861P@1T
I6@0DU9B08J6QP2XZ:P0?clo079bLP32`/80VIVI09jNWP2n_[h0U9BD0:^[Z`2k^k/0`L710;Bd]02G
UiL0X:2P08N7Q`14A4@0BTY:0<30`02QXJ40Rh^;09RHV02@T900dM7A0=KFeP1>CTh0M7Ad09fMW@1Y
JFT04a<C01@D500E5AD04a<C014A4@0201DE5@0N01TI6@0a<C407alO06m_K`0[:b/06a/K06MWI`2C
Ti<0RXZ:0:RXZ03:b/X0aLG507AdM01LG5`0XJ6Q0=CDe033`l<0`<3009FEU@2OWil0MGEe03`l?00]
;Bd0;2`/0410@01PH600=CDe01<C4`0E5AD04Q8B0P0E5AD03@0M7Ad0?3`l07MgM`14A4@0HF5Q055A
D@0Z:RX0FUYJ03Ph>00X:2P0KFe]038b<P0F5QH0100E5AD0100N7Qh0G5aL09bLW026QXH2092@T00K
05IFEP1DE5@0Hf=S06UYJ@33`l<0aLG509NGU`0a<C4092@T02PX:01UIFD0W9bL09NGU`24Q8@0JVYZ
06IVIP14A4@0<c<c04A4A02;Rh/0SXj>051@D019BDT0I6AT08n?S`2j^[X0QhN700;ooooo0000Y01V
IVH0LG5a05aLG01:BTX0>SXj06=SH`0h>3P0EeMG06UYJ@0e=CD0BTY:06QXJ015ADD0>CTi05eMG@0e
=CD0A4A406ATI00/;2`0E5AD02`/;010@400LW9b03Xj>P1_Kfl0?Cdm02d];@1IFET0Lg=c04E5A@0^
;Rh0QhN704e=C@0b<S80MgMg05eMG@11@D40EEEE01PH600X:2P0KFe]04m?C`0X:2P0LG5a07AdM00]
;Bd0Cdm?05ADE018B4P06QXJ04E5A@1XJ6P0>CTi06ATI01VIVH0=CDe02`/;013@d<0;Bd]03Lg=`2=
SHd0IFEU02PX:00a<C40P82005ADE00j>SX0NGUi04I6AP0h>3P0?3`l09RHV01RHV80=SHf05YJFP1f
MWH0<30`0451@@19BDT0=cLg055AD@2PX:00Jf][03Lg=`1JFUX0=cLg02`/;01RHV80D51@0:^[Z`2Q
XJ40De=C04U9B@1kNg/0VIVI04i>CP0f=SH0RHV90410@00a<C40Kfm_08V9R@1kNg/0B4Q8079bLP2?
Shl0IFEU04m?C`1:BTX0L71`07YjNP0l?3`0M7Ad05]KF`0l?3`0JFUY0492@P27QhL0AdM706][J`1e
MGD0@T9204Y:BP1KFe/0>3Ph051@D020P800>c/k051@D01>CTh0LG5a08J6QP1HF5P0EeMG06a/K01N
GUh0>c/k04m?C`1aLG40GemO05MGE`0i>CT0DE5A07MgM`1RHV80K6a/06i^KP12@T80FUYJ04E5A@1W
IfL0KFe]04];B`1jNWX0W9bL05ADE016ATH0ZJVY065QH@1TI6@0IfMW04A4A030`<00Ng]k0P19BDT0
9`1FEUH0KVi^04=3@`1NGUh0GEeM03Ti>@1EEED0IVIV04I6AP1VIVH0GEeM03De=@1dM7@0MGEe075a
L@2n_[h0FUYJ02`/;01bLW80/[:b08B4Q01HF5P0[:b/0;no_`29RHT0?Shn07inOP2ATI40D51@07Mg
M`3EeMD0Shn?04e=C@27QhL0_;bl07moO`15ADD0SHf=08V9R@0203Lg=`1a059BDP0f=SH0Y:BT04M7
A`1@D500VYZJ06ATI013@d<0Ogmo05mOG`1?Cdl0U9BD07=cL`19BDT0M7Ad0451@@0l?3`0MGEe04i>
CP0[:b/0BTY:06ATI026QXH0>3Ph030`<01OGel0FEUI03dm?@0c<c<0^[Zj0:6QX@2DU9@0<C4a02d]
;@27QhL0K6a/05eMG@1WIfL0?3`l034a<@3:b/X0Kfm_04E5A@1CDe<0MWIf08>3P`1:BTX0FUYJ04e=
C@1nOWh0Bd];04I6AP1XJ6P0Ph>303<c<`0n?Sh0Ogmo06UYJ@1DE5@0I6AT065QH@1BDU80DE5A04U9
B@18B4P0NWYj0:NWY`2@T900?3`l06EUI@2@T900K6a/028R8P1]KFd0Ogmo0451@@1RHV80QhN70:^[
Z`1iNGT0:b/[092@T01^KVh0KFe]02HV9P1EEED0Ng]k07UiN@0m?Cd0VIVI05UIF@0g=cL0JVYZ04m?
C`0`<300QHF50861P@0o?cl0GUiN09fMW@0n?Sh0DE5A0:f][@1MGEd0=3@d02TY:@18B4P0Kfm_05aL
G01kNg/0HF5Q096AT@1CDe<00P13@d<09@17AdL0D51@04A4A00l?3`0QHF508^;R`15ADD0>c/k04Q8
B01eMGD0Zj^[0=7Ad@2i^KT0eMGE0;Zj^P0h>3P06ATI08J6QP2QXJ40=cLg01`L700I6AT05aLG01TI
6@0J6QX05aLG01XJ6P0a<C40A4A402`/;00H61P05ADE00h>3P0A4A404a<C014A4@0@41000P0C4a<0
600E5AD04a<C01LG5`2f][H0^KVi092@T03Cdm<0e]KF0=3@d02HV9P0RHV90<c<c02<S8`0FUYJ04Y:
BP1IFET0[Zj^0;fm_@20P800ADE50820P00[:b/05ADE01HF5P80410@01@05ADE01@D500A4A40=3@d
08j>SP3Cdm<0f=SH0;6a/@25QHD0[Jf]0;Vi^@1KFe/07AdM01LG5`0C4a<05ADE01XJ6P0[:b/0Ng]k
02h^;P806ATI00X05ADE01`L7026QXH0FEUI07AdM02c/k<0IFEU04I6AP12@T80<C4a0P0E5AD07`0U
9BD0;bl_038b<P0Y:BT0<S8b02HV9P15ADD0C4a<04m?C`24Q8@0LG5a01`L700E5AD09BDU02d];@14
A4@0KVi^01LG5`0I6AT0:BTY0451@@1cLg<0emOG0<71`@0n?Sh07alO04U9B@0Z:RX071`L01TI6@0F
5QH00P0E5AD0;`0Z:RX0=SHf030`<00a<C40ADE509bLW02a/K40c/k>08b<S01BDU80GemO0820P03>
c/h0cLg=0::RXP2`/;00Ti>C04a<C02DU9@0ZJVY0861P@0c<c<061PH01XJ6P0l?3`0GemO05MGE`1e
MGD0N7Qh0492@P0[:b/0>SXj09nOW`2FUYH0;Bd]06EUI@2BTY80OWin06IVIP1fMWH0[jn_0;Rh^02Y
ZJT0Ng]k09RHV02`/;00[jn_0080X:2P02h0bLW906m_K`0P8200:b/[05YJFP1`L700[jn_07MgM`0[
:b/09BDU02PX:02o_kl0emOG0<K6aP35aLD0cLg=0>3Ph03Jf]X0UYJF09fMW@2k^k/0DU9B030`<01L
G5`0Ogmo0:f][@2CTi<0Kfm_0:NWY`2i^KT0dM7A0:RXZ02OWil0XJ6Q0:ZZZP3Hf=P0WYjN05ADE02E
UID0b<S80;Bd]02UYJD0LW9b07IfMP1eMGD0<30`100C4a<08@0D51@04A4A01DE5@0I6AT0?3`l04e=
C@0n?Sh07AdM05ADE01OGel0:BTY028R8P0_;bl0[Zj^0<O7a`2XZ:P0OWin096AT@3>c/h0f][J0;fm
_@24Q8@0:b/[01lO7`0M7Ad08B4Q02<S8`0/;2`0B4Q805UIF@0O7al05ADE01<C4`0201DE5@0>01lO
7`0d=3@0TI6A03hn?P1CDe<0`L7107EeM@2KVi/0>c/k03De=@2=SHd09bLW01@D500C4a<201DE5@0N
01lO7`1TI6@0XZ:R0;Vi^@26QXH0M7Ad05MGE`1>CTh0:b/[03Ti>@2KVi/0_Kfm0:BTY01ZJVX0O7al
07MgM`0k>c/0=3@d0<?3``3Kfm/0d=3@06MWI`1@D500HV9R06e]K@1iNGT0?clo02/[:`1ADE40N7Qh
0P2RXZ800`2[Zj/0XZ:Rooooo`01ooooo`0008H0GEeM05iNGP1?Cdl0J6QX03De=@1fMWH0@d=305=C
D`27QhL0DU9B05UIF@1^KVh0>CTi02XZ:P18B4P0>c/k02DU9@0h>3P0=cLg06=SH`0i>CT0:2PX04E5
A@0T92@0IFEU03Ph>00G5aL0:b/[04e=C@0`<300EEEE08b<S01RHV809BDU051@D00b<S80;Bd]04m?
C`0e=CD0:2PX06i^KP13@d<05aLG05IFEP1cLg<0=SHf03Xj>P0e=CD0ATI601`L700h>3P0DE5A01/K
6`0c<c<0>c/k04I6AP0Y:BT0A4A4030`<00_;bl0JVYZ06i^KP10@400=cLg07alO00];Bd0=3@d05aL
G01>CTh0DU9B03<c<`24Q8@0<c<c03hn?P1dM7@0MGEe0451@@1<C4`0ADE502/[:`1?Cdl0Rh^;06IV
IP0g=cL0EEEE061PH00M7Ad0G5aL05ADE02XZ:P0L71`04e=C@0`<300F5QH05UIF@0m?Cd0=cLg08>3
P`1BDU80=cLg06e]K@2JVYX0Lg=c04A4A01]KFd0PX:205eMG@1IFET0BDU905QHF01ZJVX0>SXj07Qh
N01>CTh0BTY:07moO`1ADE40Q8B406=SH`1gMgL0M7Ad03dm?@17AdL0QhN7079bLP1NGUh0QHF5034a
<@1>CTh0IfMW09RHV021PH40De=C059BDP80Kfm_08P0CTi>05MGE`1aLG40HF5Q05IFEP1<C4`0IfMW
07alO01PH600Lg=c07emO@16ATH0LG5a03hn?P1[Jf/0NGUi05ADE02BTY80VYZJ04];B`1@D500ZJVY
071`L01_Kfl0Hf=S05=CD`37alL0PH6104U9B@1?Cdl0B4Q806=SH`13@d<0Hf=S08^;R`1DE5@0IfMW
05ADE012@T80G5aL06EUI@0e=CD0LW9b08>3P`1dM7@0_kno06MWI`1>CTh0WYjN0<71`@1NGUh0Bd];
0<_;b`38b<P0VIVI04Y:BP2a/K40Q8B401/K6`1=CDd0_;bl09nOW`1?Cdl0Shn?0<O7a`1DE5@0<C4a
0;6a/@29RHT0=3@d0410@019BDT0<c<c0:>SX`19BDT0E5AD08R8R013@d<0ATI608^;R`1>CTh0HV9R
08^;R`1aLG40CTi>0:6QX@14A4@0=cLg07AdM01DE5@0?Shn04U9B@11@D40Ogmo05IFEP0b<S80IFEU
05=CD`14A4@0>c/k0;Bd]02KVi/0SHf=02`/;00O7al0JFUY06YZJP1<C4`0HF5Q05QHF00k>c/0b/[:
05mOG`0g=cL0HV9R08^;R`1kNg/0AdM705QHF01BDU80NWYj05QHF01>CTh0RHV908F5Q@0j>SX0CDe=
096AT@1]KFd0F5QH07UiN@1jNWX0GemO05ADE01CDe<0=SHf0P24Q8@0AP1nOWh0;Bd]05QHF025QHD0
Cdm?04Y:BP2[Zj/0VYZJ03hn?P1VIVH0M7Ad09JFUP28R8P0;bl_0;jn_P2LW9`0IfMW02@T901>CTh0
LW9b02LW9`1@D500TI6A05iNGP11@D40RXZ:051@D00M7Ad0LG5a05IFEP0V9RH0?Cdm07inOP1`L700
I6AT0<g=c@14A4@0:RXZ0410@01NGUh0Kfm_01TI6@1GEeL0WinO09^KV`1WIfL0ADE5051@D016ATH0
>c/k038b<P0^;Rh0?Cdm075aL@0_;bl05QHF01LG5`0T92@0C4a<0<C4a02=SHd0[Zj^0;>c/`0m?Cd0
9RHV07YjNP1mOGd0A4A401/K6`0G5aL201DE5@0601<C4`0D51@05ADE02d];@0g=cL05ADE0P0A4A43
01DE5@03010@400E5AD0410@008051@D05P04a<C03<c<`2n_[h0S8b<0:6QX@3Fe]H0g]kN0<G5a@1B
DU80@41006UYJ@2SXj<0F5QH03Ph>00];Bd0@D51079bLP2NWYh0d];B0;Zj^P0Y:BT05ADE01<C4`0A
4A404a<C01lO7`18B4P0P82008n?S`21PH40C4a<04m?C`2DU9@0bLW90<K6aP1`L700H61P06MWI`1<
C4`0:b/[01TI6@0G5aL06a/K02`/;02PX:00EUIF01`L700E5AD09BDU09:BTP15ADD0V9RH08V9R@2B
TY80I6AT08:2PP0/;2`06ATI01DE5@0J6QX0GemO05YJFP10@400D51@04Q8B01;Bd/0?Shn04a<C00e
=CD0=SHf01LG5`0E5AD08b<S02PX:00m?Cd0O7al01TI6@0F5QH08b<S03Lg=`1EEED0e]KF0;:b/P2Q
XJ40De=C059BDP0O7al061PH100E5AD0G00C4a<0;Bd]05mOG`28R8P0P8200861P@1PH600O7al0;no
_`1oOgl0A4A404a<C034a<@0^KVi0:b/[019BDT0GUiN0;Rh^01ADE40GemO0820P024Q8@0FEUI03Lg
=`1=CDd0@d=304Y:BP1cLg<0HF5Q05iNGP11@D40L71`08f=S@22PX80JFUY02XZ:P0a<C40T92@0;Jf
]P2;Rh/0/K6a0<g=c@3GemL0b/[:0<W9b@2XZ:P0MWIf06=SH`1WIfL0FUYJ09BDU01ZJVX08b<S02@T
902SXj<0/K6a051@D00Q8B409BDU02l_;`1kNg/0IfMW04m?C`1^KVh0QHF50<o?c`3MgMd0g]kN0:n_
[`0k>c/07alO02`/;00S8b<0GUiN0::RXP33`l<0ZJVY06][J`1PH600I6AT09^KV`39bLT0c/k>0>7Q
h@3Ph>00c<c<0<g=c@3Hf=P0c<c<06m_K`1KFe/0Zj^[0P10@4000`0k>c/08B4Q01XJ6P0201PH60<0
5aLG01<06a/K05eMG@1jNWX0=CDe055AD@1VIVH0;Bd]024Q8@0M7Ad0:2PX07QhN03Hf=P0alO709nO
W`2LW9`0bLW90;Jf]P1jNWX0<C4a00807AdM0P0O7al05P0T92@09RHV02/[:`1CDe<0BTY:01DE5@0C
4a<05ADE01`L7015ADD0IFEU0;>c/`1YJFT0Ti>C0=GEe@3Cdm<0_[jn08V9R@2IVIT0aLG502<S8`0@
410201<C4`0S038b<P1iNGT0K6a/06EUI@2f][H0Ogmo05MGE`0e=CD09BDU02LW9`0m?Cd0QhN709jN
WP2>SXh0GemO05]KF`1UIFD0Ogmo09BDU03De=@0[Zj^0;:b/P2l_;`0O7al07EeM@0k>c/07AdM01`L
700P8200=3@d07MgM`1MGEd0UYJF0:VYZ@2k^k/00_ooool0000e05mOG`2ATI40De=C07UiN@0e=CD0
MgMg04M7A`1CDe<0SHf=059BDP1PH600VYZJ069RHP0d=3@0CTi>06MWI`0/;2`0C4a<02l_;`1_Kfl0
D51@04I6AP1SHf<0;2`/07QhN01FEUH061PH02<S8`1/K6`0AdM704Q8B01WIfL0HV9R01lO7`1<C4`0
F5QH0492@P1GEeL0DU9B034a<@1OGel0?Cdm01/K6`14A4@0Jf][02l_;`0m?Cd0FUYJ04Q8B00K6a/0
=CDe04m?C`0/;2`00P1=CDd08P1<C4`0;Rh^04a<C00l?3`0<S8b075aL@1nOWh0AdM70410@02?Shl0
E5AD03<c<`1IFET0DE5A05MGE`0c<c<0Shn?051@D00^;Rh0H61P07UiN@0j>SX0C4a<03/k>`0^;Rh0
Ph>30:6QX@1HF5P0=CDe05MGE`1JFUX08R8R04e=C@1;Bd/20:FUY@0k06e]K@0k>c/0NGUi05]KF`0f
=SH0=cLg08B4Q01HF5P0?3`l07inOP25QHD0D51@03lo?`1iNGT0K6a/04i>CP1NGUh0ATI604=3@`1H
F5P0D51@08R8R00i>CT0ATI6079bLP1@D500MgMg06ATI02ATI40M7Ad0492@P1WIfL0QhN706QXJ01F
EUH0PX:203De=@1lO7`0IFEU096AT@1^KVh0D51@07EeM@2=SHd0Jf][04m?C`1HF5P0GemO06MWI`1m
OGd0F5QH07UiN@1YJFT0Jf][0:FUY@1gMgL0@D5109BDU00R8R800P1oOgl0F@1HF5P0WYjN08J6QP0]
;Bd0LG5a0:ZZZP1cLg<0K6a/024Q8@0h>3P0Ti>C0;6a/@1JFUX0EEEE069RHP0n?Sh0JFUY0:2PX02V
YZH0FUYJ07=cL`1RHV80@d=308Z:RP1cLg<0?Shn07EeM@1UIFD0OGem0<_;b`24Q8@0J6QX09jNWP30
`<00=SHf03Ti>@31`L40YZJV0861P@1RHV80aLG509BDU00n?Sh0H61P0<S8b01fMWH0IVIV0:RXZ033
`l<0H61P02DU9@1IFET0Jf][02HV9P0m?Cd0FEUI04A4A02^[Zh0GemO05iNGP2?Shl0;Bd]03De=@2D
U9@0TY:B06][J`1gMgL0H61P03De=@25QHD0C4a<03Ph>01ZJVX0@d=3034a<@1TI6@0PH6109:BTP1D
E5@0@T9206UYJ@1@D500J6QX04a<C02k^k/0P82009jNWP1LG5`0:BTY0080Hf=S02d0Fe]K09bLW01[
Jf/0@d=30<30`02:RXX0>3Ph0820P02WYjL0TY:B04E5A@23Ph<0Lg=c08V9R@0W9bL0H61P09nOW`2D
U9@0EEEE075aL@2WYjL0=SHf06YZJP27QhL0LG5a06][J`1OGel0B4Q802DU9@1ADE40PX:205EEE@13
@d<0Lg=c08n?S`11@D405ADE069RHP1iNGT0ADE507inOP2GUiL0T92@04A4A00Y:BT00P2ATI40>01[
Jf/0>CTi065QH@2?Shl0?Shn02DU9@1[Jf/0=SHf02d];@1YJFT0MgMg02`/;01]KFd0RXZ:03hn?P0l
?3`0PX:206EUI@2DU9@0e]KF07MgM`0i>CT07AdM04a<C01SHf<0@d=302<S8`0n?Sh0JVYZ04a<C010
@400A4A403Ti>@0b<S80:RXZ02HV9P0R8R80Bd];01/K6`0F5QH051@D01DE5@0Y:BT0T92@09:BTP2M
WId0bl_;06YZJP1UIFD0PX:205QHF01_Kfl06a/K01@D500A4A405ADE0P0D51@0IP0W9bL0GEeM06QX
J00J6QX04a<C014A4@0>3Ph0410@01@D500E5AD061PH02<S8`0[:b/0<C4a04Y:BP2_[jl0b/[:0<k>
cP3Ph>00h^;R0;no_`2?Shl0MWIf02h^;P0X:2P0Ng]k07QhN00`<300<c<c03hn?P1SHf<0XZ:R0=3@
d03<c<`0X:2P02l_;`0R8R80@41006QXJ01lO7`0JFUY0451@@0Y:BT0820P01lO7`0g=cL0>CTi06m_
K`32`/80^[Zj08Z:RP17AdL0E5AD06QXJ01>CTh0=SHf02l_;`0P8200@d=308J6QP1hN7P0?clo071`
L02HV9P0TY:B05IFEP13@d<0CTi>04A4A02KVi/0FEUI03/k>`0c<c<0@D510;Fe]@1kNg/0?Shn02h^
;P0/;2`0=3@d03<c<`0g=cL0?clo02/[:`0G5aL05QHF03Lg=`0n?Sh0EeMG0;:b/P0V9RH05QHF01PH
600h>3P0Ph>30<W9b@2c/k<0Q8B4059BDP1EEED09BDU01LG5`<05ADE03h04a<C01DE5@0E5AD0G5aL
0<k>cP2VYZH0TY:B08J6QP1cLg<0HV9R0:f][@35aLD0/k>c0;:b/P2f][H0YJFU04U9B@1?Cdl0Zj^[
051@D027QhL0CTi>03Hf=P10@400EeMG09BDU011@D40CDe=06ATI01BDU80[:b/08N7Q`1:BTX0:BTY
028R8P0c<c<0GUiN059BDP1eMGD0WinO05ADE02MWId0aLG50<C4a03Lg=`0OWin08n?S`2<S8`0E5AD
02h^;P0M7Ad0?3`l08b<S02PX:00UIFE09>CT`2@T900@D5103Lg=`0Y:BT0De=C038b<P<05QHF00L0
6QXJ02TY:@2h^;P0f=SH04=3@`0[:b/0;Bd]00806ATI03008B4Q051@D02KVi/0WinO06ATI00m?Cd0
;bl_03De=@1GEeL0a<C40>[ZjP2@T900Hf=S0:n_[`3?cll0[jn_06a/K00];Bd0bLW90<g=c@2m_Kd0
]kNg0:NWY`2EUID0QhN707UiN@1cLg<0MGEe08F5Q@2GUiL0`L7105IFEP2=SHd0K6a/03/k>`0X:2P0
8R8R024Q8@0d=3@0VYZJ05IFEP28R8P0;Bd]01lO7`19BDT0/;2`08b<S00j>SX301`L700C01hN7P0P
82008B4Q02l_;`0i>CT0K6a/05=CD`1=CDd0IfMW0820P02DU9@0_[jn0<_;b`30`<00_kno09RHV032
`/80_;bl0<S8b0020=[JfP0505]KF`0I6AT0;2`/06a/K01gMgL00P1?Cdl05@1MGEd0VIVI0:6QX@1E
EED0@T9203Xj>P0_;bl0GEeM08Z:RP24Q8@0?3`l02TY:@0g=cL0>3Ph04U9B@1kNg/0[jn_04i>CP21
PH40W9bL01hN7P0201TI6@0901hN7P0Q8B408b<S0410@01WIfL0MWIf09bLW02IVIT0SHf=00;ooooo
0000>P1VIVH0TI6A05IFEP1jNWX0<c<c079bLP15ADD0Bd];08Z:RP1>CTh0HF5Q09^KV`1PH600=3@d
051@D01WIfL0>CTi05QHF00m?Cd0Ph>305mOG`0m?Cd0Lg=c02l_;`1oOgl0CTi>018B4P0M7Ad0H61P
04E5A@1IFET0KVi^05iNGP0L71`0DE5A05]KF`1RHV80De=C04=3@`0/;2`0IVIV03Xj>P0Q8B40E5AD
05iNGP0];Bd0B4Q806IVIP1;Bd/06QXJ04M7A`1FEUH0<30`04m?C`11@D40>CTi03De=@1:BTX202HV
9P1>06QXJ01jNWX0BDU904Q8B02DU9@0BTY:03Hf=P1PH600Fe]K05MGE`0k>c/0T92@05QHF00d=3@0
DU9B0820P00i>CT0BTY:0410@00`<300RHV908^;R`1DE5@0@T9206a/K01FEUH0:2PX05YJFP0F5QH0
=cLg08V9R@1dM7@0>3Ph0861P@1CDe<0<S8b051@D02NWYh0BTY:03<c<`1]KFd0OGem03De=@12@T80
/K6a08b<S01DE5@0GUiN04];B`1WIfL061PH03dm?@2EUID0HF5Q0492@P1DE5@0:2PX08R8R01OGel0
T92@03lo?`0V9RH0FEUI07UiN@1?Cdl0DE5A06i^KP0F5QH0HF5Q05ADE02;Rh/0J6QX02LW9`1BDU80
JFUY04M7A`18B4P0FUYJ0P0U9BD0n01@D500BTY:07MgM`16ATH0<C4a05EEE@1QHF40?Cdm07moO`0U
9BD0BTY:06ATI01UIFD0_kno09fMW@0R8R80EEEE09^KV`1SHf<0O7al055AD@0R8R80FEUI07QhN013
@d<0J6QX07emO@0_;bl0<C4a04U9B@1dM7@0EeMG08B4Q016ATH0820P05UIF@2?Shl0ATI607moO`0Y
:BT0;Bd]08R8R01_Kfl0GUiN09bLW02f][H0>c/k06][J`2TY:@0YZJV04Y:BP1LG5`0[jn_09FEU@18
B4P0Kfm_0<_;b`1UIFD0D51@07alO02YZJT0OWin04a<C01RHV80Shn?03Ph>012@T80DU9B03<c<`2:
RXX0De=C07=cL`2a/K40C4a<02`/;01PH600<S8b04Q8B02ATI40Kfm_03hn?P1]KFd09bLW03Lg=`2M
WId0BDU901XJ6P0R8R80GUiN07EeM@1LG5`0=CDe07QhN01<C4`0DU9B0451@@36a/H0`L710;:b/P1k
Ng/09bLW05mOG`0m?Cd0BDU908j>SP1YJFT0ADE509^KV`2/[:`0@D51059BDP1]KFd0@d=3038b<P1O
Gel0IfMW07YjNP13@d<0>c/k05mOG`1SHf<0Fe]K07IfMP2:RXX0@d=303/k>`1IFET09bLW06YZJP1f
MWH0H61P04I6AP1nOWh0Ng]k04i>CP0[:b/0BDU907AdM01FEUH06QXJ06QXJ01KFe/09bLW04m?C`1M
GEd0Kfm_05IFEP0W9bL0[jn_08V9R@1=CDd0820P03hn?P1]KFd0MGEe03<c<`1bLW80AdM703@d=01[
Jf/0IfMW034a<@1^KVh0PH6103Ti>@0l?3`0RXZ:059BDP1eMGD0YJFU07AdM00e=CD08B4Q03`l?01H
F5P0EeMG02TY:@1=CDd0U9BD051@D00l?3`0>CTi030`<00/;2`09RHV01hN7P0K6a/0Bd];02h^;P0E
5AD04a<C018B4P0H61P0Ogmo0<c<c039bLT0fMWI0;Bd]02l_;`0ZZZZ08j>SP2b/[80QXJ604];B`16
ATH0A4A403hn?P0h>3P0;bl_01dM7@0d=3@0B4Q803@d=00l?3`0AdM705MGE`1ZJVX0Jf][05iNGP1Y
JFT0Hf=S069RHP2GUiL0cLg=0;Jf]P24Q8@0LG5a07YjNP2XZ:P0RXZ:07YjNP1JFUX092@T03lo?`22
PX80DE5A02XZ:P0J6QX0;2`/03Ph>01UIFD0Y:BT0<[:bP2d];@0WYjN06EUI@0m?Cd09BDU0P0N7Qh0
?P0P8200:BTY02TY:@0k>c/0S8b<0;Ng]`2^[Zh0D51@075aL@2XZ:P0QhN704a<C01IFET0IVIV04e=
C@0m?Cd0@d=305UIF@29RHT0/[:b0=_Kf`39bLT0XJ6Q04=3@`17AdL0<c<c03lo?`0n?Sh05ADE01@D
500C4a<05ADE05ADE01fMWH0H61P04A4A00b<S80;2`/02d];@0o?cl0ADE5030`<00O7al05QHF03Xj
>P2=SHd0d=3@0=7Ad@2][Jd0Ng]k04a<C01?Cdl0b<S80;Fe]@3Cdm<0Rh^;05ADE00W9bL07QhN01XJ
6P0E5AD051@D0P0E5AD0?@0C4a<05QHF06QXJ010@400=3@d05MGE`2?Shl0Rh^;08B4Q01jNWX0g=cL
0<o?c`1[Jf/0KVi^0;no_`1ADE40EEEE0;Rh^02][Jd0YjNW030`<00Z:RX09BDU030`<01KFe/0OWin
04Q8B01RHV80Rh^;07alO01?Cdl08B4Q01/K6`0N7Qh08B4Q02@T901@D500`L710:ZZZP3EeMD0d=3@
0;Ng]`30`<00aLG5096AT@1IFET0<c<c024Q8@0G5aL05ADE01TI6@0/;2`0Lg=c0=7Ad@1YJFT0:b/[
05=CD`25QHD0Rh^;07alO00O7al00P0E5AD0>`0G5aL05QHF024Q8@2PX:00cLg=04I6AP0i>CT07AdM
020P800n?Sh0:b/[04=3@`1lO7`0VYZJ05]KF`0X:2P0ATI607alO02GUiL0a<C40=;BdP2UYJD0WYjN
08Z:RP1MGEd0MgMg09fMW@1kNg/0a/K60;Vi^@2`/;00UYJF06EUI@0j>SX0;Rh^02/[:`0b<S80<c<c
04Y:BP2?Shl0cLg=0;no_`1aLG40@T9203@d=00W9bL08b<S024Q8@1>CTh0Lg=c030`<01CDe<0GUiN
01`L700c<c<0Jf][0;bl_01ZJVX07QhN008071`L0P0P8200;`0T92@0:BTY03Hf=P29RHT0dM7A08b<
S01aLG40Kfm_0:FUY@2GUiL0Hf=S08B4Q02RXZ80[:b/0<S8b03?cll0emOG09fMW@2JVYX0c/k>0:JV
YP2c/k<0IVIV04E5A@1@D500EeMG05aLG01dM7@0TY:B09NGU`25QHD0Kfm_05IFEP2DU9@0`l?309RH
V00Z:RX0;2`/038b<P17AdL0;2`/04Y:BP2i^KT0Shn?0<C4a02GUiL06a/K00806ATI00T07AdM01hN
7P0`<300EUIF06IVIP2FUYH0UIFE04i>CP2:RXX00_ooool0000m08R8R02?Shl0F5QH07IfMP0o?cl0
RHV904A4A01:BTX0NWYj04e=C@1jNWX0V9RH05=CD`0e=CD0De=C05QHF01LG5`0LG5a03/k>`1iNGT0
FUYJ051@D02:RXX0?Cdm08f=S@1BDU80BTY:07MgM`1iNGT0@D5104i>CP1XJ6P0C4a<03<c<`1dM7@0
E5AD065QH@1FEUH0:2PX05aLG02SXj<0Bd];02d];@1FEUH0JVYZ03<c<`0n?Sh0Hf=S02d];@0T92@0
LW9b05mOG`0`<300D51@04i>CP0M7Ad0@d=3069RHP13@d<0:2PX06ATI00203hn?P2o08F5Q@2ATI40
BTY:03Hf=P1PH600<C4a02d];@1=CDd0RXZ:061PH00m?Cd0GEeM06EUI@10@400IVIV06MWI`1KFe/0
PH6108f=S@0_;bl08B4Q05=CD`1DE5@0<c<c04e=C@1ADE40V9RH08n?S`1@D500>3Ph08F5Q@1GEeL0
4a<C02PX:01IFET0KVi^038b<P1SHf<0TI6A030`<00Y:BT0IfMW071`L015ADD0MgMg06MWI`1fMWH0
A4A403Ph>01[Jf/0;Rh^05MGE`1KFe/0;bl_071`L015ADD0U9BD05MGE`0U9BD0A4A404e=C@0a<C40
G5aL06i^KP0Z:RX0BTY:03/k>`2BTY80JVYZ0410@018B4P0DE5A0492@P1ADE40IVIV05mOG`19BDT0
AdM703@d=01_Kfl0N7Qh059BDP1fMWH0E5AD038b<P1/K6`0@T9206=SH`1YJFT0EeMG08Z:RP21PH40
?3`l05EEE@2EUID0De=C05mOG`1SHf<08B4Q06YZJP1bLW80@T9204];B`1EEED0FEUI03dm?@1GEeL0
ADE50451@@2<S8`0@41002TY:@1?Cdl0F5QH03Hf=P1VIVH0CDe=05eMG@2CTi<0?clo02d];@2@T900
/;2`06MWI`2EUID0UYJF0:RXZ01eMGD0Lg=c0;no_`2RXZ80D51@08V9R@3<c<`0TY:B06][J`1_Kfl0
Z:RX09:BTP1LG5`0Lg=c06a/K00o?cl0KFe]05QHF015ADD0Shn?034a<@19BDT0SHf=079bLP1:BTX0
Rh^;06][J`1KFe/0QXJ607QhN014A4@0SHf=03Lg=`14A4@0GEeM04U9B@0/;2`0>CTi05mOG`20P800
?Cdm034a<@2IVIT0NGUi065QH@0Q8B40FEUI06IVIP2;Rh/0EUIF02d];@1MGEd0BDU904e=C@1YJFT0
=CDe01lO7`1TI6@0L71`04Q8B01NGUh0Shn?065QH@14A4@00P1XJ6P0KP1cLg<0DU9B059BDP1^KVh0
P82005aLG01EEED0SXj>06][J`18B4P0Q8B405YJFP1aLG40F5QH03lo?`0m?Cd0UiNG07emO@1KFe/0
<c<c05ADE01jNWX0DU9B02<S8`2>SXh0NWYj030`<01OGel0NWYj07MgM`0m?Cd0=CDe0:>SX`22PX80
HV9R02<S8`0h>3P0GUiN05EEE@1ADE40RXZ:05]KF`0b<S80IfMW06IVIP0c<c<0G5aL08>3P`0o?cl0
@D510:^[Z`1ZJVX0MGEe0;jn_P1BDU80:b/[028R8P0c<c<0Fe]K04E5A@0Y:BT0RXZ:0:6QX@19BDT0
=cLg03De=@0Y:BT0:b/[02PX:00R8R807AdM03@d=01HF5P05aLG01<C4`0E5AD0;Bd]0::RXP3GemL0
f][J0<S8b02e]KD0clo?06EUI@1fMWH0R8R808>3P`0g=cL07AdM02TY:@0E5AD08B4Q03Ti>@1TI6@0
MWIf08V9R@23Ph<0LG5a05eMG@1@D500Bd];03Ti>@0Z:RX0:BTY02DU9@0K6a/0Bd];0:JVYP0b<S80
8B4Q0P0N7Qh0>@0];Bd0RHV909>CT`29RHT0IFEU0451@@2EUID0a/K608f=S@1MGEd0?clo03/k>`0[
:b/0NWYj0<30`02UYJD0@D5103Lg=`0i>CT0@41004a<C01JFUX0Hf=S06EUI@1OGel0Jf][06YZJP24
Q8@0Xj>S06a/K00`<300>SXj06EUI@2OWil0U9BD06IVIP1OGel0LW9b05YJFP0n?Sh0G5aL06QXJ03I
fMT0f][J06a/K00f=SH0>SXj034a<@19BDT06QXJ018B4P0D51@05ADE01TI6@0R8R80DE5A04];B`02
01dM7@8071`L01P07alO02h^;P0W9bL0<S8b01lO7`20P800cLg=0:RXZ01kNg/0DE5A07IfMP2][Jd0
e=CD0>3Ph03MgMd0^;Rh09JFUP2:RXX0:b/[01TI6@0L71`06QXJ01LG5`0I6AT201LG5`0m02TY:@1a
LG408R8R01lO7`1;Bd/0A4A404M7A`18B4P0JFUY0<30`03@d=00HF5Q04A4A02=SHd0PX:205QHF02P
X:00GEeM065QH@1@D500:BTY02DU9@0T92@0A4A40:^[Z`1gMgL0R8R806YZJP1JFUX0GemO02TY:@0H
61P06ATI028R8P0W9bL09RHV08V9R@35aLD0e=CD09nOW`1jNWX0W9bL0861P@0[:b/09bLW02TY:@0S
8b<05aLG01TI6@0G5aL071`L06ATI03AdM40ZJVY07moO`10@400RXZ:0<C4a01iNGT0;Rh^01LG5`02
01HF5P0801`L7011@D40Kfm_0<c<c01=CDd08R8R020P800^;Rh201LG5`1:03hn?P14A4@0/[:b0<30
`02k^k/0KFe]09:BTP2h^;P0dM7A0:FUY@2o_kl0CTi>01dM7@0P8200AdM707emO@2`/;00emOG08J6
QP1NGUh0Ng]k09JFUP1SHf<0>3Ph03Xj>P0i>CT0@T9205aLG02h^;P0MWIf08Z:RP30`<00b<S809BD
U01_Kfl0ADE503/k>`2;Rh/0>CTi02`/;019BDT0LG5a038b<P16ATH0DE5A0=;BdP1EEED0;Rh^01lO
7`0K6a/0820P02PX:00W9bL0<30`06a/K02IVIT0[jn_07alO01oOgl0SHf=069RHP1ADE40SHf=09^K
V`2LW9`0_kno09jNWP33`l<0Q8B4092@T02IVIT0/k>c0>3Ph02GUiL20:>SX`0?0:6QX@1ZJVX0DE5A
02LW9`0`<3009BDU0492@P1eMGD0Ti>C07EeM@1VIVH0MGEe05=CD`0m?Cd0>3Ph0080=CDe0140GemO
0<?3``3De=@0g]kN0=CDe01MGEd06QXJ01dM7@0J6QX07alO04];B`1KFe/0UYJF075aL@1?Cdl0Lg=c
079bLP02ooooo`0003X0FUYJ05IFEP1QHF40ATI603Xj>P1PH600?Shn06EUI@1?Cdl09BDU04U9B@1N
GUh0=cLg04I6AP17AdL08B4Q03Ti>@13@d<09RHV04i>CP0K6a/0<S8b05MGE`0_;bl0OGem02<S8`0X
:2P0>SXj05EEE@0h>3P0EUIF08R8R01DE5@06a/K04M7A`0k>c/0F5QH06ATI00U9BD08B4Q05]KF`0_
;bl09bLW06a/K01=CDd0=CDe01`L7019BDT0;2`/01LG5`0l?3`0@D5101dM7@13@d<0@T9202`/;00d
=3@0>3Ph0P0M7Ad08`1hN7P0E5AD02l_;`0o?cl0I6AT03Ti>@0g=cL0EEEE030`<00V9RH0<C4a05]K
F`1<C4`0>CTi05]KF`1/K6`0:b/[028R8P0i>CT0:RXZ06e]K@2?Shl0BTY:02d];@15ADD0:b/[03De
=@1HF5P0Cdm?09JFUP2:RXX0<S8b04M7A`1lO7`0Jf][0080;Rh^04D0GemO04I6AP0l?3`0NWYj09^K
V`1IFET0=3@d08B4Q01jNWX0<c<c05aLG017AdL0IFEU05YJFP1:BTX0NWYj03dm?@16ATH0H61P04E5
A@1]KFd0@41007AdM01NGUh0:BTY04i>CP1SHf<0Cdm?055AD@1oOgl0=SHf059BDP1TI6@0RXZ:07Ee
M@1ADE40D51@08N7Q`1GEeL0@410065QH@1bLW80HF5Q05ADE01?Cdl0NGUi07IfMP1@D500L71`07Ui
N@0h>3P0@d=302/[:`1YJFT0NGUi08J6QP2`/;00Ng]k03Xj>P1LG5`0VYZJ05eMG@1_Kfl0IfMW02l_
;`1?Cdl0DU9B04=3@`1BDU800P1PH600VP0o?cl0EEEE07MgM`1<C4`0SHf=034a<@19BDT0GEeM05UI
F@0d=3@0GEeM075aL@1fMWH0YJFU05EEE@1BDU80RHV90;:b/P1]KFd0U9BD08>3P`2LW9`0LG5a08^;
R`2n_[h0Q8B4059BDP2YZJT0][Jf07UiN@1WIfL0L71`0:NWY`1QHF40Ph>309ZJVP1hN7P0>SXj051@
D01ADE40<c<c0861P@15ADD0De=C08j>SP1KFe/0F5QH0:f][@2=SHd0Kfm_07]kN`1SHf<0@d=308Z:
RP1?Cdl0ATI606i^KP1IFET0ATI605ADE01UIFD0T92@059BDP0T92@0DE5A05QHF01FEUH0CTi>0;fm
_@2ATI40[Jf]05IFEP0N7Qh0ATI604M7A`1MGEd0LW9b05EEE@0[:b/0CDe=06UYJ@0k>c/0JVYZ09RH
V01[Jf/0?Cdm06ATI01VIVH0IfMW03Ti>@1YJFT0WinO0820P011@D40D51@08n?S`1TI6@0Cdm?09fM
W@1^KVh0Lg=c05aLG00b<S80=3@d0:2PX02SXj<0HV9R02h^;P1DE5@0Kfm_03dm?@13@d<0U9BD08f=
S@0f=SH0FUYJ06MWI`2;Rh/0Ogmo02/[:`2i^KT0PX:204M7A`0M7Ad0A4A4061PH01DE5@0;Rh^05QH
F01=CDd0<C4a08B4Q01bLW80=CDe05eMG@1UIFD08b<S03hn?P2GUiL0EEEE079bLP2WYjL0EEEE02XZ
:P1@D500J6QX06=SH`0c<c<05ADE05MGE`26QXH0GEeM04Y:BP0`<30202PX:00<02@T900Q8B407AdM
028R8P27QhL07alO024Q8@1MGEd0YJFU0:ZZZP2k^k/0fMWI0P3=cLd02039bLT0[Jf]09JFUP1eMGD0
A4A408N7Q`1lO7`0MGEe0P2@T900201lO7`0EUIF05aLG01^KVh0FEUI04Y:BP0b<S809BDU0P0I6AT0
?P0F5QH061PH01PH600E5AD0EeMG04M7A`0M7Ad06a/K01XJ6P0G5aL06QXJ02l_;`1mOGd0Zj^[0<30
`033`l<0a/K60<o?c`38b<P0/k>c09RHV022PX80FUYJ07MgM`3@d=00Ti>C03lo?`19BDT0F5QH05AD
E01LG5`0HF5Q04Q8B00d=3@09bLW05MGE`10@400B4Q803Xj>P1]KFd0E5AD020P800W9bL0=CDe05MG
E`29RHT0XZ:R09FEU@27QhL0V9RH09>CT`3=cLd0inOW0=7Ad@1XJ6P0M7Ad096AT@2?Shl0P82001TI
6@0K6a/05aLG0P0E5AD07@0M7Ad0:BTY04M7A`0R8R806a/K01`L700K6a/071`L02DU9@16ATH0IfMW
08>3P`2UYJD0P82006][J`14A4@0@41003Ph>010@400];Bd0=_Kf`3Ng]h0]KFe07MgM`1<C4`0J6QX
05ADE00];Bd06ATI008071`L04P07AdM02DU9@1WIfL0@41003Hf=P19BDT0GemO04Y:BP0U9BD092@T
02h^;P1FEUH0U9BD03hn?P0[:b/0LG5a0;Rh^01QHF40Fe]K051@D00c<c<0B4Q804M7A`0];Bd08b<S
03Hf=P2XZ:P0WYjN06IVIP0U9BD092@T065QH@19BDT07alO01XJ6P0K6a/0:2PX01lO7`0j>SX0Ogmo
0:RXZ01]KFd0IVIV04m?C`1FEUH07alO02HV9P0/;2`08B4Q01HF5P0G5aL061PH01/K6`24Q8@0HF5Q
03<c<`1RHV80a/K60=GEe@2][Jd0Kfm_05QHF00^;Rh07AdM024Q8@1ADE409BDU03lo?`3;bl/0=CDe
01`L700H61P201DE5@1?01LG5`14A4@0@D5105aLG03Hf=P0hN7Q0<_;b`2KVi/0MgMg08:2PP2EUID0
EUIF01dM7@0L71`07QhN05ADE01QHF40Ng]k0820P022PX80Zj^[09JFUP2LW9`0`l?307YjNP1IFET0
Cdm?05eMG@2OWil0WIfM05UIF@2][Jd0QhN708^;R`2@T900XZ:R0;>c/`3;bl/0`l?302@T900/;2`0
ADE5061PH02NWYh0TY:B06m_K`2j^[X0_Kfm07alO01RHV80;bl_01lO7`0T92@0<C4a08:2PP3AdM40
^KVi0:n_[`2BTY80E5AD02XZ:P0b<S80F5QH08B4Q03Fe]H0WIfM06e]K@2[Zj/0GemO06e]K@1OGel0
FUYJ0:NWY`3De=@0W9bL08f=S@2DU9@0Vi^K0;Vi^@0204I6AP0N051@D01HF5P0H61P05IFEP1kNg/0
Xj>S09JFUP2?Shl0[:b/06YZJP19BDT0DU9B06e]K@24Q8@0[jn_0;Fe]@2:RXX0S8b<0;Bd]01hN7P0
:BTY01hN7P0j>SX0HF5Q09VIV@1HF5P0?Shn04];B`1^KVh0<30`0_ooool0000S06=SH`1OGel0E5AD
06YZJP0e=CD0Hf=S03@d=018B4P0JVYZ03Hf=P1bLW80I6AT02<S8`0Z:RX0ATI604a<C00g=cL08B4Q
02DU9@1]KFd0@410038b<P0l?3`09BDU07YjNP19BDT0?Shn04U9B@0c<c<08R8R03/k>`1ZJVX0EEEE
01dM7@1?Cdl00P0n?Sh0SP1=CDd0@d=302HV9P1UIFD0;Rh^02LW9`1IFET0FUYJ02TY:@0/;2`0@T92
02HV9P0J6QX0?3`l04e=C@0d=3@0AdM703lo?`16ATH0@T9205IFEP1<C4`09RHV06YZJP1]KFd0?Shn
05YJFP1eMGD0;Rh^03Xj>P1UIFD0DE5A0451@@0g=cL0I6AT02/[:`0g=cL0J6QX07UiN@0o?cl0=cLg
04a<C00c<c<0Ph>308:2PP1NGUh0E5AD06ATI01<C4`0DE5A04Y:BP16ATH0Y:BT07emO@0g=cL0=SHf
07IfMP1HF5P0>3Ph04=3@`2:RXX0@d=302h^;P1CDe<0QXJ60492@P0h>3P0YjNW09>CT`1BDU80JFUY
04a<C01ZJVX0FEUI06QXJ027QhL0ATI604a<C01lO7`0DE5A075aL@1DE5@0N7Qh075aL@0b<S80CTi>
07QhN01IFET0GemO08J6QP0n?Sh0E5AD061PH024Q8@0EEEE04Y:BP1VIVH0P82005=CD`13@d<0EeMG
06ATI01XJ6P0EUIF04I6AP2=SHd0IfMW055AD@1aLG40NGUi03hn?P1>CTh0:BTY06EUI@1aLG40Shn?
0:ZZZP21PH40?clo06YZJP2YZJT0G5aL07YjNP1]KFd0>3Ph05EEE@1QHF40BTY:04e=C@1LG5`0I6AT
04=3@`1KFe/0QHF503hn?P29RHT0C4a<059BDP1KFe/0P82004i>CP1PH60207=cL`1F09NGU`1>CTh0
AdM709:BTP2EUID0Cdm?08n?S`2UYJD0[:b/06a/K02OWil0`L7106e]K@13@d<0WYjN0:j^[P1YJFT0
RHV909:BTP2WYjL0RHV907IfMP1>CTh0DE5A03<c<`1PH600E5AD03dm?@1nOWh0GEeM06m_K`2`/;00
C4a<04U9B@2>SXh0IVIV07AdM02<S8`0G5aL04e=C@1hN7P0;Rh^0410@02=SHd0CTi>02<S8`1;Bd/0
QXJ60:FUY@1TI6@0<30`05UIF@1?Cdl0IFEU06][J`3@d=00`l?30;:b/P28R8P0:BTY069RHP16ATH0
GemO08b<S01gMgL0>SXj04=3@`25QHD0@d=304m?C`28R8P0NGUi03Ti>@1_Kfl0M7Ad08j>SP1OGel0
EeMG08J6QP25QHD0@41005]KF`2JVYX0>CTi04M7A`2WYjL207=cL`0h05]KF`0/;2`0=cLg07emO@1i
NGT0HV9R030`<01@D500Kfm_04I6AP0P8200O7al0861P@0f=SH0OGem0::RXP2CTi<0MGEe02d];@31
`L40M7Ad02DU9@0G5aL0ATI605]KF`1EEED0<C4a04Y:BP0l?3`0:RXZ069RHP1`L700:b/[065QH@1d
M7@0@41003<c<`2;Rh/0Bd];06QXJ02>SXh0KVi^03@d=00H61P0:b/[051@D01=CDd05aLG03hn?P1f
MWH0I6AT04];B`0n?Sh0;Rh^02TY:@0R8R8201dM7@0U024Q8@2CTi<0[Jf]0:NWY`22PX80HF5Q07Mg
M`1XJ6P0NGUi0<S8b03Lg=`0`/;209NGU`20P800NGUi03Ti>@0Z:RX0][Jf0=CDe02CTi<0Jf][07Ui
N@1RHV80AdM705IFEP1=CDd0:BTY01XJ6P0I6AT06a/K01PH600J6QX06a/K01LG5`0a<C40IFEU02PX
:00201`L700G01XJ6P0F5QH05QHF01PH600_;bl0GUiN0;^k^`3QhN40a/K60<g=c@2@T900F5QH04];
B`1BDU80K6a/0:JVYP37alL0WYjN04Y:BP0h>3P0:2PX02LW9`0O7al00P0L71`0Q@0M7Ad0?clo030`
<00W9bL07alO01TI6@0V9RH0KVi^04e=C@0I6AT08R8R02LW9`0c<c<0B4Q8075aL@2PX:00alO70<g=
c@3Ng]h0dm?C0>OWi`37alL0^KVi09FEU@2GUiL0FUYJ03<c<`0N7Qh05aLG01<C4`0F5QH07AdM028R
8P0S8b<0;bl_01/K6`0I6AT06a/K024Q8@0P8200ADE508V9R@2IVIT0WIfM04U9B@0I6AT0<C4a03lo
?`14A4@0MWIf0:2PX02c/k<0clo?0<S8b01ZJVX0<c<c02l_;`0l?3`0FUYJ06=SH`10@40092@T01lO
7`0f=SH0LW9b0492@P1JFUX0P82004e=C@0a<C409BDU02LW9`0d=3@0>CTi07emO@0k>c/0;2`/04I6
AP2TY:@0_kno09jNWP2IVIT0A4A4030`<00o?cl0A4A403lo?`1=CDd0Z:RX09jNWP0l?3`071`L01lO
7`0e=CD0De=C03De=@0F5QH061PH01LG5`0K6a/0>CTi03hn?P1ADE40MgMg05]KF`1:BTX0EeMG024Q
8@0Y:BT0<C4a01dM7@0E5AD05aLG01PH600M7Ad0L71`02l_;`0M7Ad092@T0;Vi^@3Bd]80L71`03lo
?`1HF5P0S8b<08F5Q@1SHf<0<30`01/K6`0e=CD0Ti>C02TY:@0G5aL00`0E5AD0K`0Q8B40B4Q803hn
?P1BDU80c/k>079bLP0];Bd07QhN01lO7`0b<S80HF5Q02@T900J6QX071`L02HV9P0e=CD05QHF05eM
G@1ADE40AdM703Ph>01dM7@0MWIf06EUI@1aLG40Kfm_06EUI@1oOgl0/k>c08R8R02XZ:P0][Jf0<;2
`P2@T900IfMW03dm?@0c<c<0@T920:6QX@0S8b<0:BTY04=3@`20P800bl_;05ADE00c<c<0Xj>S04e=
C@0];Bd0@d=308>3P`1XJ6P0Lg=c0:VYZ@3Cdm<0fm_K0<o?c`2OWil0@d=301HF5P0I6AT0:2PX02h^
;P1hN7P0QXJ604m?C`2JVYX0`/;208B4Q01=CDd0D51@05ADE01mOGd0V9RH07UiN@1kNg/0NWYj06i^
KP2l_;`0T92@03Lg=`0N7Qh06ATI01LG5`0J6QX0@d=307=cL`11@D40O7al0;^k^`2/[:`0Rh^;0;Bd
]03=cLd0^[Zj0;6a/@1MGEd07AdM02PX:01LG5`0YZJV0:FUY@1FEUH0Jf][0:ZZZP1?Cdl0;bl_0410
@01=CDd0SHf=061PH002ooooo`0008/0JVYZ08^;R`1NGUh0N7Qh03/k>`1oOgl0@T9204M7A`1UIFD0
:b/[05QHF01iNGT0?3`l03dm?@18B4P0DE5A04];B`1OGel0:b/[07]kN`1VIVH0ADE506QXJ00Y:BT0
OWin05mOG`11@D40ADE504];B`0m?Cd0B4Q806i^KP1<C4`092@T05mOG`1YJFT0EUIF05MGE`11@D40
;Bd]08>3P`17AdL0>CTi07QhN01/K6`0;bl_04U9B@1BDU80@41002PX:01GEeL0Kfm_03Xj>P1ADE40
@41002h^;P1FEUH0JFUY04U9B@0S8b<0GUiN04Y:BP0l?3`0NWYj08F5Q@1=CDd0;Bd]06MWI`1`L700
FEUI03Xj>P1lO7`0HF5Q034a<@1ZJVX0KFe]0492@P1<C4`0GemO04A4A02@T900PX:20451@@0m?Cd0
DU9B04M7A`1BDU80F5QH059BDP1iNGT0LW9b0492@P0k>c/0PH6105YJFP0m?Cd0AdM7096AT@1DE5@0
>SXj05IFEP2ATI40>CTi038b<P1gMgL0N7Qh0410@01iNGT0QHF507EeM@19BDT0EEEE07moO`15ADD0
GUiN079bLP1:BTX0MWIf04e=C@1jNWX0JFUY04=3@`1ZJVX0IFEU04U9B@1/K6`0LG5a0492@P1YJFT0
F5QH08F5Q@1BDU80>c/k05UIF@1gMgL0BTY:055AD@1VIVH0CDe=0080IfMW0>40ADE509NGU`1ZJVX0
IfMW08:2PP1/K6`0Cdm?07QhN00Y:BT0LW9b06EUI@2:RXX0^[Zj07inOP0f=SH0OWin09RHV01QHF40
Ogmo03@d=011@D40NWYj07alO019BDT0De=C07=cL`10@400EUIF07emO@1UIFD0?Shn096AT@10@400
Kfm_08V9R@1SHf<0BTY:06MWI`1HF5P0L71`0:RXZ01GEeL0De=C0;6a/@2VYZH0@41006MWI`1hN7P0
R8R803lo?`1oOgl0Y:BT07emO@1DE5@0/;2`0:f][@1IFET0Hf=S05eMG@2=SHd0NWYj08:2PP1OGel0
F5QH030`<01YJFT0F5QH030`<01_Kfl0;bl_05YJFP2GUiL0JFUY05EEE@29RHT0?Shn04E5A@2>SXh0
F5QH04];B`1[Jf/06QXJ03dm?@2_[jl0EeMG030`<015ADD0EEEE09>CT`1DE5@0:b/[05iNGP1>CTh0
I6AT04A4A02CTi<0QHF50:n_[`20P8009RHV071`L01[Jf/0Hf=S08R8R01XJ6P0B4Q804Y:BP2CTi<0
ATI605MGE`2>SXh0<30`02`/;01^KVh0NGUi07moO`1NGUh0Hf=S07IfMP12@T80;bl_06a/K02DU9@0
Fe]K03lo?`2QXJ40?3`l07IfMP1hN7P0H61P05EEE@2LW9`0JFUY03Hf=P15ADD0KVi^07QhN01=CDd0
7QhN07]kN`0m?Cd0820P04=3@`1TI6@0QXJ607QhN00];Bd0c<c<08f=S@1bLW8071`L04a<C01JFUX0
HF5Q03Lg=`10@400C4a<03Lg=`1RHV80Kfm_03/k>`1hN7P0PX:20410@00a<C40N7Qh04U9B@1fMWH0
U9BD06MWI`0c<c<05aLG02<S8`1;Bd/0D51@01/K6`13@d<0RXZ:0:RXZ02?Shl0M7Ad04E5A@0l?3`0
>SXj02HV9P0P8200@D510;>c/`1ZJVX0@T92065QH@1?Cdl071`L02@T901XJ6P0WIfM0<C4a035aLD0
`l?30;bl_02:RXX0KVi^0:FUY@3Cdm<0b<S80<o?c`27QhL0?Shn02TY:@0N7Qh07AdM028R8P1CDe<0
GUiN04Y:BP1?Cdl0=3@d038b<P0`<300=SHf08j>SP0d=3@07alO020P800O7al00`0P820201`L700H
069RHP2BTY80d];B05ADE02FUYH0K6a/0410@014A4@0CDe=04=3@`2@T900OGem0:b/[01RHV80<S8b
034a<@0];Bd0;2`/024Q8@0a<C40AdM703Ti>@0/;2`07AdM0`0E5AD03@0K6a/0O7al06ATI00O7al0
6ATI01`L700N7Qh09BDU03Lg=`1TI6@0][Jf0=3@d03<c<`00P3WinL0>P3:b/X0Kfm_05MGE`22PX80
B4Q80451@@0l?3`0<S8b03Lg=`0W9bL07alO01`L700O7al0CDe=05UIF@0[:b/0:BTY01lO7`0n?Sh0
VYZJ0=OGe`1OGel0<S8b01TI6@0E5AD05aLG03@d=026QXH0BTY:07inOP2=SHd0alO705]KF`11@D40
<30`03Xj>P0a<C40@D5104e=C@1TI6@0Lg=c0;Ng]`1:BTX0ATI608J6QP1]KFd0:BTY02<S8`0X:2P0
9BDU03Ti>@16ATH0P82004I6AP0a<C40?Shn06i^KP2j^[X209jNWP0:07AdM01ZJVX0De=C055AD@1W
IfL0IFEU08>3P`2JVYX0DE5A024Q8@80:BTY01H0>c/k04m?C`0U9BD05aLG01XJ6P0L71`0ATI603Ph
>01BDU80WIfM0861P@1CDe<0FEUI028R8P0[:b/07alO01TI6@0H61P06ATI01PH600V9RH0Jf][0P0[
:b/03P1mOGd0MWIf0492@P1HF5P0JVYZ04Y:BP1cLg<0[Zj^04I6AP0T92@071`L03Xj>P19BDT06QXJ
100E5AD0E00c<c<0FUYJ09BDU03GemL0f][J059BDP0M7Ad071`L01TI6@0S8b<0EeMG01PH600I6AT0
6a/K034a<@0G5aL05ADE06UYJ@11@D40GUiN02XZ:P0m?Cd0VYZJ0:j^[P1nOWh0MGEe071`L029RHT0
^k^k09fMW@3AdM40_kno08n?S`10@4008R8R01dM7@0L71`09BDU08B4Q00e=CD0Cdm?09BDU02QXJ40
VYZJ04i>CP19BDT0WYjN02DU9@0k>c/0>SXj01hN7P2@T900h>3P0<C4a02UYJD0_;bl069RHP14A4@0
6ATI01DE5@0O7al09bLW04E5A@2;Rh/0=cLg024Q8@0f=SH0SXj>03Xj>P0Q8B40>c/k04i>CP1;Bd/0
NWYj0:j^[P1?Cdl0AdM704I6AP1FEUH0ADE501DE5@0C4a<05ADE01<C4`8051@D01T0:RXZ05MGE`0i
>CT0EeMG0<W9b@3Kfm/0d];B0:JVYP3:b/X0UYJF06i^KP1EEED0E5AD04i>CP1;Bd/0IFEU0<C4a02m
_Kd0De=C02h^;P12@T80CDe=08J6QP1GEeL0?Cdm00;ooooo00020820P01k06MWI`1HF5P0>c/k06e]
K@0n?Sh0ADE5092@T012@T80M7Ad09ZJVP15ADD0@d=3055AD@0j>SX0@T92061PH00`<300K6a/04];
B`1=CDd0MgMg02XZ:P2=SHd0>c/k05=CD`1MGEd0Cdm?03Xj>P19BDT0IFEU03dm?@0[:b/0H61P05YJ
FP1ADE40EUIF01`L700l?3`0UYJF03`l?00c<c<0Lg=c05ADE00l?3`0B4Q805QHF00_;bl06QXJ03lo
?`1=CDd0:b/[05UIF@0h>3P08B4Q03hn?P1?Cdl0<c<c028R8P1JFUX09bLW02/[:`24Q8@0HF5Q03<c
<`0e=CD0J6QX04U9B@0g=cL0Hf=S07AdM01ADE40<30`06YZJP1JFUX0:2PX02l_;`1>CTh0;Rh^07Ui
N@24Q8@0EeMG04A4A01:BTX0;2`/04m?C`1/K6`0GEeM092@T025QHD0;Rh^04Q8B02@T900Ng]k03Hf
=P1KFe/0SXj>04Q8B00o?cl0IFEU09BDU01FEUH0;Rh^07alO01QHF40<30`05YJFP1=CDd0FEUI04Y:
BP1SHf<0Q8B402h^;P1FEUH0LG5a04U9B@1VIVH0>CTi08>3P`1/K6`0<S8b04m?C`15ADD0>3Ph0080
OGem02<0>c/k04i>CP0g=cL0L71`07IfMP1:BTX0Fe]K061PH014A4@0ADE505iNGP1PH600E5AD05]K
F`0m?Cd0KVi^05aLG01OGel0G5aL05EEE@1gMgL0G5aL03/k>`1ZJVX0BDU906e]K@2LW9`0Kfm_03Hf
=P1WIfL0MWIf04Q8B01fMWH0Fe]K04I6AP02061PH01i03<c<`0b<S80IFEU059BDP0o?cl0BTY:0451
@@0n?Sh0U9BD03Ti>@1=CDd0GEeM04=3@`1:BTX0M7Ad04m?C`1HF5P0OWin03`l?00m?Cd0V9RH09JF
UP1>CTh0N7Qh06a/K02DU9@0FUYJ09RHV02b/[80RHV905iNGP34a<@0Z:RX079bLP1lO7`0K6a/08N7
Q`1[Jf/0YJFU09VIV@25QHD09bLW05]KF`1IFET0:2PX06UYJ@11@D40DE5A07=cL`1=CDd0FEUI0861
P@1HF5P0Ng]k0;:b/P1RHV80Bd];07inOP0W9bL0>3Ph0;Ng]`13@d<0>3Ph04Y:BP1CDe<0Ti>C02TY
:@0W9bL0LW9b08N7Q`1iNGT0EUIF0;jn_P2QXJ40Zj^[0451@@0c<c<0Ogmo05]KF`1OGel0LW9b03Hf
=P0T92@0De=C08Z:RP11@D40GemO08^;R`1KFe/0A4A406EUI@1_Kfl0Ogmo061PH01eMGD0V9RH07Qh
N00g=cL0CDe=07=cL`1UIFD0AdM70:JVYP1eMGD0N7Qh06i^KP1oOgl0Fe]K09bLW01oOgl0IVIV04M7
A`1EEED0L71`04U9B@0Q8B40SXj>096AT@1:BTX0CDe=06i^KP02096AT@0m03Hf=P2c/k<0UiNG08B4
Q00V9RH0CTi>04a<C01aLG40>SXj05mOG`1NGUh0@D5105EEE@0_;bl07AdM061PH01lO7`0=SHf034a
<@22PX80F5QH0:RXZ02WYjL0GEeM03Hf=P0C4a<07QhN04i>CP1HF5P06a/K04a<C027QhL0K6a/05mO
G`1ZJVX0T92@08N7Q`1@D500@D5105ADE02UYJD0L71`05mOG`1jNWX0;Rh^01XJ6P0M7Ad0DU9B06a/
K02GUiL0?clo06IVIP2_[jl0VYZJ08n?S`2k^k/0f][J0=7Ad@32`/80IfMW06][J`0201/K6`0K01dM
7@0G5aL05ADE03Xj>P1aLG40=cLg03@d=00W9bL0:BTY02d];@1]KFd0CDe=0410@01ADE40EeMG05IF
EP18B4P0A4A404E5A@0o?cl0Cdm?06m_K`1QHF40a<C407IfMP19BDT06a/K00805ADE0P0F5QH0400g
=cL0KFe]06ATI01;Bd/0H61P03`l?00];Bd0:BTY02PX:00l?3`0@d=304i>CP0^;Rh071`L01TI6@0J
6QX201DE5@0U02DU9@2HV9P0G5aL04U9B@0Z:RX06a/K01dM7@0O7al0;Bd]08V9R@3Cdm<0/[:b0<S8
b02JVYX0bl_;0;fm_@2k^k/0`/;207=cL`1BDU80D51@08N7Q`2EUID0Rh^;07alO01gMgL0NGUi08^;
R`2BTY80MGEe05aLG01MGEd0Ng]k0;no_`3Cdm<0CDe=03/k>`0201HF5P0b024Q8@1NGUh0=3@d03lo
?`2MWId0NWYj08F5Q@12@T80CDe=05IFEP1=CDd0@d=303Ti>@0g=cL0>3Ph05MGE`38b<P0T92@08F5
Q@2>SXh0<c<c028R8P0P8200<c<c01dM7@0Q8B40Hf=S08f=S@0n?Sh0<C4a02TY:@1kNg/0JVYZ051@
D01TI6@0=3@d0410@01=CDd0IfMW0;2`/01RHV80O7al0:2PX01SHf<08R8R01hN7P0P82008B4Q03/k
>`0g=cL301`L700:04Q8B00l?3`0EEEE08f=S@2;Rh/0LG5a079bLP0[:b/0A4A401hN7P806QXJ01h0
6a/K01TI6@0n?Sh0PX:204I6AP26QXH0GemO03De=@0L71`0820P030`<01HF5P0JFUY06YZJP0g=cL0
>CTi01dM7@0k>c/0<c<c01XJ6P0E5AD061PH02DU9@1XJ6P0Zj^[0::RXP2TY:@0XJ6Q0:b/[02ZZZX2
01TI6@0N01PH600U9BD0DE5A01PH600K6a/07alO02PX:00E5AD06ATI05UIF@0`<300>SXj04Q8B010
@400RXZ:0;bl_02?Shl0OGem075aL@28R8P0U9BD05IFEP1gMgL0/[:b0;Ng]`24Q8@0IfMW07EeM@18
B4P0IFEU0P2/[:`01`2@T900ADE504];B`1IFET0J6QX05]KF`27QhL00P0I6AT0700j>SX0FUYJ08R8
R039bLT0D51@03hn?P1JFUX0D51@03`l?00H61P09BDU03De=@1dM7@0_[jn07]kN`0N7Qh07alO02HV
9P1;Bd/0:2PX01PH600L71`0:BTY055AD@2>SXh0T92@01dM7@0U9BD202LW9`0304Q8B00M7Ad04a<C
008051@D01/04A4A018B4P0F5QH0JFUY07moO`1KFe/0^KVi0=7Ad@2DU9@0IfMW09FEU@2IVIT0@D51
04E5A@19BDT0EEEE06QXJ01/K6`0TY:B0;bl_01PH600KVi^07moO`29RHT0E5AD024Q8@0N7Qh00_oo
ool0000I065QH@1CDe<0FUYJ05]KF`0j>SX0Hf=S03<c<`1=CDd0Q8B40410@01lO7`0OGem03`l?01F
EUH0NGUi05ADE00k>c/0HV9R02PX:01[Jf/0<C4a03De=@1FEUH07alO08N7Q`0203@d=03=04E5A@1=
CDd0@T9205aLG01[Jf/0D51@02<S8`1?Cdl09BDU04i>CP1HF5P0:2PX02h^;P2EUID0:b/[03@d=01/
K6`0ATI603Hf=P0R8R80Cdm?034a<@0M7Ad0?Shn03dm?@0N7Qh0ATI603`l?00e=CD0D51@04e=C@0Y
:BT07alO06IVIP19BDT0;bl_08j>SP13@d<07QhN03Xj>P1bLW80BTY:02XZ:P1:BTX0AdM702TY:@0^
;Rh0DE5A065QH@0l?3`0;bl_03hn?P0i>CT0VIVI07inOP1EEED0HV9R05QHF00f=SH0De=C05UIF@1G
EeL0Vi^K06][J`0T92@0?Shn071`L01TI6@0=CDe04a<C01oOgl0:RXZ038b<P1@D500OWin03hn?P0c
<c<0LG5a06a/K013@d<0MGEe04a<C018B4P0>SXj06][J`1fMWH0?clo069RHP1MGEd0DE5A06UYJ@1H
F5P0LW9b07AdM00i>CT0D51@08F5Q@1KFe/0Ph>308:2PP0n?Sh0Hf=S06ATI01dM7@0De=C04U9B@1[
Jf/0QHF504M7A`1;Bd/0DU9B05]KF`1ADE40GUiN04i>CP1bLW80E5AD06IVIP1gMgL0LG5a09fMW@1@
D500>3Ph07inOP1UIFD0SHf=0:>SX`1OGel0=3@d07AdM01kNg/0G5aL0861P@18B4P0GEeM08J6QP1d
M7@0?clo02l_;`1XJ6P0EEEE04A4A01=CDd0IfMW03lo?`2:RXX0>SXj06i^KP1UIFD0IVIV04E5A@1j
NWX0I6AT06YZJP1iNGT0ATI604i>CP2UYJD0YjNW069RHP1gMgL0K6a/08N7Q`1BDU80Shn?0;:b/P21
PH40MWIf0=KFeP2TY:@0Kfm_0861P@1VIVH0Kfm_05ADE02][Jd0c<c<05MGE`0V9RH0JVYZ06ATI00W
9bL0KVi^0451@@1HF5P0Jf][04A4A01LG5`0PH61059BDP22PX80UYJF04A4A01MGEd0WYjN04];B`0k
>c/0^KVi04Y:BP19BDT0HV9R06MWI`25QHD0?3`l02LW9`0204m?C`1b05YJFP1>CTh0b/[:0:NWY`2/
[:`0Lg=c034a<@1WIfL0Bd];06][J`20P800EeMG03hn?P1ZJVX0Lg=c03hn?P2>SXh0/k>c05mOG`0j
>SX0KVi^07=cL`0f=SH0?Cdm09:BTP2n_[h0SXj>03lo?`1EEED0KFe]06QXJ011@D40Q8B4075aL@25
QHD0K6a/06][J`1RHV80d];B0;jn_P1_Kfl0C4a<05ADE01nOWh0?clo0451@@3?cll0UiNG04M7A`1E
EED0IVIV08V9R@1mOGd0;bl_08N7Q`29RHT0DE5A01lO7`1>CTh0D51@04E5A@1OGel0WYjN06YZJP18
B4P0GemO07EeM@0W9bL0B4Q807=cL`0l?3`0=cLg07inOP0i>CT0J6QX0:b/[01LG5`09RHV018B4P0J
6QX0DU9B06e]K@0Q8B40H61P09VIV@1CDe<0CTi>04I6AP11@D40Cdm?08B4Q02b/[80alO70:FUY@22
PX80J6QX03Lg=`0G5aL06a/K03@d=01>CTh0PH61051@D00Q8B40>3Ph0;jn_P2d];@0Cdm?03/k>`2e
]KD0Y:BT09>CT`0T92@0820P0P0C4a<2014A4@0301<C4`0f=SH0:2PX00805aLG0`0E5AD01@0b<S80
Bd];03/k>`0f=SH0>CTi0080?Cdm00/0<c<c038b<P0m?Cd0BTY:07YjNP1mOGd0c/k>0;:b/P0_;bl0
5ADE01<C4`0201DE5@0>01<C4`0a<C40Bd];05=CD`0L71`0?Cdm02<S8`0X:2P08R8R01dM7@0O7al0
:BTY02/[:`0];Bd201dM7@1Z01`L700G5aL05ADE01PH601:BTX05ADE01`L7016ATH0BDU902<S8`0c
<c<0FEUI08>3P`3Ng]h0iNGU0=7Ad@1dM7@0?clo04=3@`1fMWH0c<c<0=CDe02e]KD0GUiN09fMW@2;
Rh/0LG5a06QXJ01hN7P0NWYj08Z:RP22PX80ZZZZ0:n_[`2j^[X0a/K60=CDe02l_;`0PH6104A4A00]
;Bd09BDU0861P@0e=CD0=SHf04i>CP2<S8`0<S8b05MGE`1RHV808B4Q01`L700Y:BT0;Rh^03@d=00i
>CT0@41004a<C029RHT0WYjN0=OGe`10@4009bLW02<S8`0O7al0:BTY01dM7@0P8200Ogmo08b<S018
B4P0<30`020P801fMWH0C4a<05UIF@1XJ6P09bLW02PX:00h>3P0?clo0861P@1OGel0/k>c09VIV@1?
Cdl08B4Q01XJ6P0K6a/06QXJ01dM7@0k>c/0=SHf01`L700Y:BT0<S8b03Hf=P1<C4`0Vi^K0<71`@2I
VIT0RXZ:04m?C`17AdL0820P01XJ6P<06a/K00D0EUIF0;jn_P2JVYX0GUiN03Lg=`0301`L701m01dM
7@0S8b<0Fe]K08V9R@1VIVH0>CTi01dM7@0m?Cd0<30`02@T9016ATH0OWin08:2PP1NGUh0BDU906QX
J01lO7`0MgMg06MWI`2][Jd0ADE501dM7@0N7Qh0De=C05]KF`0G5aL06ATI02HV9P0R8R805ADE02<S
8`17AdL08R8R02TY:@16ATH0MGEe0:ZZZP1DE5@0@41003Lg=`0^;Rh0;2`/04M7A`1KFe/0<c<c08n?
S`2d];@0;Bd]028R8P0d=3@0_kno0:ZZZP25QHD0NGUi030`<00R8R80@T9205=CD`1LG5`0?clo08^;
R`0I6AT05aLG01hN7P0a<C40RHV909:BTP0`<300A4A403hn?P1DE5@0=cLg038b<P1TI6@0G5aL03<c
<`1ZJVX0@41001dM7@0S8b<0820P03Lg=`0c<c<05QHF01TI6@0M7Ad0;bl_05MGE`20P800<C4a01dM
7@0S8b<07alO02l_;`15ADD05ADE018B4P0D51@04Q8B01<C4`0R8R80IVIV05aLG018B4P0WinO0:^[
Z`1MGEd0;bl_06UYJ@1oOgl07alO024Q8@0Y:BT0<S8b03De=@0l?3`0GEeM09VIV@0h>3P0Jf][09jN
WP23Ph<0@d=303De=@0O7al00_ooool0003I075aL@25QHD0J6QX071`L010@400QhN703hn?P15ADD0
R8R803hn?P1mOGd0IFEU02/[:`0c<c<0Bd];03/k>`0l?3`08B4Q02HV9P1^KVh0C4a<038b<P0f=SH0
6ATI07UiN@13@d<0<S8b051@D01MGEd0=3@d04U9B@1ZJVX0BTY:02@T901LG5`0De=C051@D01ADE40
<C4a02PX:022PX80:b/[0492@P1<C4`0?3`l02`/;00o?cl0F5QH028R8P0J6QX0>c/k03Xj>P0f=SH0
BTY:034a<@0];Bd0?clo05aLG01:BTX09BDU06i^KP1RHV80;Rh^09NGU`1gMgL0@T9202d];@1YJFT0
F5QH038b<P1GEeL0E5AD04i>CP0^;Rh0<30`05eMG@0h>3P0<C4a04U9B@0l?3`0V9RH07EeM@0/;2`0
A4A405iNGP0n?Sh0DU9B02l_;`1@D500Z:RX07EeM@0e=CD0C4a<08b<S01HF5P0;bl_04m?C`1`L700
;Rh^03De=@1DE5@0O7al03De=@0f=SH0P82008^;R`0k>c/0N7Qh04];B`1?Cdl0@T9208J6QP23Ph<0
@41006][J`1EEED0LG5a08N7Q`1CDe<0SXj>06EUI@12@T80K6a/06UYJ@0j>SX0Ogmo07AdM01fMWH0
UYJF07moO`22PX80<S8b06UYJ@2SXj<0P82004E5A@1>CTh0DE5A05YJFP1RHV80Jf][059BDP1_Kfl0
BTY:06m_K`1jNWX0JVYZ09fMW@0m?Cd0>3Ph08^;R`1OGel0UIFE0;2`/01ZJVX0BTY:0;2`/02<S8`0
GEeM08B4Q00a<C40MWIf0:>SX`1mOGd0C4a<02DU9@1bLW80E5AD07YjNP22PX80EUIF03Xj>P2;Rh/0
@41007EeM@1^KVh0L71`04Y:BP2DU9@0M7Ad071`L01bLW80Bd];04e=C@2JVYX0YJFU051@D01_Kfl0
MgMg09>CT`1CDe<0RHV908f=S@0a<C40A4A40<30`02OWil0KVi^08Z:RP1ZJVX0KVi^04];B`29RHT0
Shn?04i>CP0W9bL0JFUY0451@@0V9RH0MGEe03lo?`1<C4`0P82005ADE01[Jf/0Ogmo06ATI00208V9
R@1_04E5A@0Y:BT0HF5Q04I6AP0[:b/0`/;203dm?@0Y:BT0IfMW0:j^[P2>SXh0<C4a038b<P1JFUX0
Bd];04E5A@0l?3`0c/k>0:VYZ@2UYJD0Jf][03De=@21PH40D51@08Z:RP2j^[X0IFEU0410@01jNWX0
KVi^02`/;02;Rh/0[:b/065QH@0j>SX0MgMg06i^KP1[Jf/0CTi>05ADE01[Jf/0Kfm_03Xj>P1BDU80
UYJF02d];@0e=CD0Vi^K06QXJ01iNGT0KFe]034a<@0X:2P0Ph>308^;R`1OGel0BDU905=CD`1gMgL0
9BDU01<C4`2IVIT0TY:B0451@@1FEUH0Jf][07emO@0/;2`07alO07]kN`2:RXX0FEUI02HV9P1<C4`0
GUiN02@T900d=3@0@d=303hn?P1EEED0PX:207UiN@0/;2`0DE5A051@D00`<300IFEU0:NWY`1MGEd0
Jf][06YZJP1@D500:b/[014A4@0F5QH0CTi>02LW9`0O7al0PX:20:6QX@1MGEd0DU9B04a<C00o?cl0
FUYJ06][J`37alL0d];B0=?Cd`33`l<0:b/[00806ATI02h0;Bd]03@d=01NGUh0QXJ604e=C@1VIVH0
K6a/06QXJ02PX:00RHV903`l?021PH40S8b<0861P@1ZJVX0FEUI01hN7P0K6a/08b<S01dM7@0N7Qh0
CDe=03De=@0N7Qh06QXJ01DE5@0C4a<05ADE01XJ6P0k>c/0<c<c02XZ:P0X:2P08b<S020P800T92@0
;bl_03@d=00^;Rh0OGem0<30`03Ng]h0];Bd07alO018B4P07QhN0`0E5AD03P0o?cl0AdM704m?C`0K
6a/06ATI01DE5@0G5aL08B4Q01dM7@0I6AT08b<S02`/;00^;Rh06QXJ0P0L71`0=00F5QH06ATI01LG
5`0l?3`05aLG01<C4`0E5AD0>c/k08n?S`2EUID0WIfM0;Fe]@3?cll0f=SH0:b/[022PX80>SXj03<c
<`0];Bd0=SHf06MWI`1@D500A4A404U9B@0e=CD071`L01dM7@0L71`09RHV08J6QP1mOGd0EEEE06EU
I@2ZZZX0hn?S0>CTi03@d=00alO709JFUP1gMgL0WinO07alO00o?cl0>SXj071`L01CDe<06a/K01`L
701eMGD0BDU901lO7`0K6a/201XJ6P0a024Q8@0Y:BT0;Bd]05IFEP0l?3`0S8b<03`l?00S8b<09BDU
028R8P0S8b<0;Bd]0492@P21PH40KVi^04E5A@0U9BD0;Bd]07inOP0o?cl0B4Q8065QH@0Y:BT09bLW
03De=@0_;bl0C4a<08V9R@20P800a<C406][J`0e=CD07alO01`L700N7Qh071`L01lO7`13@d<0<S8b
04E5A@0j>SX0>c/k051@D02g]kL0_Kfm0=?Cd`36a/H0RHV903Hf=P0201hN7P807alO02D09RHV0;2`
/02TY:@0DE5A03Ti>@0K6a/06QXJ01dM7@0L71`07AdM01hN7P12@T80?Cdm071`L01_Kfl0?clo06YZ
JP2@T900Ogmo06e]K@11@D40@41005mOG`2TY:@0^k^k06ATI00O7al0GemO05QHF02TY:@092@T028R
8P14A4@0H61P01HF5P0I6AT0?Cdm00805ADE04@0=cLg03De=@0M7Ad0820P03@d=02<S8`0Ng]k034a
<@0[:b/07alO01/K6`0F5QH09RHV05MGE`0O7al0Bd];0;6a/@1EEED07AdM05=CD`2CTi<0>3Ph05eM
G@1aLG409BDU02TY:@0c<c<0@d=305UIF@0f=SH0Shn?01TI6@0E5AD061PH028R8P2CTi<0Ng]k07em
O@1lO7`0MgMg09jNWP2`/;00O7al02h^;P0E5AD05aLG04E5A@0`<3007QhN02DU9@0S8b<0:2PX0492
@P0L71`05aLG01/K6`0V9RH0F5QH069RHP0Z:RX09bLW01lO7`0R8R807QhN03De=@0`<3005ADE010@
40805ADE01T0@41004];B`2=SHd0QHF509VIV@2@T900ADE50410@01PH600MGEe01dM7@0O7al07QhN
02LW9`0`<300?Shn03lo?`1dM7@0=CDe055AD@1_Kfl0K6a/02l_;`1@D500FUYJ00;ooooo0000:`20
P800Q8B406][J`1[Jf/0IFEU09jNWP16ATH0F5QH096AT@0k>c/0Ph>30::RXP15ADD0B4Q806YZJP1E
EED0CDe=06MWI`0a<C40QHF505YJFP0j>SX0Jf][02h^;P2@T900C4a<02`/;01EEED0LG5a04M7A`1G
EeL0J6QX05UIF@0Q8B40IFEU05iNGP1@D500Cdm?03<c<`0/;2`0OWin03De=@1=CDd00P1>CTh02@0b
<S80B4Q8065QH@0U9BD06ATI03`l?00Z:RX0=cLg05=CD`0203<c<`0?0451@@1XJ6P0De=C02/[:`1b
LW80Fe]K02d];@2^[Zh0Ng]k03lo?`0e=CD0L71`051@D00T92@0I6AT0080Fe]K0?l0>SXj03Lg=`1Y
JFT0@41004a<C01cLg<0<c<c08j>SP1[Jf/0?Shn04Y:BP1FEUH0=3@d055AD@1>CTh0?Shn06ATI01N
GUh0?Cdm055AD@23Ph<0E5AD02d];@1DE5@0NGUi02d];@0e=CD0D51@079bLP0_;bl0H61P07]kN`1h
N7P0=CDe08:2PP18B4P0De=C02PX:01aLG40Lg=c03Lg=`1/K6`0@d=3059BDP1eMGD0BTY:08:2PP13
@d<0;Bd]05ADE01^KVh0@d=30820P01<C4`0?3`l06][J`1eMGD0I6AT04=3@`0f=SH0E5AD07=cL`10
@400CDe=05QHF00m?Cd0HF5Q07YjNP18B4P0J6QX03Lg=`1hN7P0OGem05aLG02LW9`0A4A402TY:@1k
Ng/0HF5Q0:b/[02SXj<0Hf=S02@T901OGel0NGUi05eMG@1hN7P0;bl_04i>CP2@T900EEEE03Hf=P0S
8b<0FEUI030`<01WIfL0U9BD05YJFP0k>c/0OGem030`<01nOWh0J6QX07=cL`0o?cl0QXJ606YZJP1j
NWX0Q8B404i>CP1;Bd/0XZ:R08j>SP1FEUH0T92@0:n_[`2KVi/0C4a<08b<S02^[Zh0M7Ad06][J`3J
f]X0S8b<07AdM02MWId0M7Ad07alO01eMGD0M7Ad071`L01<C4`0=SHf06UYJ@0f=SH09bLW08J6QP0i
>CT0Bd];07YjNP1cLg<0RXZ:09nOW`1ZJVX0KVi^096AT@1LG5`0Bd];07alO00j>SX0:2PX09NGU`1;
Bd/0=CDe02l_;`10@400HF5Q04i>CP0c<c<0Hf=S05MGE`0c<c<0?Cdm0=3@d03<c<`0TI6A05UIF@0d
=3@0QXJ601DE5@1mOGd0W9bL05aLG013@d<0WYjN071`L00S8b<0GUiN07emO@0l?3`0;2`/07emO@1V
IVH0N7Qh055AD@1JFUX0QHF506i^KP0d=3@0C4a<06ATI00h>3P09bLW06QXJ01BDU80KVi^04m?C`0o
?cl0FUYJ08n?S`1JFUX0CTi>03`l?01NGUh0O7al0492@P0U9BD0[:b/08N7Q`0l?3`0EUIF07QhN029
RHT0C4a<02LW9`0n?Sh0LG5a04];B`0i>CT0J6QX08R8R01?Cdl0=cLg0492@P0b<S80@41006][J`28
R8P0;2`/05mOG`1fMWH0;bl_0410@01kNg/0DE5A08R8R02>SXh0@41003Ph>00Z:RX07QhN0410@01D
E5@071`L04];B`1_Kfl0QXJ609BDU02TY:@0RHV909bLW02h^;P0d];B0;jn_P2g]kL001l0MWIf08B4
Q01OGel0BDU903Hf=P1lO7`0Rh^;08J6QP1bLW80?clo01XJ6P0F5QH06a/K05QHF02EUID0NWYj0:VY
Z@2`/;00_;bl0=_Kf`34a<@0Ph>305=CD`1;Bd/0CDe=08B4Q01gMgL0Bd];024Q8@0L71`06ATI0080
5ADE01T0:b/[034a<@0X:2P0820P01lO7`0^;Rh0?3`l03lo?`1bLW80Vi^K0<?3``2FUYH0WIfM06][
J`29RHT0Ti>C06m_K`0k>c/08b<S01DE5@1=CDd0Cdm?05YJFP0P82005aLG00805ADE00P05aLG01lO
7`0Q8B40<c<c02HV9P0f=SH07alO01/K6`8071`L070061PH01DE5@0Y:BT06ATI01<C4`0B4Q8061PH
09BDU01/K6`0ATI60:RXZ03;bl/0emOG09bLW00e=CD0>CTi03Xj>P0d=3@0;2`/02/[:`0X:2P0<30`
03Ti>@1;Bd/0?Cdm01lO7`0[:b/0AdM705=CD`1FEUH0Cdm?05eMG@2GUiL0f=SH0=?Cd`1KFe/0EEEE
051@D018B4P0Ti>C0:2PX01mOGd0ZZZZ09ZJVP0R8R806ATI01LG5`0];Bd0NWYj051@D00S8b<05aLG
01DE5@0I6AT0820P02DU9@17AdL0=3@d04A4A01XJ6P0820P01dM7@0O7al0820P02l_;`11@D40GEeM
06i^KP19BDT09BDU04=3@`1lO7`0ATI603Hf=P0U9BD092@T028R8P0Z:RX09BDU030`<01XJ6P0<C4a
0:2PX03:b/X0Hf=S03Lg=`0[:b/07AdM01`L700I6AT07QhN04Q8B01bLW80Bd];04A4A021PH40ZZZZ
09JFUP1RHV80Ogmo0:2PX01mOGd0EeMG03/k>`11@D40=SHf07AdM020P800QXJ603Xj>P0Q8B407alO
0P0I6AT07@0K6a/071`L01`L701ADE40>c/k02`/;01JFUX0_kno0;Vi^@1_Kfl0DE5A05YJFP1ZJVX0
Rh^;09>CT`2/[:`0c<c<06IVIP0[:b/0EeMG04Y:BP1`L700LW9b01dM7@0k>c/0FUYJ01LG5`0M7Ad0
@T9200805ADE00L0?clo02d];@0L71`09bLW0451@@1SHf<0:b/[00D05ADE01l06a/K05IFEP0O7al0
9BDU06a/K02KVi/0LW9b08^;R`0l?3`0=CDe05ADE02GUiL0=CDe02d];@0f=SH0>c/k05iNGP19BDT0
Vi^K028R8P0E5AD06ATI03dm?@2_[jl0QHF50;:b/P2EUID0XJ6Q0;fm_@2][Jd0FEUI00805ADE00D0
5QHF04E5A@0T92@07QhN024Q8@0201lO7`0[04U9B@0Y:BT071`L01XJ6P0W9bL0D51@0:RXZ01LG5`0
;2`/02d];@0O7al08b<S01lO7`0e=CD0<c<c01<C4`0E5AD0>SXj059BDP1<C4`0UiNG09VIV@2_[jl0
Shn?05ADE01IFET0S8b<0:j^[P0k>c/0820P024Q8@0U9BD0:RXZ02l_;`11@D40P82006MWI`1_Kfl0
CTi>06UYJ@0Y:BT0;Rh^03`l?002ooooo`0002`0Ng]k06i^KP1UIFD0ADE504];B`1hN7P0@T9205EE
E@22PX80@D5108f=S@2WYjL0?Shn04a<C00g=cL0:b/[06QXJ01?Cdl0=CDe069RHP0_;bl0EEEE069R
HP0`<300U9BD04a<C01^KVh0SXj>071`L011@D40ATI606IVIP1KFe/0:b/[07QhN01XJ6P0DE5A04M7
A`0U9BD0EEEE0:BTY011@D40E5AD05IFEP80?clo01<0BDU905IFEP0^;Rh0?Shn07emO@13@d<0=CDe
05ADE014A4@0<c<c06i^KP1bLW80Cdm?02DU9@1TI6@07alO0410@02QXJ40NWYj0080>CTi00X0MGEe
04i>CP0e=CD0Ph>306EUI@1JFUX0>SXj061PH01KFe/0;bl_0P1=CDd0KP0[:b/0RHV905eMG@12@T80
CTi>04M7A`0a<C40E5AD04U9B@1SHf<0UiNG05UIF@0P8200De=C0820P00m?Cd0ATI609bLW02ATI40
@D5103Lg=`1ADE40GEeM030`<01:BTX0DE5A06ATI00d=3@0TY:B05iNGP1>CTh0<c<c079bLP1RHV80
>3Ph06e]K@1ZJVX0Jf][06UYJ@1;Bd/0MWIf05UIF@0/;2`0Bd];05UIF@0c<c<0Lg=c07UiN@1FEUH0
RHV906e]K@1XJ6P0G5aL059BDP1RHV80LG5a03Ph>018B4P0GEeM06UYJ@1CDe<0IfMW04M7A`1IFET0
Fe]K06EUI@1iNGT0KFe]07YjNP1@D500@T9207emO@1LG5`0WinO0::RXP1QHF40>c/k08V9R@1YJFT0
KVi^08:2PP0a<C40HV9R09^KV`1DE5@0>CTi02`/;01RHV80@D5104A4A01EEED0CDe=03Ph>02FUYH0
ADE50:6QX@2WYjL0NWYj03<c<`1hN7P0J6QX0:NWY`2f][H0Ng]k055AD@2TY:@0J6QX02DU9@1ADE40
NWYj0P0n?Sh03`2DU9@0YjNW06i^KP1ZJVX0f=SH08J6QP0o?cl0W9bL0;Fe]@2b/[80Rh^;07inOP1i
NGT0>3Ph04E5A@0207MgM`0A02/[:`21PH40=CDe05MGE`29RHT0KVi^08n?S`2>SXh0>CTi08^;R`2f
][H0D51@04e=C@1VIVH0@T9202PX:024Q8@00P1FEUH0?`1:BTX0ADE505]KF`18B4P0=CDe065QH@1O
Gel0=CDe051@D03=cLd0alO70:JVYP1oOgl0=3@d07moO`0m?Cd0FEUI06ATI013@d<0D51@0:FUY@1e
MGD0>3Ph06YZJP1kNg/0=3@d034a<@2SXj<0TY:B08V9R@1LG5`0F5QH07moO`1]KFd0BTY:07QhN01o
Ogl0Fe]K0492@P1DE5@0BTY:071`L013@d<0820P07]kN`2NWYh0CDe=04];B`1JFUX0Rh^;07]kN`1<
C4`0:BTY0:6QX@1[Jf/0CDe=08b<S02b/[80PH6104a<C00d=3@0B4Q806MWI`0201TI6@1903Ti>@1Q
HF40DU9B03dm?@18B4P0Bd];0410@01@D500@4100492@P2:RXX0PX:203Ti>@1FEUH0W9bL04U9B@1i
NGT0SXj>04];B`0K6a/0<30`04U9B@1XJ6P0Fe]K01dM7@1;Bd/0PH6104];B`1ADE40ADE504];B`26
QXH0e=CD0;Bd]02NWYh0V9RH04i>CP1DE5@0P8200;:b/P2i^KT0R8R805UIF@1<C4`0>SXj02@T900M
7Ad06ATI01DE5@0I6AT0AdM70;jn_P2o_kl0alO70<S8b03>c/h0PX:207YjNP1WIfL0H61P05mOG`1Z
JVX0J6QX06=SH`1GEeL0C4a<04e=C@0h>3P08B4Q02XZ:P10@400@d=303dm?@0303Hf=P0B03Xj>P1a
LG40Vi^K05iNGP2FUYH0CTi>02`/;00Q8B40>CTi05EEE@1aLG40JVYZ06ATI02MWId0IVIV07=cL`0b
<S805QHF0P0E5AD02P0H61P06ATI01XJ6P0[:b/0:2PX02l_;`0N7Qh06a/K01XJ6P0M7Ad201DE5@0/
01XJ6P0T92@05ADE01@D500`<300Fe]K03/k>`16ATH0alO70;6a/@39bLT0dM7A08j>SP1/K6`0?Cdm
02TY:@0_;bl0<c<c03@d=00V9RH0:BTY03hn?P1FEUH0MWIf055AD@0k>c/0CTi>05MGE`1FEUH0Cdm?
07QhN03Hf=P0/K6a02h^;P16ATH0L71`065QH@24Q8@0Hf=S09BDU036a/H0[:b/03Xj>P0H61P201DE
5@0506m_K`1cLg<0;bl_020P800H61P00P0L71`0DP0P8200EEEE055AD@11@D40NWYj03/k>`0P8200
8B4Q028R8P0a<C40G5aL06MWI`1SHf<0>c/k03dm?@1WIfL0Ph>305ADE00O7al06QXJ01TI6@0Q8B40
:b/[02@T900_;bl0P82006IVIP2j^[X0gMgM0:BTY01QHF40IfMW069RHP1DE5@0AdM704A4A01]KFd0
KVi^08f=S@2QXJ40_kno07emO@2g]kL0T92@0::RXP1]KFd0C4a<05]KF`1]KFd0O7al07YjNP24Q8@0
OGem0:>SX`1DE5@0A4A402`/;00^;Rh0:BTY01hN7P0M7Ad09BDU05iNGP0c<c<0:b/[069RHP3>c/h0
Xj>S09fMW@1TI6@0DU9B04=3@`0j>SX09BDU03<c<`1PH600IVIV08Z:RP1cLg<0DU9B04=3@`25QHD2
04U9B@0=06=SH`0Y:BT0DU9B06UYJ@0E5AD05aLG04E5A@0/;2`07QhN02TY:@1HF5P0C4a<01TI6@04
01DE5@0301LG5`0H61P0D51@00808B4Q02H0Fe]K0;Zj^P2NWYh0A4A403Xj>P1FEUH0^KVi0=CDe02b
/[80GemO03/k>`0i>CT0HF5Q075aL@3=cLd0OGem02LW9`0V9RH0XJ6Q0:f][@2QXJ40SXj>09jNWP2V
YZH0D51@04E5A@1KFe/0ADE501LG5`0E5AD0A4A401dM7@0L71`06a/K01dM7@0N7Qh0;2`/0492@P80
7AdM00P0;Rh^05=CD`1RHV80;bl_059BDP0_;bl09BDU02HV9P809BDU01d0?Shn03/k>`0m?Cd0D51@
04Q8B01IFET0HV9R04];B`25QHD0Jf][0820P02o_kl0QhN703Ti>@1TI6@0GEeM02l_;`0S8b<0:b/[
02XZ:P0_;bl0Ogmo09jNWP24Q8@0LW9b07]kN`0^;Rh09RHV024Q8@02ooooo`0000l0N7Qh07]kN`1j
NWX0KFe]04U9B@2=SHd0?Cdm04a<C01?Cdl092@T06MWI`24Q8@0>CTi04U9B@1DE5@00P0m?Cd0o`1G
EeL0:RXZ075aL@14A4@0:2PX04e=C@0U9BD0Kfm_02/[:`0f=SH0FEUI05]KF`0f=SH0@T9206i^KP0e
=CD0;bl_05aLG017AdL0CTi>051@D00T92@09RHV06EUI@0c<c<0AdM705mOG`10@400=3@d03Lg=`1?
Cdl08B4Q01hN7P19BDT0>c/k038b<P1BDU80;Bd]01PH6014A4@0CTi>02TY:@0N7Qh0Lg=c03Lg=`0T
92@0W9bL05aLG00b<S80=3@d06ATI00W9bL08b<S0861P@1RHV80ATI602/[:`1^KVh0G5aL02PX:01F
EUH0@d=3028R8P2CTi<0Lg=c04a<C017AdL0?clo03@d=01`L700Fe]K06QXJ02LW9`0Fe]K028R8P1m
OGd0[jn_04e=C@0Z:RX0De=C06UYJ@0m?Cd0DU9B08>3P`21PH40C4a<05mOG`1@D500Fe]K02PX:01k
Ng/0HF5Q059BDP0];Bd0M7Ad04=3@`0a<C40R8R805YJFP1SHf<0C4a<04U9B@2GUiL0IVIV03De=@1L
G5`0Cdm?03Xj>P29RHT0QHF505QHF01@D500LW9b0820P01<C4`0FEUI05mOG`0l?3`0Bd];08:2PP1`
L700EUIF065QH@1PH600ATI605iNGP1EEED0Kfm_06a/K01PH600Kfm_04U9B@1<C4`0LG5a0492@P2;
Rh/0W9bL07QhN016ATH0S8b<05MGE`16ATH0P8200410@024Q8@0]KFe04M7A`10@400Bd];08R8R00l
?3`0D51@05MGE`0f=SH0E5AD08N7Q`0/;2`0EEEE05eMG@1QHF40:b/[05UIF@12@T80IVIV05IFEP0n
?Sh0GUiN0;Rh^022PX80C4a<09:BTP2YZJT0Hf=S03lo?`1jNWX0ZZZZ071`L01bLW80fMWI092@T01Z
JVX0V9RH08F5Q@22PX80S8b<07IfMP27QhL0<30`04A4A02;Rh/0K6a/02d];@1oOgl0>CTi05MGE`1b
LW80C4a<08V9R@1mOGd0C4a<06QXJ02@T900ATI604U9B@1YJFT08R8R01/K6`1dM7@0C4a<05eMG@1?
Cdl0DE5A05]KF`0f=SH0CTi>08V9R@1kNg/0B4Q80492@P2c/k<0RXZ:09bLW01hN7P0=CDe09VIV@1W
IfL0I6AT05IFEP16ATH0Kfm_0;jn_P1oOgl0?clo08F5Q@2UYJD0<S8b03@d=01VIVH0Jf][05mOG`1<
C4`0RHV90:FUY@1ADE409BDU03/k>`26QXH0De=C04A4A01GEeL0:BTY06e]K@1SHf<0A4A407inOP00
G@30`<00JVYZ024Q8@0n?Sh0FUYJ06YZJP10@400@d=30;fm_@1aLG40;bl_04A4A01VIVH0F5QH02/[
:`0h>3P0K6a/05aLG00[:b/08b<S0410@01_Kfl0=cLg05IFEP1;Bd/0ATI604Y:BP1?Cdl0IFEU02<S
8`1IFET0Ng]k03Hf=P1NGUh0V9RH03lo?`29RHT0_[jn03/k>`0Q8B404Q8B01XJ6P1DE5@0IVIV02PX
:01ZJVX0T92@034a<@1IFET0M7Ad05ADE02?Shl0`l?30;Bd]02VYZH0Shn?03/k>`1LG5`0WIfM08j>
SP24Q8@0E5AD03De=@0Q8B407AdM02@T900K6a/07QhN01`L700U9BD0JVYZ0;jn_P3Fe]H0_[jn0<W9
b@37alL0CDe=02XZ:P0T92@09bLW02h^;P1PH600DU9B03@d=00`<300>3Ph03/k>`1TI6@0MWIf06a/
K01ZJVX0>CTi01PH600401DE5@0B03Hf=P14A4@0OGem02XZ:P18B4P0FEUI03Hf=P0S8b<08B4Q02DU
9@0g=cL0DU9B07alO02DU9@0TI6A03dm?@0E5AD051@D0P0E5AD02P0D51@05QHF030`<01;Bd/0Cdm?
03Ti>@0e=CD0>c/k02DU9@0J6QX201LG5`0J034a<@0E5AD05aLG0451@@0f=SH0B4Q808B4Q034a<@0
MWIf0;Rh^01XJ6P0<C4a04I6AP1RHV80Jf][065QH@0m?Cd0?Shn03<c<`0Q8B40@41009JFUP2c/k<0
S8b<04a<C00^;Rh201PH601701DE5@0V9RH0?3`l06][J`1RHV807QhN05UIF@30`<00V9RH0:6QX@1l
O7`0SXj>030`<01CDe<0AdM701lO7`0G5aL0?clo09fMW@1BDU80<S8b024Q8@0O7al08R8R02DU9@1d
M7@0HF5Q0492@P13@d<0EeMG02d];@0/;2`0<S8b08f=S@27QhL0U9BD05=CD`16ATH0QHF508R8R020
P800LG5a01dM7@0L71`06a/K01TI6@0N7Qh0=3@d06EUI@2`/;00_kno0;jn_P1lO7`0AdM703Ph>00f
=SH0ATI604M7A`1WIfL0MGEe0;2`/02h^;P0`/;20<_;b`2f][H0]KFe0=OGe`2XZ:P0Ng]k05IFEP1J
FUX00P1@D500;`1JFUX0Ogmo08R8R02ATI40V9RH05aLG01UIFD0EUIF06ATI01MGEd0Jf][07IfMP2]
[Jd0XJ6Q02PX:01QHF40RHV90:j^[P1gMgL0HV9R02/[:`0Q8B407QhN01lO7`0M7Ad0<30`03Ti>@14
A4@0MgMg0;Fe]@1VIVH0>CTi05UIF@2VYZH0Fe]K0:ZZZP21PH40Ng]k08^;R`0^;Rh0?Cdm08J6QP0a
<C40>c/k04M7A`1RHV80<c<c00805ADE00H04a<C01DE5@0E5AD05aLG01`L701WIfL2020P800@04A4
A02=SHd0Q8B404E5A@1MGEd0YjNW0;Ng]`1;Bd/0Kfm_0<O7a`2KVi/0J6QX092@T034a<@0Z:RX0:VY
Z@80b<S800H0gmoO0:b/[02;Rh/0R8R80;Bd]01fMWH202d];@0603/k>`1ADE40HV9R04Q8B00b<S80
6QXJ0P0L71`03P0M7Ad07QhN028R8P18B4P0:RXZ01lO7`0i>CT0E5AD028R8P0C4a<09bLW04];B`0h
>3P092@T0P0Z:RX07@0];Bd0KVi^07MgM`0c<c<0HF5Q07alO00g=cL0CTi>07MgM`17AdL0RXZ:07mo
O`1IFET09BDU01XJ6P0j>SX0Kfm_0451@@0c<c<0ATI606YZJP1RHV80/[:b069RHP1kNg/0Vi^K08V9
R@1kNg/0JFUY00;ooooo0000ZP1[Jf/0C4a<06UYJ@1MGEd0BDU905eMG@0g=cL0HV9R08R8R00c<c<0
N7Qh09nOW`12@T80DE5A07MgM`1EEED0Cdm?05YJFP0l?3`0T92@04m?C`0f=SH0?clo030`<027QhL0
A4A4030`<01SHf<0@D5103`l?01DE5@0RXZ:05MGE`0V9RH0AdM7028R8P1EEED0IVIV03Ph>00f=SH0
OGem024Q8@13@d<0NWYj05]KF`0m?Cd0:RXZ059BDP0b<S80:2PX04i>CP0T92@0=3@d06=SH`0[:b/0
8R8R05EEE@1JFUX0>SXj01dM7@25QHD0FEUI02DU9@2XZ:P0J6QX034a<@0];Bd0KVi^055AD@0^;Rh0
Lg=c02LW9`0R8R80;bl_06UYJ@1:BTX0<c<c05iNGP0Q8B40820P06IVIP1PH600@41003hn?P0j>SX0
7alO04];B`1FEUH0J6QX0;2`/01_Kfl0:b/[04];B`1XJ6P0HF5Q02l_;`1RHV80MWIf028R8P0i>CT0
CTi>07alO015ADD0E5AD055AD@1^KVh0=3@d0861P@15ADD0A4A402d];@1dM7@0JVYZ03De=@1dM7@0
EeMG06MWI`1^KVh0De=C07MgM`1UIFD0>3Ph05]KF`1:BTX09bLW06QXJ01WIfL0DU9B06IVIP1RHV80
EEEE04M7A`1OGel0JFUY03dm?@0/;2`0AdM705UIF@1FEUH0JVYZ06e]K@0n?Sh0O7al05mOG`2BTY80
LG5a03Ti>@1RHV80Jf][05=CD`1oOgl0C4a<08V9R@2LW9`0FEUI055AD@2WYjL0OGem05EEE@1fMWH0
;Bd]07inOP2WYjL0K6a/034a<@0Z:RX0IfMW034a<@1nOWh0Lg=c0P0m?Cd0^`1jNWX0<S8b07QhN01P
H600>SXj069RHP26QXH0E5AD09BDU02ATI40=SHf0451@@2KVi/0LW9b03<c<`1BDU80M7Ad06QXJ010
@400OWin09:BTP0i>CT0Lg=c0<g=c@2WYjL0NWYj0<W9b@2^[Zh0QXJ606EUI@1gMgL0F5QH02PX:00h
>3P0LW9b06=SH`12@T80SHf=03Ph>019BDT0EUIF038b<P2:RXX0TI6A05EEE@2DU9@0YjNW04];B`1<
C4`0IfMW02h^;P0I6AT0D51@02@T901bLW80K6a/05MGE`1@D50071`L03De=@1FEUH0RHV9065QH@1B
DU80c/k>09nOW`2QXJ40H61P04I6AP2PX:00GUiN06QXJ01[Jf/0:b/[04a<C02ZZZX0E5AD03<c<`2;
Rh/0Z:RX06][J`0b<S80Ogmo06ATI01PH600>CTi04U9B@1^KVh0J6QX02d];@1CDe<0Vi^K05ADE01G
EeL0FUYJ04Y:BP1TI6@0FEUI03/k>`1dM7@0c<c<07IfMP1;Bd/0@T9205eMG@1/K6`0<C4a01dM7@23
Ph<0OWin0451@@1@D500K6a/05mOG`10@400;2`/04i>CP1TI6@0CTi>03`l?01RHV80R8R804U9B@0l
?3`0ATI603lo?`1XJ6P0P82006i^KP0U9BD0GEeM059BDP0m?Cd0TI6A0::RXP1CDe<0Kfm_09JFUP1?
Cdl0=3@d01XJ6P0S8b<0E5AD030`<00J6QX0ATI607YjNP0k>c/0M7Ad07IfMP1BDU80JVYZ0<C4a02l
_;`0[Jf]0<[:bP3<c<`0NWYj06IVIP1iNGT0F5QH02`/;00G5aL04a<C014A4@0>3Ph04A4A01`L700l
?3`0BTY:05mOG`2CTi<0PH61096AT@2NWYh0]kNg09VIV@1TI6@0@T9202`/;013@d<0@D5103/k>`14
A4@0>c/k02DU9@0N7Qh00P0M7Ad01@0/;2`0?clo02d];@0E5AD05QHF00805ADE01<05QHF04Q8B015
ADD0=SHf01PH600Z:RX0KFe]04e=C@0U9BD08b<S02HV9P0R8R809bLW03/k>`1lO7`0MgMg09VIV@0a
<C407AdM00@05ADE02<09BDU08B4Q02RXZ80CTi>02PX:00_;bl092@T01TI6@0H61P05aLG0451@@0G
5aL0GEeM0492@P1=CDd0SXj>0=CDe02j^[X0HF5Q07emO@0I6AT04a<C01DE5@0J6QX0:2PX03hn?P1V
IVH0JFUY06a/K02CTi<0WinO08j>SP1ZJVX0HV9R01/K6`0201DE5@1m01HF5P0E5AD061PH01TI6@0f
=SH0R8R802DU9@1UIFD0Cdm?04i>CP1oOgl0AdM703Ti>@0K6a/071`L03De=@14A4@0;bl_01hN7P1f
MWH0VYZJ0451@@1<C4`0GUiN069RHP1[Jf/0Y:BT0;Ng]`2BTY80OGem08F5Q@21PH40FEUI059BDP1H
F5P0[jn_0<;2`P1hN7P0KFe]0::RXP2WYjL0];Bd0:RXZ01/K6`0EUIF05=CD`1@D500Cdm?05aLG02_
[jl0/;2`0=OGe`2g]kL0>CTi01lO7`0S8b<09bLW02/[:`0e=CD0ADE506QXJ02`/;00a/K60<o?c`2c
/k<0a/K60=[JfP3:b/X0@41002<S8`0T92@0;Bd]03<c<`0k>c/0?clo05IFEP1lO7`0H61P09jNWP0X
:2P0@D5102l_;`0];Bd092@T02PX:00e=CD0?clo08^;R`2IVIT0Ph>30;2`/02;Rh/0GUiN051@D00V
9RH07QhN020P800L71`07AdM034a<@0W9bL0DE5A08J6QP2@T900Zj^[05MGE`1:BTX0Kfm_0<O7a`3=
cLd0`/;20<G5a@31`L40^[Zj0<c<c03Bd]80Xj>S0;fm_@2[Zj/0QhN7034a<@0E5AD04a<C01@D500E
5AD00P0H61P0;`0Z:RX0SXj>05QHF00U9BD0:BTY07AdM02<S8`0UIFE09BDU02i^KT0F5QH03<c<`0b
<S80Cdm?0<71`@3?cll0dM7A08B4Q01ADE40=cLg06YZJP34a<@0h>3P09FEU@21PH40^[Zj0:j^[P1/
K6`0>SXj02d];@0b<S80>3Ph04E5A@1eMGD0=3@d01/K6`0M7Ad071`L020P800V9RH0;bl_03`l?011
@D40:2PX075aL@24Q8@0:BTY00805ADE00H07AdM04Y:BP0g=cL07alO02d];@0i>CT205UIF@0J03<c
<`1DE5@0QhN704A4A01ZJVX0EUIF07YjNP1TI6@06ATI02LW9`1]KFd0>CTi01HF5P0Y:BT0Rh^;08j>
SP2<S8`0GUiN05MGE`2ATI40QXJ607emO@2BTY80Fe]K06YZJP1fMWH2ooooo`000;D0M7Ad07alO01e
MGD0I6AT04a<C023Ph<0<c<c04E5A@1^KVh0>CTi07emO@19BDT0;Bd]05QHF01QHF40B4Q804];B`0^
;Rh0:b/[07UiN@1;Bd/0A4A404E5A@0I6AT0Ogmo04=3@`0g=cL0FEUI03De=@0O7al09RHV071`L01J
FUX0<C4a06QXJ01;Bd/0ATI605]KF`0b<S80=cLg06i^KP0c<c<0@41006=SH`1RHV80?Shn03<c<`1:
BTX0=3@d02d];@1HF5P0:BTY02/[:`1OGel0EEEE03Ph>01ADE40De=C02l_;`0Y:BT0Rh^;04m?C`0X
:2P0YZJV04e=C@0_;bl0CTi>07inOP1HF5P0@d=309jNWP0^;Rh06ATI02@T902EUID0@d=303Ti>@24
Q8@0@41002HV9P1lO7`0CTi>03De=@0o?cl0BTY:03<c<`1HF5P0=SHf04Q8B022PX80IVIV03@d=01N
GUh0S8b<05ADE00k>c/0SHf=07inOP0a<C40?3`l05IFEP1/K6`0>3Ph05]KF`1/K6`0OGem03/k>`2:
RXX0BDU906ATI00Z:RX0KVi^05mOG`0];Bd0M7Ad03lo?`1NGUh0Lg=c05iNGP21PH40F5QH04i>CP1`
L700GEeM03De=@1jNWX0IVIV06=SH`1[Jf/0PX:206YZJP14A4@0?clo051@D01>CTh0>CTi055AD@1>
CTh0=cLg04];B`1IFET0AdM7061PH00Z:RX0Fe]K071`L017AdL0EEEE04M7A`12@T80NWYj05iNGP2k
^k/0Vi^K04A4A010@400R8R80861P@1FEUH0MgMg03/k>`1ZJVX0PH6106i^KP0i>CT0:2PX059BDP0N
7Qh0?3`l04i>CP1CDe<0DE5A08^;R`0f=SH0X:2P07QhN01[Jf/0>3Ph05EEE@0/;2`0Hf=S0080C4a<
09T0D51@0:JVYP1lO7`0A4A407emO@2NWYh0B4Q803lo?`2<S8`0WIfM059BDP1TI6@0^KVi08>3P`1T
I6@0c<c<0=[JfP2?Shl0J6QX061PH01TI6@08b<S06QXJ02;Rh/0A4A404Y:BP2BTY80@d=3069RHP14
A4@0;2`/07inOP1gMgL0ADE507MgM`2MWId0=CDe04e=C@1aLG40ATI601`L701HF5P07QhN055AD@1F
EUH0LG5a06UYJ@0f=SH0@d=306QXJ01/K6`0@41004M7A`3@d=00UIFE08b<S00^;Rh0=3@d06EUI@13
@d<0LG5a07emO@1@D500LG5a0:NWY`1VIVH0>CTi07=cL`2FUYH0Hf=S03dm?@2TY:@0SXj>08N7Q`1I
FET0EUIF08f=S@1EEED0:BTY08:2PP2CTi<0@d=30451@@1DE5@0B4Q809nOW`1gMgL0BDU908>3P`3K
fm/0H61P0451@@24Q8@0[Zj^06i^KP0l?3`09RHV08f=S@1mOGd0De=C08n?S`2h^;P0Rh^;079bLP16
ATH0Cdm?05]KF`0W9bL0;Bd]08N7Q`29RHT0DU9B055AD@1<C4`0>c/k04Q8B01NGUh0HV9R02LW9`1R
HV80JVYZ02h^;P1RHV80NWYj04m?C`2RXZ80SHf=04E5A@0f=SH0C4a<05]KF`1lO7`0FUYJ01lO7`1:
BTX0Ogmo05aLG016ATH0<c<c02PX:00Z:RX0Y:BT06ATI01UIFD0YJFU0:RXZ02f][H0SXj>0:f][@1k
Ng/0AdM702<S8`0G5aL00P0C4a<0B@0H61P06a/K01lO7`0K6a/07QhN07EeM@1EEED0CTi>08R8R02B
TY80/k>c09:BTP1KFe/0AdM7024Q8@0@41003Ph>018B4P0R8R80A4A403Hf=P0U9BD092@T038b<P1^
KVh0DU9B038b<P0G5aL061PH01DE5@0Z:RX0@d=306ATI00I6AT07alO02d];@1LG5`0JFUY05EEE@1?
Cdl0?Shn034a<@0U9BD071`L034a<@1dM7@0[:b/07MgM`1`L700=cLg01XJ6P0G5aL07alO051@D02Z
ZZX0R8R806IVIP1=CDd0>c/k03Lg=`0_;bl0<C4a0410@01gMgL0PH610:j^[P2`/;00/k>c0=OGe`3P
h>00^[Zj08R8R01GEeL00`0C4a<0300@41005ADE02@T9011@D40>c/k08b<S029RHT0?Shn03@d=011
@D40FUYJ02`/;0<05ADE04D05aLG01PH600J6QX0:RXZ061PH01FEUH0GEeM024Q8@0L71`0EUIF03/k
>`0];Bd05ADE01PH600I6AT07QhN03Hf=P0n?Sh0@T920=CDe02f][H0[Zj^0<30`02o_kl0^KVi0;no
_`2m_Kd0a<C40<K6aP3:b/X0T92@05ADE024Q8@0Vi^K06a/K01^KVh0U9BD07moO`2ZZZX0_Kfm09nO
W`1?Cdl0<c<c02XZ:P0W9bL092@T02TY:@0f=SH0Lg=c0<K6aP3=cLd0UiNG05YJFP0Z:RX07AdM024Q
8@0P8200@41007QhN01UIFD0QhN70<g=c@3IfMT0c/k>08R8R01TI6@0RXZ:030`<00J6QX00P0L71`0
<P0Q8B4071`L01lO7`0Y:BT0ATI60;Ng]`2k^k/0S8b<038b<P0k>c/09bLW02HV9P0S8b<071`L02DU
9@1jNWX0a<C40;Rh^03<c<`0Vi^K06i^KP1OGel0>c/k02TY:@0W9bL092@T02/[:`0S8b<07alO04E5
A@12@T80FUYJ09JFUP1KFe/0J6QX09BDU037alL0XZ:R06][J`2DU9@0SXj>09nOW`39bLT0hN7Q0=;B
dP31`L40`<30061PH00Y:BT04Q8B0P0C4a<0<P0E5AD05QHF01lO7`1`L700KVi^0:BTY01TI6@0:b/[
07EeM@2WYjL0Q8B409bLW02TY:@0B4Q80492@P0o?cl0=SHf096AT@3Jf]X0YZJV07inOP0Y:BT0:RXZ
03lo?`1QHF40d=3@0;:b/P2n_[h0J6QX059BDP1fMWH0;bl_02DU9@0`<300;bl_034a<@18B4P0IFEU
01XJ6P0M7Ad07QhN01lO7`0M7Ad0:b/[03`l?01lO7`0UiNG0<G5a@2l_;`0?Shn0`0E5AD07`0H61P0
BTY:034a<@0Q8B409BDU05YJFP1MGEd0:RXZ05QHF02LW9`0Jf][07emO@1cLg<0KVi^01HF5P0C4a<0
4Q8B028R8P1[Jf/0?clo03<c<`1ADE40VYZJ06e]K@19BDT0EEEE0:>SX`2RXZ80>c/k05QHF031`L40
0P2=SHd2ooooo`0008/0OWin071`L01bLW80BDU905aLG01nOWh0?Cdm055AD@2>SXh0>3Ph08>3P`2E
UID0?Cdm04m?C`1fMWH0H61P05EEE@1^KVh0?Cdm096AT@1@D500?3`l05UIF@0b<S80UIFE04a<C014
A4@0L71`06EUI@0Y:BT0=3@d06a/K00j>SX0=cLg06a/K017AdL0Cdm?0451@@0G5aL0D51@07QhN00]
;Bd0F5QH06ATI01;Bd/0A4A4059BDP1MGEd0=CDe03/k>`1ZJVX0@D5103Ph>019BDT0;2`/02@T901N
GUh0Bd];024Q8@0M7Ad0Hf=S03@d=00V9RH0XZ:R038b<P0J6QX08b<S04e=C@0d=3@0C4a<07MgM`10
@400=CDe03lo?`2HV9P0;bl_02d];@1kNg/0>c/k03Hf=P2ZZZX0E5AD02h^;P1;Bd/0C4a<04Q8B01S
Hf<0De=C05IFEP2LW9`0E5AD02TY:@1_Kfl0WIfM055AD@0Z:RX0FEUI06YZJP0e=CD0ADE506YZJP1P
H6009BDU03Ph>01ADE40PX:203Ph>02KVi/0NGUi06][J`0g=cL0PX:204e=C@0o?cl0V9RH065QH@1b
LW80EeMG05=CD`2OWil0DU9B03Lg=`1TI6@0EEEE03lo?`2?Shl0JFUY04];B`0i>CT0NWYj07moO`1@
D500E5AD05QHF00[:b/0AdM7069RHP1PH600DE5A0080GUiN04h0>c/k071`L01DE5@0Hf=S05UIF@14
A4@0NWYj05mOG`17AdL0KFe]04i>CP2DU9@0V9RH05]KF`1@D500TY:B05EEE@1YJFT0N7Qh05mOG`27
QhL0Ogmo07=cL`0h>3P0:BTY05QHF00/;2`0Bd];059BDP1EEED0HV9R08^;R`0Y:BT0Kfm_07EeM@1V
IVH0ADE5069RHP1?Cdl0Shn?051@D010@400FEUI0;:b/P1`L700@D5108N7Q`2IVIT0;2`/030`<01]
KFd0Shn?05UIF@1aLG40`/;207EeM@10@400Shn?0:ZZZP2RXZ80JFUY06MWI`1NGUh09bLW03lo?`25
QHD0KFe]02d];@1aLG40?3`l075aL@1HF5P0>CTi07EeM@1^KVh07AdM09jNWP33`l<204e=C@14065Q
H@0P82008b<S05eMG@0U9BD0J6QX059BDP1:BTX0@D5101hN7P1QHF40Ti>C08F5Q@0m?Cd0GUiN0=3@
d031`L40Ogmo05]KF`0n?Sh0IFEU02PX:01BDU80IVIV0410@022PX80^KVi07EeM@0o?cl0PX:209JF
UP0U9BD0?3`l07IfMP1cLg<0OGem05MGE`1MGEd0Ogmo04E5A@0Q8B40K6a/08R8R01CDe<0Cdm?03dm
?@0Z:RX0EeMG05mOG`1DE5@0N7Qh0=WIf@1FEUH0ADE504=3@`1DE5@0JVYZ030`<00W9bL0Ph>30410
@00c<c<0C4a<05mOG`1gMgL0De=C03hn?P1BDU8207emO@0O03dm?@1/K6`0SHf=06a/K01IFET0Cdm?
055AD@1JFUX0IfMW07]kN`0W9bL0KVi^06a/K00/;2`0MgMg08:2PP15ADD0U9BD07YjNP15ADD09BDU
01TI6@0S8b<0EeMG0410@011@D40T92@0:2PX017AdL0?Cdm02l_;`0202`/;00>0:JVYP1HF5P0DU9B
06i^KP1oOgl0VYZJ0:RXZ02c/k<0KVi^0410@017AdL09RHV010@400C4a<201DE5@0=01<C4`0>3Ph0
3Ph>05eMG@11@D40ATI606m_K`2QXJ40[jn_08f=S@1/K6`0@D5101/K6`0200h>3P0l010@400>3Ph0
410@02TY:@1ADE40@41003/k>`0n?Sh0KVi^08:2PP19BDT07AdM02<S8`1JFUX0HF5Q04a<C00H61P0
<c<c0451@@1UIFD0@D5103lo?`1CDe<0A4A4059BDP12@T80<C4a02<S8`1SHf<0WinO04i>CP1aLG40
SXj>08B4Q01kNg/0F5QH05ADE01LG5`0HF5Q07IfMP1QHF40O7al09VIV@2PX:00VYZJ09RHV02MWId0
NWYj06ATI01VIVH0Ogmo0=?Cd`3GemL0d=3@0<W9b@1oOgl06ATI01DE5@0C4a<0410@0P0C4a<04`0G
5aL0?clo04];B`1NGUh0ATI602PX:00c<c<0BDU9059BDP0O7al07AdM01hN7P0J6QX07AdM01PH600S
8b<0Kfm_07emO@1<C4`00P0I6AT0100i>CT0@D5102l_;`0F5QH201DE5@0<01HF5P0G5aL08R8R03/k
>`2n_[h0I6AT04E5A@0o?cl0=cLg03@d=01:BTX0S8b<0P2UYJD0:02m_Kd0fm_K0<W9b@25QHD0KVi^
08f=S@1ZJVX0W9bL0<S8b03<c<`0QXJ6079bLP1JFUX0@T9202d];@0W9bL09RHV02PX:017AdL0U9BD
0;Fe]@1IFET0T92@08R8R02RXZ80Jf][06IVIP27QhL0MGEe06YZJP1cLg<0AdM708J6QP2m_Kd0UIFE
02PX:00O7al0@41006i^KP0`<30201PH600b01XJ6P0K6a/0820P03@d=01eMGD0^KVi06EUI@1XJ6P0
OWin05=CD`0b<S80;Bd]02LW9`0Q8B40;2`/0820P02VYZH0/[:b0:VYZ@2IVIT0L71`06m_K`1=CDd0
@d=304A4A00o?cl092@T01TI6@0/;2`0ADE502d];@0/;2`0MgMg08V9R@1eMGD0^;Rh0:f][@25QHD0
BTY:06e]K@25QHD0T92@0:ZZZP2f][H0fMWI0=OGe`2GUiL0Hf=S024Q8@0M7Ad301DE5@0b01`L701d
M7@0H61P01LG5`0Y:BT0VYZJ06UYJ@1CDe<0NGUi06=SH`38b<P0LG5a01lO7`0H61P07QhN05EEE@2Y
ZJT0UiNG0<;2`P2BTY80JFUY04E5A@1:BTX0H61P0;bl_03Jf]X0PX:202`/;01CDe<0?3`l04i>CP0W
9bL0:RXZ03Ti>@0O7al0<30`0820P00a<C407AdM01`L700M7Ad0<c<c05QHF026QXH0Xj>S09:BTP2;
Rh/0QhN706IVIP0H61P301DE5@0K01dM7@1EEED0<30`02h^;P1<C4`0EeMG02`/;01lO7`0];Bd09jN
WP22PX80Vi^K024Q8@0@410051@D018B4P0E5AD06ATI0:f][@2i^KT0Jf][06i^KP2SXj<0FUYJ07=c
L`2ATI40aLG50080IFEU00<0FUYJ05IFEP1TI6@00_ooool0002106m_K`1/K6`0QXJ6061PH01<C4`0
MWIf03hn?P1EEED0IfMW0492@P2BTY80XZ:R0451@@1ADE40Ogmo05mOG`1_Kfl0Jf][03/k>`2=SHd0
Cdm?03hn?P1JFUX09bLW07=cL`0_;bl09RHV05mOG`1aLG40=3@d059BDP1YJFT0B4Q802HV9P1TI6@0
BDU905iNGP16ATH06a/K03De=@1XJ6P07alO06ATI01iNGT0:b/[03Ph>00j>SX0Fe]K02<S8`0T92@0
C4a<034a<@13@d<0KVi^03@d=00J6QX0G5aL05QHF00m?Cd0<c<c0861P@0O7al0?3`l0:2PX01IFET0
:BTY03dm?@1/K6`0DU9B05ADE01fMWH08R8R01HF5P1MGEd0O7al03/k>`0i>CT0TI6A01DE5@0[:b/0
GUiN04I6AP0^;Rh0@d=302l_;`0d=3@0E5AD04e=C@1WIfL0X:2P051@D00Q8B40SXj>092@T01DE5@0
=cLg06m_K`1gMgL09BDU05ADE026QXH0N7Qh030`<013@d<0FUYJ065QH@0T92@0K6a/04i>CP1HF5P0
=SHf09^KV`1[Jf/0<C4a07moO`1PH600Jf][06e]K@1IFET0UIFE065QH@0k>c/0KVi^04a<C00[:b/0
L71`06MWI`1BDU80DE5A0080MGEe02D0FUYJ05=CD`1ADE40DU9B02d];@0n?Sh0HF5Q05QHF01WIfL0
M7Ad0451@@1XJ6P0E5AD06ATI01HF5P0;Bd]0820P01TI6@0@d=304i>CP0k>c/0GEeM05iNGP1DE5@0
HV9R0:FUY@1CDe<0ADE506EUI@1TI6@0^k^k09:BTP10@400DU9B06=SH`1^KVh0;Bd]0080C4a<0;X0
<S8b06m_K`22PX80AdM708n?S`1`L700@T9205mOG`1[Jf/0B4Q808F5Q@1;Bd/05ADE03Lg=`2HV9P0
FUYJ0410@02XZ:P0W9bL05]KF`0h>3P0FEUI09JFUP1<C4`0MgMg0:n_[`1aLG40IVIV0;Fe]@2c/k<0
UiNG06][J`1WIfL0F5QH030`<00k>c/0N7Qh06m_K`0g=cL0LW9b02`/;013@d<0GEeM03lo?`1gMgL0
LW9b04Y:BP2m_Kd0];Bd04m?C`1WIfL0Kfm_01dM7@0I6AT0G5aL030`<01SHf<0DE5A05MGE`1?Cdl0
410@04];B`1`L700S8b<04e=C@1:BTX0]kNg07UiN@1gMgL09BDU051@D01dM7@0ADE505YJFP1KFe/0
:BTY051@D02UYJD0K6a/03dm?@1kNg/0UIFE05aLG00f=SH0PH61071`L026QXH0FUYJ05=CD`23Ph<0
LW9b04I6AP1bLW80SHf=055AD@1EEED0ATI604A4A01[Jf/0De=C04U9B@1LG5`0dM7A05=CD`1PH600
EEEE05QHF01iNGT0<C4a02/[:`1lO7`0B4Q804E5A@1QHF40GUiN079bLP0i>CT0@T9206a/K02HV9P0
QHF503/k>`26QXH0MGEe0451@@29RHT0Z:RX05UIF@1LG5`0GEeM06a/K00l?3`0UiNG06YZJP0b<S80
Ph>307emO@17AdL0Zj^[0:JVYP1EEED0>3Ph01dM7@0/;2`0DE5A024Q8@0P8200JFUY09ZJVP26QXH0
Hf=S04E5A@0e=CD0?Cdm09nOW`17AdL0IVIV0410@01eMGD0HF5Q05mOG`2DU9@0QHF502LW9`0K6a/0
820P00h>3P0=3@d04A4A018B4P0@41003@d=00h>3P1MGEd0=SHf02`/;01MGEd0Jf][09jNWP1IFET0
C4a<0410@00L71`05aLG00l?3`0@410200h>3P0C010@400I6AT0BDU905UIF@0m?Cd0BDU9069RHP2J
VYX0NGUi07AdM01kNg/0W9bL02DU9@0Q8B40?clo06][J`18B4P06a/K01LG5`0201DE5@0R01LG5`0Z
:RX0D51@051@D01IFET0/;2`0492@P17AdL0LW9b09fMW@1jNWX0AdM702/[:`0O7al07QhN02`/;01G
EeL0FEUI04A4A00n?Sh0;Bd]02h^;P1jNWX0Jf][0:BTY01VIVH0J6QX06YZJP2=SHd0alO70;>c/`2:
RXX09BDU01HF5PD05ADE00L07alO07AdM00h>3P0ZJVY09>CT`1`L700I6AT0080RXZ:00h0C4a<04Q8
B019BDT0EeMG05IFEP1_Kfl0Ogmo05MGE`1>CTh07AdM01XJ6P0S8b<0B4Q803Xj>P<05aLG03P05ADE
01LG5`0I6AT0CTi>05IFEP19BDT0FEUI04=3@`0N7Qh06a/K01`L700Z:RX0EUIF0;Bd]02YZJT0g=cL
09VIV@12@T80Fe]K04I6AP0U9BD0FUYJ0<?3``36a/H0YjNW04I6AP0i>CT0ADE505EEE@1<C4`0@d=3
0410@01UIFD0_[jn04U9B@0n?Sh0G5aL09fMW@2i^KT0f][J09bLW01QHF40DU9B05aLG01aLG40;bl_
07UiN@2_[jl0S8b<04Y:BP0O7al09BDU05IFEP1bLW808b<S01XJ6P8071`L05D0<S8b07]kN`1bLW80
>CTi059BDP11@D40Bd];069RHP23Ph<0Kfm_03lo?`0f=SH0EeMG0861P@2EUID0XJ6Q09bLW01PH600
ATI605UIF@0f=SH0;Rh^03Lg=`0k>c/0?Cdm04a<C01/K6`0?Shn02/[:`0i>CT0JFUY030`<01RHV80
];Bd05UIF@0Y:BT06ATI02d];@1EEED0GUiN07QhN02KVi/0Xj>S09fMW@2n_[h0P82003lo?`0K6a/0
6ATI01DE5@0I6AT0FEUI06MWI`0H61P05ADE01XJ6P0a<C40aLG509ZJVP2;Rh/0Xj>S0;no_`0];Bd0
5aLG02h^;P1YJFT0QHF503/k>`0K6a/0BDU909jNWP30`<00YZJV07moO`2^[Zh0f][J0=WIf@20P800
?3`l06EUI@0G5aL0>SXj05]KF`0`<300@T920080:b/[00h0MWIf07AdM00o?cl0HF5Q06QXJ01dM7@0
KFe]08Z:RP2JVYX0LG5a05QHF01EEED0TI6A03@d=0@05ADE00d06a/K071`L01<C4`0Bd];06UYJ@13
@d<0Xj>S0<G5a@2UYJD0[Jf]02HV9P0A4A4051@D0080410@00h05ADE01TI6@1mOGd0L71`069RHP0h
>3P0ATI60<k>cP2j^[X0/k>c0=CDe02e]KD0R8R809JFUP80Ti>C0_ooool0001906IVIP1=CDd0JFUY
04Y:BP1?Cdl0IfMW0410@01YJFT0Lg=c038b<P1XJ6P0GEeM03dm?@23Ph<0R8R8055AD@2GUiL0EeMG
05=CD`25QHD0?3`l04A4A013@d<0?3`l09fMW@17AdL0820P05QHF00o?cl0A4A406=SH`1mOGd0@D51
02PX:011@D409bLW06][J`1UIFD0;Bd]03Xj>P1jNWX071`L0410@01<C4`0;bl_02@T900O7al0AdM7
02DU9@0T92@0F5QH01lO7`0a<C40?3`l030`<00[:b/0EeMG04E5A@0U9BD0;2`/07UiN@1;Bd/08B4Q
09:BTP0b<S80;bl_05YJFP1^KVh0BDU905EEE@1bLW806a/K01HF5P0203lo?`2H01dM7@0h>3P0Q8B4
01TI6@0f=SH0IVIV02d];@0l?3`0MWIf0492@P11@D40I6AT04];B`1YJFT0W9bL04a<C00M7Ad0OGem
08:2PP0k>c/0<c<c07moO`1gMgL07QhN03@d=01@D500IVIV02h^;P16ATH0PH6107alO00f=SH0Ti>C
04m?C`0f=SH0?Shn0:^[Z`27QhL0=cLg07emO@1:BTX0JVYZ07]kN`1]KFd0X:2P061PH00n?Sh0IfMW
06a/K018B4P0UIFE06i^KP1MGEd0Jf][09JFUP1iNGT0C4a<06EUI@28R8P0HF5Q03De=@0o?cl0G5aL
02XZ:P1kNg/0YZJV055AD@2EUID0?Cdm09RHV01^KVh0@D510861P@1DE5@0D51@059BDP1SHf<0YJFU
0861P@0_;bl0F5QH0;>c/`1dM7@0DU9B07=cL`1fMWH0eMGE05]KF`1=CDd0=cLg03`l?019BDT08b<S
04a<C016ATH09BDU06MWI`1KFe/0<30`08N7Q`1VIVH0@D5104I6AP1OGel0@4100:6QX@1UIFD0ADE5
05YJFP2k^k/0@41004e=C@2MWId0^KVi069RHP0e=CD0>c/k07=cL`1;Bd/0FEUI09:BTP22PX80FUYJ
0;Fe]@2/[:`0SXj>06a/K01[Jf/0IVIV02l_;`14A4@0PX:207EeM@0d=3@0PX:203/k>`18B4P0P820
05IFEP1nOWh0N7Qh05=CD`35aLD0[jn_03`l?01iNGT0QHF505MGE`0S8b<0FEUI02XZ:P2FUYH209BD
U00a075aL@0Y:BT0HV9R06a/K01dM7@0@T9205QHF03@d=00TY:B055AD@0`<300?3`l059BDP14A4@0
De=C0451@@10@400IFEU0;jn_P1CDe<0?Cdm06e]K@2>SXh0Fe]K03lo?`29RHT0KVi^08J6QP1HF5P0
FUYJ08f=S@1LG5`0?3`l07AdM029RHT0DE5A05MGE`1@D500AdM706MWI`1RHV80De=C04];B`3;bl/0
Jf][06IVIP1HF5P0Hf=S0861P@0203Ph>01O09ZJVP1HF5P0BTY:06ATI01kNg/0JFUY04];B`1oOgl0
_;bl0::RXP1hN7P0=CDe0;Ng]`0o?cl05ADE05aLG01VIVH0Cdm?061PH01?Cdl06ATI04M7A`2^[Zh0
NGUi03<c<`1hN7P0H61P02LW9`34a<@0/[:b06][J`0h>3P08B4Q03<c<`1;Bd/0G5aL02HV9P16ATH0
RHV90:BTY036a/H0_[jn0:RXZ02`/;00ZJVY04e=C@1FEUH0:b/[071`L01oOgl0EEEE07IfMP1<C4`0
GEeM01@D500>3Ph03@d=00`<300A4A40410@00h>3P0=3@d03Ph>065QH@0a<C405aLG02XZ:P0a<C40
E5AD09BDU01TI6@0D51@03/k>`0I6AT04a<C00l?3`0>3Ph03@d=00h>3P0F5QH0;Rh^05aLG01@D500
GEeM06UYJ@1cLg<0alO70<K6aP3Bd]80_kno034a<@12@T80GemO07=cL`0];Bd00P0U9BD0900O7al0
6a/K02<S8`0K6a/06ATI04e=C@1eMGD0`l?305ADE01^KVh0UiNG08f=S@23Ph<0NGUi04U9B@0J6QX0
6ATI01hN7P0Q8B40CDe=079bLP27QhL0SXj>08f=S@1jNWX0KVi^096AT@2XZ:P0QhN707alO01DE5@0
GEeM09FEU@1cLg<0C4a<01TI6@805ADE0P0D51@0@00C4a<09BDU06ATI00g=cL0JVYZ03lo?`0e=CD0
?Cdm069RHP1^KVh0820P01dM7@0K6a/092@T02`/;010@400Lg=c05QHF014A4@0=3@d02h^;P14A4@0
B4Q803Xj>P0J6QX061PH01HF5P0I6AT06a/K04I6AP1FEUH0:RXZ02TY:@0`<300BDU904m?C`0j>SX0
:RXZ01dM7@0e=CD0`l?30<k>cP2l_;`0^;Rh06][J`1SHf<092@T0492@P29RHT0ZJVY07moO`1SHf<0
VIVI06=SH`0X:2P0?3`l05eMG@1ZJVX0VIVI0;2`/01>CTh09BDU02<S8`1`L7020<o?c`0Z0=CDe01G
EeL0?3`l03<c<`0l?3`0BDU908N7Q`1oOgl0ZJVY09:BTP28R8P0<c<c02@T900_;bl0De=C06ATI00T
92@06a/K03hn?P1fMWH0ADE502HV9P0L71`0<c<c05QHF00^;Rh0;Bd]03Lg=`1BDU80Rh^;0:>SX`2n
_[h0c<c<0=CDe02@T900DU9B03Hf=P1@D500G5aL03Xj>P0L71`08R8R0P0P82002@0Q8B40AdM704E5
A@0`<300@T9204Y:BP0f=SH0OGem09JFUP0201dM7@0@020P800M7Ad071`L03De=@0l?3`0DE5A0492
@P2LW9`0OWin0:>SX`2DU9@0;Bd]01dM7@0V9RH0EUIF08b<S0805aLG00d0?clo06IVIP2>SXh0RXZ:
0>3Ph03Fe]H0hN7Q0;fm_@0^;Rh0<C4a09nOW`1hN7P08R8R00805ADE03406ATI0492@P2GUiL0fm_K
0<W9b@2OWil0OGem09RHV02f][H0UYJF09^KV`0Y:BT071`L05IFEP21PH40FUYJ07AdM027QhL0^k^k
0;6a/@1mOGd0HV9R04e=C@1hN7P0Ph>30:>SX`1GEeL0A4A404i>CP0c<c<07QhN03/k>`0i>CT05aLG
01DE5@0M7Ad05aLG02HV9P2DU9@0LW9b0:RXZ023Ph<0Zj^[0;fm_@2n_[h0Ogmo04m?C`19BDT0A4A4
0080?clo0100@d=306QXJ02ZZZX0Fe]K024Q8@0K6a/09BDU0=7Ad@3:b/X0XJ6Q0;Jf]P3=cLd0DU9B
03Ti>@0/;2`0=SHf0_ooool0002U07EeM@1]KFd0O7al04U9B@1@D500O7al03Ti>@1;Bd/0KFe]03Ph
>02DU9@0CDe=02DU9@0o?cl0I6AT05MGE`29RHT0=CDe03Ti>@1^KVh0Bd];04A4A00W9bL0:RXZ07Yj
NP15ADD08B4Q051@D00e=CD0;Rh^04m?C`1XJ6P0A4A402HV9P1OGel0FEUI05eMG@1@D500;2`/03hn
?P29RHT0?Shn05MGE`1<C4`0B4Q802d];@0k>c/0Cdm?028R8P0V9RH0F5QH03Lg=`1TI6@0AdM702d]
;@0/;2`0F5QH06ATI00o?cl0;2`/08V9R@1IFET08R8R06=SH`1PH6007alO03@d=01eMGD0Cdm?05MG
E`1fMWH0=3@d02PX:014A4@0AdM7024Q8@14A4@0QHF503Lg=`13@d<0IFEU02l_;`0L71`0D51@04a<
C016ATH0GemO02<S8`1FEUH0UiNG05eMG@0T92@0RXZ:08:2PP12@T80<C4a08b<S028R8P09bLW03Xj
>P1EEED0C4a<02XZ:P1ADE40LG5a07UiN@0^;Rh0WYjN04U9B@0c<c<0=SHf08J6QP1]KFd0=3@d07Mg
M`0K6a/0M7Ad07QhN01_Kfl0V9RH02d];@1IFET0RHV907emO@1=CDd0YJFU04m?C`2<S8`0NGUi08^;
R`1]KFd0:BTY04a<C01VIVH0CTi>03Hf=P13@d<0Bd];02DU9@1FEUH0IFEU04M7A`24Q8@092@T05aL
G01YJFT0@T9208j>SP0U9BD0GemO07inOP1kNg/0WIfM09JFUP0S8b<0ADE509:BTP1VIVH0De=C06MW
I`15ADD0dM7A055AD@1HF5P0DU9B0080Bd];01X0:b/[05IFEP1@D500=cLg07emO@1EEED0<S8b08j>
SP1mOGd0IFEU05mOG`1LG5`0<S8b08J6QP20P800HF5Q079bLP2e]KD0G5aL04Q8B01_Kfl0O7al05AD
E00b<S80@T9206m_K`80?clo01l0J6QX096AT@1QHF40UiNG0:VYZ@2CTi<0RHV90;2`/02DU9@0?3`l
04E5A@27QhL0Lg=c03<c<`24Q8@0?Cdm059BDP27QhL0D51@07moO`2CTi<0KVi^0<S8b02PX:00<c<c
09NGU`2OWil0GEeM02HV9P0m?Cd06ATI0080De=C02X0Jf][07moO`16ATH0H61P069RHP1/K6`0D51@
05IFEP3;bl/0Vi^K06QXJ01>CTh0>3Ph06QXJ016ATH0DU9B04Y:BP10@400JVYZ0<?3``1>CTh0?clo
075aL@2=SHd0FEUI03dm?@2<S8`0JVYZ079bLP1EEED0Xj>S0:ZZZP1_Kfl0=cLg08N7Q`22PX80ADE5
08Z:RP1/K6`0@T9206MWI`1IFET203`l?01108n?S`1FEUH0MgMg065QH@1FEUH0ADE503`l?01_Kfl0
^[Zj08j>SP1EEED0HF5Q06i^KP0d=3@09RHV04=3@`1`L700VIVI065QH@0l?3`0b<S806=SH`0f=SH0
GEeM04m?C`1:BTX0IFEU05]KF`1PH600=SHf08Z:RP1bLW80=3@d06EUI@1gMgL0:BTY07alO02;Rh/0
BTY:03Ti>@0X:2P0;Rh^04E5A@1?Cdl0:BTY04e=C@2DU9@0Bd];059BDP1[Jf/0UIFE0;jn_P36a/H0
Cdm?04A4A00l?3`0:BTY03@d=01<C4`0DU9B03Xj>P1DE5@0Cdm?01DE5@0>3Ph00P0=3@d04P0>3Ph0
3@d=010@400P8200X:2P04=3@`0I6AT06QXJ020P800T92@0ADE506a/K01gMgL0LG5a03Hf=P0Z:RX0
:b/[01hN7P80:RXZ03`0?3`l05]KF`1SHf<0IVIV07=cL`2VYZH0`L710;^k^`35aLD0WIfM0;Fe]@2L
W9`0HF5Q096AT@2;Rh/0;2`/02<S8`0Q8B4092@T020P800Q8B40:2PX0451@@1jNWX0XZ:R0;Bd]02C
Ti<0OGem05ADE019BDT0=3@d04U9B@1mOGd0J6QX0492@P1?Cdl0>SXj03@d=01iNGT0a<C40:ZZZP1Y
JFT0DU9B06i^KP2/[:`0c<c<0<[:bP1UIFD05aLG01TI6@1/K6`0H61P069RHP0V9RH05QHF01@D500C
4a<04Q8B01DE5@0l?3`203lo?`0604A4A00Z:RX08R8R02TY:@0_;bl0=cLg0P0E5AD0400G5aL06ATI
01/K6`0X:2P0@d=305UIF@13@d<0DE5A028R8P0_;bl0OGem07=cL`0n?Sh0:b/[028R8P0Y:BT205UI
F@0303dm?@0X:2P08R8R008071`L01T08B4Q04];B`1_Kfl0NGUi07EeM@2<S8`0WinO0;Vi^@2^[Zh0
WinO04];B`1GEeL0VIVI05QHF00h>3P0:b/[03@d=015ADD0LW9b09fMW@2>SXh0Q8B40820P02j^[X0
YjNW0080:2PX02<0<c<c061PH02j^[X0d=3@0=WIf@2l_;`0[Zj^0;Bd]02ZZZX0`/;203/k>`0L71`0
P8200<G5a@33`l<0WIfM05IFEP14A4@0?Shn069RHP1OGel0B4Q806MWI`0g=cL06a/K01LG5`0J6QX0
6ATI0410@013@d<0;2`/02DU9@0Z:RX0BTY:09NGU`020;^k^`0d0;bl_025QHD0KVi^05iNGP1;Bd/0
8B4Q03Hf=P0n?Sh071`L01dM7@0K6a/071`L02`/;012@T80<S8b05EEE@0];Bd0HF5Q08n?S`14A4@0
5aLG01DE5@0J6QX09BDU02l_;`0R8R809RHV03Hf=P0G5aL0De=C0:2PX01OGel0TY:B0:j^[P1hN7P0
Shn?0=GEe@1gMgL0C4a<05UIF@22PX80YjNW0<g=c@3@d=00eMGE0=_Kf`3Bd]80^KVi09NGU`34a<@0
F5QH01XJ6P<05ADE01D0;2`/05IFEP1CDe<0VYZJ04U9B@0R8R809bLW03lo?`2=SHd0Ph>30410@01d
M7@0<S8b03Hf=P3<c<`0a<C409^KV`1jNWX0O7al0;bl_02NWYh00P2IVIT0:02WYjL0_[jn04i>CP0G
5aL07AdM02DU9@0];Bd05ADE01TI6@1IFET0AdM702l_;`0K6a/05ADE01XJ6P0l?3`0alO70=?Cd`2E
UID0NWYj0;^k^`2KVi/0=cLg038b<P0k>c/0@D5103`l?00f=SH0>SXj05mOG`2b/[80I6AT01dM7@0N
7Qh0?clo0;Ng]`1TI6@0;Rh^05MGE`2[Zj/2028R8P0302HV9P0[:b_ooooo007ooooo0000;01gMgL0
NGUi0820P019BDT0Hf=S092@T010@400GEeM0410@00U9BD0RHV9079bLP0b<S80@d=305ADE00k>c/0
Rh^;07QhN01PH600UIFE06EUI@1CDe<0B4Q804M7A`2BTY80De=C02/[:`19BDT0EEEE03hn?P1EEED0
Jf][04I6AP0W9bL0G5aL05ADE01VIVH0BTY:02<S8`1HF5P0YJFU051@D01RHV80Cdm?0P1>CTh0]@0o
?cl0E5AD03@d=01SHf<0RXZ:0492@P1KFe/0BDU9038b<P0Y:BT0RXZ:05eMG@0h>3P0<30`08f=S@10
@400:b/[06UYJ@1=CDd07alO03/k>`1]KFd0ATI605mOG`27QhL0?3`l030`<012@T80LG5a02l_;`0c
<c<0J6QX02XZ:P17AdL0EUIF02l_;`0^;Rh0H61P04=3@`14A4@0De=C03/k>`1eMGD0VYZJ05aLG00Z
:RX0SHf=08J6QP10@400CTi>0;bl_02SXj<0>SXj03lo?`1LG5`0A4A402/[:`14A4@0GemO06MWI`0[
:b/0VIVI04I6AP15ADD0@d=309FEU@1KFe/0=3@d05mOG`0W9bL0I6AT05YJFP1bLW80PX:201/K6`1C
De<0N7Qh06UYJ@13@d<0UIFE0492@P1ZJVX0EUIF08>3P`1UIFD0?Cdm04Q8B01HF5P0EeMG03Lg=`13
@d<0>CTi038b<P1]KFd0C4a<0451@@1cLg<0>CTi06i^KP1<C4`0>SXj08F5Q@0];Bd0>SXj07=cL`1[
Jf/0YZJV08R8R01;Bd/0Cdm?09FEU@1ZJVX0De=C061PH014A4@0QHF507YjNP1_Kfl0HV9R05UIF@1F
EUH0=CDe07QhN01gMgL0ATI60861P@1jNWX0BTY:0:n_[`22PX80HV9R06a/K01IFET06a/K079bLP1K
Fe/0DE5A07QhN02m_Kd0EEEE07=cL`28R8P0XJ6Q06IVIP0g=cL0?Shn055AD@0H61P0De=C0;Rh^02U
YJD0CTi>07moO`2^[Zh0SXj>05ADE02=SHd0Ng]k02d];@1;Bd/0P82006e]K@12@T80MWIf03Ph>019
BDT0QhN705YJFP2SXj<0V9RH06YZJP32`/80W9bL01TI6@1fMWH0SHf=04m?C`0/;2`0Fe]K03De=@1Q
HF400P17AdL0I01LG5`0?3`l06QXJ01ADE40G5aL01/K6`1IFET0aLG50<o?c`23Ph<0EeMG02l_;`1/
K6`0Cdm?06e]K@1SHf<0AdM706a/K036a/H0Cdm?04i>CP2XZ:P0[:b/069RHP0o?cl0S8b<06YZJP0M
7Ad0<30`07UiN@2_[jl0Lg=c03Ph>02;Rh/0N7Qh02/[:`1EEED0H61P03hn?P1SHf<0G5aL02LW9`0j
>SX0O7al071`L01_Kfl0G5aL05eMG@0];Bd06ATI03Ph>01iNGT0KFe]04i>CP1[Jf/0GUiN06=SH`0^
;Rh0BDU907emO@1_Kfl0B4Q807AdM038b<P0JFUY03Ti>@1RHV80EEEE04E5A@2CTi<0RXZ:07EeM@0l
?3`0ZZZZ06a/K00m?Cd0PX:209nOW`14A4@0V9RH08f=S@1FEUH0>CTi02DU9@0c<c<0CTi>05EEE@0[
:b/0F5QH08Z:RP1ADE40BDU903dm?@0o?cl0FUYJ0<c<c021PH40?Shn02@T900K6a/201DE5@0W01XJ
6P0X:2P0ADE505mOG`0f=SH0:2PX01DE5@0A4A4061PH034a<@1OGel0R8R80:VYZ@2_[jl0Fe]K030`
<00Y:BT08B4Q02LW9`1PH600VYZJ0:RXZ02;Rh/0FEUI08^;R`18B4P0BTY:051@D01EEED0EeMG07mo
O`29RHT0RXZ:08:2PP2:RXX0JVYZ08^;R`2XZ:P0QHF50080Zj^[00h0[Zj^08V9R@1RHV80=SHf02DU
9@0P82006a/K02LW9`1VIVH0Ogmo05ADE010@400Ogmo0492@P80M7Ad00L0D51@065QH@2ATI40/k>c
06YZJP1eMGD0O7al0080KVi^01h0Q8B405MGE`1IFET0GEeM071`L028R8P0/K6a0<W9b@2`/;00BDU9
02DU9@0E5AD0:BTY0820P01BDU80Hf=S01PH600C4a<05ADE01LG5`0[:b/0@D5102HV9P1OGel0=CDe
020P800S8b<08R8R034a<@0f=SH501DE5@0@01`L700j>SX0Bd];04i>CP1WIfL0ADE505QHF02PX:00
NGUi03`l?00h>3P0H61P07IfMP1KFe/0>CTi01XJ6P806ATI01005QHF01LG5`0J6QX08R8R04m?C`2U
YJD0LG5a06m_K`1EEED0Lg=c0:6QX@2ZZZX0a<C40;>c/`1YJFT0;Bd]0P0L71`08`0M7Ad07alO02TY
:@2l_;`0IfMW05EEE@1WIfL0Q8B409NGU`1?Cdl0EEEE05QHF02MWId0d=3@0:>SX`2l_;`0MGEe04m?
C`1JFUX0Q8B40:2PX01?Cdl08R8R0:n_[`2`/;00XZ:R0;2`/026QXH0RXZ:092@T02?Shl0/K6a0<C4
a012@T806ATI00<05aLG03`06QXJ020P8015ADD0DU9B0410@011@D40F5QH08n?S`2VYZH0_[jn0=WI
f@32`/80C4a<02XZ:P0P820071`L01hN7P0k>c/0A4A401hN7P0K6a/07AdM02<S8`12@T80?Cdm09NG
U`22PX80ZZZZ075aL@0M7Ad051@D014A4@0E5AD06a/K02@T900L71`08R8R02d];@0C4a<05aLG069R
HP1JFUX0QHF50<O7a`3?cll0UYJF061PH01_Kfl0QXJ607EeM@1SHf<0LG5a09RHV023Ph<0[jn_0:f]
[@2PX:00^KVi0<W9b@19BDT201DE5@805QHF02P08R8R03/k>`1SHf<0JFUY09>CT`0_;bl0>3Ph06EU
I@21PH40GemO0;^k^`1ZJVX0A4A4096AT@2YZJT0Zj^[08n?S`2^[Zh0Y:BT08j>SP2@T900XJ6Q0;no
_`39bLT0aLG50<O7a`0m?Cd05ADE01/K6`0P8200HV9R04E5A@13@d<0IVIV07UiN@1<C4`0GemO03Xj
>P0S8b<0;bl_0P3Hf=P06P3De=@0^;Rh0:n_[`1RHV80:b/[02l_;`0[:b/0;2`/02PX:00U9BD0?Cdm
05ADE02GUiL0EeMG01dM7@0P8200I6AT08j>SP15ADD07alO02`/;02n_[h0CDe=034a<@0g=cL0@410
0_ooool0002M0:6QX@1bLW80NGUi03/k>`1TI6@0O7al0492@P1RHV80=CDe02LW9`1`L700Lg=c038b
<P0l?3`0BTY:028R8P1[Jf/0H61P05ADE01eMGD0DE5A07AdM01ADE40EEEE09BDU01JFUX0ADE506EU
I@1[Jf/0=cLg059BDP1XJ6P0>CTi03Ph>01[Jf/0E5AD06ATI00o?cl0410@05]KF`2ATI40AdM705=C
D`19BDT0;2`/0410@00e=CD0@T9201XJ6P0W9bL0EeMG0410@01PH600?Cdm02HV9P0G5aL0F5QH051@
D00h>3P0=3@d08:2PP0E5AD0J6QX09ZJVP1BDU808R8R0410@012@T809BDU07inOP2HV9P0J6QX03Lg
=`10@400Ph>302`/;00f=SH0FEUI01/K6`1<C4`0FUYJ02@T900a<C40GEeM03dm?@1=CDd0CTi>0492
@P1^KVh0MGEe05=CD`0T92@0T92@07emO@0R8R8092@T069RHP1cLg<0;Bd]03hn?P1VIVH0JVYZ03Ti
>@1KFe/0KVi^06UYJ@0Z:RX0WinO05MGE`11@D40@T9208j>SP1XJ6P0>SXj06=SH`18B4P0FUYJ04U9
B@1cLg<0FUYJ03Ph>016ATH0KVi^069RHP0m?Cd0RHV906][J`1aLG40DU9B07]kN`1GEeL0?Cdm05AD
E01XJ6P0G5aL0492@P1ADE40>SXj04A4A02=SHd0D51@04e=C@2@T900BTY:0820P01PH600>c/k07=c
L`1_Kfl0DE5A07IfMP1gMgL0WYjN096AT@1BDU80EeMG0:FUY@02069RHP1>06][J`1jNWX0XJ6Q05]K
F`1MGEd0G5aL079bLP15ADD0<30`09^KV`2IVIT0?clo07inOP1KFe/0;Bd]0:JVYP2JVYX0EeMG07Mg
M`1DE5@0BTY:09ZJVP1KFe/0CTi>08N7Q`2n_[h0A4A40820P01mOGd0R8R805QHF00g=cL0FUYJ06a/
K00Y:BT0=cLg07MgM`1^KVh0@T9207inOP2m_Kd0UIFE08:2PP1jNWX0Fe]K01lO7`13@d<0LW9b03lo
?`2BTY80FUYJ03Hf=P19BDT0L71`02h^;P1XJ6P0TY:B04i>CP31`L40U9BD028R8P1OGel0JVYZ03/k
>`0d=3@0HF5Q03@d=027QhL0DU9B04i>CP1?Cdl08b<S06YZJP1=CDd0E5AD02DU9@18B4P0LW9b0P2?
Shl0@01RHV809RHV04U9B@0j>SX0^[Zj09nOW`15ADD0KVi^0;jn_P0^;Rh0>SXj08B4Q02QXJ40IVIV
03`l?02QXJ40OWin05aLG01<C4`0I6AT09fMW@1WIfL0=SHf09ZJVP2=SHd0CTi>059BDP1ADE40>3Ph
05]KF`1RHV808b<S02/[:`2;Rh/0TI6A06IVIP1XJ6P0Hf=S06i^KP0W9bL0;Rh^07IfMP1]KFd0CTi>
08N7Q`2RXZ80K6a/03hn?P1EEED0/;2`0451@@0k>c/0ZJVY08b<S01kNg/0=3@d05EEE@1>CTh0;Bd]
069RHP1^KVh0H61P03`l?02OWil203Ti>@1608b<S02MWId0ATI609fMW@2:RXX0<C4a04I6AP1KFe/0
QXJ607emO@0m?Cd0<30`05mOG`1gMgL0Cdm?04Q8B01=CDd0GEeM05UIF@3@d=00bLW906ATI00K6a/0
6ATI01DE5@0C4a<051@D01<C4`0J6QX0@T9208F5Q@1`L700NGUi07EeM@1_Kfl0HV9R03`l?00Y:BT0
9RHV03/k>`1mOGd0TI6A05IFEP0m?Cd0<C4a0410@02<S8`0^KVi0=[JfP3>c/h0bl_;08V9R@1eMGD0
IFEU06][J`1CDe<0>3Ph05EEE@0k>c/0FUYJ08R8R022PX80I6AT06IVIP2^[Zh0RXZ:07alO02@T900
?clo02d];@80AdM700@0@T92075aL@21PH40>3Ph0P0E5AD0;@16ATH0;bl_020P800L71`0R8R80=;B
dP37alL0TI6A06MWI`0f=SH0?Cdm0;:b/P21PH40Kfm_07inOP21PH40W9bL07]kN`1WIfL0F5QH051@
D02QXJ40MGEe08V9R@1=CDd06a/K01XJ6P14A4@0Jf][06i^KP0X:2P05ADE014A4@0/;2`0CTi>034a
<@0e=CD0[:b/03@d=00N7Qh071`L01dM7@0T92@0=cLg01HF5P0401DE5@0Q01HF5P0R8R80Xj>S0<;2
`P2m_Kd0^k^k0<W9b@3GemL0_Kfm07alO022PX80TI6A06m_K`1YJFT0ADE503Hf=P0T92@06ATI01PH
600F5QH05ADE01`L700m?Cd0JFUY09nOW`2IVIT0DU9B04=3@`1:BTX0Rh^;0<c<c02UYJD0@4100080
6a/K09D071`L01dM7@0L71`08B4Q08R8R00a<C40>c/k08>3P`20P800Ph>3075aL@1=CDd0QHF50:^[
Z`2WYjL0aLG50;^k^`13@d<0;Bd]02LW9`0h>3P0<S8b06i^KP2WYjL0NGUi04M7A`19BDT0N7Qh02d]
;@0T92@0<C4a04U9B@1iNGT0YjNW03`l?00E5AD06ATI01LG5`0F5QH06QXJ01`L700^;Rh0Cdm?05IF
EP1KFe/0ZZZZ0<S8b03?cll0/[:b09bLW02OWil0=3@d02HV9P0Q8B4071`L01dM7@0T92@0>c/k04Q8
B00U9BD0<c<c059BDP28R8P0]KFe0=SHf03QhN40a/K608b<S00K6a/05ADE01@D500E5AD06a/K03<c
<`0N7Qh0<C4a02h^;P0A4A405ADE01XJ6P2DU9@0UiNG0;:b/P2<S8`0@d=3069RHP1PH600JVYZ07Qh
N02SXj<0c/k>0=3@d02TY:@0PH610:RXZ01<C4`0MWIf09RHV00G5aL05ADE01<C4`0E5AD06ATI02HV
9P1>CTh0NWYj08:2PP2LW9`0Cdm?05aLG00n?Sh08R8R02LW9`18B4P0bLW908j>SP2e]KD0a<C408j>
SP0Z:RX0Z:RX0<W9b@2c/k<0][Jf09nOW`1aLG40@4100451@@13@d<0QhN703<c<`0S8b<0B4Q803/k
>`0L71`09RHV03`l?01gMgL0GUiN03/k>`24Q8@0MgMg09bLW02b/[80fMWI0=kNgP3Bd]80Y:BT04=3
@`0201XJ6P0D01lO7`0R8R806QXJ01/K6`0P8200;Bd]06ATI01MGEd0;Bd]02/[:`2NWYh0KFe]034a
<@0Z:RX0Cdm?0::RXP1;Bd/0ADE505=CD`1VIVH2ooooo`000?h0MWIf06IVIP1gMgL0>c/k05UIF@1e
MGD0@410065QH@1kNg/0ATI6092@T02>SXh0<c<c03Ti>@1fMWH0H61P06e]K@1IFET0@D5103De=@0R
8R80Lg=c04Y:BP1=CDd0NWYj02h^;P1eMGD0RXZ:07UiN@0i>CT0DE5A06EUI@0N7Qh0=CDe06UYJ@1I
FET0IVIV04Y:BP0B4Q80AdM708^;R`0`<300DE5A04Q8B00f=SH0B4Q8034a<@0d=3@09bLW03hn?P1i
NGT0>3Ph055AD@0e=CD05ADE01lO7`1NGUh0?Shn020P800b<S80PH6103Xj>P0_;bl0IVIV055AD@0S
8b<0D51@04A4A00I6AT0FEUI07EeM@0l?3`09BDU04i>CP2<S8`07AdM03Ti>@1?Cdl06ATI051@D01P
H6008B4Q03Lg=`1MGEd0>3Ph05MGE`1CDe<0AdM709nOW`1oOgl0BDU902LW9`2<S8`0JVYZ04U9B@0d
=3@0VIVI08R8R00S8b<0@T9206i^KP1XJ6P0@41005mOG`1cLg<0DU9B03@d=02:RXX0MgMg04e=C@0n
?Sh0WYjN05=CD`1IFET0V9RH04a<C01MGEd0D51@07emO@1BDU80=3@d051@D01eMGD0MgMg0410@029
RHT0Lg=c07]kN`1NGUh0XJ6Q07alO01:BTX0E5AD075aL@0k>c/0?clo05eMG@1RHV80DE5A07UiN@1:
BTX0EeMG09fMW@1?Cdl0QhN705YJFP1=CDd0VYZJ07alO01YJFT0FEUI06][J`2f][H0UIFE04e=C@1I
FET0XJ6Q030`<01hN7P0JFUY09JFUP2ZZZX0@41004];B`2CTi<0UiNG0410@00P8200EUIF051@D00_
;bl0M7Ad04i>CP0i>CT0TY:B07QhN01MGEd0P82004a<C019BDT0S8b<051@D012@T80W9bL0<_;b`1@
D500R8R808N7Q`1eMGD0:b/[0410@01eMGD0QhN703Lg=`1RHV80R8R80492@P0S8b<0Ti>C0;fm_@2C
Ti<0U9BD08R8R01EEED07alO04I6AP2FUYH0A4A40410@01FEUH0<c<c06][J`1]KFd0=CDe08F5Q@1e
MGD0BDU90<K6aP2CTi<0:b/[06e]K@1PH600@D5103`l?01aLG40>c/k07emO@1BDU80Cdm?05ADE00S
8b<0IfMW04];B`1MGEd0C4a<08^;R`26QXH0Rh^;07UiN@18B4P0>c/k03hn?P0_;bl0Ti>C06][J`0i
>CT0R8R80<G5a@1:BTX0AdM706i^KP1nOWh0<C4a04A4A080LG5a00X0Lg=c06UYJ@1JFUX0RHV903<c
<`0Y:BT0Xj>S08F5Q@19BDT0C4a<0P16ATH0@02BTY80Ng]k059BDP0Y:BT0UYJF08Z:RP29RHT0Y:BT
0:6QX@1jNWX0;2`/02d];@1]KFd0;2`/04I6AP1ADE40Lg=c08^;R`1FEUH0KVi^0;Zj^P26QXH0Lg=c
0;:b/P1YJFT0Ogmo03dm?@1KFe/0GUiN03`l?01NGUh0KVi^06YZJP12@T80UYJF06ATI00`<300OWin
092@T01<C4`0[jn_08J6QP0];Bd09RHV030`<00m?Cd0HV9R03lo?`0`<300HV9R09RHV01@D500GEeM
06][J`1SHf<0SHf=0<G5a@3EeMD0Vi^K02`/;00I6AT05ADE01HF5P0E5AD201<C4`0B01TI6@2MWId0
Zj^[06i^KP1GEeL0E5AD03/k>`0N7Qh06QXJ01/K6`0L71`08b<S04=3@`1hN7P0Q8B40861P@2HV9P0
L71`0P3Cdm<0B@3Fe]H0UYJF03lo?`0S8b<06QXJ01LG5`0Y:BT0IVIV04E5A@0L71`05aLG01`L701P
H600^KVi07inOP2KVi/0/k>c07EeM@1EEED0Ogmo04a<C014A4@0O7al08j>SP1:BTX071`L01DE5@0G
5aL0?clo04=3@`0W9bL071`L02TY:@11@D40XJ6Q06EUI@1VIVH0@d=305EEE@1oOgl0dM7A0<O7a`2?
Shl0Hf=S03Hf=P0S8b<071`L01TI6@0J6QX06ATI075aL@2k^k/0MgMg08>3P`15ADD09bLW02HV9P1_
Kfl0GemO08n?S`1YJFT0GUiN07=cL`1oOgl0V9RH0<?3``3Bd]80VYZJ03hn?P0_;bl0;2`/02/[:`18
B4P01@0E5AD08`0H61P0;Bd]06YZJP1lO7`0[:b/0;:b/P2k^k/0RXZ:07YjNP2d];@0b/[:09>CT`2=
SHd0J6QX04U9B@0o?cl0@D5104A4A00k>c/09BDU01dM7@0b<S80DU9B08B4Q01BDU80>CTi028R8P0V
9RH0:2PX04=3@`2n_[h0LW9b02`/;00`<3007AdM008071`L02@07AdM01lO7`1CDe<0@T9203@d=019
BDT0@d=307EeM@1iNGT0QhN708J6QP1ZJVX0U9BD0:FUY@1nOWh0Ogmo06EUI@12@T809BDU01dM7@0f
=SH0QXJ604e=C@0];Bd0Bd];07MgM`0d=3@08B4Q01dM7@0];Bd0BDU906QXJ01VIVH0:BTY01TI6@0G
5aL201/K6`0C01lO7`1?Cdl0Bd];02HV9P1?Cdl0N7Qh0:RXZ02f][H0Q8B4069RHP2TY:@0=CDe02LW
9`0S8b<08B4Q01hN7P0O7al07AdM038b<P020:6QX@0808R8R02QXJ40^;Rh0<71`@39bLT0clo?09RH
V01ADE4301DE5@0L01lO7`0N7Qh07QhN02d];@0U9BD04A4A01DE5@0G5aL0JVYZ06IVIP2^[Zh0Shn?
08N7Q`2@T900Ph>308R8R023Ph<0QhN70:BTY03GemL0N7Qh07emO@0Y:BT0B4Q808>3P`2:RXX07alO
01TI6@805ADE04D06ATI02d];@1VIVH0T92@07YjNP2c/k<0BDU902LW9`0Q8B407AdM02@T900];Bd0
Ng]k0=KFeP37alL0[jn_08:2PP1IFET0PH61061PH00i>CT07QhN03Lg=`1HF5P0CDe=03@d=00e=CD0
?Cdm08>3P`1BDU80FEUI01LG5`0E5AD071`L028R8P1gMgL0`/;20:BTY02=SHd0Z:RX0:j^[P2l_;`0
`<300=_Kf`3Cdm<0c/k>05]KF`0J6QX06a/K01PH600I6AT06QXJ01LG5`0N7Qh0:BTY07YjNP29RHT0
M7Ad0:NWY`3Bd]80G5aL038b<P1EEED0/K6a04i>CP0G5aL05ADE01LG5`0M7Ad00_ooool0003o07Yj
NP1^KVh0RHV904Q8B01WIfL0Ng]k03dm?@1YJFT0OWin04M7A`2@T900QHF503De=@14A4@0PX:2065Q
H@1]KFd0HF5Q04m?C`21PH40@410055AD@13@d<0:b/[07YjNP0h>3P0>CTi05YJFP1=CDd0;bl_04A4
A01?Cdl0=SHf02XZ:P1KFe/0CTi>06=SH`1=CDd08R8R04m?C`2IVIT0>SXj04m?C`1RHV80ATI604Q8
B00X:2P0>c/k038b<P19BDT0J6QX02h^;P15ADD0=SHf01`L700_;bl0IfMW055AD@0f=SH0<S8b08b<
S00h>3P0<c<c06][J`16ATH08b<S05MGE`1WIfL07alO04];B`1[Jf/0ADE502l_;`1ADE40QXJ602d]
;@0k>c/0EeMG01dM7@1YJFT0PX:203/k>`0d=3@0GEeM02h^;P1RHV80J6QX04U9B@2@T900MgMg05AD
E00Z:RX0QHF5071`L018B4P0?Cdm09JFUP1fMWH092@T05MGE`1oOgl0IFEU03`l?01LG5`0LG5a06YZ
JP0];Bd0WIfM065QH@1JFUX0=cLg08b<S01aLG40>SXj07]kN`0l?3`0H61P04=3@`1iNGT0Lg=c0410
@01BDU80P82005ADE018B4P0Xj>S07IfMP24Q8@0@d=308J6QP22PX80Cdm?04i>CP1jNWX0IFEU03lo
?`1KFe/0GemO0410@01/K6`0LG5a04e=C@1kNg/0ADE5065QH@0W9bL0A4A407alO01UIFD0GUiN04M7
A`0m?Cd0MWIf07inOP10@400EUIF0:>SX`1=CDd0M7Ad069RHP2QXJ40V9RH04=3@`19BDT0E5AD05iN
GP1;Bd/0=CDe06QXJ011@D407alO07MgM`1KFe/0CTi>0:FUY@1FEUH0CTi>0:2PX01ZJVX0BTY:08J6
QP1CDe<0A4A40:VYZ@2j^[X0EEEE08^;R`2=SHd0UYJF05eMG@0/;2`0G5aL08n?S`10@400IfMW09:B
TP1gMgL0<c<c06][J`2g]kL0S8b<09RHV02d];@0Lg=c03Ph>01oOgl0YjNW06QXJ00h>3P0Cdm?030`
<01YJFT0Hf=S04i>CP2NWYh0I6AT02l_;`2c/k<0Ph>302DU9@1LG5`0@D5103Xj>P25QHD0P8200410
@01^KVh0DE5A04Y:BP1HF5P0;Rh^0861P@2MWId0P82005eMG@2EUID0WinO09:BTP1PH6006QXJ05QH
F01UIFD0CTi>0;>c/`1;Bd/09bLW06EUI@2/[:`0?clo055AD@1cLg<0MgMg05ADE010@400MWIf001;
06a/K01kNg/0KVi^05=CD`2?Shl0L71`01/K6`2<S8`0TY:B04Y:BP1=CDd0E5AD03Ph>019BDT0Hf=S
05YJFP0b<S80S8b<05EEE@1JFUX0PH6107MgM`1fMWH0;Rh^03Xj>P1nOWh0LW9b055AD@1BDU80JFUY
08V9R@1<C4`0Shn?0<71`@29RHT0GemO0;Zj^P1GEeL0IfMW04E5A@2NWYh0Rh^;0410@01TI6@0GUiN
05QHF01@D500_Kfm06a/K00h>3P0TY:B07YjNP1:BTX0bl_;0::RXP1OGel0BTY:02PX:00i>CT0IFEU
05eMG@0i>CT0N7Qh09nOW`2g]kL0N7Qh09FEU@2@T900GUiN03Ti>@1_Kfl0aLG506ATI00U9BD0:BTY
00805ADE00D04a<C01@D500j>SX0IfMW03<c<`02024Q8@0m03De=@1<C4`0CTi>0410@00W9bL071`L
01/K6`0O7al0:RXZ05ADE02BTY80X:2P0<C4a02o_kl0][Jf0;Ng]`1>CTh0>c/k03Lg=`0e=CD0<S8b
02PX:00Z:RX0De=C05IFEP0R8R805ADE03hn?P2IVIT0Rh^;04E5A@1>CTh0Ng]k09VIV@2c/k<0_[jn
0=KFeP2DU9@0;Bd]03`l?00j>SX0>CTi05mOG`1aLG40@d=302h^;P0U9BD0>CTi04E5A@1lO7`0IVIV
065QH@0K6a/06ATI01`L702=SHd0BDU901`L700J6QX05QHF01PH600201XJ6P1V01`L700N7Qh0HF5Q
0820P02^[Zh0ATI606MWI`17AdL0ADE504I6AP2[Zj/0];Bd08N7Q`1KFe/0F5QH06YZJP1MGEd0EeMG
06e]K@30`<00[jn_096AT@1]KFd0J6QX06UYJ@0W9bL05aLG01DE5@0F5QH05aLG01hN7P0_;bl0BDU9
05IFEP2;Rh/0EUIF03Lg=`1@D500FUYJ07EeM@2m_Kd0HF5Q038b<P0c<c<0@d=306=SH`1RHV80Kfm_
05EEE@1XJ6P0Ogmo09JFUP2SXj<0AdM705IFEP0/;2`0820P01`L700M7Ad0@d=30<;2`P1LG5`07QhN
03<c<`0Y:BT07AdM01/K6`0L71`07AdM03@d=01XJ6P0Bd];03@d=00W9bL0HF5Q04I6AP1KFe/0Bd];
04i>CP1cLg<0;bl_061PH01JFUX0Lg=c08^;R`0];Bd07QhN02LW9`1>CTh0De=C02<S8`0k>c/0GemO
038b<P0V9RH0;bl_034a<@1JFUX0?clo05MGE`1OGel0;Bd]0P0Y:BT0:`0^;Rh0=CDe05UIF@0i>CT0
EEEE07alO01BDU80[jn_09NGU`1YJFT0?clo096AT@25QHD0<c<c024Q8@0P82007alO024Q8@0`<300
De=C0<[:bP2QXJ40Ng]k0:^[Z`3:b/X0f=SH0861P@20P800Fe]K071`L017AdL051@D01DE5@0J6QX0
6ATI01dM7@0U9BD09bLW014A4@0C4a<0:BTY061PH01JFUX00P2g]kL06`1bLW80Cdm?05aLG01JFUX0
NWYj04m?C`1XJ6P0[jn_0:f][@0^;Rh071`L02DU9@2OWil0ZJVY034a<@0h>3P0G5aL03`l?00h>3P0
@D5105IFEP1`L700UYJF0=KFeP0j>SX09BDU028R8P0302DU9@0804m?C`3EeMD0L71`09ZJVP2NWYh0
`l?309bLW01hN7P301DE5@0I01LG5`0`<300Fe]K03Xj>P0b<S80JFUY09FEU@23Ph<0:2PX03Ph>013
@d<0?clo07YjNP34a<@0dm?C0<c<c01mOGd0VIVI0<O7a`2m_Kd0b/[:0=WIf@3Kfm/0Rh^;02l_;`02
01`L700C02d];@11@D40GemO07IfMP2;Rh/0Zj^[0;^k^`36a/H0f][J0=KFeP2OWil0Jf][06m_K`2a
/K40Cdm?01/K6`0G5aL04a<C01LG5`02ooooo`0003H0LW9b06=SH`2e]KD0A4A406EUI@1dM7@0B4Q8
08J6QP1hN7P0ADE508V9R@24Q8@0=cLg05ADE02EUID0Fe]K06YZJP1MGEd0FUYJ08Z:RP1ADE40E5AD
04e=C@0_;bl0VIVI04m?C`18B4P0J6QX05UIF@15ADD0KFe]07QhN010@400<C4a04=3@`0V9RH0JVYZ
06UYJ@0N7Qh0G5aL09JFUP0S8b<0B4Q8065QH@0_;bl0=3@d02XZ:P1FEUH0;bl_04A4A01/K6`09BDU
04a<C01FEUH203/k>`0N05mOG`0b<S806ATI0492@P1nOWh0:b/[03Lg=`1bLW809BDU03/k>`1eMGD0
GUiN01PH601=CDd0HF5Q04Q8B00U9BD0MGEe08J6QP0n?Sh0<S8b05=CD`0H61P0L71`061PH00Z:RX0
<30`05QHF00c<c<0?Shn0P19BDT0<@2ATI40Ogmo03`l?01;Bd/0Vi^K08n?S`1DE5@0>c/k09^KV`1L
G5`071`L0451@@21PH40H61P03/k>`1/K6`0Ng]k07emO@0d=3@0ZZZZ06=SH`0e=CD0>CTi092@T01o
Ogl0BDU907EeM@0l?3`0Q8B406MWI`2=SHd0MgMg0451@@1bLW80Q8B405EEE@0i>CT0O7al061PH02M
WId0F5QH09:BTP1cLg<0@d=306m_K`22PX80F5QH04I6AP1TI6@00P0j>SX0f`1/K6`0EeMG05]KF`1_
Kfl0D51@06m_K`0m?Cd0DU9B06i^KP15ADD0Lg=c07]kN`1^KVh0SHf=08J6QP0a<C40JFUY0;Bd]01J
FUX0OGem05MGE`2?Shl0SXj>059BDP1@D500JVYZ06e]K@1<C4`0@D5107moO`1bLW80=cLg075aL@1K
Fe/0Bd];0;6a/@1]KFd0CDe=08V9R@1VIVH0DU9B0:f][@1XJ6P0BTY:0:JVYP2][Jd0>3Ph096AT@2c
/k<0U9BD059BDP0c<c<0J6QX05EEE@0e=CD0JFUY0::RXP1YJFT0=CDe08J6QP3:b/X0HF5Q06a/K02<
S8`0DU9B01hN7P14A4@0I6AT03Lg=`1SHf<0F5QH03<c<`1cLg<0@41004E5A@2JVYX0I6AT03`l?02O
Wil0N7Qh02`/;01iNGT0EUIF02TY:@17AdL0ATI603<c<`2?Shl0PH6107YjNP1LG5`06QXJ05YJFP1C
De<0CDe=059BDP2IVIT0`/;20:f][@1ZJVX0?3`l04I6AP1PH600DU9B0<C4a01/K6`0?3`l06e]K@2W
YjL0@410069RHP2][Jd0WIfM05MGE`14A4@0U9BD07inOP1DE5@0I6AT09nOW`2DU9@0L71`02@T902D
U9@0R8R804e=C@1lO7`0Kfm_04I6AP1KFe/0F5QH03lo?`19BDT0Rh^;06ATI01iNGT0[Jf]09^KV`1?
Cdl0@T9206a/K01mOGd0Jf][051@D01cLg<0Rh^;075aL@19BDT0/[:b0<?3``1hN7P0EUIF0<30`020
P800C4a<02@T901JFUX0G5aL04A4A02BTY80Q8B405eMG@0h>3P0RXZ:06EUI@1@D500[jn_07=cL`0h
>3P0Shn?09^KV`1]KFd0AdM705EEE@2XZ:P0[Jf]03dm?@0Y:BT0Jf][07MgM`2_[jl0_;bl07EeM@0n
?Sh0;Rh^02XZ:P0R8R80JFUY0:2PX016ATH07QhN01TI6@0G5aL051@D01PH601RHV80>CTi01DE5@0I
6AT06a/K01dM7@0I6AT07alO038b<P1VIVH0Hf=S04i>CP1dM7@0RXZ:0:NWY`33`l<0b<S80=WIf@3G
emL0b/[:06e]K@0T92@05aLG01XJ6P0301DE5@805aLG00H0;Rh^06ATI01VIVH0HF5Q09FEU@0U9BD2
01/K6`0601dM7@1;Bd/0d=3@0<30`03?cll0<C4a0P0E5AD06@0H61P08R8R08N7Q`1[Jf/0F5QH05EE
E@1aLG40?3`l05aLG01fMWH0GEeM04=3@`0I6AT05ADE01XJ6P1_Kfl08R8R01LG5`0H61P05ADE01LG
5`0L71`07alO02TY:@0b<S800P2LW9`0=02IVIT0De=C02TY:@1LG5`0Hf=S06YZJP2i^KT0YZJV08V9
R@2^[Zh0UYJF07EeM@1KFe/0IfMW07inOP2RXZ80Y:BT08V9R@24Q8@0KFe]04U9B@1CDe<0KVi^03Hf
=P0Y:BT0;bl_04E5A@0i>CT0GUiN079bLP1NGUh0<S8b01`L700K6a/07QhN0410@02BTY80=cLg024Q
8@0O7al07AdM01`L700O7al0;Rh^05aLG02FUYH0c/k>0=KFeP1aLG40F5QH051@D00N7Qh201`L7008
01dM7@1`L700a<C404U9B@0L71`07AdM03@d=00];Bd201`L700?01dM7@0l?3`0LW9b03dm?@0/;2`0
9BDU069RHP1>CTh0AdM7030`<01LG5`0=CDe01TI6@0U9BD0@D510080>c/k04@07alO01dM7@0];Bd0
?3`l05iNGP0d=3@0=CDe04A4A00a<C40:b/[03Xj>P1FEUH0RXZ:0861P@13@d<0QhN708>3P`1OGel0
BTY:04A4A00e=CD0;bl_0451@@0h>3P0@T9204A4A02IVIT0W9bL08f=S@1ADE40MgMg038b<P26QXH0
DE5A03@d=00k>c/0FEUI07MgM`2FUYH0/;2`07UiN@2KVi/0`<300<o?c`2_[jl0IFEU03`l?01`L700
ADE505iNGP18B4P07QhN02/[:`0R8R807QhN02h^;P0];Bd03Ph>01XJ6P1EEED0JVYZ06ATI01[Jf/0
?clo03Lg=`0a<C40<c<c03De=@80;bl_0340:b/[03`l?022PX80<30`01hN7P0Y:BT0_[jn0=kNgP38
b<P0^KVi0<O7a`33`l<0[jn_0;Bd]036a/H0clo?0=GEe@3Hf=P0QXJ602d];@0U9BD0820P02<S8`0O
7al0A4A40=;BdP1UIFD0MWIf0:^[Z`2n_[h0W9bL061PH00E5AD051@D01TI6@0E5AD05QHF030`<029
RHT0Lg=c09jNWP1/K6`0RHV9071`L00S8b<0:2PX055AD@2RXZ80c/k>0080fMWI00@0Z:RX0;2`/03>
c/h0b/[:0P3Cdm<0603>c/h0TI6A04];B`2?Shl0WYjN0;>c/`2g]kL0ZJVY0:6QX@2][Jd0/K6a0:j^
[P2ATI40Jf][09:BTP30`<00SXj>03Xj>P1cLg<0SHf=03`l?00S8b<05ADE01HF5P;ooooo0000o`22
PX80E5AD07emO@18B4P0LW9b05=CD`12@T80Ng]k065QH@0o?cl0PX:204Y:BP0k>c/0J6QX08>3P`0o
?cl0EEEE02LW9`1>CTh0MGEe04U9B@1BDU808R8R03Hf=P25QHD0BTY:05QHF021PH40@41002LW9`14
A4@0FUYJ02@T900h>3P0GEeM04=3@`1@D500@T9201DE5@1jNWX0UiNG04E5A@14A4@0=CDe01TI6@1;
Bd/09BDU03Hf=P0U9BD0CDe=07EeM@16ATH0?Cdm03<c<`0J6QX0<30`07YjNP15ADD09RHV0492@P1[
Jf/0:2PX05aLG029RHT07QhN02DU9@1JFUX0De=C02LW9`1RHV80NGUi02HV9P0R8R80EeMG055AD@0I
6AT0=3@d04a<C00O7al0Ph>306m_K`0L71`0?Cdm06IVIP16ATH0G5aL03dm?@0d=3@0MWIf06i^KP0m
?Cd09bLW07EeM@1IFET092@T05IFEP2/[:`0J6QX02XZ:P1:BTX0RXZ:03Lg=`0o?cl0DU9B06MWI`1Y
JFT0De=C0<;2`P2JVYX0@41002d];@1PH600I6AT06YZJP2=SHd0<30`06ATI01:BTX0W9bL07AdM00Q
8B40>3Ph05iNGP1BDU80BDU908J6QP0/;2`0Lg=c04i>CP2GUiL0GemO02TY:@0m?Cd0HF5Q04U9B@1`
L700WIfM06MWI`0f=SH0D51@04A4A01oOgl0SXj>03`l?01@D500?Shn07]kN`2:RXX0ATI604i>CP1N
GUh0JFUY0<G5a@2NWYh0@D51055AD@2QXJ40>SXj08^;R`1OGel0Jf][06e]K@12@T80EUIF09jNWP2;
Rh/0@d=304m?C`29RHT0LG5a03De=@1eMGD0@d=3059BDP2VYZH0PH6105ADE02HV9P0B4Q805IFEP1m
OGd0HF5Q04E5A@2ZZZX0X:2P03@d=02GUiL0[Jf]07alO01CDe<0I6AT09jNWP27QhL0>CTi05EEE@25
QHD0;Bd]01TI6@2ZZZX0cLg=0:VYZ@2=SHd0V9RH0492@P13@d<0QXJ609jNWP1DE5@0=3@d059BDP1@
D500YZJV05IFEP1:BTX0Ph>305QHF015ADD0`l?308R8R00Y:BT0F5QH05ADE00h>3P0LG5a05IFEP0Z
:RX0CDe=03lo?`0g=cL0ATI6024Q8@1_Kfl0GemO04E5A@0Y:BT0KVi^06a/K024Q8@0G5aL03Hf=P18
B4P0@T9202LW9`2KVi/0GEeM03/k>`29RHT0/K6a03Hf=P0o?cl0IVIV06a/K00U9BD0Cdm?08Z:RP00
902LW9`0H61P05UIF@1HF5P0GemO02@T9016ATH0WYjN08:2PP0g=cL0@41002d];@1?Cdl0ZJVY08V9
R@13@d<09BDU07emO@1JFUX0HF5Q0;fm_@30`<00KFe]020P800e=CD0J6QX03Lg=`1aLG40TI6A09:B
TP1/K6`0<c<c08f=S@2SXj<0=cLg05IFEP80R8R801h0MWIf02LW9`1OGel0CDe=02DU9@1IFET0Lg=c
06MWI`0m?Cd0Shn?034a<@1?Cdl0WIfM09VIV@12@T80];Bd0;Fe]@1WIfL0CDe=0::RXP2WYjL0W9bL
04m?C`0];Bd0Jf][05YJFP3;bl/0KVi^03/k>`0b<S8202TY:@0R01hN7P0R8R80QhN708:2PP0c<c<0
6ATI01/K6`0J6QX0;bl_059BDP0a<C405ADE01TI6@0E5AD08b<S024Q8@0Z:RX0CTi>08:2PP2=SHd0
]KFe092@T029RHT0PX:209VIV@2RXZ80]kNg0=KFeP3?cll0YjNW05IFEP0M7Ad06QXJ018B4P@05ADE
00h05aLG02h^;P2BTY80^;Rh0:RXZ00O7al04Q8B014A4@0B4Q8061PH08J6QP18B4P0U9BD04Q8B0<0
5ADE01L06ATI06IVIP0e=CD0<30`03<c<`0b<S80>3Ph07=cL`1fMWH0Jf][03Ph>00I6AT061PH01lO
7`1`L70071`L01XJ6P0I6AT06a/K038b<P0`<300D51@06QXJ00207IfMP0R01TI6@0H61P0:RXZ04=3
@`0W9bL0HV9R0;Vi^@2e]KD0@d=303/k>`1?Cdl0De=C071`L01]KFd0M7Ad06a/K01ADE40A4A4059B
DP1VIVH0MWIf06YZJP2/[:`0LG5a071`L023Ph<0IfMW0410@01HF5P0DE5A02h^;P0Z:RX0@410028R
8P807alO0100;bl_08f=S@1VIVH0@D5103Hf=P0Y:BT09BDU02<S8`0P82007AdM02h^;P1ZJVX0XZ:R
06YZJP1cLg<0:BTY0P0M7Ad05P0O7al0BTY:0<G5a@3Bd]80Ogmo02HV9P0L71`07AdM030`<00[:b/0
7alO0410@016ATH0NGUi04a<C00R8R80:BTY07QhN01BDU80B4Q803lo?`1LG5`201LG5`0501HF5P0Z
:RX0>CTi030`<00];Bd00P0O7al0600f=SH0KFe]05ADE00Q8B40MgMg04M7A`0N7Qh09RHV03Ph>01D
E5@0IVIV05eMG@1YJFT0N7Qh05iNGP0l?3`0=cLg03Hf=P10@400@d=306YZJP1@D500NWYj0;>c/`80
b<S805T0]KFe06m_K`0k>c/0W9bL0<71`@2_[jl0VIVI06IVIP1MGEd0Ti>C08^;R`2<S8`0KFe]03`l
?00e=CD0GEeM06=SH`1>CTh0<30`05EEE@1@D500IFEU05YJFP0a<C40De=C04];B`19BDT0=SHf01LG
5`1<C4`0F5QH07MgM`1XJ6P08b<S01<C4`0E5AD04a<C01DE5@0C4a<0410@01<C4`0F5QH06QXJ07Ui
N@1:BTX0<S8b07QhN03IfMT0[:b/04a<C01DE5@0I6AT06=SH`1PH600M7Ad079bLP2=SHd0^;Rh09nO
W`2`/;00Kfm_03hn?P0P820092@T020P801;Bd/0c/k>08Z:RP1mOGd0Y:BT07]kN`1OGel0Ogmo02h^
;P0R8R80;bl_028R8P0O7al08B4Q05eMG@3<c<`0TI6A06YZJP1UIFD0[Jf]0:6QX@20P800MGEe09NG
U`020<?3``0O0;Rh^01dM7@0Z:RX09VIV@1:BTX0=SHf05aLG02VYZH0[Jf]07]kN`1bLW80WIfM08J6
QP21PH40KVi^065QH@0o?cl0D51@07QhN02<S8`0Ng]k075aL@1cLg<0P82005YJFP1/K6`0VYZJ04M7
A`1WIfL0K6a/07EeM@02ooooo`0001h0Ogmo05eMG@2HV9P0@D5106=SH`1NGUh0?clo07IfMP1YJFT0
C4a<08n?S`1hN7P0<C4a04E5A@29RHT0>c/k06e]K@1:BTX0@d=306=SH`15ADD0LW9b04U9B@0[:b/0
I6AT02HV9P0m?Cd0EeMG06MWI`0k>c/205=CD`1j024Q8@0/;2`0EeMG04m?C`1>CTh0ADE501DE5@1>
CTh0OWin03`l?019BDT0?3`l01TI6@13@d<0<C4a02d];@0E5AD0<c<c065QH@16ATH0CDe=04E5A@0P
82008b<S06EUI@1CDe<0?clo05ADE01XJ6P04a<C04Y:BP1WIfL0>SXj01lO7`1VIVH092@T02PX:01K
Fe/0JFUY04i>CP1:BTX0UiNG07inOP0M7Ad0:b/[05aLG00X:2P0QXJ608V9R@0o?cl0:b/[04e=C@0a
<C40Lg=c06MWI`1HF5P0Q8B408^;R`0Y:BT0IfMW0<30`02BTY80=CDe03/k>`2DU9@0@d=303Hf=P1o
Ogl0Zj^[05aLG00e=CD0GUiN06UYJ@0g=cL0;2`/05mOG`1/K6`0F5QH03dm?@1PH600=CDe04Q8B01f
MWH0ADE506i^KP0o?cl0M7Ad06][J`0a<C40DE5A065QH@0b<S80EeMG07emO@1SHf<0S8b<03@d=028
R8P0Ng]k03dm?@1ADE40G5aL02`/;00b<S80EUIF061PH017AdL0HV9R04E5A@19BDT0Kfm_04I6AP1G
EeL07AdM04Q8B028R8P0H61P06a/K00i>CT0;Rh^04m?C`1OGel204e=C@1E0:^[Z`0L71`0EEEE05IF
EP29RHT0Lg=c02LW9`0f=SH0NGUi06YZJP1;Bd/0@41005UIF@1:BTX0<C4a07UiN@1JFUX0Cdm?0<;2
`P1=CDd0G5aL09nOW`1GEeL0C4a<05]KF`1;Bd/0Hf=S0<[:bP2l_;`0GUiN0;:b/P2n_[h0MgMg030`
<014A4@0IFEU07=cL`0g=cL0De=C07emO@1=CDd0=SHf08Z:RP2LW9`0Ng]k08R8R01mOGd0>CTi01TI
6@1FEUH0MWIf04M7A`1;Bd/0@d=304M7A`24Q8@0M7Ad07]kN`2CTi<0BTY:02`/;01iNGT0HF5Q03@d
=01_Kfl0;bl_02`/;020P800Kfm_03De=@1LG5`0EUIF04M7A`18B4P08B4Q08N7Q`2EUID0JVYZ05IF
EP2ATI40Vi^K08j>SP0e=CD071`L04E5A@0203/k>`0N08b<S00b<S806ATI06EUI@2LW9`0AdM704i>
CP1gMgL0I6AT02`/;00o?cl0J6QX06EUI@1`L700Ng]k06UYJ@26QXH0FEUI02@T901jNWX0N7Qh0451
@@1>CTh0ADE502d];@1;Bd/0Lg=c059BDP0W9bL0UIFE0P1JFUX0<P20P800NWYj06][J`0S8b<0?Shn
079bLP1DE5@0DE5A04M7A`1LG5`0Lg=c04A4A02/[:`0UIFE04U9B@0l?3`0H61P05MGE`1nOWh0?3`l
0820P01QHF40>CTi05IFEP1YJFT0Hf=S04i>CP2OWil0IfMW03/k>`1gMgL0KFe]03hn?P3>c/h0`/;2
0410@00U9BD0?Cdm03Xj>P1EEED0CTi>02LW9`1hN7P0TI6A0:2PX011@D40=CDe02h^;P0W9bL092@T
0P0J6QX0>@0f=SH0/K6a05ADE00Y:BT051@D01TI6@1LG5`0>c/k01hN7P0E5AD071`L01dM7@1]KFd0
VYZJ0::RXP2;Rh/0L71`06IVIP18B4P0?clo02DU9@0Y:BT0@D5109bLW015ADD0RHV90<71`@1aLG40
RXZ:075aL@0N7Qh05ADE01@D500E5AD05aLG02`/;00o?cl0LW9b09:BTP2/[:`0ZZZZ05eMG@0F5QH0
51@D01<C4`0E5AD0JVYZ028R8P1OGel0RXZ:02PX:00^;Rh0=cLg0451@@2ATI40JVYZ03hn?P0202DU
9@0D02PX:020P800N7Qh05YJFP0U9BD06QXJ01/K6`0o?cl0GEeM01`L700W9bL0>CTi04Y:BP1ADE40
C4a<03/k>`0^;Rh0GEeM01lO7`0>3Ph201DE5@0G024Q8@17AdL0AdM70;Bd]02[Zj/0LG5a09>CT`1n
OWh0>CTi04a<C01BDU80D51@04Q8B01?Cdl0Hf=S06ATI01RHV80F5QH07QhN02@T900TY:B0<G5a@2D
U9@00P20P8003`1<C4`08b<S01XJ6P0L71`0?3`l03<c<`0_;bl0ADE504e=C@1<C4`0LW9b04];B`15
ADD0G5aL03/k>`0203<c<`0@030`<00n?Sh0HV9R09bLW02e]KD0MWIf01TI6@0V9RH0@d=306YZJP2N
WYh0h>3P0=;BdP1hN7P0FEUI03De=@8071`L00d0=CDe08V9R@1>CTh0=SHf05eMG@2ATI40@d=307If
MP3>c/h0][Jf07AdM02<S8`0C4a<00805QHF04<05aLG01TI6@0];Bd0;2`/03/k>`0j>SX06a/K02/[
:`1XJ6P0HV9R03lo?`2][Jd0]kNg07AdM01BDU80BDU903`l?00f=SH0AdM704e=C@23Ph<0ZJVY08J6
QP1WIfL0GEeM05iNGP1XJ6P0LG5a08Z:RP1mOGd0U9BD0;Vi^@30`<00a/K60<C4a02OWil0X:2P0:n_
[`2/[:`0_kno0;Vi^@2d];@0XJ6Q04e=C@0N7Qh05aLG01PH600T92@0EEEE06UYJ@22PX80OWin0<K6
aP1oOgl0PH6108n?S`1mOGd0QHF507IfMP1nOWh0AdM70410@01ADE40CTi>075aL@13@d<05ADE0080
4a<C00<051@D01DE5@0E5AD00`0E5AD08@0M7Ad0FUYJ0820P021PH40Ti>C0<c<c01[Jf/0;bl_03Xj
>P29RHT0eMGE071`L019BDT0CDe=06a/K02c/k<0U9BD06MWI`2DU9@0C4a<01/K6`0M7Ad08R8R05]K
F`2^[Zh0M7Ad0861P@1;Bd/0;Bd]03Ti>@1YJFT0MWIf04M7A`0203Ti>@0]03Xj>P13@d<0UiNG0;bl
_02PX:00Ti>C08V9R@27QhL0a/K602l_;`0S8b<0RXZ:09bLW02DU9@0<C4a01LG5`0k>c/0BTY:02TY
:@0M7Ad08B4Q06a/K03AdM40_kno0:RXZ01TI6@0@T9202l_;`0U9BD0<c<c04U9B@1KFe/0Kfm_07Ad
M01FEUH0<c<c06MWI`1^KVh0MgMg04U9B@1lO7`0Bd];02<S8`0[:b/0>3Ph00;ooooo0000B`1mOGd0
D51@08R8R011@D40L71`051@D01FEUH0YJFU03dm?@0];Bd0KVi^06=SH`0d=3@0E5AD04i>CP0b<S80
Lg=c03`l?01<C4`0<c<c02HV9P12@T80BTY:030`<02=SHd0C4a<03@d=01OGel0M7Ad03Xj>P1;Bd/0
K6a/0451@@0d=3@0EEEE04m?C`1eMGD0O7al01/K6`1<C4`0P82003Hf=P1bLW80J6QX03Hf=P0U9BD0
CTi>05EEE@0S8b<0>3Ph07EeM@0m?Cd0IfMW071`L00g=cL0>SXj055AD@0a<C4071`L07emO@1WIfL0
9RHV059BDP1?Cdl092@T04U9B@2@T900C4a<02TY:@1@D500MGEe01DE5@0J6QX0@41004Q8B002034a
<@0=05=CD`0S8b<0O7al061PH012@T80;2`/059BDP0Y:BT0CDe=04i>CP1XJ6P0SHf=04=3@`0202XZ
:P0`06MWI`1@D500>3Ph0492@P2d];@0C4a<01LG5`11@D40MGEe059BDP0c<c<0H61P04m?C`1cLg<0
<S8b09FEU@1[Jf/0B4Q803hn?P1GEeL0H61P05IFEP1UIFD0?Shn08B4Q01DE5@0QXJ606][J`0k>c/0
BTY:07=cL`1CDe<0EUIF05aLG01UIFD0U9BD04Y:BP2ATI40NGUi03lo?`1?Cdl0LW9b04I6AP13@d<0
HF5Q04e=C@16ATH0Hf=S0P1UIFD0o`1ADE40ATI6051@D00b<S80Bd];08j>SP1OGel0Ogmo03`l?01e
MGD0TY:B07moO`0d=3@0Bd];092@T015ADD0O7al055AD@27QhL0GEeM03Xj>P0n?Sh0MGEe04I6AP0i
>CT0@D5105ADE00i>CT071`L069RHP1BDU80ATI60<G5a@1OGel0=3@d06UYJ@1HF5P0>c/k04=3@`0n
?Sh0=CDe08j>SP2DU9@0@D5109FEU@2^[Zh0IVIV04U9B@18B4P0P820096AT@0g=cL0FEUI08V9R@1D
E5@0?3`l09BDU02UYJD0MWIf08J6QP2?Shl0D51@02HV9P1FEUH0U9BD04m?C`1@D500Lg=c03Ph>01o
Ogl0Lg=c07YjNP2LW9`0I6AT071`L034a<@0F5QH02TY:@1XJ6P0E5AD02`/;01]KFd0Hf=S02l_;`1D
E5@0EeMG04i>CP1;Bd/07alO05iNGP1@D500CTi>05UIF@2NWYh0UYJF0861P@19BDT0;Rh^03<c<`0o
?cl0?Cdm06i^KP18B4P0=3@d06IVIP2DU9@0;bl_04i>CP1aLG40FUYJ03Hf=P16ATH0PH6106QXJ01V
IVH0R8R80:RXZ02IVIT0IVIV02@T901[Jf/0MGEe05]KF`2>SXh0GUiN04m?C`1HF5P0C4a<0410@00[
:b/0V9RH061PH023Ph<0VIVI07=cL`1OGel07AdM0451@@1TI6@0LG5a05iNGP1JFUX0I6AT07AdM013
@d<0c<c<0:RXZ01<C4`0ATI607alO01fMWH0@d=303Ti>@28R8P0Ogmo04I6AP2?Shl0LW9b03Lg=`1O
Gel0XJ6Q05eMG@15ADD0Y:BT065QH@0S8b<0SXj>0;Fe]@2=SHd0Bd];09FEU@1BDU80JFUY05IFEP0i
>CT0S8b<09nOW`2d];@0@T9203Ph>00b<S809BDU024Q8@0L71`06a/K01DE5@1NGUh0XJ6Q04a<C00H
61P0:b/[06QXJ00];Bd06a/K03De=@1:BTX0OWin09jNWP2d];@0Ogmo03De=@0Q8B40M7Ad0:j^[P1g
MgL0Bd];03lo?`1KFe/0RXZ:01TI6@0Q8B40RHV909^KV`0k>c/0KFe]08>3P`0e=CD092@T02l_;`1?
Cdl0IFEU07AdM01<C4`0>CTi07YjNP1VIVH0LW9b05QHF00I6AT04a<C018B4P1WIfL0:BTY04Q8B034
a<@0/[:b07QhN01GEeL0=cLg03`l?01PH600Jf][06EUI@0b<S808B4Q0:b/[01YJFT0I6AT028R8P0J
6QX06ATI04E5A@14A4@09bLW03Xj>P0202h^;P0502XZ:P0Y:BT0;2`/0451@@0X:2P0100E5AD03@0F
5QH06a/K05ADE02QXJ40LG5a09RHV02IVIT0^k^k0820P012@T809BDU01lO7`0K6a/00P0J6QX0300L
71`09BDU03Xj>P2<S8`0MWIf07EeM@1fMWH0];Bd0<30`01]KFd07QhN01`L708061PH02@0;2`/07Ad
M01@D500AdM704I6AP1=CDd0Ti>C04i>CP11@D40AdM702l_;`0b<S80>c/k0451@@1:BTX0S8b<0:j^
[P2_[jl0U9BD08b<S023Ph<0M7Ad09ZJVP2ZZZX0IFEU03lo?`2CTi<0JVYZ04m?C`1;Bd/08B4Q01dM
7@26QXH0?Cdm02DU9@16ATH20;Fe]@060:JVYP2][Jd0clo?0<G5a@3@d=00<C4a0P0E5AD0;00F5QH0
5ADE01hN7P0l?3`0<S8b069RHP0O7al0:RXZ06i^KP1?Cdl0V9RH0=SHf02WYjL0`l?305eMG@0K6a/0
6QXJ020P800O7al0?Cdm07alO02UYJD0UIFE079bLP1jNWX0M7Ad06EUI@1XJ6P0RHV909jNWP27QhL0
_[jn0;Vi^@2GUiL0eMGE0;Rh^01cLg<0AdM703De=@0i>CT0Cdm?0:^[Z`1DE5@05aLG0P0E5AD0500G
5aL0820P05mOG`1ZJVX0YJFU0;:b/P3:b/X0`L7108R8R02GUiL0V9RH09BDU01WIfL0E5AD07AdM01l
O7`0AdM706MWI`1^KVh07AdM100C4a<00`0E5AD05aLG01LG5`0201DE5@1501LG5`0n?Sh0WYjN06][
J`1DE5@0Vi^K04Q8B00[:b/0;Rh^04I6AP2WYjL0Lg=c05YJFP19BDT0De=C0:NWY`2@T900CTi>05=C
D`2NWYh0?Cdm01LG5`0L71`0LG5a0:^[Z`25QHD0=3@d02h^;P0W9bL08R8R04A4A03<c<`0WinO07al
O020P800SXj>0<S8b03Fe]H0^KVi05eMG@0Q8B409BDU02`/;01mOGd0A4A406e]K@2BTY80LG5a06][
J`0I6AT05aLG02DU9@1>CTh0;Bd]01hN7P0Q8B40>CTi0:b/[02c/k<0`/;209RHV01HF5P0Cdm?06MW
I`1;Bd/0;bl_028R8P1DE5@0IfMW0080HF5Q00T0EeMG07emO@2<S8`0L71`04Q8B01cLg<08B4Q02LW
9`0V9RH00_ooool0002o0:FUY@1QHF40WYjN04=3@`1mOGd0I6AT03lo?`1EEED0EeMG03lo?`26QXH0
ATI604e=C@2][Jd0Vi^K03Hf=P1]KFd0ADE505YJFP2;Rh/0@T9204a<C00a<C40@D5108J6QP17AdL0
=3@d05iNGP1?Cdl0?Cdm071`L01mOGd0?3`l02l_;`0d=3@0:RXZ051@D01ADE406QXJ04I6AP1dM7@0
?Shn0451@@0n?Sh09BDU0451@@16ATH0Cdm?01`L700o?cl0NGUi03De=@0d=3@0?Shn04I6AP17AdL0
DE5A02`/;00R8R80Bd];05aLG00W9bL0FUYJ05mOG`0[:b/09RHV06ATI013@d<0<30`05YJFP1TI6@0
<C4a02l_;`1IFET0?clo02<S8`1>CTh0EEEE028R8P29RHT0GEeM02XZ:P0i>CT0HV9R03`l?01WIfL0
E5AD07MgM`2DU9@0?3`l02`/;00a<C40OWin059BDP0d=3@0@4100;^k^`1BDU80<C4a04m?C`2HV9P0
DU9B034a<@1YJFT0EUIF06][J`0d=3@0UIFE06=SH`10@400B4Q804M7A`1bLW80IVIV06][J`14A4@0
QhN704a<C027QhL0F5QH03Xj>P1;Bd/0Kfm_05iNGP1aLG40De=C05mOG`2CTi<0F5QH07IfMP1UIFD0
?Shn04U9B@1NGUh0@T9204M7A`1PH600@41004=3@`1TI6@0HF5Q06e]K@1:BTX0A4A404m?C`0i>CT0
De=C09jNWP1OGel0LW9b055AD@27QhL0Ph>308F5Q@0e=CD0De=C0:2PX019BDT0MWIf04M7A`1^KVh0
KFe]04I6AP11@D40NWYj04e=C@10@400Cdm?05UIF@1>CTh09RHV07IfMP1UIFD0De=C0=GEe@1jNWX0
Bd];08R8R01HF5P0@D5104A4A00n?Sh0?clo0:2PX02@T900=CDe06QXJ021PH40PX:205ADE01=CDd0
0P2IVIT0B011@D40IVIV0;Rh^01cLg<0=CDe09VIV@2DU9@0HF5Q0::RXP3?cll0K6a/038b<P1IFET0
SHf=04i>CP1BDU80GEeM03/k>`25QHD0IfMW07EeM@2^[Zh0LW9b05mOG`34a<@0EEEE03<c<`1mOGd0
I6AT03Ph>01cLg<0FEUI03Xj>P1SHf<0Ogmo06UYJ@1TI6@0;2`/05IFEP14A4@0EEEE051@D02ZZZX0
Xj>S08f=S@17AdL0?3`l04M7A`0n?Sh0=CDe06QXJ01KFe/0>c/k06m_K`2CTi<0:RXZ065QH@2QXJ40
O7al03lo?`16ATH0UIFE06YZJP0m?Cd0Hf=S05iNGP1PH600>c/k05eMG@2NWYh0CTi>03<c<`80GemO
03P0G5aL08^;R`1_Kfl0;Rh^04m?C`2_[jl0KVi^07emO@2a/K40QHF505MGE`0j>SX0P820075aL@1V
IVH0J6QX05aLG01eMGD0H61P02d];@2^[Zh0SHf=04E5A@1KFe/0Rh^;09VIV@1fMWH0;bl_05ADE01>
CTh0:BTY06IVIP1jNWX0BDU905=CD`28R8P08B4Q05=CD`2c/k<0LG5a0410@02c/k<0aLG505mOG`1B
DU80c/k>0;bl_02KVi/07alO020P801[Jf/0MWIf0=KFeP1YJFT0?3`l038b<P809bLW0P0L71`03`0F
5QH08b<S0:j^[P26QXH092@T075aL@1TI6@0GUiN07inOP2WYjL0WIfM08>3P`1OGel0FEUI024Q8@02
01DE5@80>SXj01`04a<C00l?3`0>3Ph0410@059BDP0/;2`05ADE03Xj>P2<S8`0K6a/02/[:`2ZZZX0
`<3008V9R@2<S8`0GemO03Lg=`0U9BD05aLG01PH600T92@0Fe]K03@d=01DE5@0HV9R01dM7@0D51@0
Lg=c0P1LG5`04`2?Shl0;2`/03<c<`12@T80Jf][079bLP1_Kfl0FUYJ04m?C`1CDe<0GEeM0;Rh^01V
IVH0DU9B01dM7@0G5aL071`L07=cL`0^;Rh00P0M7Ad01P0S8b<092@T01lO7`0U9BD0<C4a03Ti>@80
5ADE01d05aLG01DE5@0E5AD05ADE01PH600N7Qh0H61P04i>CP2QXJ40UYJF05ADE018B4P07alO01`L
700M7Ad06QXJ01/K6`0L71`06a/K01TI6@0N7Qh0ADE5030`<00Y:BT0EEEE09:BTP1iNGT0ADE502h^
;P0201LG5`0o01TI6@0b<S80<S8b01dM7@0O7al08b<S02LW9`21PH40KVi^03<c<`0Q8B409bLW02PX
:00b<S80@d=302l_;`0d=3@0Zj^[0=[JfP30`<00T92@05iNGP2VYZH0Ng]k02d];@0N7Qh08b<S038b
<P2BTY80Lg=c04M7A`1EEED092@T04E5A@0f=SH0C4a<06=SH`11@D40@d=307QhN02c/k<0Ng]k0;Rh
^02l_;`0HF5Q01XJ6P0E5AD05aLG01DE5@0G5aL0De=C05QHF01NGUh0>CTi03dm?@2PX:00WYjN08B4
Q01bLW80KFe]0:n_[`1hN7P071`L00806ATI03407alO02/[:`20P800S8b<055AD@0h>3P0HF5Q07in
OP13@d<0=CDe03/k>`2?Shl0NWYj0:b/[02KVi/0^[Zj0;:b/P2HV9P0BDU904M7A`0e=CD0;Bd]03<c
<`1fMWH0J6QX02PX:00I6AT05ADE01LG5`0X:2P0<c<c02<S8`2:RXX0emOG0;fm_@2GUiL0NWYj08f=
S@27QhL0S8b<09nOW`2a/K40]kNg05iNGP1EEED0U9BD06IVIP0I6AT051@D0080410@00<04a<C01DE
5@0E5AD00`0E5AD01`0H61P0?Shn059BDP1MGEd0EeMG09JFUP0i>CT00P0Y:BT0;@15ADD0Shn?03dm
?@0l?3`0@41007AdM00l?3`08b<S065QH@11@D40CTi>0861P@0/;2`071`L08f=S@2WYjL0CTi>01lO
7`0T92@07AdM024Q8@1EEED0U9BD02PX:00O7al08B4Q02/[:`1KFe/0b<S80<?3``1@D5008R8R01hN
7P0S8b<0EeMG0<?3``2UYJD0JFUY08f=S@0W9bL05QHF01PH600N7Qh0D51@02<S8`02028R8P0H03Lg
=`1mOGd0E5AD07moO`0d=3@0Rh^;06UYJ@0Q8B405ADE01XJ6P0R8R80<C4a03hn?P1@D500KVi^06AT
I01SHf<0NGUi09:BTP1]KFd0MGEe04E5A@0b<S80>SXj0_ooool0000807]kN`1EEED0N7Qh03Xj>P1b
LW80G5aL04U9B@1XJ6P203Hf=P2H092@T016ATH09bLW04e=C@1fMWH0<S8b05aLG00R8R80E5AD06UY
J@0f=SH0C4a<02<S8`0d=3@0R8R804E5A@0c<c<0I6AT04A4A00a<C40Fe]K06ATI00h>3P0>c/k06i^
KP1<C4`0Lg=c059BDP0P8200JVYZ07moO`1ADE40De=C04M7A`0d=3@0C4a<04U9B@13@d<09RHV059B
DP2@T900Cdm?051@D019BDT0<C4a04U9B@1/K6`0I6AT04];B`1dM7@0FEUI02l_;`25QHD0Ogmo03Ph
>00`<300Hf=S03hn?P1PH600YjNW07moO`1LG5`0>3Ph05aLG011@D404a<C05iNGP1SHf<0:2PX08V9
R@1JFUX07alO05ADE02?Shl0A4A4075aL@0i>CT0@d=308^;R`1_Kfl0@d=303De=@1lO7`0CTi>030`
<01_Kfl0/;2`051@D00d=3@0De=C0::RXP0_;bl0<S8b06i^KP23Ph<0Ng]k03De=@2ATI40LG5a034a
<@1;Bd/0LG5a07QhN01RHV80Lg=c05mOG`1oOgl0Bd];09>CT`1@D500F5QH07inOP1kNg/0Fe]K07Ad
M01OGel0E5AD0:6QX@1QHF40NGUi069RHP1;Bd/0MgMg07=cL`0n?Sh0B4Q806][J`0i>CT0Cdm?07al
O01dM7@0IfMW05eMG@1TI6@0MGEe0410@01ADE40Ng]k03dm?@2?Shl0Fe]K08:2PP2CTi<0PX:202HV
9P1cLg<0Ti>C03dm?@1OGel0>c/k08B4Q02KVi/20410@00>07QhN00j>SX0=SHf05ADE01WIfL0ADE5
020P801`L700EUIF0451@@38b<P0IfMW04a<C01YJFT204Y:BP200451@@1?Cdl0@T920:NWY`28R8P0
>c/k06IVIP1eMGD0Rh^;04m?C`1>CTh0Y:BT04e=C@0/;2`0AdM707]kN`24Q8@0>CTi08j>SP2HV9P0
FEUI08N7Q`2IVIT0E5AD03@d=01OGel0KVi^04M7A`1RHV80ATI603dm?@1dM7@0?Cdm06UYJ@2ZZZX0
KFe]04E5A@33`l<0DE5A03De=@2=SHd0L71`03`l?01gMgL0=cLg02PX:014A4@0DU9B06][J`1^KVh0
<30`0451@@0g=cL0?Cdm03<c<`2EUID0W9bL0:6QX@1UIFD0AdM704m?C`0g=cL06ATI06ATI01cLg<0
?Cdm071`L02JVYX0:2PX03/k>`1TI6@0F5QH01lO7`1;Bd/0MGEe07inOP1cLg<0IfMW07QhN01;Bd/0
<30`02h^;P1ZJVX0JFUY03/k>`1FEUH07QhN02LW9`1LG5`0OWin055AD@0h>3P0Vi^K030`<017AdL0
YZJV0:b/[011@D407QhN051@D01]KFd0=cLg05ADE023Ph<0YjNW08>3P`13@d<0/k>c06m_K`0];Bd0
<c<c05aLG01WIfL0RXZ:03`l?01RHV80JFUY03dm?@1LG5`0KFe]03/k>`1KFe/0Kfm_03`l?00f=SH0
L71`065QH@0[:b/20<K6aP0A03Ti>@0Y:BT0CTi>05MGE`23Ph<0?Shn02DU9@1YJFT0Lg=c0:FUY@2d
];@0GUiN03@d=00];Bd092@T01dM7@0K6a/00P0H61P0301`L700/;2`09nOW`36a/H0`<300;Fe]@24
Q8@0DU9B03Xj>P0Y:BT07alO01TI6@<05ADE00<0@d=301DE5@0>3Ph00`0>3Ph0=@0Y:BT0B4Q801<C
4`0@4100;Rh^096AT@0a<C40M7Ad0<_;b`2_[jl0=3@d01LG5`0E5AD061PH01`L700E5AD05aLG03<c
<`17AdL0;2`/0451@@1/K6`0ATI60;:b/P2h^;P0[Zj^096AT@0H61P05ADE01@D500E5AD08b<S04U9
B@1hN7P0PH6106=SH`2[Zj/0YZJV09NGU`1_Kfl0<c<c02LW9`1EEED0b<S806IVIP0d=3@0820P01lO
7`0M7Ad08B4Q02HV9P14A4@071`L00H05ADE00d05aLG01dM7@0f=SH07alO09>CT`1nOWh0B4Q803Hf
=P0H61P07alO024Q8@0L71`05aLG00<05ADE00h05QHF01LG5`0J6QX07alO02TY:@16ATH0JFUY03Ph
>01?Cdl07AdM01TI6@0L71`0@41001`L70807AdM04D06a/K02DU9@0a<C40Shn?05eMG@0/;2`09RHV
02/[:`0X:2P0<S8b04M7A`26QXH0_Kfm0;Vi^@2OWil0R8R80<K6aP1HF5P09BDU01dM7@0N7Qh07AdM
024Q8@0g=cL0Ogmo08N7Q`1;Bd/0Jf][05ADE01VIVH0VIVI05mOG`1?Cdl0QHF50<O7a`3Cdm<0/[:b
0:ZZZP2LW9`0KVi^04m?C`0Q8B405aLG01DE5@0X:2P0ADE505ADE02WYjL0W9bL0:RXZ03Hf=P0MgMg
04a<C01TI6@0CDe=02PX:01/K6`0C4a<01/K6`0I6AT07QhN03Hf=P1gMgL0Z:RX07alO01UIFD0T92@
0;:b/P2ATI400P24Q8@09P2>SXh0[jn_0:j^[P3<c<`0];Bd09RHV02@T900@41004Y:BP1;Bd/0@d=3
03De=@1IFET0/[:b07UiN@0k>c/06QXJ02@T900g=cL07QhN01dM7@13@d<0KFe]02TY:@0U9BD09bLW
03Lg=`15ADD0N7Qh0;:b/P3Kfm/0/;2`07YjNP2;Rh/0QhN707=cL`0K6a/051@D0`0A4A40100@4100
5ADE014A4@0C4a<201DE5@0d04Q8B00g=cL0LG5a07IfMP2TY:@0;Bd]02@T900i>CT0RXZ:09:BTP0e
=CD0<S8b05IFEP1LG5`05ADE01LG5`0Q8B40DE5A04a<C01LG5`0YJFU06a/K03De=@0`<300451@@0L
71`08b<S01hN7P17AdL0BDU902h^;P0N7Qh07AdM01`L700N7Qh09RHV0820P01nOWh0IFEU02<S8`0R
8R80:RXZ07IfMP1nOWh0KVi^08>3P`0o?cl05ADE01TI6@0F5QH071`L04Q8B0808R8R00T09BDU03De
=@1/K6`0AdM7071`L00V9RH0EEEE02DU9@0E5AD00P0G5aL03P0K6a/092@T02l_;`0n?Sh0F5QH09jN
WP1/K6`0I6AT08>3P`2TY:@0W9bL09jNWP1aLG40MWIf0_ooool0003o08J6QP1RHV80[Jf]03`l?01d
M7@0J6QX04e=C@1fMWH0@T9202HV9P1_Kfl0DE5A03`l?01cLg<0?clo02<S8`1KFe/0=3@d04m?C`0Y
:BT08b<S0492@P13@d<0A4A407inOP0R8R80=CDe0820P01^KVh0@410079bLP1]KFd05aLG03<c<`1F
EUH0JVYZ09bLW012@T804A4A05=CD`2<S8`0DE5A06MWI`10@4008B4Q03`l?01>CTh06ATI018B4P0b
<S80L71`03De=@1HF5P0Cdm?010@400T92@0B4Q80492@P0^;Rh0P82003lo?`0F5QH0EEEE06QXJ00c
<c<0<S8b05eMG@0L71`0<S8b05eMG@1TI6@0CDe=04i>CP2EUID0GemO038b<P1=CDd0Hf=S02HV9P29
RHT0KVi^03hn?P0W9bL0GemO0451@@1UIFD0C4a<05]KF`1kNg/0Bd];030`<012@T80UIFE05YJFP0V
9RH0?3`l06YZJP10@400<C4a05IFEP2WYjL09bLW020P800h>3P0GemO06IVIP0o?cl0[:b/08Z:RP0k
>c/0?Shn05QHF01LG5`0IVIV05UIF@0h>3P0MGEe04U9B@2LW9`0GUiN034a<@16ATH0Hf=S055AD@29
RHT0FEUI03lo?`2@T900Fe]K08b<S01TI6@0;Bd]0492@P1VIVH0B4Q8069RHP28R8P0HF5Q04U9B@1Q
HF40CDe=07YjNP1BDU80A4A405IFEP0];Bd0H61P096AT@1?Cdl0JVYZ03Xj>P1RHV80YZJV08J6QP0a
<C40BTY:08J6QP0o?cl0DU9B03Xj>P0n?Sh0T92@05EEE@10@400Ng]k06m_K`14A4@0QXJ60;Ng]`1N
GUh0820P06e]K@1FEUH0Bd];0;>c/`1_Kfl0Cdm?06a/K01?Cdl0DU9B04];B`1CDe<0CDe=0;Bd]028
R8P0CDe=079bLP2GUiL0];Bd04a<C01BDU80Xj>S08R8R00o?cl0DE5A05IFEP1QHF40ATI60;Bd]02Q
XJ40NWYj08Z:RP2/[:`0?Cdm059BDP2OWil0RHV903dm?@0c<c<0;Bd]04U9B@1iNGT0FEUI06EUI@2E
UID0>SXj04a<C036a/H0De=C03De=@1^KVh0BDU903/k>`2DU9@0I6AT030`<015ADD0EUIF04e=C@1?
Cdl09BDU0451@@0m?Cd0GUiN04Y:BP2BTY80JVYZ08^;R`1BDU80BDU905aLG013@d<0=cLg05ADE01;
Bd/0@41009fMW@2QXJ40CTi>04e=C@1mOGd0De=C02TY:@1:BTX0MWIf001M05eMG@1bLW80Kfm_07Ad
M01MGEd0@T9203<c<`1/K6`0GUiN03Xj>P1HF5P0@D5103Xj>P18B4P0Lg=c06=SH`0o?cl0YjNW05YJ
FP17AdL0P82008j>SP1PH6008B4Q05=CD`1<C4`0>3Ph03hn?P0d=3@0KFe]06a/K013@d<0bLW909^K
V`13@d<0>SXj06IVIP1HF5P0GUiN05QHF02NWYh0Ph>303hn?P1OGel0IVIV030`<01oOgl0XJ6Q04Q8
B00k>c/0R8R803lo?`0O7al0UIFE0;Rh^01gMgL0@D51092@T017AdL0F5QH024Q8@0[:b/0L71`08V9
R@1EEED0PX:209bLW01@D500;bl_02<S8`0L71`06QXJ01LG5`0E5AD0H61P06][J`2b/[80`/;207em
O@0f=SH071`L01HF5P0G5aL06a/K01dM7@0H61P07QhN01PH600F5QH0EEEE010@400>3Ph03@d=0080
3Ph>00`051@D05ADE00E5AD03Ph>01<C4`1]KFd0V9RH03Xj>P2OWil0HF5Q01LG5`0E5AD201PH600R
02@T900W9bL08b<S028R8P18B4P0GUiN04Y:BP11@D40UiNG06m_K`1DE5@0[Jf]07emO@1KFe/0DE5A
03Ti>@0^;Rh08B4Q01dM7@0^;Rh0G5aL0<o?c`3Bd]80emOG0<c<c038b<P0`/;209jNWP2][Jd0W9bL
09>CT`1GEeL0CDe=03Xj>P808R8R00@0;bl_03Hf=P0F5QH05QHF100E5AD201LG5`0803dm?@0e=CD0
6a/K08R8R01cLg<0B4Q802`/;00F5QH201LG5`805ADE00@05QHF01PH600H61P05ADE0P0G5aL08@0T
92@0;bl_03dm?@1_Kfl0>c/k03lo?`18B4P07AdM02HV9P0o?cl05ADE01XJ6P0I6AT07AdM02PX:00U
9BD0MgMg08V9R@1=CDd0B4Q804=3@`0g=cL0;bl_06MWI`2KVi/0];Bd0<;2`P3<c<`0[jn_0:6QX@0[
:b/071`L01XJ6P0201`L700Q01dM7@0N7Qh0<S8b08j>SP2XZ:P0K6a/0<c<c02IVIT0WinO0:FUY@27
QhL0CDe=03hn?P1WIfL0dM7A08>3P`0U9BD0CTi>061PH015ADD0<S8b02/[:`18B4P0ADE508F5Q@2f
][H0a/K60=SHf03GemL0SHf=07AdM01OGel0L71`0080:BTY0240Ph>303hn?P0J6QX08b<S06MWI`1m
OGd0NGUi079bLP1]KFd0UIFE0:NWY`1TI6@0A4A404M7A`2[Zj/0`L7109nOW`32`/80]KFe05mOG`1T
I6@0Bd];04a<C016ATH0<30`020P800J6QX0BDU906YZJP0V9RH0:2PX04E5A@0m?Cd00P0L71`0401R
HV80?Cdm01DE5@0C4a<05ADE01<C4`0F5QH071`L0451@@2=SHd0UYJF06a/K02JVYX0OGem0861P@0/
;2`201<C4`0400h>3P0@41004a<C01@D50<05ADE01H05aLG04e=C@0/;2`0PX:20:j^[P37alL0Ogmo
09:BTP2/[:`0aLG50<S8b02JVYX0IVIV0861P@0R8R805ADE01LG5`0K6a/07AdM05MGE`2EUID0[:b/
0P3WinL0>03>c/h0HV9R02HV9P0i>CT0>SXj03Ti>@1CDe<05aLG01`L700G5aL06QXJ01dM7@0O7al0
G5aL04e=C@1VIVH0<S8b02XZ:P0k>c/0T92@03`l?01jNWX0GUiN01LG5`0F5QH06ATI01dM7@0O7al0
ADE5020P800T92@08b<S03<c<`1OGel0;Rh^071`L00T92@0ADE501hN7P0C4a<05aLG01TI6@0L71`0
9RHV02/[:`0f=SH0B4Q804M7A`0a<C40D51@07UiN@2TY:@0[Jf]0;^k^`2YZJT0[jn_0_ooool0001]
08F5Q@1@D500Q8B404=3@`1iNGT0Cdm?06e]K@2ZZZX0H61P03Ph>02EUID0:b/[03Lg=`1OGel0PH61
02DU9@1?Cdl0:b/[06][J`1QHF409BDU03De=@0Z:RX0@D5107UiN@0d=3@0:BTY069RHP1?Cdl0=cLg
0820P02IVIT0=CDe038b<P0_;bl0:b/[06a/K01QHF407alO06MWI`1EEED092@T05QHF01PH600;Rh^
02TY:@1HF5P0ATI601dM7@0l?3`0G5aL01`L701LG5`0EUIF04E5A@17AdL0FEUI04i>CP0j>SX0PH61
065QH@0T92@0N7Qh05EEE@0^;Rh0ATI607YjNP1=CDd0@T9207emO@1@D50071`L02LW9`1>CTh0Cdm?
034a<@1SHf<0EeMG01dM7@1JFUX0M7Ad04];B`0d=3@0Fe]K02HV9P1gMgL0FUYJ07EeM@27QhL0C4a<
01HF5P13@d<0L71`065QH@0Z:RX0E5AD0:NWY`16ATH0=cLg05QHF02QXJ40@T92034a<@1GEeL0FUYJ
03@d=00j>SX0GEeM08J6QP0205]KF`2b05MGE`0Z:RX0MgMg08B4Q018B4P0JFUY0451@@2TY:@0MgMg
0410@01?Cdl0=3@d01TI6@1/K6`0JVYZ05=CD`1eMGD0<C4a09nOW`1oOgl0?Shn06YZJP1ADE40<30`
04a<C01[Jf/0IFEU055AD@1HF5P06ATI06m_K`1eMGD0FEUI04Q8B00D51@0Fe]K08j>SP1@D500QHF5
0492@P0o?cl0EEEE0820P00i>CT0EEEE08>3P`0_;bl0O7al061PH011@D40Xj>S03Ph>01:BTX0QXJ6
06MWI`0h>3P0AdM705=CD`12@T80:2PX06EUI@0j>SX0>3Ph0:n_[`1XJ6P0H61P0861P@10@400K6a/
08J6QP1eMGD0E5AD0;no_`2?Shl0<C4a04a<C01[Jf/0Rh^;04Y:BP1KFe/0Shn?07AdM011@D40IFEU
09FEU@0l?3`07alO08N7Q`22PX80H61P09BDU02/[:`0;bl_02<S8`1[Jf/0Q8B403Ti>@1IFET0;Rh^
03/k>`1^KVh0Bd];06a/K02MWId0FUYJ05UIF@2NWYh0GUiN03Lg=`23Ph<09RHV03Ph>02OWil0K6a/
038b<P17AdL0GUiN059BDP0n?Sh0:BTY079bLP24Q8@0L71`05YJFP2TY:@0Ph>30;Fe]@0];Bd0<30`
05EEE@1FEUH0?Shn05UIF@0/;2`0;Rh^06=SH`22PX80@T9206QXJ02^[Zh0LG5a03De=@17AdL0KFe]
05YJFP1<C4`0R8R80<71`@1XJ6P0BTY:03De=@1cLg<0JFUY051@D01iNGT0Bd];03Ph>019BDT0M7Ad
061PH01GEeL0_kno06i^KP1EEED0XJ6Q08J6QP1PH600:RXZ07AdM01BDU80Fe]K05QHF010@400LW9b
04m?C`0c<c<0[jn_09jNWP80DE5A03L0PH6105IFEP1EEED0?clo04Y:BP1VIVH0ATI606e]K@1IFET0
ADE506=SH`1jNWX0B4Q803Ti>@1oOgl0Lg=c03Xj>P2CTi<0b<S807AdM00l?3`0Ph>305IFEP1JFUX0
<30`020P8010@400P82004I6AP27QhL0HV9R0;Rh^020P800;bl_01dM7@0H61P05aLG01HF5P1kNg/0
Fe]K06MWI`28R8P0AdM7020P800H61P07AdM01`L700H61P05QHF020P801GEeL0:2PX02@T901HF5P0
4A4A00@03Ph>00l0410@04U9B@0O7al04Q8B010@400b<S80/[:b05]KF`1lO7`0>SXj01TI6@0L71`0
6a/K01DE5@0D51@00P0E5AD0:00F5QH05ADE02XZ:P1EEED0Lg=c09nOW`24Q8@0MWIf04Q8B00J6QX0
:2PX04E5A@1UIFD0NWYj07inOP2<S8`0[:b/0;Zj^P2VYZH0ZZZZ0<_;b`2l_;`0[:b/0;Ng]`3IfMT0
]kNg02/[:`0i>CT0Lg=c05EEE@1NGUh0F5QH05UIF@1UIFD071`L01HF5P0E5AD05aLG01DE5@0H61P2
01DE5@0801TI6@1OGel092@T01PH6020P800Shn?04Q8B00X:2P201LG5`0401HF5P0E5AD05ADE01LG
5`806a/K06h06QXJ01LG5`0E5AD09BDU038b<P0f=SH0IFEU04A4A00/;2`0CDe=0410@00a<C40@d=3
01DE5@0F5QH06ATI02XZ:P0U9BD0820P04U9B@0S8b<06ATI024Q8@13@d<0KVi^0;Bd]033`l<0`L71
0;no_`3:b/X0MGEe06e]K@24Q8@0CTi>01dM7@0L71`05aLG01XJ6P0L71`07AdM020P8010@400X:2P
0=SHf02c/k<0bl_;0<;2`P22PX80>c/k03Lg=`1GEeL0WinO0=kNgP1]KFd06a/K01HF5P0J6QX071`L
051@D02JVYX0QhN70;Zj^P36a/H0_Kfm0<?3``2MWId0PX:209nOW`2=SHd0T92@0:f][@29RHT0>SXj
03`l?01YJFT0EEEE05ADE02:RXX0LW9b069RHP0V9RH0;Rh^04i>CP1TI6@0;Bd]01dM7@0R8R80FUYJ
06a/K010@400NGUi0:>SX`2DU9@0M7Ad06UYJ@0U9BD08R8R01dM7@0R8R806QXJ02LW9`1cLg<0Cdm?
04I6AP1DE5@0:b/[01lO7`0S8b<0LW9b03<c<`805ADE00d05aLG01DE5@0E5AD05ADE01TI6@1=CDd0
Lg=c03dm?@1RHV80Ph>30:6QX@1TI6@05QHF00<04a<C02@04A4A01DE5@0B4Q8051@D01DE5@0Y:BT0
@T92038b<P2FUYH0c/k>0>;RhP3WinL0fm_K09jNWP2PX:00];Bd0;:b/P2g]kL0Q8B401LG5`0E5AD0
5aLG01/K6`0I6AT05QHF06EUI@2b/[80i>CT0=WIf@3AdM40R8R80451@@0l?3`0ATI604=3@`0o?cl5
01DE5@0/01PH6016ATH0<30`05QHF01JFUX0<c<c04];B`1dM7@0?Cdm06][J`0O7al05ADE01/K6`0L
71`05aLG01`L7012@T807AdM024Q8@0V9RH0=SHf05UIF@0Y:BT0Hf=S02HV9P10@400:2PX01HF5P0G
5aL071`L01hN7P0X:2P0;Rh^03Xj>P13@d<07AdM01LG5`0Q8B40D51@092@T02UYJD0_Kfm0:FUY@2m
_Kd2ooooo`0006P0WYjN05YJFP2VYZH0ADE50861P@1:BTX0@T9208:2PP1=CDd0>c/k0;6a/@1/K6`0
<c<c04m?C`2=SHd0:RXZ04];B`0M7Ad0CDe=071`L00i>CT0DU9B03Ph>011@D40U9BD05UIF@0`<300
GUiN038b<P0T92@0Cdm?06m_K`0c<c<0>SXj05MGE`14A4@0IVIV05=CD`0U9BD0HV9R06QXJ00n?Sh0
DE5A0492@P0X:2P0:RXZ05ADE01<C4`07AdM03lo?`1VIVH0:BTY03/k>`0m?Cd0:b/[03`l?01;Bd/0
6QXJ01LG5`2ATI40EUIF01lO7`1jNWX0=3@d01/K6`11@D40IFEU04E5A@18B4P0RHV905MGE`13@d<0
=cLg06IVIP0h>3P07AdM06MWI`1[Jf/0:BTY071`L01RHV80;bl_03hn?P1aLG40;Rh^04a<C016ATH0
NGUi06][J`14A4@09BDU03<c<`1>CTh0Cdm?028R8P1TI6@0Zj^[02XZ:P0d=3@0O7al08b<S015ADD0
;bl_065QH@80Hf=S0?l0@T9208:2PP25QHD0De=C06i^KP1jNWX0C4a<05UIF@1VIVH0EEEE06a/K00d
=3@0NWYj07EeM@1GEeL0I6AT065QH@1OGel0Ng]k05EEE@1BDU80Ti>C05UIF@1gMgL0JFUY04i>CP2G
UiL0P820059BDP1@D500Jf][06MWI`1/K6`0SXj>079bLP1aLG40K6a/08B4Q01oOgl0>SXj0492@P2?
Shl0GUiN08n?S`1HF5P0Jf][07inOP1iNGT0<c<c08:2PP2HV9P0:RXZ05EEE@0k>c/0Hf=S0:VYZ@1F
EUH0?Shn06a/K01CDe<0?3`l06i^KP2=SHd0ATI601`L701TI6@0HF5Q03dm?@2QXJ40=CDe05eMG@28
R8P0DU9B05iNGP1BDU80E5AD069RHP3Cdm<0U9BD04i>CP1CDe<0JVYZ07EeM@0V9RH0A4A4092@T01;
Bd/0<C4a06][J`2RXZ80M7Ad03De=@21PH40OGem05]KF`1HF5P0LW9b03lo?`0T92@0HV9R08B4Q00n
?Sh0H61P059BDP0`<300OGem04U9B@1=CDd0PH6105UIF@1LG5`0WYjN03Ph>012@T80R8R8059BDP0f
=SH0NWYj0492@P14A4@0Ogmo08j>SP1`L700@410028R8P1BDU80CTi>06][J`1GEeL0_Kfm09FEU@2[
Zj/0?clo03dm?@1EEED0IFEU04M7A`1]KFd0Jf][04a<C01WIfL0SXj>02DU9@10@400JFUY07emO@0i
>CT0BDU906EUI@1bLW80F5QH06IVIP2KVi/0DU9B03/k>`0b<S80M7Ad04U9B@1>CTh0Ph>305mOG`0]
;Bd0Cdm?05YJFP0o?cl0NGUi0<G5a@22PX80HF5Q09ZJVP1fMWH0=3@d03`l?02=SHd0KVi^07AdM01?
Cdl0D51@0:b/[01mOGd0B4Q80:j^[P2XZ:P0820P05IFEP2PX:00WinO06e]K@1KFe/0De=C03`l?015
ADD0^KVi08b<S019BDT0Lg=c07MgM`19BDT0@41008b<S01[Jf/0>c/k0:ZZZP37alL0Kfm_03Xj>P1[
Jf/0FEUI06e]K@11@D409BDU03Xj>P1oOgl0MgMg0;Zj^P3:b/X0c/k>0;Vi^@1HF5P08B4Q01TI6@0G
5aL0;Rh^0;2`/01hN7P0J6QX09^KV`0f=SH05aLG030`<00V9RH08B4Q01<C4`0E5AD0<S8b079bLP0Z
:RX0@D5105ADE00A4A403`l?010@400>3Ph0410@00h>3P0i>CT0>3Ph01<C4`0@41005ADE07]kN`2^
[Zh0LW9b038b<P0I6AT00@0G5aL301DE5@0U01LG5`0F5QH05ADE00h>3P0@41004a<C01/K6`1ADE40
Ogmo08F5Q@0g=cL05ADE014A4@0B4Q806ATI02DU9@0[:b/0=CDe03Ph>01KFe/0VIVI0:n_[`2OWil0
];Bd0;no_`2TY:@0PH610<;2`P1JFUX092@T02d];@1WIfL0F5QH04M7A`19BDT0IFEU01lO7`0401DE
5@805QHF00/05aLG051@D028R8P0;2`/01`L701[Jf/0aLG506YZJP15ADD071`L01TI6@0201LG5`0E
01/K6`0E5AD05QHF01LG5`0J6QX071`L01/K6`0/;2`0;Rh^03@d=01LG5`0GemO03<c<`0k>c/0De=C
08f=S@1;Bd/05ADE01LG5`0R8R808B4Q00807AdM0180?clo01LG5`0E5AD05ADE01HF5P0Z:RX0dM7A
0861P@1GEeL0WIfM08V9R@2[Zj/0^KVi04U9B@1mOGd0;bl_01`L700I6AT201XJ6P0501`L700O7al0
9BDU08:2PP2[Zj/00P3AdM40;P3;bl/0RXZ:09FEU@2h^;P0V9RH06a/K01>CTh0N7Qh04M7A`0Y:BT0
71`L03@d=01/K6`0^KVi0=KFeP3;bl/0[Zj^09RHV02WYjL0G5aL05]KF`1VIVH0Ogmo09NGU`29RHT0
Ph>307AdM01RHV80OWin07QhN032`/80U9BD08R8R00U9BD071`L01lO7`0h>3P0DU9B02HV9P0L71`0
7alO079bLP0j>SX0<S8b04m?C`1aLG4208J6QP0@06QXJ00[:b/07AdM02HV9P0[:b/0=cLg02h^;P1g
MgL0V9RH09:BTP1RHV80=SHf02DU9@0W9bL0OGem024Q8@D05ADE028061PH01LG5`0I6AT0@d=3030`
<01QHF40YJFU09nOW`2UYJD0JFUY05eMG@0E5AD051@D014A4@0C4a<05ADE01<C4`0E5AD0A4A402h^
;P0c<c<0Ng]k0;6a/@2ATI40UiNG09JFUP2CTi<0RHV90;>c/`1@D500=cLg055AD@1IFET06QXJ0P0L
71`201TI6@0<0492@P2l_;`0emOG092@T016ATH0?3`l059BDP20P800H61P07MgM`0N7Qh051@D1@0E
5AD06P0n?Sh0<30`05ADE01UIFD0?Cdm07EeM@1<C4`0HF5Q020P800E5AD05aLG01/K6`0I6AT061PH
01/K6`1:BTX0:b/[024Q8@0T92@0=cLg055AD@0T92@0Fe]K02`/;00k>c/0<C4a0P0G5aL03`0L71`0
7alO02LW9`0d=3@0?Shn02d];@0K6a/06ATI01`L700R8R80?3`l07inOP2YZJT0bLW90;Ng]`02oooo
o`000?l0[Zj^05YJFP2/[:`0BDU909^KV`1YJFT0D51@08B4Q01JFUX0ADE50:n_[`1^KVh0=cLg05=C
D`2@T900<c<c07=cL`0m?Cd0IfMW08F5Q@0j>SX0Cdm?02XZ:P0O7al0NGUi059BDP0[:b/0F5QH075a
L@0c<c<0EEEE06a/K00c<c<0FUYJ07MgM`19BDT0I6AT03Ph>00_;bl0N7Qh06i^KP0i>CT0CDe=03Lg
=`0f=SH0>SXj05IFEP0U9BD0:RXZ07=cL`1dM7@0>SXj04a<C00b<S805ADE04U9B@1dM7@0C4a<02LW
9`1VIVH0>c/k02TY:@2TY:@0CDe=02TY:@0j>SX0JFUY03@d=01WIfL0UIFE069RHP0h>3P0@410069R
HP0d=3@05ADE06QXJ01SHf<0:b/[08F5Q@1^KVh07QhN04Y:BP1cLg<0=cLg07MgM`0b<S80N7Qh07Ui
N@0o?cl0:2PX0492@P1HF5P0?Shn03Ti>@2CTi<0X:2P0410@00j>SX0A4A4096AT@0_;bl0?3`l069R
HP1WIfL0FUYJ04=3@`23Ph<0RXZ:04E5A@1;Bd/0HF5Q04M7A`1_Kfl0H61P04Y:BP1UIFD0@T9209bL
W01FEUH0ATI605QHF01VIVH0HV9R08V9R@1XJ6P0?Cdm08Z:RP1`L700VIVI05]KF`0h>3P0IfMW07Ad
M01@D500Fe]K06e]K@1BDU80@d=306UYJ@1EEED0MGEe04m?C`1NGUh0FEUI030`<01GEeL0GEeM04=3
@`1dM7@0D51@06m_K`2?Shl0JFUY01lO7`1:BTX0RXZ:03hn?P23Ph<0>CTi03dm?@20P800@T9206=S
H`2PX:00G5aL02l_;`1gMgL0V9RH06a/K00Q8B40Hf=S04=3@`15ADD0OWin05QHF01;Bd/0FUYJ04A4
A02;Rh/0PX:205aLG01:BTX0`L7107moO`0a<C40Cdm?07QhN01IFET0?Cdm06IVIP2j^[X0S8b<03`l
?01/K6`0Ti>C061PH00k>c/0TY:B08n?S`1VIVH0GEeM08N7Q`1HF5P09bLW06m_K`1EEED0>SXj07Mg
M`1;Bd/0?clo07YjNP1mOGd0Fe]K096AT@1HF5P0DE5A07IfMP0b<S80?Cdm07alO01?Cdl0>3Ph07mo
O`0h>3P0:2PX04Y:BP1=CDd0I6AT04Q8B00X:2P0HV9R05QHF00o?cl0A4A40:6QX@2ATI40UIFE05=C
D`1HF5P0GUiN0492@P0T92@0NGUi07inOP14A4@0MGEe09>CT`1=CDd0C4a<075aL@2<S8`0@T9204i>
CP1cLg<00200KVi^06UYJ@21PH40[:b/065QH@12@T80;Bd]07alO01cLg<0CTi>065QH@1CDe<07AdM
04A4A01WIfL0GemO07inOP36a/H0Hf=S05mOG`2/[:`0UYJF05UIF@0S8b<0GemO04];B`0];Bd0;bl_
03hn?P2<S8`0GemO03Xj>P80/[:b03@0GemO03Ti>@1TI6@0MgMg05YJFP1TI6@0Cdm?05MGE`0d=3@0
FUYJ06a/K00n?Sh0KFe]075aL@0J6QX0JVYZ0<;2`P1MGEd0?clo08J6QP33`l<0BDU904Y:BP28R8P0
U9BD08B4Q010@4009RHV03<c<`1XJ6P0d=3@0=SHf03WinL0iNGU0=?Cd`34a<@0L71`03@d=00b<S80
YJFU0<[:bP35aLD0d=3@0<c<c02<S8`0Cdm?0451@@12@T80?Shn02/[:`0K6a/051@D0P0E5AD04`1^
KVh0Cdm?00h>3P0=3@d03Ph>010@400A4A404a<C055AD@1mOGd07alO014A4@0U9BD0F5QH0;jn_P2L
W9`09RHV01DE5@0D51@00P0E5AD04P0C4a<05ADE01DE5@0B4Q803Ph>014A4@0@410071`L04];B`24
Q8@0GUiN069RHP0`<30051@D010@400C4a<051@D01<C4`805ADE01<08b<S07EeM@1^KVh0SHf=09NG
U`31`L40X:2P04i>CP1FEUH0VYZJ04=3@`0e=CD0;bl_04m?C`1OGel0:RXZ02HV9P0/;2`05aLG0080
5ADE01005aLG01TI6@0Y:BT0EUIF06YZJP1WIfL0HV9R07EeM@2m_Kd0c<c<0;2`/02YZJT0O7al071`
L00g=cL07QhN0P0I6AT05P0L71`06a/K01hN7P0L71`07alO03Ph>01]KFd0@D5105UIF@1hN7P0AdM7
0410@01JFUX0XZ:R05]KF`0F5QH05aLG024Q8@0O7al07QhN02d];@1LG5`201DE5@0M01LG5`0F5QH0
92@T092@T018B4P0VYZJ0:6QX@15ADD0Bd];0<k>cP2HV9P0IVIV0:n_[`1fMWH0Hf=S04=3@`0g=cL0
<S8b02l_;`1LG5`0RXZ:07EeM@3;bl/0eMGE0=kNgP32`/80NGUi030`<00I6AT00P0E5AD03`0j>SX0
IVIV05ADE01kNg/0Ogmo0:ZZZP2MWId0gmoO08B4Q01oOgl0RHV905IFEP1VIVH0Lg=c06EUI@0206e]
K@0F07MgM`21PH40RHV906a/K02IVIT0X:2P0:FUY@3=cLd0PH6101/K6`0M7Ad0820P02PX:00h>3P0
7alO01dM7@0W9bL0Zj^[03Lg=`0/;2`0<30`05eMG@80De=C0100IFEU02h^;P0m?Cd0C4a<07UiN@1B
DU80CDe=09:BTP2i^KT0RXZ:07emO@1dM7@0IfMW07UiN@2DU9@07AdM0`0E5AD06@0D51@05ADE01TI
6@0N7Qh06ATI03lo?`0W9bL0Kfm_061PH01OGel0G5aL04e=C@1>CTh0FUYJ03Ph>00I6AT04a<C014A
4@0E5AD07AdM04M7A`0g=cL0JFUY08^;R`1:BTX00P0G5aL0700F5QH0:2PX07EeM@2m_Kd0C4a<02XZ
:P0c<c<0D51@061PH00[:b/06ATI01/K6`0N7Qh0E5AD0=;BdP2c/k<0BDU9034a<@0S8b<0BDU905AD
E01lO7`0U9BD03Lg=`0G5aL05ADE014A4@0B4Q8201DE5@0803/k>`0U9BD0=SHf065QH@1IFET0PH61
05QHF00^;Rh201DE5@0G01/K6`0I6AT05ADE01DE5@0J6QX0B4Q803De=@0S8b<09bLW03hn?P1HF5P0
:RXZ05aLG00_;bl0>CTi030`<00G5aL06a/K01`L700W9bL0=CDe03hn?P0g=cL00P0L71`0200J6QX0
6a/K01`L700Q8B40@T9208F5Q@2KVi/0clo?0_ooool0001]07YjNP1QHF40QXJ604=3@`1iNGT0CTi>
05EEE@23Ph<0<C4a03Lg=`27QhL0GUiN03@d=01<C4`0>SXj04];B`24Q8@0<c<c05eMG@1KFe/0?Shn
06YZJP1QHF40:b/[07YjNP15ADD0CTi>07alO01`L700;bl_055AD@1WIfL0820P0451@@1GEeL0@d=3
06YZJP1KFe/07QhN05aLG01MGEd0>CTi079bLP0m?Cd0A4A4034a<@1?Cdl0=SHf01HF5P18B4P0HF5Q
02/[:`1CDe<0@41001TI6@0h>3P0IVIV065QH@0a<C40OGem030`<00O7al0P82005UIF@0_;bl0Cdm?
079bLP17AdL0?Cdm06MWI`1JFUX0<c<c05iNGP1iNGT0@41002PX:01WIfL0A4A4020P8022PX80Kfm_
03Xj>P0d=3@0EeMG02`/;01^KVh0ATI607=cL`1^KVh0<S8b02LW9`1SHf<0SHf=04i>CP0Y:BT0K6a/
09BDU00d=3@0De=C07=cL`2KVi/0ATI602XZ:P1@D500@41004M7A`1JFUX0TY:B092@T00205YJFP1j
069RHP0/;2`0Ph>307]kN`1QHF40C4a<03@d=025QHD0KVi^04m?C`1KFe/0=SHf03`l?020P800Jf][
04e=C@1VIVH0?clo07QhN01TI6@0AdM708J6QP1;Bd/0>c/k059BDP1bLW80HF5Q05EEE@1IFET0:b/[
075aL@1QHF40I6AT04e=C@0M7Ad0Fe]K07alO014A4@0HF5Q03@d=017AdL0M7Ad07QhN00_;bl0Cdm?
06m_K`0`<300Kfm_0410@01>CTh0MgMg02XZ:P0k>c/0L71`04i>CP0e=CD0Hf=S059BDP0d=3@0;Bd]
07QhN01CDe<0?3`l08>3P`19BDT0Kfm_07UiN@0e=CD0EeMG04=3@`0n?Sh0IfMW0=3@d01bLW80>c/k
03Xj>P1]KFd0F5QH038b<P1cLg<0Y:BT08>3P`0i>CT0KVi^0:FUY@1ZJVX0;Bd]09VIV@1fMWH0C4a<
06EUI@2CTi<0?Shn03Xj>P24Q8@0NWYj03@d=01EEED092@T06UYJ@1lO7`0KVi^069RHP2EUID0?clo
04M7A`2GUiL0DU9B051@D029RHT0EeMG05aLG02_[jl0IFEU03hn?P1FEUH0BDU905UIF@0b<S80>c/k
09BDU01fMWH205=CD`1G0;Rh^01lO7`0MGEe03Hf=P1_Kfl0Ogmo03Lg=`0];Bd0QhN706IVIP1:BTX0
QHF508R8R01EEED0Cdm?05YJFP1`L700<c<c06IVIP2QXJ40Jf][061PH028R8P0/;2`04Q8B00b<S80
EeMG0:j^[P22PX80D51@06MWI`0e=CD08b<S05aLG01PH600CDe=08:2PP39bLT0ATI606e]K@2_[jl0
V9RH04];B`0U9BD0I6AT03`l?01CDe<0ATI603/k>`25QHD0?Shn03Ti>@39bLT0a/K607UiN@1=CDd0
OGem07QhN01TI6@0QhN705]KF`1/K6`0ATI606IVIP1`L700AdM706i^KP1QHF40@41003De=@1bLW80
Jf][04M7A`1eMGD0`<3002LW9`0T92@0@D51069RHP24Q8@0BTY:02XZ:P0e=CD0IfMW0:BTY03De=@0
i^KV0080j^[Z02D0inOW0=cLg038b<P0`l?30>;RhP3Hf=P0c<c<0<C4a02^[Zh0ATI605EEE@1kNg/0
L71`06e]K@1KFe/0D51@03`l?00L71`05ADE09:BTP1]KFd061PH01@D500F5QH0820P03De=@1WIfL0
SXj>0;Bd]02<S8`0G5aL07moO`18B4P0];Bd0<[:bP0N7Qh051@D00H05ADE00/04a<C00h>3P0A4A40
4Q8B04=3@`1>CTh0Fe]K02PX:00o?cl0GemO038b<P0201DE5@1M014A4@0C4a<05ADE01DE5@0_;bl0
7QhN04Q8B03=cLd0]kNg09jNWP2EUID0IFEU05MGE`1JFUX0M7Ad01lO7`0E5AD05aLG02@T901HF5P0
CTi>02LW9`0/;2`09RHV03Hf=P15ADD0CTi>03Xj>P0N7Qh06QXJ08^;R`3AdM40/;2`0;bl_02d];@0
Xj>S08V9R@1NGUh0I6AT07UiN@1TI6@0?clo0451@@1:BTX0B4Q804i>CP1?Cdl0>SXj02PX:01IFET0
L71`07IfMP34a<@0/k>c096AT@2HV9P0WIfM09jNWP1:BTX0820P02/[:`0j>SX0BDU909fMW@2=SHd0
>CTi0410@016ATH0Cdm?08b<S02][Jd0^[Zj0=cLg03Cdm<0`<300<o?c`3EeMD0`/;20;jn_P30`<00
P82006EUI@2;Rh/0R8R805YJFP1cLg<0VIVI07EeM@2o_kl0SXj>07MgM`3Kfm/0BDU900805aLG0`0E
5AD0>@0J6QX0FUYJ08n?S`3AdM40g]kN0;:b/P35aLD0dM7A05]KF`1QHF40EEEE04A4A016ATH0=SHf
024Q8@0L71`06a/K01lO7`0_;bl0GEeM0:ZZZP2i^KT0dM7A0<c<c03?cll0][Jf06UYJ@1CDe<0F5QH
06EUI@1SHf<0J6QX04];B`15ADD0]KFe06e]K@0X:2P0<C4a02`/;01?Cdl0>c/k06YZJP1=CDd0<c<c
08Z:RP1HF5P0=CDe04i>CP25QHD0U9BD0<o?c`2c/k<0ZZZZ0:^[Z`2d];@0Y:BT02d];@0401DE5@0@
01TI6@0L71`0820P01lO7`1QHF40AdM7065QH@12@T80PH6104Q8B00X:2P0:BTY02`/;00o?cl0DU9B
0410@0805ADE00H0<30`04I6AP2ATI40[Zj^071`L00e=CD301<C4`0U02PX:02JVYX0aLG506][J`0d
=3@0=SHf03Ph>010@400Ng]k061PH00Y:BT09bLW09VIV@2a/K40V9RH055AD@0_;bl0>3Ph05aLG00g
=cL0M7Ad03Lg=`1EEED0CTi>0451@@0U9BD05ADE01PH600E5AD0>CTi02DU9@0X:2P0D51@07=cL`2Y
ZJT0DE5A01PH600201DE5@0Q01HF5P0I6AT06a/K01PH600L71`0EEEE05IFEP0a<C4092@T0410@01e
MGD0>CTi05eMG@0j>SX0>3Ph02d];@0E5AD06a/K02<S8`0d=3@0>SXj0492@P0U9BD071`L01TI6@0L
71`06a/K01dM7@0P8200>CTi06e]K@2PX:00dM7A00;ooooo00003@2LW9`0F5QH09BDU013@d<0O7al
0451@@1<C4`0O7al04U9B@11@D40RXZ:04I6AP1;Bd/00P1oOgl0k`0f=SH0FUYJ03<c<`1MGEd0@T92
01`L700m?Cd0;bl_0410@01PH600;2`/02PX:012@T80=CDe03Ph>01RHV80NWYj03Ph>01EEED0?Shn
038b<P1hN7P0HF5Q02`/;01fMWH0AdM7028R8P17AdL0C4a<04=3@`0T92@0EeMG03lo?`0M7Ad0A4A4
04a<C00M7Ad0D51@05EEE@0i>CT0?Cdm05IFEP0l?3`0=CDe09ZJVP1=CDd08B4Q09JFUP0n?Sh092@T
04a<C01[Jf/0Cdm?03dm?@1GEeL0C4a<01dM7@0Z:RX0EeMG04Q8B00Z:RX0GUiN059BDP0f=SH0QhN7
08F5Q@18B4P0=cLg06MWI`0Y:BT0JFUY05QHF02TY:@0Kfm_04M7A`0/;2`0AdM7059BDP1OGel09BDU
079bLP2<S8`09RHV03hn?P1SHf<0PX:203lo?`0/;2`0E5AD04I6AP0o?cl0B4Q8071`L02DU9@0H61P
05QHF01[Jf/0?clo07IfMP1YJFT0E5AD07UiN@1FEUH0QXJ606e]K@1?Cdl0DE5A06m_K`1LG5`0Ng]k
05eMG@1ADE40UYJF07EeM@2GUiL0I6AT0492@P1lO7`0MGEe055AD@18B4P0M7Ad06ATI01@D500JVYZ
05iNGP21PH40Fe]K06IVIP1RHV80?Cdm06i^KP2>SXh0De=C075aL@0h>3P0IVIV08^;R`1YJFT07alO
05]KF`1[Jf/0=SHf08B4Q00c<c<0De=C07UiN@0^;Rh0?Shn06m_K`0l?3`0=CDe06IVIP1@D500:RXZ
01dM7@1XJ6P0D51@03@d=015ADD0CTi>05EEE@1OGel0?3`l075aL@1QHF40GEeM06UYJ@3Cdm<0G5aL
0451@@0k>c/0Ng]k065QH@0m?Cd0HF5Q0::RXP2?Shl0@D51075aL@2e]KD0RXZ:03De=@2g]kL0Ogmo
051@D01lO7`0S8b<03De=@0T92@0Shn?08Z:RP0g=cL0DE5A02XZ:P0e=CD0EUIF05YJFP22PX80OWin
04e=C@1<C4`0KFe]0451@@1CDe<0OWin04I6AP0n?Sh0QHF505eMG@11@D40EEEE04Y:BP1PH600CTi>
02`/;01@D500J6QX06MWI`1KFe/0aLG508^;R`1fMWH0<S8b04];B`1HF5P0:RXZ02DU9@1kNg/0;Bd]
03lo?`1cLg<0R8R804i>CP1?Cdl0DU9B069RHP0Y:BT0CTi>0080JFUY02l0FUYJ0:FUY@3<c<`0FEUI
02l_;`0h>3P0UYJF07YjNP1;Bd/0HF5Q04m?C`0Z:RX0?3`l04];B`17AdL0PH610<W9b@1WIfL0I6AT
0:6QX@2CTi<0EEEE028R8P1PH600DE5A06QXJ015ADD0CTi>09NGU`16ATH0>3Ph08b<S02XZ:P0LG5a
05QHF02OWil0LW9b02PX:01iNGT0IfMW06UYJ@1>CTh0Ogmo05]KF`0a<C40OGem08j>SP0203`l?015
08J6QP21PH40EeMG0861P@2XZ:P0ATI6030`<01DE5@0GUiN08V9R@0n?Sh0;Rh^0451@@1mOGd0`<30
0;Rh^038b<P0h^;R0>WYj@3Vi^H0bl_;08n?S`2XZ:P0fm_K0=OGe`1MGEd0XJ6Q0;Jf]P2ZZZX0F5QH
0410@015ADD0De=C06][J`2@T900SXj>0820P01lO7`0b<S80;^k^`20P800MWIf06a/K01WIfL0DU9B
030`<00P8200>SXj05iNGP1KFe/0WIfM06m_K`2i^KT0clo?05MGE`1MGEd0BTY:03@d=00];Bd08B4Q
01`L700I6AT051@D01<C4`0G5aL0=SHf04];B`12@T80:BTY00806ATI01D0=CDe06MWI`0[:b/05ADE
01@D500C4a<05ADE02<S8`0X:2P06QXJ02PX:02/[:`0S8b<075aL@1KFe/0QXJ604E5A@0/;2`0CDe=
055AD@0G5aL00P0E5AD0<00I6AT0>3Ph08N7Q`1lO7`0Ogmo06EUI@0`<3006a/K01HF5P0E5AD0:2PX
09JFUP1PH600Z:RX0;6a/@2l_;`0ZJVY0::RXP2CTi<0Ng]k05UIF@1;Bd/0BTY:03`l?00^;Rh06ATI
01dM7@0Y:BT0?clo04M7A`18B4P0NGUi07MgM`2UYJD0Ph>307inOP2IVIT0YJFU0<71`@3AdM40QHF5
07emO@2=SHd0Q8B40<k>cP32`/80QhN707IfMP80Lg=c0100YZJV0;no_`3?cll0gMgM0:JVYP1cLg<0
P8200;Fe]@2YZJT0BDU902<S8`0I6AT08R8R04a<C01CDe<0HF5Q0P21PH401`32`/80a/K608F5Q@1<
C4`0a/K602LW9`0G5aL0100E5AD0>P0H61P07AdM07MgM`3QhN40gmoO0>OWi`2g]kL0alO707QhN019
BDT0:RXZ01hN7P0L71`08b<S03De=@0N7Qh07AdM01/K6`0I6AT07QhN059BDP2LW9`0alO7096AT@1d
M7@0E5AD04U9B@0m?Cd0>CTi03@d=013@d<0=SHf020P800O7al0F5QH0;fm_@19BDT09bLW02DU9@0m
?Cd0EEEE092@T02TY:@0[Jf]055AD@17AdL0CDe=06QXJ01WIfL0RHV90;:b/P1LG5`0EUIF0492@P0c
<c<0O7al06IVIP0I6AT201DE5@0H02LW9`0O7al06QXJ01dM7@13@d<0NGUi08Z:RP1PH600AdM706=S
H`1oOgl0=cLg024Q8@0Z:RX0;Rh^030`<017AdL0IfMW03Ph>01:BTX0SHf=0<S8b021PH40EEEE0P0M
7Ad0300E5AD051@D02l_;`2FUYH0hn?S0<o?c`34a<@0/k>c0861P@11@D40?Cdm06][J`80VYZJ00T0
a<C40:ZZZP35aLD0/;2`0;^k^`3?cll0dm?C0:VYZ@2NWYh00P0E5AD00`0K6a/0>CTi05iNGP0205iN
GP0903dm?@0j>SX0J6QX03hn?P29RHT0[jn_06][J`16ATH0=cLg00805QHF01L05ADE01LG5`0J6QX0
7alO02PX:022PX80Z:RX06i^KP14A4@0FUYJ09>CT`0h>3P0KVi^04I6AP0k>c/0?Shn024Q8@0S8b<0
<c<c0410@012@T80:RXZ01/K6`0301`L700701XJ6P0S8b<0A4A407IfMP2OWil0[jn_0=7Ad@02oooo
o`000;P0ZZZZ061PH02KVi/0@d=309VIV@1NGUh0EeMG08f=S@1:BTX0@D510:2PX01HF5P0<C4a04i>
CP1mOGd0?clo06ATI00W9bL0HF5Q079bLP0Y:BT0>c/k03Ti>@0`<300OWin05IFEP0l?3`0B4Q8055A
D@0X:2P0ATI605EEE@0V9RH0DE5A05QHF00h>3P0GEeM05iNGP0c<c<0I6AT071`L00e=CD0De=C04I6
AP0k>c/0BTY:08^;R`0o?cl071`L0451@@1[Jf/0>CTi04A4A00j>SX092@T03Ph>01PH600Fe]K02l_
;`2MWId0=cLg02DU9@2;Rh/0HV9R02l_;`18B4P0MgMg04];B`0h>3P0IVIV05iNGP0b<S80ATI606MW
I`16ATH07alO06YZJP1SHf<0<c<c08b<S01nOWh0BTY:03Ti>@1cLg<0>CTi06a/K014A4@0QhN707=c
L`10@400:BTY04i>CP1GEeL0HV9R02/[:`2:RXX0U9BD03dm?@1:BTX0DE5A0:b/[01=CDd0:2PX05MG
E`1?Cdl0EEEE05ADE01lO7`0VIVI05aLG01eMGD0OWin0451@@1hN7P0GUiN05eMG@22PX80HF5Q07If
MP1HF5P0E5AD05MGE`1LG5`0FEUI07moO`16ATH0DE5A09:BTP1lO7`0WYjN05IFEP1?Cdl0KVi^06UY
J@1?Cdl0CDe=07EeM@1UIFD0EeMG07AdM01IFET0P82004e=C@1[Jf/0GEeM03Hf=P1eMGD0S8b<06QX
J01^KVh0@d=307IfMP28R8P0IFEU028R8P1YJFT0N7Qh03Ph>023Ph<0?3`l07MgM`2FUYH0AdM703`l
?01VIVH0GEeM04U9B@1XJ6P0GUiN03dm?@0P8200L71`04m?C`0i>CT0De=C05QHF01ZJVX0LG5a04U9
B@21PH40HV9R06e]K@21PH40fMWI0P1GEeL0OP0g=cL0VYZJ08j>SP0j>SX0C4a<0:ZZZP1gMgL0B4Q8
08B4Q02`/;00M7Ad03Hf=P2o_kl0DE5A038b<P1gMgL0Ph>303Ph>00[:b/0];Bd092@T013@d<0O7al
03Ti>@0m?Cd0FUYJ04M7A`1MGEd0NWYj04i>CP1PH600LW9b020P801IFET0NWYj04Y:BP11@D40OGem
051@D00l?3`0DU9B04];B`1aLG40G5aL03`l?01JFUX0G5aL05QHF01`L700a<C40;Fe]@2ATI40FUYJ
08J6QP22PX80AdM702/[:`2HV9P0K6a/04E5A@2;Rh/0ZZZZ05MGE`1:BTX0JFUY08B4Q00f=SH0GUiN
07moO`1CDe<0ADE507]kN`2XZ:P0CDe=02DU9@15ADD0Ti>C04U9B@1@D500PH6104I6AP0S8b<0BDU9
03lo?`0_;bl0IVIV0<G5a@1@D500K6a/0;6a/@1aLG40A4A403@d=027QhL0FEUI06UYJ@15ADD0H61P
08>3P`1=CDd0=cLg08Z:RP2b/[80E5AD065QH@2][Jd0Ng]k03Ph>01/K6`0@D5102DU9@1=CDd0Ogmo
071`L00i>CT0LG5a06][J`0d=3@0GemO0:FUY@1KFe/0;bl_08B4Q025QHD0<c<c03De=@80J6QX01/0
L71`02`/;00e=CD0C4a<06ATI01cLg<0e=CD0=;BdP3YjNT0i^KV0;Bd]02/[:`0HF5Q08Z:RP3AdM40
eMGE0;Bd]010@400O7al0;jn_P2CTi<0DU9B0492@P0k>c/0ADE504m?C`1_Kfl00P3;bl/01@2=SHd0
8b<S01TI6@0D51@05ADE00805aLG00`07alO024Q8@0S8b<0<C4a02h^;P1WIfL0NWYj0=GEe@3Jf]X0
T92@08j>SP29RHT208Z:RP0:071`L01WIfL0GUiN05aLG01UIFD0S8b<08N7Q`1IFET0G5aL01XJ6P80
5aLG01d06ATI02`/;01OGel0:BTY01DE5@0C4a<06a/K02XZ:P0I6AT07AdM03<c<`2@T900O7al0451
@@0Q8B40;2`/04E5A@1HF5P0<c<c04Y:BP1;Bd/06a/K01`L700c<c<0ATI607IfMP1XJ6P0>3Ph02DU
9@0301DE5@0d02DU9@1`L700F5QH030`<01aLG40^KVi0<30`02f][H0QXJ607EeM@1jNWX0RHV903lo
?`0l?3`0>SXj04M7A`1BDU80BTY:03Lg=`0T92@07alO01dM7@1nOWh0]KFe09BDU01OGel0WinO09RH
V02FUYH0N7Qh09JFUP2?Shl0Z:RX0:b/[030`<00b/[:05aLG01EEED0DU9B05EEE@1MGEd0MWIf0<;2
`P2PX:00a<C40:BTY018B4P0H61P0<30`03Bd]80>SXj01HF5P805ADE00<05aLG01XJ6P0S8b<00P1K
Fe/01`2QXJ40_kno092@T01IFET0Y:BT02LW9`0H61P00P0G5aL0500H61P05QHF01XJ6P0L71`0DE5A
0<K6aP38b<P0gMgM09NGU`2NWYh0>SXj028R8P0U9BD07AdM01HF5P0J6QX07AdM02TY:@0O7al07AdM
0P0L71`0D`0^;Rh0C4a<09:BTP2j^[X0ZZZZ08f=S@0Y:BT071`L02LW9`0/;2`0?3`l01/K6`0F5QH0
6ATI020P801oOgl0/;2`04I6AP0/;2`0:b/[06MWI`2:RXX0WYjN08B4Q01NGUh0ADE5038b<P0X:2P0
6a/K02d];@1JFUX0E5AD0451@@14A4@0@D5103<c<`2@T900BDU901dM7@0D51@08B4Q01dM7@0L71`0
<C4a05YJFP13@d<0B4Q803Hf=P1eMGD0Q8B40;:b/P1fMWH0=cLg02TY:@0V9RH0>SXj051@D015ADD0
Shn?0;Fe]@36a/H0Xj>S05eMG@0Z:RX071`L01lO7`0E5AD092@T06e]K@34a<@0e]KF0>CTi03Zj^X0
inOW0>GUi@2KVi/0P82005mOG`2CTi<0f][J0<?3``3IfMT0KVi^0080Lg=c00H0Zj^[0<[:bP35aLD0
]kNg01dM7@0D51@201DE5@0<01@D500K6a/0<S8b05ADE01iNGT0YZJV0;6a/@2e]KD0LW9b03<c<`11
@D40C4a<0`0G5aL01P0K6a/06QXJ03Hf=P1MGEd0Ph>309NGU`80X:2P00`0]kNg0;jn_P1SHf<0P820
079bLP1BDU80HV9R04];B`10@400Cdm?05]KF`0`<30201dM7@0:01`L700l?3`0<30`04Q8B01/K6`0
M7Ad05ADE01PH600Ogmo09RHV0;ooooo0000DP2h^;P0IFEU09VIV@12@T80V9RH05eMG@1NGUh0PX:2
04U9B@1:BTX0Zj^[06MWI`11@D40KFe]08^;R`11@D40NWYj03@d=01oOgl0OGem02TY:@17AdL0GUiN
03Ti>@2ATI40Fe]K03Lg=`1=CDd0LG5a04U9B@1QHF40G5aL02DU9@1CDe<0I6AT04E5A@1IFET0De=C
034a<@1SHf<0IVIV03Hf=P1@D500?clo03/k>`1<C4`0VYZJ03dm?@0I6AT0>SXj06][J`0c<c<0C4a<
03De=@0M7Ad0=3@d06EUI@1mOGd0=cLg09^KV`0f=SH09BDU07inOP1EEED0;bl_04Y:BP1aLG40@T92
03<c<`1[Jf/0Fe]K038b<P1>CTh0HF5Q02LW9`0G5aL0J6QX06UYJ@0d=3@0RHV906EUI@0m?Cd206a/
K00V0451@@1YJFT0<c<c09RHV01jNWX0>c/k028R8P1@D500E5AD04Q8B00U9BD0RXZ:096AT@0l?3`0
EEEE05aLG02`/;00@D5103<c<`1SHf<0Jf][05eMG@1KFe/0QhN7092@T01CDe<0Jf][07inOP0n?Sh0
QhN705IFEP1cLg<0KFe]05ADE01dM7@0ATI606ATI01MGEd204U9B@3o07MgM`0k>c/0?clo06m_K`23
Ph<0WinO04e=C@0o?cl0MGEe07IfMP1:BTX0DE5A06e]K@16ATH0I6AT07QhN01HF5P0Rh^;04Q8B025
QHD0IFEU03De=@1nOWh0Lg=c06QXJ02>SXh0F5QH06i^KP28R8P0JVYZ02`/;029RHT0OWin03Lg=`28
R8P0ADE505iNGP1RHV80ATI603Ti>@1^KVh0GemO03lo?`29RHT0TI6A05UIF@0M7Ad0NGUi06m_K`1@
D500EEEE069RHP1gMgL0LG5a04Q8B020P800M7Ad08F5Q@29RHT0e=CD05YJFP1CDe<0F5QH0:RXZ02=
SHd0A4A405QHF02CTi<0JVYZ03@d=01ZJVX0WIfM07UiN@0m?Cd0`/;205IFEP16ATH0Ph>308n?S`19
BDT0=3@d0;Zj^P1VIVH0?clo06e]K@0Z:RX0BDU9071`L01QHF40K6a/09NGU`1@D500PH6108R8R00S
8b<0NWYj08j>SP1@D500B4Q808J6QP0j>SX0@D5106e]K@1`L700Rh^;0492@P1DE5@0R8R807AdM00l
?3`0BDU908^;R`1SHf<0LG5a03<c<`2IVIT0Zj^[04E5A@1;Bd/0[:b/07EeM@1HF5P0WYjN09ZJVP0h
>3P0EEEE08N7Q`1HF5P09bLW065QH@1/K6`0PH6105UIF@1`L700X:2P038b<P0F5QH0JVYZ0::RXP1P
H600=3@d069RHP0l?3`09bLW06QXJ011@D408R8R05eMG@2a/K40>CTi06][J`32`/80Ogmo03Hf=P0O
7al0GEeM04=3@`1XJ6P0ATI607inOP2?Shl0Cdm?03Xj>P20P800Zj^[03hn?P1DE5@0TY:B06=SH`0f
=SH0Q8B404Q8B01>CTh0@d=3055AD@1dM7@0>c/k08:2PP1gMgL061PH05EEE@2VYZH0TI6A05EEE@29
RHT0V9RH03`l?00f=SH0QXJ609:BTP20P800=SHf030`<00Y:BT0EUIF04A4A02h^;P0emOG0>CTi03M
gMd0Fe]K06ATI01lO7`0aLG50<o?c`3@d=00b<S809JFUP1NGUh0UIFE0<30`01aLG40>c/k04e=C@1K
Fe/0FEUI05mOG`25QHD0`/;20:VYZ@0l?3`05aLG01@D500G5aL06a/K01XJ6P0F5QH06QXJ01lO7`0e
=CD0@D5104Y:BP2f][H0d=3@096AT@2YZJT0W9bL07EeM@2<S8`0[Zj^07AdM020P800Lg=c061PH01V
IVH0KFe]07]kN`38b<P0DE5A01PH600F5QH05aLG01DE5@0G5aL0=cLg002f06YZJP0a<C408b<S03dm
?@0P82007alO03Ph>01EEED0OGem09JFUP0k>c/08b<S01LG5`0E5AD0;2`/06][J`1MGEd0Ogmo071`
L012@T808b<S01LG5`0E5AD0?Cdm04e=C@0l?3`0JFUY05IFEP1EEED0C4a<06UYJ@16ATH0RXZ:0:f]
[@2LW9`0Xj>S0:2PX01mOGd0GEeM04Y:BP1ADE40GUiN04Q8B00o?cl0<C4a02XZ:P0^;Rh0=cLg04U9
B@1ADE40Lg=c05mOG`3De=@0N7Qh04E5A@1XJ6P0[Jf]0;^k^`2o_kl0NGUi09jNWP3?cll0UIFE0<W9
b@2i^KT0De=C04Y:BP0l?3`0>3Ph034a<@0];Bd0[jn_06MWI`22PX80/;2`075aL@2HV9P0];Bd0:n_
[`1_Kfl05QHF01DE5@0I6AT06a/K01TI6@0M7Ad0<S8b07]kN`1nOWh0Zj^[0:FUY@25QHD0WinO04A4
A00U9BD07alO01dM7@0I6AT071`L01hN7P1DE5@0QhN70:RXZ02k^k/0]KFe07UiN@22PX80820P01hN
7P0R8R807QhN01PH600K6a/06QXJ01TI6@0Z:RX092@T01XJ6P0L71`09bLW0451@@2IVIT0XJ6Q065Q
H@2m_Kd0EeMG01PH600M7Ad0:BTY03`l?00K6a/06QXJ01/K6`0M7Ad0=3@d06YZJP2JVYX0DU9B03Lg
=`1<C4`0LW9b06m_K`2GUiL0=cLg01HF5P0C4a<05ADE01HF5P0L71`09bLW05QHF00S8b<0@d=304];
B`10@400O7al0:VYZ@1YJFT0=3@d02PX:00I6AT08b<S069RHP1lO7`0@41002h^;P0N7Qh09RHV06e]
K@3:b/X0PH6106EUI@1dM7@0N7Qh079bLP26QXH0VYZJ0<g=c@3:b/X0g]kN0:j^[P1SHf<201/K6`08
02DU9@13@d<0N7Qh06QXJ019BDT0Cdm?0;:b/P3Kfm/20>[ZjP0@0>CTi03>c/h0a<C40=3@d033`l<0
d=3@0:b/[02j^[X0H61P04=3@`2?Shl0`/;205mOG`1dM7@0DU9B01HF5P805ADE02l051@D01DE5@0E
5AD06QXJ06IVIP14A4@0Ng]k0::RXP1dM7@07alO03Ph>01ADE40<30`01/K6`0O7al0;bl_04e=C@1F
EUH0B4Q804Y:BP1YJFT0_Kfm09:BTP2GUiL0a/K60:>SX`2UYJD0ZZZZ08R8R02YZJT0WinO08B4Q02;
Rh/0CDe=02PX:00S8b<0:RXZ02PX:01QHF40MGEe069RHP0_;bl09RHV04a<C01aLG40V9RH07]kN`02
ooooo`0008D0`<3006UYJ@27QhL0ADE508b<S01GEeL0H61P07AdM00b<S80ADE5096AT@1EEED0?Shn
07QhN01oOgl0?clo07moO`0_;bl0Ogmo07MgM`0R8R80De=C04];B`0k>c/0T92@051@D00i>CT0BDU9
05]KF`15ADD0Jf][05ADE00Y:BT0MGEe05mOG`11@D40D51@04A4A017AdL0RHV906YZJP0f=SH0DU9B
03Ph>00e=CD0ADE508:2PP0_;bl07alO04Q8B01PH600=CDe05UIF@0_;bl05ADE03De=@1^KVh0MGEe
034a<@2>SXh09BDU03Xj>P2=SHd0EUIF02h^;P1>CTh0HF5Q0492@P1BDU80QhN705YJFP0_;bl0FEUI
079bLP0h>3P09BDU05eMG@1KFe/0>CTi09NGU`1bLW80?Shn05MGE`1QHF40ATI60861P@0d=3@0R8R8
071`L00b<S808R8R05]KF`1HF5P0GEeM01lO7`2;Rh/0QXJ6034a<@1ZJVX0U9BD0:b/[00h>3P08b<S
04m?C`1GEeL0>c/k075aL@2TY:@0W9bL07]kN`1TI6@0PH6103Hf=P2RXZ80MGEe071`L01@D500EeMG
0::RXP1TI6@0CTi>05aLG00b<S80;bl_07EeM@1BDU80B4Q804=3@`14A4@0TI6A06i^KP0e=CD0JFUY
0080ADE50600JFUY09FEU@1RHV80Cdm?055AD@0V9RH0UYJF06EUI@1NGUh0C4a<03Hf=P2HV9P0Ng]k
051@D01]KFd09RHV06YZJP2ZZZX0OWin02HV9P1ZJVX0DU9B03Xj>P2JVYX0DU9B08>3P`1NGUh0:b/[
03dm?@1kNg/0H61P03dm?@1GEeL0CDe=04A4A00M7Ad0M7Ad03Lg=`1CDe<0EUIF05eMG@1kNg/0GUiN
02TY:@1[Jf/0IfMW06][J`1TI6@0clo?04a<C00h>3P0Lg=c09nOW`26QXH0?3`l04Y:BP2@T900SXj>
0410@01]KFd0Z:RX051@D00d=3@0bLW907moO`15ADD0S8b<08n?S`0M7Ad0=CDe0:VYZ@1eMGD0@T92
07IfMP0^;Rh0L71`09JFUP1UIFD0Ogmo0:2PX00o?cl0K6a/09RHV017AdL0GemO06EUI@0X:2P0K6a/
0:VYZ@1EEED0>CTi04U9B@1:BTX0Jf][02d];@1BDU820861P@0h05aLG01XJ6P0YZJV0861P@1^KVh0
9RHV071`L01fMWH0;bl_034a<@1jNWX0;Rh^06MWI`2a/K40XJ6Q04m?C`0n?Sh0MgMg05mOG`0X:2P0
CTi>04];B`27QhL0Hf=S07AdM02VYZH0OWin02l_;`1>CTh0TI6A069RHP0b<S80KVi^038b<P0M7Ad0
EEEE05MGE`0a<C40Cdm?0:j^[P0N7Qh0?Shn0861P@26QXH0AdM701dM7@1LG5`0E5AD04I6AP0^;Rh0
RHV90::RXP1hN7P0ATI609:BTP2b/[8207=cL`1=0:VYZ@21PH40BDU90:f][@2<S8`0CTi>04=3@`1F
EUH0MWIf0492@P1lO7`0QHF5030`<00n?Sh0NWYj08Z:RP1DE5@0Ph>30;Bd]00Q8B40;Bd]055AD@1Y
JFT0OWin03/k>`0g=cL0<C4a06QXJ013@d<0SXj>07YjNP2b/[80d=3@09jNWP2k^k/0cLg=0;Bd]01c
Lg<0]kNg0<?3``2g]kL0MgMg05iNGP2=SHd0/[:b051@D00I6AT051@D01<C4`0E5AD09BDU07moO`27
QhL0?3`l04E5A@0e=CD092@T01XJ6P0G5aL05QHF01DE5@0[:b/0<c<c01PH601FEUH0dm?C0:f][@21
PH40MgMg02PX:00H61P08B4Q02l_;`0c<c<0>CTi03Lg=`0c<c<00P0`<3005P0^;Rh0MgMg08N7Q`1>
CTh0820P01LG5`0F5QH05ADE01TI6@0n?Sh0VYZJ05aLG00a<C40:2PX03Xj>P1HF5P0QHF508j>SP1V
IVH0?clo03/k>`0S8b<201DE5@1202DU9@1gMgL0Cdm?05]KF`0E5AD04A4A01<C4`0A4A405ADE03Xj
>P1XJ6P0KFe]02/[:`0/;2`0ATI608B4Q01CDe<0M7Ad07YjNP2NWYh0XZ:R07UiN@1bLW80B4Q804U9
B@1EEED0IfMW06EUI@1RHV80DE5A03Xj>P0_;bl0:BTY02PX:00`<300N7Qh071`L03Lg=`0PX:202l_
;`0i>CT0HV9R0<_;b`3De=@0YZJV09>CT`2NWYh0[Jf]09:BTP1gMgL0QHF506m_K`10@400;bl_024Q
8@0^;Rh0Z:RX06ATI01KFe/0Hf=S0<G5a@2=SHd0MGEe08f=S@2EUID0=SHf0P0K6a/0600N7Qh0:BTY
0410@01DE5@0WIfM08N7Q`22PX80ADE505iNGP2<S8`0A4A4061PH01GEeL0>SXj03/k>`0g=cL08B4Q
05aLG02PX:00[Jf]0::RXP2DU9@0MGEe07MgM`807AdM00@06a/K01PH600G5aL06ATI0P0E5AD07`0P
8200<30`020P800L71`0:2PX04i>CP2TY:@0J6QX03De=@2XZ:P0XJ6Q024Q8@0M7Ad0;2`/038b<P0S
8b<07AdM01/K6`0F5QH06ATI02/[:`1dM7@0XZ:R09:BTP2^[Zh0_[jn04i>CP1KFe/08B4Q018B4P0A
4A400P0E5AD0K`0I6AT0:2PX0:2PX01VIVH0C4a<05UIF@1VIVH0OGem0;>c/`2BTY80J6QX07inOP1e
MGD0QXJ609bLW00j>SX0;bl_034a<@0n?Sh0;Bd]04Y:BP2;Rh/0IVIV05=CD`12@T80ATI604Q8B01M
GEd0[:b/0<W9b@3Lg=`0i>CT0<S8b01TI6@07AdM03<c<`1bLW80GEeM02@T900B4Q8061PH02DU9@0j
>SX0Zj^[0=oOg`3Rh^80b<S808Z:RP1LG5`0Z:RX0<;2`P2][Jd0:2PX03Lg=`2EUID0L71`05YJFP2H
V9P0B4Q804M7A`1kNg/0?clo01LG5`0H61P07alO03Hf=P1=CDd0EUIF07=cL`2OWil0UIFE09fMW@1g
MgL06ATI04A4A01GEeL0SHf=05UIF@1UIFD0Fe]K03lo?`0l?3`0<C4a02`/;00o?cl0EUIF065QH@2[
Zj/0^[Zj08N7Q`2VYZH0V9RH0:VYZ@2h^;P0_Kfm0<k>cP2/[:`0=3@d03Ph>01;Bd/0GemO05UIF@16
ATH09bLW024Q8@0W9bL0Bd];06MWI`29RHT0KVi^08R8R002ooooo`0001H0[:b/07QhN026QXH0@D51
065QH@0i>CT0Fe]K08B4Q00o?cl0Bd];07UiN@0c<c<0Cdm?09>CT`1FEUH0H61P08f=S@0^;Rh0Lg=c
075aL@0Q8B40J6QX0P19BDT0C`2;Rh/0BTY:030`<01ADE40EEEE0492@P1[Jf/0>c/k02LW9`1MGEd0
=cLg04i>CP1lO7`0;bl_034a<@1eMGD0>c/k03Lg=`1^KVh0;bl_04E5A@0_;bl0P82002DU9@0Y:BT0
J6QX04];B`0b<S80M7Ad04U9B@0I6AT0CDe=06UYJ@1QHF40:b/[08R8R00i>CT0=CDe08V9R@0g=cL0
=CDe07AdM01VIVH0=3@d02h^;P1FEUH0BTY:01hN7P1BDU80Hf=S04Q8B00f=SH0LG5a04Y:BP0c<c<0
KVi^06a/K00f=SH0J6QX04A4A018B4P0IFEU04];B`2CTi<0R8R803dm?@0_;bl0K6a/06=SH`1OGel0
7alO08n?S`1FEUH071`L05IFEP1/K6`0UYJF03`l?00T92@00P1DE5@0U016ATH0MWIf07emO@24Q8@0
QhN706m_K`1ZJVX0<C4a07IfMP1GEeL0IFEU05YJFP1HF5P0VYZJ05EEE@1=CDd0IfMW07EeM@17AdL0
M7Ad04Y:BP1=CDd0U9BD07EeM@2DU9@0LW9b03/k>`1DE5@0EeMG03lo?`1HF5P0MWIf06ATI01HF5P0
JFUY05=CD`2=SHd0FEUI05aLG01RHV80=3@d07MgM`2<S8`0GEeM06QXJ00c<c<0MGEe08n?S`1WIfL0
8B4Q07alO01>CTh0<C4a07alO01DE5@0ZZZZ05aLG00K6a/0F5QH07QhN01>CTh0>SXj06UYJ@1BDU80
92@T01dM7@2BTY80Bd];05=CD`14A4@0FEUI07]kN`1=CDd0:RXZ06a/K01CDe<0G5aL05IFEP2a/K40
ATI605=CD`2DU9@0WinO08J6QP11@D40M7Ad0;Fe]@24Q8@0=cLg061PH02WYjL0CDe=030`<02WYjL0
D51@0492@P2LW9`0R8R804Y:BP0k>c/0[Zj^0861P@1nOWh0Rh^;02`/;00f=SH0FEUI04Q8B02][Jd0
MgMg06=SH`1nOWh0Lg=c0451@@1gMgL0QhN703/k>`1BDU80QHF505IFEP0f=SH0BDU9055AD@1YJFT0
ADE5092@T030`<00Rh^;05iNGP2MWId0_kno0;6a/@1UIFD0=SHf071`L01dM7@0;Rh^03hn?P20P800
<C4a03hn?P1HF5P0NWYj04e=C@11@D40UIFE04m?C`0V9RH2051@D01L055AD@0g=cL0VYZJ0<k>cP1e
MGD0:2PX06=SH`2JVYX0KFe]04=3@`1aLG40QhN704E5A@1QHF40FEUI02l_;`1LG5`0/K6a06IVIP1U
IFD0MgMg05aLG00k>c/07AdM061PH01=CDd0=CDe03/k>`1fMWH0Ng]k079bLP13@d<0aLG50=7Ad@1R
HV80MWIf0;2`/01YJFT08R8R08F5Q@21PH40Cdm?04M7A`1>CTh0A4A403Ti>@2GUiL0YJFU03Lg=`19
BDT0MgMg07QhN01DE5@0W9bL09JFUP17AdL0:b/[04i>CP1PH600Kfm_03De=@1<C4`0IfMW06a/K01O
Gel0NWYj07UiN@2l_;`0gMgM0<K6aP2LW9`0P8200:BTY015ADD0GEeM0;^k^`2XZ:P0BTY:051@D01R
HV80Rh^;0:NWY`0n?Sh04Q8B00h>3P0@41004a<C04U9B@1^KVh0ADE501dM7@0U9BD203<c<`0=038b
<P0j>SX0<c<c02XZ:P0_;bl0BDU90;Vi^@3<c<`0^KVi0:6QX@0e=CD0>SXj01PH600201HF5P805aLG
02404a<C00h>3P0>3Ph04A4A01<C4`0S8b<0Hf=S07MgM`1HF5P0820P01/K6`0E5AD071`L055AD@1e
MGD0UIFE06UYJ@1TI6@0LG5a0;Ng]`2f][H0LG5a02TY:@0I6AT09bLW03Ti>@0P82005aLG01@D500g
=cL09BDU03@d=00E5AD00P0C4a<02@0G5aL0>c/k07EeM@1oOgl0IfMW03/k>`13@d<0/;2`0:b/[002
09FEU@0[0:RXZ019BDT0<30`03Lg=`1;Bd/0SXj>0;2`/02QXJ40PX:207=cL`1HF5P0D51@05MGE`1<
C4`0?Shn034a<@0f=SH0`l?30<71`@3Fe]H0Zj^[03`l?018B4P0WIfM0:f][@33`l<0WYjN0<G5a@3I
fMT0IVIV06=SH`1TI6@0De=C04a<C01JFUX0JFUY06][J`1gMgL0d=3@07QhN00o?cl0?3`l096AT@02
06i^KP0T07MgM`26QXH0SXj>04e=C@0e=CD0GEeM05iNGP15ADD08B4Q05]KF`1fMWH0NWYj03dm?@0l
?3`0PH6101DE5@0G5aL0:b/[05iNGP1PH600F5QH08n?S`2@T900C4a<0;Vi^@24Q8@0Lg=c051@D01f
MWH06ATI01XJ6P0F5QH05aLG01HF5P0E5AD05QHF0P0G5aL04@0U9BD0<c<c01dM7@0k>c/0M7Ad0:VY
Z@1NGUh0;Rh^07YjNP3>c/h0BTY:04E5A@1FEUH07QhN01DE5@0G5aL07AdM00807alO00X09BDU03Ti
>@2g]kL0Vi^K09ZJVP30`<00QhN704];B`0E5AD04a<C0`0E5AD02`0I6AT0=3@d05=CD`0d=3@0Hf=S
06a/K025QHD0YjNW0:f][@2k^k/0Lg=c0080TI6A01<0d=3@07alO00U9BD0B4Q802h^;P14A4@0@T92
075aL@11@D40:BTY01TI6@0P8200;2`/03hn?P1LG5`0TI6A0;^k^`35aLD0cLg=0080ZZZZ0300IfMW
07AdM010@400:2PX01TI6@0D51@05ADE01XJ6P0W9bL0@D510;bl_02XZ:P0B4Q804E5A@1ADE40WYjN
09VIV@2ATI40H61P069RHP1KFe/0Rh^;07QhN00l?3`0EUIF0410@01?Cdl0YJFU06m_K`1dM7@0LW9b
05MGE`0k>c/0;Rh^03Ph>01kNg/0^[Zj0=KFeP2TY:@0;bl_04e=C@2[Zj/0]KFe08F5Q@1=CDd0<S8b
028R8P0L71`201lO7`0C02d];@1VIVH0L71`03Ti>@1NGUh0alO70;^k^`2^[Zh0`l?305mOG`1]KFd0
U9BD0::RXP1fMWH0Kfm_05YJFP10@400:2PX02DU9@0202@T90060410@01XJ6P0Lg=c061PH01cLg<0
CDe=0_ooool0000=08R8R01bLW80QHF504A4A01gMgL0BTY:061PH01mOGd0>SXj05ADE02RXZ80F5QH
02l_;`0205eMG@1a03Xj>P1FEUH0<C4a06ATI00l?3`0>CTi07IfMP0l?3`0Bd];05iNGP15ADD0@d=3
065QH@18B4P0A4A407emO@1UIFD08B4Q05=CD`0`<300@41005iNGP15ADD0;Rh^07YjNP13@d<0<30`
04M7A`0Z:RX0;2`/02d];@1SHf<0=CDe01LG5`1?Cdl0D51@028R8P0l?3`0?Cdm02`/;00o?cl0@410
034a<@0i>CT0QHF503Hf=P0h>3P0LG5a01lO7`0Y:BT0D51@05mOG`0_;bl0;Bd]05IFEP1LG5`0=SHf
07=cL`1/K6`0@41002<S8`1cLg<0H61P04i>CP29RHT0KVi^02l_;`1^KVh0D51@06EUI@1SHf<0C4a<
09BDU02ATI40<C4a03@d=01QHF40EEEE04m?C`0Y:BT0SXj>06=SH`0c<c<0MWIf06ATI020P800=3@d
02XZ:P1GEeL0DE5A03hn?P1TI6@0IfMW07moO`26QXH0Ph>3071`L00k>c/0MWIf04M7A`1NGUh0HF5Q
06YZJP27QhL0?clo04Q8B01XJ6P0G5aL04a<C01SHf<0:RXZ05IFEP25QHD00P22PX80Y@1FEUH0>CTi
04];B`1?Cdl0Bd];06IVIP1mOGd0Fe]K05MGE`1`L700EeMG07=cL`1>CTh0I6AT069RHP0o?cl0PX:2
08N7Q`1QHF40J6QX03`l?02ZZZX0UiNG04Q8B017AdL0ZJVY07UiN@0^;Rh0IVIV03dm?@2CTi<0Hf=S
03Lg=`11@D40Hf=S06][J`13@d<0JFUY06=SH`0N7Qh09bLW09>CT`1:BTX0IVIV05UIF@1ZJVX0TI6A
065QH@0h>3P0MWIf06=SH`1XJ6P0?Cdm08^;R`1;Bd/0@D510::RXP2<S8`0L71`0410@023Ph<0];Bd
0820P00l?3`0LG5a0;Zj^P20P800>CTi0;jn_P1BDU80AdM70;Jf]P2DU9@0Cdm?0492@P2j^[X0G5aL
051@D01bLW809bLW030`<01/K6`0@D5105UIF@1`L700H61P09FEU@20P8008R8R071`L01fMWH0D51@
05YJFP21PH40GEeM06=SH`2CTi<0YZJV092@T01=CDd0MWIf05mOG`1PH600KVi^09ZJVP3EeMD0[Zj^
05IFEP0o?cl0M7Ad06ATI00[:b/0LW9b08R8R016ATH0B4Q805iNGP29RHT0<c<c04];B`2g]kL0HV9R
03@d=01ADE40CDe=05UIF@1ADE40Jf][08f=S@1RHV808B4Q055AD@20P800:b/[065QH@2BTY80L71`
0492@P1<C4`0>CTi030`<028R8P0TY:B04Y:BP1PH600QHF506=SH`0f=SH0820P07EeM@1MGEd0RHV9
04a<C020P800GUiN03Ph>00Z:RX0YZJV0;6a/@0g=cL0L71`0<;2`P2OWil0>SXj08j>SP0205ADE00`
06EUI@1`L700H61P02`/;01kNg/0R8R802XZ:P1EEED0PX:203Xj>P0O7al0RXZ:08n?S`1CDe<0;Bd]
05ADE01]KFd0@d=301lO7`1RHV80IfMW05ADE018B4P0N7Qh04a<C02;Rh/0`l?30820P01YJFT0I6AT
02l_;`0K6a/0820P0;Zj^P3GemL0QXJ604A4A00f=SH0@41009ZJVP2a/K40?clo024Q8@0L71`08b<S
03lo?`1eMGD0VIVI0P20P800501hN7P0M7Ad079bLP1hN7P0QXJ607moO`2<S8`0`l?30=[JfP2b/[80
]kNg06IVIP0^;Rh0;bl_04A4A00P8200:2PX03Lg=`0V9RH04a<C0P0G5aL03@0C4a<05ADE01DE5@13
@d<0?3`l06][J`1VIVH0<S8b03Hf=P1SHf<0E5AD061PH02ZZZX00P2WYjL0F02e]KD0`l?30<C4a01Q
HF406a/K01DE5@0G5aL08B4Q03Ph>00X:2P06QXJ038b<P0Q8B40<C4a010@400I6AT0>3Ph059BDP0n
?Sh0;Bd]02<S8`2PX:00QhN7061PH01jNWX0XZ:R09JFUP2k^k/0/[:b028R8P0L71`0<c<c024Q8@12
@T80RXZ:03Hf=P0m?Cd0DE5A065QH@1lO7`0N7Qh07inOP2g]kL0_;bl0<30`03:b/X0];Bd05iNGP2C
Ti<0_;bl0:VYZ@3Cdm<0YJFU0<;2`P35aLD0]kNg09fMW@0S8b<09BDU03@d=01;Bd/0CDe=04I6AP10
@400=CDe04M7A`25QHD0_Kfm0;:b/P1ADE40Fe]K08B4Q01=CDd0DE5A06MWI`1nOWh0/k>c09FEU@0i
>CT07alO01TI6@0F5QH0=CDe06m_K`1ZJVX0?Shn0410@01eMGD301DE5@0a01HF5P0V9RH0Fe]K0<?3
``0];Bd0;bl_07UiN@1NGUh0IVIV05aLG02XZ:P0;Bd]01XJ6P0L71`05QHF01DE5@0F5QH05aLG01DE
5@0I6AT071`L05mOG`1GEeL0Q8B40;Zj^P2MWId0S8b<06YZJP21PH40emOG0;Zj^P2RXZ80WinO07Ad
M00M7Ad05ADE01LG5`0i>CT0?Cdm05ADE02BTY80/K6a05EEE@0i>CT0Jf][08R8R01fMWH06ATI014A
4@0201DE5@0X01PH600M7Ad0BTY:01`L700E5AD05aLG07]kN`2LW9`0Zj^[0;Ng]`3IfMT0a<C40<?3
``3EeMD0gMgM08^;R`26QXH0Ng]k02h^;P14A4@0DU9B05YJFP0W9bL05aLG010@400E5AD061PH01lO
7`0Y:BT0>CTi06EUI@2KVi/0Y:BT09fMW@2VYZH0NWYj02PX:00M7Ad07QhN020P80<05ADE01P05aLG
02/[:`1jNWX0J6QX05EEE@1<C4`0EEEE09>CT`22PX80LG5a01LG5`0D51@05ADE01TI6@1eMGD0UIFE
08f=S@2ATI40_kno0<g=c@2YZJT0Kfm_08j>SP1WIfL207emO@0[0;6a/@21PH40IfMW09>CT`3>c/h0
];Bd06m_K`24Q8@0PH6105eMG@0/;2`08R8R01`L700M7Ad07alO03lo?`1QHF40>3Ph02PX:00/;2`0
Jf][07moO`2j^[X0_kno0;Vi^@1VIVH0AdM705YJFP1]KFd0S8b<04Q8B00n?Sh0?3`l03Lg=`0m?Cd0
C4a<03Ti>@1iNGT0O7al05iNGP1aLG40CTi>04e=C@02ooooo`000:d0]KFe07AdM02=SHd0CDe=0:RX
Z01CDe<0J6QX07alO014A4@0KVi^0;Fe]@1UIFD0=cLg06][J`1YJFT0@T9206QXJ00Z:RX0KFe]05]K
F`0Q8B40DU9B03dm?@1/K6`0N7Qh03lo?`0Y:BT0ATI602d];@0g=cL0FEUI061PH00X:2P0J6QX05EE
E@14A4@0E5AD03dm?@1NGUh0YJFU069RHP0c<c<0CDe=038b<P0`<300@D5106=SH`0n?Sh071`L05UI
F@1DE5@0?Shn04E5A@0_;bl06a/K04];B`1YJFT0De=C03Lg=`1_Kfl0:BTY0410@01cLg<0<c<c02d]
;@1KFe/0DE5A02d];@0f=SH0HV9R04I6AP0d=3@0IVIV069RHP0];Bd06QXJ061PH01LG5`0?3`l09^K
V`1;Bd/0:2PX08>3P`1@D500I6AT05EEE@19BDT0[Zj^08F5Q@0m?Cd09bLW05ADE01>CTh0EEEE03Ph
>02/[:`0O7al03Lg=`1bLW80HV9R07moO`0/;2`0Cdm?07emO@1kNg/0D51@04a<C01HF5P0MgMg05MG
E`3;bl/0QXJ603Xj>P1gMgL0BDU908F5Q@1^KVh0Hf=S06YZJP0e=CD0LG5a07UiN@1JFUX0B4Q806][
J`0P8200KFe]07moO`1bLW80RXZ:05ADE01PH600KFe]06EUI@1<C4`0JFUY07alO01NGUh0TY:B08n?
S`1?Cdl0JFUY051@D02`/;00KFe]03Lg=`1nOWh0GEeM0861P@2@T900GemO0:RXZ02FUYH0Cdm?024Q
8@1mOGd0Lg=c034a<@1]KFd0AdM707alO01VIVH0BTY:0492@P1XJ6P0CTi>04=3@`2FUYH0YZJV03/k
>`0K6a/0QXJ605]KF`0206UYJ@0b04a<C02XZ:P0JFUY03hn?P1jNWX0IVIV04m?C`1MGEd0Y:BT05QH
F01=CDd0Y:BT0:f][@1?Cdl0=CDe05QHF02MWId0FUYJ05UIF@2ATI40YJFU06=SH`0g=cL0`l?307Yj
NP1;Bd/0VYZJ08n?S`0b<S80EeMG0;6a/@1lO7`0De=C06][J`0T92@09bLW061PH00n?Sh0K6a/07=c
L`15ADD0Ng]k07inOP0W9bL0KVi^05mOG`0o?cl0GEeM07MgM`1;Bd/204E5A@1703Ti>@1WIfL0@D51
065QH@1MGEd0DU9B06=SH`1iNGT0Xj>S092@T01GEeL0?Cdm08:2PP1MGEd092@T07inOP1iNGT0CTi>
04Y:BP1KFe/0W9bL03Ti>@0m?Cd0WYjN05QHF00a<C40I6AT07YjNP22PX80De=C08B4Q02a/K40?Cdm
01hN7P1gMgL0VYZJ05aLG00k>c/0JFUY04M7A`12@T80K6a/03@d=00];Bd0TI6A0861P@15ADD0K6a/
0:VYZ@1_Kfl0820P03<c<`28R8P0FEUI06QXJ011@D40SXj>07alO019BDT0;Rh^08B4Q02XZ:P0<C4a
07QhN035aLD0TY:B03Lg=`2KVi/0EeMG030`<01EEED00P1fMWH0=00g=cL0NWYj06m_K`0Q8B40EEEE
08:2PP27QhL0ADE507AdM02UYJD0=SHf03Ph>01dM7@0RXZ:07UiN@0/;2`0>c/k04I6AP1LG5`0Fe]K
05QHF011@D40B4Q8092@T025QHD0I6AT0410@00g=cL0CTi>08b<S02o_kl0gMgM0=7Ad@2][Jd0H61P
03<c<`1=CDd0YZJV0;jn_P38b<P0^KVi0:VYZ@2KVi/0YZJV0:n_[`1OGel0Bd];04=3@`10@400>CTi
03De=@0^;Rh2034a<@0:06MWI`2h^;P0ZZZZ04M7A`14A4@0EEEE030`<012@T80NGUi02l_;`806QXJ
04`06a/K02TY:@0d=3@0<S8b02HV9P0G5aL07AdM051@D00j>SX0K6a/096AT@2XZ:P0MWIf07AdM02M
WId0V9RH06a/K01EEED0Bd];09ZJVP2j^[X0Cdm?028R8P0F5QH061PH01XJ6P0T92@0>3Ph02@T900l
?3`0@D510492@P0f=SH0F5QH03/k>`0P82005aLG01HF5P10@400FUYJ09^KV`1PH600CDe=09NGU`1o
Ogl0MGEe07moO`0c<c<06QXJ03<c<`0U9BD09RHV05IFEP0L71`07QhN01dM7@0_;bl0BTY:0=7Ad@2`
/;00Shn?07=cL`1oOgl0]KFe079bLP0d=3@0=CDe07UiN@3MgMd0QHF5055AD@35aLD0bLW905mOG`2@
T9006QXJ0P0G5aL00`0I6AT06a/K03De=@0202DU9@0G03<c<`0n?Sh0I6AT08b<S02k^k/0_kno07Yj
NP13@d<09bLW03Ti>@1NGUh0Vi^K02<S8`0F5QH071`L01TI6@0J6QX092@T05iNGP1HF5P0GemO03lo
?`1QHF400`0E5AD0BP0F5QH05ADE01DE5@1eMGD07AdM01lO7`1YJFT0GEeM07UiN@2d];@0YJFU0;>c
/`2FUYH0L71`03`l?00[:b/071`L01TI6@0E5AD071`L02@T900n?Sh09BDU04U9B@2JVYX0Ph>305=C
D`1DE5@0];Bd08f=S@0i>CT0MWIf08j>SP2VYZH0RXZ:06YZJP0S8b<07QhN051@D02UYJD0LW9b03lo
?`22PX80@d=308F5Q@1`L700K6a/061PH00J6QX04A4A01DE5@0H61P0>c/k02/[:`0E5AD051@D01DE
5@19BDT0D51@06i^KP3<c<`0f=SH0;no_`2TY:@0clo?0=3@d02e]KD0L71`07YjNP1;Bd/0De=C07Mg
M`0c<c<07AdM0P0E5AD07@0F5QH061PH01PH600G5aL06QXJ02<S8`1hN7P0WinO0=;BdP24Q8@0Bd];
01XJ6P0K6a/07QhN024Q8@0I6AT051@D01HF5P0E5AD07AdM079bLP2TY:@0ADE503dm?@29RHT0K6a/
06IVIP1CDe<05ADE00<04a<C01L0=CDe0=;BdP35aLD0]KFe0;Rh^02f][H0O7al06i^KP1KFe/0@T92
030`<00O7al0;bl_02LW9`1SHf<0/K6a092@T03:b/X0TI6A0:FUY@2c/k<0EEEE02TY:@02028R8P0C
03Ph>01DE5@0DE5A03Hf=P0l?3`0F5QH08Z:RP2GUiL0YJFU0=_Kf`2/[:`0O7al09jNWP2[Zj/0/[:b
0<;2`P30`<00XJ6Q06e]K@0206ATI00907MgM`2OWil0[jn_08F5Q@1SHf<0Ng]k059BDP1CDe<071`L
00;ooooo0000o`2a/K40NWYj05EEE@1@D500Ogmo04M7A`1]KFd0H61P02d];@1HF5P0P82004a<C00k
>c/0F5QH03dm?@1cLg<0Ti>C03Ti>@1kNg/0FEUI03/k>`1bLW80=SHf06][J`1aLG40CDe=05UIF@26
QXH0HF5Q03Xj>P18B4P0;Rh^03Ph>01kNg/0De=C04=3@`17AdL08B4Q02LW9`1VIVH0AdM702d];@1D
E5@07alO0492@P0n?Sh0EUIF01`L700_;bl0I6AT05IFEP0c<c<0?Cdm02l_;`0B4Q80JFUY06QXJ013
@d<0>3Ph05ADE00F5QH0J6QX07EeM@0l?3`0:2PX069RHP0h>3P0=3@d05mOG`1oOgl0E5AD03Ti>@1g
MgL0J6QX01<C4`0N7Qh0HF5Q05MGE`0o?cl0VYZJ04e=C@0K6a/0IVIV04E5A@1MGEd0G5aL02h^;P1P
H600R8R8059BDP0X:2P0G5aL04Q8B00R8R80?3`l09VIV@1/K6`0<c<c05aLG01WIfL0S8b<034a<@0Q
8B40@41005=CD`18B4P0GemO071`L01_Kfl0G5aL0;bl_01OGel0=SHf08Z:RP1>CTh0HV9R065QH@1O
Gel0QHF503Ph>010@400Jf][05aLG01CDe<0HV9R0410@01MGEd0OGem06m_K`24Q8@0@T9202PX:01F
EUH0DU9B04A4A01KFe/0LW9b04E5A@1FEUH0KVi^04U9B@1gMgL0E5AD05QHF01TI6@0;Bd]07=cL`1b
LW80KVi^07emO@1@D500YJFU0:n_[`1bLW80<c<c08j>SP1YJFT0ATI60:6QX@1@D500V9RH06YZJP15
ADD0D51@06a/K02DU9@0E5AD05EEE@1BDU80C4a<02@T901`L700;Bd]07YjNP1iNGT0FUYJ06e]K@1K
Fe/0Cdm?0:BTY027QhL0?clo0410@02h^;P0LG5a071`L036a/H0WYjN08b<S017AdL0QHF50:FUY@1Y
JFT0=cLg05aLG02TY:@0?Shn034a<@2JVYX0F5QH05ADE02h^;P0PX:204M7A`0k>c/0Q8B405UIF@1R
HV80I6AT03De=@1iNGT0Ng]k04M7A`1nOWh0KFe]04m?C`29RHT0O7al02/[:`1gMgL0L71`03dm?@1m
OGd0SHf=03dm?@0[:b/0>CTi04a<C015ADD09BDU06MWI`1_Kfl0LW9b06e]K@24Q8@0UiNG0:>SX`1=
CDd0:b/[0820P01nOWh0>c/k07alO022PX80;bl_065QH@2HV9P0Vi^K059BDP14A4@0QhN706=SH`0X
:2P0A4A40492@P00Y01dM7@0DE5A09VIV@2k^k/0LW9b02@T901IFET0SXj>061PH00n?Sh0MgMg05MG
E`0c<c<0@410051@D00U9BD0NWYj08f=S@0Y:BT0De=C07AdM01WIfL0=CDe01/K6`1CDe<0EUIF03Ti
>@0T92@0SHf=092@T01]KFd0Bd];0;no_`2f][H0AdM707YjNP2k^k/0Ti>C03Ti>@2XZ:P0DU9B05]K
F`1<C4`0DU9B07EeM@0a<C40KFe]07=cL`0W9bL0CTi>071`L022PX80DU9B07QhN02HV9P0?Cdm028R
8P0n?Sh0Fe]K07moO`0c<c<0A4A404i>CP1[Jf/0N7Qh04E5A@0m?Cd0ADE505mOG`3@d=00/K6a0:ZZ
ZP33`l<0Q8B404E5A@0j>SX0EeMG0:ZZZP2h^;P0WYjN09FEU@0g=cL0Lg=c0;:b/P1nOWh0BTY:04=3
@`1WIfL0RXZ:0;Bd]011@D40=CDe030`<00[:b/09bLW02/[:`0O7al05ADE01lO7`1OGel0WYjN07Ad
M00K6a/05aLG03Lg=`1EEED0F5QH06=SH`0N7Qh071`L03Xj>P1@D500>SXj02PX:00U9BD0=3@d04U9
B@0j>SX0GemO04Q8B01mOGd0/;2`0<C4a02i^KT0Y:BT09VIV@25QHD0MWIf06a/K01ZJVX0L71`08B4
Q01=CDd0<C4a01PH600I6AT05QHF01LG5`0N7Qh0CDe=065QH@1HF5P0Fe]K04I6AP0M7Ad061PH01LG
5`0E5AD0>c/k051@D00g=cL0Q8B406YZJP1HF5P0Ph>306a/K01@D500@D51065QH@0P8200;Bd]030`
<00Q8B40De=C0`0L71`05@0e=CD0W9bL08Z:RP1JFUX0D51@03hn?P0];Bd0UYJF061PH00^;Rh0=CDe
05QHF03@d=00BDU90;Fe]@3Lg=`0^[Zj05QHF01gMgL05QHF01PH600201LG5`0C01PH600I6AT05aLG
01LG5`0H61P06ATI02XZ:P11@D40CTi>08>3P`1]KFd0;Bd]02/[:`11@D40MWIf06YZJP0K6a/05aLG
01/K6`0201LG5`0601/K6`1@D500?Cdm05EEE@0n?Sh0HV9R1P0E5AD0A@1=CDd06ATI01dM7@1_Kfl0
Ng]k0;Fe]@1jNWX0GEeM02l_;`0l?3`0EUIF06e]K@1jNWX0MGEe07QhN01dM7@0O7al06MWI`1;Bd/0
Cdm?07inOP2^[Zh0V9RH05QHF028R8P0YjNW04a<C01:BTX0ADE501hN7P0Y:BT0FEUI0:FUY@2HV9P0
OWin09nOW`1MGEd0CDe=06EUI@27QhL0N7Qh08n?S`2PX:00XZ:R09BDU02LW9`0@41002HV9P0j>SX0
?clo018B4P0C4a<03`l?01DE5@0b<S80:RXZ038b<P2i^KT0a/K60:b/[02>SXh0^;Rh0;jn_P2VYZH0
`l?30;>c/`2UYJD0V9RH05]KF`0201dM7@04010@400C4a<05ADE01HF5P805ADE01P05aLG024Q8@10
@400SXj>0;Fe]@2l_;`0JFUY01`L700N7Qh092@T02`/;00a<C407AdM01TI6@0J6QX0:2PX061PH01n
OWh0?Shn05mOG`1PH600ADE506MWI`13@d<2018B4P0<01DE5@0G5aL0JVYZ08j>SP1eMGD0FEUI05QH
F01iNGT0:BTY01DE5@0D51@04a<C0P0E5AD0:@0f=SH0Cdm?07emO@0o?cl0CTi>05aLG026QXH0JVYZ
0820P01gMgL0R8R807]kN`15ADD0IfMW08Z:RP23Ph<0RXZ:08F5Q@22PX80O7al08R8R02TY:@0emOG
0;6a/@10@400DU9B08:2PP2KVi/0Xj>S0:ZZZP2SXj<0RHV90820P02<S8`0WIfM0<[:bP2VYZH0Shn?
0::RXP1kNg/0@d=300806ATI0_ooool0001G09bLW02JVYX0MWIf04e=C@1kNg/0?Shn079bLP2<S8`0
@410065QH@2:RXX0D51@04=3@`1/K6`0?Cdm03<c<`1RHV80:BTY04Q8B00H61P0<c<c06i^KP0`<300
N7Qh02DU9@0a<C40?Shn05=CD`11@D40?Shn04];B`0d=3@0;2`/05EEE@15ADD0HF5Q07MgM`0o?cl0
=CDe08V9R@0j>SX0CDe=079bLP1ADE40DU9B03Hf=P1:BTX0=CDe01hN7P1=CDd0Cdm?03Hf=P1FEUH0
>CTi028R8P1/K6`0@d=301`L701DE5@0H61P02TY:@1GEeL0JFUY018B4P18B4P0PH6106MWI`0`<300
:BTY04Y:BP12@T80>3Ph07MgM`1aLG40ADE501XJ6P1_Kfl0<C4a03Ph>02=SHd0JFUY03Ph>024Q8@0
BDU905mOG`1JFUX0Fe]K0080SHf=03L0:BTY03`l?026QXH0JVYZ04I6AP0];Bd0Vi^K04i>CP0h>3P0
Rh^;0:f][@20P800<30`02/[:`15ADD0De=C03Ph>01^KVh0HV9R06QXJ01LG5`0alO7059BDP0a<C40
Ti>C05QHF01XJ6P0>CTi06ATI02@T900CTi>0492@P1WIfL0A4A404U9B@1EEED0=cLg065QH@1@D500
EeMG08V9R@1UIFD0=cLg05MGE`0l?3`0JVYZ0:6QX@2ATI40GUiN06EUI@1@D500?Cdm08n?S`1^KVh0
HF5Q0080>c/k08/0Q8B407YjNP1bLW80Hf=S01/K6`1YJFT0SXj>05UIF@0g=cL0TY:B04E5A@0g=cL0
P82004I6AP21PH40De=C02LW9`1jNWX0TY:B0861P@19BDT0EUIF05YJFP19BDT0AdM709fMW@1<C4`0
IVIV06a/K01NGUh0/[:b06MWI`0e=CD0E5AD04m?C`1HF5P0M7Ad0;Bd]01=CDd0<30`0:^[Z`29RHT0
DE5A04A4A01mOGd0ZZZZ07IfMP19BDT0QXJ60;:b/P1eMGD0>3Ph0:>SX`1RHV80DU9B0;^k^`1^KVh0
@T9204e=C@2][Jd0Hf=S06i^KP1WIfL08b<S03Xj>P1GEeL0@41009jNWP1fMWH0=SHf08f=S@1lO7`0
>CTi07]kN`1^KVh0:b/[05QHF01bLW80?Cdm03hn?P1=CDd0EEEE06UYJ@0[:b/0E5AD04m?C`1GEeL0
De=C08f=S@2b/[80/k>c04a<C00g=cL0EEEE07IfMP0e=CD0O7al079bLP18B4P0BDU905IFEP2ATI40
D51@05ADE02GUiL0D51@02DU9@1=CDd0?Shn06MWI`19BDT0OWin08:2PP1YJFT08R8R05ADE01lO7`0
ATI605aLG02KVi/0L71`04U9B@11@D40Fe]K02TY:@1oOgl0VIVI05aLG01cLg<0O7al06ATI00g=cL0
820P06=SH`1oOgl0SXj>02XZ:P2?Shl0KVi^0080@d=302/0VYZJ08^;R`18B4P0PH610:BTY023Ph<0
>SXj0<;2`P2;Rh/0C4a<05ADE015ADD0GEeM028R8P21PH40NGUi02HV9P1BDU80HV9R04Y:BP19BDT0
OWin07IfMP0i>CT0:BTY03lo?`1IFET0HF5Q02LW9`1SHf<0HF5Q05aLG01lO7`0@41003Ti>@16ATH0
Shn?07AdM01UIFD0Ph>305UIF@0];Bd07alO008071`L00d09BDU06ATI02YZJT0XJ6Q08^;R`34a<@0
J6QX03Hf=P0m?Cd0AdM703Lg=`1BDU80Fe]K008071`L06807alO02<S8`0[:b/0=cLg03<c<`0L71`0
>CTi08n?S`1gMgL08b<S01lO7`0D51@0AdM704a<C01KFe/0ADE503dm?@1mOGd0HV9R02XZ:P0R8R80
8b<S020P800W9bL0;Bd]05UIF@24Q8@0Kfm_0;6a/@34a<@0aLG50;^k^`31`L40N7Qh05=CD`1OGel0
9RHV01TI6@0H61P0=3@d06QXJ018B4P0820P01LG5`0E5AD06ATI01PH601<C4`0LG5a07moO`1iNGT0
G5aL04E5A@0b<S807AdM04I6AP1KFe/0?clo03Ph>01KFe/071`L01DE5@18B4P0>3Ph06IVIP10@400
Cdm?04];B`0Q8B40=3@d02<S8`1_Kfl0ADE5055AD@26QXH0V9RH05aLG00n?Sh0?3`l05YJFP2LW9`0
KFe]0::RXP2:RXX0AdM70410@02?Shl0clo?08N7Q`2YZJT0_Kfm0;Jf]P1OGel0L71`01LG5`0I6AT0
5ADE01LG5`806QXJ00l06ATI01PH600E5AD05aLG01PH600_;bl0@d=304];B`25QHD0:RXZ03Hf=P19
BDT0UIFE03Xj>P0G5aL00P0H61P0200I6AT07alO05=CD`2_[jl0N7Qh061PH01@D500Kfm_0`0E5AD0
300I6AT05ADE01DE5@18B4P06a/K02@T902SXj<0Ti>C06][J`1^KVh0MGEe02TY:@807AdM05X07alO
02DU9@0a<C40BDU9051@D01JFUX0MWIf09nOW`2PX:00bLW909bLW023Ph<0X:2P0;Jf]P18B4P09bLW
03`l?01^KVh09bLW01PH600J6QX0=CDe075aL@3Bd]80DE5A02LW9`0_;bl0De=C0:BTY03Lg=`0YZJV
0:j^[P2c/k<0XZ:R0:^[Z`2d];@0VIVI08b<S00S8b<03Ph>014A4@0>3Ph05QHF038b<P0X:2P0@D51
08F5Q@2<S8`0De=C08n?S`29RHT0_[jn06i^KP2ATI40^;Rh0=?Cd`2n_[h0>CTi01XJ6P0K6a/05aLG
01DE5@0F5QH05aLG01DE5@0F5QH061PH028R8P0b<S80KFe]0:>SX`3Fe]H0`/;206MWI`1]KFd0QXJ6
096AT@2SXj<0N7Qh06EUI@1KFe/0Hf=S0:>SX`2o_kl0^;Rh0:j^[P15ADD0?Shn071`L00i>CT301DE
5@0h03Ti>@1ZJVX09RHV05YJFP1cLg<0@41007AdM00B4Q804a<C01DE5@0C4a<05ADE01hN7P1WIfL0
FUYJ0451@@0E5AD0?clo05MGE`2IVIT0RXZ:05mOG`0Y:BT0<C4a06i^KP2k^k/0KFe]02/[:`0K6a/0
5aLG01DE5@0J6QX0:b/[07YjNP1BDU80f][J0=gMg@3@d=00_[jn09RHV01;Bd/0>SXj07moO`2JVYX0
GemO069RHP1`L700QHF50<30`02l_;`0cLg=0=7Ad@21PH408b<S01/K6`0J6QX2ooooo`0009T0N7Qh
08Z:RP1cLg<0DE5A09VIV@18B4P0GEeM08>3P`1@D500S8b<07UiN@0];Bd0C4a<07emO@1DE5@0Bd];
05EEE@1GEeL0WIfM05YJFP0k>c/0NWYj03Ti>@22PX80GEeM02PX:00m?Cd0ADE5030`<01>CTh0MWIf
059BDP0e=CD0A4A401`L700h>3P0J6QX038b<P0g=cL0O7al02PX:00W9bL0DE5A03hn?P12@T8071`L
05=CD`11@D409bLW04a<C00a<C408R8R03lo?`1<C4`0>CTi075aL@1;Bd/0<S8b05UIF@0n?Sh06a/K
071`L01TI6@07AdM01lO7`1FEUH0D51@02LW9`0_;bl0C4a<02XZ:P0[:b/0DU9B05QHF00];Bd07alO
06EUI@16ATH0Bd];07IfMP13@d<0;2`/07emO@0j>SX0?Cdm04];B`1LG5`0Y:BT06YZJP0M7Ad08R8R
051@D01CDe<0>c/k03De=@2IVIT0>c/k02@T9012@T80KFe]05EEE@0R8R80=CDe04a<C01HF5P0>c/k
07alO015ADD0EUIF05EEE@2k^k/0Bd];02l_;`1oOgl0@d=3075aL@1LG5`0H61P08R8R016ATH0ADE5
08B4Q01XJ6P0K6a/05MGE`0h>3P0J6QX07YjNP1^KVh0LG5a055AD@0g=cL0D51@03Lg=`1<C4`0NGUi
092@T01WIfL0IFEU065QH@18B4P0PX:205]KF`1MGEd0EUIF03/k>`1eMGD0M7Ad06a/K01:BTX0>CTi
09fMW@2IVIT00P11@D403P2ZZZX0HF5Q03Hf=P1dM7@0ADE509FEU@1CDe<0;Rh^04M7A`1JFUX0EeMG
03`l?01FEUH0Cdm?0P0W9bL0TP29RHT0AdM707=cL`1DE5@0D51@06m_K`1ADE40BDU90:2PX01@D500
=CDe04];B`2TY:@0EEEE02h^;P2RXZ80IVIV07AdM019BDT0OWin0:FUY@1NGUh0?3`l07AdM02RXZ80
Ng]k03lo?`2DU9@0HF5Q055AD@2c/k<0GEeM03Hf=P1NGUh0[Jf]06m_K`1WIfL0LW9b02PX:01:BTX0
Bd];04I6AP2l_;`0Jf][04m?C`2<S8`0Hf=S02TY:@22PX80NGUi03dm?@1YJFT0OGem03<c<`1>CTh0
IfMW06a/K01iNGT0?3`l06IVIP1HF5P0ATI605EEE@1RHV80J6QX07]kN`12@T80>CTi06QXJ01kNg/0
>3Ph09BDU01aLG40CTi>05UIF@1QHF40P82003<c<`1:BTX0Ogmo03lo?`0V9RH0EeMG04M7A`1kNg/0
FEUI08J6QP2=SHd0Jf][02<S8`1SHf<0Ph>3055AD@0n?Sh0J6QX05QHF01JFUX0@d=304E5A@0f=SH0
SXj>08V9R@1@D500DU9B08N7Q`1:BTX092@T02h^;P21PH40RXZ:08b<S00W9bL0TY:B06i^KP1TI6@0
@41009JFUP22PX809bLW09:BTP2g]kL0I6AT038b<P2[Zj/0U9BD04];B`1_Kfl0FEUI0492@P0V9RH0
OGem07MgM`0W9bL0F5QH06IVIP0m?Cd0FUYJ0:^[Z`1IFET0?3`l02l_;`19BDT0FEUI05EEE@0H61P0
BDU90P0o?cl0@01LG5`0?Cdm0492@P2;Rh/0W9bL03hn?P1YJFT0Hf=S03Ph>00W9bL07QhN01/K6`0I
6AT061PH01`L700/;2`0NGUi0;6a/@2XZ:P0W9bL04e=C@0`<300=cLg05ADE023Ph<0QhN704A4A00a
<C40;Rh^02<S8`0O7al071`L01XJ6P0P8200GEeM0:RXZ00`<3006a/K028R8P0D51@06a/K01`L700]
;Bd0Lg=c0;Zj^P20P800@41003@d=00Z:RX08b<S02TY:@0_;bl0<C4a03`l?030`<00S8b<08R8R01a
LG40^KVi0820P02NWYh0Bd];0451@@0Z:RX301DE5@0i01TI6@1^KVh0HF5Q04I6AP0S8b<06ATI02@T
900m?Cd0F5QH05ADE01;Bd/0BDU904M7A`1=CDd0F5QH08B4Q01]KFd0=3@d02TY:@1?Cdl0H61P02TY
:@0^;Rh0KVi^04I6AP18B4P0F5QH03Xj>P1GEeL09bLW02d];@0N7Qh0N7Qh0;Vi^@2<S8`0G5aL04A4
A00Z:RX0820P01`L700M7Ad0<30`08Z:RP2FUYH0/;2`0;Ng]`1nOWh0JVYZ07=cL`1`L700ADE5079b
LP37alL0LG5a06MWI`0H61P06ATI00805QHF00@05aLG01TI6@0H61P06QXJ0P0F5QH05P0E5AD06ATI
04E5A@0j>SX0YZJV038b<P10@400D51@09^KV`0U9BD071`L01/K6`0R8R80AdM706YZJP1QHF40G5aL
0:>SX`2n_[h0d=3@092@T00H61P401DE5@0A01LG5`11@D40:2PX05aLG02g]kL0OWin04];B`1FEUH0
Xj>S0:j^[P0o?cl0=cLg02l_;`1<C4`0P82008R8R02RXZ800P2VYZH0302TY:@0UIFE08^;R`2g]kL0
C4a<0;Ng]`2KVi/06ATI01LG5`0R8R80=cLg04U9B@806ATI04D07alO034a<@2a/K40=cLg01dM7@0i
>CT0F5QH0:b/[02[Zj/0NGUi09NGU`2TY:@0Ti>C0;2`/035aLD0emOG09JFUP0o?cl0>SXj03De=@0f
=SH0De=C04I6AP0U9BD0G5aL05MGE`0k>c/06a/K04I6AP0S8b<0NGUi08b<S01CDe<0R8R809^KV`2l
_;`0Jf][038b<P0M7Ad07QhN01TI6@0G5aL05ADE01LG5`0F5QH05aLG01/K6`0^;Rh0FEUI08f=S@39
bLT0i^KV0<K6aP2QXJ40VYZJ09jNWP3@d=00f=SH0<S8b02[Zj/0S8b<0<K6aP3Ph>00emOG0:f][@2F
UYH0@d=307inOP0c<c<00P0E5AD02P0[:b/0I6AT02@T900L71`0Bd];09jNWP1GEeL0NWYj01<C4`0D
51@201DE5@0B01HF5P12@T80PH61065QH@0I6AT06a/K03De=@1VIVH0GEeM0;2`/01aLG40=SHf06][
J`1`L700EUIF04I6AP0E5AD051@D0P0E5AD05`0M7Ad0O7al04I6AP2_[jl0emOG0=_Kf`2WYjL0PH61
092@T02GUiL0A4A404];B`2GUiL0GEeM08N7Q`2XZ:P0];Bd0<S8b02][Jd0`<300<;2`P1_Kfl06ATI
00806QXJ0_ooool0002k0:j^[P2=SHd0K6a/05IFEP2^[Zh0CDe=06YZJP1YJFT0Cdm?0820P02/[:`0
F5QH0410@01_Kfl0Bd];06m_K`1QHF40<S8b07alO01<C4`0A4A404m?C`0/;2`0O7al065QH@0a<C40
>c/k04Q8B00W9bL0=cLg05]KF`0m?Cd0=SHf06YZJP1UIFD0EeMG05eMG@0X:2P0ATI609:BTP0m?Cd0
>CTi04Y:BP0e=CD0>CTi03Hf=P1RHV80>3Ph02HV9P12@T80F5QH03@d=01;Bd/0DU9B03lo?`1PH600
Kfm_04A4A01YJFT0@D51020P801jNWX0L71`02h^;P0Z:RX0G5aL051@D00^;Rh0>SXj05ADE01@D500
C4a<05mOG`1FEUH08R8R01`L701VIVH0Cdm?04a<C01fMWH0C4a<02PX:01iNGT0ADE504m?C`13@d<0
AdM709BDU01`L700=cLg02PX:01DE5@0DE5A03<c<`0i>CT0UiNG04a<C00Y:BT0=SHf08B4Q01DE5@0
6QXJ02HV9P0k>c/0I6AT04Y:BP20P800B4Q805]KF`15ADD0V9RH04M7A`0_;bl0L71`03Xj>P1lO7`0
IVIV069RHP1lO7`0ADE505]KF`1jNWX0Fe]K07EeM@1DE5@09BDU06ATI01^KVh0N7Qh07inOP1HF5P0
AdM705aLG018B4P0G5aL0:NWY`2JVYX0Jf][07EeM@1jNWX0Bd];07moO`1NGUh0KFe]05mOG`1=CDd0
OWin06IVIP24Q8@0KFe]05=CD`2OWil0UIFE0492@P0j>SX0Vi^K05iNGP13@d<0Q8B403`l?02NWYh0
De=C02l_;`10@400E5AD05IFEP10@400GemO069RHP0U9BD0<S8b09>CT`0`<300Ng]k069RHP1SHf<0
Ng]k03lo?`1:BTX0_[jn05aLG01JFUX0MWIf0:NWY`10@400=cLg0:VYZ@0208B4Q02A04Q8B02ATI40
[jn_07YjNP13@d<0T92@0:BTY012@T80@D510;Jf]P2;Rh/0J6QX0<_;b`2=SHd05QHF06i^KP2TY:@0
JVYZ07]kN`1WIfL0<C4a061PH017AdL0>CTi09^KV`1fMWH0FEUI09^KV`1UIFD0;bl_0:>SX`22PX80
@41007QhN01iNGT0:RXZ04Q8B01EEED0G5aL08V9R@1<C4`0IfMW05UIF@1SHf<0J6QX08>3P`1eMGD0
M7Ad04Q8B00k>c/0J6QX06UYJ@0T92@0Jf][05QHF012@T80PX:208>3P`2@T900BDU9051@D01hN7P0
>CTi03<c<`1SHf<0EeMG06m_K`1<C4`0OGem07alO00j>SX07alO07QhN02FUYH0EEEE04Q8B01aLG40
@41005iNGP1ADE40?Cdm03Hf=P29RHT0KFe]03`l?01]KFd0]kNg06a/K00U9BD0:BTY05EEE@0i>CT0
<30`0410@02j^[X0WYjN08F5Q@1IFET0`<3009bLW00G5aL0O7al0;Jf]P1eMGD0=CDe09VIV@1QHF40
4A4A06YZJP2EUID0M7Ad02PX:01mOGd0>c/k028R8P1_Kfl0YJFU05mOG`1SHf<0MGEe04Q8B00P8200
@D5106IVIP27QhL0Ph>301dM7@1QHF40@d=302/[:`17AdL0ADE5059BDP2YZJT0MgMg04e=C@2_[jl0
VIVI03`l?00W9bL07QhN01`L700G5aL06QXJ01LG5`0201/K6`0605ADE02JVYX0^KVi0;Zj^P2HV9P0
UiNG0P2YZJT01@2f][H0XZ:R08J6QP1=CDd0;2`/00808B4Q04H0;Rh^07emO@2l_;`0GemO01hN7P0F
5QH09BDU01dM7@0E5AD05QHF01dM7@1MGEd0RXZ:079bLP1OGel0M7Ad059BDP18B4P0?Cdm03<c<`0_
;bl0CDe=09BDU02@T900MWIf09>CT`37alL0W9bL09:BTP0l?3`0=CDe024Q8@0G5aL05ADE01HF5P0G
5aL0;bl_08^;R`1GEeL0MWIf05MGE`1ZJVX0IFEU071`L02FUYH0De=C03/k>`0N7Qh06QXJ04A4A01:
BTX0ATI604Q8B01EEED0H61P03<c<`0a<C40;bl_04e=C@1WIfL0<c<c04a<C019BDT0ATI604Y:BP0U
9BD0<S8b04m?C`0V9RH07alO0P0Q8B400`0K6a/071`L01PH600201XJ6P0>03Ti>@1nOWh0[:b/06=S
H`0Y:BT09RHV03lo?`1SHf<0?clo05QHF02[Zj/0Ph>306m_K`0G5aL301DE5@0301TI6@0F5QH05aLG
00805ADE04h05aLG01HF5P0E5AD0=3@d04];B`28R8P0T92@07]kN`21PH40TI6A04A4A00g=cL0L71`
06IVIP12@T80<S8b02l_;`0^;Rh0Lg=c09>CT`3;bl/0RHV9055AD@0U9BD05QHF01DE5@0G5aL0=SHf
05=CD`23Ph<0a/K60;Fe]@2NWYh0De=C04A4A02@T900gMgM0=7Ad@31`L40WIfM08b<S01[Jf/0MWIf
0;>c/`1cLg<0CDe=03@d=00S8b<07alO06ATI02o_kl0a<C40;>c/`0/;2`05aLG01/K6`0T92@0CDe=
030`<00G5aL071`L020P802:RXX0F5QH03lo?`1PH600OWin0;Rh^01SHf<0UiNG09:BTP28R8P0Ng]k
05]KF`1bLW80_kno0:2PX00e=CD2034a<@0k03De=@1OGel0L71`02l_;`1YJFT0F5QH01/K6`0J6QX0
9bLW04A4A01YJFT0VYZJ04I6AP1:BTX0LW9b08j>SP1nOWh0A4A402/[:`0M7Ad071`L01XJ6P0F5QH0
5ADE01HF5P0E5AD0:b/[0410@01cLg<0EeMG08F5Q@3EeMD0OGem05]KF`2>SXh0d];B0;Vi^@16ATH0
>3Ph038b<P0g=cL0MgMg08B4Q01`L700TY:B0:FUY@2TY:@0Xj>S030`<00E5AD0?Cdm05MGE`0M7Ad0
6QXJ01`L700b<S80Vi^K06m_K`1iNGT0100E5AD0;@0N7Qh0J6QX08:2PP0O7al05ADE01/K6`0l?3`0
;Bd]05ADE02JVYX0`l?309bLW01/K6`07QhN01dM7@1YJFT06ATI01DE5@0G5aL061PH04I6AP21PH40
/[:b0:FUY@1_Kfl0emOG0<K6aP1nOWh0EeMG0861P@2l_;`0N7Qh061PH00P8200:2PX03Lg=`1HF5P0
Y:BT0=KFeP2QXJ40PH6105mOG`0Q8B406ATI01XJ6P02ooooo`0009`0/K6a09BDU01XJ6P0Fe]K0:n_
[`1>CTh0JVYZ06UYJ@1FEUH0Ph>30;Jf]P1HF5P0BTY:06m_K`19BDT0AdM706YZJP14A4@0Vi^K05AD
E013@d<0MWIf03Lg=`1dM7@0IVIV03Hf=P0_;bl0LW9b03lo?`0j>SX0G5aL03De=@0j>SX0MGEe071`
L01DE5@0OWin02l_;`0`<300MWIf0410@00n?Sh0De=C03De=@16ATH0<c<c05mOG`0h>3P09BDU04E5
A@1MGEd0ADE504M7A`1FEUH0?Cdm05iNGP1kNg/0Bd];08B4Q01ADE40:2PX08^;R`1aLG40=3@d02XZ
:P1TI6@0CTi>034a<@1:BTX0IfMW05ADE01<C4`0EeMG06=SH`0l?3`09RHV07alO01IFET0?Shn06i^
KP1CDe<0:b/[071`L01:BTX0E5AD04A4A01KFe/0Ogmo06m_K`0o?cl0;2`/05MGE`1OGel0;Rh^059B
DP2QXJ40GemO02d];@0c<c<0QHF506EUI@0V9RH0<c<c03lo?`1bLW80@d=308Z:RP1VIVH0LW9b05EE
E@1kNg/0Fe]K03`l?01aLG40=SHf05]KF`1ZJVX0IVIV08b<S017AdL0D51@07UiN@1NGUh0L71`04i>
CP0a<C40HF5Q07inOP1mOGd0OWin04U9B@0n?Sh0GEeM04i>CP1PH600UYJF07alO01SHf<0QXJ6065Q
H@13@d<0O7al051@D01aLG40CDe=05YJFP21PH40GUiN071`L01?Cdl0@T920;6a/@2NWYh0ATI603hn
?P2[Zj/205EEE@140:NWY`14A4@0XJ6Q061PH018B4P0AdM706][J`1IFET0?Cdm05eMG@1JFUX0;bl_
03@d=02BTY80>SXj07EeM@1cLg<0Jf][07]kN`1?Cdl0BDU907QhN01OGel0LW9b07emO@2g]kL0FUYJ
02d];@2MWId0SHf=03lo?`0f=SH0QhN70;Jf]P1iNGT0BDU90:ZZZP36a/H0A4A403Xj>P2[Zj/0<30`
05QHF02TY:@0Shn?03lo?`0m?Cd0PX:204I6AP2TY:@0NGUi0451@@2UYJD0QHF5051@D02g]kL0M7Ad
04E5A@1mOGd0JFUY03Lg=`2FUYH0I6AT02/[:`26QXH0Ph>303lo?`1BDU8205iNGP0B07]kN`0_;bl0
Kfm_08Z:RP1dM7@0Kfm_08j>SP1`L700S8b<04E5A@0_;bl0RXZ:08:2PP0h>3P0K6a/05IFEP0C4a<0
JFUY0P2?Shl0E@0n?Sh0Fe]K0861P@0V9RH0:RXZ069RHP1[Jf/0EUIF04];B`2MWId0UiNG02TY:@0M
7Ad0MgMg08F5Q@19BDT0AdM706=SH`0I6AT0F5QH06EUI@1NGUh0>SXj08B4Q01KFe/04a<C04I6AP1n
OWh0J6QX030`<00Z:RX0Hf=S04I6AP0`<3007QhN07inOP1oOgl0<S8b06ATI03Jf]X0_kno03Hf=P2B
TY80`l?307]kN`0a<C40Vi^K069RHP0l?3`0Cdm?05QHF01ZJVX09RHV07=cL`1PH6007QhN04m?C`2:
RXX0Hf=S06a/K01IFET0G5aL02HV9P0L71`09bLW05EEE@1aLG408R8R05mOG`15ADD0H61P04U9B@1P
H600UYJF0:JVYP1nOWh0Y:BT0:f][@2`/;00TI6A05]KF`0Z:RX08B4Q01`L700J6QX00P0G5aL0500E
5AD07QhN04a<C012@T80Z:RX05mOG`0R8R806a/K03Xj>P1:BTX0>SXj05QHF01/K6`0L71`07AdM01i
NGT0/[:b0;Vi^@2d];@0DE5A0P0L71`03P0S8b<0?Shn01LG5`0I6AT07alO04e=C@1?Cdl0D51@06YZ
JP0c<c<09BDU01dM7@0L71`07alO0P1BDU80<01/K6`0O7al08N7Q`1SHf<0GUiN07EeM@1bLW80?Cdm
03Lg=`0n?Sh0ATI603lo?`0N7Qh05QHF02`/;02IVIT0WYjN08V9R@1XJ6P0TY:B05eMG@24Q8@0NGUi
08>3P`1aLG40F5QH06UYJ@1IFET0?Shn03Xj>P0l?3`0DE5A05aLG00m?Cd09RHV01LG5`0H61P0:BTY
04a<C00];Bd0KVi^05aLG01BDU80EeMG06=SH`0m?Cd06a/K01dM7@<071`L00P05QHF01TI6@0H61P0
71`L03Hf=P1gMgL0QHF502d];@8071`L0;00:RXZ05]KF`0d=3@0E5AD08^;R`2?Shl0Lg=c02TY:@0I
6AT05ADE01PH600I6AT05aLG01TI6@0F5QH05ADE01HF5P0E5AD05QHF02d];@1UIFD0IVIV0<g=c@2I
VIT0J6QX06i^KP2[Zj/0SXj>03Xj>P0];Bd0;2`/02PX:00];Bd0>CTi0820P03Fe]H0SXj>01/K6`0V
9RH0EUIF05aLG012@T80FUYJ09:BTP2>SXh0`<300;^k^`1LG5`0CDe=08b<S00m?Cd0Xj>S0<?3``25
QHD0IFEU03Xj>P0^;Rh0:b/[04];B`1<C4`0:b/[01hN7P0L71`07AdM01hN7P1[Jf/0a/K605UIF@1<
C4`0V9RH04i>CP0H61P0820P02d];@1;Bd/092@T03Ph>011@D40MgMg09NGU`1?Cdl0I6AT08>3P`2Z
ZZX0EeMG0:NWY`2YZJT0;Bd]038b<P18B4P0CTi>07IfMP2OWil0M7Ad02h^;P0U9BD0;bl_04=3@`27
QhL0PH6108f=S@10@4005QHF01XJ6P0Y:BT0<c<c02HV9P1jNWX0MgMg03hn?P14A4@0LW9b09>CT`1F
EUH0?Shn02l_;`0P820092@T028R8P0/;2`06QXJ01TI6@0d=3@0IVIV07=cL`17AdL0GEeM0<G5a@2H
V9P0?clo03<c<`0e=CD0;bl_01`L700E5AD05aLG024Q8@1NGUh0NGUi04i>CP2CTi<0TI6A0<k>cP37
alL0B4Q80451@@1>CTh07QhN01HF5P0K6a/07AdM02`/;02QXJ40V9RH0:FUY@0O7al05aLG01`L700Q
8B40ADE509jNWP1CDe<04a<C01LG5`0N7Qh0ADE501hN7P1fMWH0K6a/0;Vi^@2TY:@09BDU01PH600J
6QX0CDe=03lo?`805ADE01X05aLG05YJFP2PX:00TY:B05]KF`2FUYH0SHf=03Xj>P1[Jf/0W9bL0:VY
Z@2PX:00b<S80:f][@10@400GEeM09^KV`2j^[X0V9RH0;jn_P1FEUH0Rh^;06a/K00i>CT07AdM01lO
7`;ooooo0000SP2VYZH0V9RH06=SH`1iNGT0XJ6Q04];B`1dM7@0SHf=061PH02<S8`0^k^k05=CD`1<
C4`0L71`04Y:BP1;Bd/0NWYj03lo?`1gMgL0=3@d05eMG@21PH40>c/k07alO01VIVH0DU9B05YJFP1h
N7P0AdM704Q8B01JFUX0?Cdm02h^;P1KFe/0E5AD07IfMP2;Rh/0<c<c03Xj>P21PH40:2PX05MGE`1X
J6P0<30`03De=@0U9BD0IFEU02h^;P0b<S80JVYZ04i>CP11@D40B4Q804m?C`0`<300I6AT07IfMP0k
>c/0QhN70451@@0M7Ad0MWIf06YZJP0];Bd0;2`/06YZJP1[Jf/08b<S03@d=01HF5P0BDU904e=C@1]
KFd0M7Ad03hn?P0V9RH0MWIf03/k>`1NGUh0RHV905QHF00a<C40FUYJ03Xj>P1GEeL0GUiN08:2PP2P
X:00L71`03lo?`0k>c/0L71`06=SH`0m?Cd0=cLg09RHV017AdL0;Bd]05IFEP2BTY80Hf=S01lO7`0e
=CD0?Cdm059BDP0R8R80PX:20820P01bLW80?Shn08Z:RP1=CDd0=SHf096AT@1;Bd/0MWIf04i>CP1`
L700Vi^K04m?C`1LG5`0FUYJ0410@01UIFD0KFe]04a<C01ZJVX08R8R03lo?`2;Rh/0IFEU03Ti>@1@
D5006a/K06=SH`2?Shl0PH6106m_K`1`L700>3Ph02LW9`2DU9@205iNGP2n01<C4`1MGEd0WYjN06QX
J02JVYX0HF5Q034a<@1eMGD0Shn?06=SH`12@T80_[jn03Ph>01>CTh0Xj>S04];B`2ZZZX0ATI602h^
;P1oOgl0RHV906a/K00j>SX0De=C04a<C00P8200>CTi092@T00l?3`0MgMg05QHF01`L700^KVi06MW
I`1DE5@0W9bL05=CD`17AdL0MGEe0;Ng]`1gMgL0>c/k0:2PX02OWil0?Cdm034a<@26QXH0ZZZZ06a/
K01[Jf/0_Kfm0<?3``1bLW80AdM70:RXZ01_Kfl0F5QH0;2`/01jNWX0@d=304U9B@2HV9P0=3@d092@
T02DU9@09bLW03/k>`1;Bd/0@d=30;Jf]P1?Cdl08R8R04a<C01NGUh0@D510<C4a01lO7`08R8R06IV
IP1_Kfl0BTY:09^KV`2OWil0Vi^K08n?S`0Q8B40C4a<06UYJ@1dM7@0GemO09>CT`2?Shl0S8b<0410
@00T92@0Bd];079bLP0j>SX0JVYZ06][J`15ADD0EeMG05IFEP1XJ6P0=CDe08>3P`32`/80QhN702d]
;@13@d<0Fe]K02PX:00C4a<0Vi^K0<G5a@1[Jf/08B4Q06EUI@1jNWX0ADE504I6AP1VIVH0BDU9051@
D011@D40CDe=0410@029RHT0ADE502`/;01KFe/0N7Qh055AD@0`<300J6QX0;Fe]@2MWId0N7Qh02@T
9029RHT0OGem065QH@1>CTh0VYZJ09BDU012@T80Xj>S0=7Ad@2>SXh0<c<c0;>c/`1]KFd0B4Q806a/
K01KFe/0H61P01lO7`2<S8`0Ng]k02DU9@1EEED0Q8B405YJFP22PX80GUiN05MGE`0b<S808b<S03<c
<`1JFUX0LW9b028R8P1MGEd0@T9207=cL`2BTY80/k>c0;Ng]`2LW9`0Rh^;05eMG@2?Shl0Cdm?08R8
R02<S8`0Jf][03Xj>P0N7Qh06a/K01HF5P805ADE00D05QHF04m?C`0M7Ad0G5aL03Ph>002010@400H
02HV9P0[:b/061PH010@400A4A406ATI03Hf=P2XZ:P0N7Qh02XZ:P0j>SX0NGUi034a<@0N7Qh09BDU
034a<@0Z:RX06ATI01/K6`0i>CT0@d=3030`<00R8R804a<C0`0E5AD08P0G5aL0@T92075aL@1[Jf/0
EeMG038b<P0N7Qh08b<S07inOP1BDU8092@T02HV9P0E5AD061PH02`/;01JFUX0K6a/05UIF@1TI6@0
MgMg07inOP2KVi/0Hf=S05MGE`0h>3P0E5AD05mOG`1ADE40Cdm?092@T027QhL0M7Ad07YjNP1QHF42
02DU9@0A03Lg=`1CDe<0A4A402<S8`0H61P09bLW0492@P13@d<0Shn?08^;R`2VYZH0EUIF0492@P0Q
8B407alO01`L700M7Ad00P0K6a/301`L700@04M7A`1oOgl0JFUY01hN7P0L71`07AdM02LW9`1MGEd0
Fe]K03Hf=P1;Bd/0Vi^K06i^KP1BDU80>SXj01HF5P@05ADE07H05QHF01@D500H61P05ADE01LG5`0_
;bl0IVIV06m_K`2CTi<0fm_K0;Vi^@2IVIT0Ph>305YJFP15ADD0?3`l0410@01^KVh0Xj>S0;Jf]P2d
];@0d=3@04i>CP0g=cL0=3@d03Hf=P1]KFd0Ti>C0820P01KFe/0CDe=05iNGP2OWil0?Cdm02PX:01D
E5@0V9RH0:ZZZP0k>c/092@T02HV9P0U9BD0<S8b04Y:BP14A4@07alO01TI6@0J6QX07AdM024Q8@0a
<C40ZZZZ0:^[Z`1RHV806a/K04M7A`2XZ:P0@D51028R8P0Y:BT0Cdm?07inOP0h>3P0ADE505ADE031
`L40Lg=c08>3P`1bLW80P820065QH@2?Shl0UiNG059BDP0I6AT061PH03Lg=`1BDU80][Jf09VIV@1[
Jf/0Bd];03`l?014A4@0S8b<0;bl_02MWId0=CDe01XJ6P0K6a/0=cLg01dM7@0K6a/0@d=309nOW`1T
I6@0DE5A05IFEP29RHT0UIFE05QHF01:BTX0AdM7034a<@0_;bl0E5AD030`<011@D40Ph>30:>SX`1U
IFD0>3Ph07inOP2KVi/0DE5A01PH600E5AD061PH0P0G5aL06@0C4a<06QXJ024Q8@1IFET0O7al05aL
G02OWil0ZJVY075aL@2HV9P0b<S80861P@0I6AT06a/K01TI6@0M7Ad07QhN05eMG@2i^KT0YZJV0;Rh
^00W9bL0:RXZ02HV9P1HF5P00P2@T900:`0P82005aLG01`L700U9BD0B4Q801hN7P1]KFd0<S8b0861
P@1eMGD0;bl_01LG5`0J6QX08b<S08f=S@0I6AT061PH03<c<`2UYJD0QHF504M7A`1PH600Xj>S02DU
9@0G5aL06a/K024Q8@1;Bd/0Vi^K0;Vi^@33`l<0e]KF0;fm_@1NGUh0:2PX024Q8@23Ph<0/;2`0:JV
YP2k^k/0][Jf08^;R`2BTY800_ooool0003o08J6QP2[Zj/0I6AT08B4Q01IFET0=cLg07AdM023Ph<0
KFe]09JFUP1=CDd0=CDe06MWI`2;Rh/0?Shn05iNGP0l?3`0BDU908V9R@11@D40DE5A04m?C`0^;Rh0
TI6A0492@P11@D40CDe=02XZ:P0R8R80@410069RHP0l?3`0<c<c03hn?P0U9BD0ATI606YZJP0b<S80
Lg=c09ZJVP0S8b<0<S8b04I6AP0`<300<S8b018B4P1HF5P0;Rh^02<S8`1UIFD05QHF02LW9`1;Bd/0
EeMG02PX:012@T80;Bd]01lO7`2LW9`0D51@02@T901nOWh0A4A4010@401EEED0Q8B405mOG`0M7Ad0
>3Ph05=CD`0D51@09bLW04M7A`1DE5@0=CDe04M7A`2:RXX08R8R03Xj>P1OGel0CDe=02DU9@1IFET0
;2`/06i^KP1KFe/0S8b<09RHV027QhL05ADE02d];@1VIVH0NWYj04U9B@1;Bd/0V9RH034a<@0J6QX0
820P05eMG@1:BTX06QXJ03Ti>@13@d<0HV9R02d];@1XJ6P0@d=305mOG`0m?Cd0NGUi04A4A00/;2`0
Ng]k04E5A@1MGEd0>c/k05ADE022PX80BTY:06a/K01@D500=SHf04];B`1XJ6P0BTY:06m_K`0m?Cd0
=SHf05mOG`1BDU80@T9205]KF`0l?3`0@D5105aLG01_Kfl0MWIf07MgM`1NGUh0>SXj06][J`1IFET0
IVIV0492@P1@D500NGUi05mOG`2BTY80MWIf04Q8B01oOgl0U9BD03Xj>P1nOWh0c/k>07MgM`18B4P0
PH6104a<C033`l<0C4a<02HV9P11@D40EUIF04Q8B00f=SH0GEeM05IFEP0I6AT0>3Ph08Z:RP0i>CT0
MWIf03/k>`13@d<0OWin07]kN`1LG5`0WIfM04M7A`0K6a/0?3`l07emO@1MGEd09BDU0:6QX@2<S8`0
Ogmo03/k>`2FUYH0Q8B4020P8016ATH0ZJVY0:FUY@1iNGT0BDU909BDU01bLW80Fe]K0;2`/01OGel0
>SXj05]KF`2][Jd0Jf][08:2PP1eMGD0:RXZ06=SH`10@400MgMg0<k>cP1RHV80QXJ60:2PX015ADD0
=3@d07UiN@1oOgl0>CTi07IfMP1ADE40;bl_03dm?@1ADE40_Kfm0:b/[01<C4`0I6AT05EEE@1oOgl0
?Shn09bLW03Hf=P0_[jn05]KF`1CDe<0I6AT05QHF00e=CD0SHf=05EEE@16ATH0HV9R08^;R`10@400
51@D059BDP2KVi/0HF5Q02/[:`15ADD0BDU9001h05iNGP0m?Cd0MGEe08b<S01WIfL0:RXZ07=cL`1T
I6@0;Rh^08Z:RP2g]kL0KFe]06YZJP16ATH0De=C04Y:BP2QXJ40DE5A0492@P1XJ6P0Kfm_04U9B@0G
5aL0@T9206=SH`2?Shl0M7Ad02<S8`28R8P0TY:B08F5Q@1ZJVX0dm?C0;2`/00o?cl0Zj^[0<k>cP2:
RXX0C4a<0=[JfP2f][H0ATI606IVIP1IFET0HF5Q02LW9`2WYjL0OGem02<S8`1DE5@0Ph>3069RHP2J
VYX0J6QX04a<C00a<C40:2PX02XZ:P1ADE40EEEE01PH601jNWX0KVi^07]kN`3MgMd0eMGE0;Fe]@20
P800I6AT07AdM01NGUh0KVi^04i>CP1QHF40Ph>305eMG@1=CDd0<S8b01dM7@0K6a/06ATI01LG5`13
@d<0:BTY03<c<`1GEeL04A4A00h>3P0_;bl0AdM7024Q8@0C4a<04Q8B01@D500G5aL0QhN703`l?00T
92@09bLW09FEU@1^KVh0CDe=03`l?00c<c<0BTY:02LW9`0Z:RX0?clo04i>CP0`<300820P01@D500C
4a<051@D01LG5`0a<C40Fe]K03lo?`1JFUX0:b/[0P0I6AT00`0J6QX0GEeM08J6QP0202PX:00G01/K
6`0L71`0:BTY03lo?`2ATI40/k>c08V9R@1[Jf/0IfMW0;>c/`1>CTh0=CDe01hN7P0h>3P0AdM703@d
=00V9RH0ATI604U9B@1<C4`0HF5Q05ADE00H61P00P0E5AD03@0O7al0>SXj04a<C016ATH0<c<c030`
<015ADD0OWin0<K6aP2EUID0Q8B404a<C00S8b<00P0P8200600T92@09BDU020P800L71`07AdM01hN
7P1QHF40PX:207IfMP0O7al0820P028R8P0U9BD0>3Ph071`L011@D40EUIF0;Rh^01mOGd0FEUI04];
B`0h>3P07AdM01LG5`H05ADE02H06ATI03`l?02PX:00Ng]k0:^[Z`3Hf=P0QXJ6055AD@1DE5@0Cdm?
07UiN@2l_;`0V9RH061PH00c<c<07alO02LW9`2PX:00/K6a07QhN01VIVH0D51@06YZJP3>c/h0FEUI
03Lg=`0n?Sh0NGUi0<71`@1^KVh0HF5Q069RHP3;bl/0X:2P05iNGP1aLG40Ng]k06ATI080KFe]01h0
HV9R06ATI01KFe/0GUiN05QHF017AdL0V9RH08Z:RP2ZZZX0Shn?02DU9@0O7al0E5AD0:2PX00i>CT0
@41006=SH`1:BTX0DE5A075aL@22PX80_Kfm08:2PP0j>SX0KFe]02d];@0I6AT0=3@d05YJFP1GEeL2
03De=@0W03Ph>01;Bd/0[jn_09ZJVP27QhL0?3`l0410@01NGUh0XZ:R0<K6aP2WYjL0EeMG02`/;00Q
8B409RHV01PH600N7Qh0=3@d05MGE`16ATH0IVIV05ADE01OGel0WIfM07]kN`0h>3P0ATI6059BDP11
@D40=SHf06IVIP26QXH0RHV906UYJ@1MGEd0?Cdm09fMW@1[Jf/0EeMG00805ADE03H05aLG01DE5@0E
5AD051@D01XJ6P0M7Ad0@410096AT@29RHT0Ng]k07YjNP1@D500CTi>0:b/[01/K6`061PH01/K6`0I
6AT07AdM03Ti>@1WIfL0HF5Q0;^k^`33`l<0BDU903De=@0g=cL0Cdm?09nOW`1KFe/0;2`/02h^;P1O
Gel0QhN705IFEP0W9bL0H61P01lO7`13@d<0Vi^K069RHP0K6a/06QXJ01hN7P1cLg<0De=C03De=@2V
YZH0T92@04M7A`1OGel0]kNg04I6AP0G5aL201/K6`0A024Q8@0Y:BT0ATI603Ti>@0];Bd0JFUY07mo
O`0H61P05aLG028R8P2k^k/0dM7A0;Bd]036a/H0W9bL07YjNP1]KFd00_ooool0000S07IfMP2<S8`0
F5QH08b<S01lO7`0@D5106ATI01iNGT0L71`08N7Q`1hN7P0?3`l04=3@`1[Jf/0?Shn06a/K01?Cdl0
?3`l07IfMP0j>SX0EUIF051@D00T92@0K6a/05QHF00l?3`0BDU906a/K00c<c<0>SXj04i>CP0Z:RX0
EEEE08R8R01BDU800P1@D500K`0J6QX0A4A407moO`10@400ADE504m?C`0P8200BTY:02/[:`1KFe/0
@41004a<C01nOWh0=SHf04E5A@11@D40AdM702DU9@1CDe<0?clo028R8P20P800>CTi01lO7`23Ph<0
B4Q800h>3P0W9bL0Fe]K04M7A`0n?Sh0MgMg08^;R`16ATH0Cdm?06=SH`0f=SH05QHF02LW9`1jNWX0
ADE506ATI01aLG40?3`l01/K6`14A4@0<S8b0492@P0_;bl0SXj>09VIV@1FEUH08B4Q02HV9P11@D40
IfMW04I6AP18B4P0S8b<05iNGP0_;bl0:2PX08N7Q`13@d<0:RXZ05aLG01NGUh0IfMW03/k>`1fMWH0
ATI604e=C@15ADD0M7Ad059BDP0n?Sh0N7Qh04M7A`29RHT0Jf][06UYJ@1aLG40KVi^0:b/[028R8P0
JVYZ07YjNP1mOGd0BTY:08b<S01hN7P0GEeM06IVIP13@d<0Kfm_06e]K@1HF5P0De=C07emO@1ZJVX0
Ng]k0:BTY01cLg<0BDU906m_K`1XJ6P0PH61055AD@1XJ6P0H61P03dm?@020;^k^`2E05mOG`2<S8`0
S8b<02PX:019BDT0/[:b06IVIP1CDe<0Q8B403Lg=`2i^KT0V9RH059BDP17AdL0H61P03Ti>@1JFUX0
/;2`09NGU`10@400@T9208^;R`0m?Cd0TY:B07inOP1VIVH0TY:B06=SH`1KFe/0WIfM05QHF011@D40
RXZ:08n?S`0k>c/0ADE50;Bd]02CTi<0RHV903/k>`2RXZ80S8b<059BDP1GEeL0`/;209BDU026QXH0
@D5107QhN01dM7@0HF5Q0;6a/@17AdL0=cLg05UIF@2_[jl0MGEe0::RXP1cLg<09bLW05iNGP1<C4`0
?clo08F5Q@2DU9@0Shn?09NGU`1:BTX0>3Ph08^;R`1PH600=3@d07UiN@1UIFD0>3Ph02TY:@0F5QH0
PX:207inOP0i>CT0QhN705IFEP1PH600=SHf07moO`27QhL0SXj>071`L012@T80E5AD04E5A@0J6QX0
P82008F5Q@1DE5@0HF5Q0:FUY@1eMGD0=cLg05iNGP2HV9P0@T92038b<P1ADE40Cdm?065QH@1<C4`0
/[:b09FEU@1LG5`0=3@d09FEU@1cLg<09bLW03De=@1NGUh0?clo061PH014A4@0?clo07inOP2_[jl0
QHF504];B`1QHF40Kfm_06UYJ@0Q8B40<S8b06QXJ025QHD0G5aL0410@02CTi<0U9BD07AdM01EEED0
emOG0:ZZZP0h>3P0bLW90=SHf01dM7@08R8R09jNWP2/[:`0Bd];06YZJP1HF5P00P0m?Cd07P34a<@0
UiNG02HV9P1ADE40V9RH061PH02i^KT0`/;206UYJ@0d=3@08b<S02HV9P1GEeL0:BTY02HV9P2CTi<0
UIFE08:2PP2j^[X0_;bl06ATI01?Cdl0@D5103Ti>@0Z:RX0?Cdm07moO`1HF5P0GemO06m_K`80DE5A
04P0?Shn030`<00Y:BT0<c<c07YjNP1BDU80:2PX061PH00W9bL07QhN04Q8B01oOgl0GUiN065QH@0l
?3`0;Rh^03Ph>02RXZ80EeMG03De=@1TI6@0][Jf0<C4a02b/[80YjNW09fMW@1kNg/0DU9B04i>CP1I
FET0N7Qh07AdM01CDe<0;Bd]01XJ6P0H61P0>c/k05]KF`0a<C40D51@02h^;P0I6AT05aLG01XJ6P0K
6a/0>CTi0<o?c`1RHV80@d=304];B`1SHf<0NWYj07moO`1DE5@0=SHf06EUI@2JVYX0OWin071`L00Y
:BT05QHF01DE5@0R8R80Cdm?02l_;`0Q8B405aLG04];B`0d=3@0?clo04Q8B00T92@301DE5@0401TI
6@0M7Ad07QhN04];B`80Hf=S0240/[:b06ATI02BTY80Q8B408n?S`1@D5008B4Q01XJ6P0M7Ad0820P
024Q8@0M7Ad071`L030`<01ZJVX0Ph>308J6QP0_;bl09BDU02`/;00X:2P09RHV06m_K`2>SXh0[jn_
0<[:bP2VYZH0;bl_03@d=01<C4`0@T92020P800C4a<00`0E5AD0;00G5aL06ATI020P801XJ6P0Shn?
07]kN`2WYjL0h^;R0;jn_P2a/K40]kNg0=CDe03MgMd0PH6102TY:@0G5aL05ADE02LW9`16ATH0Rh^;
02XZ:P0V9RH0?Cdm06=SH`2=SHd0`/;20;:b/P1fMWH0KVi^0<S8b03@d=00WinO09FEU@2e]KD0dM7A
09BDU01gMgL0EEEE03Xj>P0_;bl09BDU03hn?P0Y:BT06QXJ0P0G5aL05@0S8b<0@4100;Zj^P12@T80
IVIV0=SHf02:RXX0:RXZ01`L701ADE40YZJV0820P02:RXX0JFUY03Lg=`0Z:RX09bLW07inOP1WIfL0
=CDe06YZJP0201TI6@0_024Q8@0e=CD0<c<c055AD@1PH600?Cdm03hn?P22PX80RXZ:0<71`@21PH40
C4a<065QH@2h^;P0b/[:0;Vi^@1mOGd0I6AT03Ph>00K6a/071`L01dM7@0_;bl0Hf=S01XJ6P0M7Ad0
FEUI06ATI01`L700WinO071`L00i>CT0Bd];06UYJ@2][Jd0]kNg09nOW`1ZJVX0MGEe06IVIP1YJFT0
^;Rh05MGE`1[Jf/05aLG01DE5@0G5aL00P0E5AD0100D51@05aLG02<S8`1HF5P2092@T01003Ph>00m
?Cd0K6a/04];B`25QHD0UiNG01/K6`0L71`07alO03Ti>@0m?Cd0DU9B079bLP30`<00[:b/05]KF`1S
Hf<0H61P0:^[Z`3?cll0DE5A02DU9@0];Bd0@d=308j>SP1YJFT0@d=303`l?00J6QX08b<S07moO`2J
VYX0NWYj05aLG01CDe<0Xj>S0;bl_032`/80PH6105mOG`1aLG40b<S80=7Ad@0Q8B4061PH01`L700M
7Ad07QhN024Q8@1VIVH08R8R01DE5@0G5aL0DU9B0492@P0Q8B40Ogmo09FEU@1]KFd0[Zj^0;Vi^@30
`<00MWIf07AdM0;ooooo00002`2UYJD0/[:b05]KF`2l_;`0WYjN04];B`1`L700I6AT07YjNP2QXJ40
];Bd0080C4a<00l0B4Q802d];@2@T900MWIf051@D01]KFd0;2`/08Z:RP2CTi<0?Cdm09BDU01KFe/0
CDe=06UYJ@2@T9000P0i>CT02P1DE5@05ADE03/k>`1RHV80E5AD04e=C@2:RXX0<c<c04=3@`2PX:02
03lo?`1:04M7A`0f=SH0AdM702TY:@17AdL071`L03De=@1lO7`0?3`l059BDP14A4@0>SXj02l_;`1Y
JFT0IfMW03Ti>@2IVIT08R8R01lO7`2ATI40LW9b02LW9`0i>CT0LG5a02LW9`0b<S80ATI605=CD`0_
;bl0H61P07inOP1;Bd/0:BTY03@d=01eMGD0=SHf05iNGP1dM7@0:RXZ02DU9@1ZJVX0?3`l05IFEP0d
=3@0OWin09RHV010@40092@T038b<P0m?Cd0CTi>03<c<`19BDT0Vi^K06ATI00b<S80:BTY08n?S`0e
=CD07QhN03lo?`1MGEd0QHF503dm?@1UIFD0B4Q803De=@0b<S80UYJF05]KF`0n?Sh0H61P02XZ:P2I
VIT2065QH@0K05iNGP0e=CD0GemO075aL@1NGUh0L71`06a/K00[:b/0OWin06MWI`17AdL0NGUi034a
<@14A4@0M7Ad05aLG01BDU80LW9b03Xj>P11@D40Zj^[08n?S`14A4@0HF5Q05MGE`26QXH0BDU90080
IfMW0700:BTY0820P02<S8`0GemO09JFUP2MWId0CDe=05IFEP30`<00IfMW06UYJ@2UYJD0ADE50;6a
/@1eMGD0ATI605iNGP1VIVH0B4Q803Lg=`1EEED0L71`055AD@1<C4`0K6a/02PX:01RHV80UIFE05]K
F`2?Shl0>c/k03<c<`2DU9@0OGem05YJFP2=SHd0XJ6Q024Q8@10@400Ogmo08B4Q01`L700>SXj09fM
W@2LW9`0M7Ad06UYJ@37alL0XZ:R08j>SP1LG5`0TY:B08f=S@1SHf<0/;2`06=SH`1=CDd0Jf][0:b/
[01bLW80VYZJ05UIF@0Y:BT0Fe]K05EEE@15ADD0XJ6Q05aLG01oOgl0UIFE05mOG`13@d<0^k^k0861
P@0l?3`0O7al071`L00b<S80:RXZ01LG5`1CDe<0JVYZ030`<02MWId0I6AT05mOG`1WIfL0VIVI08n?
S`1/K6`0B4Q80451@@2ATI40IfMW03Lg=`1nOWh0GEeM04U9B@2HV9P0`/;207inOP0o?cl0Fe]K0861
P@0_;bl0?3`l06MWI`1[Jf/0L71`059BDP2j^[X0TY:B0P0Q8B40?P2DU9@0PH6103Ti>@0m?Cd0GemO
030`<01iNGT0GUiN03dm?@0g=cL0SXj>04Q8B00`<300RHV90<30`02;Rh/0<C4a030`<01VIVH0<c<c
01PH600Q8B40H61P079bLP17AdL0=CDe0=?Cd`2QXJ40=SHf08n?S`2o_kl0HV9R02@T9025QHD0GUiN
03Hf=P2TY:@0QHF503Hf=P0G5aL0PH6106m_K`0V9RH0De=C0:BTY016ATH0Ogmo08^;R`1BDU80<C4a
02<S8`0^;Rh0JVYZ04];B`0G5aL0EeMG065QH@0`<300QhN70:FUY@1JFUX0=CDe0P0V9RH0?@0W9bL0
;2`/0492@P0l?3`0>c/k07]kN`21PH40K6a/06][J`1XJ6P0L71`04i>CP0f=SH0JVYZ06IVIP1OGel0
MgMg04i>CP0n?Sh0D51@04M7A`10@400=cLg03@d=01HF5P0L71`09bLW02RXZ80b/[:08:2PP1BDU80
AdM705mOG`1lO7`0WYjN08^;R`2=SHd0QHF507MgM`29RHT0RXZ:05UIF@1ADE40MgMg06i^KP0c<c<0
Bd];030`<00I6AT05aLG02DU9@0I6AT06QXJ08j>SP2QXJ40][Jf0=;BdP2f][H0Ph>303`l?00K6a/0
0P0M7Ad0500c<c<0?3`l05ADE00b<S80;Bd]01@D500C4a<05aLG05ADE00b<S808B4Q01DE5@0Q8B40
@D5104Q8B01>CTh0>CTi01XJ6P0E5AD061PH0P0J6QX05P0L71`07alO04Y:BP34a<@0QXJ606MWI`1X
J6P0TY:B09VIV@1GEeL0?clo03@d=00b<S809bLW01lO7`0M7Ad07alO06MWI`1JFUX0N7Qh08b<S00k
>c/203<c<`0U030`<010@400PH6109JFUP2KVi/0`l?308b<S025QHD0DE5A024Q8@0`<300@d=303Xj
>P0^;Rh07alO02<S8`0b<S80D51@06IVIP1aLG40O7al05mOG`2EUID0c<c<09FEU@2HV9P0PH6108N7
Q`2MWId0OGem03hn?P18B4P0?Cdm04Y:BP1JFUX0=3@d01HF5P0201DE5@0?01LG5`0P8200I6AT06IV
IP0c<c<0Hf=S06ATI02YZJT0ADE503/k>`15ADD0WYjN03Hf=P0N7Qh05QHF00805ADE00H0:2PX038b
<P0A4A40410@01<C4`0A4A4201<C4`0C06i^KP10@400CDe=0;:b/P2<S8`0UYJF06QXJ00Q8B40O7al
09FEU@1FEUH0:BTY01/K6`0M7Ad05aLG05iNGP2BTY80Ph>305aLG00301DE5@0T01lO7`0a<C40;Rh^
024Q8@0E5AD05QHF03Hf=P27QhL0^KVi0<W9b@1nOWh0JFUY09ZJVP1]KFd0SXj>0;Vi^@2][Jd0TY:B
02DU9@0I6AT071`L024Q8@17AdL05QHF01PH600M7Ad0EUIF07]kN`2;Rh/0^;Rh09FEU@1gMgL0PX:2
09jNWP2m_Kd0]kNg0P2=SHd01P2FUYH0`L710:VYZ@1DE5@0Ti>C02<S8`805aLG03406ATI01`L700I
6AT09bLW04];B`2QXJ40_kno05]KF`1gMgL07alO06IVIP1=CDd0Ph>30<S8b01PH600De=C05MGE`1b
LW80OWin09FEU@2`/;00a/K60<W9b@2ATI40DE5A03Lg=`0i>CT0De=C08b<S010@4009bLW030`<01J
FUX0GemO07UiN@0S8b<07AdM02<S8`1lO7`0e=CD0<30`02][Jd0/[:b08Z:RP2JVYX0][Jf08J6QP2o
_kl0c<c<0080XJ6Q00P0EEEE01/K6`0G5aL06a/K020P800j>SX0QXJ601/K6`805ADE00/07QhN06IV
IP2BTY80Rh^;03Xj>P1TI6@0bLW90<o?c`3;bl/0fm_K0<g=c@02ooooo`0004X0VIVI0;Ng]`1DE5@0
PX:208J6QP1:BTX0LW9b04U9B@13@d<0MgMg09bLW019BDT0BTY:06a/K00h>3P0O7al075aL@1KFe/0
NWYj02XZ:P1@D500L71`04I6AP2WYjL0>SXj08n?S`2GUiL0O7al02l_;`0^;Rh0HV9R03Hf=P0a<C40
JFUY06e]K@1>CTh0PX:202l_;`1:BTX0X:2P0410@00i>CT0B4Q803hn?P1CDe<09bLW06IVIP0e=CD0
<c<c07]kN`10@400CTi>05=CD`0X:2P0B4Q80861P@1kNg/0>c/k0;2`/00B4Q80<C4a09JFUP1kNg/0
:2PX04E5A@1eMGD0De=C034a<@14A4@0IFEU03hn?P1WIfL0U9BD05iNGP80<c<c06P0MWIf0451@@1_
Kfl0Shn?05EEE@0S8b<0D51@0410@01>CTh0?3`l08Z:RP3=cLd0Bd];034a<@0n?Sh0>SXj04M7A`0U
9BD0Q8B40;2`/01SHf<0@41005QHF024Q8@0BDU901/K6`0h>3P0ATI605UIF@1<C4`0Ti>C07QhN01D
E5@0@T92065QH@0Y:BT0I6AT061PH011@D40Lg=c04e=C@29RHT0MgMg04i>CP1_Kfl0HF5Q06ATI02?
Shl0QhN704a<C01nOWh0GEeM04=3@`1[Jf/0B4Q805aLG01MGEd0>CTi06i^KP2DU9@0K6a/06e]K@2M
WId0<C4a04Q8B01YJFT0De=C05IFEP0d=3@0R8R806m_K`1NGUh0NWYj05UIF@13@d<0W9bL09^KV`15
ADD0GUiN09^KV`0f=SH0T92@09JFUP10@400a<C403lo?`0/;2`0OGem07inOP1EEED0=3@d04i>CP1I
FET0;Bd]06m_K`2?Shl0?Shn05aLG01JFUX0J6QX0:JVYP0i>CT0?3`l06MWI`80CDe=0300VIVI0:FU
Y@0g=cL0<c<c096AT@22PX80LW9b04E5A@2h^;P0[jn_079bLP1VIVH0_Kfm0:RXZ00l?3`0Hf=S0:>S
X`2<S8`0FEUI0;:b/P0l?3`061PH071`L02NWYh0De=C08n?S`1ADE40Cdm?0:2PX01BDU80CDe=0;6a
/@18B4P0HF5Q08^;R`11@D40?3`l0;Vi^@1iNGT0?Cdm07moO`1lO7`0?Shn03@d=00X:2P0E5AD061P
H00_;bl20:b/[01K08b<S01YJFT0V9RH08Z:RP2@T900FUYJ02d];@1CDe<0H61P03/k>`1jNWX0>c/k
01lO7`19BDT0HF5Q06e]K@10@400FUYJ07YjNP1CDe<09RHV03Xj>P1UIFD0MWIf051@D02k^k/0SHf=
05MGE`0V9RH0IFEU0861P@15ADD0@T9205]KF`0L71`0@D5105=CD`1RHV80BDU909nOW`1MGEd0820P
059BDP1ZJVX0OWin02`/;00e=CD0IfMW07QhN013@d<09bLW07AdM01gMgL0BDU90410@02WYjL0f=SH
06ATI031`L40eMGE075aL@0[:b/0/;2`07UiN@0/;2`0M7Ad07emO@1OGel08b<S09nOW`0];Bd07AdM
075aL@2c/k<0Hf=S08J6QP2VYZH0@41001<C4`0/;2`0C4a<07alO01CDe<06QXJ06EUI@1oOgl0J6QX
096AT@2h^;P0OGem034a<@0202DU9@0402<S8`0V9RH09BDU0451@@80D51@00D0C4a<04m?C`1EEED0
D51@03hn?P0203dm?@0704M7A`1lO7`0OWin092@T01GEeL0Hf=S05iNGP02038b<P0_04U9B@1WIfL0
>SXj02XZ:P0l?3`0[jn_0=7Ad@1jNWX0Ng]k06e]K@1UIFD0GEeM02HV9P0Q8B40:BTY05ADE02?Shl0
SHf=07emO@1nOWh0Rh^;0;Fe]@2:RXX0MgMg04e=C@16ATH0?3`l03Hf=P0R8R80;Rh^07YjNP1LG5`0
5ADE04M7A`23Ph<0@T9202XZ:P0K6a/071`L01dM7@0R8R809bLW02d];@1MGEd0=CDe03lo?`0M7Ad0
0P0E5AD00`1=CDd0=cLg02HV9P0201DE5@0>04m?C`1CDe<0GEeM04Q8B00X:2P061PH01XJ6P0H61P0
71`L01dM7@0V9RH0<c<c07inOP2FUYH205IFEP0D04A4A02QXJ40`l?308>3P`1cLg<0LG5a06a/K01R
HV80NWYj079bLP2c/k<0EeMG0:b/[02c/k<0DE5A04E5A@1:BTX0EeMG05YJFP1[Jf/2096AT@0Q0<G5
a@1^KVh0GEeM07UiN@1/K6`0=CDe02HV9P1NGUh0V9RH07MgM`1HF5P0L71`09ZJVP1bLW80De=C07=c
L`2WYjL0Zj^[09BDU00h>3P0<C4a03lo?`19BDT0C4a<05mOG`1fMWH0Bd];07UiN@2>SXh0RHV901XJ
6P0E5AD051@D00805ADE01P05aLG03Lg=`15ADD0PX:208n?S`0S8b<0XZ:R05MGE`0l?3`0=SHf075a
L@0g=cL07alO01LG5`0J6QX08B4Q04Q8B00E5AD04a<C010@400C4a<04Q8B01<C4`0D51@204];B`0:
05YJFP1bLW8071`L02`/;01]KFd0IFEU04];B`1HF5P0BTY:024Q8@806ATI00`0:b/[07emO@2g]kL0
Kfm_07QhN00D51@0410@01DE5@0I6AT0>SXj020P800U9BD201DE5@0403@d=02>SXh0X:2P08B4Q080
6ATI01@0;bl_07UiN@1@D500Vi^K09BDU01JFUX0F5QH03/k>`0M7Ad09BDU04E5A@0G5aL06a/K01`L
700Q8B40Rh^;0<;2`P2m_Kd0/[:b08:2PP80NGUi05@0[Zj^0<S8b02d];@0];Bd0<o?c`3MgMd0[Jf]
07emO@2n_[h0De=C02/[:`0c<c<0@d=3051@D01KFe/0MGEe08f=S@2h^;P0Zj^[075aL@1lO7`0BTY:
04a<C016ATH0K6a/0<k>cP2<S8`0KVi^05aLG01>CTh0DE5A07=cL`2GUiL0b/[:0=3@d01WIfL0C4a<
065QH@1YJFT0Kfm_06e]K@2RXZ80S8b<08N7Q`1aLG40^[Zj09:BTP0G5aL06a/K05EEE@2a/K40g]kN
0=CDe02EUID0Fe]K07]kN`2m_Kd0dM7A0<[:bP30`<00FEUI028R8P0j>SX0MGEe05YJFP0I6AT071`L
01hN7P0i>CT0UIFE01PH600C4a<05aLG01XJ6P10@400Zj^[03<c<`19BDT0Y:BT09RHV02QXJ40_[jn
0;Zj^P32`/82ooooo`000?l0R8R80<O7a`1OGel0QhN705mOG`1ADE40SHf=06MWI`1`L700U9BD07Ui
N@1KFe/0Rh^;09BDU011@D40R8R806EUI@1PH600WinO04A4A01^KVh0RHV904A4A02RXZ80@T920451
@@1eMGD0D51@04A4A01RHV80OWin03Lg=`0e=CD0>c/k04A4A01/K6`0KVi^02LW9`15ADD0Kfm_02DU
9@1;Bd/0De=C03Hf=P0l?3`0820P079bLP0[:b/09bLW06MWI`0M7Ad0EUIF07emO@0o?cl0<C4a03<c
<`0H61P0?Cdm096AT@0[:b/07AdM08N7Q`10@400:RXZ07alO01]KFd0?3`l03@d=018B4P0EUIF02TY
:@2DU9@0YjNW05QHF00`<300=cLg06][J`0[:b/0IfMW08:2PP1>CTh09bLW069RHP0f=SH0KVi^03Ti
>@13@d<0T92@08:2PP13@d<0P82008:2PP1[Jf/0:2PX04e=C@28R8P0@d=302DU9@0T92@0Lg=c03`l
?00L71`0?clo04E5A@1IFET0<C4a05iNGP0m?Cd0HF5Q03/k>`1LG5`0?3`l05ADE01BDU80?Cdm05EE
E@18B4P0Kfm_04M7A`18B4P0KVi^05aLG01@D500IfMW07=cL`0l?3`0IVIV065QH@1?Cdl0CDe=03dm
?@1KFe/0BDU903Ti>@1FEUH0I6AT06MWI`1/K6`0Shn?04E5A@1^KVh0CDe=059BDP1EEED0=CDe065Q
H@16ATH0CTi>07QhN01@D500FUYJ09>CT`2:RXX0<S8b05YJFP2CTi<0AdM707]kN`2MWId0?clo09RH
V01=CDd0=3@d06i^KP1PH600ADE503Ti>@1ADE40ATI601lO7`1UIFD0RHV903Ph>01/K6`0EeMG04e=
C@2DU9@0G5aL055AD@22PX80De=C03<c<`2<S8`0Xj>S04E5A@0c<c<0DE5A07YjNP10@400=cLg0:NW
Y`2OWil0KFe]06a/K03;bl/0[:b/07moO`1BDU80W9bL08N7Q`1@D500UIFE03Lg=`0T92@0Kfm_09fM
W@1DE5@0OWin05YJFP0Q8B40GUiN059BDP1?Cdl0]KFe059BDP24Q8@0^k^k0410@00h>3P0];Bd03lo
?`0_;bl0SHf=069RHP13@d<0AdM7059BDP1oOgl0K6a/02<S8`1WIfL0EEEE05=CD`1VIVH0U9BD07]k
N`1YJFT0A4A40451@@1cLg<0I6AT03lo?`1XJ6P0BTY:03hn?P17AdL0LG5a06a/K00j>SX0Cdm?06=S
H`1@D500;bl_0410@01ZJVX001<0IVIV05QHF02c/k<0Q8B404];B`0W9bL0HV9R07UiN@15ADD0?Shn
069RHP15ADD0IfMW03De=@13@d<0?clo09fMW@0o?cl0?Shn0080Kfm_03P0QXJ602/[:`0l?3`0MgMg
07inOP0k>c/0:RXZ07EeM@25QHD0IVIV06MWI`2KVi/0eMGE06ATI031`L40b/[:05mOG`0Z:RX0TY:B
08B4Q00c<c<0NWYj07MgM`16ATH0:RXZ09JFUP17AdL06a/K04A4A01oOgl0D51@07IfMP34a<@0@410
01TI6@0P8200:BTY05eMG@0W9bL09BDU0820P023Ph<0M7Ad09ZJVP2g]kL0QHF503De=@0Y:BT09RHV
02TY:@0`<300@T9203lo?`1CDe<0ATI603Lg=`80;Bd]01`0:BTY02d];@0];Bd0EEEE04U9B@1;Bd/0
OGem07moO`2GUiL0Cdm?061PH018B4P0GemO04e=C@0k>c/0>CTi03Xj>P0g=cL0Ti>C0:NWY`2c/k<0
JVYZ0:f][@2NWYh0ADE501PH600B4Q805QHF0P0N7Qh04P1BDU80QhN706MWI`2b/[80`L710:>SX`2K
Vi/0UYJF09RHV02DU9@0WIfM09jNWP2o_kl0N7Qh01<C4`0>3Ph0BDU904];B`80;Bd]01P06QXJ01lO
7`0N7Qh0:b/[020P801>CTh0PH6106QXJ01nOWh0RHV902`/;00T92@0IFEU07MgM`14A4@05aLG01DE
5@12@T80UiNG09:BTP1YJFT0GemO02/[:`0S8b<2024Q8@0k02LW9`0[:b/0>c/k05]KF`2k^k/0CDe=
05YJFP1]KFd0^k^k0;6a/@29RHT0Q8B408N7Q`2EUID0WinO0;Fe]@38b<P0g=cL0<o?c`1LG5`0^k^k
0=CDe02XZ:P0LW9b04i>CP1BDU80JVYZ0:NWY`2YZJT0VIVI09FEU@2KVi/0KFe]05YJFP1lO7`0QhN7
07YjNP2DU9@0TY:B04];B`2DU9@0JFUY05aLG021PH40IVIV03Ph>018B4P0L71`03Ti>@1<C4`0?3`l
03Lg=`17AdL0BTY:059BDP2i^KT0a/K60<O7a`1LG5`00`0E5AD05`0G5aL0;bl_04Y:BP1WIfL0H61P
03`l?01SHf<0>CTi07MgM`1TI6@0ATI60410@01^KVh0=SHf01/K6`0I6AT06QXJ04m?C`0_;bl04a<C
014A4@0@410051@D00804a<C00/05ADE03De=@1DE5@0P82004=3@`0F5QH05aLG01XJ6P1ZJVX0H61P
03dm?@0202`/;01?03hn?P1ADE40KFe]04Y:BP2?Shl0@41003hn?P11@D405ADE014A4@0G5aL0=SHf
02PX:00^;Rh05ADE01TI6@0i>CT0PH610:ZZZP2][Jd0BDU903Xj>P1>CTh0bl_;08f=S@1^KVh0QHF5
08^;R`1DE5@0FEUI0410@00[:b/0H61P02DU9@0M7Ad05aLG01`L701VIVH0^;Rh0=GEe@3De=@0b<S8
0<;2`P3AdM40gmoO0=SHf03=cLd0fMWI0=[JfP3WinL0^[Zj0;^k^`3Kfm/0e=CD0<G5a@2c/k<0UIFE
07alO01cLg<0GemO04a<C014A4@0GEeM09>CT`1BDU80MWIf030`<016ATH0TY:B0<K6aP1lO7`0SXj>
06UYJ@1EEED0IVIV07QhN02d];@0gMgM0;^k^`0201LG5`0R01DE5@0W9bL0EUIF09>CT`1WIfL0[Jf]
0<71`@2d];@0_kno0<;2`P0h>3P0;bl_0;Jf]P2c/k<0c/k>0=KFeP2WYjL0X:2P0;no_`3Cdm<0`/;2
071`L01iNGT0FEUI02@T900Y:BT0?3`l05YJFP1ZJVX0<S8b020P800];Bd0Lg=c01LG5`805ADE00/0
8B4Q05ADE01XJ6P0GemO09RHV02XZ:P0Ng]k05mOG`2JVYX0ZJVY05EEE@02ooooo`0001l0PH610;no
_`1FEUH0R8R807]kN`1FEUH0RXZ:06a/K01cLg<0QXJ606YZJP0m?Cd0E5AD071`L00i>CT0MgMg02TY
:@1/K6`0T92@04A4A01RHV80>c/k05EEE@2WYjL0I6AT04i>CP2ZZZX0@T92028R8P0X:2P0K6a/0080
<C4a00L0H61P03dm?@1:BTX0Kfm_02<S8`1<C4`0MWIf0080;2`/03`0?Cdm024Q8@0g=cL07alO05QH
F00N7Qh0:RXZ055AD@0Y:BT0ADE504m?C`0k>c/0?clo05UIF@1OGel0Cdm?08R8R00`<3007QhN096A
T@1GEeL06QXJ04I6AP1ADE408b<S03@d=00o?cl0Cdm?02<S8`1UIFD0QhN704E5A@0U9BD0=SHf06QX
J00g=cL0K6a/07UiN@15ADD09RHV05mOG`0d=3@0HF5Q03@d=024Q8@0WYjN04e=C@0M7Ad0CDe=04M7
A`13@d<0>3Ph04Y:BP2DU9@0FUYJ02`/;00P8200TI6A059BDP0L71`203lo?`1H04=3@`0d=3@0MgMg
03`l?01NGUh0<C4a069RHP0c<c<0FUYJ06YZJP18B4P0Kfm_05EEE@2<S8`0CDe=03lo?`1bLW80KFe]
05mOG`1eMGD0LW9b03dm?@1KFe/0Lg=c05MGE`1]KFd0@d=306e]K@1_Kfl0EEEE06YZJP1XJ6P0NWYj
069RHP2DU9@0GUiN07alO01IFET0GUiN05mOG`13@d<0LW9b05UIF@1JFUX0L71`06EUI@2;Rh/0XZ:R
09:BTP0j>SX0IFEU0:BTY01@D500QhN70::RXP17AdL0`L71069RHP1<C4`0Fe]K06UYJ@1GEeL0>SXj
059BDP1JFUX0=3@d06m_K`2BTY80=SHf07EeM@2;Rh/0De=C09:BTP18B4P0F5QH08N7Q`1aLG40Fe]K
08R8R02<S8`08R8R02@T901_Kfl0IFEU069RHP0i>CT0`<3009jNWP80LG5a08X0bl_;0:f][@1mOGd0
C4a<08Z:RP1jNWX0EEEE09>CT`13@d<0=CDe07moO`2OWil0De=C06EUI@1<C4`0;2`/05mOG`1BDU80
EeMG0;2`/01TI6@0IFEU06a/K01BDU80=cLg09:BTP0m?Cd0:b/[06IVIP11@D40@41005IFEP1kNg/0
P82006i^KP0a<C40MWIf03<c<`0i>CT0FUYJ09JFUP1LG5`0EEEE02LW9`14A4@0I6AT05aLG00b<S80
I6AT07UiN@17AdL0Bd];08b<S01kNg/0@D51051@D023Ph<0GEeM030`<016ATH0LG5a04i>CP1oOgl0
alO7092@T019BDT0;Rh^05MGE`1UIFD0@D5107emO@26QXH0Bd];07IfMP0d=3@0BDU904Q8B02LW9`0
?Shn04=3@`1iNGT0GemO08>3P`0Z:RX0A4A409^KV`1jNWX0>c/k02XZ:P1[Jf/0@410030`<00/;2`0
Jf][0<;2`P1NGUh0YjNW0;Fe]@1gMgL0;Bd]07EeM@1KFe/0@41008:2PP1SHf<0:b/[02TY:@2IVIT0
IVIV01hN7P1:BTX0PX:203lo?`1fMWH0^;Rh059BDP0S8b<09BDU02/[:`1OGel0C4a<01dM7@1@D500
K6a/061PH02d];@0eMGE0:ZZZP19BDT0@T9203hn?P1?Cdl0EeMG059BDP1MGEd0>c/k01/K6`0J6QX2
01DE5@0?01HF5P0M7Ad0Cdm?04m?C`1<C4`0=SHf05QHF01bLW80YJFU0:b/[02LW9`0LG5a038b<P0V
9RH06a/K00805QHF00T0=CDe079bLP1eMGD0PX:20;6a/@2^[Zh0Lg=c05mOG`0^;Rh00P0W9bL08@0O
7al0=SHf07MgM`1lO7`0Jf][08n?S`2`/;00JVYZ04E5A@0a<C40<30`03Lg=`15ADD0JFUY0:RXZ01C
De<0410@014A4@1/K6`0=3@d02PX:01IFET0<c<c02HV9P0/;2`0:BTY03De=@11@D4092@T03dm?@0O
7al0@T9204U9B@0203/k>`0V05UIF@1[Jf/0EeMG04M7A`1kNg/0[jn_0;Bd]02[Zj/0Rh^;05mOG`1J
FUX0A4A403dm?@12@T80CTi>03De=@0/;2`0Y:BT061PH020P800c<c<0:RXZ01fMWH0EEEE04e=C@14
A4@0?clo03Lg=`16ATH0Q8B40=3@d03GemL0HV9R0<71`@1/K6`0DE5A05UIF@2>SXh208b<S00h04U9
B@0`<300@T9204m?C`1UIFD0NGUi08V9R@2EUID0YJFU0;>c/`2o_kl0/k>c0;Jf]P1bLW80RHV9061P
H00Q8B405ADE01<C4`0E5AD0<S8b03Hf=P0N7Qh0?clo05ADE01FEUH0De=C05UIF@1nOWh0Vi^K0:^[
Z`1aLG4061PH01dM7@0m?Cd0K6a/07alO01;Bd/0820P05MGE`0H61P07AdM07YjNP20P800T92@07al
O01JFUX0QhN704=3@`0L71`06a/K02d];@0o?cl05aLG014A4@0E5AD2014A4@1P01<C4`0B4Q804a<C
03@d=01NGUh0V9RH02`/;00L71`061PH01LG5`0n?Sh0MWIf0:6QX@1^KVh0MWIf03De=@0/;2`071`L
01DE5@1:BTX0HF5Q02DU9@1^KVh0DU9B014A4@0E5AD0:BTY03Ph>00V9RH05aLG03Lg=`0_;bl0N7Qh
09BDU01/K6`0De=C05mOG`1aLG40Rh^;0;fm_@2JVYX0Fe]K05YJFP1oOgl0B4Q805EEE@1gMgL0QHF5
06IVIP1NGUh0<C4a02/[:`2BTY80WYjN0=?Cd`3IfMT0bl_;0:^[Z`2a/K40Xj>S09^KV`2CTi<0V9RH
0<C4a033`l<0a<C40<_;b`2k^k/0^;Rh05eMG@0^;Rh09bLW024Q8@0P82007AdM02d];@0T92@0?3`l
05eMG@2/[:`0XJ6Q06][J`1mOGd0][Jf0=;BdP2WYjL0X:2P06MWI`1NGUh0KVi^0:f][@3=cLd0gMgM
0<C4a00M7Ad051@D0P0E5AD0;@0G5aL0FUYJ0=;BdP3Jf]X0b/[:0<_;b`33`l<0aLG50;fm_@2f][H0
QXJ609bLW02m_Kd0I6AT028R8P0O7al0:2PX04=3@`22PX80=3@d028R8P1=CDd0FUYJ03`l?00Y:BT0
=cLg04=3@`1dM7@0Jf][03Hf=P1ZJVX06ATI01DE5@0I6AT0;Rh^0861P@16ATH0TI6A0;2`/01cLg<0
>c/k02PX:01HF5P0][Jf05MGE`02ooooo`0003L0[:b/0<[:bP1OGel0WYjN08n?S`1BDU80Ti>C06UY
J@2;Rh/0SXj>0820P013@d<0Fe]K07alO00e=CD0UYJF061PH01aLG40RHV903@d=01QHF40F5QH03/k
>`2TY:@0EeMG07emO@2m_Kd0QhN703Xj>P0[:b/0LW9b02/[:`16ATH0QhN705MGE`1<C4`0KFe]024Q
8@1IFET0Ti>C04Q8B00i>CT0@d=301lO7`16ATH0<30`059BDP0L71`0=3@d05mOG`0j>SX0FUYJ051@
D00e=CD0CDe=0080Jf][03<0Ph>30820P00S8b<092@T0;2`/01ZJVX08R8R051@D01MGEd0=cLg03`l
?01IFET0Ng]k0492@P29RHT0Ogmo04U9B@0U9BD0@41006m_K`0c<c<0Hf=S07IfMP11@D409bLW069R
HP0o?cl0P82003dm?@2:RXX0Shn?03dm?@0Z:RX0H61P05iNGP0o?cl0;Rh^06i^KP2PX:00G5aL02XZ
:P0L71`0WIfM04M7A`0c<c<0KFe]07IfMP1EEED0@41007]kN`13@d<00P1EEED06027QhL0;2`/055A
D@1hN7P0DE5A08R8R01<C4`0VYZJ04i>CP1MGEd0S8b<08B4Q01ZJVX0IfMW07QhN01CDe<0Jf][06QX
J01=CDd0W9bL04i>CP2GUiL0RXZ:05ADE080J6QX0<80JFUY05mOG`2EUID0D51@06YZJP1UIFD0RXZ:
07QhN014A4@0Ng]k069RHP1MGEd0Z:RX069RHP2>SXh0Zj^[09>CT`0];Bd0UYJF09FEU@13@d<0QhN7
0::RXP1FEUH0b/[:06EUI@15ADD0GEeM0861P@1_Kfl0C4a<06UYJ@1]KFd0>3Ph07]kN`2>SXh0<c<c
06UYJ@1fMWH0EUIF08V9R@0Q8B40Cdm?09>CT`1TI6@0EeMG09JFUP2>SXh08b<S02HV9P1nOWh0EeMG
06=SH`0k>c/0`l?308j>SP1YJFT0U9BD0=[JfP2h^;P0OGem04U9B@2_[jl0Ph>30820P02c/k<0FUYJ
03Ph>026QXH0RHV904E5A@1TI6@0C4a<02l_;`1/K6`0BDU907alO02SXj<0F5QH08j>SP27QhL0J6QX
04=3@`23Ph<0BDU9038b<P1UIFD0?Cdm0492@P1]KFd0Rh^;0:BTY01]KFd0<C4a05UIF@0d=3@0=cLg
04i>CP2WYjL0W9bL071`L00_;bl0@d=305ADE00o?cl0;Rh^09FEU@1_Kfl0?Shn04Y:BP2@T900=cLg
02LW9`1XJ6P0XJ6Q04i>CP0/;2`0>CTi061PH00g=cL0IfMW079bLP1DE5@0F5QH02`/;01>CTh0E5AD
02LW9`14A4@0Jf][04m?C`1/K6`0AdM70492@P20P800b/[:07MgM`14A4@0M7Ad061PH01CDe<0;Bd]
06a/K02_[jl0LW9b02l_;`0X:2P0HF5Q06MWI`0o?cl0@d=30:b/[03Ng]h0QhN7092@T039bLT0Ng]k
03De=@1hN7P0E5AD04Q8B02][Jd0UIFE07inOP0^;Rh0S8b<03dm?@0Z:RX0RXZ:0820P013@d<0L71`
0:RXZ01SHf<0:RXZ04e=C@1KFe/0P82005aLG00O7al0DU9B06i^KP0X:2P0h^;R0>GUi@3IfMT0/;2`
0:ZZZP2TY:@0VYZJ08n?S`2/[:`0ADE501XJ6P805ADE07P04a<C01TI6@0I6AT061PH03lo?`0n?Sh0
De=C03@d=00N7Qh0MWIf0<?3``34a<@0HV9R05aLG00M7Ad06ATI01`L700G5aL061PH06UYJ@10@400
B4Q808j>SP30`<00WIfM07YjNP2JVYX0_;bl06YZJP1HF5P0PH6109BDU00X:2P04Q8B01<C4`0H61P0
EeMG08:2PP1RHV80?Shn024Q8@0H61P05aLG01/K6`0g=cL0SXj>01PH600I6AT0N7Qh02LW9`0f=SH0
7alO02`/;01CDe<0D51@069RHP18B4P071`L020P801dM7@0BDU903Hf=P0n?Sh0GUiN04=3@`0N7Qh0
7AdM03<c<`1LG5`0W9bL08N7Q`2FUYH0JFUY03lo?`0S8b<0;Bd]04E5A@1[Jf/0K6a/04U9B@0l?3`0
8R8R08j>SP38b<P0V9RH08R8R01cLg<0Jf][04Y:BP16ATH0BDU904Y:BP1MGEd0RXZ:09fMW@2RXZ80
[Jf]0=WIf@2b/[80DE5A0451@@0m?Cd0IfMW07=cL`0/;2`071`L01TI6@0Q8B40<30`02LW9`0_;bl0
>CTi06][J`2k^k/0b<S80=GEe@3Ph>00`l?30:ZZZP10@40601DE5@0?03/k>`0L71`05QHF01XJ6P0Y
:BT0D51@09>CT`2FUYH0Rh^;06e]K@2`/;00Ogmo06UYJ@15ADD0:b/[00806QXJ01005QHF04a<C00M
7Ad05ADE02TY:@1UIFD0/[:b05MGE`2KVi/0/[:b08^;R`0Z:RX0;Bd]06IVIP0G5aL05ADE0`0A4A40
2@0C4a<05ADE01DE5@0E5AD0EeMG09BDU02PX:008B4Q01LG5`0201TI6@06038b<P1XJ6P0GEeM03Xj
>P0e=CD05aLG0P0E5AD02`0C4a<061PH05ADE00o?cl092@T08N7Q`18B4P05ADE01LG5`0k>c/09BDU
0080?Shn02P0Bd];0:BTY01oOgl0ATI60451@@0j>SX0AdM705ADE01BDU80L71`09RHV01gMgL0D51@
08B4Q02;Rh/0XJ6Q05EEE@0k>c/0HV9R09>CT`2][Jd0WinO07MgM`2/[:`0c<c<0;6a/@2:RXX0NGUi
06i^KP2VYZH0][Jf08j>SP1hN7P0UIFE09jNWP23Ph<0WYjN0;Bd]01VIVH0?Shn0P0T92@05`0M7Ad0
820P03Xj>P0O7al08R8R04];B`1cLg<0cLg=0:ZZZP3Cdm<0bl_;0=7Ad@2YZJT0YjNW08^;R`2OWil0
dM7A0;bl_02PX:00QHF50:b/[01SHf<071`L00<05ADE00P0ADE50=KFeP3Ti>@0gmoO0>3Ph038b<P0
[:b/0=OGe`80aLG500<0_;bl07MgM`0W9bL00P0N7Qh07@0U9BD0;Rh^061PH01>CTh09BDU02PX:01;
Bd/0MgMg05eMG@11@D40;Bd]03dm?@1GEeL0R8R809JFUP1<C4`09RHV02`/;01=CDd0X:2P05ADE01i
NGT0HV9R03/k>`0U9BD0:BTY03hn?P2NWYh0`l?300;ooooo0000TP2VYZH0XZ:R04A4A02VYZH0P820
05EEE@24Q8@0@d=308B4Q02<S8`0UYJF04=3@`1ADE40De=C03lo?`2n_[h0NGUi08:2PP1:BTX0=CDe
08Z:RP1cLg<0A4A408Z:RP0e=CD0V9RH0;jn_P24Q8@0<c<c03Lg=`1]KFd07AdM06a/K02BTY80D51@
04=3@`0i>CT0>SXj09fMW@2TY:@0CDe=04Q8B012@T80;2`/069RHP0Y:BT0@d=303Ph>01aLG40QXJ6
03Ti>@1EEED0EeMG030`<020P800VIVI06UYJ@2?Shl0Jf][01@D501=CDd0`l?307]kN`0V9RH0DE5A
05=CD`10@400H61P0:6QX@2<S8`0CTi>08j>SP1lO7`0FUYJ03@d=01TI6@0K6a/03Hf=P1WIfL0Lg=c
0492@P17AdL0Kfm_04E5A@2=SHd0ATI609>CT`36a/H0G5aL03Xj>P1]KFd0M7Ad03dm?@0];Bd0Ph>3
0::RXP1HF5P08b<S01`L7023Ph<0?Shn01XJ6P0g=cL0GUiN055AD@0j>SX0Q8B404m?C`11@D40>SXj
071`L00];Bd0BTY:04i>CP0n?Sh0FEUI03`l?02=SHd0<S8b03Lg=`1aLG40MGEe06IVIP1PH600GemO
04=3@`19BDT0BTY:05=CD`24Q8@0>c/k07IfMP1KFe/0?Cdm05YJFP1OGel0?3`l03Lg=`1RHV80?3`l
07]kN`19BDT0EEEE04i>CP0c<c<0L71`0P0m?Cd0KP1mOGd0CTi>07AdM02g]kL0P82002d];@1_Kfl0
MGEe03@d=02=SHd0N7Qh059BDP2h^;P0Fe]K03Ti>@1QHF40OGem03/k>`1VIVH0X:2P07MgM`0g=cL0
OGem05IFEP13@d<0R8R807EeM@1?Cdl0Ti>C02/[:`1/K6`0`/;207YjNP1YJFT0T92@08V9R@13@d<0
B4Q80;2`/02?Shl0OWin03Xj>P35aLD0I6AT0451@@1PH600^k^k09FEU@1<C4`0HV9R0<S8b021PH40
GemO0:JVYP1XJ6P0@T920:6QX@28R8P0=SHf05=CD`1;Bd/0<c<c06QXJ00h>3P0O7al09bLW01`L700
Kfm_08R8R01GEeL0?3`l0;>c/`1GEeL0<S8b06UYJ@0i>CT0ADE50820P02ZZZX0/k>c07moO`13@d<0
EEEE0451@@1JFUX0;Rh^07EeM@1[Jf/0IfMW0492@P15ADD0Fe]K03Xj>P0L71`0MGEe05EEE@0l?3`0
IFEU09nOW`1KFe/0<c<c04=3@`22PX80;Bd]03`l?017AdL0A4A404M7A`1TI6@0HF5Q0P1;Bd/0B00W
9bL0BTY:06IVIP0a<C40?clo06IVIP1<C4`0Hf=S03De=@0Z:RX0@d=30:NWY`1aLG40?Shn079bLP1]
KFd0OWin02DU9@14A4@0Shn?05QHF00U9BD08R8R061PH01VIVH06a/K01`L702EUID0fMWI06UYJ@2U
YJD0d=3@09>CT`0a<C40JFUY03@d=00K6a/0M7Ad08V9R@1RHV809bLW09NGU`0X:2P04a<C04E5A@27
QhL0J6QX05eMG@23Ph<0MgMg01XJ6P0P82009RHV05EEE@0S8b<06a/K04Q8B01VIVH0Hf=S0=SHf03L
g=`0Y:BT05eMG@1CDe<0EEEE07inOP1<C4`0@D5104];B`15ADD0<S8b01/K6`805ADE0P0I6AT02`0X
:2P071`L02h^;P0R8R80C4a<06YZJP1kNg/0Xj>S075aL@16ATH0;Rh^00805ADE01804a<C0451@@1J
FUX0<C4a03Xj>P1/K6`0IfMW02TY:@1?Cdl0U9BD0;jn_P2^[Zh0RHV907YjNP28R8P0=SHf02PX:00I
6AT201DE5@0a04M7A`21PH40Hf=S0410@00c<c<0>c/k03De=@0Z:RX0Jf][05aLG01<C4`0Q8B404A4
A00S8b<05aLG01HF5P0N7Qh0@d=307EeM@13@d<0;Bd]03hn?P2RXZ80O7al03/k>`0Z:RX0:b/[03@d
=012@T809BDU05ADE02>SXh0JVYZ0;Jf]P2d];@0RXZ:03De=@0L71`06a/K01`L700P8200=CDe05=C
D`1FEUH0QXJ60;>c/`2m_Kd0H61P04E5A@0202<S8`0=03Ph>01FEUH0FEUI06YZJP2XZ:P0_kno0;Bd
]01_Kfl0J6QX0;^k^`2j^[X0P82005eMG@0204Q8B00302`/;00R8R806ATI00805ADE00d071`L01TI
6@0[:b/0;Rh^061PH02RXZ80`/;20=3@d03Lg=`0/k>c05eMG@0J6QX05aLG00D05ADE00h0<C4a02h^
;P0L71`061PH01DE5@0I6AT0?clo065QH@2ATI40WIfM09VIV@19BDT06QXJ01LG5`805QHF0P0E5AD0
3P0j>SX0=3@d018B4P0E5AD0:2PX0::RXP15ADD0DU9B0:n_[`2f][H0ZJVY0;fm_@1aLG405ADE0`0C
4a<04P0E5AD0410@01DE5@0N7Qh0=CDe04=3@`2i^KT0`<3003Hf=P0E5AD061PH01DE5@10@400IVIV
04M7A`0f=SH06QXJ01<C4`<05ADE02H05aLG04A4A01>CTh061PH02`/;02@T900Fe]K01LG5`1@D500
Q8B4061PH017AdL0U9BD06EUI@1`L700IVIV07moO`1hN7P0H61P03dm?@0h>3P0>SXj059BDP1dM7@0
VIVI09fMW@2QXJ40/K6a06][J`1NGUh0KVi^06QXJ03@d=00_kno09VIV@1hN7P0Bd];01hN7P805ADE
02D08B4Q04M7A`0X:2P0;2`/034a<@13@d<0EEEE09nOW`2EUID0ZZZZ08n?S`1jNWX0I6AT0451@@0a
<C40>CTi0451@@0`<3009RHV0410@024Q8@0bLW90>;RhP38b<P0a<C409BDU021PH40Ti>C0;Vi^@2_
[jl0[Zj^04I6AP0Q8B40:BTY04E5A@2<S8`0Fe]K00805ADE02d0<C4a0:FUY@2f][H0[Jf]06IVIP25
QHD0YZJV0;Vi^@2k^k/0bl_;0=kNgP32`/80CTi>01TI6@0O7al09bLW02/[:`0U9BD0DE5A04U9B@0T
92@09BDU03<c<`0l?3`0L71`07YjNP1_Kfl0H61P04Q8B01kNg/0G5aL07EeM@1nOWh0Lg=c0;6a/@2F
UYH0SXj>08R8R00j>SX0=cLg02XZ:P0[:b/0?3`l0;>c/`24Q8@00_ooool0003o0:BTY02m_Kd0Fe]K
07moO`1kNg/0DU9B08Z:RP0e=CD0<S8b04];B`1gMgL0@410055AD@1NGUh08b<S08N7Q`1ADE40Kfm_
05EEE@0R8R80FUYJ06=SH`13@d<0P82002`/;018B4P0RXZ:06YZJP0c<c<0?clo07]kN`0H61P0<C4a
065QH@15ADD0E5AD04Y:BP0H61P0Cdm?07EeM@0i>CT0?clo04=3@`0S8b<0@D51030`<01BDU8061PH
03`l?015ADD09bLW05UIF@1>CTh09bLW06QXJ01/K6`0IfMW0:b/[01/K6`07AdM02DU9@22PX80D51@
02HV9P1NGUh0?Cdm01TI6@0W9bL0<30`055AD@0`<300SXj>08:2PP0Y:BT06a/K04Y:BP1UIFD0<S8b
05mOG`1oOgl0=cLg02l_;`1MGEd0ATI606][J`0/;2`0LG5a09jNWP1HF5P0;Bd]07MgM`1mOGd0F5QH
03Ti>@1HF5P0UYJF05MGE`0X:2P08R8R09>CT`1=CDd06QXJ03Xj>P1>CTh0<S8b06ATI030`<00Ph>3
07=cL`0n?Sh0Kfm_02`/;01KFe/0HV9R04i>CP1ADE40@4100:6QX@0c<c<0A4A407AdM01_Kfl0GEeM
06QXJ01`L700DU9B03Lg=`0o?cl0EeMG07inOP1NGUh0WinO055AD@0i>CT0HF5Q07IfMP1UIFD0AdM7
05IFEP11@D40TI6A05iNGP1mOGd0@D51038b<P24Q8@0BDU905=CD`1hN7P0?Cdm07AdM03:b/X0UiNG
04I6AP1oOgl0LW9b03Ti>@2b/[80Xj>S05MGE`2e]KD0AdM70410@01`L700S8b<05eMG@17AdL0K6a/
05YJFP0c<c<0RXZ:07YjNP0b<S80F5QH05ADE01YJFT0ZZZZ04M7A`1EEED0Hf=S05mOG`1]KFd0WinO
0:BTY00j>SX0:b/[08>3P`2:RXX0De=C04];B`2h^;P0/K6a05IFEP1SHf<0_;bl092@T00Z:RX0=3@d
09BDU01VIVH0FUYJ0:n_[`0Z:RX06a/K08:2PP2GUiL0E5AD05EEE@12@T80EEEE0:6QX@1EEED0Jf][
07EeM@14A4@0J6QX08Z:RP13@d<0;Rh^05ADE01ADE40;Rh^07=cL`10@400?Cdm075aL@2;Rh/0RXZ:
0820P00n?Sh0Ng]k0861P@1]KFd0H61P07YjNP1ZJVX0TI6A03@d=018B4P0UiNG071`L00j>SX0QhN7
055AD@0I6AT0O7al0:^[Z`1iNGT0=SHf0451@@1fMWH04A4A03<c<`1@D500HF5Q001_04m?C`1UIFD0
KFe]03hn?P0g=cL0ATI609jNWP1fMWH0<c<c03/k>`14A4@0;bl_07moO`1XJ6P0?3`l04i>CP2SXj<0
@41003`l?02QXJ40/;2`09FEU@0X:2P0=SHf06QXJ00d=3@0?3`l07IfMP20P800JFUY01TI6@0O7al0
UYJF0;:b/P0Y:BT0OWin09:BTP1]KFd0:b/[075aL@12@T809BDU06EUI@1dM7@0EUIF02l_;`2=SHd0
>SXj01`L701ADE40HV9R051@D01MGEd0OGem06ATI00U9BD0:2PX02`/;01GEeL092@T020P8015ADD0
F5QH05EEE@2RXZ80Zj^[0:ZZZP1;Bd/0<S8b02l_;`1?Cdl0FEUI034a<@0[:b/0>c/k03Ti>@17AdL0
D51@04Y:BP12@T80<30`02@T900M7Ad0;2`/024Q8@10@400;Bd]04M7A`2VYZH0T92@03Ph>015ADD0
5ADE01<C4`0D51@0IVIV03`l?00o?cl0Hf=S071`L00a<C407AdM04m?C`1@D500Z:RX0:6QX@1WIfL0
8b<S01HF5P0L71`0:RXZ0080<C4a04L0>CTi03Lg=`0o?cl0IFEU065QH@12@T80Bd];04Q8B01?Cdl0
@T9209ZJVP2?Shl0SXj>05EEE@0I6AT05aLG01`L700P8200De=C0492@P1;Bd/0RHV906a/K020P800
6a/K01@D500>3Ph051@D01<C4`0S8b<0LG5a08:2PP1;Bd/0;bl_05IFEP1`L700G5aL07IfMP1VIVH0
?Shn02h^;P0n?Sh0=3@d02l_;`0o?cl0Z:RX09NGU`2^[Zh0Xj>S08f=S@17AdL06QXJ01LG5`0L71`0
;Bd]04A4A02?Shl0[Zj^0820P01EEED0BTY:09RHV02c/k<0]KFe061PH00c<c<0;bl_02@T900L71`0
6ATI01XJ6P0301LG5`0;01/K6`15ADD0ATI606UYJ@1WIfL0O7al0;bl_01?Cdl0C4a<01LG5`0D51@0
1@0E5AD0100K6a/0@D5102DU9@0P820201HF5P0601`L7010@400VYZJ09^KV`1dM7@0<c<c100E5AD2
01LG5`0302l_;`0h>3P05ADE00805ADE00T0IfMW06e]K@0h>3P0NGUi09ZJVP2g]kL0e]KF03Lg=`0C
4a<00P0@410201DE5@0j01<C4`0G5aL0@d=302l_;`1LG5`0`/;20<K6aP1QHF406a/K01TI6@0N7Qh0
@D5105]KF`1BDU80<30`01HF5P0E5AD04a<C01@D500C4a<05aLG024Q8@1MGEd07AdM01LG5`0a<C40
QHF508N7Q`1^KVh0U9BD06IVIP2DU9@0Shn?04e=C@0G5aL08R8R02d];@0l?3`0IfMW05eMG@1FEUH0
>CTi02XZ:P0n?Sh0Shn?09fMW@2/[:`0/k>c03Ti>@0R8R80>3Ph08Z:RP3GemL0f=SH08b<S01KFe/0
7QhN01DE5@805QHF03L0ADE502XZ:P0d=3@06a/K01<C4`0G5aL09RHV09NGU`2UYJD0[Zj^0;fm_@2Y
ZJT0X:2P092@T01UIFD0IfMW06i^KP1IFET0=cLg04e=C@2k^k/0clo?0=KFeP35aLD0/[:b07IfMP2X
Z:P0[Jf]0;Ng]`2ZZZX0MgMg05YJFP0h>3P07alO02/[:`1BDU80WYjN08>3P`1[Jf/0Ti>C05iNGP0m
?Cd0<C4a02XZ:P1SHf<0]KFe0=?Cd`3EeMD0clo?0=[JfP2[Zj/09BDU02<S8`0U9BD0:2PX00808R8R
00D0ADE504e=C@0V9RH09BDU034a<@0202h^;P0D05UIF@2CTi<0WYjN0::RXP2[Zj/0Ph>304Q8B01=
CDd0PH610=3@d02e]KD0][Jf05aLG011@D40BTY:03De=@0h>3P0K6a/0:NWY`0M7Ad2ooooo`000?l0
[:b/0<[:bP1TI6@0T92@071`L01fMWH0_[jn05mOG`23Ph<0Ogmo06ATI01gMgL0^KVi0:RXZ00l?3`0
WIfM05iNGP2SXj<0VYZJ0492@P1FEUH0BTY:0861P@2l_;`0F5QH08R8R01mOGd0EUIF08F5Q@2MWId0
/K6a02l_;`0h>3P0=SHf0410@02UYJD0NWYj02/[:`1eMGD0HV9R03@d=01]KFd0Lg=c03Lg=`0Z:RX0
CTi>07AdM00U9BD0ADE505EEE@0S8b<0PH6108Z:RP1ADE40M7Ad05]KF`0h>3P0c<c<0:RXZ010@400
<S8b0:>SX`0l?3`0GUiN09bLW01IFET0=CDe051@D01JFUX0Cdm?02DU9@2OWil0Vi^K06MWI`0O7al0
I6AT04Q8B00?3`l0EeMG096AT@1XJ6P0?3`l05iNGP0V9RH0MgMg04m?C`27QhL0VYZJ05ADE011@D40
]KFe0<G5a@1HF5P0?clo06MWI`25QHD0=cLg04];B`1HF5P0WYjN07MgM`0K6a/0>c/k051@D00a<C40
?3`l069RHP1_Kfl0IfMW03Lg=`1XJ6P05QHF07]kN`23Ph<0EUIF04I6AP0d=3@0]KFe05eMG@1;Bd/0
GEeM03Lg=`1iNGT0Z:RX08n?S`1CDe<0@d=303De=@1_Kfl0Zj^[05aLG02EUID0<C4a030`<01mOGd0
Ti>C09FEU@16ATH0H61P01`L702@T900J6QX08Z:RP0^;Rh0:b/[09RHV02ATI40Cdm?07EeM@0E5AD0
;2`/06IVIP2JVYX0BDU909:BTP1[Jf/05aLG08J6QP2KVi/0H61P0<;2`P0@41009BDU059BDP2IVIT0
JFUY04m?C`1oOgl0>SXj00`<3020P800NWYj03/k>`1@D5005ADE02/[:`2[Zj/0OWin06e]K@1mOGd0
Bd];01XJ6P1XJ6P0W9bL059BDP0_;bl0QhN706m_K`1ADE4092@T0;2`/01mOGd0GUiN06][J`2m_Kd0
UiNG06i^KP16ATH0L71`05eMG@1gMgL0Ti>C03Hf=P0h>3P0Xj>S092@T01FEUH0=cLg03<c<`0J6QX0
GemO05iNGP1mOGd0X:2P038b<P1BDU80Ph>305MGE`0h>3P0F5QH02d];@0h>3P0XJ6Q04A4A018B4P0
W9bL0:j^[P2HV9P0IfMW024Q8@1NGUh0IVIV07inOP1MGEd0BTY:01lO7`1eMGD0>CTi02l_;`1?Cdl0
GUiN03lo?`1gMgL0HV9R03Xj>P1LG5`0Ti>C06i^KP0h>3P0ADE508F5Q@0b<S80<c<c03Ph>01BDU80
04d0De=C05YJFP1NGUh0@T92034a<@0Q8B40DU9B05aLG00X:2P0>c/k04];B`0Y:BT0>SXj03Hf=P0a
<C40ATI60::RXP15ADD0;2`/06MWI`1JFUX0LG5a02@T900n?Sh0I6AT02h^;P0C4a<0=CDe06][J`1S
Hf<08R8R03Lg=`2b/[80TY:B05ADE02LW9`0/K6a05iNGP0_;bl0WinO07UiN@0i>CT0GUiN05eMG@1C
De<0?Cdm09ZJVP1IFET08R8R05EEE@1GEeL0Cdm?07EeM@1kNg/0IFEU030`<00_;bl0<30`05eMG@0f
=SH0:2PX075aL@2BTY80GemO05]KF`17AdL0ZZZZ075aL@13@d<0=CDe02XZ:P1;Bd/0BTY:04=3@`19
BDT0FEUI059BDP0204=3@`0M05aLG01WIfL0HF5Q05YJFP1FEUH0?clo03/k>`0[:b/0ATI60<c<c02P
X:00=CDe06EUI@0Y:BT071`L02/[:`2[Zj/0Shn?0:>SX`35aLD0R8R802l_;`11@D40<C4a01lO7`1g
MgL0IFEU024Q8@0>3Ph00`0=3@d200h>3P806a/K01P06ATI01hN7P0b<S80FEUI04=3@`0/;2`0?clo
03hn?P1<C4`0d=3@05IFEP0f=SH0:RXZ01LG5`0M7Ad0CTi>02l_;`0W9bL09BDU06QXJ01dM7@0?clo
014A4@0@4102014A4@0>01DE5@0G5aL0PH6107emO@0j>SX0820P03<c<`1gMgL0;bl_02TY:@1MGEd0
UYJF06QXJ00J6QX201DE5@0I03Lg=`2CTi<0/[:b02h^;P0O7al0=cLg08>3P`2;Rh/0GemO04i>CP1H
F5P0MGEe09fMW@2m_Kd0WinO08f=S@1ZJVX0^;Rh0<S8b02BTY80=SHf02DU9@0T92@061PH01DE5@03
01HF5P0<01TI6@0H61P0:RXZ06EUI@0n?Sh0@d=306][J`1:BTX0[:b/059BDP1:BTX08B4Q1`0E5AD0
0`19BDT0:2PX01`L700301`L700503dm?@33`l<0NWYj0492@P13@d<0100E5AD04P0G5aL071`L01dM
7@19BDT05ADE014A4@0C4a<0=cLg09bLW00k>c/0D51@07UiN@1OGel0`L71034a<@0C4a<04A4A01<C
4`804A4A03l04a<C030`<00X:2P07alO0;Bd]03GemL0gMgM0;>c/`0e=CD09BDU04e=C@1mOGd0GemO
08F5Q@0S8b<04a<C010@400D51@0410@014A4@0C4a<05QHF05MGE`0l?3`07AdM01DE5@0V9RH0V9RH
0<g=c@2OWil0][Jf0<;2`P1KFe/07QhN01XJ6P0T92@0?3`l04A4A00d=3@08R8R034a<@1>CTh0IVIV
055AD@0o?cl0OWin075aL@2DU9@0^[Zj06=SH`1<C4`0Hf=S0<g=c@3?cll0P82004I6AP0E5AD061PH
01LG5`0M7Ad0A4A401PH600J6QX00`0E5AD01@0F5QH0D51@04i>CP1YJFT0MWIf0080]kNg01d0MGEe
055AD@1<C4`0ADE504];B`1dM7@0VIVI08j>SP38b<P0^k^k0<?3``27QhL0Lg=c08j>SP1QHF40=cLg
03De=@16ATH0JFUY06YZJP13@d<0;Bd]034a<@1[Jf/0clo?0;jn_P1NGUh09bLW02h^;P0203hn?P0X
069RHP36a/H0d=3@0=_Kf`3Fe]H0`L7109JFUP0c<c<0=3@d02/[:`0U9BD0820P01lO7`0b<S80CTi>
038b<P0f=SH0E5AD03`l?00g=cL0@41005aLG02][Jd0`<300;jn_P39bLT0Rh^;0:f][@3QhN40c<c<
0;2`/01oOgl0Bd];04m?C`1SHf<0MgMg0:^[Z`36a/H0_[jn05YJFP;ooooo0000o`1PH600b<S8065Q
H@2ZZZX0E5AD04M7A`2CTi<0EUIF0:^[Z`24Q8@0DE5A03`l?01FEUH0N7Qh03lo?`1aLG40<30`07Ee
M@1lO7`0BTY:04i>CP0k>c/0Cdm?08R8R01<C4`0QHF506IVIP0b<S80:2PX03lo?`22PX809BDU03Ph
>00f=SH09bLW05eMG@1TI6@0;2`/07emO@1[Jf/0:2PX034a<@17AdL0:2PX03`l?00_;bl0FUYJ01lO
7`0o?cl0A4A4024Q8@0o?cl0B4Q803<c<`1ADE40AdM702@T902=SHd0GemO04Q8B00h>3P0YJFU02XZ
:P0U9BD0Fe]K06ATI011@D40EUIF06EUI@1CDe<061PH04E5A@1CDe<0AdM701/K6`1UIFD0CDe=01DE
5@0l?3`0G5aL04a<C00j>SX0GUiN01LG5`0o?cl0Bd];09:BTP2WYjL0IfMW01`L701IFET0NWYj07em
O@0d=3@0JVYZ07YjNP0P82005ADE01LG5`1fMWH0GemO01XJ6P0k>c/0D51@0492@P15ADD0MWIf05EE
E@1SHf<0?Cdm06a/K00T92@0G5aL06ATI01FEUH0DU9B03De=@21PH40CTi>05UIF@1YJFT0@T92055A
D@1NGUh0KVi^05ADE00i>CT0;Bd]05mOG`21PH40CTi>0:6QX@1EEED0;2`/059BDP1DE5@0ATI605MG
E`1eMGD0?3`l06e]K@16ATH0UYJF05eMG@0f=SH0MgMg03dm?@1TI6@0W9bL06i^KP2:RXX0YjNW065Q
H@0j>SX0WinO08>3P`0m?Cd0QXJ605QHF01XJ6P0[Zj^06=SH`0f=SH0De=C08J6QP1IFET0Ogmo0:RX
Z01[Jf/09bLW06IVIP1XJ6P0?3`l065QH@1FEUH0@4100;2`/019BDT0NGUi0:j^[P1^KVh0DE5A09JF
UP1fMWH0?clo04e=C@2FUYH0HV9R06UYJ@0c<c<0_[jn07QhN01UIFD0Rh^;0<k>cP2a/K40GemO05YJ
FP2UYJD0<S8b04i>CP1jNWX0Cdm?0410@02?Shl0IVIV0410@01<C4`0A4A402l_;`1iNGT0AdM70:NW
Y`2m_Kd0IVIV055AD@23Ph<0?3`l02`/;01lO7`0@D5102DU9@1MGEd0>c/k03dm?@23Ph<0`/;20;Zj
^P1aLG40<C4a05IFEP1<C4`0Cdm?03lo?`1mOGd0P82008J6QP1<C4`0@410065QH@1SHf<0BTY:0:j^
[P2MWId0De=C06YZJP2UYJD0=SHf01hN7P1KFe/0Ti>C04m?C`0b<S80>c/k07MgM`00K010@400O7al
09fMW@1`L700G5aL02/[:`1HF5P0Hf=S03Lg=`1OGel0Ph>3051@D01GEeL0;bl_02h^;P1HF5P0]kNg
069RHP16ATH0OWin06e]K@1hN7P07AdM0451@@29RHT0H61P01XJ6P0l?3`0IVIV03De=@0k>c/0Lg=c
0;^k^`2DU9@0CDe=0:f][@2`/;00De=C01`L701?Cdl0H61P03Lg=`1QHF40Bd];01/K6`0Q8B40Q8B4
05=CD`0Q8B40E5AD05eMG@0P8200FUYJ09FEU@2:RXX0<c<c0410@00m?Cd0I6AT01LG5`0L71`0BDU9
069RHP1PH600SHf=04U9B@1BDU80WIfM07EeM@1XJ6P0DU9B071`L01bLW80MWIf08F5Q@21PH40QXJ6
08n?S`1fMWH0N7Qh065QH@1OGel0GUiN07UiN@22PX80RXZ:09JFUP36a/H0fMWI0;no_`1PH600WinO
08^;R`1GEeL0IfMW0<k>cP2TY:@0B4Q803Hf=P1EEED0MGEe07MgM`22PX80OWin0:NWY`1FEUH05QHF
00h>3P<03@d=00<03Ph>00d=3@0C4a<00P0E5AD05P0D51@05ADE01TI6@11@D40GUiN04Y:BP12@T80
B4Q80<_;b`1@D500?3`l03hn?P0J6QX0ADE503De=@0I6AT0FEUI04=3@`1DE5@0Hf=S01XJ6P0@4102
00h>3P0>010@400C4a<0A4A405MGE`1JFUX0G5aL01PH601EEED0XZ:R03<c<`0M7Ad07QhN04i>CP1M
GEd201DE5@0501TI6@1NGUh0^[Zj051@D00f=SH00P0E5AD04@0[:b/0RXZ:02HV9P0H61P06ATI024Q
8@1[Jf/0NGUi08B4Q027QhL0V9RH0<S8b01lO7`0MWIf02PX:00M7Ad06a/K00<05ADE00l05aLG01TI
6@0J6QX07AdM02HV9P1RHV80<30`02/[:`1RHV80De=C0:ZZZP1NGUh0Cdm?03dm?@0G5aL00P0E5AD0
400C4a<051@D01DE5@0E5AD0?3`l04M7A`0M7Ad0820P024Q8@0/;2`0Lg=c09ZJVP1^KVh0>3Ph07If
MP0G5aL301DE5@<05aLG00d0EEEE01DE5@0B4Q805ADE02LW9`34a<@0>CTi04I6AP1bLW80?3`l0:RX
Z01FEUH04A4A00804a<C01<04A4A018B4P0E5AD0H61P034a<@17AdL0>SXj05EEE@2RXZ80b<S80;2`
/01]KFd0PX:209ZJVP2ATI40/k>c04Y:BP0C4a<0410@00804a<C02/04A4A010@400E5AD0I6AT079b
LP1@D500BTY:06UYJ@30`<00c<c<0=SHf037alL0WinO03Hf=P1GEeL0I6AT069RHP1NGUh0=3@d02DU
9@0K6a/071`L01XJ6P0S8b<0>3Ph01XJ6P0k>c/0ZJVY096AT@2LW9`0c<c<0:ZZZP34a<@0h>3P0=?C
d`2g]kL0>3Ph01LG5`0E5AD07AdM0410@00M7Ad04a<C00805ADE04T051@D018B4P0E5AD071`L01LG
5`1@D500C4a<09^KV`2XZ:P0Q8B406QXJ01LG5`0J6QX07AdM02GUiL0c/k>0=3@d034a<@0]kNg0:f]
[@0c<c<0820P03<c<`0N7Qh06a/K01XJ6P0L71`0:b/[0492@P1bLW80MWIf04A4A016ATH0Zj^[09:B
TP0n?Sh0Ng]k09bLW02a/K40T92@08V9R@2VYZH0d=3@0=;BdP3Hf=P0^k^k0;Vi^@1WIfL0DE5A03/k
>`0V9RH08B4Q01lO7`0[:b/0GemO05MGE`1BDU80UYJF0:>SX`2:RXX0OGem08Z:RP2e]KD0c/k>0:6Q
X@2ZZZX0EeMG04];B`2a/K40]kNg0<30`01YJFT0R8R80080[Zj^00D0R8R8065QH@0e=CD0>3Ph092@
T002ooooo`000300XZ:R09JFUP1?Cdl0Shn?06i^KP1TI6@0SHf=06IVIP2JVYX0];Bd08F5Q@16ATH0
GEeM06UYJ@1GEeL0/k>c04m?C`2GUiL0QHF505EEE@1`L700JFUY05eMG@2OWil0HF5Q08n?S`2OWil0
MGEe03dm?@1:BTX0IfMW02DU9@1HF5P0GEeM0492@P1FEUH0;Rh^02<S8`24Q8@0KVi^03`l?01;Bd/0
>SXj02XZ:P1;Bd/0<c<c03De=@0`<30205YJFP3n03/k>`1JFUX0EEEE0492@P1NGUh0OGem05aLG02U
YJD0Hf=S05ADE01EEED0ZZZZ05ADE00d=3@0Jf][05=CD`1:BTX0Ogmo0:BTY01/K6`0@41007AdM01P
H600AdM7034a<@1UIFD0Hf=S02@T901NGUh0I6AT059BDP13@d<0MGEe03Ph>01FEUH0Bd];08N7Q`28
R8P0F5QH02l_;`1cLg<0Q8B406IVIP0j>SX0[jn_09fMW@1HF5P0820P01XJ6P25QHD0@41002PX:01H
F5P0Lg=c04Q8B01EEED0XZ:R05]KF`0_;bl0J6QX07=cL`0d=3@0N7Qh030`<01QHF40KFe]04Y:BP1a
LG40;Bd]05UIF@1cLg<0GUiN09jNWP1`L700>CTi05UIF@1@D500BDU907YjNP1HF5P0;2`/08N7Q`1N
GUh0?3`l07EeM@22PX80?3`l04e=C@1WIfL0>SXj0861P@1DE5@0IFEU04U9B@0g=cL0OWin04I6AP12
@T80KVi^07EeM@2EUID0`l?308N7Q`12@T80S8b<06EUI@0m?Cd0WIfM07MgM`1RHV80W9bL05aLG00h
>3P0J6QX06e]K@0K6a/0DE5A08B4Q01/K6`0;Bd]069RHP10@400De=C07IfMP1NGUh0?clo0:b/[00R
8R80>SXj05aLG01QHF40JFUY0:^[Z`1hN7P0;Bd]04=3@`2<S8`0N7Qh06MWI`0c<c<0]kNg03lo?`0`
<300HF5Q0:6QX@2=SHd0F5QH05aLG01hN7P0Hf=S06EUI@2[Zj/0LG5a0451@@1]KFd0R8R804i>CP0j
>SX0@41003@d=01jNWX0@41007QhN02@T900GUiN06UYJ@2TY:@0EEEE028R8P13@d<0BDU9030`<021
PH409BDU02HV9P1OGel0LG5a0820P025QHD0?3`l05UIF@1>CTh0Jf][03@d=01]KFd0E5AD07EeM@1J
FUX0ADE506QXJ013@d<08R8R06YZJP24Q8@0?3`l05aLG02SXj<0IFEU03Ti>@0g=cL0RHV904e=C@0d
=3@0A4A407=cL`0];Bd0=cLg05ADE01TI6@0BTY:02h^;P1FEUH0@T9201XJ6P0j>SX0I6AT04a<C01g
MgL0?clo02LW9`1eMGD0_Kfm08b<S013@d<0N7Qh06][J`1HF5P08b<S05IFEP2VYZH0I6AT01TI6@0o
?cl0I6AT02d];@0P8200>SXj0;Vi^@1<C4`0QXJ60<;2`P2d];@0KVi^02XZ:P1EEED0Bd];02h^;P1f
MWH0HF5Q02@T900U9BD0X:2P0451@@0R8R8205=CD`0k051@D01KFe/0QhN705iNGP0h>3P0Ti>C0:j^
[P1nOWh0?Shn02DU9@15ADD0M7Ad02/[:`36a/H0Y:BT08N7Q`3:b/X0N7Qh03lo?`0e=CD0;Bd]0451
@@0c<c<0:BTY030`<00j>SX0@41005YJFP1kNg/0SXj>09NGU`2:RXX0[Zj^0:VYZ@2FUYH0]KFe0:n_
[`2LW9`0^k^k0=3@d03>c/h0]KFe06UYJ@0l?3`0@T9209BDU01FEUH0;Bd]02@T900_;bl0LG5a0:ZZ
ZP2j^[X0dM7A08V9R@0I6AT03`l?014A4@0>3Ph0100=3@d0<@0A4A405ADE01DE5@0E5AD04a<C01@D
500I6AT0BTY:06m_K`2d];@0d];B0;Rh^01XJ6P0DE5A061PH01?Cdl0<c<c03lo?`2XZ:P0R8R807If
MP0n?Sh06ATI01DE5@0@41004A4A01LG5`0c<c<0LG5a03De=@0O7al0A4A404Y:BP10@400<C4a04E5
A@11@D407alO024Q8@1@D5009RHV01DE5@0U9BD0/k>c07YjNP17AdL0A4A401/K6`0R8R800P0E5AD0
<`0H61P05ADE01DE5@0G5aL0@T9209VIV@0_;bl0A4A402<S8`1dM7@0OWin09RHV01;Bd/0@41003`l
?00_;bl0<C4a03@d=00o?cl0BTY:04U9B@1;Bd/0KFe]07emO@19BDT0@T9207inOP1FEUH0_;bl07]k
N`1EEED0GEeM01dM7@0N7Qh06a/K01PH600E5AD06ATI01DE5@0U9BD0JFUY03/k>`0/;2`07QhN03@d
=022PX80<c<c05=CD`0k>c/0Ogmo02TY:@0401DE5@0@01HF5P0E5AD0GEeM01/K6`0E5AD05QHF03Ph
>03Kfm/0LW9b03Lg=`21PH40?Shn08Z:RP2FUYH05ADE010@40804A4A01X0410@03/k>`31`L40I6AT
02<S8`0W9bL0<C4a09^KV`38b<P0WIfM0;Fe]@2m_Kd0SHf=07IfMP1SHf<0Kfm_04e=C@0@41004a<C
018B4P0A4A4051@D03<c<`1aLG40O7al07QhN080De=C00d0W9bL0<?3``3Cdm<0aLG50<c<c02BTY80
LG5a09bLW02VYZH0CTi>03De=@0U9BD06ATI00805aLG01D071`L02DU9@0K6a/0;Rh^09JFUP3<c<`0
^;Rh0:JVYP2h^;P0i^KV0<o?c`3EeMD0g]kN07alO01FEUH0?Shn03Ph>01VIVH06ATI01DE5@0G5aL0
0P0E5AD05P0C4a<04A4A01LG5`0G5aL0B4Q804];B`22PX80D51@06MWI`1nOWh0J6QX03hn?P1CDe<0
U9BD09:BTP2IVIT0Vi^K051@D018B4P0EEEE04Q8B00g=cL201dM7@0c01`L700K6a/06QXJ01dM7@0c
<c<0GemO0;Bd]02@T900U9BD0:f][@2i^KT0R8R804U9B@0R8R808B4Q03`l?023Ph<0/K6a0=;BdP34
a<@0Vi^K0;Bd]02n_[h0[:b/09NGU`2<S8`0ATI604M7A`1^KVh0V9RH0:JVYP2OWil0U9BD0:2PX036
a/H0f=SH0<?3``2][Jd0M7Ad07EeM@2GUiL0Ogmo06YZJP2k^k/0XJ6Q0=SHf034a<@0]KFe09VIV@1V
IVH0<C4a008071`L00<09RHV07inO_ooool00Oooool000080;:b/P32`/80GEeM09fMW@1jNWX0PX:2
0:NWY`1<C4`206UYJ@29051@D01bLW80Zj^[05QHF00c<c<0RXZ:0492@P2HV9P0=cLg03Ph>01eMGD0
FEUI06e]K@26QXH07AdM08Z:RP2FUYH0IFEU05YJFP27QhL0KVi^01XJ6P0f=SH0IFEU03hn?P1LG5`0
IVIV028R8P27QhL0MgMg03Ph>01<C4`0De=C03De=@1NGUh0@41004Q8B00L71`0;Bd]04];B`0[:b/0
GEeM04I6AP0Q8B40Hf=S06MWI`1<C4`0WIfM05QHF00I6AT0BTY:08Z:RP12@T80>CTi075aL@0^;Rh0
:2PX04I6AP1UIFD0E5AD04Y:BP22PX80LG5a024Q8@0I6AT0CDe=05iNGP0S8b<0JVYZ061PH00P8200
>3Ph06MWI`0g=cL0IFEU02XZ:P1_Kfl0Y:BT069RHP0a<C40P82009bLW00h>3P09RHV09nOW`2IVIT0
EeMG04M7A`1VIVH0Y:BT04a<C00E5AD0;Bd]05=CD`0X:2P0IVIV09jNWP20P800CTi>03`l?019BDT0
:2PX09JFUP1SHf<0FUYJ04U9B@17AdL0XJ6Q03dm?@13@d<0K6a/04e=C@2?Shl0Ti>C06YZJP1LG5`0
<C4a02/[:`2;Rh/0NWYj04Y:BP2CTi<0<C4a04=3@`1cLg<0PH6106a/K01cLg<0@T92030`<02OWil0
F5QH06ATI00i>CT0@d=309BDU01DE5@00P1[Jf/07@0a<C40MgMg0:n_[`2LW9`0AdM708n?S`1=CDd0
ADE509nOW`1kNg/0LG5a0:BTY014A4@0HF5Q0;:b/P2<S8`0AdM706IVIP1^KVh0EEEE03`l?02IVIT0
C4a<03`l?01QHF40EEEE07=cL`2a/K40G5aL0080Kfm_05<0OGem05YJFP2j^[X0QhN704A4A013@d<0
U9BD06e]K@1JFUX0?Cdm0<;2`P2?Shl0EUIF079bLP2i^KT0TY:B03/k>`2?Shl0/;2`07AdM01cLg<0
Y:BT05IFEP0d=3@0RHV909JFUP1ZJVX0DE5A03Ph>01KFe/0];Bd06m_K`20P800Vi^K03Ph>024Q8@0
`/;2065QH@0b<S80CTi>03hn?P0d=3@0U9BD04];B`14A4@0IVIV08F5Q@1ZJVX0NWYj03@d=01PH600
EEEE07MgM`1XJ6P0Vi^K07AdM01iNGT0@T9204Q8B01ZJVX0B4Q803Hf=P21PH40JVYZ0492@P1aLG40
ZJVY06=SH`0j>SX0>3Ph09^KV`0a<C40>3Ph05ADE01KFe/0Bd];059BDP1?Cdl0?3`l04A4A00_;bl0
GUiN06m_K`0203Hf=P1106IVIP1YJFT0SXj>06QXJ014A4@0BTY:0;2`/01nOWh0@D5109>CT`2HV9P0
Lg=c024Q8@0n?Sh0Ng]k05IFEP0`<300J6QX09^KV`1oOgl0<S8b04a<C02k^k/0IfMW0451@@2GUiL0
L71`061PH00e=CD0RXZ:055AD@0f=SH0/k>c09JFUP15ADD0;Bd]09jNWP0b<S80@D5108Z:RP2DU9@0
H61P08:2PP2:RXX0GUiN024Q8@0];Bd0?Cdm05QHF00_;bl0<S8b05QHF01iNGT0A4A408F5Q@2;Rh/0
[Zj^0;bl_01NGUh0CDe=03<c<`0X:2P08B4Q03Lg=`0n?Sh00P0T92@08P0W9bL0=cLg03hn?P0^;Rh0
=3@d05IFEP2EUID0bLW908j>SP16ATH0;2`/02XZ:P1kNg/0dM7A0;:b/P0o?cl05ADE014A4@0>3Ph0
7alO08f=S@1TI6@0;Rh^02HV9P0f=SH0P82005YJFP2[Zj/0YJFU05iNGP0E5AD03Ph>00d=3@0>3Ph3
00d=3@0300h>3P0D51@05aLG00805aLG00d071`L02/[:`1EEED0Xj>S0=oOg`3EeMD0fMWI0;Fe]@33
`l<0/;2`0820P01jNWX0Jf][0080T92@05<0Ng]k061PH01LG5`0GEeM065QH@1LG5`0IFEU08J6QP2c
/k<0IfMW03lo?`1FEUH0J6QX06][J`1cLg<0F5QH06e]K@1fMWH0CDe=03`l?01ADE408B4Q069RHP3I
fMT0TI6A069RHP1EEED061PH01@D500C4a<0410@01DE5@0M7Ad05aLG01TI6@1^KVh0c/k>04i>CP2_
[jl0R8R80:2PX03<c<`0b<S809VIV@29RHT0OGem06YZJP1NGUh0Fe]K05MGE`19BDT0?3`l02l_;`0n
?Sh0I6AT09VIV@2a/K40Zj^[06YZJP2c/k<0UIFE07AdM02MWId0<c<c02XZ:P0N7Qh08b<S02@T900R
8R808B4Q04E5A@2ATI40BDU905=CD`0m?Cd0J6QX05mOG`0M7Ad0:RXZ05ADE01TI6@0HF5Q01DE5@02
01@D500@018B4P0E5AD05QHF059BDP1LG5`0CDe=07IfMP2d];@0h>3P0>?Sh`2VYZH0_[jn03Lg=`1j
NWX0clo?020P8080410@00l05QHF04E5A@1XJ6P0AdM705QHF01=CDd0GEeM09fMW@36a/H0c/k>06a/
K01JFUX0Xj>S08j>SP1:BTX00P1VIVH0;`1QHF4092@T00l?3`0>3Ph05ADE02LW9`1FEUH0@D5101<C
4`0O7al0De=C09RHV02/[:`0b<S80=?Cd`2l_;`0Ogmo06YZJP1UIFD0S8b<08R8R01NGUh0:b/[01hN
7P0L71`06a/K01TI6@0M7Ad0<C4a02l_;`15ADD0IFEU06IVIP2IVIT0_Kfm0;Bd]03Lg=`0bl_;0=KF
eP2OWil0YJFU02d];@1@D500^;Rh06=SH`0I6AT05aLG00<05ADE04l051@D01dM7@0R8R806ATI04E5
A@10@400Ng]k04a<C00j>SX0Lg=c0<C4a03Jf]X0fm_K0<W9b@2MWId0MGEe09FEU@1IFET0EEEE05MG
E`0i>CT0ADE502PX:00P820092@T020P800J6QX07AdM01lO7`0T92@0GUiN0<71`@39bLT0X:2P034a
<@0E5AD06QXJ02l_;`1PH600LW9b04e=C@19BDT0RXZ:09ZJVP28R8P0QXJ6071`L01KFe/0a<C40<71
`@2h^;P0/;2`09NGU`1lO7`0UiNG09^KV`2EUID0/[:b0=7Ad@3GemL0^k^k04U9B@0Q8B40:2PX05mO
G`38b<P0`l?30<30`02_[jl0_[jn09RHV01MGEd0@d=303Lg=`0U9BD07alO024Q8@0U9BD0Jf][00;o
oooo0000<02HV9P0`L7105UIF@2;Rh/0ADE506m_K`2[Zj/0GUiN08f=S@1[Jf/0=CDe04A4A01YJFT0
IFEU03lo?`1XJ6P08R8R09FEU@1`L700@410055AD@0P8200KFe]08N7Q`12@T80U9BD04E5A@0V9RH0
B4Q808R8R02@T90092@T03/k>`0[:b/0De=C09>CT`1HF5P09bLW08V9R@0n?Sh0>3Ph07AdM01YJFT0
@d=304A4A01ZJVX0EUIF02<S8`80?clo0<H0:b/[0861P@1oOgl0@d=3069RHP18B4P0GemO0<W9b@2L
W9`0=CDe05]KF`2FUYH0?Cdm06ATI02RXZ80J6QX0410@01@D500J6QX038b<P19BDT0/;2`079bLP1@
D5007alO06UYJ@17AdL0<C4a0:JVYP2JVYX0AdM703hn?P1@D500?3`l07emO@0l?3`0OGem0:ZZZP0k
>c/0ATI60;6a/@31`L40J6QX03@d=02QXJ40Ng]k01/K6`0R8R80=CDe07moO`1UIFD06ATI02d];@1A
DE40@D5105UIF@1jNWX0HF5Q055AD@10@400?clo028R8P1WIfL0E5AD05IFEP1:BTX0>SXj07=cL`12
@T80AdM706m_K`17AdL0JFUY05UIF@1OGel0FEUI03<c<`0U9BD0KFe]071`L01;Bd/0S8b<06QXJ014
A4@0F5QH07AdM01YJFT0O7al07inOP1EEED0N7Qh05MGE`1JFUX0Jf][04M7A`2:RXX0DU9B05MGE`1Y
JFT0IFEU09BDU02i^KT0TI6A04=3@`2;Rh/0Kfm_03/k>`2KVi/0Lg=c079bLP24Q8@0@41003Hf=P1F
EUH0Ng]k04U9B@1XJ6P0JVYZ02d];@0V9RH0VIVI055AD@17AdL0CTi>01lO7`1BDU80Zj^[06ATI01e
MGD0IfMW04E5A@1:BTX0YJFU0:>SX`0m?Cd0@d=309RHV01EEED0@D5102/[:`2[Zj/0Ti>C06ATI01c
Lg<0[jn_09>CT`0i>CT0JVYZ08R8R01NGUh0Ng]k09nOW`0K6a/0;Bd]0;Rh^02EUID0GUiN069RHP0Y
:BT0;bl_09>CT`1ZJVX0PX:208Z:RP0k>c/0C4a<07MgM`1;Bd/09bLW06IVIP0Y:BT0GEeM0:VYZ@1J
FUX0?Cdm04M7A`1XJ6P0MWIf069RHP0Y:BT0R8R80:VYZ@2XZ:P0JVYZ0:6QX@1KFe/0Shn?034a<@1O
Gel0a<C407UiN@17AdL0R8R806YZJP16ATH0_[jn0<S8b027QhL203`l?01e09>CT`0G5aL0@41008b<
S01XJ6P0GEeM05=CD`1YJFT0B4Q802@T901=CDd0WYjN075aL@0a<C40=SHf059BDP0[:b/0QhN708:2
PP0n?Sh0GUiN0<71`@0i>CT0ATI609RHV02JVYX0NGUi02l_;`1HF5P0Ti>C01hN7P0X:2P0Hf=S05aL
G00X:2P0;Bd]06e]K@2`/;00Lg=c051@D034a<@0VIVI02TY:@0P8200KFe]065QH@0W9bL0GUiN055A
D@0W9bL0;Bd]09nOW`16ATH0820P05ADE01=CDd0<C4a07inOP2RXZ80F5QH02h^;P0g=cL0AdM705EE
E@0B4Q80=cLg0820P021PH40F5QH06e]K@1TI6@0IFEU06ATI01iNGT0>SXj02h^;P0Z:RX09RHV01lO
7`0o?cl0GemO04i>CP1bLW80OGem04M7A`0b<S808R8R034a<@0k>c/0UIFE04A4A00[:b/0:2PX028R
8P1nOWh0`L7108Z:RP0I6AT05ADE01<C4`0?3`l0410@01TI6@1WIfL0LG5a03`l?00a<C40JFUY05EE
E@2XZ:P0Lg=c05]KF`1;Bd/06ATI00d=3@0<30`03Ph>00@03@d=02d0GemO08:2PP28R8P0WinO0;bl
_02g]kL0[jn_0<g=c@3;bl/0`L710<C4a03Lg=`0a/K608R8R02?Shl0WYjN0:BTY02VYZH0V9RH09JF
UP1hN7P0FUYJ03lo?`0Z:RX0;bl_079bLP1iNGT0GUiN05QHF01@D500>SXj038b<P0h>3P0EEEE0492
@P1BDU80M7Ad0820P023Ph<0R8R80;Ng]`1kNg/0GemO04E5A@1RHV800P0C4a<0=P0E5AD04A4A01DE
5@0E5AD0;bl_05aLG02k^k/0c/k>0<_;b`3WinL0h>3P0;no_`3IfMT0bl_;09BDU012@T80?clo0451
@@12@T80CDe=05IFEP18B4P0@41003`l?01EEED0H61P04Q8B01=CDd0JFUY0:VYZ@2l_;`0JVYZ09ZJ
VP3?cll0Y:BT07IfMP1UIFD0@D5103@d=00Z:RX0:BTY02PX:024Q8@0E5AD04=3@`1hN7P0YjNW03Hf
=P0L71`05QHF03Xj>P1?Cdl0TI6A01TI6@805ADE02X051@D01DE5@0K6a/0Shn?07IfMP1@D500MGEe
07IfMP2OWil0_Kfm0<o?c`3Jf]X0Lg=c06YZJP3Ng]h0YZJV06ATI01JFUX0Ng]k05=CD`0L71`04a<C
01DE5@0g=cL0TY:B06IVIP1?Cdl0VYZJ0:j^[P1CDe<0BDU908^;R`1TI6@0Lg=c06EUI@0n?Sh0GemO
02d];@0E5AD09bLW04Q8B01=CDd2010@401h01<C4`0G5aL0@d=305]KF`35aLD0WIfM0:>SX`0S8b<0
6ATI02<S8`0h>3P0C4a<03lo?`0W9bL071`L01HF5P0G5aL07AdM02TY:@13@d<0Cdm?04i>CP0];Bd0
9bLW03Hf=P1jNWX0WIfM0<O7a`1RHV80EEEE06i^KP2DU9@0LG5a02TY:@1BDU80GemO01XJ6P0F5QH0
6a/K01LG5`0F5QH05ADE01PH600T92@06QXJ04=3@`16ATH0LG5a04];B`0V9RH0ATI60:ZZZP3Cdm<0
cLg=071`L00n?Sh0Fe]K08>3P`1GEeL0?clo06EUI@1fMWH0DE5A05MGE`0j>SX0=cLg034a<@0S8b<0
820P02DU9@0R8R80:b/[06IVIP2c/k<0I6AT02DU9@0W9bL0@T9206ATI01:BTX0=cLg02h^;P0e=CD0
EUIF08B4Q02NWYh0G5aL05UIF@1DE5@0Jf][03lo?`0a<C40:2PX02LW9`0_;bl0Bd];020P800I6AT0
92@T038b<P1FEUH0GEeM01`L700M7Ad08R8R02d];@35aLD0_kno0;>c/`28R8P0TI6A08F5Q@0f=SH0
<c<c03Hf=P0a<C408B4Q02@T900e=CD0J6QX0_ooool0000I07inOP2_[jl0De=C0::RXP1YJFT0M7Ad
0:f][@1NGUh0VIVI08>3P`1nOWh0Bd];08b<S01mOGd0ADE50:>SX`0k>c/0VIVI07]kN`12@T80HV9R
04e=C@1aLG40UiNG065QH@02092@T03o05MGE`0Z:RX0I6AT08Z:RP0Z:RX0>SXj04E5A@0i>CT0KFe]
051@D00T92@0PH61061PH00b<S80@d=304Q8B00d=3@0>3Ph04E5A@0f=SH09bLW0410@014A4@0<30`
04U9B@1;Bd/0>c/k05YJFP0i>CT0GEeM04m?C`1CDe<0:BTY075aL@27QhL092@T02h^;P1/K6`0EEEE
03`l?017AdL0IfMW02XZ:P13@d<0QHF50492@P0h>3P08B4Q06UYJ@0m?Cd07QhN06=SH`1ZJVX0>SXj
04Y:BP1?Cdl0=SHf05mOG`0g=cL0PX:20:n_[`0Z:RX08B4Q059BDP1XJ6P0EUIF030`<02c/k<0K6a/
03Xj>P0c<c<0:BTY08^;R`1HF5P05aLG02d];@1CDe<0<S8b06][J`2BTY80Jf][05=CD`0n?Sh0E5AD
03@d=01mOGd0H61P05EEE@1NGUh0DU9B07emO@16ATH0BDU90820P01`L700VYZJ06MWI`1cLg<0GEeM
03`l?00b<S80NWYj07UiN@1BDU80U9BD06UYJ@1?Cdl0IVIV06QXJ01RHV80Jf][07alO01IFET0PH61
05QHF01>CTh0H61P05IFEP2?Shl0DU9B05=CD`1fMWH0PH610:ZZZP2`/;00NGUi04=3@`2EUID0G5aL
04=3@`2XZ:P0F5QH06][J`1bLW80GUiN04];B`2@T900QhN704e=C@1fMWH0MGEe06QXJ00[:b/0NGUi
03`l?017AdL0@d=303@d=01_Kfl0YZJV04a<C025QHD0GemO06m_K`1>CTh0VYZJ06QXJ00W9bL0BTY:
09RHV01^KVh0MWIf03Ph>02m_Kd0P82006MWI`1nOWh0YjNW0::RXP11@D40QHF5079bLP1ADE40WinO
096AT@0e=CD07alO09RHV01cLg<0GUiN059BDP0U9BD0AdM707MgM`1BDU80RHV908B4Q01HF5P0Q8B4
0861P@1ADE40:b/[04e=C@0R8R809BDU07AdM00i>CT0>c/k03dm?@0`<300BDU9055AD@0I6AT0A4A4
04e=C@1mOGd0E5AD0:BTY01ZJVX0Shn?02HV9P0b<S80E5AD06=SH`14A4@0WinO06i^KP0/;2`0Fe]K
0;2`/01HF5P0<c<c05ADE02NWYh0>CTi02HV9P1;Bd/0HV9R02d];@1KFe/0O7al06EUI@0^;Rh0:RXZ
05ADE015ADD08b<S04i>CP1OGel0;bl_06EUI@1EEED0:RXZ06][J`2NWYh0HF5Q03Ti>@2=SHd0N7Qh
03`l?00K6a/0ADE508B4Q01BDU806a/K001F05ADE01eMGD0Bd];01XJ6P12@T80[:b/055AD@1FEUH0
`L710:b/[01XJ6P092@T04i>CP1JFUX0ADE508N7Q`1DE5@07QhN02HV9P2MWId0>CTi03Lg=`20P800
BDU903Ph>01?Cdl0QhN705QHF00[:b/0ATI606ATI01NGUh0:2PX02XZ:P1?Cdl0D51@038b<P2KVi/0
Hf=S04m?C`1<C4`0D51@06UYJ@0c<c<092@T01lO7`0N7Qh08R8R05EEE@1RHV80BDU907emO@0i>CT0
:2PX02l_;`12@T80@d=307alO01UIFD09BDU030`<01VIVH0/k>c0:VYZ@2IVIT07AdM01TI6@0A4A40
3Ph>014A4@0C4a<051@D05]KF`28R8P0Fe]K06a/K01aLG40WinO09:BTP0T92@0<c<c059BDP0K6a/0
3Ph>00d=3@0>3Ph200d=3@1901<C4`18B4P0A4A405YJFP1BDU80A4A4051@D02HV9P0F5QH04A4A02e
]KD0cLg=0=_Kf`3?cll0[:b/05UIF@1<C4`0GUiN09bLW02KVi/0OWin08>3P`1nOWh0K6a/05eMG@18
B4P0D51@07emO@2;Rh/0EEEE02/[:`0G5aL04a<C00h>3P0U9BD0HV9R02LW9`0];Bd0E5AD09nOW`3C
dm<0WIfM04i>CP1UIFD0LG5a0:ZZZP0o?cl0;Rh^02l_;`0d=3@0?3`l051@D02CTi<0bLW90=CDe01]
KFd0d];B0=kNgP3De=@0cLg=0<c<c02XZ:P0WYjN06QXJ01[Jf/0F5QH05ADE01GEeL0DE5A03`l?00e
=CD0;bl_02DU9@0201dM7@0L01lO7`16ATH0`L710<o?c`12@T80XZ:R08f=S@1DE5@0Bd];059BDP1m
OGd0X:2P0;2`/028R8P0Cdm?092@T01[Jf/0/;2`0:b/[01[Jf/0>CTi01LG5`0F5QH05aLG04Q8B02;
Rh/0:BTY018B4P804a<C00@05ADE069RHP2ATI405aLG0`0E5AD02`0G5aL0CTi>0<_;b`3<c<`0RXZ:
05QHF02l_;`0;bl_04a<C02EUID0BDU900804a<C07P092@T04=3@`1WIfL0CTi>04=3@`0c<c<06a/K
03`l?024Q8@0S8b<08j>SP2FUYH0U9BD06e]K@1BDU80>c/k05eMG@1VIVH0Fe]K05QHF00K6a/0410@
018B4P0C4a<08b<S03Ph>01jNWX0b<S805eMG@2/[:`0GUiN01DE5@0I6AT08B4Q04M7A`0n?Sh0?clo
020P800G5aL071`L024Q8@10@400G5aL04Y:BP0e=CD0;Rh^02PX:00c<c<0C4a<05]KF`1bLW80<S8b
01`L700h>3P0E5AD08n?S`15ADD0<c<c06QXJ00R8R806ATI01XJ6P0I6AT05aLG01PH600I6AT0@D51
03Xj>P1XJ6P0Fe]K05iNGP0m?Cd09RHV04E5A@1RHV80Fe]K09nOW`1LG5`0N7Qh09bLW02a/K40EeMG
030`<01[Jf/0@T9203Xj>P0i>CT0?3`l04i>CP1BDU80D51@0410@00e=CD0?Cdm03hn?P1HF5P0TY:B
08J6QP25QHD0HF5Q04I6AP0_;bl0:b/[034a<@0/;2`09BDU04I6AP2;Rh/0V9RH04A4A01^KVh0Jf][
04Q8B00H61P06ATI01HF5P0L71`07AdM03Hf=P0M7Ad201XJ6P0E01`L700R8R80Bd];01lO7`0L71`0
820P03/k>`27QhL0ZJVY07UiN@26QXH0RHV90:RXZ01;Bd/0@41002d];@0S8b<092@T02DU9@1IFET0
B4Q800;ooooo0000o`2j^[X0^;Rh055AD@2YZJT0LG5a08B4Q02][Jd0F5QH09VIV@26QXH0Q8B4055A
D@25QHD0Ng]k03Xj>P2MWId0ATI60:FUY@1cLg<0@41006UYJ@1CDe<0L71`09ZJVP1PH600QhN709FE
U@1ZJVX0AdM706MWI`23Ph<08R8R0410@01FEUH0EEEE06ATI01:BTX09BDU08b<S01YJFT0<30`051@
D01=CDd0;bl_0410@01HF5P0>CTi02HV9P12@T80ADE503/k>`1FEUH0>SXj02HV9P1>CTh0ATI608V9
R@1>CTh0E5AD02d];@1lO7`0Rh^;04A4A016ATH0OWin05EEE@0o?cl0Fe]K08R8R010@400HV9R0:^[
Z`17AdL0?Shn03@d=01SHf<0FUYJ03Lg=`29RHT0N7Qh04I6AP1CDe<0Hf=S04E5A@1nOWh0?clo09nO
W`2l_;`0@410034a<@1_Kfl0TY:B055AD@0m?Cd0aLG507YjNP0l?3`0@41003@d=01jNWX0<S8b03De
=@1>CTh0H61P03@d=01;Bd/0Y:BT07=cL`0j>SX0L71`05aLG00b<S80RXZ:03dm?@1/K6`0Fe]K05aL
G01jNWX0A4A405aLG024Q8@0Kfm_0:6QX@1_Kfl0BTY:06][J`1GEeL0>c/k08>3P`1>CTh0F5QH08V9
R@1LG5`0GemO07UiN@1YJFT09bLW061PH01fMWH0EUIF09RHV017AdL0KVi^059BDP1;Bd/0P82002LW
9`1FEUH0OGem06IVIP38b<P0][Jf03hn?P18B4P0WYjN05IFEP14A4@0UiNG02d];@1YJFT0P82005YJ
FP1NGUh0ZZZZ06QXJ00g=cL0TY:B0;6a/@1YJFT0;2`/071`L00Z:RX0IFEU04e=C@0g=cL0S8b<08B4
Q00T92@0QHF508f=S@1^KVh0IfMW0:FUY@1BDU80BTY:08B4Q02HV9P0HF5Q069RHP0_;bl0_Kfm05=C
D`0f=SH0EeMG075aL@2ATI40=cLg08J6QP2:RXX0>c/k07=cL`28R8P0AdM703De=@2g]kL0@D5102l_
;`19BDT0<c<c04U9B@1ZJVX0C4a<0:FUY@2b/[80IfMW08B4Q02HV9P0?clo03Hf=P1YJFT0ATI602XZ
:P22PX809BDU03hn?P1SHf<0I6AT08j>SP1SHf<0=3@d05iNGP17AdL0IFEU02LW9`1bLW80QHF5079b
LP10@400BTY:061PH011@D409bLW06a/K01aLG40?clo09RHV02f][H0DU9B034a<@0l?3`0QXJ602XZ
:P0f=SH0JFUY06QXJ000]014A4@0ATI605UIF@19BDT0?3`l04e=C@20P800G5aL02TY:@0Z:RX0Cdm?
04];B`1gMgL0K6a/02l_;`1DE5@0YZJV05YJFP15ADD0[Jf]0;6a/@1]KFd07QhN04=3@`27QhL0=3@d
028R8P1mOGd0KFe]03Xj>P0M7Ad0DE5A0:VYZ@1lO7`0LG5a0<S8b02[Zj/0LG5a02h^;P1ADE40G5aL
03Hf=P1JFUX0F5QH02h^;P0X:2P0TI6A05EEE@0_;bl0IFEU059BDP0i>CT0CTi>08f=S@1DE5@09BDU
04M7A`1ZJVX0M7Ad04m?C`0e=CD0GemO06IVIP14A4@0AdM706MWI`1aLG40EUIF04U9B@1KFe/0DU9B
02TY:@0Q8B407alO01`L700c<c<0_[jn09FEU@2/[:`0VIVI07YjNP2;Rh/0BTY:01TI6@1YJFT0VYZJ
075aL@2<S8`0/[:b0<W9b@2i^KT0Zj^[08b<S01PH600=3@d020P800H61P05aLG01<C4`0E5AD0EEEE
0::RXP2GUiL0/[:b0=?Cd`34a<@0IfMW02HV9P0W9bL0GEeM02l_;`0?3`l0410@00h>3P0C4a<03`l?
01LG5`0E5AD05QHF01/K6`0];Bd0N7Qh03Xj>P0A4A40410@03Ti>@38b<P0^KVi08n?S`1MGEd0IFEU
092@T02h^;P0OGem01LG5`0B4Q8061PH02/[:`0a<C40I6AT06][J`1iNGT0Zj^[05iNGP0I6AT06a/K
01TI6@0K6a/05aLG01<C4`1_Kfl0SHf=06QXJ01SHf<0X:2P06EUI@2n_[h0ZZZZ0;>c/`2j^[X0]kNg
07inOP23Ph<0S8b<096AT@2DU9@0DU9B0:>SX`1QHF40MWIf0=;BdP34a<@0B4Q803Hf=P1IFET0]KFe
0:ZZZP32`/80=cLg02<S8`D05ADE00X051@D01DE5@0C4a<07AdM03De=@18B4P0JFUY0<;2`P37alL0
I6AT0P1kNg/03`1OGel0EUIF03`l?00g=cL0>CTi04i>CP1eMGD0a/K60=7Ad@20P800M7Ad09NGU`0m
?Cd0=SHf01`L700201DE5@0402h^;P1LG5`0Hf=S01HF5P805ADE01X0;bl_0:j^[P0X:2P051@D01DE
5@0D51@04A4A01@D500[:b/0KVi^0=kNgP2YZJT0YJFU0:j^[P25QHD0/;2`07YjNP1gMgL0K6a/07=c
L`1dM7@0MGEe065QH@0b<S805ADE01<C4`804A4A04`071`L05IFEP2:RXX0Xj>S0;^k^`2`/;00Ng]k
04M7A`1>CTh0[jn_07UiN@0H61P0410@00h>3P0E5AD05aLG030`<016ATH0LG5a08j>SP2TY:@0B4Q8
08B4Q00V9RH05ADE01XJ6P0l?3`0ADE504];B`0m?Cd0820P02@T900o?cl0EEEE0410@012@T80C4a<
034a<@0k>c/0>SXj02d];@0M7Ad0[:b/03<c<`0G5aL092@T03Ti>@1LG5`0W9bL05MGE`2IVIT0GemO
04E5A@10@400CDe=05ADE01XJ6P0GemO0;fm_@27QhL0/k>c0:BTY024Q8@0FUYJ05QHF01bLW80J6QX
06i^KP2NWYh0Y:BT08F5Q@1oOgl0[Zj^0:RXZ02<S8`0Fe]K0P0N7Qh05@0`<300;bl_01hN7P0L71`0
;Rh^0492@P1YJFT0VIVI0:BTY02o_kl0WinO09:BTP1KFe/0=CDe01hN7P0I6AT092@T024Q8@0U9BD0
:RXZ065QH@020;Vi^@04038b<P1aLG40H61P03lo?`<06ATI01/071`L01dM7@0g=cL07QhN01TI6@0J
6QX07QhN03Ph>02OWil0N7Qh06UYJ@1=CDd0PH6109fMW@1dM7@0@41007AdM02FUYH0fm_K09bLW01N
GUh0>CTi02`/;00Y:BT0=CDe05EEE@19BDT00_ooool0000^0;>c/`2=SHd0F5QH0;Vi^@1XJ6P0QhN7
08J6QP1QHF40_[jn0<71`@1iNGT0D51@07YjNP1/K6`0BTY:0:NWY`18B4P0U9BD06m_K`11@D40L71`
04U9B@1[Jf/0UYJF05eMG@2<S8`0VIVI06MWI`0n?Sh0L71`03Xj>P0`<300Fe]K05ADE01:BTX0L71`
02HV9P0`<300SHf=05MGE`0g=cL0DU9B03Ti>@11@D40@d=305YJFP80:BTY0?l0HV9R03lo?`0g=cL0
HF5Q0451@@0I6AT0GEeM04i>CP1mOGd0De=C03`l?00I6AT0Lg=c07MgM`0h>3P0Bd];06e]K@0S8b<0
;bl_059BDP1aLG40<C4a06MWI`2GUiL0Bd];01lO7`0^;Rh0H61P0492@P0i>CT0XJ6Q07AdM00L71`0
Cdm?05MGE`16ATH0Ng]k020P801XJ6P0Xj>S0492@P0b<S80K6a/09:BTP0m?Cd0<C4a0:b/[01dM7@0
=CDe04e=C@1;Bd/0Jf][02h^;P0A4A407alO04I6AP0d=3@0<30`07UiN@1`L700<C4a04Q8B00o?cl0
;bl_08j>SP15ADD0E5AD03dm?@1IFET0QHF503`l?00e=CD0F5QH04];B`2GUiL0LG5a051@D01DE5@0
<C4a03Ti>@2@T900DU9B051@D01bLW80@T9205QHF01jNWX0HF5Q03dm?@1ADE40G5aL04a<C02HV9P0
C4a<03lo?`0a<C40G5aL079bLP0^;Rh0A4A406=SH`16ATH0];Bd0<;2`P1cLg<0ADE5092@T00f=SH0
D51@08f=S@13@d<0G5aL07emO@1;Bd/0Lg=c0:n_[`1bLW80?Shn05aLG01VIVH0Fe]K03Xj>P1iNGT0
;Rh^04U9B@0g=cL0?3`l09VIV@1ZJVX0=CDe071`L01DE5@0I6AT069RHP2XZ:P0Fe]K02PX:018B4P0
V9RH06QXJ01fMWH0?Cdm0;fm_@2=SHd0GemO065QH@1UIFD0Kfm_03Xj>P2GUiL0WIfM06a/K02>SXh0
T92@03`l?00W9bL0[:b/07QhN01@D500=CDe038b<P1NGUh0SXj>04];B`1iNGT0N7Qh03/k>`2;Rh/0
WYjN03/k>`0_;bl0GEeM02TY:@0d=3@0UiNG03Lg=`0`<300CTi>05EEE@1DE5@0EUIF02h^;P1eMGD0
M7Ad07inOP1GEeL0TY:B051@D01jNWX0<C4a04m?C`24Q8@0D51@03/k>`1lO7`0AdM702l_;`24Q8@0
WinO06a/K00i>CT0?clo09FEU@0e=CD09RHV04m?C`14A4@0AdM704Y:BP1DE5@0GemO04e=C@0e=CD0
IFEU06MWI`0^;Rh0;bl_05UIF@0f=SH0FEUI07UiN@10@400HV9R0;2`/01fMWH0?clo0820P02FUYH0
Kfm_01hN7P1;Bd/0Q8B404=3@`0K6a/0MgMg07UiN@1KFe/09BDU05IFEP2FUYH0MWIf07]kN`36a/H0
[:b/07=cL`0`<300HF5Q06i^KP0o?cl0FEUI04I6AP0K6a/09BDU06a/K018B4P00100<c<c071`L01H
F5P0>SXj055AD@1gMgL0GemO01hN7P0n?Sh0KFe]07MgM`1?Cdl0=3@d051@D01iNGT0FEUI0P0e=CD0
LP0l?3`0CTi>05eMG@1LG5`0Hf=S05]KF`10@400<c<c05QHF02FUYH0d=3@0=7Ad@2l_;`0a<C40;Jf
]P2][Jd0QXJ606YZJP1nOWh0aLG50;bl_022PX80D51@07EeM@2d];@0J6QX04I6AP18B4P0F5QH06=S
H`1QHF40GemO04E5A@0f=SH08B4Q065QH@2^[Zh0c<c<0<_;b`2i^KT0d=3@08b<S00i>CT0:b/[04m?
C`0[:b/0410@00l?3`0G5aL06a/K01HF5P0G5aL07AdM02l_;`25QHD0<c<c00T92@0:2PX030`<03@d
=02SXj<0De=C06a/K01<C4`08b<S05MGE`1nOWh0E5AD01DE5@0C4a<05aLG01<C4`0E5AD0410@01HF
5P0S8b<0De=C05eMG@0N7Qh04a<C01XJ6P0E5AD05aLG02/[:`25QHD0F5QH05]KF`1cLg<0]kNg08^;
R`2l_;`0Ph>3079bLP1^KVh0P82005]KF`1EEED0G5aL05ADE01TI6@0RXZ:0<;2`P2HV9P0UYJF071`
L02SXj<0:b/[01LG5`1LG5`0fm_K0:VYZ@2NWYh0?3`l02h^;P808b<S0140:BTY02`/;00i>CT0>c/k
03dm?@12@T80F5QH0;^k^`33`l<0dM7A0>;RhP2f][H0`/;209RHV00i>CT071`L01/K6`0201`L700/
01dM7@0P82007alO04Q8B02f][H0dM7A06ATI01YJFT0EeMG0492@P0S8b<05aLG01DE5@0I6AT0?Cdm
0;jn_P14A4@07AdM02XZ:P2VYZH0E5AD01@D500B4Q804A4A01<C4`0A4A407alO08^;R`1]KFd0WYjN
03/k>`1VIVH0WYjN09nOW`0o?cl09RHV0820P03De=@0]KFe09FEU@24Q8@0>c/k01lO7`0B4Q8201DE
5@0<01@D500A4A4071`L09jNWP1aLG40Z:RX07=cL`25QHD0UIFE08N7Q`2e]KD0CTi>0P0C4a<0A@0E
5AD06a/K03<c<`18B4P0:b/[05eMG@0`<300D51@03lo?`19BDT0MWIf01TI6@0F5QH0;Bd]06ATI01?
Cdl0G5aL03Ti>@1EEED0CTi>02XZ:P0d=3@0?3`l03@d=00^;Rh0=cLg02TY:@0J6QX0<S8b0<K6aP1f
MWH05aLG01lO7`0V9RH0LW9b07YjNP37alL0M7Ad03Lg=`1]KFd0SHf=08Z:RP20P800NGUi06ATI027
QhL0d];B0=?Cd`33`l<0a/K60;bl_01iNGT0QXJ606IVIP1FEUH0Ti>C0:NWY`1gMgL0OWin0:RXZ02O
Wil0Zj^[07MgM`0N7Qh07alO02@T900Z:RX0?3`l02PX:00201`L700c02PX:01GEeL0]kNg0;no_`30
`<00R8R802/[:`0G5aL05QHF01/K6`0O7al0820P02DU9@17AdL0[Zj^07IfMP1CDe<0GemO069RHP1a
LG40<C4a02HV9P0G5aL06ATI01`L700M7Ad0<c<c034a<@0O7al0;bl_06QXJ02VYZH0`l?309>CT`1n
OWh0Ti>C0<?3``3=cLd0LG5a03Lg=`26QXH0d=3@0>OWi`3MgMd0ZZZZ04M7A`0j>SX0@D5105eMG@15
ADD0De=C00;ooooo0000<`2n_[h0UIFE04e=C@2GUiL0IVIV09NGU`20P800@T9206MWI`1TI6@0HF5Q
051@D01gMgL0;2`/04a<C028R8P0A4A40820P00Y:BT0AdM7079bLP0o?cl0T92@05YJFP0O7al0N7Qh
05UIF@12@T80E5AD07EeM@1?Cdl071`L03dm?@0h>3P0@T9207QhN00b<S807alO075aL@0d=3@0:BTY
04m?C`0g=cL09bLW01lO7`1ADE407AdM01DE5@0j>SX0<30`02l_;`0205IFEP0b02PX:01;Bd/0<C4a
065QH@1gMgL0DU9B01dM7@1dM7@0CDe=02HV9P1ADE40HF5Q04Y:BP0Z:RX0Bd];06UYJ@0S8b<0F5QH
071`L00Z:RX0;Rh^02`/;01JFUX0@d=302XZ:P1YJFT0J6QX02d];@19BDT0@D5103Lg=`1MGEd0@D51
09nOW`2IVIT0;bl_0492@P2@T900WIfM05EEE@0e=CD0`l?305]KF`0^;Rh0Cdm?04a<C01YJFT0De=C
018B4P0V9RH204m?C`0K02TY:@1XJ6P0G5aL03`l?01@D500@D51034a<@2:RXX0EUIF05mOG`1MGEd0
GUiN07alO016ATH0?3`l08B4Q01ZJVX0U9BD05mOG`1SHf<0G5aL03Xj>P0i>CT0RHV906IVIP1ZJVX0
QXJ60080GUiN0=D0IfMW05eMG@1>CTh0CTi>07UiN@1MGEd0SXj>05MGE`15ADD0G5aL05UIF@1gMgL0
B4Q806YZJP1fMWH0GUiN0;Bd]02[Zj/0KVi^04A4A02@T900CTi>04U9B@2GUiL0@D51065QH@1lO7`0
F5QH05]KF`1oOgl0O7al04m?C`1cLg<0P820030`<016ATH0Rh^;04];B`1KFe/0B4Q804I6AP2m_Kd0
QXJ604Q8B02EUID0FUYJ06IVIP1]KFd0ZJVY07=cL`0a<C40DU9B0:JVYP11@D40?clo02h^;P2WYjL0
Ph>305QHF01MGEd0I6AT069RHP0e=CD0RXZ:08N7Q`1RHV80TI6A08J6QP0^;Rh0=3@d0:JVYP1nOWh0
C4a<03Xj>P0`<300@T9207YjNP1NGUh0Rh^;08b<S01ZJVX0Rh^;092@T011@D40@T9204E5A@0L71`0
8b<S06IVIP0f=SH0?Shn05iNGP1IFET0H61P05YJFP0S8b<0DE5A059BDP1[Jf/0GUiN09NGU`1<C4`0
O7al04M7A`1DE5@0IFEU069RHP12@T80Lg=c059BDP1<C4`0SXj>0;Fe]@1cLg<0<S8b04=3@`2:RXX0
:RXZ02l_;`19BDT0;Bd]04E5A@1;Bd/0Jf][07inOP1<C4`0=SHf05mOG`1[Jf/0>CTi030`<019BDT0
>SXj05=CD`1bLW80;2`/05iNGP2UYJD0QhN7055AD@2RXZ80Vi^K079bLP0R8R80F5QH09BDU01UIFD0
7AdM08:2PP1iNGT0E5AD04=3@`2HV9P0`L710861P@1PH600/K6a08B4Q01?Cdl0?clo0<C4a02RXZ80
@d=305MGE`15ADD0:2PX04A4A02ZZZX0EUIF03De=@23Ph<0PH6105QHF01mOGd0SXj>06QXJ00b<S80
@D51075aL@1YJFT0@D5103/k>`2DU9@0X:2P06MWI`11@D40>3Ph03De=@0_;bl0<C4a07AdM02=SHd0
FEUI0:FUY@36a/H0[:b/08J6QP1XJ6P0Zj^[0;fm_@2QXJ40O7al0:VYZ@1lO7`0R8R80<71`@2h^;P0
TY:B030`<00K6a/0@D5107EeM@0h>3P00P0H61P0:`0I6AT07AdM024Q8@0Z:RX0?3`l065QH@28R8P0
_kno0;>c/`2QXJ40UIFE079bLP1`L700Zj^[07moO`1WIfL0<S8b069RHP17AdL0<C4a03@d=00a<C40
=3@d03Xj>P12@T80Xj>S03Ti>@0=3@d02`/;00T92@0<30`0ATI608f=S@1=CDd0Kfm_06IVIP29RHT0
[Jf]0:RXZ01aLG407AdM01PH600E5AD00P0>3Ph05P0?3`l05ADE01<C4`0n?Sh0Ogmo02LW9`0G5aL0
4a<C01DE5@0a<C40De=C0451@@0Y:BT08b<S028R8P1^KVh0?clo08^;R`2>SXh0F5QH08F5Q@0];Bd3
01`L70806a/K01407AdM02TY:@1]KFd0_;bl09^KV`25QHD0Fe]K07QhN030`<00gMgM0<?3``3De=@0
[Jf]09NGU`2?Shl0FUYJ05MGE`0205QHF00=04];B`0n?Sh0<C4a02h^;P0Z:RX0FUYJ07alO02a/K40
eMGE0=oOg`33`l<0F5QH01lO7`0301`L702=01dM7@0V9RH0DU9B08R8R03>c/h0`/;20;bl_02a/K40
WinO07inOP0X:2P06a/K01DE5@0D51@0;bl_0=CDe03?cll0ZJVY0;Rh^03;bl/06ATI010@400>3Ph0
5ADE024Q8@16ATH0IFEU06QXJ02FUYH0UiNG02DU9@1FEUH0S8b<08R8R00E5AD08B4Q06m_K`2a/K40
bLW90:>SX`1SHf<0>3Ph02PX:00I6AT04Q8B014A4@0>3Ph05ADE02d];@3Kfm/0OWin07alO01MGEd0
<C4a06EUI@2l_;`0MgMg04I6AP0B4Q805ADE01PH600_;bl0E5AD02LW9`0M7Ad0>c/k01LG5`0I6AT0
IFEU02`/;01`L700De=C01LG5`0Q8B40De=C05QHF01hN7P0VYZJ065QH@0X:2P0;bl_030`<00d=3@0
;Bd]03Ti>@0a<C407QhN03Ph>01fMWH0g=cL0<g=c@1^KVh0<c<c01hN7P1SHf<0N7Qh0<[:bP2b/[80
[jn_079bLP1IFET0MGEe07IfMP24Q8@0R8R809FEU@3Lg=`0^;Rh0;2`/03EeMD0a<C40:6QX@25QHD0
I6AT071`L01:BTX0GEeM07MgM`1RHV80QhN70:^[Z`1lO7`0P82002XZ:P0O7al0820P02<S8`0X:2P0
?3`l03/k>`0g=cL0DU9B05aLG01QHF40SXj>0<W9b@2QXJ40E5AD030`<00Z:RX0<c<c00807AdM02L0
;bl_08V9R@1FEUH05aLG03Ph>01fMWH0BDU90861P@18B4P0CDe=01/K6`0L71`08B4Q03<c<`1GEeL0
QHF505=CD`1FEUH0AdM705UIF@2<S8`0E5AD069RHP2XZ:P0[jn_08N7Q`2CTi<0MWIf0<[:bP3>c/h0
O7al07EeM@24Q8@0[Jf]0:b/[02EUID0U9BD06m_K`13@d<00_ooool0002?0;Fe]@2RXZ80DE5A09BD
U01CDe<0T92@08f=S@1ADE40UiNG0820P019BDT0KFe]09^KV`1VIVH0D51@06EUI@0i>CT0XZ:R069R
HP17AdL0Fe]K02/[:`24Q8@0TI6A06e]K@1lO7`0Q8B405]KF`12@T80MWIf075aL@0R8R80DU9B06MW
I`1EEED0KFe]03hn?P10@400WYjN05QHF00e=CD0C4a<04=3@`0];Bd0<S8b04I6AP0S8b<07AdM051@
D01GEeL0@D5105=CD`1<C4`0;Rh^05iNGP1BDU80Fe]K05EEE@1UIFD09BDU0820P01KFe/0=SHf04];
B`1ZJVX0CDe=02TY:@1@D500I6AT02l_;`1[Jf/0IfMW03dm?@0i>CT0<30`06][J`1HF5P0>c/k06QX
J01]KFd0=3@d04Y:BP1ADE40B4Q807=cL`18B4P0[Zj^08:2PP0Y:BT0=3@d05]KF`1aLG40F5QH03@d
=034a<@0C4a<02l_;`1>CTh0FEUI06EUI@17AdL0=3@d04M7A`1MGEd0FUYJ02XZ:P1/K6`0D51@03Ph
>01?Cdl0:b/[03@d=027QhL0BTY:05aLG01>CTh0Hf=S07moO`17AdL0@41008J6QP1]KFd0Y:BT06a/
K01VIVH0EEEE038b<P0n?Sh0SXj>07IfMP1jNWX0Jf][05mOG`1^KVh0Jf][061PH019BDT0GemO07em
O@1OGel0N7Qh05QHF015ADD00P1JFUX0B@1fMWH0?clo05YJFP1mOGd0MGEe0<?3``2WYjL0GemO0410
@02KVi/0>3Ph04Y:BP24Q8@0=cLg06IVIP1UIFD0GEeM06ATI02DU9@0MWIf05IFEP2=SHd0Z:RX05iN
GP18B4P0Lg=c04A4A01LG5`0=cLg02`/;02KVi/0L71`0492@P2VYZH0Kfm_03lo?`1VIVH0WIfM079b
LP0U9BD0CTi>0:FUY@1ADE40Hf=S03Ti>@2UYJD0UIFE06ATI01kNg/0Ti>C06QXJ00d=3@0SHf=0:2P
X01aLG40^k^k09FEU@1:BTX0HF5Q09:BTP1iNGT0De=C04M7A`0h>3P0@41008J6QP1[Jf/0S8b<09>C
T`2FUYH0[Jf]08:2PP1JFUX00P1QHF40IP0];Bd09RHV06m_K`18B4P0BDU9075aL@1WIfL0K6a/059B
DP0T92@0EEEE04a<C01EEED0EUIF08f=S@1NGUh0HV9R02XZ:P1RHV80PX:205EEE@0m?Cd0N7Qh06a/
K00k>c/0NWYj0;jn_P26QXH0CTi>059BDP2ATI40A4A403`l?017AdL0@D5105EEE@2CTi<0TY:B07in
OP0l?3`0?Cdm05=CD`1GEeL0>3Ph04=3@`1CDe<0CTi>04A4A01QHF40<c<c07IfMP2DU9@0M7Ad04i>
CP2HV9P0SHf=05EEE@0l?3`0TY:B0<?3``1aLG40820P08n?S`1DE5@010@402`/;028R8P0^k^k07]k
N`1@D500RXZ:08:2PP1FEUH08R8R06MWI`1fMWH0>CTi05EEE@18B4P09BDU02d];@2IVIT0HV9R03Hf
=P1nOWh0FEUI02TY:@1LG5`0[Jf]08>3P`0_;bl0ATI607]kN`1RHV807AdM04E5A@2FUYH0OGem05=C
D`21PH40?Shn03<c<`80;2`/00D0IVIV0=;BdP3De=@0`l?309VIV@0206a/K00=08J6QP2^[Zh0^;Rh
0;Jf]P1VIVH092@T020P800i>CT0UIFE07MgM`1bLW80<S8b01hN7P02059BDP0502DU9@0C4a<04a<C
01@D500F5QH00P0D51@0A00>3Ph05ADE03Hf=P33`l<0Q8B407QhN02=SHd0MWIf04m?C`1EEED0LG5a
06QXJ01HF5P0De=C0;Vi^@1oOgl0KFe]071`L02@T900YJFU0=CDe02WYjL04a<C00d=3@0820P03@d=
00T92@1MGEd0O7al065QH@2?Shl0RXZ:069RHP2EUID0]kNg08J6QP13@d<08B4Q00`<300=3@d03Ph>
00d=3@0@41004a<C01hN7P1fMWH0IfMW020P800D51@0?Shn04e=C@0[:b/07alO024Q8@0T92@0;bl_
05mOG`1XJ6P0RHV909JFUP1nOWh0LG5a024Q8@0L71`06QXJ01`L700I6AT06a/K0P0L71`0300S8b<0
Ogmo08:2PP1eMGD0Rh^;06MWI`0j>SX0b<S80=;BdP3AdM40Ph>3030`<0805ADE00L051@D01DE5@0E
5AD05ADE01@D500E5AD04a<C00805ADE04`0<C4a05MGE`38b<P0h>3P0:ZZZP2LW9`0F5QH02XZ:P0[
:b/0@d=307]kN`2QXJ40/k>c0:f][@2ATI40`l?30<c<c02e]KD0/;2`0<W9b@2b/[80IFEU020P800O
7al0RHV90=gMg@38b<P0YZJV0>CTi03MgMd0J6QX02d];@0f=SH0DE5A05ADE00i>CT0<S8b02/[:`2G
UiL0WIfM04m?C`1cLg<0RHV909VIV@0S8b<0EeMG07inOP1cLg<0IfMW04I6AP1nOWh0SHf=09NGU`1M
GEd0;Bd]01hN7P0K6a/0Cdm?0:j^[P3Ti>@0]KFe04I6AP26QXH0EUIF05QHF02LW9`0T92@05IFEP0D
51@05aLG02DU9@1NGUh0BDU901TI6@0n?Sh092@T0P0E5AD0:@0];Bd0EeMG02DU9@21PH40@d=301`L
700`<300[Zj^0;>c/`2:RXX0Bd];030`<00];Bd0B4Q804U9B@17AdL0=CDe02@T9011@D40PH610;Ng
]`2HV9P0UYJF0;fm_@2GUiL0FEUI05eMG@26QXH0c/k>0=OGe`2TY:@0NWYj05aLG01HF5P0J6QX08R8
R01mOGd0C4a<0492@P2ZZZX0a/K60080`l?30300[:b/09VIV@1`L700:b/[01hN7P0S8b<0Hf=S08R8
R02ATI40^;Rh09:BTP1oOgl0MWIf02h^;P0O7al07AdM02DU9@0T92@0<c<c061PH00_;bl09bLW03`l
?01MGEd0MWIf0<k>cP2SXj<0CDe=0410@01KFe/0>3Ph02/[:`1jNWX0S8b<01LG5`0M7Ad0=CDe059B
DP1_Kfl0KVi^08n?S`1mOGd0KFe]04e=C@1>CTh0Bd];04E5A@1eMGD202l_;`0E03Lg=`1XJ6P0]kNg
09JFUP2[Zj/0ZJVY05iNGP1/K6`0[Zj^0<o?c`2QXJ40EUIF08:2PP0n?Sh0<C4a03<c<`1BDU80U9BD
0<_;b`2`/;00RHV900;ooooo0000b02e]KD0Vi^K065QH@2k^k/0LG5a09:BTP25QHD0JFUY0<C4a030
`<00Fe]K04e=C@1WIfL0HV9R096AT@2IVIT0AdM70:6QX@1]KFd0GemO0861P@0l?3`0Shn?09>CT`1]
KFd0OWin09ZJVP1TI6@0BDU90861P@1<C4`0CDe=08b<S01]KFd0JVYZ05iNGP0E5AD0<S8b08n?S`1S
Hf<0?3`l04a<C00U9BD0EUIF03lo?`1OGel08b<S03Ti>@24Q8@0GEeM04e=C@1BDU80>c/k038b<P1g
MgL0ATI606=SH`1OGel0E5AD024Q8@20P800DU9B038b<P1<C4`0IVIV05EEE@0h>3P0O7al07IfMP16
ATH0MgMg07EeM@1LG5`0>SXj03Hf=P2:RXX0GemO03Ti>@1RHV80HF5Q04E5A@1?Cdl0G5aL055AD@1c
Lg<0De=C0;Fe]@2;Rh/0@41003/k>`1RHV80Q8B405aLG00e=CD0bl_;05]KF`0k>c/0EUIF06=SH`1B
DU808b<S061PH01VIVH0QXJ606=SH`0X:2P0Ogmo075aL@1BDU80V9RH03@d=00j>SX0R8R804=3@`1j
NWX0@41005]KF`1OGel0A4A405]KF`1[Jf/0HF5Q0:2PX01LG5`0FEUI055AD@0V9RH0?clo08j>SP1I
FET0Ph>305QHF01KFe/0HV9R06QXJ01MGEd0>c/k06a/K01nOWh0I6AT08f=S@1lO7`0SXj>0410@01E
EED0GUiN03<c<`2NWYh0VYZJ071`L02k^k/0Vi^K04Q8B01kNg/0/k>c0410@01<C4`0KVi^03Ph>02@
T900Ph>305EEE@1QHF40V9RH051@D01VIVH0c<c<0=7Ad@1GEeL0BDU905mOG`1NGUh0UYJF03dm?@14
A4@0YjNW06a/K01<C4`0bLW90:f][@1[Jf/0JVYZ09^KV`1NGUh0FEUI09:BTP34a<@0IFEU06m_K`11
@D40`/;205EEE@1HF5P0Rh^;09fMW@1MGEd0:RXZ08j>SP2PX:00?clo0P2d];@0U01jNWX0QHF50820
P01BDU80JFUY09FEU@0k>c/0BDU908^;R`1<C4`0`l?30;bl_01mOGd0XJ6Q08^;R`1MGEd0Ti>C07Yj
NP1<C4`0:2PX07=cL`1QHF40G5aL09bLW02FUYH0TI6A05mOG`0`<300GUiN04E5A@1BDU80GEeM08V9
R@1jNWX0N7Qh03Lg=`1HF5P0RHV904M7A`1:BTX0/K6a061PH00g=cL0OGem0:VYZ@1:BTX0:RXZ08J6
QP2d];@0Kfm_03Ph>00i>CT0BTY:024Q8@1`L700Q8B408F5Q@0m?Cd0@D5105iNGP0e=CD07alO06a/
K02OWil0H61P03Ti>@1iNGT0:RXZ09jNWP2g]kL0U9BD051@D02@T900Rh^;03De=@0K6a/0AdM708R8
R01ADE407QhN08n?S`1TI6@092@T024Q8@1ADE40W9bL06EUI@0f=SH0GUiN05]KF`1YJFT0<c<c075a
L@1mOGd0<S8b04i>CP1DE5@0@T9203@d=027QhL0GEeM038b<P1YJFT0C4a<04Q8B01PH600Vi^K06QX
J00R8R80@d=307UiN@1dM7@0ATI602h^;P24Q8@0MGEe05QHF02VYZH0KVi^03Lg=`10@400LW9b0;Fe
]@2YZJT0MgMg05iNGP2BTY80GEeM02PX:00P8200:RXZ04M7A`2PX:00RHV908B4Q01dM7@0HF5Q09VI
V@24Q8@0UIFE08J6QP1[Jf/0W9bL05MGE`0L71`061PH02TY:@0G5aL201DE5@0Q01@D500C4a<04a<C
02/[:`20P800Lg=c06IVIP32`/80MgMg02/[:`0R8R80:2PX05IFEP1`L700][Jf0;fm_@20P800Shn?
09ZJVP2=SHd0I6AT034a<@1_Kfl0J6QX01lO7`0=3@d03Ph>014A4@26QXH0MgMg06i^KP1aLG40UiNG
0080Xj>S0240c/k>09RHV01CDe<0;Rh^00l?3`0=3@d030`<00d=3@0>3Ph04Q8B01TI6@0i>CT0WYjN
05iNGP1LG5`0?clo02HV9P0^;Rh0<30`03Lg=`0/;2`0?clo05QHF01;Bd/0SHf=0:ZZZP2VYZH0FUYJ
06ATI00m?Cd0:2PX02DU9@0N7Qh00P0L71`03`0I6AT07AdM03/k>`24Q8@0<c<c08J6QP0h>3P0@T92
0:b/[01mOGd0UiNG01dM7@0E5AD03Ph>01<C4`0801DE5@0a01TI6@15ADD0I6AT0:f][@2i^KT0X:2P
04U9B@3;bl/0/k>c0<[:bP33`l<0Xj>S075aL@1[Jf/0EUIF03/k>`1WIfL0bl_;08^;R`2=SHd0JVYZ
0:6QX@39bLT0];Bd0;>c/`3Ogml0[Jf]0:b/[02MWId0/[:b08N7Q`2i^KT0_[jn07=cL`0m?Cd0:2PX
01lO7`0M7Ad0=cLg0<o?c`37alL0RXZ:0:RXZ03?cll0b/[:08B4Q02CTi<0BTY:02TY:@0201<C4`0J
01LG5`0T92@0CDe=07inOP33`l<0b/[:0:n_[`26QXH0IVIV0:RXZ03MgMd0R8R806m_K`2][Jd0ZZZZ
0;Vi^@2:RXX0GUiN02XZ:P0b<S80E5AD04Q8B00G5aL05ADE03`l?00F5QH201<C4`0=01DE5@0i>CT0
=SHf03De=@2BTY80<C4a02l_;`2h^;P0S8b<06EUI@1OGel0@d=30410@002061PH00n04a<C00a<C40
DE5A07YjNP2KVi/0H61P01TI6@0J6QX0ATI60:VYZ@2ZZZX0WIfM0<S8b03Hf=P0/k>c04M7A`0_;bl0
?clo08N7Q`1jNWX0C4a<04U9B@1<C4`0Bd];09VIV@1mOGd0TI6A0<71`@33`l<0`<3007inOP0J6QX0
5ADE01TI6@1;Bd/0YZJV08f=S@2HV9P0S8b<09fMW@2b/[80CTi>04Q8B00m?Cd0<30`02PX:00V9RH0
CTi>024Q8@0T92@0?clo069RHP1kNg/0NGUi03lo?`1WIfL0LG5a079bLP2i^KT0/k>c0<c<c014A4@2
01TI6@0=02@T900g=cL0OGem092@T02BTY80VYZJ0:n_[`1JFUX0A4A403lo?`0n?Sh0M7Ad04I6AP02
034a<@0D051@D01UIFD0OWin0<G5a@2JVYX0WIfM0;Ng]`3Bd]80aLG509bLW02QXJ40`L7109ZJVP1f
MWH0IVIV05YJFP1dM7@0JFUY08b<S02OWil2ooooo`0002X0][Jf06UYJ@1NGUh0VYZJ069RHP2HV9P0
FUYJ03Hf=P1GEeL0R8R804i>CP1BDU80EUIF020P801FEUH0PX:203lo?`1UIFD0<30`079bLP2:RXX0
@41009BDU01CDe<0;bl_08J6QP2ATI40FEUI03hn?P25QHD0;Bd]01PH601>CTh0EeMG065QH@1LG5`0
:2PX02<S8`1oOgl0C4a<03hn?P15ADD202LW9`3o02DU9@1XJ6P07AdM01XJ6P12@T80@d=30451@@1@
D500<c<c02XZ:P1^KVh0@D5105ADE01NGUh0;bl_03De=@2ATI40JFUY03<c<`1=CDd0?3`l02d];@1G
EeL0RXZ:07EeM@0n?Sh0JVYZ0861P@0a<C40;Bd]05aLG023Ph<0IFEU034a<@1OGel0Hf=S03lo?`1d
M7@0IfMW055AD@2>SXh08B4Q08b<S02h^;P0HV9R03hn?P1PH600QHF503Hf=P18B4P0a<C409nOW`0i
>CT0Bd];06IVIP1@D500:b/[01@D500Y:BT0GemO05]KF`0[:b/0Q8B405UIF@0R8R80EEEE04E5A@0n
?Sh0P82003lo?`29RHT0AdM704a<C01>CTh0>3Ph051@D01VIVH0E5AD0861P@1FEUH0:BTY05EEE@1M
GEd0=cLg08:2PP0M7Ad0Hf=S06EUI@1BDU80I6AT06i^KP1KFe/09bLW07=cL`21PH40GUiN07emO@0h
>3P0De=C03hn?P1DE5@0IVIV01DE5@19BDT0K6a/05EEE@2^[Zh0U9BD02TY:@0/;2`0L71`0410@01A
DE40JFUY03@d=01EEED0N7Qh05=CD`1MGEd0V9RH04=3@`0Z:RX0E5AD075aL@0n?Sh0EEEE04=3@`1B
DU80RHV905UIF@1<C4`0X:2P04I6AP0I6AT0IVIV079bLP1RHV80LG5a0;>c/`0i>CT0:2PX0410@01g
MgL0IVIV05IFEP1BDU80a<C406QXJ00^;Rh0D51@07QhN00m?Cd08b<S09JFUP2KVi/0A4A408Z:RP1f
MWH0<C4a08>3P`2LW9`0EEEE02d];@1=CDd0>SXj03Ti>@1VIVH092@T06YZJP1nOWh0C4a<0820P02>
SXh092@T05]KF`1jNWX0Bd];028R8P1aLG409bLW04Q8B023Ph<0R8R809BDU025QHD0BDU906IVIP15
ADD0GUiN02`/;01eMGD0Z:RX09JFUP1NGUh0H61P08f=S@0/;2`0<c<c08:2PP1VIVH0A4A407EeM@2E
UID0@T9201LG5`1MGEd0Ng]k03Lg=`0Z:RX0=cLg02`/;012@T80F5QH05=CD`1SHf<0:RXZ04=3@`1F
EUH0;Rh^00T92@0_;bl0H61P04E5A@0^;Rh0IVIV01HF5P1BDU80UIFE07IfMP1@D500QhN708f=S@1W
IfL06QXJ04I6AP1lO7`0;Rh^01TI6@22PX80RXZ:06IVIP0e=CD0LW9b09BDU00`<300C4a<08N7Q`1/
K6`0HV9R03`l?01iNGT0HV9R038b<P1bLW80?3`l000Q028R8P0c<c<0KFe]034a<@0g=cL0MGEe06IV
IP1:BTX0Fe]K075aL@1MGEd08b<S04E5A@1lO7`0Fe]K03dm?@0d=3@0T92@0820P01FEUH0[Jf]09nO
W`2^[Zh0`l?30;:b/P1ZJVX0DE5A04e=C@17AdL0BDU906m_K`1CDe<06a/K00806ATI00D0Ogmo0;Bd
]02b/[80R8R8065QH@0208Z:RP0c05iNGP2BTY80JFUY0;no_`2RXZ80FEUI04e=C@1<C4`0ADE503hn
?P0c<c<0:BTY02LW9`0O7al0JVYZ06m_K`26QXH0D51@0;Jf]P35aLD0QXJ607IfMP2CTi<0a<C40:FU
Y@2d];@0^k^k09FEU@1FEUH0;2`/018B4P0>3Ph04A4A01@D5018B4P0OGem05=CD`0o?cl0K6a/0;Zj
^P21PH40QXJ606i^KP1UIFD0HV9R07=cL`3MgMd0[Zj^034a<@0F5QH02@T9008030`<0P0=3@d200h>
3P0800l?3`1kNg/0`l?305MGE`14A4@0>SXj0410@00m?Cd204A4A00M06=SH`1PH600?Cdm08:2PP3?
cll0<C4a01/K6`0L71`0;Bd]03lo?`1=CDd0Cdm?0410@00a<C40=SHf02DU9@0o?cl0WinO08:2PP1L
G5`0XZ:R0:BTY01/K6`0LG5a09fMW@0M7Ad051@D014A4@0C4a<00P0>3Ph0=P0C4a<05ADE01LG5`0F
5QH09RHV04M7A`1ADE40@d=307emO@2GUiL0Lg=c0<O7a`1_Kfl0_kno0=CDe02][Jd0OWin079bLP1<
C4`0;bl_03Ti>@0m?Cd0<c<c08n?S`2n_[h0KFe]03/k>`1>CTh0GEeM0:^[Z`3QhN40jNWY0:RXZ02n
_[h0cLg=075aL@1ADE40FUYJ05mOG`2][Jd0e=CD0:^[Z`2EUID0SHf=0;Fe]@3Lg=`0fm_K0>3Ph03O
gml0hn?S0>KViP3Cdm<0Fe]K02l_;`80410@03<03Ph>01DE5@0>3Ph03Ph>01TI6@2>SXh0bLW907em
O@0J6QX051@D01/K6`1lO7`0alO708Z:RP2<S8`0c<c<0=3@d03Hf=P0[jn_09nOW`1RHV80FEUI01HF
5P0E5AD06ATI0451@@0E5AD0410@014A4@0B4Q805aLG04a<C00V9RH0GemO09jNWP2CTi<0Xj>S0:6Q
X@2=SHd0WYjN0::RXP2GUiL0Z:RX06YZJP1eMGD0JFUY096AT@2?Shl0ADE501PH600G5aL00P0L71`0
;@0m?Cd0SXj>05=CD`1KFe/0g=cL0>CTi03Fe]H0_Kfm0;jn_P1ADE408R8R03Lg=`1ADE40L71`09:B
TP37alL0N7Qh0:>SX`3Cdm<0clo?0<K6aP26QXH06ATI01DE5@0_;bl0Cdm?04=3@`22PX80DU9B04e=
C@2:RXX0_Kfm06EUI@1FEUH0AdM704E5A@14A4@0CDe=06YZJP19BDT0C4a<07AdM025QHD0UYJF04e=
C@0201LG5`0V02`/;02KVi/0Xj>S04=3@`0e=CD0EeMG03Lg=`0L71`08B4Q034a<@1cLg<0^KVi0::R
XP2d];@0ZZZZ07QhN01MGEd0EUIF065QH@2OWil0[Jf]08J6QP20P800MGEe059BDP2LW9`0U9BD0:b/
[02n_[h0emOG0:FUY@2:RXX0bl_;06QXJ00S8b<0;Rh^04=3@`1aLG420:j^[P0306i^KP11@D40>3Ph
00;ooooo00001@32`/80Vi^K051@D02OWil0Hf=S0080WYjN01T0FEUI08R8R02/[:`0EEEE055AD@1d
M7@0F5QH06ATI01fMWH0>CTi08f=S@1BDU80>c/k069RHP0^;Rh0WYjN06][J`0_;bl0HF5Q096AT@1R
HV80CDe=09jNWP1bLW80<C4a0080EeMG0740IVIV07IfMP0/;2`0<c<c09NGU`0i>CT0@T9205aLG00l
?3`0;2`/01HF5P1EEED0:BTY01/K6`1EEED09BDU03lo?`1UIFD0Bd];02d];@1ZJVX0@T92061PH01k
Ng/0A4A401TI6@1PH600CTi>02PX:01FEUH0CTi>0410@00[:b/0Lg=c055AD@0c<c<0MWIf05aLG00U
9BD07AdM01lO7`1ADE40BTY:02XZ:P1IFET0ATI601TI6@0g=cL0D51@03Hf=P1IFET0;Bd]06YZJP20
P800=3@d03`l?01PH600M7Ad028R8P0e=CD0];Bd05UIF@0_;bl0EeMG0861P@1TI6@0BTY:01hN7P0o
?cl0Hf=S03Lg=`0_;bl0TY:B06=SH`0c<c<0De=C04a<C01BDU80SXj>03lo?`1SHf<0D51@061PH01^
KVh0<C4a03/k>`1RHV80DU9B08b<S022PX80CDe=04i>CP0^;Rh0@41009>CT`1UIFD0MgMg05YJFP11
@D40Kfm_09>CT`1_Kfl0>c/k065QH@15ADD0GEeM09FEU@1GEeL0F5QH02h^;P1SHf<0OGem04M7A`02
051@D01H03Hf=P27QhL0UIFE055AD@12@T80U9BD02DU9@1FEUH0LW9b0410@01TI6@0B4Q803/k>`1M
GEd0U9BD071`L01_Kfl0N7Qh079bLP0b<S80M7Ad06ATI014A4@0NWYj059BDP1?Cdl0^;Rh07inOP0b
<S80V9RH06IVIP10@400NWYj0::RXP1VIVH0<C4a04I6AP2BTY80<S8b02/[:`1?Cdl0bLW909>CT`1<
C4`0KFe]08B4Q01JFUX0;Bd]0:BTY02EUID0KFe]0;jn_P2ATI40>CTi05iNGP1@D500G5aL04e=C@1J
FUX0:BTY02h^;P19BDT0=SHf08J6QP1cLg<0AdM706e]K@2KVi/0>3Ph05ADE01jNWX07alO01`L701Y
JFT09BDU03Xj>P1MGEd0Cdm?06m_K`1HF5P0>CTi05iNGP17AdL0DU9B0492@P17AdL0LW9b07AdM080
Bd];08L0MgMg04e=C@0i>CT0MGEe059BDP0j>SX0MWIf09bLW01_Kfl0=cLg07QhN024Q8@0:2PX038b
<P1FEUH0Bd];055AD@1^KVh0JVYZ05iNGP0_;bl0C4a<05=CD`13@d<092@T03/k>`0m?Cd0;2`/02/[
:`18B4P0<C4a0861P@2a/K40M7Ad04Y:BP2<S8`0Shn?06=SH`0Q8B40BTY:07QhN00/;2`07AdM07in
OP2>SXh0IVIV03Xj>P20P800^KVi05YJFP0L71`0:b/[06][J`1JFUX0?Shn09ZJVP18B4P0;2`/06m_
K`1HF5P0>SXj03Ti>@1eMGD09BDU06MWI`2TY:@0MgMg04I6AP1IFET0U9BD04=3@`14A4@0SHf=0:NW
Y`1=CDd0;bl_03Xj>P2DU9@0JFUY02@T9024Q8@0d=3@0=oOg`3?cll0^k^k09VIV@24Q8@0M7Ad05aL
G01OGel0Fe]K05aLG012@T80820P024Q8@1]KFd0GemO03lo?`0Z:RX0=CDe05EEE@2IVIT0J6QX09NG
U`35aLD0]kNg05mOG`0o?cl0>SXj03Hf=P0h>3P0?Cdm04U9B@1?Cdl0GEeM071`L02e]KD0/[:b05iN
GP1[Jf/0FEUI02XZ:P0E5AD05QHF04M7A`1_Kfl0LG5a06e]K@1QHF40KFe]03Lg=`0`<300<C4a02<S
8`0C4a<00P0@41004`0W9bL0RXZ:0;>c/`2BTY80eMGE08Z:RP17AdL0ADE504=3@`0k>c/0JFUY0=7A
d@2c/k<0RXZ:02LW9`0<30`02@T900L71`0<30`00`0=3@d0400A4A40OWin0:FUY@2_[jl0VIVI08>3
P`1cLg<0JFUY06MWI`1RHV80N7Qh0820P02OWil0cLg=0;Jf]P0^;Rh201XJ6P0F01HF5P0G5aL05aLG
01TI6@0R8R80<c<c04Q8B01KFe/0TI6A0:FUY@2[Zj/0>CTi0:ZZZP2<S8`0=cLg061PH02HV9P07alO
018B4P0@41004a<C00h>3P804A4A01006QXJ0492@P1ADE40A4A402TY:@0O7al0=cLg0:RXZ01aLG40
PX:20;Bd]03Ph>00UiNG05UIF@1FEUH0MWIf0P2=SHd09`1HF5P0BDU903Ti>@0f=SH0J6QX0;2`/02B
TY80;Bd]02PX:00n?Sh0IFEU0=oOg`3Vi^H0f=SH0=?Cd`3<c<`0Vi^K09RHV02EUID0TY:B07YjNP2@
T900d=3@0>KViP3Ti>@0]kNg0=oOg`3Ng]h0g=cL0:JVYP2e]KD0gMgM0<[:bP0^;Rh04A4A00h>3P0?
3`l0410@00h>3P02014A4@0401PH602BTY80LW9b01dM7@804a<C00`051@D01LG5`1cLg<0^;Rh061P
H039bLT0d];B0>7Qh@3GemL0clo?08R8R00G5aL201DE5@0?05mOG`1LG5`05ADE018B4P0A4A4051@D
01<C4`0U9BD0@41002PX:02HV9P0[jn_04E5A@2HV9P0a/K60080bLW900P0`l?30;Rh^02[Zj/0`L71
0:j^[P1hN7P0<C4a01TI6@805aLG00`06a/K01TI6@0Z:RX0=cLg02d];@0o?cl0WinO05UIF@2ATI40
^k^k0::RXP0J6QX201DE5@1401/K6`13@d<0P82008^;R`2EUID0bl_;0>GUi@3WinL0fMWI0:RXZ01C
De<0>SXj04];B`0n?Sh0@41001XJ6P1:BTX0E5AD04m?C`2;Rh/0ZZZZ06YZJP1WIfL0Jf][06ATI01a
LG40TY:B08>3P`2<S8`0Zj^[0<_;b`2QXJ40GemO01lO7`0M7Ad0=CDe08V9R@1YJFT04A4A01@D500G
5aL0DE5A04i>CP0X:2P0=cLg05eMG@2TY:@0eMGE0<S8b02YZJT0Ti>C09RHV02QXJ40]kNg0=CDe03K
fm/0b<S80<71`@35aLD0b/[:0<?3``1ZJVX0`/;20=?Cd`2`/;00MWIf0:JVYP2CTi<2028R8P0802`/
;00c<c<0A4A408>3P`2BTY80Vi^K05EEE@0k>c/2ooooo`0001<0[jn_08^;R`1BDU80Ogmo05eMG@2Z
ZZX0Ti>C05iNGP2@T900WYjN06QXJ01bLW80[:b/06UYJ@1mOGd0EUIF04Y:BP2PX:00F5QH0080D51@
02@0<c<c0:2PX02<S8`0=cLg06m_K`12@T80ADE5059BDP2>SXh0GemO03Hf=P1:BTX0<S8b05EEE@1f
MWH09RHV03lo?`2KVi/0AdM703Xj>P1<C4`0=CDe034a<@0V9RH0FUYJ02XZ:P0U9BD0GUiN0451@@0j
>SX0A4A403lo?`0R8R80FUYJ034a<@1:BTX205=CD`3o020P801^KVh0;Rh^02HV9P1MGEd0DE5A03`l
?00g=cL0RXZ:03lo?`0X:2P0OWin06QXJ014A4@0;Rh^03Xj>P1bLW80ATI603<c<`2;Rh/0J6QX04A4
A01=CDd0F5QH04I6AP1VIVH0D51@09bLW01cLg<09BDU0492@P1lO7`0P82005MGE`0e=CD0aLG503@d
=00Z:RX0?clo07YjNP1FEUH0<S8b02HV9P19BDT0K6a/05eMG@0R8R80Vi^K059BDP0[:b/0HF5Q03Hf
=P1:BTX0PX:204];B`1YJFT09BDU05QHF01PH600?Cdm0451@@17AdL0?Cdm059BDP1aLG40HV9R05=C
D`0j>SX0<C4a07alO01WIfL0MWIf05aLG01IFET0IFEU05eMG@1UIFD0BDU907QhN01lO7`0DE5A06=S
H`1QHF40HV9R04A4A01YJFT0LG5a04I6AP1IFET0OWin07=cL`2NWYh0T92@03Ph>01IFET0VIVI03Lg
=`1>CTh0C4a<04A4A02HV9P0Hf=S04U9B@14A4@0NGUi05aLG01oOgl0YZJV09BDU00i>CT0F5QH04I6
AP1?Cdl0PX:202d];@0`<300SHf=05]KF`12@T80alO709NGU`1HF5P0MgMg09bLW01SHf<0ADE507Ad
M02RXZ80ADE504e=C@1`L700e=CD08J6QP1UIFD0YZJV0;Bd]01HF5P0;bl_0:>SX`1oOgl0FUYJ0<c<
c02YZJT0J6QX079bLP1DE5@0C4a<05eMG@1DE5@07AdM03Xj>P1QHF40?clo08V9R@1iNGT08b<S05YJ
FP25QHD0B4Q805iNGP2HV9P071`L02<S8`1fMWH0ADE50410@01gMgL0DE5A07]kN`10@40092@T06QX
J01UIFD0HF5Q059BDP1ADE40TI6A08f=S@0/;2`0?3`l09jNWP1GEeL0?Cdm07=cL`10@4008B4Q04M7
A`2;Rh/0M7Ad04E5A@23Ph<0MGEe0410@00U9BD0CTi>05QHF01DE5@0[Zj^08f=S@1ADE408b<S04a<
C01iNGT0DU9B034a<@12@T80=cLg02d];@0d=3@0DE5A03`l?028R8P0RHV905=CD`1jNWX0c<c<0;Bd
]01ZJVX08B4Q04];B`1eMGD04A4A01LG5`1kNg/0TI6A071`L01BDU80ZJVY0;fm_@1/K6`08R8R0492
@P1WIfL061PH051@D038b<P0Q8B402/[:`17AdL0@T9203Ti>@1UIFD0Y:BT04];B`0g=cL0Ng]k04Q8
B01dM7@0XZ:R08j>SP1IFET07alO03Ph>01RHV80EEEE000T03Xj>P11@D40WIfM06i^KP0d=3@0B4Q8
0<S8b02l_;`0CDe=03<c<`0Y:BT0:b/[038b<P1:BTX0LW9b0:FUY@2>SXh0XJ6Q03Xj>P0b<S80L71`
05mOG`0Z:RX09bLW02`/;00d=3@0CDe=092@T03<c<`0f][J0<o?c`1FEUH0=CDe02h^;P0W9bL08B4Q
0P0I6AT0:00J6QX0:2PX02d];@1QHF40NWYj07QhN020P8008B4Q014A4@0@41004A4A010@400L71`0
:2PX03Hf=P1DE5@0J6QX04e=C@0W9bL0:BTY03Lg=`14A4@0;2`/01DE5@0W9bL0DE5A08J6QP2XZ:P0
e]KF08j>SP0d=3@0>c/k02<S8`0Z:RX0PX:208B4Q00W9bL0A4A407=cL`0Y:BT200`<300900<30`0=
3@d03@d=00l?3`0R8R80F5QH02TY:@0N7Qh0820P00807AdM00l08B4Q02PX:017AdL0YJFU0:NWY`2X
Z:P0Zj^[0;6a/@2NWYh0EEEE02d];@0M7Ad06QXJ01/K6`0G5aL00`0E5AD0B@0G5aL0<S8b08j>SP2<
S8`0Hf=S04e=C@1ZJVX0=SHf06ATI02ATI408b<S014A4@0>3Ph05ADE01@D500S8b<0ATI6051@D00b
<S809bLW02<S8`0T92@08B4Q0861P@23Ph<0=3@d05IFEP31`L40fm_K09:BTP0h>3P05aLG01DE5@0N
7Qh0ATI607emO@20P800HF5Q05MGE`24Q8@0U9BD0=3@d01MGEd08B4Q01hN7P0Y:BT0dM7A0=_Kf`3P
h>00bl_;06m_K`11@D40AdM704e=C@18B4P0CTi>04e=C@1_Kfl0SHf=0<k>cP2e]KD0bl_;06UYJ@1?
Cdl0`<300=SHf03;bl/0[:b/06i^KP0@41003@d=010@400>3Ph00P0@41002`0C4a<0ATI609NGU`0d
=3@05ADE010@400E5AD04a<C018B4P0M7Ad0_Kfm0080_[jn01l0bl_;0=OGe`3EeMD0`l?302PX:00D
51@05ADE02h^;P3>c/h0Lg=c01HF5P0E5AD051@D01<C4`0>3Ph04a<C04E5A@0X:2P0O7al05QHF019
BDT0FUYJ0<71`@26QXH0GEeM05UIF@2/[:`0fm_K0<S8b019BDT09RHV00805QHF0P0J6QX0300L71`0
61PH02d];@0];Bd0=SHf04];B`1jNWX0@D5102DU9@1;Bd/0^k^k02l_;`<05ADE00d07AdM06=SH`10
@400JVYZ075aL@2c/k<0i>CT0=gMg@33`l<0/[:b07IfMP15ADD0:BTY00805ADE01806QXJ04I6AP1E
EED0Ph>308b<S00`<300;Rh^02HV9P0T92@0;2`/05aLG00f=SH0ATI608B4Q02g]kL0^[Zj05mOG`1J
FUX204e=C@0V08B4Q01SHf<05ADE01<C4`0F5QH09bLW04];B`1_Kfl0FUYJ07MgM`2VYZH0TI6A09FE
U@2QXJ40Jf][061PH01RHV80AdM704U9B@1IFET0GemO09FEU@39bLT0d=3@0=?Cd`2f][H0c/k>0;^k
^`30`<00`L710<o?c`2HV9P0;Bd]02/[:`0f=SH0>SXj059BDP1oOgl203dm?@0307=cL`24Q8Cooooo
007ooooo0000n@35aLD0TY:B059BDP2DU9@0DU9B09VIV@1lO7`0IFEU07YjNP1OGel0?clo05QHF028
R8P0LW9b08N7Q`1NGUh0?Shn09NGU`1JFUX0De=C071`L00/;2`0U9BD09RHV00d=3@0Kfm_09BDU01J
FUX0BDU909FEU@1SHf<0F5QH08F5Q@1RHV80OWin04e=C@0U9BD0LG5a09nOW`1;Bd/0>CTi04U9B@0X
:2P0;Bd]01/K6`1GEeL08B4Q01hN7P1JFUX0@d=303lo?`19BDT0A4A4024Q8@1BDU80@41007alO01h
N7P0HV9R020P801iNGT0FUYJ03De=@1BDU80=cLg02XZ:P1PH600ZJVY08F5Q@17AdL0IfMW06EUI@1:
BTX0;Bd]03lo?`1hN7P0=cLg02`/;01CDe<0I6AT04M7A`1>CTh0;Bd]04a<C020P800DE5A0:6QX@2B
TY809bLW05=CD`1iNGT0Kfm_04];B`12@T80^KVi04m?C`0e=CD0?clo08>3P`1@D500>CTi06=SH`1f
MWH0RXZ:06a/K00N7Qh0_Kfm055AD@19BDT0RXZ:03`l?01CDe<0OGem04i>CP1lO7`0>c/k06=SH`1G
EeL0>c/k04A4A01EEED0Bd];05IFEP1SHf<0EUIF05MGE`11@D40?clo07emO@0^;Rh0K6a/06MWI`1E
EED0GUiN05EEE@1MGEd0;Bd]06][J`1ZJVX0DU9B05aLG01iNGT0O7al03De=@1XJ6P0F5QH03hn?P2A
TI40QHF505]KF`1cLg<0P820028R8P1/K6`0TY:B02`/;00o?cl0<S8b02/[:`1GEeL0Lg=c03hn?P0m
?Cd0MGEe02XZ:P1lO7`0Z:RX0::RXP0j>SX0HF5Q02/[:`1MGEd0X:2P05EEE@0j>SX0WIfM07AdM01=
CDd0RXZ:075aL@1XJ6P0QhN70<G5a@1=CDd0;bl_08>3P`2RXZ80HF5Q059BDP2<S8`0e]KF03`l?00m
?Cd0JFUY08R8R01HF5P0:RXZ0:BTY02JVYX0Shn?0=[JfP2[Zj/0JFUY08R8R01CDe<0@d=302`/;01T
I6@0:BTY01lO7`1EEED0=SHf0;>c/`2RXZ80LG5a07alO01oOgl0;2`/09:BTP2VYZH0EUIF01/K6`1M
GEd0<C4a075aL@35aLD0Z:RX0;:b/P1JFUX0;Rh^059BDP11@D40G5aL03Ti>@23Ph<0][Jf092@T00n
?Sh0?3`l07AdM00a<C40>CTi09NGU`1GEeL0;Rh^04M7A`2NWYh0>CTi02`/;0020:>SX`1_065QH@0_
;bl0DU9B055AD@0e=CD0IfMW07UiN@1WIfL0@d=304i>CP1^KVh0@T9203Xj>P1_Kfl0IfMW02PX:00_
;bl0CTi>03Hf=P28R8P0L71`03@d=00c<c<0CDe=079bLP1>CTh0820P05EEE@1kNg/0:BTY01XJ6P1k
Ng/0J6QX02PX:00j>SX0HF5Q0;Jf]P1jNWX09BDU03Lg=`1:BTX0?Shn02`/;01mOGd0F5QH02d];@1P
H600>3Ph01/K6`0h>3P0Ng]k03<c<`1MGEd0T92@03Ti>@0k>c/0OWin07EeM@1ZJVX0:2PX04];B`1n
OWh0Cdm?02/[:`1FEUH0Xj>S07inOP16ATH0A4A409jNWP1oOgl0?Cdm03/k>`11@D40ADE504=3@`0n
?Sh0>c/k04I6AP2FUYH0_;bl0::RXP1:BTX0UYJF0:NWY`2QXJ40<C4a02`/;01GEeL0RHV90<71`@2m
_Kd0e]KF0;bl_03?cll0QHF505eMG@1BDU80HF5Q05eMG@1EEED0FUYJ04I6AP1EEED0Jf][07MgM`2N
WYh0I6AT01`L700B4Q803@d=00803Ph>00P03`l?00h>3P0I6AT06QXJ03dm?@1dM7@0BTY:03Hf=P80
<S8b02d0IVIV0:ZZZP27QhL0K6a/05QHF00o?cl0aLG50:ZZZP11@D40@41002PX:01_Kfl0/[:b02HV
9P0<30`03`l?03Ti>@1jNWX0<30`01<C4`0:2PX03@d=01<C4`0D51@0IVIV051@D00n?Sh0@41005iN
GP1DE5@0BDU9051@D01DE5@0D51@08:2PP1eMGD0<c<c024Q8@0j>SX0_kno061PH01dM7@0EeMG02DU
9@0L71`00`0E5AD04`0C4a<05ADE01LG5`1cLg<0SXj>07IfMP0Z:RX0MgMg04A4A01mOGd0/K6a02DU
9@0D51@0410@02LW9`17AdL0@D5102XZ:P0Q8B400P0N7Qh07`0Q8B407AdM03Hf=P2IVIT0@T9202TY
:@0f=SH0R8R80<g=c@17AdL0SHf=05QHF00O7al07QhN024Q8@0M7Ad0=3@d08>3P`2GUiL0EUIF065Q
H@35aLD0a<C4071`L00f=SH0>CTi0<71`@38b<P0fMWI0861P@0M7Ad01`0E5AD03@0H61P0OGem0=WI
f@2NWYh07AdM03`l?01NGUh0P8200:BTY023Ph<0[:b/034a<@0=3@d0100>3Ph0;@0U9BD0Ph>304M7
A`0S8b<051@D01DE5@0A4A404a<C01TI6@1NGUh0XJ6Q092@T02^[Zh0ZJVY0<[:bP3>c/h0WinO01HF
5P0E5AD0<S8b08f=S@0d=3@0FEUI01hN7P0E5AD051@D01DE5@0A4A4051@D02@T901/K6`0Q8B405UI
F@1EEED0SHf=07emO@2?Shl0V9RH0;^k^`3Fe]H0YZJV09RHV00K6a/04a<C018B4P0301TI6@805aLG
01T0?3`l02LW9`0_;bl0M7Ad071`L00d=3@06ATI01/K6`1[Jf/0OGem01LG5`0E5AD05aLG01/K6`1F
EUH08B4Q02TY:@0c<c<0@T9208n?S`0n?Sh0N7Qh0;jn_P2:RXX092@T00805ADE01<05aLG01`L700e
=CD0BTY:0::RXP23Ph<0Jf][05=CD`0d=3@0;Bd]02`/;01VIVH0>CTi05ADE02CTi<0QHF50::RXP1g
MgL0NWYj0080WYjN00@0QhN707MgM`0E5AD04a<C0P0I6AT0300Q8B40]KFe0=;BdP3Hf=P0`L710:FU
Y@21PH40?3`l028R8P0P8200:2PX01TI6@805ADE01H05aLG05aLG02YZJT0ZZZZ0=3@d03Ogml0]kNg
069RHP1cLg<0U9BD0<?3``2j^[X0RXZ:03`l?00i>CT0CDe=09VIV@1KFe/0<30`03Hf=P0g=cL0FEUI
0_ooool0003o0<K6aP2DU9@0DU9B0:ZZZP1IFET0[:b/08J6QP1aLG40Z:RX0:BTY01ADE40EUIF06UY
J@1>CTh0S8b<075aL@1ADE40WIfM06EUI@1]KFd0QhN703@d=02WYjL0UYJF030`<01YJFT0T92@05IF
EP1<C4`0LG5a02/[:`0j>SX0Jf][079bLP1GEeL0E5AD01TI6@17AdL0Ti>C04U9B@0g=cL0DU9B01dM
7@1DE5@0;Rh^06][J`0I6AT0?clo07MgM`1=CDd0>c/k04a<C013@d<0:b/[04i>CP0f=SH0B4Q807Yj
NP16ATH0?3`l08R8R01^KVh0=CDe05MGE`0c<c<07AdM03De=@1YJFT0H61P0410@01gMgL0IFEU02d]
;@1CDe<0L71`07UiN@1DE5@0>3Ph05=CD`1OGel0@d=304Q8B01?Cdl0?Cdm07QhN01ADE40VIVI08B4
Q00m?Cd0A4A406ATI01VIVH092@T069RHP2h^;P0GEeM03/k>`12@T80SHf=04Y:BP0S8b<092@T03lo
?`1mOGd0Kfm_02@T902i^KT0IFEU03De=@1OGel0@d=304e=C@1_Kfl0GUiN096AT@0n?Sh0I6AT04];
B`1MGEd0MGEe05UIF@1>CTh0F5QH04m?C`0c<c<0F5QH03@d=00e=CD0Ng]k05aLG01DE5@0GUiN05IF
EP1KFe/0De=C06IVIP0c<c<0IVIV06i^KP1?Cdl0PX:205]KF`1BDU80;Bd]06][J`1ADE40;2`/05YJ
FP25QHD0DU9B07EeM@27QhL0<30`05]KF`2BTY80:RXZ03Lg=`15ADD0=3@d05YJFP1ZJVX0;bl_03Lg
=`23Ph<0IVIV07alO01RHV80TY:B03Hf=P1CDe<0?Cdm04A4A02@T900CDe=03Lg=`2BTY80RHV9079b
LP2GUiL0QhN706m_K`1oOgl0]kNg08B4Q00W9bL0HV9R0;bl_01PH600FEUI09bLW03<c<`0N7Qh05AD
E025QHD0XJ6Q075aL@0/;2`0V9RH0::RXP2b/[80aLG50:b/[01SHf<0NGUi05MGE`1RHV80?Shn05EE
E@0d=3@07alO05IFEP0_;bl0Ti>C08n?S`1KFe/0P82007inOP0n?Sh0ADE508b<S00m?Cd06QXJ05=C
D`0S8b<0?3`l06=SH`1KFe/0LG5a05mOG`0d=3@0EeMG04];B`1KFe/06a/K059BDP1lO7`0Shn?05MG
E`1@D500M7Ad01dM7@0W9bL0NGUi06][J`0h>3P0Bd];096AT@0P820061PH07IfMP19BDT0:BTY038b
<P1FEUH0CTi>000h05aLG01QHF40De=C059BDP0j>SX0BTY:05YJFP0b<S805ADE05QHF01`L700<c<c
03Lg=`0i>CT0ATI60;Rh^02@T900HV9R061PH02DU9@0[:b/03lo?`0m?Cd0P82008F5Q@0k>c/0=CDe
0:FUY@2<S8`0IVIV04M7A`1cLg<0^k^k07emO@0U9BD0B4Q805IFEP1=CDd0?Cdm08N7Q`0h>3P0?clo
09jNWP1PH600;Bd]03Xj>P18B4P07alO0410@01aLG40De=C03hn?P1KFe/0K6a/02h^;P1JFUX209bL
W00T0451@@0S8b<0;Bd]08N7Q`1PH600:b/[07UiN@2n_[h0^k^k08j>SP1KFe/0>c/k03`l?00[:b/0
:2PX034a<@0g=cL0>3Ph06ATI03<c<`0b/[:0;Bd]01YJFT0QXJ6092@T02BTY80R8R808F5Q@2j^[X0
cLg=0=GEe@2GUiL0VYZJ061PH00F5QH04a<C0P0D51@02@0G5aL08B4Q0820P026QXH0=3@d03Ph>01B
DU80E5AD034a<@0200h>3P1=010@400>3Ph03`l?00h>3P0?3`l04Q8B01/K6`0k>c/0XZ:R05YJFP17
AdL0Bd];08:2PP2_[jl0PH6103/k>`0V9RH08b<S09FEU@2k^k/0KFe]03lo?`16ATH0/[:b07]kN`0I
6AT03@d=00h>3P0C4a<0Ng]k0=GEe@2_[jl0QXJ607moO`1kNg/0WinO09RHV02OWil0V9RH06ATI01I
FET0DE5A04M7A`0c<c<0;Rh^03De=@11@D40DE5A01hN7P0E5AD09BDU0:RXZ00m?Cd05aLG05mOG`27
QhL0=3@d01/K6`0E5AD05aLG01DE5@0I6AT061PH05]KF`2l_;`0c/k>07EeM@2h^;P0ZJVY0<g=c@3L
g=`0GEeM04e=C@1LG5`0?clo020P800N7Qh00P0K6a/09P0O7al09BDU02XZ:P0];Bd0VIVI06MWI`0P
820092@T034a<@1WIfL0`/;20451@@1`L700WYjN09JFUP1:BTX0=3@d034a<@0f=SH0AdM707moO`2a
/K40VIVI0;jn_P3Ogml0eMGE0<k>cP2c/k<0dM7A0;>c/`3AdM40=3@d01lO7`0J6QX05ADE01@D500E
5AD05QHF0`0E5AD0301<C4`0_kno05UIF@0M7Ad0DU9B02XZ:P0i>CT0PX:20:n_[`29RHT0P82001<C
4`803Ph>01X03`l?01DE5@1mOGd0F5QH02HV9P0Y:BT051@D01<C4`0G5aL0<c<c06e]K@1aLG40<C4a
05UIF@2NWYh0Ti>C0451@@28R8P0V9RH01XJ6P0Y:BT0Ti>C02PX:00D51@0?Shn03`l?0<05ADE0100
51@D01LG5`0I6AT0De=C0=?Cd`2b/[80_[jn09:BTP25QHD0TI6A05]KF`1FEUH0WYjN03Lg=`0b<S80
EeMG0P0G5aL201DE5@1M01@D500E5AD0:RXZ04A4A00Q8B40;bl_09NGU`12@T806ATI01LG5`0F5QH0
8b<S09:BTP1:BTX071`L02l_;`1hN7P0YZJV02TY:@0I6AT0:BTY03@d=010@4006ATI03De=@2RXZ80
EUIF01DE5@0C4a<05ADE01dM7@0g=cL0EUIF06i^KP1_Kfl0BDU9059BDP23Ph<0DU9B0410@01SHf<0
]KFe09jNWP2VYZH0Fe]K055AD@1YJFT071`L02XZ:P1KFe/0SXj>0;jn_P2SXj<071`L01LG5`0N7Qh0
?clo07emO@2MWId0Vi^K0<K6aP2YZJT0/k>c0<K6aP2PX:00PX:206YZJP0/;2`05aLG01HF5P0I6AT0
7alO06e]K@1_Kfl0XZ:R0=3@d03MgMd0U9BD03dm?@1^KVh0MWIf09ZJVP27QhL0UYJF0;bl_02EUID0
W9bL0=gMg@1oOgl0AdM703Xj>P0n?Sh0Bd];00;ooooo0000;P31`L40M7Ad08R8R02g]kL0EUIF0:^[
Z`1PH600J6QX08B4Q02QXJ40BDU905iNGP1fMWH0GEeM07alO01YJFT0Hf=S05eMG@1=CDd0VIVI07Qh
N00e=CD0[Zj^07MgM`17AdL0QhN708V9R@1BDU80?3`l09RHV01CDe<0A4A4069RHP1:BTX0Hf=S06IV
IP0S8b<0D51@0:6QX@1@D500>CTi059BDP0];Bd0>SXj020P801PH60201LG5`2h055AD@1;Bd/0=CDe
051@D00[:b/06a/K05aLG015ADD0Bd];05EEE@0a<C4071`L06=SH`1GEeL0<C4a05UIF@17AdL0BDU9
03Ti>@1_Kfl0FUYJ04E5A@1hN7P0GemO04A4A00R8R80G5aL06i^KP1@D500>c/k05MGE`0o?cl0=CDe
069RHP19BDT0@d=305aLG00f=SH0UYJF0:FUY@1DE5@0@d=306=SH`1[Jf/0<c<c0451@@2][Jd0?clo
04I6AP1TI6@0TY:B06YZJP0^;Rh0=cLg05UIF@1kNg/0>3Ph04M7A`3:b/X0N7Qh03Lg=`1PH600?Cdm
05IFEP1lO7`0Fe]K07IfMP0b<S80L71`04];B`0/;2`0DU9B06UYJ@0f=SH0DE5A06ATI01BDU80HV9R
03Ti>@0c<c<0PH61061PH01TI6@0Lg=c059BDP1EEED0GUiN07QhN017AdL0OWin06YZJP1HF5P0U9BD
071`L01WIfL0>3Ph071`L01gMgL0CDe=069RHP24Q8@0GUiN0820P02SXj<0?Cdm06ATI02PX:00<S8b
03Ti>@1GEeL0>SXj05=CD`1MGEd0Bd];06][J`2KVi/0JVYZ07moO`1IFET0QXJ602`/;01ZJVX0BTY:
04];B`2DU9@0J6QX03Hf=P2OWil0SXj>09:BTP27QhL0JVYZ06IVIP2DU9@0^k^k0861P@0[:b/0EeMG
0:ZZZP1`L700GEeM0;Zj^P2a/K40PX:2059BDP2=SHd0ZZZZ05YJFP0c<c<0];Bd0::RXP20P800^k^k
0::RXP1@D500MGEe05YJFP1QHF40AdM705QHF00[:b/07AdM08:2PP1:BTX0RHV907YjNP10@400Z:RX
0:FUY@1EEED0>CTi09FEU@0l?3`07alO06][J`1PH600GUiN08V9R@1?Cdl0LW9b059BDP0[:b/0EeMG
04A4A080EeMG01D0Hf=S06EUI@27QhL09bLW06i^KP2o_kl0I6AT02/[:`1YJFT0DE5A03<c<`2DU9@0
Z:RX07EeM@0h>3P0P82005mOG`0B4Q80@d=309FEU@25QHD00P1KFe/0@@1XJ6P0>SXj02@T901[Jf/0
JFUY030`<00R8R80IFEU06QXJ00g=cL0B4Q803<c<`0V9RH0Ng]k06e]K@0Q8B40K6a/09bLW02`/;00
Cdm?01dM7@16ATH0Hf=S01@D500L71`0PH6109FEU@1SHf<0Cdm?07=cL`2f][H0IFEU03De=@1QHF40
G5aL06=SH`13@d<0LW9b03Ti>@0/;2`0IFEU02d];@0J6QX0?Shn04a<C00N7Qh0G5aL06][J`1=CDd0
C4a<06a/K01GEeL0:BTY02l_;`1?Cdl0NWYj05mOG`0m?Cd0>CTi09NGU`1KFe/0<c<c0;:b/P2l_;`0
[Jf]0080AdM702D0BTY:03@d=00U9BD08B4Q01`L700M7Ad0<30`04m?C`2HV9P0QhN70;6a/@3Kfm/0
f=SH0;jn_P2BTY80QXJ605aLG00i>CT0CTi>06UYJ@2b/[80L71`09JFUP1KFe/06QXJ01<C4`0E5AD0
6ATI01LG5`1]KFd0Cdm?01TI6@0W9bL0?clo05QHF01:BTX04Q8B00803Ph>02L0410@00h>3P0>3Ph0
3Ph>010@400G5aL09BDU08B4Q02`/;00Cdm?065QH@2QXJ40U9BD08F5Q@18B4P09bLW01hN7P1DE5@0
`<300<C4a02PX:00^k^k09fMW@29RHT0TI6A07EeM@1dM7@0Shn?0<g=c@3Kfm/0clo?0:ZZZP2TY:@0
^;Rh0=SHf037alL0IVIV05iNGP1^KVh00P1MGEd08@1KFe/0>c/k01XJ6P0D51@08b<S03Ph>00e=CD0
6ATI01HF5P1[Jf/0T92@014A4@0B4Q80>3Ph09ZJVP1LG5`0<C4a03Lg=`19BDT0F5QH06EUI@2[Zj/0
cLg=0=7Ad@2;Rh/0dM7A0:ZZZP3Ph>00i^KV0=kNgP2ZZZX0G5aL02l_;`0201lO7`0Q020P800V9RH0
?3`l04];B`0j>SX0JVYZ09VIV@0e=CD0;Rh^02TY:@13@d<0P8200<?3``1FEUH0BTY:065QH@1hN7P0
7AdM01PH600D51@04a<C01DE5@0J6QX0BTY:0<K6aP3Kfm/0Y:BT0861P@2ATI40d=3@0=7Ad@2_[jl0
Kfm_00808B4Q00D06ATI01DE5@0D51@05QHF01@D500201DE5@0Z01LG5`0_;bl0TI6A038b<P0I6AT0
BDU901XJ6P0V9RH0O7al09JFUP27QhL0R8R806QXJ00C4a<03Ph>01DE5@1FEUH0HV9R02/[:`0Y:BT0
4a<C01TI6@0i>CT0ATI604A4A00e=CD0=SHf03Lg=`1iNGT0Ng]k09fMW@12@T80MgMg0;Zj^P2CTi<0
a<C406ATI00G5aL04Q8B03@d=01ZJVX08B4Q0P0E5AD04@0D51@05ADE01TI6@12@T80UIFE09VIV@0_
;bl0>3Ph07=cL`0_;bl071`L04=3@`1=CDd061PH01lO7`1?Cdl0B4Q800<05ADE01/04a<C01DE5@10
@400<C4a01hN7P0k>c/0^k^k02d];@0I6AT05aLG01DE5@0F5QH0ADE50<C4a01/K6`0DU9B03/k>`1[
Jf/0;Rh^024Q8@0U9BD08b<S02LW9`0a<C40<c<c08j>SP1jNWX00P0E5AD09P0M7Ad0=cLg05YJFP2A
TI40@41001DE5@0S8b<0DE5A05]KF`26QXH0QHF50:VYZ@2SXj<0OGem051@D00l?3`0F5QH06IVIP0O
7al071`L02TY:@0m?Cd0PX:20=;BdP2DU9@0PH6108Z:RP2YZJT0KFe]07inOP2d];@0WIfM09bLW02=
SHd0=cLg01TI6@0W9bL0<c<c0P0G5aL0600J6QX092@T04i>CP1`L700B4Q803<c<`1:BTX0a<C40;Fe
]@11@D40IfMW09BDU02SXj<0Rh^;061PH02n_[h0eMGE09>CT`2d];@0bl_;0:^[Z`1`L700K6a/07mo
O`;ooooo0000G02n_[h0LW9b051@D02ATI40De=C0:n_[`21PH40I6AT07]kN`2LW9`0Bd];06UYJ@2L
W9`0MWIf08f=S@1RHV80GEeM09nOW`1IFET0DE5A05aLG00b<S80Vi^K04I6AP0U9BD0Kfm_08N7Q`1C
De<0FEUI09ZJVP15ADD0Bd];04M7A`0k>c/0R8R806MWI`0O7al0CDe=08V9R@0[:b/0De=C07IfMP13
@d<0;bl_01lO7`1RHV80;Bd]01lO7`1@D500>CTi04i>CP1eMGD0@T9202PX:01DE5@0?clo04Y:BP1/
K6`0G5aL02LW9`21PH40Fe]K02l_;`1PH600BTY:04E5A@0l?3`0E5AD03hn?P1>CTh0Zj^[069RHP11
@D40<C4a04A4A01KFe/0BDU903`l?01`L700BTY:02TY:@0l?3`0CTi>05]KF`1]KFd0:2PX05=CD`21
PH40?Shn071`L02][Jd0VYZJ0P1<C4`0;@2m_Kd07alO030`<00h>3P0R8R805]KF`0^;Rh0?Shn05IF
EP1IFET0@d=301lO7`1cLg<0LG5a02XZ:P1MGEd0?Shn071`L01_Kfl0GemO05=CD`0[:b/0QhN705IF
EP0g=cL0GEeM05UIF@1<C4`0SXj>08V9R@1;Bd/0FEUI0451@@1XJ6P0/K6a065QH@1VIVH0D51@04M7
A`2?Shl0ZJVY08:2PP13@d<0MGEe0451@@0207alO00n071`L01SHf<0>c/k08F5Q@1eMGD0De=C06=S
H`1;Bd/0A4A40:>SX`2BTY80>CTi061PH02=SHd0=SHf075aL@1_Kfl0<S8b059BDP0h>3P09BDU03De
=@1iNGT0EEEE06][J`15ADD0=SHf02HV9P2=SHd0IVIV04Q8B024Q8@0Bd];04e=C@33`l<0UIFE0861
P@28R8P0H61P02h^;P1eMGD0ZJVY07alO010@400Jf][0:JVYP1FEUH0ADE50<[:bP2d];@0MWIf05=C
D`2<S8`0Shn?04E5A@0T92@0Q8B409NGU`1JFUX0^;Rh07IfMP0m?Cd20;Jf]P1k069RHP18B4P0E5AD
02DU9@0d=3@0Xj>S06][J`2CTi<0MWIf03hn?P1BDU80JVYZ0451@@0_;bl0S8b<02/[:`1DE5@0/;2`
061PH01LG5`0UYJF04m?C`1mOGd0CDe=03Ph>023Ph<0Ti>C08Z:RP1TI6@0QXJ607EeM@2MWId0>c/k
04Q8B01gMgL0GUiN034a<@1]KFd0EeMG01`L701;Bd/0Q8B407UiN@0i>CT0Q8B407QhN00o?cl0;2`/
06][J`1bLW80FEUI05EEE@1NGUh0Cdm?01HF5P1;Bd/0PX:205QHF00m?Cd0Hf=S03Xj>P0H61P0MgMg
04i>CP0c<c<0RXZ:071`L01@D500@D5106a/K02KVi/0C4a<024Q8@1ADE40L71`04A4A00G5aL0Kfm_
09RHV01IFET0A4A407QhN02KVi/0820P01LG5`1kNg/0SHf=06QXJ00e=CD0R8R805=CD`0i>CT0Kfm_
03Xj>P0f=SH0JVYZ06e]K@0U9BD0G5aL05iNGP18B4P0I6AT0:2PX023Ph<0Hf=S02XZ:P15ADD0LG5a
03De=@0g=cL0AdM70;Jf]P2:RXX0I6AT06UYJ@2KVi/0YZJV06][J`1EEED0C4a<05eMG@1JFUX0H61P
0080I6AT01@0JFUY07inOP1OGel0KFe]09jNWP2g]kL0fMWI08F5Q@0/;2`05aLG01DE5@0C4a<0?Cdm
02/[:`0m?Cd0YjNW079bLP1`L700RHV903Hf=P805ADE00/08b<S06e]K@0k>c/08R8R01XJ6P10@400
EEEE05mOG`0Q8B404A4A010@400201@D50804A4A02H05aLG01lO7`0W9bL0N7Qh05EEE@2?Shl0b/[:
0<71`@2k^k/0Xj>S07]kN`1FEUH0>CTi03/k>`38b<P0e]KF0<;2`P1MGEd0<30`028R8P0^;Rh0;Bd]
034a<@0d=3@0=cLg04Q8B01^KVh0Ph>3079bLP29RHT0_;bl09NGU`1bLW80I6AT03De=@0h>3P0=CDe
01XJ6P80410@00T05ADE01XJ6P0Y:BT0<30`03hn?P0I6AT0;2`/09nOW`0Y:BT00P0@4100601GEeL0
emOG0;no_`2TY:@0NWYj06a/K01fMWH0WinO0:b/[01cLg<0PH610=GEe@3Ph>00g=cL0>;RhP2a/K40
c/k>0<c<c02UYJD0Ogmo05aLG028R8P0V9RH09VIV@80Rh^;00l0`l?305]KF`19BDT0@4100492@P1E
EED0O7al08^;R`1QHF40>3Ph02XZ:P1HF5P0;Bd]01dM7@0J6QX00P0C4a<03`0G5aL0I6AT07UiN@3C
dm<0eMGE0<_;b`34a<@0f][J0;^k^`26QXH0VYZJ02l_;`0R8R80820P028R8P0301DE5@0801PH600E
5AD06ATI02LW9`1hN7P09RHV01`L700n?Sh201LG5`0:07MgM`1iNGT0Y:BT05iNGP2FUYH0CTi>01<C
4`1@D500Ogmo038b<P807alO01H0>c/k04Q8B00];Bd0820P01`L700K6a/08B4Q03@d=02BTY80EUIF
0<G5a@2RXZ80^[Zj0;6a/@1<C4`0H61P0:2PX02@T900KVi^07YjNP2h^;P0B4Q80P0E5AD03@0C4a<0
5ADE02@T901_Kfl0Shn?065QH@0T92@0KVi^03Xj>P0F5QH06QXJ04m?C`0V9RH00P0E5AD00`0O7al0
Hf=S055AD@0201DE5@0?01<C4`0P8200DU9B03@d=00j>SX0L71`0=3@d00Z:RX06ATI01HF5P0E5AD0
5QHF01dM7@2HV9P0820P00805ADE0100B4Q803@d=00P8200A4A403@d=00`<300B4Q805=CD`2_[jl0
TI6A01dM7@0Z:RX0>c/k051@D024Q8@0>c/k0P0E5AD01`0H61P0>3Ph0;Ng]`2=SHd0JFUY09JFUP1g
MgL00P2@T9003022PX80N7Qh08Z:RP0h>3P0=3@d03Ph>011@D40EUIF0<O7a`3Kfm/0b/[:09BDU080
L71`00H0UIFE0;Vi^@2m_Kd0_;bl06][J`0I6AT201`L700K02PX:00Y:BT07QhN02DU9@0m?Cd0DE5A
09BDU01:BTX0<S8b03Ti>@2:RXX0alO708Z:RP1LG5`0LW9b09^KV`2?Shl0ATI608Z:RP2EUID0:2PX
02l_;`19BDT0RHV90:6QX@2^[Zh0a<C400;ooooo0000@@38b<P0Q8B4059BDP1gMgL0H61P0;Ng]`24
Q8@0L71`0861P@1YJFT0Cdm?08b<S02PX:00HV9R07moO`0T92@0MGEe09bLW01UIFD0FUYJ06=SH`0i
>CT0YZJV08j>SP0];Bd0FEUI01PH600];Bd0B4Q808n?S`0i>CT0@T920410@00Z:RX0DE5A07=cL`0Q
8B40B4Q808b<S011@D40<c<c05EEE@0_;bl0:b/[01lO7`1MGEd0<C4a01lO7`1BDU805ADE02DU9@1G
EeL0GUiN02h^;P1;Bd/0?clo0820P02CTi<0IVIV02@T901gMgL0ADE504Q8B02LW9`0KFe]0080@D51
06l0EeMG03Xj>P0^;Rh0JFUY065QH@1ADE40:BTY05EEE@1bLW803Ph>03Hf=P25QHD0IFEU03/k>`17
AdL05ADE03/k>`1YJFT0ATI606m_K`24Q8@0=3@d0410@01WIfL0JVYZ03dm?@1FEUH0Vi^K03<c<`12
@T80?clo08b<S01;Bd/08b<S04];B`1LG5`0Cdm?04a<C00a<C40UIFE051@D00d=3@0LW9b028R8P1[
Jf/0PX:205iNGP1=CDd05aLG06m_K`1IFET0>3Ph05YJFP0g=cL0:RXZ04Q8B01RHV80?clo065QH@0X
:2P0@4100861P@1=CDd0EeMG04=3@`0m?Cd0De=C04a<C01>CTh0?Cdm0820P01IFET0ADE5051@D028
R8P0IVIV01/K6`1_Kfl0N7Qh069RHP2GUiL0EEEE05aLG01]KFd0Lg=c034a<@2EUID0Rh^;02PX:01=
CDd0?clo03@d=01MGEd0FUYJ02l_;`0];Bd0J6QX04];B`1mOGd0EUIF061PH00N7Qh0IFEU04];B`0o
?cl0P82002XZ:P1>CTh0T92@08^;R`2DU9@00P1nOWh0W`1/K6`0MGEe09jNWP1`L700;bl_069RHP2g
]kL0A4A403@d=02UYJD0YZJV07alO01WIfL0];Bd0:NWY`1dM7@0<c<c08N7Q`1cLg<0D51@0<k>cP2P
X:00@D5105EEE@1ZJVX0BTY:05=CD`1GEeL071`L02LW9`1MGEd0BTY:0:VYZ@2=SHd0I6AT06][J`25
QHD0C4a<02d];@2=SHd092@T01lO7`1PH600CDe=05QHF02RXZ80E5AD08B4Q014A4@092@T04m?C`1=
CDd0Lg=c065QH@1kNg/0M7Ad0::RXP1LG5`0JFUY06e]K@1PH600<S8b06MWI`1^KVh0BTY:069RHP2O
Wil0P82004=3@`29RHT0Kfm_05=CD`0[:b/0PH6107moO`1EEED0N7Qh08f=S@29RHT0=3@d04=3@`1`
L700Bd];0410@01XJ6P0FEUI02LW9`1YJFT0=3@d03Ph>02BTY80LG5a06=SH`1:BTX0GUiN0820P01@
D500>SXj0861P@20P800;2`/01TI6@1GEeL0R8R805]KF`1WIfL0aLG50;Ng]`2<S8`06ATI07YjNP23
Ph<0:b/[03Lg=`2DU9@0Kfm_04];B`2ZZZX0@d=301hN7P1;Bd/0P82003lo?`1ADE40JFUY02h^;P13
@d<0SHf=09FEU@1SHf<0;bl_04M7A`26QXH0=SHf01DE5@0h>3P0P82007emO@1>CTh0[:b/0;Zj^P2/
[:`0KVi^04E5A@0e=CD0<C4a020P800N7Qh06a/K01TI6@0S8b<0:RXZ03Ph>01TI6@0EUIF03<c<`2K
Vi/0?3`l01HF5P0201DE5@0=010@400a<C40>3Ph01hN7P0m?Cd0Vi^K07YjNP1HF5P0Ti>C0861P@1:
BTX0Q8B4055AD@0203`l?008020P801:BTX0KVi^07emO@1<C4`07AdM01/K6`0I6AT201PH600U01DE
5@0O7al0?clo03dm?@0H61P04A4A01XJ6P1RHV80<c<c03Ti>@0];Bd06ATI02d];@1BDU80WinO0=KF
eP3IfMT0b/[:0;2`/02QXJ40PX:206a/K00l?3`07QhN01dM7@0O7al0;2`/04a<C02@T900Ph>306EU
I@2DU9@0b/[:06EUI@0d=3@0820P00l?3`0400h>3P17014A4@0D51@092@T03Hf=P0k>c/0@T9201LG
5`1=CDd0Ph>301HF5P0@4100E5AD0::RXP1iNGT0N7Qh08V9R@2HV9P0`<300<g=c@3?cll0b<S80<71
`@3MgMd0g=cL0<k>cP3Jf]X0g=cL0;6a/@2;Rh/0/;2`0=GEe@3Jf]X0QhN702TY:@0N7Qh07alO02TY
:@1nOWh0N7Qh06MWI`1ADE40=cLg03@d=011@D40IVIV05mOG`0e=CD07alO030`<00i>CT061PH01LG
5`0E5AD06a/K04I6AP1;Bd/0>c/k07IfMP0g=cL0KVi^03lo?`2EUID0LG5a07EeM@32`/80JVYZ02XZ
:P0W9bL0:RXZ020P800H61P00P0F5QH201PH600h02DU9@1QHF406QXJ02l_;`0k>c/061PH01/K6`1:
BTX0W9bL0:n_[`1cLg<0@d=30:NWY`1nOWh0XZ:R04=3@`10@400AdM703/k>`0Q8B4071`L01/K6`0G
5aL06ATI01LG5`0V9RH0NGUi0:JVYP1oOgl0I6AT02TY:@1IFET0KFe]06YZJP0F5QH07AdM02l_;`11
@D40E5AD07AdM02[Zj/0CDe=01DE5@0C4a<08b<S04E5A@1QHF40b/[:09nOW`1JFUX0MgMg01TI6@0J
6QX07AdM04a<C00G5aL201DE5@0401LG5`0T92@0FUYJ04a<C0805aLG00h0CTi>05iNGP1/K6`0JFUY
0;Ng]`3Ng]h0<30`01`L700J6QX061PH01DE5@0K6a/0PH6101LG5`805ADE04<0820P06m_K`0W9bL0
;Rh^04I6AP1BDU80OWin0;2`/03Ng]h0b/[:06a/K010@400C4a<08Z:RP1?Cdl05ADE01dM7@0X:2P0
DE5A06e]K@1IFET0/;2`0<;2`P2VYZH0SXj>07AdM01;Bd/0=CDe03`l?02OWil0TY:B0:>SX`2RXZ80
U9BD0:2PX02d];@0EEEE075aL@31`L40]KFe0<71`@3:b/X0c/k>0=SHf031`L40HV9R02<S8`0J6QX0
7AdM02d];@1:BTX0?clo03Hf=P0U9BD071`L055AD@1@D500=SHf02l_;`1ZJVX0][Jf08n?S`2f][H0
SXj>092@T02YZJT0B4Q80080Ogmo00L08R8R02LW9`0X:2P0;Bd]03Xj>P27QhL0^[Zj00;ooooo0000
o`2g]kL0LG5a05iNGP2LW9`0CDe=09BDU01]KFd0QHF50:FUY@1bLW80@D5106e]K@2=SHd0K6a/08R8
R014A4@0IfMW092@T01EEED0F5QH03De=@17AdL0UiNG07IfMP0_;bl0HV9R04i>CP0g=cL0?Cdm09JF
UP0c<c<0ATI605]KF`1CDe<0HV9R07AdM00Q8B40ADE509RHV01JFUX0ADE5059BDP0X:2P092@T03Ph
>01QHF40;2`/024Q8@1;Bd/0;2`/03Ph>00n?Sh0?Cdm02TY:@1:BTX071`L03De=@1QHF40F5QH02@T
901fMWH051@D02XZ:P1QHF40F5QH03hn?P1:BTX0I6AT05mOG`1;Bd/0Shn?06=SH`1EEED0:2PX04I6
AP1JFUX0?clo03/k>`1FEUH0EeMG0492@P1:BTX0@d=304Y:BP1WIfL0BTY:092@T01]KFd0@41004Q8
B01aLG40Lg=c03lo?`1CDe<0UIFE02h^;P15ADD0@d=309BDU00e=CD0;Bd]05iNGP1[Jf/0N7Qh05mO
G`1EEED0Z:RX03De=@0/;2`0RHV904E5A@1^KVh0CTi>06UYJ@1lO7`0>c/k07QhN00Z:RX0CTi>07Ui
N@1YJFT0@T920410@012@T809bLW07YjNP18B4P0?clo07MgM`0X:2P0GEeM05UIF@17AdL0De=C05UI
F@1;Bd/0;2`/071`L01KFe/0ATI605ADE01:BTX0Jf][034a<@1gMgL0EEEE03Xj>P1RHV80J6QX07mo
O`21PH40OWin02@T901YJFT0UiNG03`l?01DE5@0BDU902TY:@1LG5`0Kfm_03<c<`0g=cL0NWYj02/[
:`1ZJVX0UYJF092@T00[:b/0Jf][03Xj>P1PH600ZZZZ075aL@14A4@0QhN7065QH@25QHD0];Bd08j>
SP1_Kfl0HV9R0;Ng]`1OGel0>SXj08R8R038b<P0NWYj04Q8B027QhL0MgMg02@T900g=cL0M7Ad09BD
U029RHT0<S8b08n?S`1iNGT0?Cdm0:b/[02QXJ40DU9B06=SH`1YJFT071`L04i>CP25QHD0@D5101hN
7P1@D500?3`l0;Rh^02ZZZX0L71`07UiN@2CTi<09bLW03hn?P2:RXX0ADE502HV9P1VIVH0;Rh^05MG
E`2^[Zh0V9RH0:BTY01TI6@0<c<c05QHF01?Cdl0LW9b0451@@20P800XJ6Q09nOW`1FEUH0K6a/065Q
H@1HF5P0?Shn071`L01eMGD0D51@061PH02[Zj/0DE5A03Ti>@2LW9`0RXZ:06ATI00j>SX0V9RH08>3
P`00A@0V9RH0ATI607MgM`1dM7@0>3Ph055AD@2JVYX0<c<c02TY:@1dM7@0NGUi02XZ:P1gMgL09RHV
03Lg=`2PX:00VIVI06UYJ@1DE5@0I6AT06MWI`0T92@09RHV05MGE`1nOWh0Bd];024Q8@1LG5`0Lg=c
02XZ:P0b<S80JVYZ07MgM`0];Bd08R8R07]kN`1eMGD0@d=302PX:01eMGD0>3Ph02d];@1lO7`0C4a<
034a<@1CDe<0FUYJ02TY:@1^KVh0SXj>061PH01LG5`0Ng]k05iNGP1@D500=CDe05=CD`20P800C4a<
03Lg=`0j>SX0Ph>306][J`0l?3`0CTi>08J6QP24Q8@0=cLg02<S8`0201dM7@0601XJ6P0I6AT05QHF
01HF5P0I6AT071`L0P1FEUH0901aLG40AdM704=3@`1[Jf/05aLG01DE5@0C4a<0410@02TY:@12@T80
=3@d01LG5`19BDT0c<c<09jNWP1GEeL0M7Ad09nOW`35aLD0ADE504Q8B00n?Sh08R8R04M7A`2<S8`0
PX:209:BTP17AdL06a/K01DE5@0G5aL09BDU04A4A012@T805aLG00h>3P803@d=01d04a<C04i>CP0Y
:BT0>3Ph02<S8`0A4A4051@D02LW9`2o_kl0d];B0=KFeP3@d=00WinO08>3P`1EEED0F5QH06m_K`1U
IFD0BDU903Xj>P18B4P0@410071`L01MGEd0E5AD0;:b/P2[Zj/0?Cdm00l?3`0200h>3P<03@d=0`0>
3Ph0>@0D51@0<c<c03@d=00m?Cd0:2PX01hN7P2j^[X0IfMW06e]K@1ZJVX0:2PX01`L700K6a/071`L
01TI6@0T92@0OGem071`L02MWId0g=cL0>GUi@3IfMT0^;Rh0:VYZ@3MgMd0FEUI065QH@18B4P0EUIF
0:VYZ@2IVIT0;2`/02<S8`0f=SH0A4A405QHF02QXJ40=SHf01dM7@0J6QX061PH01TI6@1ADE40Cdm?
03Lg=`0U9BD071`L03dm?@0B4Q805QHF02l_;`0m?Cd0:2PX02`/;01ADE406a/K01LG5`0203Lg=`1G
02<S8`1[Jf/0U9BD0<S8b02NWYh0>c/k02d];@0h>3P07AdM01hN7P0K6a/05ADE01LG5`0E5AD0:b/[
07EeM@0I6AT0FEUI08Z:RP10@400>CTi05IFEP2l_;`0[Jf]0;no_`29RHT0[:b/0=3@d02YZJT0QXJ6
03Ti>@0K6a/05aLG01XJ6P0G5aL05QHF020P800i>CT0FUYJ07alO02m_Kd0`<3009JFUP0Z:RX08b<S
04=3@`1NGUh0QhN701`L700F5QH06ATI01`L700N7Qh08R8R07QhN02k^k/0FEUI034a<@1XJ6P0FEUI
0;Bd]027QhL0]KFe07EeM@17AdL06QXJ01/K6`0X:2P0CTi>01LG5`0E5AD05QHF01DE5@0G5aL07AdM
04U9B@21PH40R8R80<o?c`2b/[80/;2`0=7Ad@3Ogml0h^;R06][J`0X:2P092@T00805ADE00<08b<S
07emO@0I6AT00`0E5AD0<P0b<S80G5aL02PX:01PH600Fe]K0=CDe03Hf=P0e=CD0>?Sh`2b/[80J6QX
08^;R`1gMgL06ATI01dM7@13@d<0C4a<02LW9`0G5aL05ADE05=CD`2MWId0Vi^K05]KF`1>CTh0J6QX
03/k>`0n?Sh0HV9R01/K6`0Q8B40@T9208J6QP3@d=00U9BD04Y:BP2ATI40Kfm_04U9B@1LG5`0TY:B
0:ZZZP39bLT0XZ:R05MGE`1SHf<0=CDe02`/;014A4@0;2`/0P0I6AT05`0G5aL06a/K059BDP1JFUX0
A4A403Xj>P1BDU80/K6a0410@00j>SX0X:2P0;no_`34a<@0G5aL09JFUP2@T900?clo03Lg=`0d=3@0
A4A407QhN02CTi<0f=SH00;ooooo00006`32`/80E5AD069RHP2;Rh/0D51@09fMW@17AdL0G5aL06m_
K`22PX80DU9B09^KV`29RHT0BDU908n?S`1@D500Ti>C08:2PP1XJ6P0QhN703lo?`16ATH0P82006EU
I@1>CTh0QXJ608R8R00203/k>`0c06QXJ00Y:BT0LG5a06e]K@1>CTh0I6AT0451@@0[:b/0KFe]08f=
S@1ADE40ATI604];B`0K6a/0<c<c03De=@12@T807AdM03Ph>01NGUh0;bl_0451@@1;Bd/0:b/[03<c
<`1OGel0?Cdm04M7A`19BDT0;bl_03Ti>@21PH40@D5103@d=01JFUX0?Cdm04e=C@1mOGd0TI6A05mO
G`13@d<0TY:B059BDP11@D409RHV04m?C`1DE5@0Bd];05UIF@1ZJVX0BDU90080FEUI03h0AdM705AD
E01GEeL0>SXj09RHV02CTi<0C4a<055AD@1jNWX0KVi^02<S8`1KFe/0Vi^K03lo?`16ATH0ADE5092@
T01DE5@09RHV04I6AP1DE5@0CTi>02PX:01SHf<0Lg=c05=CD`0b<S80R8R8055AD@1hN7P0J6QX06][
J`1VIVH0?3`l0861P@1@D500=SHf069RHP1kNg/0?Shn0492@P1@D500@d=308^;R`17AdL0DU9B08:2
PP1@D500I6AT04E5A@18B4P0RHV909:BTP1jNWX0B4Q808B4Q01MGEd0KVi^07inOP1XJ6P0N7Qh04A4
A080RHV90=h0E5AD05eMG@1KFe/0M7Ad0:n_[`22PX80;Bd]07]kN`2CTi<0@41007UiN@1lO7`0@410
05ADE01CDe<0EEEE0861P@2GUiL0IfMW07inOP1QHF40MgMg02d];@1ZJVX0AdM703@d=027QhL0K6a/
04E5A@22PX80IFEU05ADE01bLW80FUYJ03lo?`1FEUH0[jn_03hn?P0^;Rh0G5aL0;Ng]`1SHf<0?Shn
07AdM027QhL0D51@04Y:BP2@T900Vi^K06YZJP0m?Cd0^k^k092@T019BDT0/;2`075aL@1GEeL0^;Rh
0:f][@0n?Sh0>SXj061PH00l?3`07AdM04I6AP0Y:BT0WIfM0:FUY@1UIFD0MgMg08V9R@0N7Qh0;2`/
07inOP12@T808b<S061PH00M7Ad0>SXj06EUI@1VIVH0PH61079bLP11@D40Cdm?059BDP1dM7@04a<C
03Lg=`1OGel0YJFU06i^KP20P800ZJVY03Ti>@0a<C40MGEe05]KF`0h>3P0S8b<0;jn_P1@D5009RHV
09BDU01PH600:BTY02XZ:P1mOGd0Ogmo055AD@1>CTh0LG5a0451@@0J6QX0JVYZ092@T01=CDd09bLW
051@D01GEeL0=3@d09jNWP19BDT0<C4a08^;R`1eMGD0>c/k092@T02a/K40XJ6Q04I6AP0S8b<0De=C
05YJFP0Y:BT0:b/[05mOG`2<S8`0CTi>03Ti>@1aLG40YjNW06=SH`0J6QX0JFUY07emO@1EEED0;2`/
06a/K01VIVH0=cLg06e]K@0X:2P08R8R059BDP1@D500;2`/03dm?@1ZJVX0FEUI07alO02DU9@0MgMg
0410@01nOWh0^;Rh09jNWP16ATH0=CDe04=3@`25QHD0CTi>01/K6`1=CDd0VYZJ0;Jf]P19BDT0;Bd]
01lO7`0M7Ad071`L01XJ6P0G5aL06ATI03hn?P0b<S80TI6A08Z:RP2LW9`0Bd];02l_;`1^KVh07alO
01DE5@0D51@04a<C03`l?02<S8`0K6a/02l_;`0l?3`0ZZZZ07]kN`2EUID0VYZJ07MgM`2:RXX0QXJ6
05IFEP1GEeL0Kfm_09:BTP2c/k<0`L710:VYZ@2HV9P0BDU905IFEP1XJ6P0CDe=01TI6@0@410300d=
3@0I01<C4`0o?cl0K6a/04=3@`1TI6@0IfMW05UIF@1_Kfl0UiNG0<o?c`2`/;00^k^k09bLW00];Bd0
;Rh^03/k>`1JFUX0Ogmo079bLP1kNg/0QHF508^;R`21PH40YJFU0;Zj^P020<K6aP0305mOG`0n?Sh0
4a<C00L03@d=00h0410@01<C4`0I6AT0<S8b02/[:`10@4007QhN09jNWP3Ng]h0Ng]k02HV9P0E5AD0
6ATI01PH60805ADE01d0ATI6071`L00K6a/07alO0:6QX@3>c/h0WYjN05YJFP1HF5P0e=CD09fMW@1:
BTX0@T9204Q8B017AdL0N7Qh09NGU`1]KFd0QhN701@D500];Bd0SHf=02HV9P0I6AT05ADE01TI6@0U
9BD0F5QH08j>SP0203<c<`11020P800X:2P0GEeM03dm?@0Y:BT06a/K02/[:`1@D500<30`014A4@0E
5AD06ATI03hn?P0G5aL0GUiN0;Rh^023Ph<0^[Zj06QXJ00o?cl09RHV02LW9`0M7Ad06ATI01DE5@0G
5aL06a/K02/[:`1RHV80820P079bLP1cLg<0P8200:2PX02c/k<0eMGE0<c<c02h^;P0_Kfm0<;2`P2_
[jl0[Jf]03/k>`0F5QH05aLG01`L700b<S80De=C071`L01ZJVX0De=C05EEE@1MGEd0EeMG07UiN@1[
Jf/0820P01hN7P0b<S80Fe]K0:2PX00a<C406a/K01LG5`0E5AD00P0H61P0=@0d=3@0YJFU0<G5a@26
QXH0@4100:BTY01?Cdl0<C4a08>3P`2LW9`0BTY:01LG5`0Q8B40LG5a06i^KP0R8R807alO02<S8`0[
:b/0<c<c0492@P1QHF40Y:BT0<O7a`39bLT0/;2`08b<S01jNWX0HV9R0<[:bP2LW9`0;bl_02HV9P0I
6AT05ADE02TY:@20P80061PH01DE5@0D51@04a<C01dM7@1KFe/0K6a/07alO02WYjL0clo?0:RXZ03R
h^80g]kN0=OGe`33`l<0eMGE0080;2`/00`0E5AD02TY:@0E5AD04a<C01DE5@0F5QH0De=C08f=S@24
Q8@0@d=305eMG@2WYjL206EUI@0F07=cL`0_;bl06a/K02<S8`0a<C40YJFU0;Bd]02CTi<0N7Qh05iN
GP0C4a<0=3@d075aL@12@T80Shn?0:VYZ@11@D40KVi^09VIV@1[Jf/0;2`/024Q8@<071`L01H08R8R
05EEE@1GEeL0ATI603Hf=P0_;bl0Ti>C03@d=00Q8B40<S8b08j>SP3Jf]X0e=CD0;Zj^P2/[:`0T92@
0:2PX02`/;00`<300;bl_02_[jl0Vi^K0_ooool0002c0<c<c01gMgL0Fe]K06ATI01HF5P0^;Rh0820
P01`L700MgMg03Xj>P12@T80RXZ:09BDU01CDe<0Kfm_03Xj>P2;Rh/0Ogmo04=3@`1TI6@0@D5105YJ
FP21PH40@T9202h^;P1GEeL0>CTi0451@@1UIFD0OGem02<S8`1ADE40@D5103dm?@2CTi<0IFEU02DU
9@1;Bd/0IVIV03/k>`1gMgL0PH6103Ti>@0W9bL0<c<c04i>CP0Q8B4071`L04a<C00T92@0DU9B08F5
Q@1=CDd0?Cdm05aLG014A4@0IfMW069RHP0o?cl0:RXZ07alO01:BTX0<30`069RHP0o?cl0;2`/04Q8
B01LG5`0EeMG03hn?P2HV9P0BTY:02PX:00R8R80A4A405iNGP11@D40G5aL06=SH`0];Bd0:b/[05AD
E00l?3`0L71`04m?C`0`<300KFe]08F5Q@0n?Sh0NGUi0:6QX@1mOGd0?3`l051@D02<S8`0:BTY05]K
F`1]KFd0R8R805iNGP0T92@0EEEE059BDP1JFUX0@d=304i>CP1gMgL0F5QH03@d=01mOGd0:RXZ06YZ
JP1KFe/0I6AT0492@P1YJFT0VIVI05ADE00n?Sh0Jf][05EEE@1@D500MWIf05aLG013@d<0NGUi03@d
=01IFET0M7Ad0410@01lO7`0ADE503Ti>@1ADE40GemO05iNGP0h>3P0Kfm_03<c<`1HF5P0CTi>06a/
K01MGEd0:b/[06a/K01fMWH0D51@05mOG`0/;2`0Cdm?08J6QP1UIFD0<c<c07QhN01OGel0=CDe07Yj
NP1KFe/0>c/k04e=C@0];Bd0=CDe04Q8B01WIfL0@d=308R8R01CDe<0@D5102l_;`25QHD0DU9B03`l
?027QhL0G5aL07AdM02IVIT0Ph>308J6QP2JVYX00P1:BTX0Y`1PH600/K6a0861P@10@400LW9b0<?3
``14A4@0@d=30:j^[P2UYJD0JVYZ03Xj>P1nOWh0T92@061PH00c<c<0_kno08N7Q`1?Cdl0^[Zj0820
P014A4@0FEUI071`L011@D40B4Q8061PH00^;Rh0FUYJ08:2PP0m?Cd0OWin08N7Q`1YJFT0UiNG09RH
V01ADE40:RXZ07]kN`0[:b/0C4a<07emO@13@d<0FUYJ07MgM`1ADE40Ng]k0410@00/;2`0MgMg08:2
PP1kNg/0DU9B071`L01VIVH0SXj>02`/;016ATH0HF5Q04e=C@0b<S80H61P0410@00Y:BT0H61P09NG
U`1WIfL0;bl_0:n_[`1bLW80DE5A03<c<`2?Shl0QHF505IFEP1<C4`0E5AD06a/K00];Bd0G5aL07in
OP16ATH0@d=306=SH`0h>3P06ATI06YZJP0`<300;Bd]07UiN@1bLW80D51@04e=C@1LG5`0MgMg0492
@P0R8R80E5AD06YZJP0d=3@06QXJ04a<C02@T900D51@03Ph>01dM7@0ZJVY06m_K`0T92@0RHV90820
P01ZJVX0<S8b06=SH`1XJ6P0>CTi065QH@0l?3`0<c<c05ADE01EEED0<C4a051@D01HF5P0AdM708N7
Q`2BTY80QXJ603Xj>P0];Bd0Bd];07IfMP1;Bd/0<c<c03/k>`1`L700HF5Q03`l?01_Kfl0dM7A0<o?
c`2QXJ40IfMW05UIF@0f=SH08R8R01dM7@0S8b<0C4a<07]kN`2[Zj/0dm?C0<k>cP3@d=00IFEU04=3
@`1CDe<0JVYZ03Lg=`0n?Sh0D51@04e=C@2KVi/0W9bL07AdM02TY:@0C4a<00805ADE03@0ADE509NG
U`3@d=00aLG50:n_[`1VIVH0CTi>04Q8B01iNGT0R8R80;Jf]P3AdM40][Jf05IFEP0E5AD030`<014A
4@0E5AD03Ph>00d=3@0B4Q806ATI05]KF`2QXJ40XZ:R09JFUP1lO7`0@D5103Hf=P1mOGd0Xj>S04i>
CP0g=cL0MGEe01PH600:2PX03@d=00l?3`0V9RH08B4Q02XZ:P0k>c/0EUIF06QXJ02g]kL0[jn_03`l
?00T92@0FEUI02`/;00a<C403Ph>0`0=3@d300h>3P0g014A4@0C4a<061PH02PX:00m?Cd0<C4a03Lg
=`2j^[X0]kNg02h^;P0G5aL06ATI01/K6`0E5AD05QHF03Ti>@2YZJT0>3Ph02<S8`0X:2P0UiNG05mO
G`2BTY80?Cdm03@d=02WYjL0;2`/06=SH`1<C4`08B4Q030`<01TI6@0WinO0;>c/`28R8P0;2`/03@d
=02IVIT0:RXZ02`/;01SHf<0M7Ad07=cL`2QXJ40Vi^K08:2PP18B4P0<S8b03@d=011@D405QHF01TI
6@0T92@0@d=304M7A`0301<C4`0e01DE5@0W9bL0>SXj04M7A`1eMGD0?3`l07AdM03Bd]80WIfM0492
@P0g=cL0:BTY02/[:`0L71`07AdM020P801=CDd0DE5A0451@@0g=cL0<C4a03Ti>@0o?cl0AdM706][
J`3AdM40b/[:0:ZZZP2d];@0UiNG09FEU@2TY:@0Fe]K0820P01mOGd0MGEe05eMG@1DE5@0BTY:03Ti
>@0P820071`L01dM7@1SHf<0TI6A01lO7`0N7Qh08B4Q059BDP27QhL0Ogmo01/K6`0L71`00`0E5AD0
0`0K6a/0B4Q80=7Ad@020<71`@0e0820P00O7al0F5QH08F5Q@30`<00O7al06][J`2YZJT0inOW0=kN
gP2n_[h0/K6a0;Bd]02PX:00T92@08V9R@22PX80IVIV04];B`1dM7@0YjNW09FEU@1MGEd08R8R06=S
H`2d];@0HV9R02LW9`0L71`07AdM03Ti>@1hN7P05ADE01/K6`0C4a<05ADE030`<023Ph<0Zj^[07Qh
N02LW9`0^k^k0=CDe02RXZ80TY:B0:VYZ@3Rh^80g]kN05QHF01VIVH07alO01DE5@0G5aL00P0E5AD0
8P0G5aL0De=C06i^KP1TI6@0AdM707]kN`1HF5P0<c<c04I6AP2GUiL0?Cdm04=3@`1JFUX0PH6108Z:
RP2_[jl0Y:BT0:JVYP2TY:@0SHf=09RHV01hN7P0?clo07inOP39bLT0IFEU05=CD`1LG5`0KFe]04M7
A`0Q8B406QXJ01LG5`0M7Ad204A4A00D05IFEP0n?Sh0;Rh^02PX:01bLW80HF5Q02@T900];Bd0FUYJ
0;Fe]@1PH600HF5Q06ATI00J6QX07QhN055AD@2g]kL0EeMG0492@P19BDT2ooooo`0005H0VIVI05]K
F`1JFUX0JVYZ04I6AP2@T900LW9b069RHP1mOGd0Lg=c0410@01dM7@0V9RH05IFEP1iNGT0=cLg07=c
L`20P800ATI604E5A@0N7Qh0Fe]K08F5Q@1TI6@0@41005UIF@0X:2P08b<S03Lg=`1WIfL0820P04Y:
BP0g=cL0<c<c071`L01UIFD09bLW05=CD`1FEUH0<30`03lo?`1ADE40=SHf024Q8@0k>c/0F5QH02TY
:@0N7Qh0C4a<02TY:@0W9bL0?Shn04a<C00c<c<0A4A402d];@1WIfL0KFe]059BDP0d=3@0R8R8034a
<@1YJFT0U9BD06QXJ00k>c/0Cdm?04e=C@0j>SX0GEeM0;jn_P1WIfL0F5QH028R8P1HF5P0BTY:030`
<01gMgL0R8R8055AD@0i>CT0B4Q802PX:01^KVh0G5aL05IFEP80Ng]k03X0;bl_06UYJ@1nOWh0Ng]k
03Hf=P1;Bd/0SXj>01hN7P0k>c/0?3`l096AT@1GEeL07AdM05YJFP1FEUH0CDe=04Q8B01BDU80HV9R
03dm?@0i>CT0RHV902h^;P1[Jf/0DU9B061PH00e=CD0>CTi07moO`18B4P0@41005MGE`1NGUh0BDU9
04Y:BP1HF5P0=cLg07IfMP0l?3`0EUIF079bLP1:BTX0I6AT04E5A@1:BTX0H61P06=SH`1GEeL0?Shn
06e]K@1?Cdl0MgMg0492@P1]KFd0GUiN02l_;`1bLW80LG5a0P1DE5@0>P0o?cl0Ng]k08R8R01ADE40
:RXZ06i^KP1FEUH0=cLg08f=S@1=CDd0?Cdm04I6AP0i>CT0?clo04a<C01JFUX0@d=308F5Q@1;Bd/0
FEUI01lO7`1hN7P0<S8b03<c<`1]KFd0?clo059BDP1ZJVX0L71`08N7Q`1lO7`0?clo03Ph>01TI6@0
YjNW08V9R@0d=3@0IVIV0<;2`P1CDe<0@41005eMG@2@T900I6AT03Xj>P1lO7`0RHV907YjNP12@T80
YjNW08R8R01;Bd/0][Jf09^KV`1CDe<0NGUi09bLW016ATH204A4A00?01DE5@0_;bl0Jf][03Ph>01f
MWH0IVIV03lo?`1fMWH0IFEU0410@00W9bL0O7al028R8P0/;2`0J6QX0080BDU903d0IfMW05=CD`1i
NGT0DE5A02l_;`1;Bd/0ATI608J6QP1LG5`0Q8B4065QH@21PH40?Cdm075aL@1QHF40DE5A02l_;`1D
E5@0Cdm?04A4A02CTi<0^;Rh07alO013@d<0`<3006UYJ@1GEeL0=cLg08:2PP27QhL0G5aL04a<C01N
GUh0JFUY02HV9P1OGel0R8R806ATI01>CTh0J6QX04Q8B00Z:RX0OWin03Ph>00V9RH0Ng]k0820P01P
H600IFEU06e]K@1gMgL0@T9201/K6`1GEeL0Hf=S028R8P0O7al0C4a<09:BTP1SHf<0Fe]K0080/K6a
0500L71`034a<@2HV9P0IfMW05QHF00^;Rh0KFe]07MgM`0m?Cd0HF5Q04m?C`0k>c/0L71`06i^KP0_
;bl0D51@04E5A@0c<c<0PX:20<30`01YJFT0De=C03lo?`1IFET0S8b<04M7A`0i>CT0?Cdm06=SH`1o
Ogl0CDe=0;Fe]@3>c/h0b/[:0:>SX`1aLG40H61P05iNGP1KFe/0FUYJ05iNGP1>CTh0JVYZ0;^k^`3A
dM40Shn?0;Zj^P38b<P0/[:b0:NWY`3:b/X0NGUi059BDP16ATH0>CTi03<c<`1EEED0YjNW0<g=c@1J
FUX0>3Ph02l_;`0L71`07AdM08Z:RP39bLT0RHV907=cL`1EEED0IFEU092@T02YZJT0WIfM0=OGe`2?
Shl0AdM704A4A00f=SH0:b/[01HF5P803Ph>01405ADE02/[:`20P800ZJVY07alO01XJ6P0Lg=c0451
@@1;Bd/0QhN704e=C@0k>c/07AdM05=CD`1>CTh04Q8B00h>3P0200d=3@0>010@400M7Ad09BDU01hN
7P0O7al0DE5A07QhN00o?cl05ADE03`l?00U9BD0DU9B014A4@0@410200h>3P1T00d=3@0>3Ph03@d=
00d=3@0@41005aLG024Q8@0f=SH0EEEE06=SH`35aLD0Zj^[061PH00X:2P08R8R02LW9`1EEED0SXj>
0;Ng]`2f][H0?Shn02h^;P12@T80YjNW04Y:BP32`/80Ogmo0451@@1ZJVX04a<C01@D500l?3`0C4a<
02`/;00];Bd0MGEe07inOP1DE5@0Ti>C0;Zj^P3:b/X0YZJV0:BTY01CDe<0=cLg03Hf=P1UIFD0N7Qh
05ADE02@T900NWYj08:2PP0e=CD07AdM02HV9P0d=3@0GEeM01<C4`0>3Ph04A4A01@D500C4a<05ADE
03/k>`0o?cl0Ng]k04];B`11@D40/[:b0=_Kf`2QXJ40IFEU05MGE`2>SXh0@41004M7A`27QhL0Jf][
04i>CP1;Bd/071`L01LG5`0S8b<0<c<c04E5A@1NGUh0]kNg0:2PX02LW9`0/[:b08V9R@2FUYH0f=SH
0;Rh^01iNGT0O7al08Z:RP1lO7`0GEeM04Q8B080AdM701l0=cLg03<c<`1IFET0VYZJ04e=C@0P8200
8B4Q04M7A`1PH600_Kfm030`<00N7Qh06a/K01`L700[:b/0Cdm?04M7A`2PX:00`/;20=7Ad@0o?cl0
CTi>075aL@0n?Sh0LG5a0=[JfP36a/H0eMGE0=;BdP3IfMT0Jf][0080BDU90680ATI604=3@`14A4@0
BDU906UYJ@2o_kl0i>CT0>?Sh`2ATI40:RXZ024Q8@0];Bd0_[jn08V9R@0^;Rh07alO030`<016ATH0
NWYj01dM7@0];Bd051@D01DE5@0N7Qh0:b/[051@D03Fe]H0b<S80<C4a02n_[h0UIFE0:JVYP3AdM40
g=cL0;:b/P2EUID0EEEE04=3@`0K6a/05ADE01<C4`0E5AD05QHF05YJFP1EEED0HV9R05=CD`1PH600
?3`l034a<@1nOWh0QHF504U9B@1<C4`0AdM70410@016ATH0SHf=08B4Q02@T900OWin07EeM@1QHF40
/K6a06e]K@1aLG40a/K609fMW@1IFET0BDU905MGE`1VIVH0EUIF02TY:@0I6AT0>c/k03hn?P1;Bd/0
EEEE04];B`0Z:RX09RHV05QHF02JVYX0<30`03dm?@1hN7P0dm?C069RHP1MGEd0IfMW02`/;00O7al0
N7Qh06IVIP0Z:RX0AdM704U9B@;ooooo0000L033`l<0KFe]05EEE@2ATI40De=C09VIV@24Q8@0GEeM
07]kN`2a/K40C4a<07=cL`2OWil0F5QH08b<S00n?Sh0MGEe08^;R`0i>CT0EUIF04A4A01EEED0V9RH
06m_K`0k>c/0Lg=c08J6QP0h>3P0=3@d07emO@0M7Ad0>CTi055AD@1LG5`0PX:207MgM`0X:2P0EUIF
08V9R@1EEED0CTi>05ADE00`<3007QhN04a<C01BDU80820P028R8P1:BTX09bLW03Lg=`1>CTh0ADE5
02d];@16ATH0@41004Y:BP1dM7@0D51@038b<P2@T900@D5103<c<`1VIVH0FEUI03@d=01=CDd0DE5A
0451@@0g=cL0MWIf04e=C@0f=SH08b<S04M7A`1=CDd0>3Ph06MWI`1^KVh0@D5104E5A@10@400>3Ph
07EeM@13@d<0JFUY07emO@24Q8@0D51@05ADE01eMGD0M7Ad038b<P14A4@0TY:B03Lg=`1DE5@0AdM7
09JFUP1IFET06a/K05aLG01VIVH0KVi^06ATI01BDU80H61P03Xj>P0m?Cd0T92@03Hf=P1cLg<205aL
G00K04i>CP1JFUX0Ti>C04I6AP12@T80G5aL06MWI`1ADE40CTi>0451@@0];Bd0Kfm_03@d=01PH600
Jf][04E5A@1IFET0AdM704a<C01HF5P0H61P06IVIP12@T80MWIf05QHF028R8P0DU9B0080J6QX0=D0
=cLg08B4Q022PX80GUiN059BDP1GEeL0OWin092@T01QHF40:2PX06m_K`1TI6@0=cLg09ZJVP1WIfL0
>c/k05ADE01MGEd0ATI604m?C`1eMGD0EUIF07inOP1DE5@0M7Ad02XZ:P1eMGD0@41002h^;P1jNWX0
HF5Q079bLP23Ph<0Ng]k07alO021PH40JFUY05]KF`1=CDd0VYZJ06=SH`0h>3P0EeMG0<S8b01_Kfl0
Bd];07MgM`2DU9@0G5aL03Ph>01`L700TI6A06QXJ01<C4`0WinO08>3P`1ADE40^k^k08^;R`1CDe<0
O7al0:VYZ@14A4@0?clo03hn?P0J6QX0<C4a065QH@0d=3@0N7Qh05mOG`0n?Sh0YjNW06IVIP0d=3@0
;Rh^07QhN00T92@0<c<c06ATI00T92@0?Shn05EEE@1NGUh0Jf][05QHF00j>SX0FUYJ04U9B@1[Jf/0
Hf=S08b<S01MGEd0TY:B059BDP1mOGd0JFUY05MGE`0X:2P0Cdm?03Lg=`13@d<0MWIf0;6a/@1nOWh0
D51@0<C4a01SHf<0ATI603Xj>P29RHT0OWin05iNGP2BTY80UIFE07AdM00V9RH0G5aL08j>SP14A4@0
@41006m_K`1<C4`0;Bd]09BDU01<C4`0;2`/07emO@2BTY80H61P09>CT`1]KFd0M7Ad03/k>`0/;2`0
QHF50861P@1>CTh08B4Q04U9B@1PH6009bLW05EEE@2?Shl0UYJF05eMG@0i>CT0XZ:R03hn?P0C4a<0
<C4a08Z:RP1XJ6P0GEeM09nOW`1:BTX0:BTY07IfMP1jNWX0?Shn06YZJP1dM7@0:2PX07AdM02n_[h0
M7Ad05UIF@1GEeL0P8200:f][@1`L700?Shn069RHP2XZ:P0Ogmo03Ph>026QXH0C4a<05IFEP2OWil0
bl_;08^;R`1XJ6P0CDe=04i>CP2HV9P0`l?304Q8B00V9RH0Lg=c0<?3``2VYZH0bLW90<g=c@2a/K40
c<c<0:RXZ01MGEd0D51@04m?C`1kNg/0SXj>09JFUP2XZ:P0Lg=c09>CT`34a<@0cLg=0:b/[039bLT0
gMgM0<C4a02a/K400P2`/;007P2e]KD0`L710<g=c@3Fe]H0_[jn061PH00K6a/06QXJ02HV9P0F5QH0
4A4A024Q8@1ADE40Q8B409jNWP2d];@0_Kfm08j>SP1oOgl0;bl_00d=3@0T92@0AdM703/k>`0L71`0
;Rh^06=SH`0I6AT0410@00d=3@<03Ph>00d08R8R02/[:`0W9bL0FEUI0410@01hN7P0>SXj01hN7P1]
KFd0DU9B02l_;`0L71`04a<C00<04A4A03X0410@00h>3P0>3Ph03@d=010@400_;bl0GUiN0;Bd]03D
e=@0WinO08:2PP26QXH0O7al0:^[Z`2ZZZX0Lg=c05=CD`2SXj<0ZJVY09:BTP1hN7P0P82007MgM`39
bLT0b/[:09ZJVP1mOGd0:b/[01lO7`0L71`08B4Q04Q8B015ADD0De=C04i>CP0d=3@0:RXZ07MgM`3Q
hN40c/k>07alO01[Jf/0KVi^08V9R@2PX:00_kno07QhN02=SHd0V9RH0;:b/P1nOWh0B4Q803Ti>@1P
H600:2PX01<C4`0D51@04a<C0`0E5AD0100[:b/0Bd];05MGE`1EEED2059BDP0=0=_Kf`3Lg=`0`L71
0<71`@33`l<0NWYj09VIV@33`l<0EUIF06=SH`1=CDd06ATI01DE5@0201TI6@1g028R8P1ADE40S8b<
05mOG`1QHF40ZJVY09RHV03AdM40c/k>0<G5a@2CTi<0L71`055AD@0c<c<07AdM01LG5`0I6AT06a/K
020P800Y:BT09bLW05iNGP2UYJD07QhN02@T900j>SX0KVi^09VIV@2MWId09BDU02XZ:P1UIFD0JVYZ
034a<@0d=3@0EeMG0<O7a`2`/;00Vi^K07UiN@11@D40;Rh^08R8R03MgMd0hN7Q07IfMP12@T80ZJVY
0;2`/01ADE40Cdm?04U9B@1BDU80HV9R08J6QP2f][H0iNGU0>CTi03Jf]X0MWIf028R8P0P82008b<S
08J6QP2_[jl0GEeM02PX:00j>SX0De=C08B4Q00K6a/071`L01TI6@0b<S808b<S02LW9`1hN7P0/k>c
0>KViP35aLD0I6AT0<?3``34a<@0`L7105YJFP1nOWh0Z:RX07moO`1BDU80ADE502d];@0G5aL05ADE
01PH601`L700Cdm?07MgM`1ADE40DU9B02l_;`1LG5`0P82002/[:`0J6QX08R8R02/[:`0h>3P0JFUY
09FEU@26QXH0W9bL08b<S01KFe/0CDe=08n?S`2o_kl0[Jf]0<S8b025QHD00P1dM7@0701>CTh0EEEE
04Y:BP1BDU80Hf=S0410@00N7Qh0<30`04E5A@1LG5`0DU9B079bLP38b<P0aLG509:BTP1/K6`0/k>c
08B4Q02CTi<0E5AD05YJFP1VIVH0De=C0:NWY`13@d<0CTi>06EUI@1dM7@2ooooo`0009d0c<c<06IV
IP1EEED0SXj>05QHF02SXj<0PX:207moO`2RXZ80/k>c04a<C01`L700XZ:R05aLG02BTY80@41008:2
PP2>SXh0=3@d061PH00l?3`0NWYj0::RXP1OGel0@T9208>3P`2?Shl0@d=303dm?@1iNGT06ATI04E5
A@1XJ6P0GEeM08R8R01cLg<0:2PX06IVIP2;Rh/0D51@05EEE@1CDe<0=CDe028R8P1EEED0De=C02DU
9@0Z:RX0BDU902l_;`0o?cl0Bd];04e=C@0Z:RX0DU9B04A4A01HF5P0M7Ad059BDP0b<S80Ti>C04Q8
B00l?3`0KFe]05]KF`0_;bl0AdM705eMG@1FEUH0?3`l0820P00c<c<09bLW020P8019BDT0DU9B04=3
@`1hN7P0JVYZ034a<@1ADE40@T9203Xj>P1hN7P0=cLg06=SH`2;Rh/0K6a/0451@@1IFET0OGem05iN
GP0];Bd0AdM708R8R00[:b/0EeMG04Y:BP1oOgl0=CDe02TY:@1>CTh0EEEE06e]K@11@D40CTi>07If
MP0M7Ad0KVi^09>CT`0h>3P0J6QX04E5A@2TY:@0FUYJ069RHP26QXH0A4A405EEE@1fMWH0Kfm_05EE
E@1=CDd0C4a<03/k>`1nOWh0@d=305mOG`1TI6@0=cLg07UiN@1VIVH0C4a<05UIF@1ZJVX0CTi>059B
DP2KVi/0De=C08B4Q014A4@0TI6A08V9R@0e=CD0PX:206e]K@1HF5P0QHF506YZJP28R8P0QXJ6051@
D00/;2`0V9RH08b<S011@D40X:2P0080>3Ph02`0Q8B40820P016ATH0DE5A06a/K00Y:BT0Ti>C0;Ng
]`2=SHd0:2PX08N7Q`11@D40>c/k08n?S`1RHV80M7Ad07emO@1WIfL0QXJ6092@T016ATH0NGUi05IF
EP2>SXh0CDe=04I6AP17AdL0clo?069RHP1ADE40M7Ad08f=S@0];Bd0ADE50;Jf]P2NWYh0N7Qh04e=
C@2RXZ80@D5105eMG@39bLT0WYjN079bLP80^k^k0440?Cdm06IVIP1LG5`0;Rh^03<c<`1TI6@0?Cdm
0:j^[P21PH40EEEE0:RXZ01oOgl08B4Q04];B`1oOgl0=CDe03Lg=`1aLG405aLG06=SH`2@T900X:2P
0861P@1:BTX0;bl_06EUI@1>CTh0BDU903`l?02CTi<0UiNG08b<S00o?cl0Lg=c06MWI`1PH600=cLg
07moO`1YJFT0Cdm?071`L02][Jd08R8R0492@P2UYJD0LW9b069RHP0n?Sh0Y:BT079bLP0b<S80F5QH
08B4Q01[Jf/09bLW05YJFP2XZ:P0=3@d03<c<`28R8P0KVi^02XZ:P2VYZH071`L03De=@0209^KV`0o
05]KF`26QXH0VYZJ07UiN@0M7Ad092@T06][J`20P800DU9B04U9B@29RHT0TY:B04M7A`1DE5@0S8b<
05YJFP0K6a/0Cdm?07YjNP1gMgL0C4a<02h^;P1LG5`04a<C03Lg=`1cLg<0I6AT03@d=01VIVH0DE5A
01LG5`1>CTh0M7Ad051@D01nOWh0clo?05YJFP0O7al0?3`l06YZJP27QhL0JVYZ024Q8@0a<C40JFUY
03Ti>@0G5aL0QhN70:b/[02:RXX0DU9B05mOG`2YZJT0SXj>05YJFP1/K6`0KFe]09FEU@1cLg<0;bl_
03dm?@3>c/h0eMGE0080dm?C0380WYjN0<K6aP36a/H0WYjN08B4Q01cLg<0@41003<c<`0Y:BT0<S8b
08>3P`2k^k/0c/k>0>WYj@3Ogml0Vi^K0:^[Z`35aLD0VIVI09NGU`1kNg/0U9BD0:JVYP31`L40_[jn
07moO`2?Shl0N7Qh04M7A`0i>CT0Jf][08j>SP23Ph<0HV9R06IVIP2VYZH0RXZ:07moO`28R8P0?3`l
02l_;`0B4Q805aLG05EEE@10@400:b/[02PX:00c<c<0B4Q8010@40803@d=04X03Ph>00d=3@0>3Ph0
71`L02@T901gMgL0@d=306YZJP1kNg/0MGEe0=CDe036a/H0Y:BT07YjNP1/K6`0KFe]06a/K01]KFd0
K6a/05MGE`13@d<0<S8b02l_;`1nOWh0b<S80:n_[`3Lg=`0[:b/0:BTY03:b/X0Ogmo034a<@0M7Ad0
71`L020P800^;Rh0IVIV06ATI02][Jd0NWYj0;Rh^01BDU809bLW05YJFP1WIfL0M7Ad09^KV`1OGel0
>CTi02DU9@16ATH0H61P05YJFP1?Cdl0:2PX06UYJ@3>c/h0[Jf]08f=S@26QXH0SXj>08V9R@2UYJD0
Ti>C09bLW02HV9P0a<C40;fm_@2KVi/0]kNg0;bl_02;Rh/05aLG01<C4`80410@02<04Q8B01DE5@0G
5aL0DU9B06YZJP0j>SX0K6a/065QH@1HF5P0b/[:09fMW@1`L700RHV90;Jf]P37alL0fm_K0<30`01D
E5@0NWYj04Q8B00I6AT05aLG01`L700N7Qh07alO03<c<`1fMWH0?3`l038b<P1nOWh0@d=306m_K`1S
Hf<0>3Ph01PH600401DE5@0301<C4`0E5AD05ADE00805ADE05805QHF02h^;P2ATI40E5AD02@T900g
=cL0MgMg08F5Q@3Fe]H0[Zj^0:ZZZP1XJ6P0=CDe03Xj>P1XJ6P0HV9R03Xj>P3Ph>00emOG096AT@2F
UYH0`<300>OWi`3Ph>00XZ:R06a/K013@d<0OWin0<30`01gMgL0KVi^07=cL`26QXH0/K6a0>3Ph036
a/H0TY:B0<o?c`1ZJVX0]kNg08f=S@0Q8B407QhN04e=C@2c/k<0_Kfm04];B`12@T80P82006MWI`0M
7Ad071`L01lO7`1GEeL0:2PX06MWI`2[Zj/0IfMW0=oOg`3Ph>00^;Rh0=SHf03EeMD0IfMW08B4Q03;
bl/0;2`/03Ti>@1bLW80H61P0492@P14A4@0:RXZ028R8P1nOWh0GUiN09VIV@1UIFD0@D5104a<C02@
T900>SXj0P0L71`0;@0N7Qh08R8R028R8P0b<S80Kfm_096AT@1hN7P0[Zj^06i^KP1OGel0I6AT096A
T@3<c<`0Ph>305=CD`1lO7`0XJ6Q08B4Q016ATH0@T9204a<C01jNWX0EEEE03`l?01GEeL0RXZ:0:BT
Y031`L40W9bL0:b/[03De=@0f][J0=3@d02c/k<0A4A4075aL@2NWYh0QHF507MgM`2XZ:P0OGem07Yj
NP1lO7`0HF5Q05eMG@02ooooo`000?l0b<S805mOG`1nOWh0P82004i>CP26QXH0Bd];06UYJ@21PH40
UIFE04E5A@1KFe/0GEeM06=SH`2SXj<0?Shn09BDU025QHD0>CTi06][J`0l?3`0Q8B4071`L011@D40
HV9R08Z:RP1iNGT0AdM704a<C013@d<08b<S08:2PP1`L700GUiN07AdM012@T80@41008n?S`2<S8`0
EUIF05mOG`15ADD0;bl_03hn?P1OGel0<C4a02TY:@1@D500KVi^03`l?017AdL0C4a<02LW9`19BDT0
GUiN03Ti>@1HF5P0B4Q803Lg=`1KFe/0VYZJ04Y:BP0h>3P0Jf][04a<C01:BTX0QHF508N7Q`1KFe/0
@41009>CT`0i>CT07AdM04m?C`1jNWX0GUiN0410@01dM7@0K6a/030`<01RHV80FUYJ0410@01mOGd0
>3Ph05eMG@2CTi<0KFe]03dm?@1NGUh0Ng]k05IFEP0h>3P0Q8B408j>SP0a<C40De=C04M7A`28R8P0
;2`/01TI6@1CDe<0Bd];0451@@0e=CD0EeMG05EEE@11@D40KFe]07inOP0/;2`0E5AD02LW9`1ZJVX0
H61P05]KF`1mOGd0:BTY06e]K@1kNg/0GemO05=CD`1HF5P0=CDe034a<@21PH40?Shn06=SH`19BDT0
8B4Q06e]K@1SHf<0AdM705EEE@1]KFd0@d=303dm?@1jNWX0BDU907EeM@0Y:BT0EeMG06][J`0l?3`0
U9BD0492@P0k>c/0LG5a055AD@25QHD0X:2P034a<@0Z:RX0SHf=07alO017AdL0[Zj^02l_;`0^;Rh0
EEEE04Q8B01KFe/0Rh^;04I6AP0G5aL0Bd];07QhN01]KFd0:2PX096AT@0F5QH0GUiN0:6QX@1UIFD0
L71`07MgM`0C4a<0MWIf09>CT`1ZJVX0EeMG05=CD`2EUID0=cLg04];B`1oOgl0cLg=09BDU01EEED0
VYZJ0:6QX@0X:2P0;Bd]06a/K01iNGT0CDe=04M7A`2l_;`0MGEe03/k>`2GUiL0@T92038b<P2>SXh0
/[:b034a<@0m?Cd0L71`04M7A`1:BTX0Hf=S03@d=02GUiL0RXZ:04m?C`2d];@0Rh^;02HV9P0c<c<0
Jf][02TY:@1=CDd0N7Qh024Q8@0j>SX0D51@07EeM@1`L700De=C03Hf=P1PH600BTY:04U9B@0I6AT0
Fe]K06m_K`27QhL0A4A406YZJP1cLg<0:b/[028R8P1QHF40Fe]K03lo?`1ZJVX0ZJVY07AdM01/K6`0
PH6107]kN`1`L700EUIF0<71`@2;Rh/00P1NGUh0PP1MGEd0B4Q802PX:027QhL0WinO04e=C@0m?Cd0
J6QX03lo?`0l?3`0ZZZZ03dm?@0e=CD0N7Qh06UYJ@0k>c/0WIfM0<?3``2YZJT0B4Q801XJ6P1VIVH0
J6QX01DE5@0T92@0FEUI07QhN014A4@0JFUY0;>c/`1cLg<0<30`03@d=01jNWX0M7Ad06ATI00`<300
E5AD05YJFP0k>c/0L71`04Y:BP0h>3P0M7Ad051@D00_;bl0CDe=06][J`14A4@0MGEe0<c<c01gMgL0
@41003`l?01@D500MWIf059BDP0j>SX0@41009nOW`1[Jf/0;2`/0=cLg02m_Kd0V9RH06UYJ@1FEUH0
@d=306IVIP2QXJ40OWin065QH@1?Cdl0Q8B40;Fe]@2i^KT0^[Zj0;^k^`2m_Kd0MgMg07inOP2h^;P0
_kno071`L01SHf<0E5AD02l_;`0P82008B4Q01/K6`0Y:BT0Vi^K0=WIf@3Kfm/0cLg=0;Rh^02/[:`0
b/[:0:f][@1^KVh0N7Qh06a/K01PH600IFEU07QhN01;Bd/0@T9208N7Q`2k^k/0f][J0;^k^`2>SXh0
HF5Q07emO@2g]kL0UYJF05MGE`1CDe<0M7Ad04Y:BP0R8R80<C4a02l_;`22PX80ADE503/k>`0T92@0
8B4Q04U9B@0[:b/500h>3P1701PH601?Cdl0RHV905UIF@1;Bd/0b<S80;>c/`1IFET0OWin09^KV`1<
C4`0=CDe028R8P0e=CD0?Shn04M7A`1@D500Ng]k09^KV`2UYJD0Vi^K0=SHf03Ogml0h^;R09VIV@2Z
ZZX0Ph>304M7A`15ADD0>3Ph02LW9`0T92@07alO02`/;01GEeL0UYJF0:ZZZP2c/k<0LW9b024Q8@0`
<300=CDe01<C4`0Y:BT0J6QX08n?S`2:RXX0Fe]K05QHF01oOgl0O7al04i>CP2FUYH0QhN706i^KP0n
?Sh0@T9204M7A`1fMWH0LW9b06MWI`1mOGd0QhN708:2PP2RXZ80Y:BT0:VYZ@1UIFD0De=C04U9B@0C
4a<00P0A4A408P0C4a<04A4A030`<01eMGD0K6a/05YJFP2<S8`0Y:BT0:f][@2KVi/0BDU905iNGP1i
NGT0EEEE05YJFP2^[Zh0WYjN06QXJ01gMgL0ADE501XJ6P0K6a/07AdM01lO7`0g=cL0=CDe08:2PP0]
;Bd0:2PX03lo?`1CDe<0KFe]05ADE00I6AT301DE5@0401<C4`0D51@04a<C01@D50<05ADE05@061PH
024Q8@1=CDd0^[Zj03Ti>@0o?cl0Ph>30<g=c@3Hf=P0eMGE071`L01RHV80MgMg07emO@1@D500;Rh^
05ADE03Ph>00gMgM07AdM017AdL0<c<c08b<S02[Zj/0/k>c0<S8b02[Zj/0Jf][0::RXP0V9RH05QHF
01PH600I6AT0<c<c09BDU00i>CT0K6a/092@T00O7al0G5aL0;2`/01ZJVX0:RXZ02h^;P1lO7`0d=3@
08n?S`1JFUX0[Zj^04e=C@0M7Ad09RHV065QH@2FUYH0UIFE0<g=c@29RHT0LW9b0<[:bP3AdM40fMWI
0;jn_P15ADD0IVIV03Hf=P1IFET09RHV01XJ6P0M7Ad0Cdm?07moO`15ADD0@d=307alO02KVi/0Shn?
09^KV`1XJ6P0C4a<08B4Q01DE5@07QhN01/K6`0L71`201dM7@09028R8P0W9bL0DU9B0:JVYP1aLG40
UIFE08>3P`10@400CDe=0080YZJV01`0OWin03Ti>@18B4P0N7Qh0=WIf@3Hf=P0c/k>0<G5a@36a/H0
^[Zj09jNWP2BTY80W9bL09nOW`1fMWH0IVIV09bLW03Cdm<0i>CT0=_Kf`3Fe]H0QXJ608^;R`3Jf]X0
d=3@0=_Kf`31`L40EUIF0P10@4000`1EEED0PH61ooooo`01ooooo`0001L0e=CD05EEE@1IFET0Ogmo
06UYJ@2k^k/0QHF507AdM02;Rh/0Zj^[04M7A`1fMWH0QXJ604i>CP1eMGD0>3Ph08j>SP1_Kfl0K6a/
09:BTP0e=CD0RXZ:07=cL`020410@02>08f=S@1lO7`0De=C075aL@1ADE405aLG04];B`1BDU80M7Ad
092@T00k>c/08R8R05iNGP0j>SX0BDU90861P@1/K6`0=CDe01PH601BDU80FUYJ028R8P0U9BD0A4A4
01PH601KFe/0MgMg03dm?@0_;bl0?clo03dm?@2JVYX0G5aL02h^;P0c<c<0N7Qh03/k>`1>CTh0N7Qh
02h^;P0W9bL0BDU905iNGP1:BTX0@d=30:BTY011@D40:b/[01hN7P1=CDd0I6AT03Xj>P27QhL0L71`
028R8P0h>3P0Cdm?03Hf=P1_Kfl0<c<c02d];@1WIfL0OGem03`l?01NGUh0OWin051@D00Q8B40BDU9
07inOP0e=CD0DE5A05UIF@1eMGD0DU9B01dM7@1MGEd0EeMG02@T900_;bl0PH6106IVIP13@d<0PX:2
07UiN@0f=SH0J6QX0451@@1mOGd0DE5A06e]K@21PH40=cLg05UIF@1DE5@0EeMG06ATI023Ph<0G5aL
04=3@`1eMGD0<S8b07alO01fMWH0?Shn07=cL`0W9bL0@T9207EeM@1cLg<0LG5a05=CD`1cLg<0?clo
0820P018B4P0H61P030`<012@T80WYjN07QhN01QHF40H61P01hN7P1TI6@0TI6A05aLG00_;bl0P820
04I6AP15ADD0UYJF05MGE`0n?Sh0FUYJ01dM7@0c<c<0G5aL06i^KP11@D40H61P05ADE080?clo06d0
XJ6Q03hn?P0i>CT0NGUi0451@@28R8P0Shn?04a<C01]KFd0JVYZ03`l?01aLG40TY:B0:VYZ@1KFe/0
>SXj04A4A02f][H0@D5104U9B@20P800Vi^K05MGE`0d=3@0Kfm_07QhN00k>c/071`L096AT@1mOGd0
CTi>08V9R@1TI6@0@d=305IFEP1lO7`0=SHf051@D01KFe/08R8R06m_K`1kNg/0EEEE08j>SP1eMGD0
8b<S06i^KP25QHD0@41003hn?P1fMWH06ATI05mOG`2;Rh/0C4a<04e=C@1EEED0FUYJ06ATI01=CDd0
BDU908N7Q`1VIVH0@D5104Q8B022PX80FUYJ07MgM`0M7Ad0Jf][06i^KP10@400;Bd]061PH010@400
?Shn09FEU@2VYZH0T92@08R8R01YJFT0ATI601XJ6P1VIVH0`/;2096AT@1UIFD0J6QX06UYJ@0L71`0
6a/K06ATI02BTY80HV9R03`l?024Q8@0:2PX03dm?@2XZ:P0F5QH03Xj>P2HV9P0GUiN01TI6@1<C4`0
G5aL07AdM00g=cL06a/K0080IFEU00P0=cLg01dM7@1LG5`0Jf][04Q8B01mOGd0`l?308B4Q080?Cdm
06@0TI6A07=cL`1NGUh0?Shn08N7Q`1bLW80De=C08V9R@15ADD0?clo0:j^[P1WIfL0<C4a075aL@1j
NWX0<c<c07IfMP3@d=00Q8B405=CD`1GEeL0JVYZ09:BTP1FEUH0@T9203`l?02c/k<0NWYj03hn?P20
P800Cdm?04];B`0a<C40:2PX02HV9P0S8b<0;bl_06e]K@2GUiL0TI6A08B4Q033`l<0fMWI09FEU@2X
Z:P0`L710:VYZ@1MGEd0YjNW0492@P0];Bd0=3@d04Q8B01FEUH0HF5Q04i>CP0_;bl0@T920:2PX03I
fMT0g=cL0>?Sh`2j^[X0VYZJ09FEU@3De=@0]kNg0:>SX`2UYJD0KFe]03Ph>00V9RH0?Cdm051@D01V
IVH0ZZZZ0<c<c02c/k<0Ogmo05mOG`2[Zj/0WYjN07emO@0W9bL05ADE00l?3`0N7Qh0@T9204M7A`1`
L700SHf=05EEE@0j>SX0<c<c020P800V9RH0EUIF018B4P0D51@04A4A0P0@41002`0h>3P0GEeM0820
P01dM7@0DE5A0;Ng]`2DU9@0CTi>051@D01/K6`05aLG00<0410@02<07QhN02HV9P0_;bl0>CTi03lo
?`1ADE40U9BD0=3@d036a/H0b<S80;Rh^02?Shl0G5aL03`l?00i>CT0;Rh^018B4P0C4a<071`L01LG
5`1oOgl0QhN709VIV@1PH600Fe]K028R8P0e=CD0=SHf014A4@0C4a<05ADE01TI6@0l?3`0RXZ:0:2P
X00209>CT`0E0:FUY@2SXj<0Y:BT07emO@13@d<0>SXj071`L01;Bd/0;Rh^030`<00h>3P0E5AD07If
MP1JFUX0K6a/05]KF`1[Jf/0;bl_02d];@14A4@08B4Q00805ADE02408B4Q04=3@`23Ph<0Hf=S04m?
C`1:BTX0LW9b0;:b/P2RXZ80UIFE06IVIP0[:b/0;Rh^04A4A01QHF40WIfM07=cL`1gMgL0@D5101dM
7@0N7Qh08b<S01dM7@0h>3P0Fe]K055AD@1>CTh07alO03Hf=P1KFe/0PH6105eMG@0K6a/00`0E5AD0
0`0G5aL051@D01<C4`0401DE5@0]01HF5P0T92@0>CTi0<W9b@2ZZZX0EEEE09NGU`2JVYX0[Zj^07Yj
NP2DU9@0[jn_08N7Q`1/K6`0OGem0861P@2VYZH0_;bl0=CDe01_Kfl0SHf=09bLW03Jf]X0_kno059B
DP33`l<0SXj>01LG5`11@D40CTi>01XJ6P0H61P0820P05]KF`10@400<c<c09nOW`17AdL06QXJ02DU
9@1@D500YZJV0:6QX@1;Bd/0AdM70080d];B02H0a<C40=WIf@1JFUX0RHV90:^[Z`2o_kl0Y:BT0=OG
e`2o_kl0O7al0:>SX`1RHV80>SXj08J6QP1eMGD05ADE01LG5`0i>CT0;2`/05IFEP0M7Ad05aLG01TI
6@0g=cL0W9bL07QhN02j^[X0`<300<O7a`2YZJT0EeMG07AdM01lO7`0:BTY01TI6@0L71`07AdM01`L
70807QhN02X08R8R0492@P1cLg<0LG5a09JFUP1lO7`0ADE507inOP2IVIT0L71`0861P@1jNWX0>c/k
05EEE@3?cll0YJFU08R8R02EUID0Shn?0;2`/01bLW80Kfm_06][J`20P800[:b/0<?3``3IfMT0hn?S
0>CTi03Fe]H0][Jf09jNWP3@d=00i>CT0;Bd]03AdM40U9BD03dm?@1MGEd0PH6109NGU`2=SHd2oooo
o`0003D0_kno05aLG02;Rh/0Hf=S05eMG@2QXJ40Rh^;09bLW02YZJT0DE5A05mOG`2[Zj/0WinO06EU
I@1bLW80D51@0:f][@1DE5@0?Shn055AD@0i>CT0UIFE08>3P`0j>SX0EEEE061PH00T92@0>3Ph04m?
C`1QHF406QXJ0410@00R8R80?Cdm06UYJ@1MGEd0;Bd]07QhN01FEUH0=3@d0410@01<C4`0:b/[020P
801NGUh0I6AT02@T900X:2P0CTi>03<c<`0j>SX0@T9203Lg=`02034a<@1l028R8P10@400DE5A03@d
=00j>SX0MgMg01/K6`17AdL0Jf][04a<C00W9bL0DE5A05IFEP0N7Qh0BTY:08N7Q`1@D500B4Q803<c
<`1PH600DU9B038b<P1mOGd0SXj>05EEE@1;Bd/0@D5103Ph>025QHD0ADE506a/K02ATI40Ogmo059B
DP2@T900^[Zj07QhN00[:b/0DE5A08R8R00R8R80@410055AD@1WIfL0EUIF01`L701JFUX0DU9B04A4
A00[:b/0ADE504e=C@17AdL0O7al06m_K`0T92@0KVi^04e=C@1TI6@0;Bd]05YJFP2<S8`0?Shn05AD
E01nOWh0;Rh^038b<P18B4P0E5AD0492@P1iNGT09bLW04e=C@1PH600?3`l06m_K`1EEED0@41004a<
C01OGel0MWIf05YJFP21PH40ADE507=cL`1CDe<0HV9R075aL@0d=3@0N7Qh071`L01HF5P0HV9R059B
DP2LW9`0SHf=04Y:BP0a<C40OWin05aLG00e=CD0VYZJ05MGE`1BDU80LW9b05aLG00_;bl0J6QX06i^
KP1BDU80W9bL09ZJVP1EEED071`L07emO@1BDU80@41007EeM@0[:b/0AdM707YjNP1WIfL0UIFE075a
L@80?Shn01T0@41008Z:RP1bLW80>CTi04E5A@2h^;P0GemO04Y:BP1`L700Ogmo0492@P0f=SH0K6a/
071`L01MGEd0:RXZ0:^[Z`1RHV80Hf=S0:>SX`1]KFd0EEEE09>CT`2ZZZX0B4Q80080H61P0440;2`/
02PX:01DE5@0BTY:09nOW`1dM7@0GemO08:2PP1XJ6P0;Bd]03dm?@1YJFT0;Bd]05ADE01eMGD0>3Ph
05=CD`1QHF40IfMW06][J`0J6QX0>3Ph07moO`1hN7P0EeMG051@D02ATI40GUiN0820P00U9BD0SHf=
0:VYZ@13@d<0<S8b06][J`0h>3P0ADE50:j^[P2QXJ40MgMg08R8R01eMGD0E5AD03`l?01<C4`0_Kfm
06][J`1BDU80^k^k0:VYZ@1GEeL07QhN04m?C`28R8P0ADE503Lg=`1nOWh0De=C03De=@22PX80DE5A
03lo?`2NWYh0WinO04a<C00208:2PP1S08>3P`0c<c<06a/K06][J`1QHF40?Shn02DU9@1WIfL0D51@
03<c<`2IVIT0_;bl05YJFP0[:b/0DE5A096AT@1:BTX09bLW03@d=01OGel0:RXZ04Y:BP22PX80?clo
020P801PH600ADE502PX:01nOWh0PX:202PX:01VIVH0a<C409FEU@1UIFD0G5aL07YjNP2`/;00Jf][
03De=@1QHF40`<3007inOP11@D40Jf][04i>CP11@D40;Rh^02PX:00V9RH08B4Q01hN7P0M7Ad08B4Q
04E5A@2][Jd0UiNG0:>SX`1RHV80EEEE065QH@1[Jf/0De=C07alO00J6QX051@D014A4@0?3`l0410@
01<C4`0U9BD0F5QH0;2`/02IVIT0Z:RX096AT@39bLT0MGEe06EUI@1VIVH0_Kfm06e]K@1[Jf/0PX:2
0:2PX02f][H0TY:B05YJFP0j>SX0T92@0:2PX028R8P0TY:B04i>CP2YZJT0T92@08N7Q`1bLW804a<C
00803Ph>00d03`l?010@400U9BD0PX:209^KV`1hN7P0>c/k04Y:BP0U9BD06a/K03De=@0W9bL05ADE
00804a<C02d0;bl_04E5A@18B4P0?clo03`l?01^KVh0UIFE0:n_[`25QHD0K6a/0451@@0J6QX05ADE
01LG5`0U9BD0=cLg04U9B@11@D40>CTi03`l?019BDT0SHf=0=GEe@3Ng]h0UiNG08n?S`2f][H0PX:2
05iNGP1FEUH0D51@055AD@1RHV80MWIf09VIV@2a/K40ZJVY059BDP16ATH0EeMG02h^;P0g=cL0?Cdm
01DE5@0D51@00P0E5AD03P0C4a<092@T04M7A`1QHF40U9BD0;no_`31`L40WYjN08V9R@0k>c/0IfMW
06QXJ00`<300820P0`0E5AD07P0b<S80F5QH06a/K01WIfL0MWIf03hn?P0P82008B4Q055AD@0i>CT0
>3Ph04Q8B01;Bd/0Shn?06a/K01SHf<0IFEU09ZJVP2SXj<0EEEE05YJFP10@4007AdM028R8P0l?3`0
BTY:07alO01hN7P0O7al0492@P80:RXZ00`09BDU02PX:01@D500:2PX01DE5@12@T80BDU90410@01N
GUh0LW9b06m_K`0b<S8201DE5@0501LG5`0F5QH04a<C014A4@0B4Q800P0C4a<0700@41006a/K020P
800_;bl0V9RH0=GEe@2k^k/0e=CD0=cLg02PX:00]KFe0;>c/`1mOGd0XZ:R06i^KP1KFe/0GUiN03lo
?`36a/H0clo?096AT@28R8P0O7al0:VYZ@3Ogml0Bd];061PH02;Rh/201TI6@0906MWI`0M7Ad07AdM
04=3@`0g=cL06a/K024Q8@29RHT0820P008071`L0280820P04I6AP2`/;00f][J092@T02EUID0i^KV
0<k>cP3Lg=`0clo?09>CT`1[Jf/0QHF50861P@32`/80]kNg0;6a/@2=SHd0>3Ph01XJ6P1`L700NWYj
01PH600E5AD05aLG024Q8@0a<C40ADE501LG5`0E5AD06ATI02h^;P2/[:`0dm?C0P2o_kl01`31`L40
TI6A08Z:RP15ADD06QXJ01`L700M7Ad00P0L71`0;00M7Ad0820P024Q8@11@D40GEeM071`L01jNWX0
SHf=05aLG02LW9`0<c<c05MGE`1/K6`0VIVI08R8R02<S8`0QHF503Ti>@0[:b/0BTY:0:f][@2n_[h0
`l?308:2PP2YZJT0b/[:0<o?c`3Hf=P0/[:b09NGU`3Ng]h0eMGE0;2`/01^KVh0PX:20:BTY03<c<`0
i>CT0;bl_02PX:00U9BD08F5Q@1XJ6P0GUiN0_ooool0000O0;fm_@1ADE40KFe]07EeM@1SHf<0R8R8
05MGE`27QhL0Ti>C07=cL`15ADD0IVIV06EUI@1nOWh0N7Qh03<c<`25QHD0Fe]K04];B`1IFET08b<S
06m_K`1mOGd0=CDe05EEE@2BTY80MWIf02h^;P13@d<0JFUY02DU9@0206i^KP1807MgM`1]KFd0G5aL
04m?C`2DU9@0OWin04Y:BP13@d<0Bd];038b<P0M7Ad0IfMW05]KF`0P8200<S8b04Q8B00c<c<0CDe=
04i>CP0o?cl0=cLg04];B`0Y:BT0CDe=05EEE@0f=SH0?Shn09:BTP0j>SX0=SHf06QXJ01GEeL0:RXZ
05=CD`1cLg<0?3`l04e=C@2>SXh0>CTi02PX:00i>CT0EEEE065QH@0h>3P0De=C065QH@10@400EUIF
03Ph>00X:2P0DU9B03Hf=P1jNWX0QXJ6075aL@0Y:BT0?clo05IFEP1HF5P07alO05YJFP1nOWh0:BTY
03Ti>@1EEED0FEUI03/k>`0g=cL0JFUY06IVIP1TI6@0@T920P1bLW803@0j>SX0H61P07QhN00/;2`0
IFEU04I6AP2HV9P0LG5a05eMG@24Q8@0@d=306ATI01oOgl00P1NGUh0f`1BDU80IFEU04Y:BP2;Rh/0
>c/k06UYJ@1MGEd0ADE509:BTP1nOWh0@d=3055AD@1iNGT0LG5a06YZJP26QXH0CDe=07moO`1MGEd0
UIFE08f=S@0j>SX0Q8B405MGE`1_Kfl0TI6A05QHF032`/80Rh^;03Hf=P1<C4`0TY:B06a/K00l?3`0
V9RH034a<@1=CDd0O7al075aL@0V9RH0Hf=S05]KF`0Z:RX0DU9B07MgM`1[Jf/0:RXZ09NGU`1CDe<0
H61P07emO@1:BTX0H61P08b<S01eMGD0[Jf]07alO01>CTh0HF5Q05QHF02c/k<0UIFE04e=C@1MGEd0
bl_;06][J`1QHF40PH6108f=S@0l?3`0@T9206i^KP1lO7`0A4A403<c<`2f][H0MWIf04e=C@1mOGd0
?Shn05QHF02BTY80O7al02d];@1aLG40LW9b03Hf=P13@d<0IfMW04M7A`2/[:`0Rh^;05iNGP2XZ:P0
PH6102`/;01GEeL0NGUi04=3@`28R8P0OGem02@T901QHF40RXZ:09ZJVP1lO7`0DU9B0492@P1VIVH0
A4A404M7A`1=CDd0XJ6Q08Z:RP2BTY806QXJ04I6AP1RHV80EeMG03Xj>P1nOWh0:BTY01`L701DE5@0
OGem05IFEP23Ph<0TI6A07EeM@1<C4`0Ph>30=7Ad@1eMGD0?3`l05=CD`1RHV80CTi>024Q8@1RHV80
Vi^K038b<P0h>3P0QHF504i>CP0m?Cd0Shn?04];B`1VIVH0_;bl09bLW018B4P0VYZJ0:b/[02JVYX0
<C4a02l_;`22PX80EeMG03Ti>@17AdL0P82005eMG@0f=SH0Q8B40<k>cP1QHF40<S8b03Ti>@1`L700
HV9R06=SH`0c<c<0Fe]K04A4A00o?cl0MgMg04Y:BP0g=cL0MGEe03<c<`0K6a/0GUiN06ATI00`<300
ATI60;Rh^01mOGd0AdM707=cL`2a/K40/;2`05IFEP0P8200:2PX08V9R@14A4@08B4Q09NGU`1@D500
=CDe02h^;P0Z:RX09BDU01lO7`0M7Ad0820P01`L700J6QX0Kfm_0410@014A4@0GemO03Ti>@1;Bd/0
KFe]09^KV`11@D405aLG01DE5@03014A4@0_010@400>3Ph06ATI05eMG@2MWId0HF5Q03<c<`1FEUH0
6a/K02@T9013@d<0MGEe05mOG`0Q8B403`l?014A4@0P8200>c/k07MgM`2OWil0X:2P0:j^[P1YJFT0
WYjN0=KFeP37alL0MGEe02@T901=CDd0;Bd]010@400>3Ph0410@014A4@0@41009RHV08b<S01kNg/0
H61P06ATI00n?Sh06a/K01lO7`1?Cdl04a<C00h>3P0/;2`00P14A4@0;@0Y:BT04a<C01LG5`1TI6@0
QHF50;Ng]`28R8P0SHf=05IFEP1QHF40MGEe07UiN@2:RXX0UIFE0:VYZ@2QXJ40Vi^K096AT@2>SXh0
Rh^;0:b/[03:b/X0GEeM075aL@3:b/X0f=SH0;:b/P2@T900S8b<08:2PP1eMGD0OGem0:j^[P3GemL0
EeMG01dM7@15ADD0DU9B03hn?P0g=cL0ADE501DE5@0C4a<051@D01<C4`0201DE5@0801HF5P18B4P0
>SXj0:^[Z`2m_Kd0a<C40;>c/`1FEUH2024Q8@<05ADE01<05aLG01DE5@0E5AD09bLW03Xj>P1mOGd0
][Jf08Z:RP11@D40@T9204M7A`1iNGT0Hf=S061PH01kNg/0IVIV0861P@1BDU80FUYJ0080PX:201l0
GUiN05IFEP1FEUH0;Bd]01dM7@0R8R80=cLg06YZJP2DU9@0YjNW06a/K00o?cl07alO01hN7P1?Cdl0
9RHV01<C4`0E5AD05aLG07=cL`1/K6`0Hf=S065QH@1PH600AdM701lO7`0H61P05aLG010@400A4A40
5ADE00803Ph>00`04A4A010@400H61P0820P03`l?02/[:`0V9RH04=3@`2d];@0inOW0:j^[P1HF5P2
01/K6`0K01`L700I6AT061PH01HF5P0g=cL0cLg=075aL@1GEeL0<c<c02@T900d=3@0WinO0;Fe]@1>
CTh0NGUi024Q8@0E5AD0H61P05IFEP15ADD0=CDe01lO7`0N7Qh09bLW05IFEP0P82007AdM008071`L
02P07alO03Lg=`2MWId0gmoO0;Rh^03Ogml0gMgM0>?Sh`1jNWX0?Shn03<c<`1KFe/0C4a<0;2`/03>
c/h0[Zj^0:JVYP0K6a/05aLG075aL@2?Shl05ADE014A4@0D51@071`L02LW9`15ADD0A4A401TI6@0M
7Ad06a/K04];B`2OWil0`<300<?3``3:b/X0c/k>07IfMP0U9BD06ATI0P0K6a/201`L700/01hN7P0O
7al08b<S0410@01/K6`0Jf][0820P02LW9`0ZJVY030`<00O7al0;Bd]07YjNP2TY:@0_;bl06=SH`1O
Gel0<c<c03Lg=`1;Bd/0HF5Q09VIV@3Ph>00f=SH0=KFeP33`l<0YJFU08:2PP28R8P0_Kfm0;2`/02V
YZH0h>3P0=oOg`3GemL0XJ6Q0<[:bP3Ogml0c<c<08F5Q@1iNGT0IVIV051@D00i>CT2ooooo`000?l0
bLW905IFEP28R8P0NWYj08b<S02a/K40G5aL06=SH`24Q8@0LW9b06EUI@2OWil0H61P05IFEP1kNg/0
>CTi08R8R01KFe/0Jf][08:2PP0c<c<0QHF506MWI`14A4@0N7Qh08b<S01WIfL0=SHf055AD@0e=CD0
7alO059BDP1?Cdl0Kfm_05IFEP0/;2`0?3`l06e]K@1SHf<0Bd];04e=C@11@D40<C4a02HV9P1]KFd0
;Bd]02<S8`18B4P0DE5A02PX:01;Bd/0EUIF01`L7012@T80DE5A02HV9P1DE5@0?Shn030`<01^KVh0
Vi^K03`l?00h>3P0JFUY04E5A@0e=CD0GEeM08b<S018B4P0FEUI08J6QP0j>SX0=cLg03`l?01FEUH0
JFUY04I6AP1UIFD0GUiN03lo?`1ZJVX0BDU903Ph>01/K6`0>CTi07MgM`2[Zj/0J6QX03`l?01YJFT0
Kfm_05IFEP0o?cl0SXj>0861P@0f=SH0ADE5061PH01WIfL0?3`l01/K6`1BDU80IFEU05]KF`11@D40
U9BD08>3P`1TI6@0A4A407AdM00f=SH0I6AT02h^;P1mOGd0G5aL05MGE`1ZJVX0=CDe07=cL`1XJ6P0
DU9B07IfMP26QXH0D51@04m?C`1jNWX0@T9208:2PP0l?3`0;Bd]07MgM`16ATH0ADE507MgM`2GUiL0
?Cdm05YJFP1^KVh0FEUI07emO@0n?Sh0EEEE07=cL`1IFET0VYZJ05ADE011@D40HF5Q0451@@2WYjL0
V9RH04E5A@0];Bd0Q8B405QHF01KFe/0[Jf]04];B`0i>CT0I6AT03lo?`0T92@0L71`06e]K@15ADD0
IfMW061PH01;Bd/0@T92096AT@0h>3P0Fe]K07QhN01:BTX0NGUi06][J`0/;2`0MGEe06UYJ@1;Bd/0
EeMG09fMW@2e]KD0FEUI03Lg=`1VIVH0[:b/05iNGP22PX80^KVi0:FUY@17AdL0<c<c061PH027QhL0
EeMG034a<@2d];@0MgMg04m?C`1kNg/0GEeM04E5A@1^KVh0DU9B02h^;P12@T80@41003Ph>01]KFd0
M7Ad03dm?@2OWil0M7Ad04E5A@2XZ:P0Jf][02XZ:P0X:2P0CDe=03Hf=P2VYZH0IVIV03Xj>P0k>c/0
DU9B05=CD`1TI6@0<C4a04M7A`2EUID0RHV905ADE00/;2`0IFEU07UiN@21PH40<30`08B4Q02JVYX0
>3Ph034a<@1dM7@0CDe=0410@02FUYH0Shn?04m?C`1gMgL0D51@06][J`1LG5`0JFUY0<O7a`1nOWh0
04H0JFUY0:f][@2KVi/0CTi>02@T901ZJVX0Q8B403Lg=`0Q8B40K6a/0451@@1CDe<0NWYj02l_;`0c
<c<0Rh^;05MGE`0^;Rh0NWYj08Z:RP22PX80>3Ph01TI6@1NGUh0Bd];03<c<`0Q8B40Fe]K03/k>`0m
?Cd0X:2P0<K6aP1LG5`09RHV03Lg=`2>SXh0<30`034a<@1fMWH0Lg=c03Lg=`11@D40MGEe03hn?P0h
>3P0/[:b03lo?`0R8R80FUYJ071`L00];Bd0?clo0;Ng]`2DU9@0G5aL065QH@1VIVH0R8R803Lg=`0Z
:RX0HV9R0:j^[P1hN7P0?3`l09ZJVP1jNWX0>c/k02d];@0V9RH08R8R0P0O7al03@0M7Ad071`L01`L
701FEUH0@41003lo?`17AdL0A4A405EEE@2@T900d];B030`<00M7Ad00P0E5AD02P0D51@05ADE01DE
5@0A4A406QXJ0820P01=CDd0>SXj03<c<`0j>SX201TI6@0:03hn?P1LG5`07alO01TI6@0@41003Ph>
00l?3`0>3Ph04A4A04U9B@80`/;200`0d=3@0=kNgP3EeMD0XZ:R01XJ6P0I6AT071`L05EEE@1XJ6P0
=cLg02XZ:P0H61P201<C4`1908J6QP13@d<0A4A4071`L01ZJVX0>3Ph02HV9P1/K6`0<C4a02h^;P1H
F5P0CTi>01LG5`0?3`l03@d=03Xj>P0b<S80@41009NGU`3Kfm/0_;bl0::RXP1dM7@0D51@03`l?00`
<30092@T01lO7`0K6a/05aLG01<C4`0B4Q805ADE0410@02KVi/0`L710<G5a@2h^;P0^[Zj09NGU`19
BDT0?3`l034a<@0Z:RX0E5AD0:2PX03Fe]H0EeMG0451@@0o?cl0Bd];051@D00e=CD0ATI6018B4P0C
4a<05ADE018B4P0E5AD04a<C01DE5@0N7Qh0D51@06IVIP1kNg/0RXZ:05mOG`0F5QH04Q8B01LG5`0E
5AD04a<C01@D500301DE5@1E01LG5`1;Bd/0BDU906ATI02VYZH0UIFE05UIF@1mOGd0`/;208:2PP17
AdL0<S8b02`/;00^;Rh08R8R05]KF`1LG5`08B4Q02@T901PH600@D5105iNGP1:BTX0>SXj03Hf=P1^
KVh0OWin0=WIf@2b/[80BTY:02HV9P0o?cl0O7al01<C4`0>3Ph05ADE01LG5`1_Kfl0QXJ60<_;b`2X
Z:P0De=C05IFEP0i>CT05aLG01DE5@0A4A40410@014A4@0@41004A4A01DE5@0D51@07AdM02/[:`1L
G5`0eMGE0<c<c02HV9P0^k^k0=cLg01CDe<05ADE01HF5P0E5AD06ATI01lO7`0J6QX06ATI07]kN`21
PH409RHV03/k>`0W9bL07AdM02LW9`1PH600Shn?0:NWY`1OGel0?3`l01XJ6P1JFUX0@D5103dm?@02
05]KF`0]05EEE@1VIVH0T92@06MWI`1QHF40A4A403/k>`15ADD0ATI605MGE`2GUiL0fm_K0>3Ph03Y
jNT0i>CT08n?S`0c<c<0:2PX03Ph>029RHT0_kno0<?3``1hN7P0U9BD01PH600K6a/0QXJ60;6a/@0U
9BD05ADE01@D500I6AT0:BTY02LW9`0l?3`0@41002PX:00^;Rh0Lg=c06e]K@2;Rh/0`l?30=CDe03A
dM40>c/k00806QXJ03006ATI01`L700L71`07AdM020P800N7Qh07alO03hn?P1hN7P0HF5Q0:JVYP37
alL0T92@02DU9@0N7Qh09BDU08B4Q03Hf=P0emOG0<[:bP20P800EUIF05UIF@1:BTX0B4Q80820P03=
cLd0VYZJ0:>SX`2?Shl0XJ6Q09^KV`2j^[X0d];B08:2PP28R8P0a/K60>3Ph02o_kl0V9RH08V9R@2X
Z:P0ZJVY02LW9`0S8b<09RHV02<S8`0R8R82ooooo`0003D0`l?305IFEP26QXH0KFe]06MWI`2][Jd0
FUYJ06MWI`23Ph<0H61P059BDP1oOgl0LG5a06e]K@1hN7P0HF5Q09jNWP0h>3P0EUIF07EeM@0d=3@0
Rh^;03Ph>00f=SH0GUiN08F5Q@1cLg<0Jf][08>3P`1RHV807AdM051@D00h>3P0Ng]k08^;R`1:BTX0
?Shn08R8R019BDT0DU9B06e]K@1PH600>SXj01@D501OGel0CTi>01dM7@0[:b/0>3Ph01XJ6P1MGEd0
J6QX02d];@0203Ph>03904U9B@22PX80C4a<02DU9@12@T80Ng]k02l_;`0i>CT0H61P02LW9`0f=SH0
GemO06i^KP0i>CT0HV9R0820P00c<c<09RHV055AD@1QHF40De=C03Hf=P1/K6`0I6AT02`/;01>CTh0
A4A402LW9`21PH40=CDe05=CD`2ATI40HV9R03Xj>P1UIFD0HF5Q04];B`0O7al0FUYJ05iNGP0a<C40
ADE5075aL@1LG5`0@T9201hN7P1NGUh0IFEU04M7A`0S8b<0S8b<075aL@1>CTh0>3Ph06ATI00d=3@0
LG5a03lo?`1WIfL0@T9207IfMP21PH40=3@d05YJFP15ADD0<30`05IFEP1PH600Jf][04A4A01]KFd0
;Bd]05mOG`19BDT0=CDe07AdM01SHf<0=SHf04a<C01RHV80HF5Q07moO`1KFe/0CDe=08N7Q`1DE5@0
DU9B04E5A@1SHf<0Y:BT06e]K@1DE5@0De=C02d];@2=SHd0Shn?04M7A`0i>CT0PX:204i>CP0k>c/0
Shn?04e=C@10@400FUYJ02`/;00D51@0E5AD05IFEP0m?Cd0Ogmo07AdM018B4P0;Bd]08:2PP13@d<0
AdM705YJFP0h>3P0J6QX05EEE@14A4@0VYZJ04E5A@0V9RH0=CDe079bLP1PH600DU9B03Hf=P1LG5`0
]kNg04=3@`1MGEd0Rh^;09FEU@15ADD0?clo08n?S`2SXj<0GEeM03Ph>02m_Kd0NGUi05QHF02VYZH0
MGEe055AD@2:RXX0DU9B02d];@17AdL0DU9B030`<00f=SH0Kfm_051@D02DU9@0NWYj04a<C02][Jd0
IVIV02l_;`0W9bL0ADE503hn?P2^[Zh0B4Q804=3@`1=CDd0M7Ad06=SH`1UIFD0DU9B04E5A@22PX80
LG5a04];B`1ADE40LW9b05=CD`1nOWh0:BTY06MWI`1bLW80A4A402/[:`1oOgl0EUIF03Ti>@20P800
QXJ607=cL`25QHD0SHf=09>CT`1mOGd0?Shn0<S8b01KFe/0>CTi0080Rh^;02D0IVIV02h^;P1QHF40
PX:204e=C@0l?3`0MgMg05=CD`0n?Sh0ADE504M7A`0l?3`0XJ6Q08^;R`0n?Sh0M7Ad07inOP1jNWX0
>CTi02`/;02CTi<0H61P0451@@0^;Rh0D51@03<c<`0R8R80K6a/0<K6aP17AdL092@T03Hf=P1]KFd0
BTY:02l_;`0R8R80E5AD0080@T9201l0HV9R02`/;00f=SH0[Jf]05ADE00S8b<0DE5A06UYJ@0G5aL0
8b<S0:JVYP2>SXh0EEEE0820P021PH40R8R803hn?P0M7Ad0A4A407emO@1WIfL0=CDe075aL@2;Rh/0
EUIF038b<P0Z:RX08R8R02<S8`0T92@0820P008071`L00`0ATI604U9B@0m?Cd0?3`l09:BTP2l_;`0
f][J0=_Kf`1VIVH0<30`01TI6@0F5QH301DE5@0>01@D501>CTh0PH6104A4A013@d<0@D5102DU9@0L
71`06QXJ059BDP1QHF406a/K02TY:@0C4a<400h>3P1901<C4`1iNGT0HV9R05]KF`32`/80V9RH07al
O00K6a/09bLW01<C4`0e=CD0@D5101DE5@0N7Qh0;Bd]030`<00X:2P0Rh^;05ADE00f=SH0<S8b05]K
F`29RHT0[jn_08f=S@2OWil0[Jf]06MWI`0];Bd0410@00h>3P0O7al0?clo03<c<`0e=CD0Ph>305EE
E@1jNWX0IVIV01hN7P0I6AT061PH018B4P0E5AD0:BTY01hN7P0I6AT05aLG01DE5@0I6AT0OWin09BD
U03Jf]X0Xj>S069RHP1[Jf/0a<C406IVIP17AdL0@T9203Xj>P1/K6`0[Jf]0:2PX01BDU80B4Q804i>
CP1?Cdl0FUYJ04E5A@10@4005ADE01<C4`0201DE5@804a<C00X051@D01DE5@0k>c/0L71`05UIF@2C
Ti<0L71`02LW9`0C4a<05aLG0P0E5AD03P0D51@05ADE01DE5@0G5aL05ADE04E5A@2ATI40Fe]K06AT
I01SHf<0Vi^K0=;BdP32`/80CDe=0P0F5QH09@0G5aL06ATI03@d=018B4P0=cLg01LG5`0K6a/08R8R
04A4A00B4Q80>CTi07EeM@2CTi<0X:2P0;no_`2l_;`0Q8B408:2PP2JVYX0Ph>306a/K01<C4`0BDU9
04e=C@1LG5`0Rh^;0:BTY02l_;`0`<3006e]K@1ADE40@D5101LG5`0D51@03`l?014A4@0@41000P0D
51@0@P0E5AD061PH03De=@16ATH0Shn?0=;BdP3WinL0];Bd08b<S02j^[X0IVIV02LW9`0E5AD05aLG
01lO7`0I6AT05aLG02DU9@2TY:@0<C4a01dM7@0m?Cd0@41002<S8`0Q8B40DU9B05=CD`28R8P0VIVI
071`L00h>3P0Cdm?01hN7P0f=SH07QhN01DE5@0G5aL0:BTY04I6AP0K6a/07AdM02HV9P0c<c<0AdM7
071`L02NWYh0bLW90=SHf03Ti>@0inOW0?3`l03Ti>@0gmoO0=3@d02o_kl0e=CD0=kNgP1oOgl0Bd];
0820P00M7Ad0De=C0<71`@2d];@0Y:BT0492@P805ADE00D07QhN030`<00a<C40D51@05mOG`0206m_
K`06069RHP1OGel0C4a<08j>SP2RXZ80@d=30P0R8R8201`L700L01hN7P0W9bL0=3@d028R8P0Q8B40
>SXj07inOP1ADE40WIfM0:b/[01eMGD0GemO02`/;00e=CD0VYZJ0;Vi^@3Jf]X0]kNg0;Fe]@2i^KT0
Y:BT09^KV`2UYJD0_;bl0;Rh^02UYJD0S8b<05YJFP80DE5A00`0Rh^;0<[:bP2d];@0a<C40<W9b@31
`L40EEEE05YJFP0c<c<0Cdm?0;Fe]@1PH602024Q8@03028R8P0V9RKooooo007ooooo0000Z`31`L40
EEEE09NGU`1nOWh0VYZJ0;fm_@1JFUX0N7Qh09ZJVP2EUID0FUYJ09nOW`2:RXX0JFUY07IfMP13@d<0
Ph>304A4A01TI6@0FEUI0492@P2NWYh0E5AD04=3@`1OGel0De=C03dm?@0k>c/0D51@05]KF`0N7Qh0
A4A403dm?@1OGel0MWIf03lo?`0l?3`0QXJ605IFEP16ATH0?3`l03/k>`10@40092@T06IVIP1IFET0
61PH02/[:`15ADD0<C4a0410@01:BTX08B4Q02h^;P0];Bd0=3@d05]KF`14A4@07QhN05ADE01jNWX0
:2PX05mOG`1YJFT0@41002LW9`1:BTX0FUYJ03Xj>P1oOgl0Ti>C03hn?P0g=cL0>CTi04i>CP0b<S80
=CDe08B4Q01WIfL0>3Ph05YJFP0i>CT09bLW05]KF`0c<c<0NGUi08R8R01EEED0A4A409^KV`2:RXX0
Bd];028R8P1WIfL0A4A402XZ:P1JFUX0M7Ad055AD@0e=CD09BDU06UYJ@1dM7@0De=C02<S8`2DU9@0
G5aL03Lg=`0k>c/0L71`02/[:`1OGel0>c/k05ADE013@d<0GEeM06e]K@0];Bd0DE5A03hn?P0m?Cd0
De=C05ADE01VIVH0CDe=07MgM`0d=3@0E5AD02HV9P0b<S80LW9b05MGE`0h>3P0C4a<04m?C`1HF5P0
MWIf05ADE01fMWH0OWin05YJFP1OGel0KVi^06UYJ@2HV9P0E5AD04m?C`0k>c/0:BTY0<K6aP26QXH0
<S8b03dm?@1mOGd0@d=304E5A@2@T900?clo04I6AP1SHf<0>3Ph03<c<`1YJFT0KFe]03`l?02>SXh0
S8b<04m?C`0h>3P0S8b<0410@00205UIF@0X03lo?`1/K6`0BDU904U9B@2[Zj/0AdM704I6AP1IFET0
VIVI05IFEP19BDT0?Cdm06MWI`2j^[X0J6QX071`L02:RXX0YZJV05ADE01YJFT0bl_;0;Zj^P1dM7@0
=cLg0<_;b`1BDU80QhN70;:b/P1XJ6P0IVIV08R8R01LG5`0;Rh^04E5A@1SHf<0?Cdm04e=C@1ZJVX0
@d=309BDU080G5aL0800ZZZZ04M7A`0`<300<S8b051@D01=CDd0_[jn0451@@0g=cL0QHF50<C4a03?
cll0Ng]k04I6AP18B4P0OWin075aL@10@400D51@07IfMP1GEeL0Q8B4038b<P20P800Fe]K0451@@0X
:2P0SXj>05YJFP1ADE40N7Qh071`L00^;Rh0Kfm_06][J`28R8P0P82003dm?@2e]KD0L71`05UIF@1c
Lg<0L71`05aLG00/;2`0FEUI06i^KP0Q8B40<c<c07QhN01KFe/0?Cdm07EeM@0f=SH0Jf][0<;2`P2:
RXX0ADE506MWI`1kNg/0OWin03<c<`0f=SH0NWYj061PH00l?3`0;bl_0451@@0a<C40?Shn07]kN`3>
c/h0IfMW02HV9P0e=CD0Cdm?05YJFP15ADD0:b/[06e]K@1TI6@0@T9205=CD`0a<C408B4Q08j>SP0Z
:RX06ATI04m?C`1LG5`0>c/k03Ph>02ATI40Shn?04Q8B020P800NWYj07UiN@1<C4`0<S8b065QH@2B
TY80Ng]k03@d=038b<P0PX:207]kN`0f=SH0:BTY01dM7@0P82007alO01dM7@0K6a/071`L03lo?`1S
Hf<0?clo08V9R@35aLD0Z:RX0<C4a02DU9@0^KVi0:NWY`1]KFd0>c/k024Q8@805ADE00H08R8R096A
T@1BDU80EeMG03dm?@19BDT301hN7P04024Q8@0^;Rh0;bl_03@d=0805ADE0`0>3Ph07@0A4A40JVYZ
04Q8B00S8b<0WIfM075aL@1lO7`0=SHf03Xj>P0A4A40=3@d02/[:`0>3Ph04a<C01TI6@0d=3@0FUYJ
0<S8b02BTY80MgMg07EeM@2DU9@0QhN707IfMP2@T900[Jf]0;Jf]P1gMgL09bLW00803@d=00l0BDU9
02TY:@0_;bl0ATI607YjNP0W9bL0EeMG08^;R`1BDU80Cdm?03lo?`0W9bL08b<S05=CD`1<C4`00P11
@D406P0^;Rh0IFEU030`<00a<C40YjNW09bLW012@T80?Cdm05]KF`0P82008B4Q02HV9P0S8b<06ATI
02LW9`13@d<0Xj>S04a<C01=CDd0N7Qh07emO@1JFUX0D51@01XJ6P0E5AD04a<C0`0E5AD02`0D51@0
5ADE024Q8@2VYZH0WIfM06MWI`2TY:@0CTi>020P800L71`05aLG00@05ADE00/06QXJ01lO7`1iNGT0
De=C059BDP1OGel09RHV06ATI02=SHd0Shn?02/[:`0201LG5`0E01PH600];Bd0CTi>04i>CP0I6AT0
5ADE01LG5`0E5AD0@T9202d];@0B4Q804a<C02TY:@1aLG40gmoO0;fm_@3AdM40_;bl05aLG00K6a/0
6ATI00807AdM010092@T02l_;`0`<300JFUY0;Zj^P2m_Kd0FEUI07]kN`1VIVH0D51@01`L700>3Ph0
4a<C018B4P0G5aL0:BTY0P0c<c<0801?Cdl0PX:20;no_`3Bd]80Zj^[06IVIP1JFUX0KFe]05]KF`17
AdL05aLG01HF5P0E5AD05aLG01PH600g=cL0Lg=c01XJ6P0E5AD0;Bd]059BDP0f=SH09RHV051@D01/
K6`0TI6A06UYJ@2CTi<0NGUi030`<00d=3@05aLG0P0E5AD0B00G5aL0DU9B024Q8@0M7Ad06a/K01PH
600L71`06ATI01hN7P1BDU80CDe=0=3@d03WinL0fm_K0>KViP2a/K40[:b/0<O7a`3Lg=`0i>CT0=3@
d00d=3@0>c/k06i^KP1XJ6P0`/;205UIF@0Q8B40EeMG09^KV`1dM7@0;bl_01/K6`0b<S80?3`l055A
D@20P800V9RH03De=@1QHF40GUiN04m?C`1WIfL0YjNW0<W9b@2TY:@0S8b<06a/K00i>CT0:RXZ0451
@@1_Kfl0DU9B05]KF`1OGel0Xj>S09RHV03>c/h0IVIV03Ph>00l?3`0QHF509^KV`27QhL0MWIf0:BT
Y01GEeL0?Shn04a<C01=CDd0BTY:05aLG080^KVi01<0SXj>09JFUP2UYJD0ZZZZ0:f][@3=cLd0TI6A
09BDU02m_Kd0_;bl0:2PX00k>c/0HV9R05ADE010@400SXj>0<71`@1=CDd08b<S00809BDU0_ooool0
000m0;bl_01PH600]kNg06i^KP2=SHd0UIFE055AD@2;Rh/0[jn_08^;R`1QHF40VIVI08N7Q`1aLG40
P82005ADE02UYJD0@T9205YJFP1PH600>SXj09JFUP1NGUh0ADE506EUI@2ATI40JFUY0492@P1EEED0
Fe]K01dM7@1=CDd0De=C06m_K`1YJFT0>3Ph03Xj>P2DU9@0JFUY04U9B@11@D40<C4a04M7A`0S8b<0
Hf=S05YJFP0K6a/0;bl_04M7A`0Z:RX0A4A404i>CP0[:b/0<C4a03/k>`0a<C40BDU903/k>`0R8R80
FUYJ09JFUP0203De=@03061PH00m?Cd08b<S0080BTY:09X09RHV065QH@1kNg/0FEUI03hn?P11@D40
CTi>04Y:BP1>CTh0N7Qh065QH@0l?3`0Fe]K03De=@0b<S80H61P02LW9`1mOGd0QHF5069RHP0[:b/0
E5AD05iNGP1IFET08b<S06a/K01:BTX0=SHf04=3@`1dM7@0BDU902PX:00V9RH0CTi>06ATI018B4P0
8b<S0:JVYP1:BTX0:b/[04Y:BP1[Jf/0;Rh^06=SH`19BDT0JFUY04M7A`1RHV80NWYj02d];@1ADE40
A4A404Y:BP1?Cdl0FEUI05QHF01NGUh0P82003De=@1IFET08b<S0451@@1]KFd0Cdm?03De=@19BDT0
EUIF04Q8B01iNGT0Fe]K08f=S@1UIFD0Fe]K07MgM`1/K6`0P82009BDU01<C4`0Kfm_05IFEP0e=CD0
bLW908b<S00l?3`0@T9208b<S01CDe<0?3`l08b<S00k>c/0AdM706ATI00f=SH0;bl_079bLP1YJFT0
D51@06MWI`1dM7@0BTY:03Ph>02?Shl0ATI608f=S@26QXH0AdM707AdM01=CDd0DE5A0<_;b`1kNg/0
DE5A06UYJ@2FUYH0AdM703Xj>P10@400U9BD0<?3``1LG5`0M7Ad096AT@2EUID0=cLg06UYJ@37alL0
Shn?04a<C00g=cL0a<C405iNGP1HF5P0R8R806IVIP1QHF40NGUi051@D01MGEd0DU9B069RHP13@d<0
F5QH06YZJP14A4@0Y:BT05mOG`1_Kfl0]kNg04i>CP0T92@0EUIF059BDP19BDT0XJ6Q0P0/;2`0D`0m
?Cd0FEUI069RHP1`L700EUIF04];B`1aLG40N7Qh04Q8B01:BTX0ZZZZ0;>c/`22PX80=cLg09bLW01M
GEd0=3@d04i>CP2RXZ80De=C0451@@1RHV80PX:2051@D017AdL0DE5A08V9R@20P800ADE508F5Q@1=
CDd0IFEU08J6QP21PH40Kfm_02/[:`1HF5P0GEeM059BDP0_;bl0HV9R06=SH`0d=3@0EUIF038b<P0k
>c/0WinO0820P00l?3`0FUYJ05mOG`25QHD0>c/k01dM7@1^KVh0L71`0451@@0Y:BT0A4A404e=C@11
@D40SHf=0=3@d01fMWH07alO03@d=01lO7`0MgMg04M7A`0`<300I6AT04I6AP0n?Sh0B4Q802DU9@0_
;bl0VIVI03@d=00R8R80D51@07AdM01]KFd0?Shn0080Rh^;01<0ADE508^;R`1fMWH0Kfm_03Ph>00Q
8B40R8R80;2`/022PX80<C4a0;bl_033`l<0M7Ad05UIF@0g=cL09BDU028R8P0O7al071`L00806a/K
06T0=3@d09^KV`2HV9P0T92@05=CD`0U9BD0?Cdm04A4A018B4P0I6AT08b<S02/[:`0WinO0820P01V
IVH0[:b/08R8R01=CDd0De=C04Q8B00m?Cd08R8R02@T900Q8B403Ph>01@D500a<C40De=C01LG5`0@
41003`l?010@400>3Ph04a<C071`L018B4P06a/K09BDU02d];@0YjNW0;Bd]01NGUh0Cdm?06QXJ01n
OWh0EUIF04Y:BP0l?3`0@d=304i>CP2=SHd0V9RH09nOW`2<S8`0WIfM09ZJVP2DU9@0Xj>S0:BTY01g
MgL0?3`l02@T900?3`l08b<S04U9B@0/;2`0>CTi07AdM013@d<09bLW06MWI`0C4a<04A4A01PH600[
:b/0>CTi04A4A01EEED0LG5a07YjNP3:b/X0^k^k03dm?@0I6AT0:BTY05EEE@2UYJD0VIVI07alO012
@T809RHV028R8P0N7Qh08b<S01dM7@0V9RH0ADE508^;R`1YJFT0H61P06EUI@28R8P0W9bL08F5Q@0M
7Ad00P0C4a<07@0E5AD051@D01DE5@0E5AD06ATI02LW9`39bLT0_[jn08n?S`2n_[h0W9bL08B4Q01Y
JFT0EeMG03Xj>P0e=CD0=3@d03Lg=`11@D40FUYJ0::RXP1MGEd0LG5a09NGU`1YJFT0WIfM07alO01b
LW805aLG00805ADE00@05aLG05EEE@12@T809BDU0P0D51@201DE5@0b028R8P16ATH04A4A010@400C
4a<0?clo0=WIf@2SXj<0Y:BT07moO`0o?cl07QhN028R8P0X:2P0=3@d02l_;`0[:b/0=3@d06YZJP3N
g]h0Kfm_08>3P`1@D500MWIf07=cL`1CDe<0<30`03dm?@0j>SX0<C4a02HV9P0c<c<0IfMW07=cL`1d
M7@0UiNG0=OGe`29RHT0P82008F5Q@1ADE40Rh^;05QHF00S8b<05ADE01LG5`0F5QH06ATI04I6AP0V
9RH201DE5@0<01HF5P0/;2`0Bd];03Hf=P1=CDd0R8R809>CT`2e]KD0O7al0;Jf]P0^;Rh05aLG0P0E
5AD0700K6a/0<c<c075aL@0L71`06ATI01PH600J6QX05aLG01TI6@0M7Ad0;Bd]04A4A02FUYH0d=3@
09>CT`3?cll0LG5a04a<C025QHD0bl_;0;6a/@3EeMD0BDU907=cL`2i^KT0b/[:0451@@0@410201DE
5@0C01lO7`1TI6@0Ph>306=SH`0d=3@092@T02LW9`0h>3P0H61P02@T901NGUh0?3`l05EEE@2FUYH0
`/;206ATI01>CTh0OGem09RHV0020;:b/P0]09NGU`2c/k<0/K6a0;Jf]P2UYJD0f=SH0<c<c02d];@0
>c/k020P8011@D40UYJF09>CT`1/K6`0V9RH071`L00h>3P0CTi>04Y:BP1;Bd/0GemO09:BTP2VYZH0
>3Ph0451@@1@D500E5AD055AD@1XJ6P0UYJF07=cL`18B4P0I6AT09FEU@1kNg/08R8R05]KF`1[Jf/0
Cdm?05]KF`3EeMD0b<S808:2PP0n?Sh0>SXj00;ooooo0000L`2b/[80DU9B0:>SX`1hN7P0UYJF0:f]
[@1DE5@0IVIV0:BTY01nOWh0HF5Q07=cL`16ATH0RHV90820P01CDe<0TY:B04i>CP2<S8`0MWIf04m?
C`2MWId0ATI6069RHP2:RXX0SXj>061PH00o?cl0GUiN05QHF00O7al0GemO05=CD`1SHf<0JVYZ038b
<P0n?Sh0Xj>S05mOG`17AdL0@41002`/;01GEeL0=SHf075aL@0];Bd0;2`/05YJFP1VIVH0<C4a03dm
?@1@D5009BDU04Q8B014A4@0<S8b04I6AP0n?Sh0:2PX08F5Q@2JVYX0<c<c03Hf=P1VIVH0@D51024Q
8@1ADE40GemO030`<01^KVh0O7al05=CD`0o?cl0BTY:06MWI`1SHf<0Cdm?08B4Q01BDU80=SHf05eM
G@14A4@0?3`l06QXJ00N7Qh0LW9b0:BTY01HF5P0;Bd]06m_K`1gMgL0?Shn02d];@2<S8`0De=C03Ti
>@13@d<0Lg=c03dm?@0[:b/09BDU04e=C@1kNg/0De=C02HV9P2DU9@0EeMG038b<P0l?3`0JVYZ02/[
:`1KFe/0=CDe06MWI`0f=SH00P1QHF40lP0X:2P0De=C03/k>`0c<c<0De=C04I6AP1JFUX0FEUI06MW
I`0a<C40D51@03Lg=`0n?Sh0IVIV04E5A@0a<C40BDU906UYJ@1VIVH0NGUi04=3@`1cLg<0KVi^06m_
K`1LG5`0Lg=c07]kN`1[Jf/0Bd];051@D01>CTh0?Shn0<c<c02=SHd0@D5105eMG@2MWId0GUiN03Xj
>P26QXH0C4a<04M7A`1IFET0820P02<S8`1oOgl0Hf=S04];B`1ZJVX0P82003hn?P0h>3P0O7al04A4
A01QHF40LG5a0410@01cLg<0:BTY038b<P2QXJ40MgMg05]KF`1cLg<0Vi^K069RHP0Q8B40DE5A0:j^
[P2j^[X0IfMW08j>SP26QXH0U9BD05ADE02:RXX0dM7A08j>SP1CDe<0A4A40<C4a01`L700NGUi09RH
V01TI6@0GEeM07QhN01DE5@0>CTi07MgM`1_Kfl0ADE505=CD`20P800N7Qh0=GEe@2XZ:P0Jf][0;bl
_01kNg/09RHV04I6AP0j>SX0ADE508f=S@0Z:RX0>c/k04e=C@1`L700NGUi05UIF@0i>CT0@d=3061P
H01LG5`0;bl_034a<@1KFe/0IFEU07inOP0g=cL0S8b<05ADE00i>CT0;Rh^07]kN`0b<S80AdM705IF
EP1^KVh0DU9B04Q8B01>CTh0EEEE05IFEP10@400EeMG03dm?@1/K6`0T92@07AdM01WIfL0;2`/05AD
E01VIVH0IfMW03<c<`1eMGD0IVIV02PX:01?Cdl0FEUI05YJFP35aLD0QHF503Hf=P17AdL0Cdm?08b<
S016ATH09BDU07inOP1UIFD0=cLg02DU9@14A4@0@T9204m?C`2>SXh0bl_;06YZJP0K6a/0<c<c08^;
R`20P800D51@03/k>`1ZJVX0BTY:03Ti>@12@T80<C4a03Ti>@22PX80EeMG03hn?P11@D40Ogmo08:2
PP0h>3P0P82008b<S011@D40Ti>C08f=S@26QXH0@41002XZ:P2HV9P0];Bd07UiN@0a<C40UIFE09^K
V`39bLT0U9BD05UIF@0];Bd08b<S01hN7P0M7Ad071`L02<S8`1UIFD0d=3@06m_K`0];Bd0:2PX02h^
;P0M7Ad071`L04=3@`19BDT0:2PX034a<@0o?cl0L71`0:j^[P3Ng]h0KVi^04M7A`1>CTh0CDe=02h^
;P0];Bd05QHF01<C4`0D51@061PH01hN7P0k>c/0;2`/0P0@4100:P0>3Ph03`l?01LG5`2LW9`0F5QH
01`L702=SHd0h>3P0=kNgP2l_;`0PX:205mOG`12@T80CTi>02PX:00S8b<08B4Q034a<@0R8R80<c<c
05=CD`1ZJVX0LW9b09bLW02/[:`0UIFE08>3P`2EUID0LG5a034a<@0];Bd0:BTY07IfMP1XJ6P0@T92
05EEE@2HV9P09BDU05UIF@0_;bl03Ph>00d=3@<03Ph>03`04Q8B024Q8@0^;Rh0=cLg07EeM@23Ph<0
6a/K01LG5`0g=cL0@d=3075aL@1nOWh0I6AT04Q8B00i>CT0>SXj03`l?00a<C40>SXj038b<P0o?cl0
LG5a07moO`1ZJVX0V9RH08n?S`24Q8@0a<C406UYJ@0g=cL08b<S020P800Q8B409BDU02d];@1LG5`0
Jf][0<o?c`2^[Zh0MGEe0;:b/P2PX:00Xj>S05mOG`27QhL0YjNW09:BTP1RHV80E5AD05YJFP1ZJVX0
Zj^[0:FUY@2;Rh/0WYjN07YjNP2][Jd0^[Zj07MgM`0G5aL201DE5@0504A4A00i>CT0?clo01<C4`0B
4Q800P0E5AD0<P0D51@05aLG03@d=00[:b/08b<S04E5A@1bLW80bLW90=;BdP2TY:@0YJFU06i^KP17
AdL0H61P04E5A@0i>CT0?clo04U9B@1[Jf/0Hf=S07MgM`2b/[80Ti>C08R8R01JFUX0OGem0:NWY`1S
Hf<0;Bd]02h^;P1FEUH0Fe]K04m?C`0g=cL08B4Q05=CD`2<S8`0h^;R09^KV`1jNWX0Ph>3092@T03:
b/X0DE5A03@d=00G5aL06QXJ01TI6@0J6QX0DU9B100E5AD02P0J6QX0=cLg04];B`1=CDd0SHf=09:B
TP2c/k<0D51@07AdM00M7Ad201LG5`04028R8P1@D500O7al05IFEP807AdM01P061PH01/K6`0K6a/0
6a/K028R8P0h>3P0EEEE0;Jf]P22PX807alO08F5Q@2BTY807QhN02TY:@1gMgL0N7Qh0<k>cP31`L40
d];B09VIV@1hN7P08R8R014A4@0D51@201DE5@1101LG5`0U9BD0J6QX09FEU@27QhL0H61P03lo?`1C
De<0EUIF05eMG@0n?Sh0M7Ad08>3P`3GemL0RHV906IVIP1_Kfl0MGEe07UiN@2RXZ80^k^k0<G5a@2g
]kL0L71`05UIF@30`<00c/k>0;:b/P0[:b/07QhN02DU9@12@T80V9RH0<O7a`2PX:00HV9R059BDP0b
<S80C4a<06][J`2MWId0WinO03dm?@1:BTX0@41002PX:00V9RH0:RXZ03<c<`17AdL0S8b<04Y:BP1R
HV80UiNG08>3P`0Q8B40;Rh^05mOG`1bLW80De=C0;Fe]@2RXZ80UYJF0:BTY01NGUh00_ooool0001i
0<K6aP1GEeL0^;Rh07EeM@2e]KD0^KVi05UIF@1lO7`0^[Zj0861P@1]KFd0UiNG07QhN01oOgl0MgMg
075aL@27QhL0>c/k06EUI@1VIVH0Jf][09NGU`16ATH0=SHf06YZJP28R8P0DU9B0451@@1RHV80;bl_
03hn?P2@T900@d=305iNGP1FEUH08R8R04];B`2BTY80D51@03hn?P13@d<0@T9205UIF@0S8b<0CTi>
059BDP0H61P0=CDe03/k>`0[:b/0@D5104I6AP0M7Ad0=SHf02LW9`0k>c/0BDU903De=@0J6QX0Hf=S
07=cL`0T92@0=CDe061PH00^;Rh0=3@d07IfMP1WIfL0<S8b07alO01kNg/0@d=302d];@16ATH0De=C
05EEE@0m?Cd0MWIf05UIF@11@D40I6AT04M7A`1>CTh0IFEU0410@01lO7`0Y:BT05QHF00X:2P0LW9b
06][J`1WIfL092@T075aL@10@400>SXj0410@01hN7P0DE5A02/[:`0/;2`0C4a<07moO`1HF5P0CDe=
08j>SP1<C4`0=cLg04M7A`1_Kfl0<S8b06MWI`19BDT0D51@02d];@1YJFT0KFe]02TY:@0k>c/09RHV
02h^;P0205]KF`3>05QHF01ZJVX0FUYJ030`<01IFET0?3`l0410@01CDe<0=SHf0492@P1[Jf/0M7Ad
065QH@1hN7P0>CTi08F5Q@20P800Kfm_051@D00o?cl0JVYZ065QH@1<C4`0EeMG02/[:`0g=cL0dm?C
07YjNP0d=3@0AdM707inOP11@D40=SHf07inOP17AdL0D51@059BDP0O7al08B4Q09FEU@1[Jf/0C4a<
06EUI@1`L700>CTi03lo?`25QHD0ATI607IfMP1nOWh0?clo071`L018B4P0Bd];0:n_[`1QHF40G5aL
06QXJ02MWId0JFUY05IFEP13@d<0WYjN0:n_[`1OGel0SHf=07=cL`2IVIT0B4Q809BDU03@d=00TI6A
04m?C`1[Jf/0_;bl06m_K`27QhL0Shn?04m?C`1DE5@0LW9b04Q8B00d=3@0A4A405=CD`0Z:RX0@410
0451@@1<C4`0[:b/07IfMP1JFUX0ZJVY05mOG`0c<c<0DU9B05ADE01BDU80S8b<04I6AP18B4P0F5QH
07EeM@24Q8@0J6QX0451@@16ATH0FUYJ05EEE@0o?cl0@41007emO@21PH40Jf][02LW9`21PH40ADE5
04A4A010@400TY:B04E5A@1<C4`0GEeM08J6QP0l?3`0CTi>04Y:BP1=CDd0EEEE05YJFP18B4P0A4A4
06i^KP2XZ:P0Ogmo05iNGP0S8b<0@d=305ADE017AdL0;Bd]06YZJP14A4@092@T05]KF`1PH600Fe]K
0<;2`P2MWId0@410038b<P0a<C40Q8B404E5A@0W9bL0NWYj06=SH`0d=3@0:BTY04Q8B014A4@0D51@
08F5Q@39bLT0L71`02@T9017AdL0SHf=08>3P`1GEeL0BTY:079bLP1[Jf/0@d=305ADE01IFET0AdM7
08F5Q@1LG5`0>c/k04m?C`2ATI40M7Ad03Xj>P23Ph<0MWIf03Ph>022PX80QHF507moO`1[Jf/0BTY:
0:NWY`2f][H0?clo02PX:02CTi<0H61P0;>c/`2a/K40TI6A04Q8B00c<c<09BDU02`/;01:BTX2071`
L00E09jNWP1iNGT0:b/[02DU9@0];Bd09RHV01/K6`0J6QX0De=C03/k>`0W9bL08b<S024Q8@0m?Cd0
`L710::RXP1;Bd/0E5AD05UIF@0e=CD08B4Q00<05ADE01L07alO02LW9`0];Bd05aLG02/[:`0E5AD0
51@D01PH601NGUh0c/k>0:6QX@1>CTh0aLG50=[JfP2_[jl0ADE5018B4P0D51@06ATI02TY:@0C4a<0
410@00X:2P0300d=3@0G04M7A`1ADE40XZ:R0861P@1CDe<0PH6109VIV@1DE5@0@d=307moO`1_Kfl0
M7Ad09:BTP30`<00YjNW0<O7a`33`l<0PX:20:n_[`0V9RH0410@00h>3P0@41000`0>3Ph0300E5AD0
<C4a028R8P0/;2`0OGem02LW9`0F5QH0ATI603Ph>00k>c/071`L024Q8@<03Ph>03@04a<C014A4@0A
4A404A4A01<C4`14A4@0PX:203lo?`13@d<0Rh^;0;jn_P38b<P0VIVI04];B`17AdL0BTY:05UIF@1F
EUH0E5AD05EEE@1HF5P0/K6a09:BTP1eMGD0X:2P0<;2`P2k^k/0WinO07moO`1iNGT0TY:B05UIF@12
@T80@D5104Q8B02_[jl0/[:b08F5Q@2TY:@0Ng]k05eMG@2^[Zh0R8R8065QH@0S8b<0:RXZ04Q8B016
ATH06a/K01DE5@0C4a<051@D0`0E5AD02P0O7al0H61P04A4A00_;bl0<S8b0<71`@3WinL0Ti>C0:FU
Y@1gMgL204U9B@0:08>3P`24Q8@0K6a/05ADE00e=CD0Bd];06ATI03>c/h0Ogmo06YZJP80OWin00H0
WinO09FEU@1mOGd0JFUY03@d=00K6a/201DE5@0W01PH601iNGT0][Jf0>OWi`2o_kl0`<300=?Cd`3P
h>00i>CT0;Ng]`1@D5005aLG01DE5@0G5aL0<S8b03De=@0C4a<05ADE01HF5P0E5AD06ATI01hN7P1U
IFD0L71`07QhN02_[jl0[Jf]06][J`1cLg<0<C4a03@d=01?Cdl0CDe=03@d=00Q8B40=3@d02DU9@0L
71`06ATI00<071`L00`0@D5104E5A@28R8P0PX:205=CD`0N7Qh0=cLg0<71`@0c<c<0:BTY05eMG@2N
WYh20>3Ph00706i^KP0b<S80G5aL03De=@0C4a<04A4A01<C4`0201DE5@0D01TI6@0Q8B40<30`061P
H02HV9P0[:b/08n?S`2l_;`0NGUi05EEE@1PH600WIfM07QhN03:b/X0fm_K0<g=c@2c/k<0T92@08:2
PP1oOgl206=SH`0H05YJFP2GUiL0^[Zj0=WIf@3Bd]80UYJF08R8R025QHD0RXZ:0<C4a03GemL0/[:b
09RHV00_;bl0=CDe04Q8B01iNGT0Shn?0492@P0d=3@0<S8b02LW9`0Z:RX0;Rh^0P0`<300400m?Cd0
M7Ad04A4A01RHV80ZZZZ08>3P`0];Bd0?clo06m_K`1[Jf/0Q8B40:b/[02:RXX0?clo075aL@2d];@2
ooooo`000;T0[Zj^06MWI`34a<@0DU9B0861P@2SXj<0HF5Q08b<S02CTi<0A4A4071`L02IVIT0GUiN
07inOP1FEUH0NGUi0:BTY01:BTX0Jf][05iNGP1VIVH0YjNW06EUI@16ATH0L71`07alO01?Cdl0F5QH
07moO`1ADE4092@T04e=C@0`<300MgMg05aLG00U9BD0>SXj096AT@0k>c/0Bd];051@D011@D40BDU9
01/K6`1<C4`0E5AD01`L700l?3`0BTY:02TY:@17AdL0ATI601dM7@0k>c/09BDU03De=@1DE5@0;Bd]
01TI6@1[Jf/0J6QX02<S8`0e=CD0DE5A0492@P0M7Ad0G5aL06ATI00_;bl0P82007IfMP0o?cl0:2PX
03dm?@14A4@0D51@0410@01hN7P0CTi>0451@@1/K6`0=cLg03<c<`1WIfL0<c<c07QhN02IVIT0HF5Q
02h^;P1dM7@0IfMW059BDP0V9RH0N7Qh04I6AP0l?3`0De=C07emO@0n?Sh09BDU03Xj>P1EEED0Ph>3
04I6AP13@d<0IfMW055AD@0o?cl0De=C06MWI`1:BTX0P82004U9B@1EEED0AdM708B4Q023Ph<0:RXZ
04];B`0m?Cd0;Rh^04e=C@1SHf<0C4a<071`L01CDe<0<30`05ADE019BDT0@d=305aLG00i>CT0=3@d
04=3@`1UIFD0DU9B07YjNP18B4P0EeMG07IfMP1QHF40FEUI06e]K@0n?Sh0Lg=c04m?C`1EEED0?Cdm
04Y:BP3AdM40PH6103dm?@1<C4`0Ogmo04m?C`0a<C40RHV905eMG@1@D500FEUI03lo?`0b<S80b/[:
06][J`1GEeL0CTi>06=SH`0i>CT0GemO08n?S`14A4@0OGem05YJFP11@D40PH6105iNGP1;Bd/0Z:RX
065QH@0g=cL0P8200<S8b01[Jf/0D51@04I6AP020::RXP0e061PH029RHT0WIfM0861P@1EEED0X:2P
0<o?c`2IVIT0>CTi06ATI02e]KD0<C4a07inOP2a/K40AdM705=CD`26QXH0@D510410@01EEED0DE5A
024Q8@0/;2`0GemO055AD@2ZZZX0FEUI04e=C@2PX:00@D5102<S8`1<C4`0B4Q80410@01mOGd0<c<c
03Xj>P1/K6`0L71`07YjNP1DE5@0Cdm?04Q8B01KFe/0FUYJ04Q8B01>CTh0TY:B075aL@1XJ6P0<C4a
07AdM01=CDd00P19BDT0G`27QhL0>CTi03dm?@1FEUH0RHV903Ti>@19BDT0CTi>05EEE@11@D40H61P
03lo?`0f=SH0Jf][0;Rh^01iNGT0CTi>02DU9@1NGUh0EUIF04e=C@0`<300EEEE02d];@0Z:RX0?Cdm
04a<C01EEED0b<S809^KV`15ADD0@T9202TY:@1`L700>CTi02DU9@25QHD0DE5A02`/;00l?3`0GEeM
02h^;P0n?Sh0Lg=c0;fm_@1>CTh06ATI0451@@1KFe/0CDe=03Ti>@1NGUh0MGEe05iNGP1mOGd0R8R8
059BDP11@D40TY:B04m?C`0f=SH0N7Qh0:ZZZP1mOGd0@d=309^KV`2?Shl0?clo07]kN`1`L700TI6A
07AdM01MGEd0^KVi0;fm_@22PX80>CTi075aL@1WIfL0SHf=0=_Kf`2TY:@0_Kfm08V9R@1nOWh0IfMW
04U9B@0T92@05aLG01lO7`1WIfL0KVi^02l_;`0U9BD0;Rh^00805aLG00`0=cLg04M7A`0f=SH0<c<c
02h^;P0Y:BT0QXJ60<_;b`2;Rh/0Fe]K07]kN`0N7Qh201DE5@803Ph>02405ADE02DU9@16ATH0?Cdm
08N7Q`1fMWH0B4Q8059BDP1DE5@0NWYj09VIV@2i^KT0_kno09fMW@1aLG404Q8B014A4@0B4Q806ATI
04Q8B00O7al04A4A00d=3@0>3Ph03@d=00l?3`0a<C40;Bd]05aLG02b/[80JFUY05UIF@1MGEd00P0l
?3`03@2JVYX0LW9b055AD@17AdL0ADE50::RXP2IVIT0[Zj^0;2`/01FEUH0EEEE03`l?00F5QH00P0>
3Ph03P0=3@d03Ph>01<C4`10@400;2`/02/[:`1bLW80>c/k01LG5`1NGUh0BDU902/[:`0I6AT092@T
0P0=3@d03`0>3Ph0410@00h>3P0>3Ph03@d=00`<300N7Qh0<C4a08:2PP13@d<0F5QH0;fm_@3:b/X0
^;Rh07alO00206UYJ@0S071`L01QHF40NGUi065QH@1eMGD0?Cdm03De=@0l?3`0O7al06a/K01SHf<0
O7al09^KV`2VYZH0[Zj^0:FUY@28R8P0IfMW04m?C`1KFe/0PH6105YJFP2=SHd0/K6a04E5A@2[Zj/0
Ti>C0:j^[P2d];@0PX:205EEE@0U9BD03Ph>014A4@0>3Ph00P0@41007P0D51@04a<C01DE5@1FEUH0
92@T02XZ:P0b<S80clo?0>;RhP3Jf]X0cLg=0;jn_P2XZ:P0TI6A07AdM01BDU80CTi>05QHF010@400
;Rh^03hn?P3Cdm<0];Bd03Lg=`1EEED0`l?30:VYZ@3AdM40;Bd]01HF5P805ADE01805aLG01TI6@0T
92@0LW9b0=GEe@2k^k/0B4Q808Z:RP2XZ:P0PH6109^KV`2QXJ40^;Rh03Ph>00H61P07AdM06e]K@0N
7Qh201DE5@0Z01LG5`0E5AD05ADE02TY:@0a<C40Q8B406a/K030`<00/[:b09:BTP1nOWh0KVi^05UI
F@0j>SX09RHV01hN7P0L71`07alO04E5A@0R8R806QXJ01`L700O7al0;Bd]04];B`1nOWh0GemO0820
P00X:2P07QhN02@T901jNWX0XJ6Q051@D02n_[h0h>3P0=[JfP3:b/X07QhN024Q8@1>CTh0Cdm?0P0E
5AD0=00C4a<05ADE01DE5@0G5aL07AdM01lO7`0P8200=CDe06QXJ02RXZ80e=CD0;Ng]`2FUYH0_Kfm
0=[JfP2][Jd0dM7A0=3@d02@T900G5aL03lo?`10@400MWIf0;no_`3Bd]80alO70<G5a@2f][H0^k^k
0>CTi03Ph>00]KFe0861P@2MWId0bl_;0=GEe@39bLT0HV9R02HV9P0l?3`0LG5a09nOW`0b<S8071`L
01dM7@0[:b/0<S8b02h^;P0W9bL0;bl_030`<00l?3`205QHF00306YZJP2d];@0MWIf0080=cLg00P0
TI6A0:BTY02h^;P0/[:b0<W9b@20P800R8R80;Jf]P;ooooo0000^@2KVi/0EUIF0;2`/01RHV80QHF5
06=SH`1XJ6P0Y:BT0;Fe]@1UIFD0L71`07EeM@1:BTX0UiNG06a/K01]KFd0LW9b05YJFP21PH40DU9B
07]kN`2QXJ40KVi^04E5A@1jNWX0IFEU03Hf=P0j>SX0IfMW04U9B@0n?Sh0HF5Q02LW9`1?Cdl0DU9B
02/[:`1CDe<0XZ:R02d];@0d=3@0ATI603<c<`17AdL06a/K055AD@0o?cl0<C4a06ATI01LG5`092@T
05YJFP1MGEd0:RXZ05UIF@0e=CD0@T9206YZJP15ADD07alO07QhN01TI6@09RHV055AD@1MGEd0?Shn
01dM7@1OGel0BDU902d];@2DU9@0S8b<03@d=00V9RH0>CTi03/k>`0m?Cd0>SXj08J6QP1CDe<0ADE5
05UIF@0W9bL0>CTi06a/K00h>3P0L71`09bLW018B4P0>c/k09RHV01kNg/0;bl_02<S8`25QHD0;Rh^
03<c<`16ATH0JFUY028R8P0M7Ad0?clo05iNGP2EUID0De=C06a/K02OWil0?3`l03De=@20P800K6a/
03Hf=P1OGel0?clo07alO00k>c/0JFUY05YJFP0/;2`0Cdm?04U9B@1=CDd0FEUI04E5A@0m?Cd0OGem
061PH00W9bL0GEeM028R8P1ADE40LG5a04m?C`0a<C40>3Ph03De=@12@T80TI6A05EEE@1XJ6P0HF5Q
059BDP1KFe/0Jf][02/[:`1XJ6P0@D5105=CD`13@d<0AdM70=?Cd`1`L700>CTi04i>CP27QhL0E5AD
05QHF02QXJ40DE5A05QHF01TI6@0:b/[034a<@3<c<`0KFe]04U9B@2;Rh/0SXj>03Hf=P11@D40MGEe
03dm?@29RHT0EUIF03Hf=P1kNg/0<30`0451@@2g]kL0L71`03/k>`15ADD0KFe]04i>CP0b<S80EeMG
0080^[Zj08l0CDe=065QH@1dM7@0?Shn03Ti>@23Ph<0`l?308Z:RP10@400NWYj0;Rh^01UIFD0GemO
07moO`1JFUX0Bd];06i^KP0h>3P0CTi>07emO@1EEED09BDU04I6AP1WIfL0GEeM0<71`@1VIVH0C4a<
0:^[Z`1HF5P08B4Q069RHP15ADD0:BTY05YJFP0];Bd0=CDe06i^KP1jNWX0SHf=04m?C`0R8R80ADE5
07IfMP1TI6@0?clo04Y:BP2;Rh/0L71`07]kN`0f=SH0YJFU08N7Q`1EEED0@d=309BDU01ADE40=SHf
08N7Q`2ATI40>3Ph061PH01gMgL0?Shn02<S8`0m?Cd0<C4a03De=@1FEUH0a<C408Z:RP0h>3P0<c<c
08B4Q01[Jf/0I6AT030`<01ZJVX0?clo03`l?00n?Sh0@41005EEE@37alL0R8R803Ph>029RHT0NWYj
06=SH`0Z:RX0:BTY08n?S`0k>c/06a/K02LW9`1HF5P071`L02l_;`24Q8@0^[Zj06][J`0g=cL0FUYJ
06m_K`0X:2P08R8R04m?C`1[Jf/0?Cdm04E5A@1CDe<09BDU03`l?02HV9P0CDe=02@T901dM7@0Ogmo
034a<@17AdL0`L7109fMW@15ADD0SXj>07MgM`27QhL0FEUI03De=@36a/H0_;bl08N7Q`0j>SX0G5aL
079bLP1DE5@0Rh^;0=gMg@3Ng]h0fMWI07QhN00X:2P071`L01HF5P0201DE5@0:01/K6`1LG5`0H61P
038b<P0X:2P09RHV01DE5@0G5aL0ADE502/[:`809bLW00H0:2PX04Y:BP2g]kL0c/k>0:>SX`1[Jf/4
01DE5@0B01dM7@0K6a/07alO03`l?00M7Ad0<30`08J6QP2c/k<0MGEe0492@P0T92@0J6QX0<_;b`2l
_;`0Q8B4069RHP0e=CD0>CTi0P0o?cl0;P1UIFD0Fe]K04Q8B00f=SH09BDU01XJ6P17AdL0<C4a02<S
8`0V9RH0WYjN0:^[Z`2_[jl092@T02XZ:P1HF5P0NGUi03/k>`1lO7`0Lg=c08j>SP2FUYH0Rh^;0820
P028R8P0MGEe02XZ:P0e=CD0CDe=03Hf=P0H61P0410@014A4@0E5AD06QXJ04=3@`0l?3`0Q8B405EE
E@0J6QX0LW9b05MGE`0L71`08B4Q02HV9P0>3Ph2010@401M00h>3P0@41003Ph>00d=3@0>3Ph0:RXZ
04I6AP2e]KD0Ng]k07EeM@39bLT0dM7A0<;2`P2RXZ80QXJ609fMW@2f][H0G5aL061PH01RHV80>SXj
02@T900];Bd0Kfm_08F5Q@0U9BD0A4A4059BDP1GEeL0PX:208n?S`1JFUX0KVi^06YZJP0^;Rh0AdM7
0:6QX@2@T900a<C40=;BdP2<S8`0^KVi0:BTY02^[Zh0dM7A0;Vi^@1RHV804a<C010@400D51@05ADE
01<C4`0D51@04a<C01@D500/;2`0?3`l02@T900o?cl0JVYZ0=WIf@3Fe]H0]KFe08F5Q@3>c/h0RXZ:
04a<C01oOgl0QhN704A4A00i>CT0FUYJ061PH01^KVh0>c/k0492@P2>SXh0KVi^09BDU02FUYH0H61P
07EeM@0U9BD07AdM01`L700K6a/0;2`/05YJFP2IVIT0_Kfm0=_Kf`2a/K40H61P0080J6QX02L0D51@
065QH@2?Shl0ZJVY03lo?`1nOWh0_kno02<S8`0E5AD05QHF01dM7@0H61P05ADE02/[:`0X:2P0@410
069RHP2RXZ80UYJF0410@01=CDd0Cdm?02@T900M7Ad05aLG01XJ6P0H61P07AdM08:2PP1NGUh0>SXj
0492@P1LG5`0EeMG08^;R`1OGel0A4A405]KF`0K6a/00P0L71`03@0o?cl0dm?C0=_Kf`2WYjL0UiNG
07=cL`2FUYH0;2`/01TI6@11@D40HV9R01HF5P0D51@00`0E5AD08@0C4a<05aLG01dM7@0T92@09BDU
03`l?01eMGD0Vi^K0<71`@28R8P0UiNG0<?3``1eMGD0EEEE03lo?`1RHV80QXJ605ADE00h>3P0@d=3
05iNGP3Cdm<0f][J08V9R@14A4@0SHf=0;Zj^P2RXZ80a/K609^KV`38b<P0c<c<0=SHf0020<71`@04
07moO`1RHV80WYjN03Ph>08071`L00D08B4Q02h^;P0`<3009BDU02@T900202/[:`0@0492@P1IFET0
QhN706i^KP2XZ:P0IVIV05UIF@0`<300IfMW0;2`/02UYJD0bLW90>3Ph03IfMT0b/[:0=?Cd`;ooooo
0000N02i^KT0GUiN0<C4a01PH600Rh^;09BDU01EEED0FEUI0:BTY01IFET0PX:206UYJ@0[:b/0Kfm_
06EUI@1mOGd0A4A403dm?@1`L700@D5107MgM`1OGel0G5aL06m_K`2NWYh0UIFE04A4A013@d<0H61P
01`L7013@d<0OWin0451@@1QHF40@T9201TI6@1EEED0Rh^;03@d=01:BTX0D51@02DU9@19BDT09RHV
05EEE@0T92@05aLG03Hf=P12@T80:2PX0451@@1=CDd05QHF04];B`0l?3`0;bl_03lo?`0O7al06ATI
06i^KP1cLg<09RHV03@d=01FEUH0>c/k02/[:`1eMGD0Bd];01PH601<C4`0JFUY05ADE00e=CD0?Shn
04e=C@0m?Cd0<c<c061PH018B4P0>c/k06][J`0o?cl0>c/k069RHP0^;Rh0Rh^;0:FUY@19BDT09bLW
05YJFP1?Cdl08B4Q02d];@28R8P0Bd];03lo?`11@D40OGem02/[:`0K6a/0=CDe04a<C01PH600ADE5
09bLW037alL0J6QX0451@@1dM7@0Hf=S03`l?01<C4`0<c<c06a/K010@400MGEe0492@P0K6a/0Cdm?
0410@080E5AD01<0?Cdm02l_;`1SHf<0DU9B02h^;P1>CTh071`L03lo?`1IFET0?clo02LW9`0`<300
;bl_03Ph>01`L700@T9205QHF01;Bd/0>3Ph0080IfMW0;/09bLW05iNGP0Q8B40Jf][05ADE013@d<0
dm?C07=cL`0];Bd0PH610::RXP15ADD0=cLg06YZJP0N7Qh0D51@079bLP19BDT0A4A40=CDe01GEeL0
;Rh^05YJFP25QHD0>c/k04A4A01PH600;bl_07UiN@1PH600?Cdm0861P@0d=3@0?Cdm07AdM01BDU80
BTY:065QH@2VYZH0EEEE034a<@0i>CT0OGem0:NWY`1TI6@0PX:207QhN02;Rh/0D51@08j>SP39bLT0
PX:203Ti>@2RXZ80_[jn05YJFP1HF5P0QhN705YJFP2KVi/0ZZZZ05eMG@0[:b/0?3`l06EUI@0I6AT0
>c/k0451@@1GEeL0];Bd07YjNP1=CDd0[Zj^05eMG@0I6AT0E5AD04e=C@0_;bl0@T9202h^;P0O7al0
FEUI08>3P`2KVi/0F5QH03Xj>P13@d<0CDe=04Y:BP0O7al0CDe=0:f][@2NWYh0D51@024Q8@1KFe/0
EEEE03lo?`1EEED0ZJVY0492@P0W9bL0IVIV07YjNP0N7Qh0De=C06IVIP1HF5P0?clo05IFEP0T92@0
=CDe05ADE02EUID0PH6105]KF`0Y:BT0C4a<06=SH`0Y:BT0;2`/06IVIP0h>3P0=3@d05iNGP14A4@0
HF5Q0=3@d028R8P0;bl_051@D01BDU80BDU901hN7P0f=SH0WIfM05QHF00`<300De=C08B4Q01ADE40
>c/k06=SH`2l_;`0?Cdm020P801VIVH0H61P05ADE00l?3`0Hf=S05ADE00j>SX0@T9205UIF@0Q8B40
=3@d07UiN@0Z:RX0:b/[0:6QX@27QhL0BDU904Y:BP31`L40Ph>305]KF`3Bd]80_Kfm08N7Q`0T92@0
5aLG09bLW02/[:`0NWYj03Lg=`1MGEd0N7Qh069RHP1VIVH0dM7A0=cLg034a<@0>SXj020P800I6AT0
5QHF00<05ADE018061PH055AD@1ZJVX0?Cdm034a<@0L71`06ATI02TY:@1:BTX05aLG01PH600I6AT0
:BTY096AT@2?Shl0];Bd05EEE@0I6AT301DE5@12028R8P1:BTX0>c/k06][J`15ADD0?Cdm03Lg=`1K
Fe/0/;2`0;Zj^P2?Shl0a/K6065QH@2SXj<0`<3007QhN00i>CT09BDU02@T900R8R805ADE018B4P0J
6QX0:RXZ03lo?`1YJFT0OGem03Hf=P0G5aL07AdM07emO@3Ogml0c<c<05IFEP0X:2P0>CTi05QHF00l
?3`0ZZZZ0;Ng]`2FUYH0D51@01<C4`0U9BD0EeMG06=SH`1iNGT0;Bd]020P800d=3@0EEEE03Hf=P0I
6AT04a<C01DE5@0S8b<0H61P0;Fe]@2BTY80CDe=0:^[Z`2GUiL0;Bd]02@T900C4a<0410@0P0>3Ph2
01<C4`1801DE5@0>3Ph03`l?04A4A01NGUh0Zj^[0;bl_01TI6@0MgMg09>CT`25QHD0S8b<02/[:`16
ATH0Ti>C0:NWY`1cLg<0KVi^08Z:RP2@T900^;Rh0=cLg01eMGD051@D01<C4`0Q8B40>SXj04i>CP1G
EeL0LW9b03Xj>P1NGUh0SXj>09>CT`2n_[h0b<S80=GEe@33`l<0VIVI0:JVYP28R8P0^;Rh0<[:bP31
`L40N7Qh01<C4`0@41004A4A01<C4`0D51@04a<C014A4@0U9BD0@41003<c<`16ATH0KVi^06MWI`1^
KVh0WIfM0861P@2BTY80Shn?0:n_[`2OWil0J6QX06i^KP1fMWH0B4Q8024Q8@0G5aL06QXJ0P0E5AD0
B`0/;2`0YJFU0<71`@2m_Kd0N7Qh08B4Q01^KVh0:b/[03Ti>@1<C4`0PH610;Zj^P2OWil0bLW908j>
SP2WYjL0aLG508n?S`1cLg<0JFUY069RHP1GEeL0/k>c0=gMg@2UYJD0^[Zj09FEU@0c<c<06ATI01dM
7@0Q8B407QhN01dM7@0Q8B40>SXj06i^KP2PX:00ADE502DU9@0g=cL0:RXZ03@d=00Q8B4061PH01LG
5`0O7al0;bl_04m?C`0h>3P0<c<c0451@@1BDU80TY:B07EeM@1CDe<0HF5Q05YJFP0L71`07AdM020P
8016ATH0^k^k06ATI00m?Cd0CTi>07inOP2@T900EUIF01LG5`0^;Rh0Hf=S024Q8@0E5AD04a<C01DE
5@0201<C4`0U01PH600M7Ad08R8R02DU9@0m?Cd0_Kfm0:^[Z`2CTi<0FUYJ08Z:RP1YJFT07AdM02l_
;`0^;Rh0:BTY03Ph>02@T900TY:B05YJFP2OWil0b<S80<[:bP17AdL0BTY:09RHV015ADD0@d=306IV
IP1hN7P0/k>c0=GEe@3Rh^80/;2`0<;2`P3=cLd0c/k>06a/K00201`L700H01dM7@0[:b/0;Bd]02TY
:@0T92@09BDU02LW9`0Y:BT0@d=306i^KP1WIfL0Kfm_08V9R@1YJFT0=3@d04Y:BP1QHF40TY:B08n?
S`3Cdm<0f][J0:NWY`1jNWX0L71`0_ooool0003o0<G5a@1PH600/[:b07emO@32`/80YZJV06QXJ01J
FUX0Y:BT06e]K@2b/[80`l?306IVIP1lO7`0H61P07emO@2>SXh0EEEE07YjNP10@400QXJ606IVIP10
@400>3Ph07alO02:RXX0?Shn03Lg=`1`L700CTi>03lo?`1hN7P0Bd];05eMG@0h>3P07alO04E5A@1o
Ogl0:BTY05YJFP1KFe/0?clo04I6AP0I6AT0BTY:04Q8B00O7al0<C4a04M7A`0Y:BT0ADE504];B`0S
8b<0AdM703Xj>P0];Bd0E5AD04=3@`0G5aL0Lg=c06EUI@0G5aL0ADE503Hf=P0J6QX0<c<c07MgM`1]
KFd0:b/[08J6QP24Q8@0=CDe02TY:@1<C4`0KFe]06QXJ00o?cl0L71`0410@00O7al0A4A404i>CP0o
?cl0MGEe02LW9`1?Cdl0Vi^K06ATI00`<300NGUi06m_K`11@D4092@T06i^KP10@400C4a<06][J`22
PX80NGUi02l_;`12@T80ATI606ATI011@D40H61P07AdM01?Cdl0B4Q806=SH`1RHV80OWin061PH013
@d<0GEeM03`l?01nOWh0DE5A01lO7`11@D40=SHf05ADE01KFe/0DU9B04m?C`1[Jf/0Cdm?03De=@1B
DU80<c<c05=CD`1/K6`0ADE503Hf=P19BDT0@T92051@D01fMWH0ATI60:FUY@1mOGd0BTY:069RHP1J
FUX0@d=305QHF00a<C40CTi>03Hf=P0m?Cd0e=CD06m_K`0W9bL0D51@092@T01:BTX0?3`l08B4Q00j
>SX0Kfm_05iNGP0W9bL0NWYj0;Fe]@1iNGT0EeMG04M7A`1gMgL0B4Q8079bLP21PH40A4A4075aL@1X
J6P0BTY:09>CT`1NGUh0FUYJ08F5Q@1mOGd0IFEU05]KF`2h^;P0MgMg06a/K01BDU80S8b<0:NWY`1`
L700X:2P09nOW`2JVYX0EEEE096AT@2i^KT0RHV904a<C02][Jd0/[:b06EUI@1IFET0RHV904M7A`1L
G5`0U9BD05aLG012@T80E5AD05]KF`0K6a/0?3`l05MGE`1IFET0WYjN07inOP1?Cdl0Zj^[06m_K`0]
;Bd0I6AT04i>CP0];Bd0<30`04A4A00b<S80EeMG05QHF01]KFd0EeMG03Ph>01?Cdl0BDU904Y:BP0Z
:RX0>CTi05]KF`24Q8@0I6AT03dm?@1QHF40DU9B01hN7P1;Bd/0QXJ605ADE00h>3P0JFUY08R8R00k
>c/0Cdm?055AD@1RHV80ATI6069RHP0f=SH0JVYZ000L06UYJ@2CTi<0S8b<04=3@`1;Bd/0_Kfm07Ui
N@14A4@07AdM061PH01HF5P0;bl_0861P@0E5AD0ATI60:b/[02>SXh0BTY:06][J`2@T900NGUi03Ph
>00Y:BT0T92@03hn?P0H61P0A4A407=cL`80<C4a0100H61P0;Vi^@1OGel08R8R03hn?P1NGUh0Cdm?
03Hf=P1bLW80C4a<01dM7@1]KFd0Ogmo04Y:BP0k>c/0MWIf0P0L71`0B01kNg/0NWYj059BDP1YJFT0
cLg=06ATI00Z:RX0Ogmo0:2PX02:RXX0?clo01LG5`1eMGD0WIfM08:2PP0f=SH0GEeM08Z:RP1MGEd0
];Bd0=kNgP3MgMd0dm?C09VIV@13@d<06a/K01XJ6P0G5aL071`L02<S8`0_;bl09BDU04U9B@1YJFT0
@T9202/[:`0N7Qh071`L05YJFP0a<C4061PH01DE5@0Y:BT0QhN703/k>`2c/k<0SHf=02d];@0a<C40
>c/k0492@P1YJFT0TI6A09ZJVP2/[:`0UIFE05ADE018B4P0?Cdm03Hf=P1MGEd0eMGE0;fm_@1>CTh0
JVYZ0:>SX`2CTi<0K6a/02LW9`0J6QX06ATI01HF5P804Q8B02/061PH01DE5@0H61P0GemO03Hf=P0L
71`0@T920;fm_@3Ti>@0dm?C08^;R`1HF5P0FEUI09jNWP2CTi<0T92@0<_;b`0n?Sh0:2PX01XJ6P0E
5AD03@d=02l_;`1MGEd0RHV903lo?`0O7al0:b/[05QHF01^KVh0>3Ph01lO7`1<C4`0[Zj^0<_;b`2m
_Kd0c/k>0=WIf@32`/80OGem03Lg=`0@41003Ph>00<0410@0300=cLg05QHF00F5QH04a<C01`L702G
UiL0ZZZZ0=cLg030`<00TI6A08j>SP2PX:00];Bd07moO`2YZJT0[Zj^0<;2`P2f][H0/[:b08n?S`1W
IfL0IVIV0=;BdP1eMGD07alO01XJ6P0C4a<05ADE020P8013@d<0I6AT07moO`1MGEd0Hf=S0:NWY`32
`/80h>3P0;>c/`11@D405QHF01XJ6P0/;2`0QXJ60:VYZ@35aLD0XZ:R0451@@0C4a<2014A4@0E01<C
4`0B4Q805QHF03dm?@0[:b/0DE5A06UYJ@0`<3006QXJ01PH601>CTh0IfMW06e]K@2l_;`0dm?C0;jn
_P2j^[X0[jn_03Ph>00S8b<07QhN008071`L02d06ATI01dM7@0N7Qh0OGem0:f][@2m_Kd0ZJVY07Ui
N@35aLD0K6a/06][J`1_Kfl0Shn?0::RXP3:b/X0Xj>S055AD@0O7al0@D5109VIV@3<c<`0[jn_0:^[
Z`2i^KT0c<c<0>3Ph03<c<`0DE5A05UIF@29RHT0KFe]038b<P0S8b<0?Cdm02h^;P0W9bL0?3`l07al
O02GUiL0@41001hN7P0d=3@08B4Q04a<C00N7Qh00P0G5aL0@P0R8R80ADE502LW9`0Q8B409bLW04a<
C023Ph<0NGUi05YJFP2ATI40RXZ:06e]K@0L71`07QhN02DU9@1?Cdl0WIfM02TY:@14A4@0HF5Q08R8
R01bLW80Ti>C01/K6`0P8200H61P03Hf=P0E5AD04a<C01DE5@0D51@05QHF01/K6`0O7al08R8R02/[
:`1:BTX0YjNW07moO`2HV9P0LG5a0;>c/`17AdL092@T02h^;P13@d<0@D5103Ph>00V9RH0Ng]k0<K6
aP32`/80XJ6Q09>CT`28R8P0UIFE04M7A`0k>c/0A4A4059BDP1jNWX0U9BD0=GEe@2l_;`0NGUi0:b/
[080dm?C00T0@D5101`L700M7Ad0820P02LW9`0U9BD09bLW02/[:`0V9RH00P0X:2P04011@D40Jf][
065QH@0f=SH0OGem07moO`0^;Rh0[jn_0:BTY02a/K40cLg=0<G5a@2?Shl0IFEU06UYJ@1@D502oooo
o`0002T0T92@05YJFP2;Rh/0DU9B07AdM025QHD0De=C059BDP1EEED0@T9208>3P`28R8P0C4a<069R
HP1ZJVX0]KFe08F5Q@1BDU80L71`04M7A`2RXZ80TY:B05aLG013@d<0PX:205YJFP1=CDd0IVIV08:2
PP18B4P0@T92061PH01>CTh0TI6A04a<C00Q8B40ATI6079bLP18B4P0Q8B407MgM`0203@d=03o02d]
;@1MGEd0?Shn02@T900d=3@0<c<c03@d=02=SHd0OGem024Q8@17AdL0>3Ph05aLG025QHD0@41001TI
6@27QhL0CTi>02HV9P27QhL0De=C03/k>`0T92@0BTY:05mOG`0R8R80PH6108B4Q01:BTX0<30`04M7
A`1<C4`0DE5A0492@P2KVi/0J6QX03Lg=`10@400:b/[04E5A@1iNGT0ADE507EeM@2][Jd0?Shn04];
B`2CTi<0RHV905mOG`0Z:RX0NGUi02LW9`0b<S80@41004i>CP17AdL07alO04I6AP12@T80KFe]055A
D@22PX80UYJF05UIF@0l?3`0CDe=03Hf=P1GEeL0HF5Q0451@@18B4P0@D510;bl_01mOGd09RHV05QH
F00c<c<0Cdm?09:BTP1aLG40DU9B071`L01?Cdl0I6AT07EeM@11@D40Bd];06EUI@0e=CD0CDe=06AT
I01HF5P0@D5107UiN@15ADD0Ogmo071`L010@400LG5a04A4A012@T80NWYj03Hf=P1DE5@0<c<c03dm
?@3@d=00PX:204M7A`1OGel0XJ6Q06IVIP1XJ6P0]KFe05iNGP1`L700JFUY03@d=01gMgL0I6AT07al
O01KFe/0B4Q805QHF00];Bd0K6a/07moO`12@T80NGUi03Xj>P1/K6`0XZ:R075aL@1ZJVX0O7al07Qh
N018B4P0JVYZ0;Jf]P2@T900IfMW05YJFP1lO7`0TY:B05mOG`2a/K40YJFU08j>SP1ADE40QHF50:FU
Y@2EUID0ATI60=SHf02_[jl0GUiN05IFEP24Q8@0GemO0820P01/K6`0=SHf04];B`16ATH0CDe=01XJ
6P13@d<0IFEU06YZJP2TY:@0I6AT05MGE`2h^;P0OWin02d];@1GEeL0ADE50410@01@D500G5aL03<c
<`1TI6@0Fe]K071`L01=CDd0>CTi08f=S@2ZZZX0Hf=S05YJFP1CDe<0PH6108F5Q@1UIFD0?Cdm09NG
U`1RHV80=3@d05MGE`29RHT0CDe=03lo?`1bLW80QXJ603/k>`1@D500EUIF03Lg=`0F5QH08R8R02<S
8`0c<c<0HF5Q09BDU01VIVH0;Rh^01lO7`1IFET0EeMG04a<C00U9BD0I6AT03`l?00m?Cd0T92@05EE
E@12@T80Ti>C055AD@0`<300Ti>C096AT@1aLG40?Shn02PX:02<S8`0EEEE02HV9P16ATH0I6AT02/[
:`0_;bl0IfMW0<?3``1kNg/0;2`/05=CD`25QHD0Hf=S04];B`1^KVh0C4a<034a<@12@T80C4a<000h
03Ph>00n?Sh0M7Ad02l_;`0X:2P0UYJF096AT@1KFe/0KFe]0<o?c`2OWil0ADE509BDU01XJ6P0H61P
04e=C@10@400XZ:R0<?3``1hN7P0:BTY09JFUP31`L40OWin0<71`@3=cLd0WIfM0:VYZ@30`<00UYJF
03Xj>P0R8R807AdM01`L700M7Ad06ATI02<S8`0T92@0Fe]K07QhN01<C4`0;Rh^02l_;`21PH40SHf=
03De=@0b<S80DU9B0:n_[`2;Rh/0e=CD0=?Cd`2c/k<0WIfM0861P@1UIFD205mOG`0A05ADE01:BTX0
UiNG0451@@0o?cl0<c<c02d];@0[:b/0][Jf0;6a/@15ADD0GEeM0492@P0_;bl0FUYJ071`L00W9bL0
0P0G5aL2014A4@805ADE00d07alO04];B`17AdL0H61P0;Vi^@2c/k<0Rh^;08:2PP2IVIT0Z:RX0<K6
aP31`L40Ph>30080>c/k01X0E5AD02d];@0];Bd08b<S01DE5@0>3Ph04a<C03hn?P2CTi<0Hf=S02l_
;`0`<300@d=308F5Q@2XZ:P0KFe]07inOP2][Jd0bLW90;Ng]`3Cdm<0a<C408n?S`1YJFT0BDU902d]
;@805ADE01L0@T9205=CD`0Z:RX05aLG01HF5P0^;Rh0A4A4051@D027QhL0^[Zj0=GEe@3Fe]H0d];B
0=_Kf`3Fe]H0^[Zj0:n_[`30`<00^[Zj04e=C@0];Bd05aLG02DU9@0207AdM00404E5A@0K6a/06QXJ
01XJ6P804a<C05P0=CDe08R8R03Hf=P0c<c<0<g=c@2m_Kd0`l?3092@T00o?cl08B4Q01LG5`0Q8B40
EEEE06ATI02QXJ40Xj>S059BDP13@d<05aLG01<C4`0D51@05ADE0410@00d=3@0CTi>04Y:BP0P8200
5QHF01DE5@0C4a<06ATI0861P@1`L700alO70;jn_P3MgMd0]KFe07UiN@0b<S80;Bd]01lO7`0S8b<0
9bLW03dm?@1^KVh0Lg=c096AT@2LW9`0PH610<k>cP2h^;P0Y:BT03Ph>00_;bl0B4Q80861P@2_[jl0
d];B0;Vi^@0W9bL071`L01/K6`0];Bd0GemO0:2PX03Jf]X0h>3P0=?Cd`31`L40Zj^[05UIF@0n?Sh0
@D5105eMG@2>SXh0UIFE08b<S029RHT0NGUi09ZJVP36a/H0W9bL05]KF`0L71`07alO030`<00i>CT0
<30`0P0I6AT0800[:b/0@410020P800V9RH0B4Q807YjNP2<S8`0CTi>04Y:BP20P800]kNg07=cL`12
@T807alO03dm?@1PH600OGem03@d=00n?Sh0BTY:071`L02;Rh/0YZJV02/[:`0O7al0EeMG05=CD`0D
51@04A4A01@D500G5aL071`L0P0Q8B40800R8R80<S8b06i^KP1EEED0@d=30:f][@1gMgL0D51@04e=
C@1FEUH0<30`04a<C01PH600FEUI02l_;`17AdL0[Zj^0:^[Z`1>CTh0KFe]0;^k^`1@D500?Cdm0492
@P15ADD0D51@09FEU@2ZZZX0HV9R04U9B@1MGEd0EeMG0P2SXj<06`1IFET07QhN024Q8@0S8b<09BDU
02LW9`0X:2P0;Bd]02LW9`0^;Rh0>c/k05=CD`1[Jf/0A4A403<c<`2RXZ80alO708j>SP37alL0d=3@
0=GEe@35aLD0IfMW04U9B@1?Cdl0QXJ60:NWY`02ooooo`0001@0[:b/05QHF032`/80M7Ad08n?S`2I
VIT0CTi>05=CD`2MWId0GEeM08n?S`2NWYh0Bd];06ATI00m?Cd0Jf][069RHP1HF5P0C4a<02l_;`80
IVIV0>D0C4a<03Xj>P24Q8@0I6AT02TY:@0[:b/0HV9R03Lg=`0i>CT0EUIF030`<01aLG40C4a<01XJ
6P12@T80J6QX02<S8`0m?Cd0?clo02`/;00Z:RX071`L04E5A@0];Bd071`L02PX:00^;Rh08R8R04M7
A`1BDU80;Rh^03`l?00Y:BT0=cLg05UIF@1=CDd06ATI08B4Q01CDe<061PH059BDP1DE5@09bLW01/K
6`0];Bd0@41004A4A02_[jl0VIVI04i>CP0b<S80HV9R04Q8B00U9BD0;Bd]05QHF017AdL0;Bd]02<S
8`0W9bL0ADE507QhN011@D40IfMW08>3P`16ATH092@T065QH@1FEUH0>c/k02XZ:P1_Kfl08R8R03Ti
>@13@d<0KVi^02/[:`0C4a<0CDe=04M7A`1gMgL0F5QH07alO01kNg/0BTY:03lo?`1ADE40BTY:07Yj
NP1KFe/0@41003dm?@0/;2`0JFUY05eMG@0L71`0DU9B0410@017AdL0GUiN04];B`0i>CT0GemO04M7
A`15ADD0Fe]K030`<010@400HF5Q05YJFP11@D40EeMG05aLG00b<S80Fe]K04m?C`2?Shl0Ng]k04U9
B@1@D500De=C071`L01lO7`0>SXj05IFEP1BDU80=CDe0;Fe]@1oOgl0ADE506QXJ02?Shl0=cLg06i^
KP2QXJ40EUIF06MWI`1[Jf/0ADE507QhN01_Kfl0Ogmo06IVIP16ATH0JFUY03Ph>01kNg/0De=C03Xj
>P1YJFT0H61P05=CD`2EUID0Bd];06a/K01hN7P0KVi^0492@P0d=3@0Ng]k04a<C00c<c<0De=C07Mg
M`1nOWh0GemO0:NWY`2JVYX0Ogmo04a<C024Q8@0ZZZZ08R8R00l?3`0gmoO0:FUY@1GEeL0J6QX07If
MP1SHf<0Z:RX07EeM@0i>CT0C4a<03Ti>@15ADD0CTi>06UYJ@1WIfL0I6AT09nOW`1NGUh0JFUY0<G5
a@23Ph<09bLW05YJFP0];Bd071`L03<c<`0i>CT0;Bd]05]KF`1PH600De=C04Y:BP0`<300GemO04U9
B@1<C4`0Cdm?05IFEP22PX80QhN706ATI00b<S80UiNG08Z:RP18B4P0CTi>09RHV012@T80De=C08N7
Q`2GUiL0?clo06ATI01JFUX0=3@d0080:BTY00l06QXJ01/K6`19BDT0TY:B06e]K@1IFET0:2PX09:B
TP1PH600@41002@T901>CTh0<S8b02HV9P1?Cdl00P13@d<00`31`L40O7al04Q8B002079bLP0/07Ad
M01NGUh0:RXZ09JFUP1WIfL08R8R04m?C`1SHf<0<S8b030`<01jNWX0c/k>08B4Q00d=3@0HF5Q092@
T01VIVH0GEeM07EeM@1SHf<0IFEU04e=C@1<C4`0ATI603lo?`2=SHd0;bl_02XZ:P2OWil0Vi^K05YJ
FP2GUiL0fm_K0:FUY@19BDT0_;bl0;:b/P1nOWh0>3Ph02<S8`21PH40d=3@0:j^[P1ZJVX20=?Cd`0f
0<G5a@2o_kl0O7al04M7A`1bLW80QXJ60:^[Z`2@T900De=C02PX:00L71`06a/K01`L700K6a/06QXJ
02/[:`1fMWH0SXj>05mOG`1ZJVX0Zj^[0<c<c027QhL0T92@0;Zj^P3Cdm<0W9bL0<G5a@3>c/h0YjNW
04I6AP0];Bd09BDU02@T9013@d<0[jn_0:6QX@2c/k<0BTY:034a<@0L71`08B4Q05MGE`3Fe]H0c<c<
0:ZZZP2^[Zh08b<S010@400F5QH0D51@07YjNP0/;2`06ATI0`0E5AD05P0G5aL092@T07AdM02WYjL0
ZZZZ079bLP1EEED09BDU01TI6@0Y:BT0CDe=0<C4a02=SHd0SXj>01hN7P0E5AD0:2PX04a<C00f=SH0
>CTi024Q8@0C4a<2010@400b03<c<`2FUYH0UIFE05MGE`1]KFd0XZ:R0<K6aP2[Zj/0XZ:R0:VYZ@2_
[jl0X:2P0<k>cP2i^KT0IVIV0861P@1dM7@0LW9b06e]K@2`/;00G5aL01dM7@0N7Qh06QXJ034a<@1X
J6P0DU9B01LG5`0W9bL0aLG50=gMg@3Ng]h0fm_K0<S8b03>c/h0fMWI0:j^[P1EEED0PX:201/K6`0G
5aL05QHF01DE5@0J6QX0Bd];05aLG00Z:RX06a/K01`L700K6a/201<C4`0I02DU9@2l_;`0TY:B03Xj
>P1?Cdl0UIFE08R8R01EEED0>CTi01dM7@10@400CTi>04Q8B021PH40];Bd05=CD`1OGel0DE5A01dM
7@0E5AD0<S8b05mOG`1DE5@0>3Ph03<c<`0301DE5@2801LG5`0E5AD0K6a/0::RXP2`/;00Fe]K0<C4
a01:BTX0D51@06QXJ01QHF40@41007inOP1eMGD0IVIV03lo?`0S8b<06ATI04m?C`1lO7`0`l?30=7A
d@2o_kl0C4a<03dm?@2o_kl0f][J0>GUi@2_[jl0@d=304e=C@0K6a/05QHF01LG5`0d=3@0AdM707Ee
M@37alL0UiNG0:JVYP20P800Q8B403hn?P18B4P0@d=304E5A@1>CTh0MgMg07alO02JVYX0/K6a0=?C
d`30`<00UIFE03/k>`0c<c<0BTY:07UiN@1dM7@0<30`03@d=011@D40BDU902HV9P1<C4`0LW9b071`
L00i>CT0<C4a03lo?`2_[jl0Zj^[061PH01ZJVX0MWIf04I6AP1BDU80F5QH06MWI`1=CDd0PH6109JF
UP2TY:@0Q8B405MGE`0Q8B40DE5A06MWI`0G5aL051@D01DE5@0F5QH092@T028R8P0P82008B4Q03`l
?026QXH0=CDe04];B`2TY:@0IVIV01HF5P0C4a<0<C4a07]kN`2=SHd0Xj>S07alO01fMWH0X:2P06QX
J01SHf<0VIVI06e]K@2:RXX0=CDe038b<P11@D40CTi>07EeM@2o_kl0GUiN01dM7@0l?3`0@41007em
O@24Q8@0YJFU07MgM`0b<S807QhN01`L700S8b<0;2`/034a<@80<S8b0180?3`l04M7A`2PX:00IFEU
06UYJ@23Ph<0_[jn0=[JfP2l_;`0[Jf]0<C4a03GemL0g=cL0820P01dM7@0YjNW096AT@1PH602oooo
o`0000@0[Jf]06UYJ@36a/H0S8b<0P2EUID0e@1PH600M7Ad0;6a/@1GEeL0T92@0:n_[`1=CDd0Ph>3
04Y:BP2CTi<0MgMg05eMG@23Ph<0ADE508b<S02JVYX0C4a<03De=@2@T900TY:B03Ti>@18B4P0RXZ:
03Xj>P11@D40L71`04m?C`2EUID0G5aL01`L701?Cdl0N7Qh03hn?P1SHf<0EUIF03dm?@0];Bd0:RXZ
061PH00i>CT071`L03@d=012@T80@41005=CD`1PH600<C4a03/k>`0o?cl0B4Q805mOG`1QHF407AdM
08^;R`1/K6`07QhN05aLG01aLG407alO01LG5`0^;Rh0F5QH020P801FEUH0IFEU05UIF@0e=CD0G5aL
04E5A@1IFET0?3`l04I6AP18B4P0:BTY034a<@17AdL0@D5107moO`1<C4`0J6QX08V9R@15ADD0;bl_
06UYJ@1JFUX0>3Ph02l_;`1[Jf/06QXJ03dm?@16ATH0KVi^028R8P0g=cL0OWin08J6QP1kNg/0C4a<
07moO`1jNWX0EeMG07MgM`2>SXh0EeMG08R8R01JFUX0CDe=05=CD`0i>CT0OGem05aLG00S8b<0CTi>
0451@@22PX80MgMg04];B`0o?cl0G5aL03Ph>01IFET0E5AD034a<@1:BTX0EeMG04=3@`1DE5@0HF5Q
06ATI01EEED0IVIV0451@@28R8P0NWYj071`L01CDe<0BTY:07AdM01CDe<0E5AD08:2PP1>CTh0=3@d
0<_;b`2:RXX0GUiN0:RXZ02YZJT0HV9R05QHF02UYJD0@d=306m_K`1/K6`0<30`07YjNP28R8P0N7Qh
069RHP1QHF40Ph>303Hf=P20P800Bd];03Ti>@1RHV80IFEU05QHF02GUiL0>3Ph06QXJ01lO7`0LW9b
05QHF01XJ6P0X:2P04I6AP13@d<0C4a<08B4Q02BTY80Q8B40:^[Z`2GUiL0C4a<06a/K02UYJD0/;2`
08Z:RP1=CDd0hN7Q0:f][@0f=SH0VIVI09ZJVP1ZJVX0/K6a09bLW01GEeL0AdM704A4A00m?Cd0G5aL
0;Zj^P2GUiL0EUIF09^KV`15ADD0?clo0:NWY`1UIFD08b<S06QXJ00202`/;03M04A4A00P8200<S8b
06IVIP1fMWH0Hf=S03lo?`0k>c/0Ogmo04Y:BP0e=CD0<S8b05]KF`1nOWh0QhN705IFEP0o?cl0LG5a
06QXJ011@D40A4A408B4Q01GEeL0@T9208:2PP1oOgl0?Cdm05=CD`1JFUX0Cdm?04];B`0/;2`0:2PX
03Hf=P1EEED0[jn_09>CT`1[Jf/0?clo0:6QX@1ZJVX0@d=302/[:`1<C4`0A4A403Ti>@13@d<0?3`l
03Lg=`2f][H0RXZ:03lo?`1mOGd0NWYj06i^KP1=CDd09BDU09nOW`14A4@0:RXZ059BDP1EEED06a/K
04M7A`2QXJ40`l?306m_K`0j>SX0P8200:VYZ@14A4@0I6AT08N7Q`1XJ6P0Bd];051@D01IFET08B4Q
03<c<`2:RXX0C4a<02l_;`2/[:`0PH6102h^;P1oOgl0`l?306][J`0h>3P0Z:RX0:b/[021PH40BDU9
02d];@1EEED0]KFe0<G5a@1hN7P0alO70<c<c03Cdm<0b<S808f=S@1dM7@0ADE504e=C@1ADE40GUiN
07IfMP27QhL0@T9202`/;00T92@08B4Q01`L700Q8B40=SHf0<k>cP32`/80XZ:R0;2`/039bLT0/[:b
08n?S`1<C4`0Vi^K08>3P`1^KVh0`/;209jNWP2k^k/0V9RH08F5Q@2KVi/0b<S80=GEe@3IfMT0[:b/
05QHF01EEED0MgMg08J6QP2:RXX0VIVI0::RXP11@D40OGem07EeM@0R8R803Ph>01LG5`0h>3P0NWYj
02l_;`0I6AT05ADE01XJ6P0Q8B40G5aL0<W9b@2TY:@0Jf][0451@@0J6QX06ATI01dM7@0Q8B40ADE5
08b<S01BDU80@d=3055AD@0H61P05ADE03<c<`1:BTX0De=C05QHF00W9bL0;Rh^01/K6`0E5AD0<S8b
0;:b/P3IfMT0`<300:n_[`2TY:@0[Jf]0861P@1IFET0RHV90<G5a@3Bd]80NWYj06EUI@1bLW80GEeM
04A4A01oOgl0/[:b06UYJ@0a<C40820P04e=C@1EEED06a/K01dM7@0X:2P0HF5Q0<o?c`3Ph>00clo?
0:JVYP1YJFT0OGem0:BTY01bLW808b<S03dm?@0K6a/00`0E5AD01@0D51@06ATI05QHF01CDe<0>CTi
008071`L02d0410@01DE5@0G5aL0N7Qh03De=@0W9bL0:RXZ096AT@1YJFT0QXJ603lo?`0L71`0DU9B
07moO`1:BTX0FUYJ0::RXP2LW9`0ATI608B4Q021PH40DE5A04A4A016ATH0?Shn03Ti>@0b<S806ATI
01DE5@0G5aL05QHF01DE5@0c<c<0emOG0;Jf]P1YJFT0Shn?04a<C00^;Rh08B4Q08F5Q@29RHT0=SHf
01dM7@0G5aL00`0E5AD0BP0V9RH0JVYZ09JFUP2OWil0gMgM0=cLg032`/80_[jn0;fm_@2OWil0d];B
0:2PX01NGUh0?clo01TI6@0G5aL071`L04U9B@1XJ6P0LG5a05YJFP1RHV80^[Zj0:j^[P1mOGd0DE5A
05QHF01YJFT0OWin09NGU`2TY:@0TI6A09NGU`3@d=00e=CD0:n_[`2k^k/0`/;20<[:bP32`/80^KVi
09VIV@2VYZH0SXj>06IVIP1JFUX0Jf][06m_K`0h>3P0:RXZ03lo?`1aLG40<S8b020P801MGEd0DE5A
0:RXZ01HF5P0DE5A01PH600i>CT07AdM03@d=02VYZH0`<3008B4Q02QXJ40G5aL05eMG@2DU9@0<S8b
01/K6`0T92@0GemO0P1MGEd0?P11@D40<c<c04a<C02YZJT0>3Ph06a/K02h^;P0F5QH010@400C4a<0
5ADE03hn?P33`l<0gMgM0<G5a@2XZ:P0E5AD02HV9P0K6a/0;bl_0:BTY02EUID0Hf=S03Lg=`1;Bd/0
P8200;Jf]P2ATI407QhN01dM7@0d=3@0De=C04=3@`23Ph<0Xj>S06i^KP1QHF40:BTY01dM7@0e=CD0
<c<c03Ph>00i>CT0>c/k051@D01mOGd0]KFe09^KV`1RHV80Ogmo0<K6aP3>c/h0KVi^09ZJVP3>c/h0
b<S80:NWY`2o_kl0alO7061PH00f=SH0@4100_ooool0000i09BDU028R8P0a<C4071`L02MWId0GemO
075aL@2ATI40VIVI04];B`1cLg<0K6a/059BDP2c/k<0Bd];07]kN`1OGel0WYjN09ZJVP13@d<0[:b/
09NGU`17AdL0@T9209bLW02?Shl0?clo05ADE01mOGd0=CDe07emO@26QXH0EeMG09>CT`16ATH0:2PX
07UiN@1^KVh0>c/k06=SH`1BDU80<C4a04Y:BP0[:b/0@d=302DU9@0o?cl0N7Qh04e=C@0/;2`0DE5A
05QHF00L71`0Cdm?03Ph>019BDT0HV9R0080<S8b0?l0Y:BT06UYJ@0K6a/0Cdm?05]KF`0a<C40=3@d
06a/K01YJFT0>3Ph08R8R01mOGd0IfMW03Lg=`27QhL0P82006][J`0e=CD0>c/k03`l?00^;Rh0HV9R
04];B`0l?3`0I6AT03Lg=`2BTY80[Jf]06=SH`11@D40EeMG055AD@0Z:RX0DU9B09JFUP14A4@0>SXj
05IFEP27QhL0<c<c01LG5`1>CTh0B4Q804e=C@1:BTX0S8b<0:VYZ@1>CTh0B4Q807QhN01;Bd/0X:2P
06ATI01lO7`0NGUi0492@P2?Shl0ATI603Ti>@1aLG40De=C08B4Q02ATI40De=C038b<P1/K6`0>CTi
07IfMP16ATH0>3Ph07alO01UIFD0@d=307moO`2HV9P0>3Ph069RHP1bLW80B4Q80:2PX01ZJVX0H61P
05iNGP0f=SH0V9RH04Q8B00b<S80EUIF03De=@0h>3P0alO708J6QP0i>CT0K6a/09BDU01CDe<0R8R8
0:j^[P0Y:BT0CDe=07YjNP0j>SX0WYjN0:n_[`14A4@0E5AD09^KV`28R8P0>SXj08n?S`1HF5P0JFUY
09RHV02?Shl0DU9B09jNWP17AdL0RXZ:0<G5a@2OWil0JFUY071`L02SXj<0B4Q803Ph>01`L700VIVI
09nOW`2>SXh0]kNg0:f][@1YJFT0DU9B08b<S02KVi/0@41005QHF02f][H0T92@03Xj>P1RHV80PX:2
05UIF@2o_kl0[Jf]04i>CP1kNg/0N7Qh05aLG00T92@0CDe=07moO`1KFe/0UYJF07alO01cLg<0][Jf
06a/K00j>SX0Y:BT05=CD`0o?cl0EeMG02@T901HF5P0SXj>0:VYZ@2BTY80FUYJ0410@02<S8`0AdM7
038b<P0U9BD0NWYj0<71`@2a/K40@41004i>CP1PH600@d=303De=@1FEUH0OWin04i>CP1QHF40X:2P
07AdM014A4@0MGEe08:2PP1OGel0Fe]K03De=@0f=SH0:RXZ03Ti>@2][Jd0Vi^K07UiN@1QHF40/k>c
092@T013@d<0>c/k069RHP1EEED0>CTi04i>CP0l?3`0@4100;bl_02;Rh/0=SHf07inOP23Ph<0K6a/
0492@P0g=cL0YZJV059BDP0g=cL0LW9b08^;R`0i>CT0;Rh^06m_K`2m_Kd0;2`/01XJ6P1BDU80OWin
04U9B@18B4P0=3@d04M7A`0H61P0?clo08:2PP1=CDd0=SHf07MgM`0G5aL08B4Q08B4Q027QhL0Bd];
08f=S@3Cdm<0?clo02<S8`1eMGD0P82006=SH`0`<30000`09BDU03De=@1EEED0YJFU03hn?P3:b/X0
e=CD0>7Qh@31`L40YjNW0:JVYP1aLG4304m?C`1i051@D01PH600MgMg08J6QP1WIfL0CTi>03dm?@11
@D40KFe]0=7Ad@2VYZH0S8b<09:BTP36a/H0Fe]K03<c<`0K6a/08b<S07MgM`30`<00a/K60;2`/02W
YjL0alO70:2PX01hN7P0H61P06m_K`2QXJ40WIfM0:^[Z`1`L700FEUI04A4A00Q8B408R8R08V9R@0k
>c/0=cLg04E5A@1QHF407alO01@D500E5AD0FUYJ08J6QP0g=cL0<C4a04=3@`2JVYX0/[:b096AT@1c
Lg<0E5AD030`<00b<S80:BTY02HV9P0k>c/08b<S02DU9@1GEeL0E5AD0410@01:BTX06a/K02@T901<
C4`0EEEE04a<C00P82007alO030`<00Z:RX061PH05mOG`36a/H0V9RH0:6QX@2f][H0b<S80<71`@2h
^;P0S8b<03/k>`0V9RH0GemO07=cL`1DE5@0IfMW07QhN02g]kL0WinO0:>SX`2XZ:P0WYjN06MWI`0E
5AD0?3`l05EEE@2<S8`0Fe]K03lo?`2`/;00DE5A05mOG`0_;bl08R8R03Hf=P1iNGT0ADE501lO7`0/
;2`05aLG01DE5@0B4Q804a<C01DE5@0N7Qh0LG5a05iNGP02028R8P0H01TI6@0E5AD07AdM07alO00g
=cL08B4Q028R8P1mOGd0DE5A03<c<`2LW9`0<c<c04M7A`2^[Zh0R8R804e=C@2HV9P0e=CD09NGU`2A
TI40U9BD05YJFP1FEUH0C4a<0P0k>c/01`0U9BD05QHF01DE5@0G5aL05ADE01LG5`0^;Rh00P3IfMT0
2024Q8@0MWIf09FEU@0h>3P08B4Q05iNGP0c<c<05aLG100E5AD0700G5aL0?clo055AD@1oOgl0OGem
0>7Qh@3WinL0]kNg08J6QP1JFUX0Cdm?0820P01kNg/0QXJ608:2PP1EEED0:2PX01`L700c<c<0KVi^
05MGE`1DE5@0@41009:BTP3Jf]X0emOG0<71`@2c/k<20;Zj^P0P0;bl_036a/H0^;Rh0;:b/P3Kfm/0
inOW0=SHf02VYZH0NWYj06a/K022PX80RXZ:075aL@27QhL0];Bd0<?3``3=cLd0RXZ:04Y:BP0f=SH0
ATI605EEE@0V9RH06a/K01TI6@0Z:RX0F5QH07YjNP1/K6`0<30`01HF5P0K6a/201dM7@0M03Hf=P2F
UYH0T92@0:f][@21PH40LG5a0;2`/01ZJVX0<c<c04M7A`0X:2P092@T0451@@1gMgL0YZJV0;bl_02e
]KD0V9RH0:RXZ037alL0;bl_01@D500E5AD05aLG01HF5P1/K6`0a/K609NGU`0n?Sh00`0J6QX0:`0N
7Qh0=cLg09VIV@2MWId0NGUi0;2`/02][Jd0YjNW065QH@0U9BD06a/K02TY:@1PH600Cdm?069RHP1o
Ogl0YZJV08F5Q@1:BTX0=3@d08f=S@1hN7P0EEEE05mOG`1UIFD0WIfM09>CT`1DE5@0AdM706m_K`2U
YJD0JVYZ0=3@d02;Rh/0^KVi09fMW@1cLg<0F5QH06QXJ02TY:@0>CTi03/k>`13@d<00_ooool0001>
0:JVYP1]KFd0S8b<075aL@2i^KT0RHV906][J`1WIfL0NGUi04i>CP2/[:`0ZZZZ05YJFP2QXJ40@D51
07emO@12@T80MGEe07moO`13@d<0^[Zj05iNGP1EEED0H61P07=cL`1OGel0@410069RHP1_Kfl0:2PX
05ADE01KFe/0ADE508j>SP0o?cl0820P06UYJ@1GEeL0AdM708n?S`1IFET0<c<c02/[:`0a<C40>3Ph
034a<@0R8R80A4A402PX:00a<C40Ogmo05aLG00R8R80?clo02PX:01YJFT0OWin030`<00I6AT0OGem
04A4A00H61P0E5AD0492@P0U9BD0=CDe05ADE01VIVH0<C4a08V9R@23Ph<092@T01lO7`1LG5`0CTi>
051@D011@D40HV9R0P0f=SH0o`0b<S808b<S04Y:BP1JFUX0=CDe06a/K02][Jd0CDe=069RHP2=SHd0
K6a/02/[:`0W9bL0KFe]02DU9@0l?3`0GEeM07moO`1HF5P06ATI06=SH`1CDe<0BDU903De=@1@D500
IfMW05ADE01IFET0I6AT02HV9P1ZJVX0H61P06EUI@1:BTX0820P08b<S01SHf<07alO05IFEP0E5AD0
BDU906MWI`1[Jf/0C4a<065QH@0S8b<0CDe=071`L00o?cl0E5AD0492@P0S8b<0=cLg05QHF01NGUh0
EUIF05=CD`0i>CT0K6a/06i^KP1ZJVX0@d=301`L702KVi/0KVi^0451@@1IFET0<C4a02TY:@2EUID0
U9BD04M7A`1^KVh0Shn?02PX:00o?cl0P82004i>CP1LG5`0Jf][02h^;P1UIFD0G5aL05iNGP11@D40
GEeM03De=@0W9bL0SXj>04e=C@0m?Cd0Hf=S03dm?@1ZJVX0YjNW04I6AP1VIVH0MWIf05ADE00e=CD0
N7Qh0::RXP2;Rh/0BTY:04m?C`2?Shl0@T9204=3@`1WIfL0Rh^;06YZJP1LG5`0Vi^K09>CT`2;Rh/0
Ogmo0:>SX`24Q8@0A4A407EeM@1YJFT08b<S06m_K`2BTY80G5aL03De=@1MGEd0FEUI02TY:@1jNWX0
BDU906=SH`2LW9`0IfMW07IfMP2d];@0@D5102XZ:P21PH40GUiN05]KF`2IVIT0De=C030`<01FEUH0
Kfm_06IVIP1MGEd0BDU90:n_[`24Q8@0@T9203Xj>P16ATH0EEEE08F5Q@1KFe/0F5QH07EeM@1<C4`0
8R8R061PH020P800B4Q806a/K02/[:`0J6QX028R8P16ATH0HF5Q04E5A@1KFe/0O7al06i^KP1KFe/0
HF5Q0:VYZ@1oOgl0<C4a07=cL`39bLT0SXj>04M7A`0T92@0IFEU06][J`0m?Cd0Ogmo02@T901XJ6P0
]kNg07moO`1;Bd/0/k>c0<G5a@25QHD0?Cdm01dM7@2?Shl0<S8b01LG5`12@T80G5aL03Xj>P0i>CT0
QXJ60<c<c01SHf<08B4Q04U9B@1kNg/0EUIF05mOG`0f=SH0EeMG03`l?00[:b/0EEEE04a<C00h>3P0
IVIV02TY:@0O7al0QHF5096AT@1KFe/0T92@0=[JfP1jNWX0?clo09jNWP2CTi<0Ng]k03Ti>@0^;Rh0
KVi^07alO027QhL0BDU90=gMg@3@d=00`L710<O7a`2_[jl0^;Rh0;>c/`26QXH0O7al07YjNP1OGel0
DU9B04i>CP1SHf<0SHf=0:VYZ@004@2<S8`0YjNW0=;BdP31`L40NGUi04U9B@2NWYh0f][J07IfMP0o
?cl0L71`07=cL`1:BTX0WinO0<W9b@34a<@0a/K60080`/;203/0YZJV09VIV@24Q8@0UYJF0:RXZ02J
VYX0GUiN03/k>`0];Bd09BDU01hN7P1:BTX0Xj>S075aL@1<C4`0@d=306e]K@0W9bL05aLG069RHP3B
d]80XJ6Q0;Vi^@3@d=00Y:BT08J6QP1IFET0M7Ad05EEE@1IFET0IFEU06IVIP1eMGD07AdM01LG5`0F
5QH0ADE505YJFP0U9BD0ADE506IVIP0^;Rh0:2PX061PH01NGUh0?3`l01XJ6P0N7Qh0=SHf055AD@1S
Hf<0Ogmo034a<@1IFET0JVYZ08R8R03=cLd0D51@00`<300200X:2P0L014A4@0i>CT0KFe]065QH@1E
EED0/k>c0<K6aP2i^KT0`L710=GEe@22PX80TI6A0=SHf02DU9@0<C4a01dM7@0K6a/0NWYj01/K6`14
A4@0CTi>02<S8`0T92@0BTY:07AdM00Y:BT0;bl_01dM7@D05ADE0340:RXZ07moO`10@4008B4Q02LW
9`0M7Ad0>3Ph05aLG00`<3007QhN024Q8@2ATI40Bd];01HF5P2UYJD0][Jf075aL@1<C4`0][Jf09:B
TP2QXJ40c<c<0=GEe@1XJ6P0NWYj0;Rh^02OWil0Bd];0492@P1mOGd06ATI01DE5@0F5QH05ADE02<S
8`1<C4`0Xj>S0>OWi`3YjNT0^;Rh0:BTY02l_;`0DE5A04A4A01@D500:RXZ01TI6@0E5AD051@D0080
5ADE03D071`L02@T9012@T80<30`0;Ng]`3IfMT0eMGE08j>SP0e=CD0?clo03dm?@12@T80IFEU051@
D00o?cl0GemO07IfMP1VIVH0@D5108Z:RP1MGEd0Fe]K04e=C@1LG5`0alO70<K6aP2:RXX0Ogmo06UY
J@1OGel0E5AD06m_K`1CDe<0Lg=c0=OGe`3Fe]H0[Zj^07moO`1SHf<0B4Q804Y:BP10@400@T9206QX
J01lO7`0]KFe0=GEe@2LW9`0C4a<06=SH`1MGEd06ATI01XJ6P0201TI6@0N01PH6013@d<0K6a/06=S
H`1:BTX05ADE01lO7`0M7Ad071`L02HV9P0e=CD0QXJ608:2PP2][Jd0PX:20<71`@3Lg=`0Shn?06][
J`1]KFd0MGEe0861P@2BTY80V9RH096AT@1bLW80UYJF0;no_`2[Zj/05aLG0P0C4a<0=00E5AD07QhN
07MgM`1FEUH0<c<c01DE5@0F5QH05ADE01XJ6P0K6a/0;Bd]04Q8B02XZ:P0LG5a03Hf=P0O7al0=3@d
059BDP0^;Rh071`L02h^;P25QHD0WinO0:NWY`21PH40UiNG08J6QP1fMWH0Cdm?09FEU@2f][H0Ng]k
07AdM027QhL0MgMg05ADE01`L700QhN70;6a/@1nOWh0HV9R0=SHf02UYJD0SHf=0:RXZ02=SHd0L71`
079bLP2BTY80ATI602XZ:P0o?cl2ooooo`0009X0Vi^K08j>SP2GUiL0CTi>08N7Q`22PX80LW9b06=S
H`10@400<c<c07]kN`29RHT0GemO06UYJ@0i>CT0TI6A05EEE@1`L700CDe=03Hf=P2>SXh0MgMg04=3
@`0_;bl0C4a<02/[:`0_;bl0AdM707MgM`0^;Rh0HV9R02h^;P0T92@0Fe]K04I6AP0Y:BT0M7Ad04Y:
BP0U9BD0BTY:04e=C@0c<c<09RHV038b<P14A4@09BDU028R8P1TI6@092@T01LG5`0j>SX0DE5A03Hf
=P0l?3`05aLG03De=@1GEeL0B4Q8020P802WYjL092@T018B4P1QHF40L71`02PX:00^;Rh0@T92034a
<@0L71`0EeMG06IVIP13@d<07AdM06QXJ00i>CT0410@03De=@1hN7P0ADE50492@P0n?Sh0410@0492
@P1YJFT0@D5106a/K02QXJ405aLG02d];@0n?Sh0Bd];038b<P0X:2P0KVi^01DE5@0/;2`0=cLg06m_
K`0L71`061PH06EUI@1EEED0HF5Q05ADE01HF5P0HV9R05ADE01PH600F5QH04E5A@25QHD0ADE5075a
L@1SHf<0=CDe07emO@1BDU807alO065QH@1>CTh0LW9b059BDP0c<c<0=CDe075aL@0j>SX0H61P06=S
H`0m?Cd0E5AD07moO`17AdL0@T9205UIF@1ZJVX0IfMW07MgM`1?Cdl0QHF506QXJ01]KFd0DU9B03/k
>`2TY:@0Hf=S03/k>`1_Kfl0NWYj03dm?@2@T900QXJ603lo?`1bLW80XJ6Q0P1CDe<0X`2@T900F5QH
07AdM01_Kfl0AdM7075aL@1/K6`0I6AT0492@P1KFe/0Cdm?02PX:01eMGD0BTY:04E5A@1bLW80ATI6
03Ti>@1^KVh0Fe]K08J6QP1kNg/0K6a/03`l?01LG5`0PX:205IFEP0d=3@0C4a<08V9R@1KFe/0Ogmo
08^;R`2MWId0KVi^04A4A02n_[h0WYjN0820P02@T900/K6a092@T010@400IfMW07IfMP1IFET0IfMW
0861P@1;Bd/0ADE504];B`0];Bd0BTY:0:NWY`1;Bd/0EEEE08n?S`0g=cL0G5aL09fMW@1BDU80:b/[
09FEU@0[:b/0=CDe05mOG`0`<300=CDe05EEE@1oOgl0GemO03@d=00b<S80HV9R071`L01GEeL0H61P
055AD@1fMWH0Vi^K03Lg=`1;Bd/0UIFE07YjNP0k>c/0FEUI07YjNP0I6AT0@T9208f=S@1kNg/0@d=3
04m?C`1IFET07AdM03Ph>00c<c<0BDU903De=@1VIVH0WinO07]kN`1BDU80ADE50;Fe]@1[Jf/0D51@
03Hf=P1WIfL09bLW04Y:BP2?Shl0Fe]K03Ph>02b/[80Cdm?01TI6@1@D500LG5a079bLP1HF5P07AdM
09:BTP13@d<08b<S051@D01KFe/06QXJ03Ti>@2;Rh/0clo?07YjNP0X:2P0@d=308N7Q`1EEED0GEeM
03/k>`1PH600Hf=S02h^;P1BDU80H61P03`l?01aLG40<C4a024Q8@25QHD0Ng]k0492@P2DU9@0fMWI
07MgM`10@400V9RH07moO`1JFUX0;Rh^01lO7`2KVi/0MgMg04M7A`1EEED00P3De=@0:P36a/H0VIVI
096AT@2h^;P0XZ:R06a/K00m?Cd0=SHf03De=@14A4@0K6a/08b<S01hN7P0[Jf]0<?3``3GemL0bl_;
0=[JfP3Bd]80eMGE096AT@1kNg/0[Zj^0:RXZ03AdM40a/K60::RXP31`L40c/k>0;^k^`3@d=00`<30
0<71`@2d];@0RHV906m_K`23Ph<0S8b<07moO`1IFET0C4a<03Lg=`80:BTY02<0>SXj03Ti>@0_;bl0
@D5105IFEP1WIfL0W9bL09^KV`2MWId0JFUY04=3@`2CTi<0YjNW09bLW023Ph<0MWIf06IVIP1?Cdl0
;bl_03<c<`0k>c/0Cdm?03@d=00M7Ad05ADE03Lg=`1CDe<0@T9203@d=01VIVH0Ph>304A4A012@T80
Vi^K03/k>`0201hN7P0503@d=01MGEd0Xj>S06ATI023Ph<00P1jNWX00`11@D40SXj>01TI6@0200d=
3@1F00h>3P0=3@d03Ph>01XJ6P1PH600QhN70;Fe]@2m_Kd0fm_K0=?Cd`3:b/X0/[:b0:6QX@3@d=00
>CTi00h>3P0@41006ATI05ADE00M7Ad071`L03/k>`0i>CT092@T02/[:`1YJFT0DU9B02TY:@0h>3P0
5QHF01DE5@0G5aL05ADE01<C4`0F5QH0=SHf08:2PP0h>3P09bLW02`/;01PH600CDe=02DU9@0O7al0
;bl_092@T012@T8061PH04m?C`0J6QX0;bl_0451@@1=CDd0a<C40<_;b`2n_[h0f][J09nOW`1_Kfl0
Ph>30;>c/`1MGEd0NWYj069RHP0T92@07alO02PX:015ADD0Ti>C0;Rh^02ATI40_;bl0>7Qh@38b<P0
^[Zj0;^k^`2<S8`0OWin030`<00P82008b<S01DE5@0H61P05QHF01LG5`0V9RH203<c<`0a024Q8@2G
UiL0`<300>GUi@2QXJ40>c/k02TY:@0e=CD0?Cdm04i>CP1OGel0I6AT04m?C`0f=SH0?Shn08Z:RP2J
VYX0IVIV06UYJ@1lO7`0W9bL0<_;b`1ADE408b<S03Ti>@13@d<0AdM705MGE`2MWId0];Bd0:j^[P2Z
ZZX0dM7A0;^k^`2<S8`0RHV909jNWP29RHT0OGem09^KV`2h^;P0PX:205mOG`2c/k<0a/K608f=S@1L
G5`06QXJ01DE5@0201LG5`0W01DE5@0G5aL05aLG04A4A018B4P0G5aL01DE5@0K6a/09RHV01lO7`0R
8R80:2PX0410@026QXH0_;bl0<[:bP3Fe]H0dm?C09VIV@1[Jf/0EUIF04M7A`13@d<0EUIF07EeM@1i
NGT0OGem0:ZZZP3AdM40_[jn02XZ:P0E5AD05aLG02DU9@1UIFD0bLW909>CT`0_;bl05aLG00<06a/K
01H07alO02l_;`1@D500GemO01TI6@0L71`07alO02XZ:P1DE5@09bLW020P801:BTX0B4Q807MgM`21
PH40T92@08F5Q@2[Zj/0WinO0::RXP2l_;`0Q8B40P1gMgL04`26QXH0UiNG0:2PX02^[Zh0]KFe0;Ng
]`1GEeL0[Zj^0<G5a@2j^[X0TI6A0;^k^`2JVYX0][Jf0<c<c02^[Zh0KVi^03De=@1dM7@00_ooool0
003o08b<S01bLW80Vi^K06IVIP2IVIT0RHV909FEU@1gMgL0TY:B04Y:BP2;Rh/0VYZJ06IVIP2LW9`0
>SXj0:2PX01;Bd/0EeMG08F5Q@10@400TY:B08b<S01<C4`0<C4a09VIV@1jNWX0<C4a051@D02?Shl0
;Rh^065QH@28R8P0CDe=0820P011@D409BDU0820P01UIFD0@d=305eMG@1@D500<S8b02d];@0V9RH0
@D5102HV9P0O7al0C4a<03dm?@0c<c<0BTY:055AD@0Y:BT0ATI602h^;P19BDT0DU9B04I6AP0Q8B40
YJFU04a<C00F5QH0BDU905QHF00X:2P0<30`02PX:01NGUh0=cLg06][J`1IFET0<30`01XJ6P1IFET0
?3`l051@D00l?3`0BTY:03De=@0h>3P0;Bd]020P8017AdL0Cdm?04M7A`1/K6`0N7Qh02d];@14A4@0
@41003dm?@0I6AT0:b/[065QH@0J6QX0<C4a03Xj>P1/K6`06a/K02HV9P29RHT0LW9b05aLG016ATH0
HF5Q05YJFP1>CTh0SXj>05MGE`14A4@0TI6A02l_;`1aLG40GUiN02l_;`23Ph<0ADE502HV9P1GEeL0
@T92061PH01ADE407alO03Lg=`1fMWH0>c/k06a/K012@T80Bd];07=cL`1UIFD0?Cdm03`l?01<C4`0
=cLg07emO@1WIfL0Bd];07MgM`18B4P0JFUY04=3@`0Z:RX0Shn?03Ti>@1KFe/0QXJ605ADE00];Bd0
UYJF07QhN01CDe<0WinO09VIV@15ADD0FUYJ08R8R011@D40Rh^;07moO`16ATH0GUiN06YZJP1HF5P0
LW9b09JFUP1GEeL09bLW06a/K00l?3`0ATI606i^KP1<C4`0DE5A09RHV01EEED0Shn?07MgM`1dM7@0
De=C07moO`2e]KD0BDU9038b<P1:BTX0QhN706UYJ@24Q8@0SXj>0:>SX`1PH600CDe=0::RXP2YZJT0
MWIf09BDU02XZ:P0Ph>304U9B@2QXJ40Jf][061PH01^KVh0WinO061PH011@D40GEeM04=3@`0H61P0
DU9B05YJFP1]KFd0ZJVY0492@P1>CTh0V9RH04];B`0b<S80WIfM03De=@0o?cl0F5QH01XJ6P0n?Sh0
EUIF08V9R@1DE5@0<S8b03De=@1gMgL0BDU9024Q8@0d=3@0BDU90861P@2GUiL0DE5A051@D01cLg<0
L71`0492@P1RHV80UYJF05QHF01NGUh0WYjN08b<S015ADD0Cdm?05iNGP13@d<0De=C04M7A`1MGEd0
ADE5000m05mOG`2`/;00Ti>C05ADE00n?Sh0a<C405aLG01<C4`0@d=305MGE`0o?cl0=3@d04Q8B01?
Cdl0>3Ph0;jn_P2CTi<0AdM705mOG`1`L700Ng]k07AdM00M7Ad0OGem0492@P0X:2P0C4a<05mOG`0R
8R80?3`l08Z:RP3?cll0KVi^03<c<`12@T80M7Ad051@D01RHV80@41006EUI@1KFe/0=CDe05QHF018
B4P0=SHf079bLP0T92@07alO07EeM@1]KFd0A4A409BDU03?cll0NGUi0451@@2BTY80IFEU0451@@12
@T805ADE071`L00207AdM00B04U9B@35aLD0][Jf09RHV01^KVh0@T9205eMG@2a/K40/[:b08F5Q@1^
KVh0IFEU06UYJ@1JFUX0EEEE06MWI`2=SHd0d];B0P3Cdm<0B`2<S8`0[jn_0<[:bP10@40071`L04];
B`2n_[h0NGUi0410@00o?cl0B4Q806IVIP2IVIT0^[Zj0<S8b033`l<0UIFE04i>CP0e=CD0:2PX02`/
;01VIVH0IfMW05=CD`1>CTh0Bd];04Q8B00e=CD0=3@d034a<@0N7Qh071`L024Q8@22PX80_Kfm08V9
R@1?Cdl0@d=308N7Q`1;Bd/0N7Qh03Ti>@0/;2`0H61P04m?C`0S8b<0820P01TI6@0k>c/0>SXj034a
<@0E5AD05aLG05]KF`1=CDd0D51@04a<C01TI6@0Zj^[08n?S`2k^k/0N7Qh03Lg=`0c<c<0TY:B0;fm
_@2/[:`0LG5a0<30`03?cll0@d=30451@@1`L7004Q8B00l?3`0200d=3@<03Ph>00/04Q8B05=CD`3E
eMD0fm_K0<_;b`2_[jl0UiNG09nOW`0X:2P0KFe]03Ph>002014A4@1201DE5@18B4P07AdM01XJ6P0H
61P0G5aL02`/;00Q8B40@D5108R8R01>CTh0<S8b02h^;P0E5AD05QHF01<C4`0E5AD06ATI01LG5`1_
Kfl0JVYZ03hn?P0l?3`0SXj>03Xj>P0];Bd0<S8b03Xj>P2CTi<0=cLg02l_;`0J6QX03Ph>01<C4`0W
9bL0>c/k08V9R@3Ti>@0^;Rh05=CD`20P800][Jf08n?S`2WYjL0^k^k06e]K@1bLW80BDU90492@P1k
Ng/0[:b/0861P@0g=cL06QXJ05ADE01ZJVX0bLW90;Jf]P36a/H0fm_K09:BTP0Z:RX07AdM02TY:@0O
7al061PH0P0I6AT0:@0P8200?3`l01/K6`0M7Ad0Shn?0:VYZ@3Jf]X0bLW908f=S@0g=cL08B4Q02/[
:`0`<300Bd];06=SH`1UIFD0I6AT05YJFP1/K6`0NGUi0;Bd]035aLD0`/;20:b/[02l_;`0BDU904E5
A@1CDe<0GemO0820P02_[jl0dm?C0;Vi^@1KFe/0TY:B0<71`@3@d=00YjNW08n?S`2;Rh/0Ng]k0080
QhN700X0/[:b0;>c/`26QXH0`<300;jn_P2WYjL0:2PX01hN7P0J6QX04a<C0P0E5AD0;P0G5aL04Q8B
01HF5P1HF5P0DE5A02DU9@0I6AT0<30`02@T900V9RH0:BTY03@d=02/[:`0a<C40=cLg037alL0/K6a
06IVIP1>CTh0EEEE05IFEP1EEED0A4A403Lg=`16ATH0[Jf]0=GEe@3@d=00UYJF09:BTP1CDe<0Hf=S
08B4Q02<S8`0]kNg0;no_`1:BTX05QHF01`L700K6a/07AdM020P800W9bL0@410055AD@0K6a/201dM
7@0T02LW9`1/K6`0<C4a03Hf=P0o?cl0AdM704e=C@1hN7P0MGEe079bLP2FUYH0aLG508F5Q@2m_Kd0
_kno0;Fe]@2LW9`0Rh^;07emO@1MGEd0W9bL0<S8b02j^[X0V9RH0;jn_P24Q8@0Jf][09RHV02j^[X0
=cLg04Q8B011@D40G5aL0<[:bP2SXj<0KVi^0_ooool000110:2PX024Q8@0^k^k069RHP27QhL0DE5A
07IfMP2@T900P82004U9B@27QhL0SXj>07=cL`2SXj<0=SHf08f=S@18B4P0Lg=c09ZJVP18B4P0U9BD
08:2PP1KFe/0EeMG08f=S@1^KVh0>3Ph05EEE@1BDU80<C4a07QhN01gMgL0@D5107inOP0`<300>SXj
09BDU01HF5P0Cdm?05aLG01?Cdl0>SXj04A4A00/;2`0=SHf02`/;011@D40MgMg03Ph>00a<C40AdM7
04e=C@0X:2P0B4Q8034a<@1HF5P0Lg=c05YJFP0R8R80ZZZZ059BDP0I6AT0Cdm?05QHF00W9bL00P0R
8R80A`1OGel0>CTi065QH@1HF5P0@d=301dM7@1GEeL0AdM705MGE`15ADD0B4Q803Lg=`0j>SX0=CDe
02l_;`1=CDd0H61P05EEE@2ATI40VYZJ03/k>`1:BTX0?clo0492@P0N7Qh0BTY:07moO`0V9RH0<30`
03`l?025QHD06ATI02XZ:P1?Cdl0EUIF051@D01;Bd/0HV9R05IFEP0c<c<0GemO05EEE@0l?3`0TI6A
02`/;02<S8`0IVIV03De=@23Ph<0=CDe03hn?P1ZJVX0BDU905mOG`1:BTX0;Rh^03Ti>@1^KVh0<S8b
06][J`16ATH0>3Ph05MGE`1XJ6P0>SXj03`l?01@D500Bd];06ATI01@D500?clo0080IVIV07T0GemO
04Q8B00X:2P0P82003Xj>P17AdL0CTi>02h^;P0M7Ad0Q8B405eMG@0i>CT0Ogmo08Z:RP15ADD0Lg=c
08V9R@0U9BD0HV9R05]KF`0c<c<0SXj>08J6QP0f=SH0BDU9071`L01CDe<09bLW08R8R01<C4`0LW9b
08n?S`1WIfL0GUiN08j>SP1QHF40ZZZZ09RHV025QHD0Jf][071`L02b/[80KVi^03dm?@1?Cdl0Xj>S
07YjNP2:RXX0[:b/0:NWY`19BDT0Ng]k0:ZZZP28R8P0@d=30:>SX`39bLT0NWYj038b<P2:RXX0GUiN
05MGE`1VIVH0YJFU06ATI014A4@0HF5Q04I6AP0Y:BT0KFe]06i^KP1]KFd0V9RH06IVIP25QHD0_kno
05aLG00d=3@0Z:RX03lo?`10@400IVIV02/[:`1DE5@0PX:20;Bd]026QXH0@41003Lg=`1lO7`0A4A4
01XJ6P0e=CD0EeMG0861P@2DU9@0?Shn06a/K01cLg<0Cdm?03Hf=P1GEeL0UIFE05aLG01lO7`0YZJV
07emO@1?Cdl0IFEU07=cL`1OGel0Jf][04U9B@1[Jf/0?Cdm071`L03;bl/0WIfM059BDP0n?Sh0a/K6
0080GEeM05@0B4Q804i>CP11@D40E5AD03Xj>P12@T80=SHf0<G5a@2ATI40>CTi069RHP1/K6`0LW9b
065QH@0L71`0MGEe0451@@0X:2P0BDU9075aL@0O7al0BDU90:BTY02j^[X0HF5Q03/k>`1JFUX0RHV9
03@d=01MGEd0J6QX06i^KP1GEeL0;2`/04];B`0L71`0>CTi08:2PP0j>SX09BDU08V9R@1;Bd/0>SXj
0:BTY030`<00KFe]03dm?@21PH40JVYZ05QHF01OGel071`L04i>CP2<S8`0dM7A051@D030`<00[:b/
09JFUP1YJFT0A4A403Ph>01^KVh0d];B0<O7a`2EUID0S8b<08N7Q`1mOGd0QHF507UiN@1WIfL0RXZ:
0=;BdP3;bl/0P82003Ph>01YJFT0Ogmo04i>CP0c<c<0Vi^K0410@00S8b<201`L701102l_;`11@D40
J6QX0;Vi^@34a<@0Ti>C04a<C00];Bd08R8R01hN7P0];Bd0JFUY07IfMP17AdL0=CDe030`<01>CTh0
GUiN03dm?@0P82008R8R04i>CP1UIFD0NGUi02@T900@41004Q8B03hn?P0b<S80G5aL05MGE`0[:b/0
CTi>05MGE`17AdL0:RXZ02DU9@14A4@09BDU03lo?`11@D40<C4a04I6AP1KFe/0E5AD05mOG`1[Jf/0
Ogmo0;bl_02VYZH0MWIf07emO@2YZJT0_;bl0492@P28R8P0XJ6Q06EUI@2GUiL0<c<c04Y:BP1OGel0
3@d=00h>3P0=3@d00P0@410201<C4`0N00h>3P0g=cL0Shn?06MWI`1ADE40>3Ph0410@01/K6`06QXJ
03Ph>016ATH04A4A00h>3P0C4a<0@d=302@T900Q8B40410@03`l?016ATH07AdM02<S8`1UIFD0NGUi
04I6AP20P800@d=302LW9`0L71`05aLG0P0E5AD0300/;2`0O7al08n?S`1SHf<0Ph>302XZ:P0b<S80
?Cdm03lo?`2HV9P0>CTi02`/;0803Ph>01806a/K01DE5@0E5AD0E5AD0;:b/P2_[jl0@41003Ph>01B
DU80Zj^[0=GEe@3Ng]h0d=3@0:VYZ@2`/;00g]kN09NGU`0h>3P301DE5@1304=3@`0n?Sh0L71`0;bl
_034a<@0bl_;0<S8b012@T807alO02DU9@17AdL06ATI01DE5@0M7Ad0;2`/02l_;`0G5aL0ADE50<k>
cP36a/H0VYZJ08j>SP2RXZ80UIFE06QXJ00n?Sh0=3@d04=3@`1fMWH0UiNG09VIV@2CTi<0`<300;jn
_P33`l<0YJFU06ATI00o?cl0M7Ad01/K6`0E5AD06a/K02l_;`1SHf<0]KFe07QhN01RHV80@T920:^[
Z`2WYjL0ZZZZ0<G5a@1kNg/0Hf=S06e]K@1?Cdl0C4a<07moO`3;bl/0YjNW0=3@d039bLT0N7Qh04i>
CP0N7Qh05aLG00l?3`0201DE5@1D01TI6@0E5AD04a<C038b<P1LG5`0EeMG01XJ6P0X:2P09RHV03Lg
=`1RHV80NWYj09ZJVP3De=@0h^;R0;>c/`29RHT0LG5a059BDP1>CTh0A4A404a<C01EEED0JFUY0;Rh
^03Kfm/0^k^k0:NWY`1EEED0K6a/0<;2`P24Q8@0=SHf01lO7`0a<C40XJ6Q06UYJ@0U9BD06ATI01`L
700M7Ad08B4Q02h^;P10@400Cdm?01`L700N7Qh0820P02TY:@1/K6`0AdM703`l?016ATH0Bd];05QH
F015ADD0EeMG06i^KP1kNg/0d];B0=WIf@2e]KD0`<300;bl_02ZZZX0P82009VIV@2EUID0c<c<0;:b
/P34a<@0_kno05YJFP1NGUh0IVIV07moO`2j^[X0D51@0410@00i>CT0IfMW0;bl_00];Bd08R8R0_oo
ool0001N0:>SX`24Q8@0/;2`0820P02d];@0QHF5055AD@1>CTh0M7Ad04Y:BP2;Rh/0E5AD06m_K`21
PH40;Rh^06QXJ012@T80Xj>S07emO@0n?Sh0R8R803hn?P0k>c/0>CTi06a/K01MGEd0=3@d065QH@25
QHD0820P06e]K@23Ph<0B4Q806i^KP0e=CD071`L06MWI`1:BTX0IVIV0820P00l?3`09BDU02h^;P0e
=CD08b<S01<C4`0X:2P0Bd];02/[:`17AdL0GUiN04m?C`0T92@0Bd];02`/;01HF5P0MGEe03<c<`0m
?Cd0[Zj^04M7A`0I6AT0DU9B0410@00j>SX0A4A4069RHP1NGUh0=cLg06IVIP1OGel0=CDe02l_;`1l
O7`0Hf=S051@D017AdL0D51@02LW9`0o?cl0@41003Lg=`1VIVH0EeMG03De=@1QHF40TY:B03dm?@17
AdL0?clo0492@P0I6AT0=CDe05aLG080;Bd]0>d0?3`l07]kN`0];Bd06ATI05]KF`1PH600BDU905aL
G02>SXh0RXZ:04i>CP1UIFD0EeMG03/k>`2JVYX0D51@07AdM01HF5P0?Shn09BDU014A4@0;Rh^06a/
K01?Cdl0K6a/059BDP19BDT0Cdm?07MgM`0n?Sh0QhN706QXJ016ATH0IFEU04M7A`11@D40IfMW08V9
R@1FEUH0FEUI04Y:BP1ADE40Vi^K06UYJ@1iNGT0GEeM02d];@2OWil0CTi>06MWI`1EEED0@T9202<S
8`27QhL0NGUi03dm?@1dM7@0N7Qh028R8P27QhL0YZJV04Q8B026QXH0H61P03<c<`15ADD0MGEe055A
D@1CDe<0Kfm_02HV9P0W9bL0[jn_03lo?`1;Bd/0M7Ad0410@01fMWH0TY:B04Q8B02QXJ40WIfM07em
O@1CDe<0Shn?0<c<c01ZJVX0:b/[04Y:BP1_Kfl0?clo06][J`2QXJ40V9RH051@D01JFUX0_Kfm08R8
R00f=SH0WYjN061PH01cLg<0<30`08N7Q`0a<C40?clo09fMW@2[Zj/0Cdm?07EeM@1YJFT0=CDe02d]
;@1ZJVX0GEeM079bLP26QXH0D51@07QhN02o_kl0@D5103Lg=`2QXJ40BDU903dm?@1eMGD09BDU03lo
?`1@D500IFEU07=cL`1@D500=3@d0861P@1>CTh09BDU03lo?`2JVYX0/K6a0;Fe]@14A4@0HF5Q05mO
G`18B4P0;bl_07emO@1aLG40@41007YjNP2^[Zh0Cdm?04a<C024Q8@0Kfm_04m?C`1BDU80G5aL08^;
R`0j>SX0EeMG08^;R`1[Jf/0ADE503dm?@33`l<0D51@03`l?01^KVh0N7Qh05ADE01ADE40Cdm?04Q8
B00k>c/0aLG50861P@0e=CD0HF5Q079bLP1IFET0=cLg02XZ:P23Ph<0>3Ph02h^;P1/K6`0N7Qh024Q
8@0b<S80M7Ad0;no_`0d=3@0B4Q809^KV`22PX80>SXj03dm?@0_;bl0C4a<01`L700W9bL0K6a/05AD
E00c<c<0L71`018B4P0V9RH0W9bL0820P013@d<0U9BD0:RXZ00j>SX0>c/k08B4Q01_Kfl0@T92061P
H00_;bl0ATI603Hf=P2:RXX0=cLg0<S8b03;bl/0^;Rh05=CD`0m?Cd0>CTi08b<S02j^[X0][Jf05EE
E@0d=3@0:2PX01dM7@0I6AT00P0F5QH09`0G5aL0Y:BT06IVIP20P800JFUY03Ti>@17AdL0KVi^0:6Q
X@2d];@0De=C020P800H61P06QXJ0492@P17AdL092@T06YZJP2GUiL0WIfM09RHV01MGEd0=3@d02TY
:@0Q8B40<c<c09:BTP2ATI40NGUi071`L023Ph<0P82006a/K01DE5@0O7al09^KV`1FEUH0F5QH01DE
5@0201TI6@0D03Lg=`1>CTh0EEEE07emO@0k>c/0>CTi01DE5@0`<300MgMg07=cL`1dM7@0IFEU04E5
A@1MGEd0JFUY05mOG`1iNGT0BDU905MGE`1JFUX204e=C@0>06ATI00K6a/0820P06MWI`2YZJT0>SXj
09nOW`0o?cl0820P04m?C`1BDU80IfMW03lo?`0=3@d200h>3P1X00l?3`0>3Ph0410@010@400B4Q80
>3Ph061PH00m?Cd09BDU034a<@0m?Cd0NGUi04M7A`0l?3`0FEUI01LG5`0D51@05ADE05ADE017AdL0
<30`01PH6011@D40XZ:R03lo?`0N7Qh0<c<c09fMW@2EUID0MWIf069RHP1<C4`0@d=303hn?P0k>c/0
=CDe03`l?01EEED0_[jn096AT@2;Rh/0IFEU06ATI014A4@0<c<c0:f][@1dM7@06a/K01DE5@0G5aL0
<30`038b<P12@T80UIFE0;jn_P2DU9@05QHF024Q8@0l?3`0Rh^;07QhN03Bd]80CDe=04E5A@1XJ6P0
L71`01/K6`0G5aL06a/K02LW9`0_;bl0HV9R06m_K`29RHT0CDe=0<K6aP3:b/X0clo?08^;R`0c<c<0
7QhN02HV9P0/;2`06ATI02d];@0f=SH0820P03Xj>P1_Kfl0f][J07EeM@0d=3@0Ogmo096AT@2KVi/0
U9BD0:n_[`2KVi/0YZJV09ZJVP1XJ6P0@d=304];B`1cLg<20;Bd]00408V9R@0b<S80>SXj069RHP<0
5ADE04807AdM0451@@1^KVh0HV9R06i^KP17AdL0^;Rh09RHV02DU9@0ZZZZ0<K6aP2GUiL0VYZJ08>3
P`1jNWX0PH610;>c/`3UiND0`/;20:FUY@1lO7`0L71`03Ti>@0N7Qh0410@01<C4`0J6QX04a<C00l?
3`0A4A405aLG06=SH`1cLg<0?Cdm02TY:@0T92@0Bd];09VIV@2YZJT0b<S80<?3``3UiND0h>3P0<C4
a02`/;00YjNW09^KV`2LW9`0UYJF09^KV`3@d=00i>CT0>?Sh`2`/;00YjNW0;bl_02^[Zh0NGUi0:>S
X`2XZ:P0De=C02`/;01nOWh0JFUY07moO`0Y:BT201`L700[028R8P0/;2`0BTY:04U9B@0L71`08B4Q
02TY:@0n?Sh0R8R805eMG@1;Bd/0AdM704Q8B00[:b/07AdM02HV9P1PH600TI6A0<[:bP3Lg=`0c/k>
0;Vi^@2FUYH0RXZ:07YjNP1dM7@0^k^k0=gMg@38b<P0/k>c08R8R00/;2`0:2PX034a<@18B4P0L71`
08Z:RP0o?cl0?Cdm06=SH`2<S8`07alO02PX:002ooooo`0001l0W9bL08Z:RP1^KVh0G5aL0:b/[01b
LW80Bd];04M7A`0l?3`0GemO0;Bd]02>SXh0P82005mOG`1>CTh0YZJV04I6AP1gMgL0Kfm_05MGE`2W
YjL0MGEe0492@P0k>c/0Fe]K0410@01CDe<0Lg=c08f=S@0S8b<0JVYZ0080<S8b04<0LG5a03hn?P0X
:2P0QXJ602HV9P0e=CD0F5QH051@D00j>SX0820P04E5A@1?Cdl07QhN038b<P1DE5@061PH02d];@1E
EED0HF5Q02/[:`0c<c<09BDU05mOG`29RHT0?Cdm01dM7@24Q8@092@T03@d=01dM7@0@41001dM7@0L
71`0=cLg05=CD`0_;bl0Kfm_05iNGP0R8R806a/K04U9B@0d=3@0=cLg04U9B@1SHf<0=3@d03`l?00V
9RH0:BTY07YjNP1OGel0E5AD07EeM@1`L700=SHf05eMG@1@D500@D5101/K6`0m?Cd0K6a/020P800m
?Cd0CDe=07=cL`0X:2P07alO0080HF5Q0?l07alO04Q8B01ZJVX0K6a/0451@@1SHf<0CDe=03lo?`1a
LG40<C4a06a/K00`<3008B4Q08j>SP19BDT0<c<c05mOG`0K6a/0DU9B05UIF@1BDU80BTY:05ADE00V
9RH0N7Qh065QH@12@T80Hf=S0410@00`<300AdM706m_K`16ATH0E5AD04A4A00e=CD0L71`06QXJ01/
K6`0:2PX03dm?@2WYjL0EEEE06e]K@1QHF40:b/[03`l?02YZJT0TY:B051@D01hN7P0MGEe02d];@1Y
JFT0OGem03Ti>@1eMGD0Kfm_05IFEP1;Bd/0FUYJ05aLG01>CTh0Hf=S02d];@0L71`0V9RH04i>CP1;
Bd/0HF5Q01DE5@1cLg<0TI6A05]KF`2CTi<0K6a/03Lg=`0F5QH0M7Ad0:BTY01YJFT0<S8b03/k>`1S
Hf<0?clo06MWI`21PH40MWIf065QH@1TI6@0`/;20:VYZ@1/K6`0b/[:05=CD`1lO7`0?3`l08B4Q00h
>3P0:BTY04a<C024Q8@0?Shn034a<@1BDU80=CDe03lo?`1lO7`0HV9R09BDU02MWId0DE5A07YjNP33
`l<0ATI6034a<@2>SXh0:RXZ05iNGP2PX:00<c<c03/k>`1CDe<0SXj>06QXJ00o?cl0>SXj0:6QX@1W
IfL08B4Q02`/;01QHF40Jf][096AT@1FEUH0E5AD06a/K01MGEd0;2`/04];B`1MGEd0?Shn0861P@2]
[Jd0IVIV04I6AP1KFe/0FEUI01hN7P1FEUH0MgMg09VIV@1]KFd0NWYj07emO@1KFe/06a/K05mOG`2m
_Kd0JVYZ04Y:BP0o?cl0J6QX03hn?P1>CTh0Hf=S038b<P15ADD0YjNW07=cL`12@T80OGem09fMW@1]
KFd0@41001/K6`1VIVH0<c<c02DU9@1<C4`0L71`03@d=00o?cl0Ph>30<[:bP18B4P0=CDe07QhN01m
OGd0ATI604E5A@10@400E5AD02l_;`0T92@0Fe]K04e=C@0g=cL0O7al02<S8`0R8R80MWIf07YjNP1:
BTX0XZ:R0;Rh^00N7Qh08R8R0820P02HV9P0MgMg03Xj>P0M7Ad0EeMG05YJFP1WIfL0<c<c0;Rh^02b
/[80^;Rh05]KF`16ATH0MGEe07moO`2c/k<0D51@02LW9`0O7al0820P02<S8`0R8R808B4Q01hN7P0I
6AT0De=C06QXJ01@D500HF5Q06a/K00h>3P0;bl_0861P@36a/H0EUIF02`/;00J6QX07alO03Lg=`0K
6a/05ADE04e=C@1QHF40;Bd]07EeM@2b/[800200^k^k06m_K`1=CDd0FUYJ08n?S`2EUID0Ph>308:2
PP20P800Vi^K08N7Q`2LW9`0/k>c0;Vi^@1_Kfl0Ng]k01/K6`0O7al07AdM028R8P1KFe/0EUIF0820
P01]KFd0ATI6034a<@0i>CT0;Bd]02/[:`0_;bl0@41005YJFP80GEeM00P0:RXZ04i>CP1WIfL0C4a<
06IVIP1MGEd0CTi>04I6AP8071`L00`0C4a<0;6a/@3>c/h0^KVi07emO@0m?Cd0D51@08f=S@2JVYX0
@41001@D500>3Ph200d=3@1^010@400>3Ph03Ph>01<C4`1FEUH0HV9R055AD@0Z:RX0>3Ph04];B`27
QhL0FEUI071`L026QXH0=SHf03De=@0h>3P0Ng]k06e]K@1DE5@0@D5104A4A01NGUh0Vi^K05ADE01E
EED0XZ:R0<71`@2<S8`0AdM703Ti>@0[:b/09RHV02`/;00];Bd0D51@06IVIP2NWYh0aLG509fMW@3:
b/X0GUiN0820P02UYJD0alO70:RXZ01hN7P0HV9R06=SH`1RHV80GEeM06MWI`36a/H0f=SH09^KV`0M
7Ad03Ph>018B4P0V9RH0CTi>09fMW@16ATH0:RXZ08b<S019BDT0>3Ph03<c<`0`<3009RHV02l_;`23
Ph<0W9bL0;Jf]P1]KFd0Fe]K0<c<c03@d=00R8R807UiN@1<C4`0>SXj04i>CP0d=3@0@D5101hN7P12
@T80KFe]0<_;b`2c/k<0BTY:02TY:@0m?Cd0YjNW09BDU01EEED0@41006YZJP2/[:`0E5AD03hn?P0c
<c<0;2`/05eMG@2NWYh0TY:B065QH@0];Bd0@D5104Q8B00D51@301DE5@0K02h^;P1SHf<0JVYZ051@
D01=CDd0`L7109bLW02:RXX0CTi>05ADE02YZJT0=CDe02l_;`0d=3@0De=C08>3P`37alL0W9bL05=C
D`1kNg/0Q8B409>CT`0c<c<06QXJ01DE5@0X:2P04a<C00804A4A05404a<C02<S8`2IVIT0UYJF034a
<@1<C4`0Cdm?096AT@36a/H0dM7A0:NWY`3IfMT0[Jf]06e]K@10@400<c<c024Q8@0L71`06ATI01XJ
6P27QhL0emOG08R8R01?Cdl0MgMg09NGU`2BTY80?clo04A4A021PH40/[:b0:>SX`1YJFT0JVYZ04I6
AP1QHF40>CTi01hN7P0M7Ad0;Bd]05QHF011@D407alO02LW9`13@d<0Bd];07YjNP1^KVh0ADE504m?
C`0b<S8071`L01lO7`0W9bL0BDU90<?3``30`<00c<c<09RHV01lO7`0?Cdm02TY:@0b<S80JFUY0<g=
c@3?cll0UiNG09RHV024Q8@0;2`/02l_;`0e=CD0@d=3051@D02FUYH0GemO04E5A@1hN7P0D51@02<S
8`0Y:BT00_ooool0000Y08F5Q@2GUiL0X:2P05UIF@2QXJ40MgMg06UYJ@1WIfL0CDe=04Q8B01UIFD0
O7al08>3P`1DE5@09RHV09FEU@1=CDd0IFEU02l_;`17AdL0UIFE06e]K@0m?Cd0?3`l05UIF@0d=3@0
;Bd]05IFEP26QXH0:b/[06YZJP1lO7`0B4Q8069RHP0_;bl08B4Q08R8R01DE5@0A4A404m?C`14A4@0
0P0^;Rh05@13@d<0<C4a01`L700f=SH0D51@02l_;`0d=3@0?clo05YJFP0Y:BT0ADE5034a<@1;Bd/0
IFEU03dm?@0T92@0Z:RX04A4A00S8b<0BDU9059BDP02034a<@0V05=CD`0a<C40=SHf08b<S01aLG40
>SXj01`L701DE5@0:BTY024Q8@1JFUX0R8R803hn?P16ATH0<S8b01XJ6P1[Jf/0LG5a069RHP2ATI40
NWYj028R8P1OGel0JVYZ05IFEP0Y:BT0@T9206a/K00J6QX0?Cdm04U9B@1cLg<0<c<c02d];@1jNWX0
MgMg04a<C01HF5P205eMG@3R0410@02>SXh0DU9B04U9B@1/K6`08B4Q09BDU01OGel0?clo07IfMP0]
;Bd0=3@d04m?C`0/;2`0Fe]K04A4A00J6QX0ADE505aLG00e=CD0MWIf05]KF`19BDT0O7al06ATI00l
?3`0@d=305QHF00n?Sh0N7Qh05MGE`14A4@0OWin05]KF`2?Shl0A4A402d];@28R8P0@T9207AdM01F
EUH08R8R01hN7P2;Rh/0LG5a059BDP2ATI40QhN70410@01YJFT0J6QX02d];@26QXH0N7Qh06EUI@1>
CTh0FEUI04m?C`1nOWh0VYZJ04Q8B00U9BD0SHf=04=3@`10@400GemO03dm?@1dM7@0QXJ6059BDP2E
UID0K6a/065QH@1@D500Ogmo0;Rh^01`L700>SXj0410@01IFET0DE5A08F5Q@23Ph<0NWYj06ATI02S
Xj<0bl_;0:b/[01YJFT0clo?05iNGP1JFUX0ADE50:j^[P15ADD0@410051@D02:RXX0Bd];04A4A01B
DU807QhN04I6AP26QXH0CDe=071`L026QXH06QXJ069RHP2WYjL0Fe]K030`<02MWId08b<S03Hf=P1S
Hf<0:b/[04A4A01WIfL0/;2`07inOP0V9RH08R8R06m_K`24Q8@0?3`l051@D026QXH0P8200:f][@0_
;bl0IfMW0:ZZZP1`L700=cLg05=CD`1aLG409BDU05UIF@2YZJT0P82004e=C@1IFET0DE5A020P8010
@400EUIF07]kN`1SHf<0PH6107QhN01bLW80;Bd]04Q8B02IVIT0Hf=S04U9B@1:BTX0EeMG01lO7`1>
CTh0IFEU05aLG00f=SH0[Zj^03dm?@0M7Ad0K6a/08V9R@2<S8`0MgMg024Q8@1/K6`0F5QH02XZ:P1:
BTX0Rh^;034a<@16ATH0PX:20<[:bP1JFUX0;Rh^06][J`2MWId0Fe]K069RHP1PH600Lg=c05eMG@0W
9bL0HV9R04I6AP0m?Cd0ZZZZ03/k>`0Y:BT0VIVI055AD@15ADD0^[Zj0;fm_@1KFe/09RHV04I6AP1G
EeL0K6a/06IVIP0i>CT0DE5A04i>CP0R8R805ADE0<?3``2`/;00Zj^[06QXJ02FUYH0OWin08f=S@1o
Ogl0;2`/02HV9P0M7Ad071`L01dM7@8071`L0P0M7Ad0<00Z:RX0Jf][0410@00j>SX0FUYJ06=SH`0j
>SX0@d=30::RXP1cLg<0AdM7024Q8@0Z:RX0=cLg01LG5`0E5AD0E5AD04U9B@0K6a/0=cLg07AdM01n
OWh0>CTi03Hf=P0_;bl0:b/[04E5A@1UIFD0DE5A04Y:BP14A4@0EUIF09BDU026QXH0R8R80:f][@2=
SHd0JFUY02h^;P0];Bd0:BTY04U9B@1cLg<0U9BD092@T01VIVH0?Shn024Q8@8071`L03`061PH01/K
6`0k>c/0?clo06ATI00h>3P0:b/[055AD@1aLG40KVi^0;2`/02TY:@0JFUY07QhN02KVi/0d=3@0;Fe
]@2m_Kd0bLW90:JVYP2b/[80SXj>06a/K02e]KD0O7al065QH@1IFET0@d=303@d=00W9bL05aLG01PH
600W9bL0[Zj^07IfMP2WYjL0Cdm?055AD@1XJ6P0LG5a03hn?P1@D500OGem024Q8@0M7Ad061PH05EE
E@2;Rh/0=CDe038b<P0^;Rh09BDU03hn?P2RXZ80YjNW08^;R`2VYZH0Zj^[05]KF`0Y:BT2020P801<
02@T900Q8B409bLW04U9B@27QhL0fm_K0=cLg039bLT0fm_K08Z:RP1mOGd0WinO04];B`0n?Sh0ATI6
038b<P0];Bd0ADE50;Rh^03Zj^X0jNWY0;6a/@1`L70051@D010@400E5AD0BDU908B4Q01^KVh0K6a/
08j>SP0M7Ad08R8R02<S8`0Y:BT08R8R01dM7@1dM7@0Q8B403Hf=P0Y:BT0C4a<07YjNP3Ph>00[Zj^
06a/K01kNg/0NWYj07emO@12@T807QhN04Y:BP1iNGT0UYJF0861P@2LW9`0FEUI02/[:`0l?3`0CDe=
024Q8@1aLG40<c<c020P800f=SH0RHV906MWI`1EEED0Fe]K096AT@36a/H0UYJF05]KF`12@T80DE5A
024Q8@805ADE00l051@D01LG5`1;Bd/0DE5A08R8R02SXj<0dM7A0;>c/`1KFe/0BDU90492@P0a<C40
Kfm_01/K6`0G5aL00`0E5AD07P1ZJVX0`l?307alO01DE5@0EUIF0861P@1NGUh06ATI01LG5`0_;bl0
8b<S02d];@0F5QH06ATI01lO7`1NGUh0bLW90;>c/`3@d=00dm?C0<G5a@3IfMT0bl_;08j>SP3Fe]H0
BDU901@D500C4a<04Q8B01<C4`805ADE03h092@T0;6a/@2ZZZX0>3Ph0410@02GUiL0OWin08N7Q`1_
Kfl0ADE503Ph>01NGUh0N7Qh0:n_[`2TY:@0KVi^03lo?`1GEeL0BTY:02TY:@0k>c/0P82003Ti>@0W
9bL0@T9203hn?P12@T80FEUI08^;R`1?Cdl0ATI601hN7P0O7al0820P03Ph>01oOgl0GEeM0:JVYP39
bLT0^;Rh07=cL`0n?Sh0KFe]0:>SX`2TY:@0e]KF0<?3``0k>c/0H61P065QH@0V9RH0<c<c03Ti>@0l
?3`0AdM707QhN02?Shl0B4Q807YjNP0f=SH0>3Ph05aLG0;ooooo0000A`2;Rh/0P82009jNWP1NGUh0
M7Ad051@D02;Rh/0Y:BT06a/K01>CTh0K6a/07QhN02EUID0QhN702/[:`2>SXh0@d=307EeM@1iNGT0
EeMG0:JVYP1]KFd0>SXj04A4A02@T900JVYZ0451@@1[Jf/0PX:2038b<P1QHF40S8b<05YJFP1YJFT0
<30`03Ph>02NWYh0De=C04Y:BP1ADE40BDU904E5A@0k>c/0AdM7030`<00U9BD0D51@06YZJP0_;bl0
@41003lo?`1CDe<0:b/[05EEE@0`<300@D5105QHF00/;2`0>CTi0::RXP1HF5P0:RXZ05ADE00`<300
:b/[03dm?@1ZJVX0CDe=01lO7`1>CTh0IVIV0080<c<c08@0QHF504i>CP0_;bl0@D5104e=C@0Y:BT0
G5aL03hn?P0_;bl0HF5Q061PH01aLG40XZ:R07]kN`0g=cL0De=C0410@012@T806QXJ05=CD`1]KFd0
6QXJ034a<@13@d<0IVIV01DE5@0X:2P0D51@06UYJ@1=CDd0GEeM07UiN@1JFUX0=3@d05aLG01;Bd/0
@41006e]K@0T92@0QhN7061PH00n?Sh0OWin02DU9@1>CTh0HF5Q03Xj>P1LG5`0CDe=01TI6@1FEUH0
JFUY03Ti>@1jNWX0=cLg04=3@`1gMgL0GUiN04E5A@0k>c/0BTY:02TY:@1CDe<0EeMG0451@@1ZJVX0
CDe=05IFEP1BDU80=SHf08^;R`0b<S80Jf][07IfMP0o?cl0<30`08b<S010@400DE5A09VIV@29RHT0
?Cdm06m_K`1SHf<08R8R06=SH`1XJ6P0IFEU04E5A@1@D500?Shn04M7A`1cLg<0?3`l024Q8@2<S8`0
:b/[06EUI@22PX80FEUI08:2PP24Q8@0CTi>0:b/[02e]KD0P82006QXJ02RXZ80^k^k06UYJ@17AdL0
IVIV06QXJ01NGUh0Shn?07moO`1RHV80?Shn071`L02n_[h0Vi^K06YZJP3Bd]80P82006UYJ@0f=SH0
V9RH05IFEP10@400E5AD08b<S011@D42075aL@80;Rh^05T0IFEU05MGE`2KVi/0NGUi05aLG02FUYH0
]KFe034a<@0k>c/0X:2P04=3@`0d=3@0GUiN01TI6@0n?Sh0M7Ad09nOW`20P800@T9202h^;P1YJFT0
BTY:02DU9@1BDU80SXj>08B4Q02WYjL0:BTY03dm?@1YJFT0EEEE02/[:`1LG5`0GEeM01lO7`1IFET0
Ti>C05]KF`1WIfL0Shn?08j>SP1IFET0L71`07alO02`/;00EeMG07IfMP2k^k/0U9BD05=CD`1<C4`0
[jn_05YJFP1CDe<0DE5A04E5A@0T92@0B4Q803hn?P19BDT0>SXj0<71`@1[Jf/0<S8b04m?C`1`L700
OWin061PH00`<300Ng]k03lo?`0n?Sh0JFUY07YjNP0D51@0?clo08b<S02VYZH0?Shn02`/;01RHV80
PH6101dM7@15ADD0FUYJ06UYJ@1VIVH0=3@d07emO@0203Hf=P0R0861P@0Y:BT0=3@d09FEU@1RHV80
=cLg09VIV@2QXJ40?3`l04=3@`27QhL0Shn?07MgM`11@D40?clo09fMW@2XZ:P0LG5a02XZ:P36a/H0
U9BD06m_K`3Fe]H0SHf=09jNWP2YZJT0ADE502d];@0Y:BT08B4Q01lO7`0P82007AdM01hN7P806a/K
00d07AdM05QHF00n?Sh0@T9204=3@`1cLg<0E5AD038b<P1lO7`0RXZ:05]KF`1gMgL0CDe=00806ATI
00X05aLG075aL@1_Kfl0<C4a03lo?`1SHf<0A4A401`L700S8b<0:RXZ0P0T92@05@0_;bl0H61P04i>
CP12@T80Kfm_08J6QP2>SXh0[Jf]0<;2`P2BTY80/K6a09bLW01`L700LG5a08N7Q`2n_[h0Rh^;08b<
S01JFUX0;2`/01dM7@0201`L701A024Q8@0c<c<0:b/[034a<@1RHV80PX:2034a<@15ADD0e]KF0<_;
b`31`L40][Jf0<S8b035aLD0Z:RX06MWI`2=SHd0/;2`0;jn_P2FUYH0UIFE09BDU03;bl/0`<3005]K
F`0P82008R8R03De=@12@T80GUiN065QH@1ZJVX0[Zj^0<30`01mOGd0OWin09^KV`2JVYX0ZZZZ05UI
F@15ADD0TI6A08^;R`1WIfL0HF5Q04Q8B02=SHd0[jn_04=3@`15ADD0;bl_02TY:@0];Bd0MWIf0<30
`01:BTX0DE5A0<k>cP39bLT0PH61065QH@1FEUH0DE5A05=CD`1HF5P0QhN708B4Q03Fe]H0c<c<0<_;
b`38b<P0Shn?0;Vi^@1WIfL0R8R80;Zj^P2<S8`0TI6A09nOW`3IfMT0dM7A0080c/k>00X0Xj>S0:^[
Z`1;Bd/04a<C01DE5@1>CTh0Lg=c0>?Sh`3QhN40CDe=0P0L71`06`0R8R80:BTY02DU9@0M7Ad0N7Qh
04=3@`0H61P07AdM034a<@1[Jf/0c<c<0=WIf@2ATI40X:2P0;Jf]P2IVIT0?Shn065QH@2XZ:P0K6a/
02@T901OGel0Vi^K059BDP0k>c/0Cdm?02<S8`0201TI6@0N061PH00k>c/0>CTi05eMG@2EUID0TI6A
04a<C02QXJ40P82008V9R@2PX:00P82007IfMP0O7al05QHF01DE5@0G5aL0;2`/07YjNP1]KFd0>c/k
03Hf=P1iNGT0MgMg034a<@0k>c/0BDU9051@D01MGEd0:b/[0P0G5aL0H00F5QH0<S8b09fMW@2SXj<0
XZ:R08Z:RP1PH600CDe=06ATI00J6QX06ATI01`L700V9RH0DE5A020P800M7Ad0=cLg08B4Q02i^KT0
eMGE0=SHf02SXj<0^[Zj0>WYj@3>c/h0LW9b0<o?c`0[:b/04a<C01@D500B4Q804a<C01DE5@0G5aL0
CDe=0<W9b@1WIfL0=3@d03Xj>P1NGUh0:b/[07EeM@1oOgl0EUIF04Q8B00d=3@0?clo08>3P`27QhL0
Rh^;09JFUP2<S8`0N7Qh08R8R02;Rh/0WYjN03Xj>P1;Bd/0ATI60492@P1?Cdl0EUIF07YjNP1QHF40
;Rh^01hN7P0Q8B40?Cdm07moO`17AdL0Bd];0:^[Z`3MgMd0eMGE0=KFeP3De=@0U9BD02LW9`0K6a/0
LG5a0;>c/`0e=CD0BTY:04i>CP0S8b<0<S8b03Hf=P0o?cl0@d=305YJFP2KVi/0M7Ad07inOP11@D40
Lg=c07AdM0;ooooo0000C`2EUID0Shn?0:NWY`1kNg/0]KFe07QhN020P800QHF506=SH`1@D500IFEU
04i>CP2GUiL0MGEe02XZ:P1fMWH0B4Q80:b/[01lO7`0Hf=S09RHV01IFET0J6QX075aL@2>SXh0HV9R
0492@P1KFe/0ATI604E5A@21PH40M7Ad05MGE`1BDU80820P024Q8@1oOgl0?Shn04E5A@12@T80:b/[
038b<P0e=CD0;bl_020P800G5aL0@T92055AD@0_;bl0>SXj0492@P11@D408R8R055AD@0X:2P0>SXj
05UIF@0k>c/09RHV0:NWY`1?Cdl09RHV04Y:BP19BDT0;2`/03Xj>P1IFET0Hf=S02l_;`1[Jf/0GEeM
03<c<`0U9BD0D51@04a<C00j>SX0CTi>05ADE00J6QX00P0m?Cd04`0e=CD0I6AT04M7A`13@d<0Q8B4
08:2PP0^;Rh0H61P04a<C019BDT07QhN05YJFP1/K6`08R8R04A4A01MGEd0KFe]03Hf=P0Z:RX00P1Q
HF409019BDT0RXZ:0;Zj^P1bLW80AdM706YZJP13@d<0H61P0861P@13@d<0RXZ:06ATI01GEeL0QXJ6
03`l?00i>CT0GEeM03dm?@1MGEd0CDe=03Xj>P1NGUh0IVIV03Hf=P1hN7P0D51@03@d=01fMWH0J6QX
03Xj>P0l?3`0FEUI03De=@1LG5`0BTY:03Hf=P80Jf][09/0HF5Q04i>CP0];Bd0UIFE051@D01JFUX0
GUiN03dm?@0`<300N7Qh06][J`0o?cl0S8b<096AT@0o?cl0MGEe07QhN01@D500TY:B07QhN01ZJVX0
EeMG055AD@1GEeL0A4A407AdM00h>3P08B4Q08b<S00i>CT0=cLg07IfMP1;Bd/0NWYj07AdM015ADD0
PH6108:2PP1oOgl0HF5Q09BDU02g]kL0@T9202LW9`1/K6`0M7Ad05MGE`2`/;00_;bl096AT@1HF5P0
UIFE0<71`@1]KFd0Fe]K0:j^[P2@T900IfMW04I6AP2^[Zh0ADE504m?C`1aLG40Shn?03dm?@0e=CD0
Hf=S02d];@10@400MWIf05ADE02LW9`0TI6A06EUI@2i^KT0Zj^[04A4A00k>c/0Y:BT0410@00f=SH0
Hf=S02/[:`0n?Sh0EeMG09RHV01PH600ATI603Ti>@1oOgl0Hf=S024Q8@0c<c<0YjNW0;^k^`2YZJT0
ADE5051@D01FEUH0ADE502PX:01iNGT0K6a/03lo?`1KFe/0X:2P04M7A`14A4@0G5aL06a/K00];Bd0
J6QX08n?S`2WYjL0HV9R06EUI@1VIVH0LW9b02XZ:P11@D40Zj^[05UIF@0U9BD0GemO07=cL`18B4P0
R8R806UYJ@0e=CD0BTY:0<71`@1mOGd0De=C09VIV@2VYZH0E5AD02XZ:P0M7Ad0J6QX02XZ:P0Y:BT0
GEeM06IVIP0U9BD0ADE507UiN@2[Zj/0:2PX04=3@`1hN7P0HV9R03Xj>P18B4P0AdM7055AD@0202/[
:`0T075aL@1HF5P0C4a<0:RXZ00l?3`09bLW08Z:RP1SHf<0B4Q80;Vi^@2[Zj/0ADE502<S8`14A4@0
De=C0492@P1FEUH0?Cdm05ADE02<S8`0JFUY02h^;P3Cdm<0aLG50<c<c03AdM40[jn_0;no_`1iNGT0
ADE504=3@`0W9bL07QhN024Q8@0S8b<09BDU0P0Q8B40=@0N7Qh06QXJ04I6AP18B4P0@d=302d];@0n
?Sh0MGEe02TY:@1HF5P0KFe]05=CD`1GEeL0ATI601lO7`0W9bL0ATI604];B`1GEeL0Ti>C0;Rh^02i
^KT0UIFE065QH@1FEUH0ATI603`l?00c<c<09RHV030`<01<C4`0IVIV092@T02i^KT0`L710:n_[`30
`<00b/[:0;Bd]036a/H0^[Zj07alO01WIfL0/k>c09jNWP25QHD0L71`061PH00_;bl09BDU03Hf=P0[
:b/06ATI00805ADE07H0?3`l0<C4a02i^KT0b/[:0=?Cd`3Fe]H0bl_;0;:b/P2QXJ40HF5Q059BDP1;
Bd/0K6a/0<?3``35aLD0]KFe0:RXZ024Q8@0NWYj07EeM@26QXH0D51@01@D500E5AD04A4A01DE5@0I
6AT09BDU02l_;`1iNGT0a/K60:b/[02MWId0][Jf0=?Cd`2IVIT0][Jf04e=C@0S8b<09RHV03De=@0m
?Cd0HV9R0:6QX@1OGel0HV9R03lo?`0i>CT0BDU90820P01jNWX0ZZZZ07EeM@36a/H0eMGE0:2PX01k
Ng/0E5AD03/k>`0d=3@0:RXZ04Y:BP2=SHd0d];B0;Vi^@1lO7`0W9bL07EeM@2<S8`0410@02@T901^
KVh0I6AT0:NWY`3De=@0NWYj03Lg=`0j>SX0Zj^[06=SH`29RHT0^KVi03Xj>P0G5aL0D51@09RHV03K
fm/0WinO02d];@0L71`06ATI01lO7`0L71`07AdM01lO7`2:RXX0=cLg01XJ6P0H61P07alO03<c<`3E
eMD0j^[Z0=OGe`3AdM40eMGE0=CDe02SXj<0`<30069RHP0K6a/07QhN06=SH`2GUiL0<30`0492@P18
B4P05QHF0P0E5AD0P00N7Qh0IfMW05YJFP1:BTX0DE5A07MgM`39bLT0dm?C0410@01DE5@0X:2P09:B
TP2GUiL0HV9R03dm?@0R8R806QXJ06IVIP1mOGd0=3@d02TY:@0a<C40C4a<05mOG`0V9RH0=3@d03/k
>`1gMgL0CDe=04Y:BP0K6a/07QhN0451@@1jNWX0ADE504Y:BP28R8P0S8b<0;2`/02=SHd0XZ:R02`/
;00O7al09RHV02XZ:P1;Bd/09bLW01hN7P0m?Cd0MgMg0=_Kf`3Cdm<0b<S80=gMg@2][Jd0a/K60<g=
c@35aLD0b/[:020P800D51@04a<C01DE5@0C4a<05ADE01`L702<S8`0XJ6Q02`/;00N7Qh0@D51059B
DP0^;Rh0>3Ph07]kN`1TI6@0>CTi04a<C01CDe<0WYjN06a/K015ADD0I6AT08R8R02][Jd0b/[:0=;B
dP3EeMD0XZ:R07YjNP1ADE40EUIF06UYJ@1HF5P0Hf=S06][J`0/;2`0<30`07QhN025QHD0;Rh^03Ti
>@2@T900^[Zj0=[JfP38b<P0^k^k0;Rh^02b/[80AdM702<S8`1BDU80^[Zj03Lg=`18B4P0@D51020P
800b<S80:BTY03Hf=P15ADD0DE5A07inOP1lO7`0[Jf]0861P@1:BTX0D51@0_ooool0001a09BDU02E
UID0MWIf092@T02WYjL0Ogmo09VIV@2PX:00I6AT05YJFP2>SXh0Ogmo0:JVYP27QhL0=cLg08N7Q`11
@D40N7Qh06i^KP1SHf<0V9RH03lo?`16ATH0@D5107moO`1OGel0De=C05YJFP1BDU80=cLg06UYJ@1Z
JVX0IFEU05aLG00b<S809bLW09VIV@0o?cl0Hf=S05mOG`0e=CD0<S8b02l_;`0o?cl0<30`01dM7@1:
BTX0Cdm?02/[:`15ADD0EeMG05EEE@0[:b/0HF5Q02h^;P1?Cdl0E5AD030`<00W9bL0YJFU04Y:BP0]
;Bd0Bd];03dm?@0];Bd0<c<c05ADE01NGUh0<S8b0820P01IFET0>3Ph02@T901CDe<0@410030`<01>
CTh0E5AD02/[:`1?Cdl0:RXZ02@T901XJ6P0D51@071`L02OWil0Q8B403De=@1cLg<0KVi^065QH@0R
8R80Cdm?069RHP0L71`0=cLg04M7A`1ZJVX0<S8b030`<01TI6@0HF5Q0492@P1:BTX0P82006m_K`13
@d<0MGEe04I6AP0n?Sh0Lg=c04Q8B01[Jf/00P15ADD0T`1lO7`0@D5103`l?01LG5`0=3@d06e]K@1O
Gel0@T9206i^KP1ADE40CTi>08R8R01>CTh0A4A408>3P`1:BTX0Fe]K061PH01ZJVX0@41007IfMP0[
:b/0Cdm?08b<S01/K6`0JFUY030`<00l?3`0Z:RX05]KF`1YJFT0FEUI04E5A@1YJFT0[:b/06YZJP17
AdL0T92@071`L015ADD0WYjN0820P01BDU80[jn_07AdM01QHF40IFEU05MGE`1IFET0Lg=c0:>SX`0f
=SH0>SXj08V9R@0l?3`0>c/k07IfMP0_;bl0Ng]k09ZJVP1CDe<0Z:RX09jNWP1IFET0?3`l0:NWY`2i
^KT0M7Ad03dm?@1iNGT0K6a/04];B`1iNGT0JFUY07alO01@D500VIVI0<_;b`22PX80G5aL07UiN@1T
I6@0>c/k05]KF`2@T900Cdm?03Ph>01/K6`0Ph>304I6AP17AdL0MWIf02LW9`1DE5@0Rh^;04U9B@2U
YJD0QXJ60451@@25QHD0U9BD05ADE01:BTX0_[jn038b<P19BDT0Jf][02TY:@1OGel0T92@0;fm_@2I
VIT0AdM703Ti>@21PH40J6QX01lO7`0_;bl0R8R80;6a/@2TY:@0A4A408B4Q01cLg<0@T9202@T901Q
HF40ADE502TY:@1_Kfl0XJ6Q07IfMP1eMGD0NWYj07alO00f=SH0@d=305iNGP27QhL0?Shn07moO`31
`L40WIfM05EEE@19BDT0[:b/06EUI@0204];B`1504M7A`0_;bl0MGEe07EeM@0n?Sh0>c/k0;^k^`1@
D500<30`05MGE`1LG5`0Lg=c06EUI@0J6QX0F5QH03De=@0S8b<0AdM705eMG@0Z:RX0FEUI0:6QX@2j
^[X0>SXj01lO7`0n?Sh0EeMG02`/;01LG5`0Q8B40820P01RHV80:b/[051@D00E5AD0>SXj096AT@0f
=SH08B4Q07inOP0K6a/09bLW09BDU02UYJD0EUIF02@T900o?cl0FEUI0451@@0g=cL0EeMG0<;2`P3>
c/h0=cLg020P802OWil0/K6a0<k>cP3Bd]80e]KF0=SHf027QhL0<c<c02h^;P0R8R807AdM01lO7`0M
7Ad071`L00806ATI05005ADE01HF5P0i>CT0?3`l02h^;P0Q8B40=3@d09^KV`2NWYh0Rh^;07]kN`26
QXH0MgMg08F5Q@2CTi<0DE5A020P800M7Ad061PH01XJ6P1WIfL0^[Zj09JFUP2SXj<0QhN706MWI`1H
F5P0EEEE051@D015ADD0=cLg06EUI@2;Rh/0`l?30;>c/`2h^;P0d=3@0;bl_02/[:`0`<300;Ng]`2D
U9@0Q8B4096AT@2RXZ80`l?30;Bd]02JVYX0T92@06][J`0g=cL09BDU01TI6@0K6a/07AdM03De=@3>
c/h0]kNg07moO`1OGel0J6QX08j>SP2n_[h0aLG50:b/[02i^KT0a/K60=KFeP3Vi^H0a/K60:j^[P17
AdL0?Shn034a<@0c<c<0@D51079bLP1LG5`05ADE00h>3P<05ADE00D09RHV08>3P`2g]kL0fm_K0=;B
dP020;Vi^@0Y0<o?c`2HV9P0Fe]K04=3@`0e=CD0<S8b02`/;00W9bL0@4100:RXZ01UIFD0B4Q805AD
E022PX80QhN703Ti>@2DU9@0/k>c0<g=c@2WYjL0OGem07EeM@28R8P0TY:B096AT@1nOWh0DU9B04Q8
B02k^k/0I6AT09^KV`3:b/X0c<c<051@D00@41004a<C02TY:@1IFET0MGEe04i>CP0H61P00P0E5AD0
:00Y:BT0X:2P05YJFP2l_;`0/K6a02/[:`1<C4`0b/[:0:f][@1ZJVX0;Rh^01dM7@0Q8B408R8R02TY
:@1;Bd/0MGEe0<K6aP2?Shl0>CTi02/[:`0R8R80<C4a0=WIf@3MgMd0d];B0=SHf03Lg=`0hn?S0>[Z
jP33`l<0:RXZ01TI6@0N7Qh0P82005IFEP0U9BD0B4Q803Lg=`0H61P201DE5@0n01dM7@0n?Sh0KFe]
06EUI@1BDU80De=C09bLW031`L40ADE503/k>`34a<@0Ph>307inOP0i>CT0CTi>06=SH`29RHT0YjNW
03Ti>@0[:b/0;Rh^03Lg=`1^KVh0T92@03Hf=P0S8b<0<c<c04E5A@16ATH0LG5a05EEE@1cLg<0G5aL
02h^;P0R8R80:BTY051@D01]KFd0IfMW0:n_[`2g]kL0JFUY02h^;P14A4@0=cLg06EUI@0e=CD0=3@d
04];B`2SXj<0bl_;09FEU@2][Jd0f=SH0>3Ph035aLD0Zj^[0>CTi03@d=00EUIF01@D500C4a<201DE
5@0V01PH6015ADD0`<30051@D00I6AT061PH04i>CP1PH6007QhN01XJ6P0I6AT0FUYJ05IFEP0a<C40
<S8b06ATI02KVi/0>SXj03Hf=P1RHV80Z:RX0:f][@3:b/X0dm?C0<[:bP2VYZH0[:b/0<71`@2XZ:P0
GUiN03lo?`1QHF40CTi>0:BTY01KFe/09BDU03<c<`1hN7P20;>c/`09065QH@1mOGd0JFUY02h^;P1W
IfL0];Bd0;Zj^P3<c<`0eMGE0080F5QH00d0=cLg024Q8@0];Bd0:BTY051@D01SHf<0IFEU05IFEP2V
YZH0d=3@0=WIf@2g]kL0a/K600;ooooo0000XP23Ph<0UiNG08V9R@1OGel0RHV90861P@2j^[X0Xj>S
04M7A`2=SHd0/k>c07YjNP2[Zj/0CDe=05aLG02ATI40Bd];061PH00^;Rh0GUiN09^KV`1@D500Fe]K
05MGE`15ADD0?3`l04Y:BP1EEED0=3@d05YJFP1oOgl0<S8b03@d=01NGUh0:BTY02l_;`2EUID09bLW
03Ti>@1=CDd0DE5A03@d=00V9RH0?clo03dm?@0M7Ad0CDe=059BDP0G5aL0?Cdm05=CD`1OGel0<S8b
05=CD`0V9RH0?Cdm05=CD`0`<300=3@d09jNWP0g=cL0Cdm?07AdM01ADE40:2PX034a<@1BDU80De=C
03Xj>P2OWil0N7Qh03Ti>@0X:2P0EeMG03<c<`0Q8B40HV9R06i^KP0b<S80Bd];02@T900f=SH0Ti>C
05YJFP1TI6@0^;Rh06i^KP0S8b<0Fe]K04a<C01=CDd0820P05YJFP1DE5@05aLG02@T901<C4`0JFUY
02l_;`12@T80J6QX06IVIP1IFET0C4a<08Z:RP1EEED0=3@d08>3P`1KFe/0BDU906QXJ00m?Cd0RHV9
06MWI`0k>c/0N7Qh03<c<`1?Cdl0EeMG030`<015ADD0Bd];01`L701YJFT0GemO03@d=01]KFd0<30`
04I6AP1fMWH0D51@02/[:`0Y:BT0@d=302LW9`1TI6@0DE5A02d];@1GEeL0>c/k07]kN`13@d<0:BTY
07=cL`0c<c<0O7al06EUI@0_;bl0?clo09ZJVP0o?cl0EeMG0:f][@1cLg<0<S8b07QhN016ATH0=3@d
07YjNP1`L700JVYZ04Y:BP80AdM702T0Bd];07AdM00o?cl08R8R079bLP0T92@0GEeM07inOP0a<C40
HV9R07alO01:BTX0Y:BT0;Ng]`1_Kfl0>3Ph06e]K@2/[:`0H61P04M7A`2IVIT0QXJ605iNGP2^[Zh0
Lg=c04E5A@10@400U9BD0;Fe]@24Q8@0N7Qh08^;R`1RHV80Jf][04Q8B02ATI40EUIF03hn?P1GEeL0
GEeM03dm?@0207moO`1l02TY:@0i>CT0H61P03Ph>02_[jl0U9BD06UYJ@2MWId0XZ:R02TY:@1HF5P0
[jn_04e=C@0];Bd0EEEE01HF5P12@T80DU9B07AdM01TI6@0EUIF038b<P26QXH0DE5A014A4@0B4Q80
UYJF0=;BdP2OWil0<30`03hn?P1WIfL0E5AD03Ti>@1eMGD0GUiN02l_;`14A4@0NGUi04A4A01IFET0
S8b<07QhN00m?Cd0=SHf04i>CP24Q8@0Bd];05mOG`1TI6@0PX:204];B`1GEeL0bLW905ADE00Z:RX0
L71`06m_K`0j>SX0Lg=c0492@P0`<300HV9R0<_;b`2>SXh0D51@06EUI@1/K6`0M7Ad05iNGP0Q8B40
EEEE02l_;`0[:b/0A4A406m_K`0D51@0=cLg06a/K02TY:@0=CDe02DU9@0i>CT0EeMG02HV9P0[:b/0
@41005UIF@1XJ6P09bLW06][J`14A4@0?Cdm07alO00j>SX09BDU08N7Q`1]KFd0?Cdm0:6QX@2`/;00
EeMG02@T9012@T80I6AT06=SH`0j>SX0?Shn069RHP1nOWh0J6QX01hN7P2IVIT0dM7A0=OGe`2OWil0
QHF50451@@23Ph<0Y:BT051@D00V9RH07alO01`L70806ATI100E5AD03P0O7al0DU9B02h^;P0`<300
DE5A0:ZZZP2DU9@0VIVI0<K6aP2g]kL0b<S80;^k^`1fMWH06ATI0`0E5AD0E@0F5QH0:RXZ07MgM`0[
:b/092@T03Lg=`1LG5`0QhN709:BTP26QXH0Hf=S05EEE@24Q8@0K6a/0:6QX@3Rh^80e=CD0;Rh^02T
Y:@0Shn?0;:b/P2f][H0HF5Q055AD@1LG5`0NWYj0;Jf]P23Ph<0WYjN0:>SX`25QHD0N7Qh06e]K@1S
Hf<0Kfm_06e]K@2FUYH0e=CD05QHF01CDe<0C4a<04=3@`0g=cL0U9BD07moO`1CDe<0ATI604U9B@1I
FET0];Bd0:VYZ@1oOgl09bLW01XJ6P0E5AD07AdM02HV9P0^;Rh0CTi>05YJFP0[:b/061PH01dM7@1<
C4`0K6a/05mOG`2VYZH0W9bL0<C4a03EeMD0h>3P0=KFeP2HV9P0I6AT059BDP1=CDd0DU9B05mOG`1a
LG40MWIf06a/K02TY:@0<C4a01`L700M7Ad00P0o?cl06@1fMWH0RHV909>CT`0Y:BT071`L010@400C
4a<05ADE02XZ:P1MGEd0[jn_0;jn_P2_[jl0Jf][0;6a/@3:b/X0h>3P04E5A@0b<S80ATI603Lg=`0/
;2`0C4a<028R8P0G5aL00`0E5AD0FP1FEUH0WYjN08B4Q03<c<`0/K6a08N7Q`3EeMD0UiNG0:j^[P1b
LW80DU9B0451@@1bLW80VYZJ0;>c/`1ZJVX0=cLg07EeM@2/[:`0NWYj075aL@2LW9`0PH6107YjNP2>
SXh0Vi^K0<_;b`3Jf]X0iNGU0=oOg`2GUiL0=cLg02@T902FUYH0:b/[02@T901KFe/0<c<c01PH600G
5aL061PH028R8P0P82006a/K05QHF023Ph<0Ogmo0:>SX`2a/K40SHf=03hn?P3?cll0UIFE06QXJ00N
7Qh09RHV03/k>`1ZJVX0BDU9059BDP0f=SH0ADE506EUI@2YZJT0g]kN08R8R00R8R80:2PX034a<@1F
EUH0SXj>08R8R015ADD0=CDe02<S8`0R8R80:2PX02`/;01lO7`0P82009NGU`2b/[80/K6a08Z:RP2B
TY80JFUY0:b/[02VYZH0VYZJ0;jn_P80iNGU00X0XJ6Q09^KV`2m_Kd0gmoO0>3Ph03MgMd0hn?S0<W9
b@2TY:@0820P0P0E5AD0800K6a/0:b/[0:VYZ@2IVIT08B4Q01HF5P0K6a/0=3@d07alO00E5AD06QXJ
01LG5`0J6QX0I6AT05ADE00`<300<C4a07=cL`25QHD0?Cdm079bLP2GUiL0^k^k0=7Ad@3@d=00]kNg
0<G5a@2LW9`0Shn?0;jn_P2e]KD0MgMg0P0S8b<07`18B4P07QhN02DU9@1HF5P0YJFU0;2`/026QXH0
;bl_06i^KP1IFET0:BTY02d];@0e=CD0BDU907AdM03Cdm<0[Jf]06e]K@0V9RH07QhN02@T900/;2`0
A4A404];B`1DE5@0Kfm_08n?S`3AdM40fm_K0=KFeP3GemL00_ooool0003o07=cL`2?Shl0U9BD07Ee
M@22PX80EEEE06=SH`2:RXX0Bd];059BDP1@D500B4Q80:^[Z`1QHF40F5QH07MgM`1GEeL0PX:206i^
KP1LG5`0UYJF04Q8B01WIfL0LG5a07QhN01HF5P0B4Q804M7A`0[:b/0A4A407AdM01HF5P0?3`l04a<
C00R8R80:b/[07QhN01:BTX0B4Q8051@D00[:b/0A4A403dm?@0b<S808b<S02LW9`1FEUH0BTY:03Ti
>@1FEUH0BTY:02TY:@0[:b/0FEUI02DU9@0f=SH0ATI601`L700j>SX0S8b<03hn?P0d=3@0DE5A02@T
900c<c<0CTi>07]kN`12@T807QhN04a<C01TI6@0>c/k03@d=01MGEd0EUIF038b<P17AdL0CTi>030`
<01FEUH0AdM702/[:`1UIFD0Cdm?06IVIP2n_[h0LW9b03<c<`1WIfL0De=C0410@00K6a/0MGEe05]K
F`0G5aL0820P055AD@19BDT07alO03@d=012@T80CDe=05EEE@1<C4`0Ph>305=CD`13@d<0I6AT04U9
B@1<C4`0Jf][04I6AP1dM7@0IFEU03Ph>01UIFD09bLW04i>CP1MGEd0>c/k0492@P1ADE40;Bd]06=S
H`1EEED0=SHf06UYJ@1<C4`0?clo07alO01IFET0:RXZ03Lg=`1UIFD0@41005mOG`1ADE40>CTi06MW
I`1bLW80LG5a04U9B@0b<S80NGUi038b<P1=CDd0K6a/0410@01;Bd/0YJFU0492@P0k>c/0S8b<07Qh
N00h>3P0SHf=05aLG01MGEd0UYJF06m_K`2:RXX0I6AT04Q8B015ADD0FEUI079bLP0n?Sh0:BTY07Ee
M@0a<C40>c/k08N7Q`1>CTh0IfMW05IFEP0Y:BT0OWin09JFUP1gMgL0C4a<08R8R02d];@0<c<c03Ph
>02j^[X0QhN705=CD`2LW9`0OWin07YjNP1@D500VYZJ0;Jf]P1mOGd0MGEe0;fm_@1hN7P0JFUY05eM
G@29RHT0IfMW04];B`1]KFd0OWin04Q8B01;Bd/0OGem02DU9@0o?cl0Q8B405IFEP2=SHd0NWYj05eM
G@2[Zj/0SHf=03/k>`18B4P0Z:RX03hn?P0_;bl0EeMG02/[:`1SHf<0IVIV09JFUP1]KFd0DU9B03Ti
>@28R8P0EEEE03De=@0o?cl0KFe]0;2`/02SXj<0CTi>0451@@1FEUH0;bl_030`<01`L700JVYZ03Xj
>P1CDe<0Ogmo05eMG@1[Jf/0Hf=S06a/K00k>c/0=cLg05EEE@1bLW80GemO002@08J6QP1hN7P0Vi^K
065QH@1?Cdl0c<c<05YJFP0b<S80DE5A04i>CP0j>SX0NGUi03Ti>@0I6AT0?Cdm0;Ng]`22PX80A4A4
06][J`1iNGT0<S8b01LG5`0j>SX0MWIf05ADE00];Bd0@d=306YZJP0V9RH0CDe=07IfMP2ZZZX0<c<c
02TY:@13@d<0Hf=S0410@018B4P0CTi>05QHF01OGel0>3Ph08F5Q@1<C4`0AdM70820P00i>CT0:2PX
08N7Q`1ZJVX0@D510:BTY02/[:`0BTY:024Q8@10@400Cdm?04U9B@1GEeL0DU9B09RHV02DU9@0O7al
02@T901UIFD0XJ6Q08V9R@1dM7@0MWIf03`l?00m?Cd0CDe=08^;R`1cLg<0;Rh^01dM7@0I6AT05QHF
01DE5@0F5QH06QXJ03Lg=`1?Cdl0PH6108f=S@2OWil0IVIV03Ph>00l?3`0GEeM08N7Q`1SHf<0P820
06i^KP1DE5@0820P01TI6@0E5AD05QHF01/K6`0P8200Jf][02TY:@0^;Rh09BDU020P800N7Qh09RHV
03Ph>01SHf<0Ph>30:JVYP36a/H0i>CT0>;RhP3:b/X0F5QH04e=C@1<C4`0Jf][092@T019BDT0=3@d
034a<@0j>SX0^k^k0;Jf]P1lO7`0/K6a096AT@22PX80TY:B08:2PP1cLg<0Kfm_09:BTP31`L40Ogmo
04a<C00X:2P08b<S04M7A`1dM7@08b<S0P0E5AD02P0C4a<0>CTi05QHF02^[Zh0O7al020P800L71`0
7AdM01PH600R8R8202@T900J03dm?@1/K6`0MWIf07AdM01RHV80AdM7061PH022PX80/K6a0;Vi^@3;
bl/0TI6A06][J`21PH40VYZJ08J6QP1`L700HV9R06ATI01HF5P0G5aL020P801/K6`0M7Ad02/[:`0N
7Qh20451@@0707=cL`2i^KT0?Shn01HF5P0L71`051@D018B4P02014A4@0R010@400L71`0MGEe0<g=
c@2k^k/0/K6a0:^[Z`39bLT0b/[:03dm?@0I6AT051@D01DE5@0V9RH0A4A402@T900F5QH06ATI01DE
5@0G5aL0Hf=S0:JVYP36a/H0g=cL0=oOg`3EeMD0`l?30;^k^`2@T900Ti>C07emO@20P800AdM7028R
8P<05ADE04<0<S8b075aL@25QHD0YJFU02HV9P1hN7P0LW9b09RHV039bLT0MgMg0=;BdP28R8P0Vi^K
0;no_`2RXZ80/;2`01lO7`0f=SH0][Jf05]KF`1;Bd/0;Bd]024Q8@0a<C40=3@d02XZ:P0_;bl0BTY:
09>CT`1gMgL0/;2`0;^k^`2h^;P0hN7Q0<c<c01=CDd07AdM02HV9P0k>c/0@T9202DU9@1@D500MGEe
06QXJ02<S8`0TI6A0<c<c032`/80IFEU038b<P0d=3@0KFe]09^KV`1LG5`0BTY:03Lg=`0^;Rh0@410
04Q8B00_;bl0MWIf0:6QX@2i^KT0EUIF07inOP33`l<0bl_;0080e=CD0P3?cll02@3GemL0fMWI0<[:
bP1oOgl0UiNG09FEU@2NWYh0e=CD0>KViP020>WYj@150<?3``1_Kfl0BTY:04];B`1@D500J6QX0<[:
bP13@d<0=CDe04e=C@1oOgl0][Jf0;jn_P0K6a/05QHF01DE5@0G5aL06ATI06QXJ01MGEd0;bl_03Xj
>P2VYZH0YJFU0:>SX`2d];@0[Zj^0<K6aP39bLT0b/[:0;Fe]@3<c<`0Q8B40<71`@2m_Kd0OGem08>3
P`1iNGT0MGEe0451@@1=CDd0ZZZZ09nOW`2i^KT0=3@d04A4A01_Kfl0E5AD02LW9`0/;2`0<C4a03Xj
>P0m?Cd0LW9b0<S8b02WYjL0:BTY02/[:`0a<C40>CTi04E5A@1<C4`0Jf][092@T01jNWX0^[Zj05mO
G`0j>SX0=SHf00;ooooo00002@2?Shl0V9RH071`L02<S8`0Y:BT08N7Q`1oOgl0M7Ad05ADE00209^K
V`1505ADE02RXZ80NWYj07IfMP0m?Cd0AdM708N7Q`1OGel0KFe]07emO@0o?cl0C4a<079bLP2DU9@0
M7Ad06ATI01_Kfl0A4A405EEE@1YJFT0De=C06MWI`1cLg<0=cLg028R8P1mOGd0<30`07AdM01QHF40
9RHV03lo?`0b<S80=CDe01/K6`0L71`0@D5103<c<`0Y:BT0C4a<05iNGP0k>c/0;2`/05eMG@0Y:BT0
Bd];055AD@0Z:RX0=cLg08V9R@0j>SX0=CDe051@D00];Bd06a/K03<c<`1FEUH0Fe]K02XZ:P1KFe/0
JFUY02/[:`0c<c<0BDU904];B`0d=3@0MWIf079bLP0S8b<0=CDe0080?clo0;T0[:b/04M7A`16ATH0
U9BD07emO@13@d<0S8b<08V9R@1<C4`06a/K05QHF01<C4`08B4Q03<c<`1KFe/0AdM703Hf=P17AdL0
?clo05UIF@1HF5P0EUIF09>CT`1TI6@0BTY:05aLG00c<c<0LW9b0861P@1GEeL0LW9b02h^;P1LG5`0
L71`03hn?P1IFET0AdM70410@023Ph<0HV9R03@d=01aLG40De=C05mOG`2@T900CDe=0492@P1PH600
ATI606][J`1mOGd0MgMg04E5A@1/K6`0;bl_061PH01lO7`0MWIf07QhN00a<C40De=C09NGU`13@d<0
KVi^06a/K019BDT0MgMg0;^k^`1TI6@0@D5109fMW@1lO7`0@T920:6QX@1PH600Ph>308f=S@1?Cdl0
LG5a08j>SP1[Jf/0BDU906i^KP1cLg<0<c<c061PH02BTY80=cLg0492@P1_Kfl0?Shn07]kN`2NWYh0
@D5109bLW01nOWh0M7Ad04Y:BP2<S8`0[Jf]079bLP1eMGD0c/k>09BDU01JFUX0[Jf]08j>SP21PH40
CTi>0:2PX02k^k/0ADE506m_K`2i^KT0YZJV07EeM@1UIFD0MgMg055AD@1XJ6P0TY:B06ATI019BDT0
G5aL07]kN`0U9BD0FUYJ09jNWP1KFe/0WYjN05YJFP1>CTh0bLW9096AT@0o?cl0Cdm?0:>SX`10@400
GemO06m_K`0`<300M7Ad06i^KP2DU9@0KFe]055AD@1CDe<0YjNW0:>SX`0U9BD0EUIF08Z:RP38b<P0
UiNG03dm?@19BDT0EeMG05UIF@0o?cl0Kfm_06IVIP15ADD0DU9B08V9R@1bLW80L71`06IVIP1]KFd0
:2PX02l_;`1DE5@0KVi^04U9B@29RHT0Ogmo08J6QP1PH600@4100=KFeP1XJ6P0>c/k06][J`1GEeL0
>SXj06i^KP0204Y:BP0Z06a/K039bLT0MgMg03/k>`1cLg<0SHf=05]KF`0^;Rh0:2PX05iNGP0O7al0
:RXZ04];B`1OGel08R8R05IFEP1cLg<0XZ:R02`/;01>CTh0QhN706UYJ@0h>3P0AdM705ADE01BDU80
5aLG04U9B@1eMGD0ADE503lo?`1aLG4092@T04e=C@1jNWX0GemO03hn?P2WYjL0YZJV03`l?00R8R80
@d=30P1<C4`03@1LG5`0EUIF07emO@1FEUH0JVYZ04M7A`0j>SX0EeMG08N7Q`23Ph<0OGem03lo?`11
@D400P15ADD03`18B4P0MGEe05IFEP0U9BD07AdM03<c<`13@d<0@41003Hf=P0a<C40@41003`l?00o
?cl0F5QH04m?C`02051@D00o07EeM@1jNWX0Bd];05YJFP1[Jf/0@T9201dM7@0J6QX05aLG01TI6@0O
7al0IFEU03@d=00U9BD0:b/[030`<00c<c<07alO01`L700M7Ad0;Bd]07=cL`29RHT0clo?0<c<c02d
];@0De=C03Ti>@0o?cl0B4Q807YjNP17AdL0HV9R0410@014A4@0]kNg0:JVYP21PH40]kNg0;Zj^P1N
GUh0ATI6065QH@2HV9P0][Jf0:FUY@2<S8`0_[jn06MWI`0O7al0:BTY06i^KP0i>CT05ADE02XZ:P0O
7al0;2`/05ADE00Z:RX0P8200=7Ad@11@D4071`L00807AdM02806a/K02LW9`0f=SH0>CTi05IFEP35
aLD0J6QX06=SH`2?Shl0TY:B09bLW02c/k<0D51@08>3P`0U9BD0<30`03dm?@0o?cl0E5AD071`L023
Ph<0MWIf07emO@1^KVh0CTi>0451@@2l_;`0Jf][04M7A`1PH600D51@0;Jf]P2MWId0>SXj0P0J6QX0
3P0E5AD051@D018B4P0D51@04A4A01HF5P1iNGT0@T92030`<01SHf<0LG5a07UiN@2FUYH07QhN0P0E
5AD01@0F5QH0;Bd]02l_;`15ADD0<c<c00806QXJ00D06a/K01lO7`2b/[80eMGE0=WIf@020>7Qh@07
0=_Kf`39bLT0Ogmo03Ph>00R8R805aLG01<C4`0301DE5@0401PH600I6AT09BDU09JFUP80RHV901P0
c/k>0=?Cd`37alL0c/k>03Hf=P2_[jl0BTY:02XZ:P0a<C40GemO0;Ng]`1LG5`0V9RH06e]K@1NGUh0
O7al06EUI@1QHF40LG5a06YZJP1UIFD0GUiN05EEE@1KFe/209bLW01h0=KFeP3Lg=`0inOW0=SHf022
PX808b<S03Hf=P1LG5`0CDe=059BDP1^KVh0OWin0861P@1:BTX0=CDe059BDP2i^KT0Ti>C096AT@1U
IFD0QXJ606][J`18B4P0H61P04E5A@1=CDd0B4Q805QHF01`L700ATI606QXJ02LW9`0OGem06=SH`26
QXH0`<300>OWi`37alL0X:2P092@T02c/k<0VYZJ0:RXZ02`/;00ZZZZ08B4Q01QHF40?Shn0=GEe@3P
h>00j^[Z0>3Ph03@d=00UIFE08f=S@2:RXX0bLW909FEU@1ADE40EUIF0492@P1:BTX0PH61071`L01>
CTh06ATI01DE5@0G5aL05QHF01hN7P1YJFT0De=C03hn?P2TY:@0^[Zj06m_K`1QHF40OGem0=[JfP3D
e=@0Y:BT08:2PP2c/k<0fm_K0=7Ad@2RXZ80KVi^05eMG@1SHf<0LG5a0;:b/P2l_;`0WinO0;Bd]01?
Cdl0<C4a04e=C@1gMgL0?3`l02HV9P0U9BD0;Bd]03`l?018B4P0BDU907AdM03?cll0I6AT02LW9`0b
<S80=cLg04A4A01<C4`0P82009>CT`2=SHd0R8R8028R8P0L71`08b<S0_ooool0000X08j>SP2GUiL0
HF5Q06UYJ@2KVi/0OWin07AdM01YJFT0@41004m?C`1[Jf/0GUiN08f=S@1=CDd0Ti>C07MgM`17AdL0
LW9b04I6AP2>SXh0W9bL061PH01@D500N7Qh03<c<`0i>CT0EeMG06IVIP0f=SH0I6AT04i>CP0G5aL0
?clo055AD@0_;bl09RHV06m_K`0C4a<0<c<c05EEE@80Cdm?0=007QhN05aLG013@d<07AdM0492@P0i
>CT08R8R06i^KP1hN7P0DE5A034a<@14A4@0>c/k08F5Q@1^KVh0;Bd]03dm?@20P800=cLg06m_K`1/
K6`0=3@d01lO7`0i>CT0EEEE05]KF`0[:b/0J6QX075aL@11@D40=CDe03`l?00^;Rh0410@03hn?P1G
EeL0=CDe0451@@0S8b<0:2PX07=cL`1GEeL0K6a/0:n_[`1/K6`06ATI04I6AP1SHf<0GUiN01dM7@1T
I6@0?Cdm01DE5@0k>c/0NGUi04Q8B00[:b/0B4Q803hn?P16ATH0=cLg07moO`2CTi<0KFe]0451@@1C
De<0>c/k04];B`1XJ6P0D51@06IVIP0h>3P0?Cdm06=SH`0j>SX0Fe]K04E5A@0N7Qh0?Shn05mOG`11
@D40M7Ad0451@@0h>3P0Ogmo04E5A@10@400M7Ad04m?C`0b<S80ATI605iNGP0m?Cd0FUYJ03`l?011
@D40LG5a06a/K01UIFD08b<S03Lg=`1mOGd0C4a<06QXJ01FEUH07AdM06IVIP2b/[80GUiN03`l?02W
YjL0CTi>04Y:BP2e]KD0O7al0861P@2@T900Fe]K075aL@1NGUh0AdM703`l?01lO7`0JVYZ02LW9`0j
>SX0O7al03<c<`11@D40H61P024Q8@14A4@0NGUi03`l?02:RXX0LG5a03<c<`1;Bd/0XZ:R0:^[Z`1T
I6@0SHf=0=?Cd`1mOGd0EEEE0<c<c02j^[X0Ph>3051@D02ZZZX0/k>c04Q8B00i>CT0FEUI07alO01P
H600KVi^061PH00R8R80Hf=S09ZJVP1KFe/0BTY:06UYJ@1:BTX09bLW05]KF`2JVYX0DU9B0:ZZZP1:
BTX0@T9208f=S@1kNg/0@D5104i>CP2BTY809BDU05]KF`1aLG40<c<c06QXJ01VIVH0QHF5071`L00f
=SH0=3@d08B4Q02=SHd0D51@06e]K@26QXH0d];B09BDU00h>3P0PX:2071`L01;Bd/0ADE507EeM@1Q
HF40>SXj04e=C@2?Shl0OWin06e]K@1VIVH0M7Ad0P0d=3@0E024Q8@0V9RH05eMG@25QHD0K6a/075a
L@0d=3@0FUYJ0=[JfP1?Cdl0;bl_06e]K@1BDU80Bd];09fMW@1JFUX0DU9B079bLP34a<@0MgMg05AD
E02l_;`0bLW905eMG@0e=CD0;Rh^07inOP0L71`0@D510:JVYP1hN7P0:2PX05MGE`1fMWH0W9bL01/K
6`17AdL0Lg=c04m?C`0`<300@d=304a<C01>CTh0Fe]K03Hf=P1cLg<0CTi>04A4A01WIfL0=3@d02DU
9@1OGel0De=C03De=@2SXj<0/[:b03@d=00`<300MGEe092@T01kNg/0GEeM0492@P1ZJVX0B4Q804];
B`0k>c/0?Cdm04=3@`2FUYH0KVi^08V9R@10@400;bl_02d];@0h>3P0=cLg03Ti>@1FEUH0QhN705MG
E`0d=3@08b<S02@T90807AdM01@08b<S01XJ6P0E5AD07AdM04E5A@1RHV80F5QH09>CT`2IVIT0Lg=c
04e=C@1GEeL0Ph>302h^;P0K6a/05aLG01PH600N7Qh0OGem04m?C`808b<S00l0820P02@T900/;2`0
9RHV02l_;`1IFET0DE5A05UIF@3EeMD0S8b<06IVIP1]KFd0G5aL0492@P0o?cl00P1^KVh06@1MGEd0
@T9203Ph>01RHV80XZ:R0:f][@1UIFD0A4A40861P@2l_;`0KVi^03@d=00[:b/0;Bd]04Y:BP1lO7`0
YJFU07moO`21PH40QXJ601DE5@0>3Ph05ADE02@T901KFe/00P0_;bl01@14A4@0f][J0;jn_P1FEUH0
8B4Q00807alO0P0K6a/0JP0[:b/0CTi>0;bl_02MWId0R8R804U9B@0g=cL0M7Ad04Q8B01LG5`0OGem
02DU9@0T92@07QhN01TI6@0K6a/07AdM03De=@1BDU80Lg=c08J6QP2JVYX0XJ6Q0>7Qh@3<c<`0`L71
0;Bd]036a/H0/;2`06m_K`0h>3P06QXJ01`L700I6AT05ADE018B4P0E5AD071`L065QH@2f][H08b<S
01`L700N7Qh0Jf][0:b/[020P800I6AT01LG5`0C4a<05QHF02TY:@0Q8B40=cLg09FEU@2=SHd0HF5Q
05aLG01CDe<0];Bd0=oOg`3QhN40g]kN0=_Kf`2f][H0SHf=05YJFP25QHD0QXJ607EeM@14A4@0:RXZ
01TI6@0E5AD05aLG02PX:01gMgL0:BTY02HV9P0a<C40QXJ605aLG02YZJT0bLW903Lg=`24Q8@0O7al
03Ph>00d=3@0B4Q809^KV`2m_Kd0QHF507AdM01bLW80CTi>03dm?@0c<c<0<C4a02HV9P0R8R808B4Q
01hN7P0O7al09RHV06YZJP3MgMd20>[ZjP100>KViP2WYjL0De=C0:FUY@2<S8`0P82008:2PP1bLW80
FEUI03Hf=P0g=cL0;Bd]02l_;`1UIFD0`/;208j>SP2i^KT0c<c<04a<C00m?Cd0L71`04e=C@1GEeL0
IfMW05iNGP1DE5@0QXJ6079bLP0d=3@0;bl_069RHP2LW9`0e=CD0<[:bP3AdM40/K6a0;no_`2i^KT0
a/K60;^k^`1`L700@T9203Ti>@16ATH0FUYJ0;Bd]031`L40a/K60=OGe`3Jf]X0[:b/07]kN`2:RXX0
[Zj^07IfMP0V9RH09bLW03<c<`1<C4`0JVYZ04U9B@1OGel0Bd];01LG5`805ADE03<05QHF01`L702S
Xj<0YJFU0;Fe]@25QHD0PH610:b/[03GemL0h^;R0=gMg@3Cdm<0SHf=069RHP3Kfm/0Z:RX0:ZZZP2E
UID0CDe=05IFEP2:RXX0gMgM0=CDe039bLT0T92@02LW9`1>CTh0MWIf07]kN`0e=CD08B4Q02DU9@0X
:2P0=CDe04Q8B01=CDd0G5aL0<_;b`35aLD0PX:204I6AP0m?Cd0@d=305IFEP2PX:00WIfM0:BTY02L
W9`0>CTi04M7A`1`L7000_ooool0000P08Z:RP2TY:@0S8b<08B4Q02a/K40LG5a05YJFP1kNg/0E5AD
06i^KP2IVIT0K6a/08B4Q01BDU80W9bL07YjNP1GEeL0F5QH024Q8@1WIfL0QXJ604];B`19BDT0O7al
05MGE`17AdL0@D5105aLG00d=3@0JFUY07IfMP1:BTX208N7Q`2f03Lg=`0U9BD0Lg=c03lo?`1?Cdl0
G5aL04a<C015ADD0;2`/04Q8B00k>c/071`L0410@00o?cl09RHV03De=@1GEeL0EEEE02`/;01>CTh0
:RXZ04E5A@1IFET0;2`/03dm?@1nOWh08b<S03De=@1OGel0ATI601/K6`0l?3`0EUIF02PX:00C4a<0
<C4a071`L012@T80<S8b030`<00T92@08R8R05=CD`1IFET0;2`/0410@00I6AT0>SXj07emO@1>CTh0
JVYZ0;Ng]`1CDe<08B4Q06i^KP1GEeL0@D5101hN7P1VIVH0<C4a014A4@0H61P0CTi>04M7A`0Q8B40
C4a<03`l?010@4007AdM06UYJ@1]KFd0I6AT03dm?@1@D500A4A406=SH`1KFe/0GEeM07MgM`1DE5@0
?clo03Hf=P0c<c<0GemO04=3@`0i>CT0A4A4059BDP0S8b<0G5aL05=CD`0n?Sh0L71`03lo?`10@400
Kfm_05IFEP1:BTX0C4a<07=cL`19BDT0DE5A02PX:01IFET0NGUi06=SH`1BDU809bLW0410@01fMWH0
?Shn06UYJ@1`L700A4A405eMG@2i^KT0C4a<03lo?`2LW9`0@T92030`<02VYZH0BTY:08^;R`2GUiL0
EUIF0:NWY`1]KFd09BDU034a<@2BTY80Hf=S03/k>`1:BTX0FEUI03<c<`1CDe<0QHF504m?C`1LG5`0
QXJ604=3@`2=SHd0IfMW04Y:BP0j>SX0JFUY09VIV@1JFUX0VYZJ0=[JfP0j>SX0;bl_08F5Q@2<S8`0
G5aL05]KF`2a/K40_;bl06e]K@1lO7`0EUIF08:2PP1_Kfl0MGEe075aL@1FEUH0F5QH08F5Q@1DE5@0
Cdm?06a/K01WIfL0:2PX04U9B@2CTi<0CTi>0:FUY@1kNg/0L71`0;no_`2FUYH204m?C`1j09>CT`0[
:b/0@41004e=C@0O7al0HV9R05YJFP1ZJVX0C4a<0451@@0V9RH0PX:206QXJ00S8b<0DU9B07inOP3H
f=P0Ti>C02PX:01>CTh0MWIf05IFEP11@D40M7Ad04i>CP0j>SX0MGEe09bLW01VIVH0IFEU05]KF`1n
OWh08B4Q03@d=01?Cdl0Lg=c06ATI01gMgL0M7Ad071`L00f=SH0@d=30;bl_01SHf<0<c<c059BDP10
@400<30`06QXJ01?Cdl0A4A4069RHP32`/80Fe]K038b<P1PH600MGEe061PH013@d<0=3@d09bLW00[
:b/09RHV04A4A01LG5`0<C4a04i>CP1oOgl0VYZJ034a<@1=CDd0Ti>C05aLG00T92@0?clo04A4A01@
D500H61P0410@01LG5`0>3Ph05IFEP28R8P0=CDe038b<P1]KFd09bLW02PX:02IVIT0YjNW0410@00O
7al0>SXj04E5A@10@400?clo03De=@1OGel0BTY:05IFEP0e=CD0>SXj03dm?@2XZ:P0LG5a0;Fe]@1C
De<0=SHf02d];@0Z:RX0<30`03lo?`1:BTX0UiNG04Y:BP0V9RH06a/K01DE5@0D51@04a<C01DE5@0G
5aL301DE5@0Z02PX:01VIVH0XZ:R0:b/[02SXj<0I6AT08B4Q02FUYH0QHF502h^;P0K6a/071`L024Q
8@2SXj<0Shn?03Lg=`0V9RH07alO01dM7@0R8R808B4Q02`/;01ADE40FEUI08B4Q02h^;P0Bd];07=c
L`0R8R80FUYJ07inOP1gMgL0S8b<05IFEP1IFET0Kfm_07MgM`1`L700HF5Q09fMW@1lO7`0?Shn0P0f
=SH0:01<C4`04Q8B010@400>3Ph0410@01TI6@0a<C40Xj>S0=gMg@1]KFd04Q8B010@400G5aL08B4Q
03dm?@0M7Ad09RHV06QXJ01jNWX0ATI607UiN@1]KFd0;bl_01XJ6P0K6a/05aLG01DE5@0/;2`0_[jn
03dm?@0d=3@0=CDe04A4A01WIfL0;bl_09ZJVP1kNg/09RHV02DU9@0`<30301TI6@0401`L700];Bd0
<c<c03Lg=`80=SHf00T0KFe]08n?S`2=SHd0dm?C0>OWi`25QHD0Fe]K04e=C@0H61P00P0I6AT04P0L
71`07AdM02`/;014A4@0[:b/09VIV@0N7Qh092@T03`l?01:BTX0U9BD09nOW`2NWYh0JFUY055AD@0l
?3`0@d=3051@D080Fe]K00L0FUYJ065QH@1WIfL0ADE50820P02[Zj/0c/k>0080e]KF00d0_Kfm06YZ
JP0h>3P0=cLg03dm?@10@400EUIF06e]K@1iNGT0H61P03<c<`1QHF40;Bd]00<05ADE01`0<30`0820
P01jNWX0c/k>0:RXZ01ZJVX0`/;209NGU`20P800[Jf]0:RXZ01jNWX0OGem08V9R@1nOWh0PX:207Ad
M01mOGd0Hf=S03hn?P0Z:RX0;Bd]02l_;`0S8b<07alO03@d=03AdM40inOW0`3YjNT02@3WinL0`/;2
08^;R`13@d<0>c/k01LG5`0U9BD0IfMW03lo?`02034a<@0?04A4A027QhL0_;bl0:6QX@35aLD0[Zj^
06YZJP2?Shl0QhN706a/K01hN7P0MGEe08B4Q02c/k<0?3`l00<071`L00D0@T9209NGU`25QHD0alO7
0=GEe@020;:b/P03071`L00_;bl092@T00807alO00d0=cLg04Q8B020P800[Zj^0;no_`3WinL0clo?
06m_K`0j>SX0=3@d03lo?`2TY:@0=3@d0080<c<c03/0EeMG04i>CP0i>CT0<30`05EEE@1LG5`0:2PX
01TI6@0L71`06QXJ04i>CP3Ogml0eMGE0=;BdP38b<P0[:b/08j>SP2TY:@0dM7A0<?3``37alL0e=CD
0<g=c@1=CDd0Lg=c0:^[Z`2GUiL0I6AT071`L03<c<`0fMWI0=cLg02YZJT0Ph>3069RHP2YZJT0][Jf
03Xj>P0U9BD0:BTY02DU9@0`<300>3Ph04e=C@2FUYH0emOG0=?Cd`3GemL0/K6a06i^KP1GEeL0Q8B4
0<G5a@2e]KD0alO70<o?c`2@T900K6a/04M7A`02ooooo`000?l0N7Qh09jNWP1oOgl0P8200:JVYP1T
I6@0H61P09JFUP1CDe<0KFe]0:6QX@1SHf<0WYjN08J6QP2l_;`0O7al04m?C`1hN7P0Fe]K071`L02L
W9`0Fe]K04e=C@2@T900TI6A075aL@1BDU80JVYZ03@d=01XJ6P0S8b<05EEE@2KVi/0T92@03Ph>00/
;2`0K6a/03De=@1:BTX0GEeM03dm?@0o?cl0<S8b02/[:`0P82007AdM0410@00k>c/0>3Ph055AD@1S
Hf<0FEUI03Hf=P1DE5@0@D5105QHF01eMGD0=3@d03hn?P27QhL0ATI603hn?P1HF5P0>CTi01TI6@0c
<c<0Fe]K05YJFP0W9bL0=SHf06=SH`0i>CT0<c<c03`l?00i>CT0;Rh^06m_K`1SHf<0<S8b03`l?00a
<C40@41007]kN`1KFe/0Hf=S0:2PX01CDe<08b<S07IfMP1GEeL0?clo024Q8@1TI6@0;Rh^01DE5@0N
7Qh0OWin03De=@0U9BD0GUiN05QHF018B4P0=cLg07moO`1iNGT0H61P059BDP1mOGd0?clo06m_K`19
BDT0KVi^09JFUP1DE5@0BDU90451@@0g=cL0K6a/03lo?`0j>SX0BDU9055AD@0X:2P0HV9R04e=C@0k
>c/0JVYZ04e=C@1]KFd0M7Ad069RHP1aLG40IFEU04Q8B01IFET0IFEU03Xj>P1mOGd0PX:2055AD@1[
Jf/0>SXj04Y:BP1^KVh0<c<c07emO@1WIfL0?Cdm071`L02j^[X0>SXj05=CD`2d];@0C4a<05iNGP33
`l<0?clo061PH01eMGD0E5AD09jNWP2:RXX0De=C02h^;P2DU9@0GEeM04E5A@1bLW80Cdm?02d];@1H
F5P0MWIf05EEE@1ZJVX0QXJ604];B`2SXj<0PX:206m_K`1[Jf/0UIFE0:b/[01GEeL0ZZZZ0<g=c@26
QXH0Fe]K0:6QX@2BTY80CDe=05iNGP2o_kl0^;Rh06EUI@2IVIT0Xj>S09:BTP19BDT0OWin09jNWP1P
H600Lg=c0:RXZ01eMGD0FEUI07AdM01oOgl0=SHf05IFEP2OWil0EeMG09nOW`1^KVh0L71`0<71`@2C
Ti<0ATI605=CD`2OWil0ADE504];B`1SHf<0;bl_05QHF01ADE40MgMg05]KF`1<C4`0:BTY07inOP1T
I6@0:b/[059BDP1[Jf/0f=SH0820P00[:b/0EEEE04m?C`0n?Sh0=SHf07IfMP11@D407alO05QHF01i
NGT0J6QX05EEE@1<C4`0JFUY02l_;`0f=SH0EeMG079bLP1MGEd004T0Ng]k08N7Q`2?Shl0K6a/03Hf
=P2h^;P0R8R803Lg=`1:BTX0GemO04=3@`1jNWX0K6a/04Q8B01OGel0aLG508n?S`1BDU80UiNG0;bl
_02?Shl0FEUI04Q8B02@T900<c<c02l_;`1GEeL0LW9b02l_;`19BDT0MGEe09nOW`0i>CT0GemO096A
T@1YJFT0=SHf04a<C01WIfL0Ogmo06EUI@1?Cdl0Kfm_03`l?01CDe<0PX:203/k>`18B4P0LW9b04a<
C00U9BD0QHF50:NWY`1:BTX0:b/[04a<C01LG5`0=3@d024Q8@11@D40Rh^;08j>SP1RHV80=cLg03`l
?01;Bd/0d=3@0;6a/@3De=@0WIfM0492@P0f=SH0:BTY00809BDU00@092@T05ADE00V9RH06ATI100E
5AD00`0I6AT05aLG01DE5@0301DE5@0_02PX:02_[jl0dM7A0<W9b@2[Zj/0_;bl06e]K@2][Jd0GUiN
04E5A@13@d<0GEeM0;2`/026QXH0PH6104U9B@0W9bL07QhN020P800k>c/0FEUI04U9B@0k>c/0K6a/
0=3@d02<S8`0Rh^;02d];@0O7al0Ogmo0<o?c`2/[:`0UiNG07UiN@0c<c<07alO01DE5@0Q8B40NWYj
03Ph>00Y:BT0ADE503Ti>@1@D500?Cdm01DE5@0C4a<00P0E5AD04P0^;Rh0IFEU0:b/[02b/[80:2PX
01TI6@0T92@0AdM705aLG00a<C40;2`/08J6QP0Q8B403Ph>018B4P1HF5P0P82003De=@806ATI04d0
5ADE02d];@2TY:@0ADE502DU9@0e=CD0LW9b05MGE`1UIFD0]kNg08n?S`1;Bd/0;Bd]020P800G5aL0
6ATI01DE5@0G5aL06QXJ02<S8`0[:b/0;Bd]02h^;P0T92@0OWin05IFEP1hN7P0`l?30:VYZ@27QhL0
N7Qh01dM7@0K6a/08R8R03Ph>01mOGd0G5aL09RHV03Hf=P0Vi^K02/[:`10@400DE5A03Ti>@0l?3`0
_[jn0<_;b`37alL0HF5Q02LW9`0^;Rh0?Cdm04=3@`0i>CT0<30`03Hf=P1=CDd0HV9R09bLW02j^[X0
cLg=0=CDe02CTi<0^[Zj08n?S`1@D500?clo03`l?00n?Sh0=SHf04A4A00o?cl0GEeM0;6a/@1JFUX0
5ADE01HF5P0201DE5@0i01dM7@27QhL0[:b/0;jn_P3Kfm/0_kno0=cLg03>c/h0^KVi0:^[Z`2YZJT0
Fe]K04];B`0m?Cd0IfMW05IFEP0i>CT0>c/k06EUI@2;Rh/0OGem055AD@0c<c<09bLW020P801gMgL0
cLg=0=SHf031`L40G5aL09NGU`3Ng]h0@T9201dM7@13@d<06ATI01LG5`0R8R80QXJ605aLG01:BTX0
C4a<061PH021PH40WYjN0;6a/@1gMgL0]KFe0=7Ad@2OWil0]KFe09jNWP1SHf<0?Cdm02<S8`1mOGd0
:BTY00807AdM00T06QXJ02/[:`1EEED0KVi^0:^[Z`2`/;00dm?C06][J`0G5aL00`0E5AD0B`0G5aL0
5ADE01PH600h>3P0b/[:0>;RhP3=cLd0/[:b05MGE`0O7al08B4Q03<c<`2MWId0HF5Q02TY:@0o?cl0
J6QX03lo?`0i>CT0<30`02h^;P0g=cL0G5aL04a<C00`<3009bLW0:FUY@3Fe]H0`L71092@T01<C4`0
=cLg04A4A02QXJ40U9BD0<G5a@2m_Kd0^[Zj0=7Ad@15ADD0=cLg07moO`2m_Kd0]kNg0<C4a03De=@0
eMGE0=[JfP2g]kL0clo?0<_;b`3Fe]H0b/[:05QHF00f=SH0>3Ph03@d=00l?3`0B4Q809jNWP2MWId0
Kfm_0:BTY03Cdm<0c<c<0=OGe`37alL0bl_;0=GEe@2m_Kd0_[jn08b<S00g=cL0B4Q807inOP02oooo
o`000?l0NWYj09fMW@1TI6@0YjNW07inOP1]KFd0RHV909bLW01?Cdl0Lg=c0:^[Z`1SHf<0YJFU08Z:
RP30`<00M7Ad05MGE`2FUYH0Fe]K08j>SP1dM7@0>CTi06MWI`2;Rh/0P82007moO`2<S8`0I6AT02@T
901_Kfl0QHF504i>CP2FUYH0Bd];02`/;01:BTX0KFe]03Hf=P1QHF40EEEE02TY:@1<C4`0;bl_03/k
>`0M7Ad0=3@d05YJFP1>CTh0Bd];08:2PP1nOWh0>SXj051@D01ADE40>c/k06UYJ@1lO7`0;Bd]04];
B`1cLg<0?Cdm04=3@`1?Cdl0:b/[01PH600l?3`0GEeM06MWI`0a<C40>3Ph06QXJ013@d<0MgMg06e]
K@0c<c<07alO065QH@1iNGT0Bd];04e=C@0h>3P0BDU908n?S`1MGEd0SHf=0;Vi^@1aLG409bLW075a
L@1TI6@0C4a<0492@P2CTi<0B4Q801hN7P0_;bl0R8R804U9B@0O7al0ADE503Xj>P17AdL0>c/k0:6Q
X@2[Zj/0J6QX03lo?`1>CTh0>3Ph08Z:RP1>CTh0ATI607IfMP1BDU80H61P05YJFP0f=SH0QHF504a<
C014A4@0KVi^06][J`0X:2P0JVYZ04m?C`1HF5P0L71`03Lg=`1CDe<0C4a<04];B`1IFET0J6QX06i^
KP14A4@0GemO030`<01NGUh0Jf][0451@@1BDU80=3@d071`L01hN7P0;bl_05iNGP1IFET0AdM70:b/
[02e]KD0>3Ph0451@@2HV9P0ADE502l_;`2DU9@0EEEE09BDU01dM7@0JFUY07AdM01LG5`0AdM703<c
<`2HV9P0De=C02`/;01fMWH0KFe]038b<P1ADE40@D5103<c<`22PX80L71`0451@@1jNWX0S8b<079b
LP2NWYh0^;Rh09JFUP1ADE40alO70;jn_P27QhL0De=C0;Zj^P2][Jd0LW9b05]KF`33`l<0/;2`03Ti
>@1]KFd0FEUI06ATI01:BTX0KVi^079bLP18B4P0WIfM0;Fe]@1FEUH0GEeM09FEU@1]KFd0?Cdm079b
LP21PH40Fe]K0:^[Z`1>CTh0ATI60;6a/@22PX808B4Q05iNGP28R8P0?3`l055AD@1QHF409BDU06e]
K@1nOWh0Zj^[075aL@1QHF40<S8b06QXJ01HF5P0?clo06a/K01SHf<0gMgM07QhN00g=cL0L71`06MW
I`16ATH0;Bd]05aLG00d=3@0:2PX05ADE01oOgl0HF5Q055AD@19BDT0H61P03Hf=P10@400GEeM07Qh
N01JFUX005H0QhN70:FUY@2=SHd0EEEE02/[:`1lO7`0F5QH028R8P1>CTh0AdM704A4A01mOGd0BDU9
03De=@1SHf<0^k^k08^;R`1DE5@0ZZZZ0;Vi^@2?Shl0G5aL07alO02XZ:P0EEEE03De=@1MGEd0KFe]
038b<P0n?Sh0MgMg0:JVYP0`<300Cdm?0:NWY`1cLg<092@T03lo?`15ADD0IVIV03hn?P20P800Ph>3
04I6AP1LG5`0TI6A028R8P0e=CD0Lg=c05IFEP0S8b<0Q8B409NGU`0W9bL0?Cdm075aL@1cLg<0E5AD
03/k>`0Y:BT0GEeM079bLP1;Bd/0AdM707AdM02g]kL0eMGE0=OGe`2][Jd0KVi^065QH@2?Shl0HF5Q
04];B`0o?cl0=cLg05UIF@0/;2`0;Bd]020P800b<S80820P01/K6`0H61P06ATI01PH60806QXJ0380
61PH01/K6`2c/k<0`L710=gMg@3<c<`0TY:B0861P@2BTY80@T9203De=@14A4@0Rh^;030`<00G5aL0
;Bd]08B4Q01SHf<0?Shn055AD@1NGUh0MWIf065QH@1HF5P0ATI609ZJVP2WYjL0W9bL08:2PP14A4@0
JVYZ0:j^[P0j>SX07alO01DE5@0G5aL06QXJ01TI6@0W9bL0K6a/02DU9@0C4a<05ADE02HV9P11@D40
FUYJ02h^;P0E5AD06ATI01lO7`80LG5a01/0[Jf]0=SHf02k^k/0Rh^;07EeM@23Ph<0SHf=08J6QP2G
UiL0/[:b01DE5@0>3Ph0410@018B4P1UIFD0ZJVY04E5A@0^;Rh092@T03dm?@2_[jl0Lg=c03Xj>P1W
IfL0R8R808V9R@2WYjL00P0X:2P01@1WIfL0DU9B01dM7@0J6QX06a/K008061PH00@06ATI01hN7P0W
9bL0:RXZ0P0R8R80;`1?Cdl0WinO05MGE`2[Zj/0c<c<0;Fe]@3<c<`0OGem05]KF`1=CDd0>c/k02d]
;@13@d<0WinO0<c<c01]KFd0GUiN09RHV01CDe<0M7Ad051@D02EUID0Lg=c09VIV@3De=@0PX:206MW
I`1eMGD0Kfm_06QXJ01OGel0IVIV06e]K@22PX80`<300<c<c03;bl/0YZJV08Z:RP0d=3@0/[:b03hn
?P0Y:BT08R8R02<S8`0O7al08b<S00807AdM0P1ADE4301DE5@0Z01LG5`0Q8B40DE5A0:FUY@2?Shl0
hN7Q0<30`03Xj>P0c<c<0<O7a`2QXJ40^KVi055AD@1XJ6P0Z:RX03`l?00P82007QhN01lO7`0W9bL0
9BDU03Xj>P1bLW80NGUi04A4A01=CDd0Rh^;0<o?c`2HV9P0VIVI04m?C`1>CTh0b/[:03/k>`15ADD0
TY:B04E5A@0_;bl0?Shn075aL@31`L40][Jf0P2l_;`0602@T900C4a<05aLG02VYZH0dM7A0=cLg031
`L40VYZJ08>3P`0n?Sh07QhN02TY:@1FEUH09bLW034a<@0V9RH08R8R05ADE016ATH0EeMG06QXJ00f
=SH0I6AT03De=@<05ADE01@05aLG01/K6`0F5QH061PH03/k>`3?cll0_[jn0:RXZ02`/;00T92@03hn
?P0S8b<0:b/[05MGE`2HV9P0>3Ph051@D01IFET09bLW02`/;080=3@d03H0;bl_038b<P0g=cL0L71`
0;2`/02LW9`0GEeM05mOG`0/;2`0=SHf04m?C`1CDe<0BTY:038b<P1PH600[:b/0<;2`P3GemL0[Jf]
03hn?P1JFUX0/k>c0=KFeP3Lg=`0emOG0<_;b`2IVIT0b<S80=7Ad@3De=@0fm_K0>3Ph031`L40RXZ:
04M7A`0`<300;Rh^08F5Q@1hN7P0;bl_05mOG`1`L700XZ:R0<k>cP35aLD0g=cL0=_Kf`32`/80_Kfm
0;Ng]`2][Jd0QhN70;6a/@25QHD2ooooo`0001<0MgMg09NGU`1EEED0N7Qh08V9R@1@D500FUYJ04m?
C`1^KVh0UiNG08Z:RP1WIfL0TI6A09JFUP35aLD0@d=305EEE@1`L700?3`l0080O7al05<0?Cdm04Q8
B01`L700?clo04A4A01>CTh0JVYZ028R8P17AdL0E5AD03Lg=`1WIfL0H61P02TY:@0j>SX0DE5A030`
<01OGel0HV9R038b<P0g=cL07QhN0492@P0R8R806QXJ03hn?P0Y:BT0<S8b05=CD`1OGel0D51@03Ti
>@0k>c/0ADE508N7Q`1NGUh0<S8b07QhN01/K6`0?Cdm04I6AP1LG5`0<S8b02/[:`1RHV80Ogmo061P
H00h>3P0EUIF06YZJP0];Bd0Bd];0410@00O7al0:BTY07QhN01PH600?3`l04i>CP0P8200ATI608B4
Q011@D40J6QX0;Bd]01OGel0>3Ph09jNWP2>SXh0?3`l03De=@1TI6@0<S8b01DE5@0Q8B40Kfm_02PX
:00L71`0Cdm?03@d=010@400:BTY08>3P`0206IVIP1I04Y:BP1;Bd/0=3@d06=SH`1ADE40A4A406YZ
JP0i>CT0J6QX04];B`0c<c<0LW9b04E5A@1=CDd0A4A4055AD@0W9bL0GUiN04A4A00d=3@0H61P03Ph
>01IFET0M7Ad05iNGP10@400G5aL07=cL`1=CDd0JFUY03Xj>P1ZJVX0M7Ad04a<C01=CDd0?Shn07If
MP21PH40AdM705eMG@1_Kfl0@D510820P02^[Zh0=cLg03lo?`2BTY80Bd];0451@@2XZ:P0FEUI0;no
_`1VIVH0IFEU08R8R01KFe/0?Cdm03Hf=P27QhL0A4A40492@P1kNg/0E5AD030`<01]KFd0N7Qh04U9
B@1LG5`0Ng]k059BDP1^KVh0Ogmo05ADE01HF5P0YjNW07inOP11@D40b<S80:2PX014A4@0BTY:0:n_
[`2LW9`0E5AD05mOG`3@d=00ZJVY059BDP2GUiL00P1ADE40<`1?Cdl0KVi^065QH@0e=CD0J6QX08J6
QP0j>SX0ADE5071`L00b<S80?Cdm0861P@2<S8`0I6AT0:^[Z`17AdL0;Bd]0;Ng]`2EUID0ADE506IV
IP28R8P0;Bd]07inOP1TI6@06a/K04M7A`14A4@0NGUi06QXJ01<C4`0;Rh^059BDP1LG5`0?Shn05aL
G01OGel0fm_K075aL@11@D40M7Ad07UiN@1PH600<c<c05mOG`0j>SX0>CTi061PH01lO7`0ATI605mO
G`0208B4Q00l03dm?@0n?Sh0I6AT07QhN00l?3`0L71`06][J`24Q8@0M7Ad03Hf=P1[Jf/0Hf=S02@T
901_Kfl0IFEU04U9B@1kNg/0@d=303Lg=`1SHf<0WinO08J6QP1IFET0/K6a0;Fe]@2CTi<0EUIF09FE
U@2e]KD0LG5a03Lg=`1JFUX0MGEe01TI6@0n?Sh0Ng]k08^;R`0e=CD0IFEU0<[:bP26QXH0<S8b03Ph
>012@T80H61P0451@@1LG5`0M7Ad05=CD`1XJ6P0YJFU038b<P0a<C40IFEU04I6AP0S8b<0Ng]k09^K
V`0k>c/0;2`/0P17AdL08@1TI6@0B4Q802TY:@1FEUH0KFe]0492@P0_;bl0QHF506EUI@2WYjL0f=SH
0<O7a`1^KVh0Bd];05aLG01^KVh0GemO05UIF@1_Kfl0Ph>306m_K`2][Jd0][Jf0<71`@1`L700>c/k
03<c<`0j>SX0?3`l03dm?@1;Bd/0CDe=05mOG`020=OGe`0U0=cLg03QhN40cLg=0;:b/P2WYjL0Shn?
08R8R035aLD0Ti>C03@d=00[:b/08b<S02HV9P2EUID0b/[:0:b/[02[Zj/0Vi^K09jNWP2IVIT0Fe]K
05EEE@2k^k/0];Bd0<S8b02VYZH0f][J0<O7a`1:BTX0:2PX028R8P0/;2`0<S8b03Ph>00n?Sh0M7Ad
038b<P0301DE5@0Y02TY:@13@d<0KVi^03hn?P18B4P0RHV90:VYZ@2:RXX0];Bd0=KFeP27QhL0FEUI
06YZJP22PX80UiNG096AT@2NWYh0YjNW03Ph>00C4a<0410@014A4@0/;2`0f][J0=CDe02_[jl0WYjN
0:b/[036a/H0a<C40;Jf]P3?cll0g=cL0;Zj^P0`<3007AdM01lO7`0L71`0CDe=05=CD`0O7al00P0L
71`0>P0I6AT071`L01dM7@0Q8B407AdM024Q8@0M7Ad0820P09FEU@3=cLd0fm_K0>[ZjP3Shn<0i^KV
0=oOg`3De=@0V9RH0861P@2@T900][Jf0=cLg02BTY80HF5Q055AD@1oOgl0];Bd0<k>cP2VYZH0PX:2
02LW9`0];Bd0IfMW06QXJ00W9bL0;bl_02`/;00N7Qh07AdM01TI6@0G5aL092@T07MgM`2:RXX0c/k>
0<?3``1VIVH0=CDe03Lg=`1bLW807AdM01/K6`0L71`07AdM01`L700U9BD08R8R02HV9P1KFe/201DE
5@0B01XJ6P0m?Cd0BTY:03<c<`0l?3`0c<c<0=cLg03AdM40i>CT0=7Ad@3EeMD0UIFE0<?3``2f][H0
G5aL03dm?@10@4008B4Q0P0N7Qh0K00P82007QhN02HV9P0T92@0>3Ph09bLW02d];@0/[:b06EUI@1k
Ng/0Ti>C05IFEP26QXH0`L710<C4a025QHD0De=C055AD@1lO7`0_;bl06YZJP1KFe/0Q8B40<G5a@30
`<00GemO0492@P0[:b/0:2PX08F5Q@2PX:00Zj^[07alO01VIVH07AdM01hN7P15ADD0;Bd]03<c<`1>
CTh0ADE504a<C01nOWh0G5aL05IFEP1HF5P0;2`/0410@00U9BD05aLG01DE5@0F5QH061PH01HF5P0H
61P06ATI02l_;`2MWId0NGUi08J6QP2^[Zh0YJFU07emO@0e=CD0=3@d04E5A@2UYJD0K6a/06UYJ@13
@d<0:2PX02d];@0g=cL0@T9203hn?P0i>CT0Cdm?0;Jf]P2ATI40R8R808b<S019BDT0=cLg05=CD`1S
Hf<0BTY:04=3@`0k>c/0<S8b03De=@1SHf<0d];B0=oOg`2_[jl0`/;20<_;b`2f][H0g=cL0<S8b01f
MWH0VYZJ0;Jf]P33`l<0d=3@0=gMg@3IfMT0]kNg08n?S`80Vi^K0180RHV908j>SP0n?Sh0BTY:07Ui
N@1fMWH0LW9b0<71`@3Kfm/0fMWI0=GEe@3Kfm/0f=SH0<G5a@2LW9`0bLW90=GEe@1mOGd2ooooo`00
0640Ng]k0;Jf]P1cLg<0VIVI09:BTP1>CTh0FUYJ08R8R01?Cdl0DE5A092@T01VIVH0MgMg07AdM02j
^[X0LW9b069RHP28R8P0GUiN08:2PP2NWYh0Bd];04M7A`2>SXh0SHf=05UIF@1=CDd0M7Ad028R8P18
B4P0N7Qh04Y:BP1SHf<0Shn?03<c<`0n?Sh0D51@03Ti>@1<C4`0B4Q802TY:@14A4@09BDU01lO7`0P
82007QhN04M7A`0d=3@0?clo05aLG01YJFT0CTi>0410@00n?Sh0;bl_05EEE@19BDT08b<S06EUI@0i
>CT0:RXZ05iNGP1`L700;2`/01/K6`13@d<0IVIV04U9B@0V9RH0AdM705MGE`0`<300@D510492@P0R
8R80:2PX06EUI@1NGUh0?3`l0451@@0J6QX0@D5108B4Q018B4P0OGem09ZJVP1DE5@07alO05]KF`1F
EUH0<C4a03@d=01VIVH0;bl_01@D500P8200N7Qh00806QXJ07`0D51@03Hf=P12@T80<c<c0:RXZ01V
IVH0Hf=S04=3@`15ADD0>SXj06a/K012@T80@d=3075aL@0o?cl0F5QH03<c<`0^;Rh0JVYZ04E5A@1j
NWX0Cdm?03/k>`0K6a/0EUIF04=3@`0i>CT0CDe=02l_;`1QHF40GemO05eMG@13@d<0FEUI05QHF01G
EeL0GemO034a<@1LG5`0GUiN04m?C`16ATH08B4Q07QhN026QXH0CDe=05YJFP1TI6@0@D5109JFUP2H
V9P0<C4a0492@P1iNGT0;Bd]04M7A`2LW9`0?Shn0;Bd]01JFUX0H61P07]kN`1NGUh0:BTY04A4A02=
SHd0<C4a03lo?`29RHT0>3Ph02XZ:P1dM7@0P82004m?C`1NGUh0NWYj05]KF`1[Jf/0Rh^;07EeM@1a
LG40ZJVY0820P01;Bd/0b/[:09NGU`1HF5P0H61P0:NWY`2?Shl0Bd];06MWI`3IfMT0[Zj^05UIF@2E
UID0De=C06i^KP1OGel0MgMg06][J`1DE5@0PX:209>CT`17AdL0EeMG08:2PP1WIfL0>CTi06a/K02A
TI40L71`09^KV`1DE5@0H61P0:JVYP21PH40;Rh^05]KF`2;Rh/09bLW04m?C`1OGel0<S8b0P15ADD0
>P1gMgL0EeMG04E5A@0^;Rh0Cdm?065QH@0S8b<0;bl_04m?C`3@d=00Kfm_03dm?@1`L700MgMg04M7
A`0o?cl0M7Ad06a/K01FEUH0Lg=c09NGU`1ADE40Bd];05iNGP1LG5`0;2`/055AD@2:RXX0NWYj05IF
EP1hN7P0DU9B06MWI`1IFET0B4Q809>CT`1/K6`09bLW051@D01PH600ADE507UiN@0o?cl0:BTY075a
L@2/[:`0Shn?05UIF@2/[:`0Vi^K03dm?@0^;Rh0VIVI0;>c/`1]KFd0Cdm?096AT@2;Rh/203@d=02:
06m_K`1iNGT06a/K03@d=02NWYh0MgMg02l_;`0b<S80BTY:065QH@1EEED0F5QH07YjNP1<C4`0G5aL
0:ZZZP0d=3@0<S8b061PH018B4P08B4Q07inOP2UYJD0@D5103Hf=P1@D500Fe]K06a/K01@D5009RHV
05ADE01/K6`0Jf][03<c<`2NWYh0OWin07alO022PX80IfMW08N7Q`29RHT0Fe]K05ADE01PH600KFe]
0492@P1VIVH0>SXj04I6AP1XJ6P0VYZJ08Z:RP1/K6`0EEEE04U9B@0n?Sh0@D5103lo?`0Z:RX0JFUY
0:f][@3AdM40fm_K0>3Ph03De=@0fMWI0<K6aP2j^[X0RXZ:08^;R`2>SXh0LG5a04];B`0i>CT0;Rh^
07inOP1gMgL0A4A404];B`1YJFT0S8b<0;Fe]@2YZJT0H61P0;Ng]`3Cdm<0hN7Q0=?Cd`3Shn<0e]KF
0;Bd]01fMWH0Cdm?05IFEP1ZJVX0XZ:R0:2PX02^[Zh0HF5Q03@d=00];Bd08b<S028R8P0Z:RX0GemO
0:BTY019BDT0<S8b06EUI@1;Bd/0JVYZ0<_;b`1VIVH09BDU01lO7`0/;2`0UiNG05eMG@0f=SH0ADE5
09JFUP0Y:BT04a<C03Ti>@2GUiL0^k^k09VIV@26QXH0PX:208Z:RP2j^[X0WIfM09ZJVP37alL0fMWI
0:6QX@0a<C4061PH0P0C4a<0>00G5aL0B4Q8059BDP0V9RH07AdM01LG5`0J6QX07AdM01XJ6P0P8200
8b<S02d];@0c<c<0Vi^K09BDU02o_kl0f][J0<71`@2UYJD0CDe=05ADE01NGUh0GEeM07emO@2k^k/0
inOW0<_;b`2HV9P0>CTi03@d=01]KFd0YjNW0<;2`P27QhL0:b/[03Lg=`15ADD0IVIV01<C4`0E5AD0
6QXJ01/K6`0H61P05ADE01PH600N7Qh0HV9R08n?S`3?cll0a/K609VIV@1cLg<09RHV06QXJ00R8R80
71`L0P0M7Ad0V`0H61P092@T02TY:@0a<C40I6AT02PX:00P8200?Cdm03Lg=`0S8b<0820P02`/;02[
Zj/0VIVI09RHV03Lg=`0UIFE08>3P`33`l<0][Jf07inOP0c<c<06a/K04M7A`0d=3@08R8R020P800N
7Qh07AdM01lO7`0T92@0;Rh^06IVIP3Cdm<0N7Qh02/[:`2?Shl0YZJV07=cL`2m_Kd0^[Zj0=3@d023
Ph<0IVIV04e=C@29RHT0/k>c0:VYZ@2XZ:P0I6AT034a<@0Z:RX0@d=306EUI@1WIfL0DU9B096AT@2j
^[X0W9bL06e]K@29RHT0;bl_03<c<`1:BTX0:2PX04I6AP29RHT0X:2P0<K6aP1IFET0LW9b06=SH`1N
GUh0>c/k059BDP0Z:RX06ATI01HF5P0J6QX06ATI01`L700I6AT07AdM05IFEP1PH600B4Q809>CT`2E
UID0_[jn0::RXP26QXH0HF5Q06][J`21PH40^k^k0;Vi^@1CDe<0>CTi03Xj>P0c<c<0;Bd]03dm?@1c
Lg<0^KVi09BDU02OWil0BDU905=CD`1mOGd0KFe]05mOG`1;Bd/0FUYJ04U9B@0i>CT0?Cdm038b<P0W
9bL0Rh^;0=OGe`3IfMT0Ng]k03Hf=P0k>c/0^k^k0:RXZ02^[Zh0d];B0<c<c039bLT0clo?0<?3``2>
SXh0WinO0:f][@2FUYH0JFUY069RHP2CTi<0XJ6Q0;Bd]03;bl/0c/k>0<?3``3EeMD0`/;20>;RhP3G
emL0bLW90<C4a02JVYX0Ng]k0;Ng]`2o_kl0`l?300;ooooo00009P1/K6`0W9bL06][J`2EUID0IFEU
07IfMP2JVYX0V9RH04i>CP1DE5@0XZ:R06i^KP2f][H0QhN70<W9b@1dM7@0EUIF07MgM`1PH600X:2P
09nOW`18B4P0De=C09BDU02BTY80H61P05UIF@20P80092@T05ADE024Q8@0@41006IVIP2=SHd0=CDe
04e=C@1CDe<0>SXj0P1<C4`0o`0c<c<0DE5A02TY:@0`<300<C4a01dM7@1;Bd/0A4A40492@P1PH600
KFe]05MGE`11@D40?Shn02XZ:P1NGUh0E5AD02l_;`1eMGD0ATI602/[:`0m?Cd0EeMG02XZ:P0K6a/0
C4a<065QH@1UIFD0>CTi05IFEP1ADE40;Rh^05MGE`1CDe<0>CTi0410@01kNg/0J6QX04A4A018B4P0
<S8b04];B`1bLW80F5QH09JFUP2KVi/0FUYJ02PX:01[Jf/0GEeM03Hf=P0g=cL0MWIf03dm?@0I6AT0
9BDU07UiN@0R8R80>CTi07EeM@1JFUX0DE5A03De=@2f][H0Jf][04I6AP1bLW80LG5a03Lg=`1UIFD0
CDe=04];B`1fMWH0=SHf04e=C@18B4P0>3Ph075aL@1?Cdl0OGem05ADE00n?Sh07alO05]KF`11@D40
@T9204e=C@0/;2`0HF5Q06YZJP1>CTh0BTY:059BDP1:BTX0GUiN06EUI@0X:2P0Fe]K06QXJ01FEUH0
De=C02PX:01^KVh0Kfm_04A4A01QHF40EEEE03lo?`2>SXh0U9BD034a<@16ATH0R8R8030`<017AdL0
T92@03<c<`2i^KT0EUIF06QXJ01dM7@0GEeM03Hf=P1<C4`0VYZJ04A4A010@400Q8B404A4A00`<300
QHF507alO01DE5@0MgMg08j>SP1LG5`0L71`09fMW@1cLg<0SHf=0;:b/P2MWId0EeMG0<[:bP2i^KT0
Q8B407]kN`2_[jl0XZ:R0451@@1`L700bl_;0:f][@1CDe<0NGUi05ADE01_Kfl0De=C0:b/[02KVi/0
F5QH08^;R`2[Zj/0D51@05=CD`28R8P0HV9R04A4A01^KVh0QXJ607QhN02m_Kd0KFe]06m_K`2WYjL0
MGEe03@d=01_Kfl0P82003De=@1VIVH0CDe=028R8P0j>SX0AdM707IfMP1MGEd0;2`/02TY:@1nOWh0
TI6A03De=@1TI6@0BDU90<[:bP1EEED0<C4a071`L01YJFT0AdM7030`<01]KFd0Kfm_05=CD`2[Zj/0
Y:BT079bLP1ADE40GUiN06=SH`0V9RH0ADE5061PH01VIVH0GUiN07UiN@1VIVH0O7al04I6AP0Y:BT0
NWYj05aLG00[:b/0EUIF04M7A`18B4P0Q8B4038b<P0X:2P0F5QH09RHV01^KVh0GUiN0;no_`2c/k<0
Ng]k04Q8B031`L40V9RH02TY:@0h>3P0HV9R07alO00Z:RX0?Shn07AdM02DU9@09RHV03<c<`1kNg/0
MGEe03@d=00n?Sh0EeMG06UYJ@001P1ADE40IfMW07IfMP13@d<0ADE50;2`/080=3@d00D0MGEe05MG
E`0R8R80M7Ad0861P@0203Hf=P0d05YJFP16ATH0=3@d03De=@0W9bL0F5QH06EUI@1SHf<09RHV051@
D015ADD0@41004=3@`0n?Sh0ADE5055AD@1eMGD0O7al059BDP1?Cdl0Ph>309jNWP2RXZ80SHf=065Q
H@1BDU80NGUi07MgM`1fMWH0Hf=S051@D01GEeL0Fe]K09RHV02<S8`0FEUI0;fm_@2ZZZX0e]KF0<K6
aP2i^KT0`l?30:FUY@1CDe<0A4A404E5A@17AdL0CDe=05QHF02g]kL0/;2`05eMG@80DE5A01<0FUYJ
08^;R`1JFUX0HV9R09jNWP35aLD0hN7Q0<O7a`2][Jd0c/k>0;Bd]02ZZZX0_kno0;bl_025QHD0M7Ad
06a/K01aLG40CDe=00805ADE06/06a/K02DU9@0j>SX0B4Q807IfMP1^KVh0=cLg03Ti>@1?Cdl0AdM7
04];B`2e]KD0K6a/01LG5`0];Bd0E5AD0451@@1;Bd/0EeMG03Ph>01GEeL0b<S80::RXP34a<@0JFUY
02h^;P0P82008b<S01dM7@0^;Rh0`L7105UIF@0e=CD0Ph>30::RXP2<S8`0MGEe01`L700C4a<0410@
01DE5@0J6QX0Xj>S08B4Q01JFUX0BTY:0451@@0i>CT0=SHf03@d=00n?Sh0EUIF08Z:RP1DE5@0@T92
09FEU@36a/H0Rh^;0=_Kf`2ATI40D51@03Xj>P0[:b/08R8R02h^;P2@T900hn?S0<c<c013@d<0Bd];
06m_K`1nOWh0Zj^[0820P00o?cl0;2`/04M7A`20P8005aLG01@D500C4a<05aLG01DE5@0F5QH06QXJ
030`<02DU9@0]kNg09nOW`1dM7@0QHF509BDU01<C4`0>c/k07AdM00X:2P0820P01lO7`0K6a/071`L
024Q8@0d=3@0DU9B07moO`0n?Sh08R8R01`L700201hN7P0L05QHF01QHF40K6a/09nOW`1RHV80Z:RX
09>CT`2RXZ80WinO0;2`/027QhL07AdM038b<P28R8P0>SXj02PX:00O7al0820P01dM7@0P8200:b/[
06UYJ@2EUID0>c/k03Ti>@31`L40gmoO0;^k^`80][Jf01@0bl_;0;2`/01ZJVX0WIfM0<K6aP3@d=00
[:b/038b<P0R8R8071`L01TI6@0E5AD05aLG03<c<`2CTi<0_kno08R8R02^[Zh0^;Rh065QH@80E5AD
00H0:RXZ02l_;`1IFET0W9bL05mOG`2:RXX206IVIP0505eMG@1ADE40<C4a055AD@0b<S800P0K6a/0
?@0J6QX05aLG01TI6@0L71`07AdM05aLG00V9RH0>3Ph092@T02MWId0XZ:R0:6QX@2>SXh0XJ6Q0;Jf
]P2o_kl0d];B0=WIf@2YZJT0IFEU03lo?`0i>CT0IVIV0:j^[P2][Jd0QXJ60::RXP1>CTh0F5QH08B4
Q033`l<0Shn?06IVIP1CDe<0>SXj03lo?`0^;Rh0<S8b03<c<`0^;Rh0EEEE0=GEe@3Ogml0Z:RX04e=
C@1JFUX0TI6A09NGU`3Rh^80f][J0<S8b03=cLd0gMgM0:BTY01ZJVX0Jf][05EEE@1aLG40Ti>C0:f]
[@2j^[X00P2BTY803P2XZ:P0[:b/0;Fe]@2PX:00De=C0<71`@2o_kl0aLG50<K6aP39bLT0clo?0:NW
Y`1>CTh0Kfm_0_ooool0003j07]kN`2YZJT0LW9b0:RXZ02=SHd0C4a<05=CD`1VIVH0AdM705IFEP1j
NWX0RXZ:0:VYZ@1/K6`0_Kfm06][J`28R8P0V9RH055AD@2UYJD0G5aL0492@P28R8P0P82006MWI`1=
CDd0EEEE07=cL`10@400T92@08B4Q01MGEd0IVIV03hn?P0j>SX0LW9b05eMG@0j>SX0BTY:04Q8B00f
=SH0FUYJ034a<@0g=cL0;Rh^04=3@`21PH40Cdm?03dm?@1OGel0J6QX055AD@1^KVh0B4Q802/[:`1R
HV80IFEU0492@P2NWYh0GEeM03/k>`0n?Sh0FUYJ03Ti>@0n?Sh0P82006m_K`1UIFD0;bl_07EeM@1J
FUX08b<S06a/K01jNWX0>SXj0451@@1QHF40Jf][05mOG`1UIFD0>SXj04i>CP1iNGT0H61P0:FUY@2V
YZH0LW9b02TY:@1/K6`0HV9R051@D01QHF40W9bL05UIF@0L71`0<C4a08R8R00P82007QhN04U9B@0h
>3P0>SXj03Ph>02e]KD0F5QH05IFEP0k>c/0D51@02l_;`1UIFD0<C4a07=cL`1_Kfl0<30`04U9B@10
@400EEEE09:BTP1KFe/0IFEU055AD@1<C4`0=cLg08B4Q014A4@0BTY:04M7A`1ADE40SXj>07QhN017
AdL0A4A4059BDP0];Bd0Ogmo0820P00Z:RX0FUYJ04Y:BP1eMGD0Ogmo03<c<`1bLW80Jf][05QHF026
QXH0IVIV03/k>`27QhL0T92@03Ti>@1bLW80WYjN04];B`1=CDd0QXJ603De=@2i^KT0UYJF06m_K`1`
L700HF5Q02/[:`2;Rh/0Z:RX05aLG00o?cl0PX:205ADE01GEeL0[Jf]07inOP1JFUX0Ogmo08Z:RP22
PX80ZJVY0::RXP1gMgL0RHV90;>c/`2<S8`0I6AT0;Bd]02QXJ40NWYj08B4Q02UYJD0[jn_06UYJ@1G
EeL0f=SH0:BTY01CDe<0NWYj05ADE01=CDd0;Rh^07alO01oOgl0C4a<08j>SP2KVi/0A4A405QHF02?
Shl0H61P04M7A`1eMGD0?Cdm065QH@2JVYX0M7Ad06UYJ@2WYjL0QXJ6024Q8@1nOWh0SXj>0451@@1J
FUX0CDe=02DU9@1LG5`0RHV90<30`01oOgl0AdM702XZ:P0i>CT0F5QH030`<01MGEd0A4A40;>c/`1G
EeL0ADE507YjNP1VIVH0DU9B03<c<`1aLG40:2PX02h^;P1bLW80G5aL05]KF`1VIVH0H61P08J6QP80
@4100400D51@07EeM@0^;Rh0IFEU09bLW02?Shl0JFUY03lo?`2WYjL0K6a/038b<P1WIfL0?Shn03Ti
>@21PH40FUYJ03hn?P1`L700Y:BT02`/;01=CDd0Ogmo071`L02=SHd0EEEE0<c<c025QHD0JVYZ03@d
=01BDU80O7al02@T9018B4P0WIfM09RHV00R8R809RHV06UYJ@1EEED0;bl_07=cL`2UYJD0MgMg04a<
C01/K6`0JFUY03lo?`1NGUh0]KFe03Hf=P0/;2`0NGUi01/K6`0S8b<0NWYj08N7Q`0h>3P0>SXj06YZ
JP0o?cl08R8R038b<P10@400OGem0P1JFUX09P0/;2`0D51@04];B`18B4P0@D5103Lg=`0^;Rh0<C4a
03Ti>@19BDT0M7Ad08n?S`2XZ:P0[jn_09bLW01cLg<0@T9203Lg=`0l?3`0@D5104M7A`1DE5@0L71`
09ZJVP2g]kL0U9BD08F5Q@2h^;P0T92@0<W9b@36a/H0IfMW06=SH`35aLD0VYZJ06m_K`1EEED0G5aL
0P1PH600701^KVh0^k^k0<C4a02OWil0PX:20;Rh^01^KVh0CDe=0410@00_;bl0DE5A0;Zj^P3:b/X0
dM7A0;Bd]01nOWh0XJ6Q092@T02YZJT0SXj>0:JVYP36a/H0Zj^[06][J`0N7Qh05ADE01@D500F5QH2
01DE5@1?01dM7@1CDe<0MWIf061PH018B4P0@T9205iNGP1WIfL0YJFU08B4Q00_;bl0Ng]k038b<P0E
5AD09RHV079bLP1HF5P0DE5A0=oOg`3Kfm/0OWin02PX:00J6QX061PH01LG5`0H61P0:RXZ0:j^[P16
ATH0@D51071`L01mOGd0AdM705mOG`1DE5@05ADE018B4P0D51@0;Rh^0<G5a@2d];@0YJFU08n?S`1k
Ng/0OWin07]kN`1aLG40Ng]k07QhN01fMWH0Hf=S05]KF`2OWil0hN7Q0=gMg@3Rh^80inOW0<k>cP1j
NWX0GEeM051@D01:BTX0CDe=09BDU03=cLd0@41001DE5@0G5aL09BDU05EEE@1OGel0DU9B02TY:@10
@400P82002d];@0@41006ATI01`L700201TI6@1204m?C`1cLg<0Q8B40:j^[P1MGEd0F5QH06e]K@1_
Kfl0Ogmo01/K6`1JFUX0N7Qh03Xj>P0W9bL08B4Q01TI6@0R8R80?clo07emO@1SHf<0>CTi01XJ6P0O
7al0820P04];B`1FEUH0HV9R0:ZZZP1QHF40820P04U9B@30`<00W9bL07moO`21PH40Shn?08b<S01^
KVh0R8R808j>SP2=SHd0KFe]04Y:BP0e=CD0:RXZ03@d=01mOGd0GEeM075aL@2MWId0hN7Q0=kNgP3A
dM40`l?309jNWP3Hf=P0e=CD0;Fe]@3AdM40c/k>069RHP10@400D51@02d];@0M7Ad05QHF0`0E5AD0
6@0Y:BT0QHF505=CD`2XZ:P0W9bL05eMG@0h>3P0RXZ:08J6QP1jNWX0G5aL02h^;P0[:b/0J6QX05iN
GP1ADE40Kfm_0451@@0c<c<0F5QH03dm?@0L71`06QXJ01/K6`0I6AT00P0L71`202d];@0F01`L700j
>SX0UIFE09:BTP2?Shl0XZ:R04e=C@1?Cdl0E5AD08j>SP2j^[X0e=CD0<K6aP34a<@0Xj>S0:RXZ02l
_;`0T92@09^KV`2`/;00DU9B069RHP80TY:B02d0HV9R04U9B@1IFET0DE5A04Y:BP13@d<0?Cdm03De
=@14A4@0ADE508B4Q03GemL0[jn_0::RXP3>c/h0fMWI08F5Q@28R8P0e]KF0=oOg`2YZJT0UiNG0<[:
bP0g=cL071`L03/k>`1SHf<0Jf][051@D00n?Sh0MWIf0:FUY@33`l<0`L710;Fe]@36a/H0MGEe09RH
V03;bl/0/[:b0:>SX`1BDU80BDU90:b/[02CTi<00P0o?cl2ooooo`0006X0Lg=c09JFUP1IFET0][Jf
08j>SP1?Cdl0F5QH07moO`17AdL0KVi^069RHP1UIFD0P82006ATI02;Rh/0<30`05MGE`2:RXX0ADE5
0::RXP1hN7P0>SXj05IFEP23Ph<0IfMW05MGE`1_Kfl0H61P02DU9@1QHF40NGUi071`L029RHT0M7Ad
02DU9@1SHf<0CDe=03Lg=`1HF5P0ATI6030`<01BDU80>SXj03lo?`0V9RH08R8R04e=C@0i>CT0>SXj
075aL@1RHV80<C4a05YJFP0h>3P0<C4a061PH00/;2`0>3Ph07UiN@1EEED0<S8b04I6AP1ADE40820P
024Q8@1KFe/0H61P05QHF00j>SX0PH6105EEE@0Y:BT0B4Q804A4A00R8R80@T9205UIF@0e=CD0AdM7
069RHP0];Bd0FEUI06e]K@0h>3P0O7al0:>SX`1XJ6P0<C4a07inOP1aLG40<c<c0492@P1iNGT0ATI6
02HV9P1LG5`0LW9b03<c<`0N7Qh0DU9B04M7A`0m?Cd0>CTi0;jn_P1WIfL0GUiN0P1@D5007P0];Bd0
HF5Q03De=@1>CTh0H61P02HV9P1<C4`0ATI6038b<P1fMWH0BDU904e=C@1lO7`0BDU9030`<01/K6`0
?3`l05YJFP1=CDd0:RXZ06UYJ@1KFe/0DU9B05UIF@1VIVH0ATI605eMG@1LG5`0;Bd]06IVIP80G5aL
09L0CTi>02TY:@24Q8@0A4A404E5A@1kNg/0GemO04a<C02TY:@0Jf][03/k>`1iNGT0OWin04=3@`1/
K6`0P8200492@P2RXZ80GEeM05mOG`2DU9@0LW9b0492@P1HF5P0O7al03@d=01>CTh0W9bL03Lg=`10
@400OWin05aLG01]KFd0Ph>304E5A@1]KFd0J6QX06EUI@1SHf<0T92@0;Fe]@1[Jf/0AdM708:2PP20
P800C4a<08^;R`37alL0]kNg05QHF01IFET0d];B07emO@0f=SH0SHf=09:BTP1CDe<0@D5108b<S01U
IFD0DE5A09fMW@26QXH0=CDe069RHP2@T900DU9B04=3@`1oOgl0J6QX07UiN@2BTY80EUIF05eMG@2`
/;00K6a/02d];@1bLW80GEeM03Xj>P1JFUX0C4a<024Q8@0/;2`0>CTi05eMG@1YJFT0EeMG03Hf=P14
A4@0EUIF02<S8`0l?3`0@D510;:b/P1oOgl0BDU908j>SP1gMgL0AdM705IFEP2:RXX0JVYZ06][J`28
R8P0Hf=S03De=@1ZJVX0PX:2079bLP0b<S80ADE505iNGP1YJFT0I6AT069RHP1OGel0IVIV07=cL`15
ADD0^KVi05UIF@15ADD0WYjN06e]K@16ATH0EeMG04e=C@10@400VIVI09ZJVP1SHf<0M7Ad07MgM`1H
F5P0HV9R06=SH`3Hf=P0/K6a06m_K`0l?3`0FUYJ07inOP0S8b<0<C4a07IfMP1kNg/07AdM05EEE@2h
^;P0N7Qh0080<c<c0200DE5A03dm?@0R8R80Shn?07UiN@0S8b<0@41009fMW@0U9BD0EeMG09ZJVP1F
EUH07alO06e]K@1kNg/09BDU059BDP2j^[X0Ng]k03/k>`0U9BD0AdM708>3P`1PH600EUIF02d];@1@
D500AdM703/k>`0^;Rh0:2PX02@T90<08B4Q03X0:2PX05aLG03<c<`0/K6a0<C4a02XZ:P0GEeM051@
D022PX80Q8B4079bLP1WIfL0EEEE04];B`1LG5`0/K6a0=gMg@2_[jl0PH6109FEU@2JVYX0ADE50861
P@22PX80S8b<075aL@0f=SH09RHV01lO7`0/;2`0@D5108B4Q02VYZH0HF5Q03/k>`1QHF40M7Ad02LW
9`0M7Ad0=SHf0:ZZZP2LW9`0C4a<0410@01WIfL0ZZZZ0;no_`2c/k<0]kNg0;:b/P2LW9`0WYjN0:j^
[P2SXj<0M7Ad055AD@0/;2`071`L0P0I6AT03@0J6QX0C4a<07YjNP11@D407QhN01/K6`10@400BTY:
09BDU01fMWH0ATI607emO@0G5aL00P0E5AD0800Z:RX0R8R80:n_[`3GemL0]KFe03lo?`0J6QX05QHF
01LG5`0F5QH07QhN04A4A02@T900:b/[02LW9`1XJ6P0HV9R04Q8B00f=SH0Hf=S03`l?00R8R80GEeM
071`L00e=CD0820P024Q8@0X:2P092@T02HV9P0];Bd0>SXj0P1cLg<0=@25QHD0^;Rh0;jn_P3Jf]X0
fm_K0:n_[`3Ogml0hn?S07]kN`0U9BD06ATI01LG5`0C4a<04A4A01PH600f=SH0KFe]024Q8@0H61P0
5aLG03dm?@1PH600DE5A03dm?@0a<C40HV9R06i^KP0L71`0820P02LW9`13@d<0G5aL04a<C010@400
UYJF09ZJVP1MGEd0EEEE05MGE`1ZJVX0MWIf04I6AP0N7Qh0Cdm?0820P01EEED0>CTi03lo?`1=CDd0
@T920451@@1ADE40MGEe00809bLW00X0@d=305ADE01aLG40FUYJ0861P@1JFUX0@T9202LW9`2:RXX0
bLW90P2/[:`00`2:RXX0UiNG05aLG00202PX:00I04=3@`21PH40Ti>C06ATI01OGel0Ogmo08^;R`2]
[Jd0_Kfm0=7Ad@1cLg<0De=C0;Bd]02h^;P0aLG50>7Qh@3MgMd0gmoO0=gMg@1LG5`09BDU028R8P0i
>CT0A4A401PH600201LG5`0I01HF5P0I6AT09RHV07UiN@27QhL0H61P09NGU`2ZZZX09RHV02@T900e
=CD0ADE503/k>`0X:2P0<C4a051@D01IFET0E5AD06EUI@0c<c<0>CTi055AD@0a<C406ATI01`L7002
01XJ6P0I01`L700O7al0CDe=01lO7`0U9BD0HV9R09ZJVP1JFUX0T92@09FEU@10@400ADE505=CD`28
R8P0SXj>05UIF@2UYJD0SXj>0<C4a03De=@0YjNW0;:b/P2d];@0L71`07MgM`02092@T00H06IVIP0R
8R80:BTY02d];@15ADD0DE5A04M7A`1;Bd/0BTY:04];B`1QHF40`/;20:6QX@1DE5@0=CDe06YZJP2`
/;00Xj>S08j>SP2o_kl0^;Rh05EEE@23Ph<0UIFE0P0G5aL201PH600>02@T901<C4`0Q8B407UiN@1S
Hf<0LG5a08n?S`2n_[h0^;Rh0:b/[03GemL0Ti>C0<K6aP1OGel204m?C`0408f=S@2CTi<0ADE502h^
;P;ooooo0000H`1[Jf/0XJ6Q05=CD`1lO7`0MgMg05iNGP1HF5P0?Shn05iNGP26QXH0Ng]k06m_K`1>
CTh0KFe]09jNWP16ATH0JVYZ04];B`14A4@0V9RH079bLP0j>SX0Jf][04=3@`0`<300J6QX07IfMP1W
IfL0:2PX065QH@0Y:BT0AdM706e]K@1KFe/092@T07=cL`0`<300@T9207QhN01TI6@0AdM70492@P13
@d<0CTi>03@d=00Z:RX0DE5A014A4@0];Bd0K6a/07]kN`10@400Hf=S01TI6@15ADD0S8b<06e]K@0c
<c<0Rh^;02DU9@0[:b/0NGUi0820P00b<S8092@T05QHF00g=cL05aLG0492@P2RXZ80OGem03@d=01?
Cdl0@d=301DE5@1OGel0RHV906ATI01ADE40@D5101@D501EEED0QhN7061PH02LW9`0][Jf02d];@0^
;Rh0GemO08J6QP11@D40?Shn07EeM@0@41004Q8B05ADE01VIVH0?clo024Q8@0205YJFP0501DE5@0P
8200UiNG08j>SP1OGel00P1CDe<0o`0^;Rh0TI6A05MGE`1DE5@0<c<c02XZ:P1_Kfl0Lg=c03/k>`1j
NWX051@D03Hf=P1fMWH0M7Ad0492@P1>CTh061PH06MWI`1hN7P0=SHf071`L00D51@0=3@d05IFEP1i
NGT0ATI605iNGP0j>SX08b<S07]kN`1jNWX0EeMG04M7A`0O7al0T92@07MgM`1IFET0G5aL024Q8@1F
EUH0^k^k0:>SX`11@D40SHf=06MWI`0O7al0G5aL07]kN`1?Cdl0YJFU05aLG00m?Cd0Bd];05=CD`0f
=SH0PH61079bLP0L71`0=cLg08Z:RP1GEeL0BDU907emO@0K6a/0@d=309FEU@1iNGT0Ti>C06YZJP0c
<c<07QhN0451@@2KVi/0UiNG05ADE027QhL0O7al02<S8`1LG5`0QhN707alO01;Bd/0RHV90=_Kf`2K
Vi/0BDU9051@D019BDT0Hf=S0492@P2JVYX0BDU905YJFP2][Jd0QXJ604U9B@15ADD0QhN7055AD@1=
CDd0R8R807AdM02JVYX0VIVI04a<C01/K6`0a<C4071`L00d=3@0OWin04M7A`11@D40RXZ:05QHF00_
;bl0@410038b<P1SHf<0IFEU04U9B@1:BTX0C4a<06a/K00c<c<0B4Q802HV9P1iNGT0IVIV0492@P1_
Kfl0FUYJ02PX:00i>CT0N7Qh06=SH`1NGUh0Kfm_05iNGP1<C4`0DU9B061PH01MGEd0:b/[05YJFP2:
RXX0GUiN06i^KP1UIFD0HV9R05=CD`1ADE40HF5Q0;Ng]`1=CDd08b<S05EEE@1:BTX0K6a/08>3P`0Z
:RX06QXJ07alO01mOGd0Fe]K08b<S02l_;`0RXZ:03lo?`1MGEd0Zj^[05YJFP12@T80F5QH08>3P`2S
Xj<0CTi>0451@@23Ph<0MWIf01<C4`0o?cl0VYZJ07YjNP0c<c<0>c/k05EEE@12@T8071`L05mOG`22
PX80@41004Y:BP2EUID05ADE03hn?P2BTY80DU9B01TI6@1lO7`0IfMW010@400a<C40IfMW06][J`1`
L700ATI602XZ:P1DE5@0=SHf01XJ6P0h>3P0C4a<03dm?@0e=CD0<c<c02h^;P0W9bL09RHV020P800M
7Ad06a/K03hn?P3=cLd0BTY:07UiN@2j^[X0e=CD0;2`/018B4P0@T9205EEE@1UIFD0S8b<0<[:bP34
a<@0T92@0:RXZ01ZJVX0TI6A09^KV`2m_Kd0RXZ:03Lg=`0G5aL09bLW04I6AP1aLG40:b/[01lO7`0L
71`06ATI02TY:@1oOgl0V9RH03Ti>@00;P0_;bl0KFe]02d];@1LG5`0V9RH08n?S`1aLG40=SHf03Lg
=`0j>SX0Ogmo06YZJP2>SXh0][Jf0<;2`P2VYZH0T92@08R8R017AdL0=SHf05QHF01eMGD0Kfm_05MG
E`0f=SH0:2PX03Xj>P2<S8`0:RXZ01dM7@0K6a/0;2`/04];B`2FUYH0MWIf01DE5@13@d<09bLW01DE
5@0G5aL0:BTY0<71`@38b<P0T92@0:RXZ00i>CT201DE5@0801XJ6P0^;Rh0EeMG0;:b/P38b<P0HV9R
03@d=01ZJVX206UYJ@0903/k>`1IFET0];Bd0:6QX@1>CTh07AdM01HF5P0E5AD04a<C00805ADE07l0
6a/K01XJ6P0G5aL06a/K03lo?`0m?Cd0AdM704a<C02WYjL0fm_K08b<S02m_Kd0c/k>0;Rh^00];Bd0
6ATI01DE5@0J6QX05ADE01<C4`0F5QH0IFEU059BDP0K6a/05ADE02PX:01EEED0AdM7055AD@0a<C40
ATI60;Rh^01gMgL0GEeM05UIF@10@400;Rh^04m?C`1EEED0d];B08f=S@1MGEd0Kfm_04Y:BP2/[:`0
UYJF08n?S`0m?Cd0;2`/04a<C02QXJ40MGEe03/k>`0Q8B406a/K02LW9`0i>CT0MWIf08J6QP1RHV80
JVYZ071`L00h>3P0ADE501XJ6P0H61P0EUIF04e=C@28R8P0NGUi06UYJ@2>SXh0[Zj^06][J`1]KFd0
LG5a03Ph>00T92@0>c/k09NGU`1hN7P0I6AT09nOW`2_[jl0a/K60<O7a`1aLG40=3@d05iNGP2GUiL0
H61P04a<C02o_kl0bl_;0<o?c`3>c/h0CTi>03Hf=P0];Bd07alO04a<C00G5aL06ATI020P800];Bd0
9bLW03dm?@1lO7`0Y:BT03Ti>@1lO7`0ZZZZ04M7A`11@D40=SHf030`<00j>SX0:2PX03`l?01?Cdl0
IFEU06YZJP1ADE40<c<c030`<01=CDd0<S8b00807alO0P0L71`0B`0M7Ad0=cLg05IFEP0];Bd0>c/k
08>3P`2LW9`0C4a<05eMG@1gMgL0C4a<04Y:BP1>CTh0G5aL0:n_[`2/[:`0Hf=S0=7Ad@3Jf]X0a<C4
0<K6aP3Jf]X0^;Rh0:JVYP2WYjL0W9bL06i^KP0c<c<071`L028R8P0X:2P09bLW034a<@1JFUX0@T92
04M7A`1ADE40ZJVY0<C4a01bLW80GemO03`l?01@D500UYJF0<_;b`2DU9@0dm?C0=OGe`2ZZZX0`l?3
07emO@0E5AD05aLG01PH600F5QH061PH01`L701EEED0?Cdm02<S8`0W9bL0=cLg06MWI`1PH600PX:2
0:j^[P1:BTX0QXJ603Lg=`18B4P0HV9R09^KV`21PH40KFe]05YJFP02ooooo`000?H0LG5a0;6a/@1L
G5`0YJFU05aLG02<S8`0Ti>C07=cL`0n?Sh0HF5Q07moO`1hN7P0KFe]055AD@2OWil0ADE507alO01o
Ogl0?Cdm09NGU`2>SXh0@T9206i^KP25QHD0HV9R05ADE01LG5`0L71`02h^;P25QHD0MGEe05YJFP1Z
JVX0L71`02DU9@21PH40J6QX03Hf=P19BDT0EEEE03Ph>01;Bd/0>CTi03dm?@0^;Rh09RHV04I6AP0`
<300:b/[0492@P1nOWh0@d=306m_K`0c<c<0;Rh^05aLG01IFET0>3Ph08B4Q00a<C4071`L03lo?`1H
F5P09BDU02@T901EEED0?Cdm030`<00l?3`0R8R805eMG@0W9bL0C4a<03Ph>00I6AT0<S8b05]KF`1<
C4`0BTY:03hn?P0K6a/0@d=307YjNP1SHf<0XJ6Q09^KV`1@D50092@T04e=C@1VIVH0>3Ph04A4A02D
U9@0@T9201/K6`1ZJVX0EEEE02TY:@0M7Ad0G5aL04e=C@1>CTh0A4A409ZJVP1ZJVX0DU9B051@D01I
FET0<30`06a/K014A4@0EEEE061PH00Y:BT0ADE5055AD@0d=3@0NWYj04i>CP1DE5@0Fe]K065QH@0b
<S80KVi^02/[:`1HF5P0FUYJ03Ti>@1fMWH0HV9R038b<P14A4@0K6a/04Y:BP1YJFT0Hf=S02l_;`1Q
HF40IFEU05=CD`17AdL0:BTY08Z:RP1RHV80GemO055AD@0g=cL0A4A40:JVYP1hN7P0:b/[07QhN01N
GUh0<C4a05=CD`1LG5`0=cLg0:NWY`1_Kfl0L71`05MGE`13@d<0>CTi096AT@23Ph<0A4A403/k>`25
QHD0@41004m?C`2GUiL0HF5Q04Q8B02<S8`0LW9b09JFUP1jNWX0QhN706ATI01HF5P0/k>c08b<S01R
HV80SXj>08f=S@1UIFD0SXj>0:>SX`1oOgl08b<S06MWI`3;bl/0SXj>04U9B@1MGEd0J6QX06a/K01>
CTh0XZ:R07=cL`14A4@0KFe]08^;R`15ADD0@D5105IFEP0e=CD0HV9R08b<S01_Kfl0Y:BT08f=S@0k
>c/0De=C09nOW`1UIFD0<C4a08^;R`1FEUH09RHV055AD@1UIFD0@T9203hn?P0j>SX0KFe]071`L00O
7al0;Bd]069RHP25QHD0AdM706YZJP0`<300EeMG05UIF@15ADD0PH6107YjNP1:BTX0?Shn08J6QP1b
LW80MgMg096AT@1JFUX205IFEP0K06UYJ@1<C4`06QXJ0410@01LG5`0Lg=c06IVIP21PH40V9RH04=3
@`0Y:BT0ATI60:6QX@1LG5`0=SHf07=cL`0T92@0;Rh^04e=C@17AdL0;2`/08V9R@1[Jf/08B4Q04U9
B@1@D500J6QX0080Ng]k0440ZZZZ05QHF015ADD0<C4a04Q8B02EUID0G5aL055AD@2BTY80ZJVY020P
800l?3`0[:b/07MgM`14A4@0MgMg09^KV`1jNWX0?clo05iNGP1kNg/0?Cdm05UIF@2WYjL0?Cdm02l_
;`2WYjL0@41001lO7`24Q8@0QhN703Xj>P0a<C40M7Ad04a<C00g=cL0?Cdm071`L02PX:00C4a<034a
<@0V9RH0ATI60410@00e=CD0=SHf03<c<`0^;Rh0:BTY020P800O7al0;2`/09RHV03Bd]80R8R808F5
Q@1oOgl0`l?303Ph>00K6a/05ADE01@D500G5aL0Cdm?0;^k^`020:n_[`080:2PX034a<@0/[:b08B4
Q01mOGd0JFUY01DE5@0A4A4201<C4`0M02DU9@16ATH0?clo03Ph>00[:b/06a/K0492@P1eMGD0QhN7
03<c<`1mOGd0F5QH09FEU@24Q8@0N7Qh02PX:00L71`07AdM01lO7`1:BTX0J6QX06m_K`1kNg/0Ti>C
0:RXZ02l_;`0b<S80:2PX01?Cdl00P0n?Sh05P1ADE40IVIV05YJFP1KFe/0Q8B40:n_[`1]KFd0FUYJ
03dm?@14A4@0XJ6Q0;jn_P20P8005aLG01HF5P11@D40:BTY01dM7@24Q8@0WIfM07UiN@2;Rh/209BD
U01803Ti>@11@D40ADE506e]K@1aLG40>c/k05EEE@2SXj<0N7Qh06YZJP2=SHd0G5aL03Hf=P1ADE40
c/k>06IVIP0N7Qh06ATI01DE5@0[:b/05QHF01DE5@0H61P05ADE01HF5P0G5aL07AdM02d];@1<C4`0
IVIV08f=S@2l_;`0fMWI0<W9b@38b<P0Z:RX0=3@d02VYZH0J6QX04Q8B00];Bd061PH01HF5P0D51@0
;Bd]08>3P`0e=CD05aLG01/K6`1TI6@0@D5104a<C01KFe/0EeMG0=;BdP1CDe<0B4Q804E5A@1=CDd0
IFEU08J6QP2LW9`0h>3P0<30`02d];@0TY:B05UIF@2TY:@0b<S807emO@1UIFD0QHF50P2FUYH0;P2H
V9P0OWin05EEE@1HF5P0De=C05]KF`1bLW80cLg=0;Fe]@1MGEd0;Rh^04A4A00O7al04Q8B01@D500G
5aL0F5QH08Z:RP1GEeL0H61P08Z:RP1LG5`0UYJF08n?S`1[Jf/0M7Ad059BDP0e=CD0YZJV096AT@1^
KVh0Y:BT0;bl_031`L40HV9R06=SH`1oOgl0Ph>304i>CP0U9BD08b<S05YJFP2][Jd0_[jn08b<S01[
Jf/203Lg=`0N020P801:BTX0=SHf02XZ:P10@400De=C04M7A`0m?Cd0>CTi09BDU01KFe/0GEeM0:JV
YP1fMWH0M7Ad09VIV@0b<S80BTY:03Ti>@1IFET0I6AT07AdM01mOGd0@T9203`l?00i>CT0IFEU03Hf
=P0Q8B408R8R0P0O7al0=00R8R80BTY:034a<@0Z:RX0GUiN0:2PX01mOGd0CTi>051@D00a<C407AdM
02l_;`14A4@0GUiN08j>SP2o_kl0VYZJ09:BTP3EeMD0_[jn0<O7a`32`/80YJFU0<O7a`3>c/h0[Jf]
03Ph>00L71`07QhN024Q8@0X:2P0<c<c02/[:`0g=cL0GemO04a<C027QhL0VYZJ0:RXZ02a/K40C4a<
04M7A`1ADE40T92@0<?3``39bLT0WIfM0:j^[P3:b/X0fm_K07UiN@0G5aL201TI6@0401hN7P0W9bL0
>3Ph05YJFP80;2`/00l0:BTY03@d=01PH600F5QH07]kN`1RHV80>c/k05mOG`0X:2P0;2`/02l_;`27
QhL0ATI604A4A01KFe/00_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate six-band training data (top half of each image)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(db4 = DaubechiesFilter[4];\)\), "\[IndentingNewLine]", 
    \(\(trainingData1 = \(GenerateSixBandTrainingData[
              TakeMatrix[#, trainPos1, trainPos2], trainOffset, db4] &\) /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(39.594773`8.04918285095966\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perform vector quantization for each band", "Subsection"],

Cell[BoxData[
    \(\(maxCodes = 6;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(trainingData2 = \((trainingData1\  // \ 
            Transpose)\);\)\), "\[IndentingNewLine]", 
    \(\(vqTrainingData = \(Flatten[#, 1] &\)\  /@ \ 
          trainingData2;\)\), "\[IndentingNewLine]", 
    \(\(centroidsAll = \(VQAll[#, maxCodes,  .0001] &\)\  /@ \ 
          vqTrainingData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(223.51118`8.800844244860448\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(centroidsAll\  = \ 
        Drop[centroidsAll\  // \ Transpose, 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute histograms for all levels of quantization", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(classes = 
        Table[centroids = centroidsAll[\([i]\)]; 
          Table[\(AssignClass[#, centroids[\([j]\)]] &\)\  /@ \ 
              trainingData2[\([j]\)], {j, 1, Length[centroids]}], {i, 1, 
            maxCodes}];\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(39.893015`8.052441853781277\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(histAll = 
        Table[\(ComputeHistograms[#, codes] &\)\  /@ \ 
            classes[\([codes]\)], {codes, 1, maxCodes}];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #1 (2 clusters per band) ", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 1;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6B625C5C5F626320
4F4B4A404D4C4B09
6A62625C61606714
5D4247383D394800
6052574C585C650D
5C464F3F513D5501
735D65646A626D1B
F0FDE0FFEAFFE6CE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6575697B69756400
6D6C6F746F706E04
6077627D63775E05
6A6F727677777108
667E6884687A600B
706E757475757208
5F7A637A62785E06
F9E9FFEDFBECFB83
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Ko
oooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][
7OmRHV8hoeaLG1goGemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY
7?meMGDMofATI1_o00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP
820FoooooagoIFEU7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolL
of][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/L
ofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][7OmRHV8hoeaLG1goGemO7?mRHV8Lof=S
Haco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY7?meMGDMofATI1_o00003_ooool000co
oooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP820FoooooagoIFEU7?meMGDLofUYJAgo
Ng]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R
7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo
000<oooooacoJf][7OmRHV8hoeaLG1goGemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mY
JFTMog]kNacoJFUY7?meMGDMofATI1_o00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelL
of9RHQcoHf=S7?lP820FoooooagoIFEU7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>
ooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEe
MAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][7OmRHV8hoeaLG1go
GemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY7?meMGDMofATI1_o
00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP820FoooooagoIFEU
7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolLof][JagoHV9R>?mL
G5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmT
I6@Ko`0000kooooo000<oooooacoJf][7OmRHV8hoeaLG1goGemO7?mRHV8Lof=SHaco820P5_oooolM
ofEUIAcoMGEe7?mYJFTMog]kNacoJFUY7?meMGDMofATI1_o00003_ooool000cooooo7?m[Jf/Mof9R
HSSoG5aL7OmOGelLof9RHQcoHf=S7?lP820FoooooagoIFEU7?meMGDLofUYJAgoNg]k7?mYJFTLogEe
MAgoI6AT6ol0000>ooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Ko
oooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][
7OmRHV8hoeaLG1goGemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY
7?meMGDMofATI1_o00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP
820FoooooagoIFEU7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolL
of][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/L
ofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][7OmRHV8hoeaLG1goGemO7?mRHV8Lof=S
Haco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY7?meMGDMofATI1_o00003_ooool000co
oooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP820FoooooagoIFEU7?meMGDLofUYJAgo
Ng]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R
7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo
000<oooooacoJf][7OmRHV8hoeaLG1goGemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mY
JFTMog]kNacoJFUY7?meMGDMofATI1_o00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelL
of9RHQcoHf=S7?lP820FoooooagoIFEU7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>
ooooo`003?oooolLof][JagoHV9R>?mLG5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEe
MAcoJFUY7OmkNg/LofUYJAcoMGEe7OmTI6@Ko`0000kooooo000<oooooacoJf][7OmRHV8hoeaLG1go
GemO7?mRHV8Lof=SHaco820P5_oooolMofEUIAcoMGEe7?mYJFTMog]kNacoJFUY7?meMGDMofATI1_o
00003_ooool000cooooo7?m[Jf/Mof9RHSSoG5aL7OmOGelLof9RHQcoHf=S7?lP820FoooooagoIFEU
7?meMGDLofUYJAgoNg]k7?mYJFTLogEeMAgoI6AT6ol0000>ooooo`003?oooolLof][JagoHV9R>?mL
G5`MoemOGacoHV9R7?mSHf<Lob0P81Kooooo7OmUIFDLogEeMAcoJFUY7OmkNg/LofUYJAcoMGEe7OmT
I6@Ko`0000kooooo000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TF
oooooagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?
CagoBd];7?m:BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAd
M1coKfm_7?m`L70Mofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAco
C4a<7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410ko
oooo000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]
7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?CagoBd];7?m:
BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAdM1coKfm_7?m`
L70Mofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<7?m;Bd/L
o`T92AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410kooooo000<oooo
oacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]7?m/K6`Lofm_
KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?CagoBd];7?m:BTXLod10@1go
CDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAdM1coKfm_7?m`L70Mofi^KQ_o
10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<7?m;Bd/Lo`T92AKooooo
7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410kooooo000<oooooacoCdm?7Om;
Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_
KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?CagoBd];7?m:BTXLod10@1goCDe=7?m<C4`L
od];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAdM1coKfm_7?m`L70Mofi^KQ_o10@43_ooool0
00cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/
K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410kooooo000<oooooacoCdm?7Om;Bd/LodY:BQco
@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1go
KVi^6ol410@>ooooo`003?oooolLodm?CagoBd];7?m:BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T9
5_oooolMofe]KAcoK6a/7?m_KflMogAdM1coKfm_7?m`L70Mofi^KQ_o10@43_ooool000cooooo7?m?
CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/K1coKfm_7Omd
M7@Lofm_KacoL71`7Om^KVhKo`@410kooooo000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdL
oda<C1coBd];7?l92@TFoooooagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>
ooooo`003?oooolLodm?CagoBd];7?m:BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]
KAcoK6a/7?m_KflMogAdM1coKfm_7?m`L70Mofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];Baco
BTY:7?m0@40Mode=CAcoC4a<7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_Kaco
L71`7Om^KVhKo`@410kooooo000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];
7?l92@TFoooooagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oo
oolLodm?CagoBd];7?m:BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_
KflMogAdM1coKfm_7?m`L70Mofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40M
ode=CAcoC4a<7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhK
o`@410kooooo000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooo
oagoKFe]7?m/K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?Cago
Bd];7?m:BTXLod10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAdM1co
Kfm_7?m`L70Mofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<
7?m;Bd/Lo`T92AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410kooooo
000<oooooacoCdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]7?m/
K6`Lofm_KagoM7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLodm?CagoBd];7?m:BTXL
od10@1goCDe=7?m<C4`Lod];Baco2@T95_oooolMofe]KAcoK6a/7?m_KflMogAdM1coKfm_7?m`L70M
ofi^KQ_o10@43_ooool000cooooo7?m?CdlMod];BacoBTY:7?m0@40Mode=CAcoC4a<7?m;Bd/Lo`T9
2AKooooo7Om]KFdLofa/K1coKfm_7OmdM7@Lofm_KacoL71`7Om^KVhKo`@410kooooo000<oooooaco
Cdm?7Om;Bd/LodY:BQco@4107Om=CDdLoda<C1coBd];7?l92@TFoooooagoKFe]7?m/K6`Lofm_Kago
M7Ad7?m_KflLog1`L1goKVi^6ol410@>ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P
7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo
000<oooooacoJVYZ>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mR
HV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4L
of1PH1coIfMW7?lD51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>
ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMg
MacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoJVYZ>OmRHV8LoeaLG1go
HF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mRHV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o
1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD51@FoooooagoH61P
7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>ooooo`003?oooolLofYZJSWoHV9R7?mL
G5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmN
GUhKo`D51@kooooo000<oooooacoJVYZ>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolM
of1PH1coMgMg7?mRHV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9R
HQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMg
MagoGUiN6ol51@D>ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Ko
oooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoJVYZ
>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mRHV8MogemOAcoHf=S
7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD
51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>ooooo`003?oooolL
ofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdL
of=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoJVYZ>OmRHV8LoeaLG1goHF5Q7?mPH60LofMW
Iaco51@D5_oooolMof1PH1coMgMg7?mRHV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o1@D53_ooool000co
oooo7?mZJVXiof9RHQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD51@FoooooagoH61P7?mgMgLLof9RHQgo
OGem7?mSHf<LogMgMagoGUiN6ol51@D>ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P
7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo
000<oooooacoJVYZ>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mR
HV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4L
of1PH1coIfMW7?lD51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>
ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMg
MacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoJVYZ>OmRHV8LoeaLG1go
HF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mRHV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o
1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD51@FoooooagoH61P
7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>ooooo`003?oooolLofYZJSWoHV9R7?mL
G5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmN
GUhKo`D51@kooooo000<oooooacoJVYZ>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolM
of1PH1coMgMg7?mRHV8MogemOAcoHf=S7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9R
HQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMg
MagoGUiN6ol51@D>ooooo`003?oooolLofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Ko
oooo7OmPH60LogMgMacoHV9R7OmmOGdLof=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoJVYZ
>OmRHV8LoeaLG1goHF5Q7?mPH60LofMWIaco51@D5_oooolMof1PH1coMgMg7?mRHV8MogemOAcoHf=S
7?mgMgLMoeiNGQ_o1@D53_ooool000cooooo7?mZJVXiof9RHQcoG5aL7OmQHF4Lof1PH1coIfMW7?lD
51@FoooooagoH61P7?mgMgLLof9RHQgoOGem7?mSHf<LogMgMagoGUiN6ol51@D>ooooo`003?oooolL
ofYZJSWoHV9R7?mLG5`Mof5QHAcoH61P7?mWIfLLoa@D51Kooooo7OmPH60LogMgMacoHV9R7OmmOGdL
of=SHacoMgMg7OmNGUhKo`D51@kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi
>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000co
oooo7?mMGEdMod92@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_Kaco
LW9b7OmfMWHhogMgMagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm
7?li>CTLodQ8B1co00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo
000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_
KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mMGEdMod92@QcoAdM77?lh>3PM
ocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_KacoLW9b7OmfMWHhogMgMagoLG5a6ol820P>
ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm7?li>CTLodQ8B1co00005_oooolMofYZ
JQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco
>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o
20P83_ooool000cooooo7?mMGEdMod92@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo
7OmZJVXLofm_KacoLW9b7OmfMWHhogMgMagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7
AdLLocPh>1go?Cdm7?li>CTLodQ8B1co00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7Oma
LG4Ko`P820kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000F
oooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mMGEdMod92
@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_KacoLW9b7OmfMWHhogMg
MagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm7?li>CTLodQ8B1co
00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo000<oooooacoGEeM
7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf
>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mMGEdMod92@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8
B4PLo`0001Kooooo7OmZJVXLofm_KacoLW9b7OmfMWHhogMgMagoLG5a6ol820P>ooooo`003?oooolL
oeeMGAgo@T927?m7AdLLocPh>1go?Cdm7?li>CTLodQ8B1co00005_oooolMofYZJQcoKfm_7?mbLW8M
ogIfMSSoMgMg7OmaLG4Ko`P820kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi
>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000co
oooo7?mMGEdMod92@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_Kaco
LW9b7OmfMWHhogMgMagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm
7?li>CTLodQ8B1co00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo
000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_
KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mMGEdMod92@QcoAdM77?lh>3PM
ocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_KacoLW9b7OmfMWHhogMgMagoLG5a6ol820P>
ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm7?li>CTLodQ8B1co00005_oooolMofYZ
JQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco
>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o
20P83_ooool000cooooo7?mMGEdMod92@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo
7OmZJVXLofm_KacoLW9b7OmfMWHhogMgMagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7
AdLLocPh>1go?Cdm7?li>CTLodQ8B1co00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7Oma
LG4Ko`P820kooooo000<oooooacoGEeM7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000F
oooooagoJVYZ7?m_KflLog9bLQgoMWIf>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mMGEdMod92
@QcoAdM77?lh>3PMocdm?Aco>CTi7?m8B4PLo`0001Kooooo7OmZJVXLofm_KacoLW9b7OmfMWHhogMg
MagoLG5a6ol820P>ooooo`003?oooolLoeeMGAgo@T927?m7AdLLocPh>1go?Cdm7?li>CTLodQ8B1co
00005_oooolMofYZJQcoKfm_7?mbLW8MogIfMSSoMgMg7OmaLG4Ko`P820kooooo000<oooooacoGEeM
7Om2@T8LodM7Aaco>3Ph7Olm?CdLocTi>AcoB4Q87?l0000FoooooagoJVYZ7?m_KflLog9bLQgoMWIf
>?mgMgLMog5aLA_o20P83_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mU
IFDLo`d=3AKooooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<
oooooacoH61P7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhL
ofQXJ1goQ8B47?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<
C1goF5QH7?mLG5`LofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1P
H1_o2`/;3_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKo
oooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P
7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B4
7?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<C1goF5QH7?mL
G5`LofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_oo
ool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo7OmVIVHL
oginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P7OmBDU8LoeMG
EacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYj
NQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<C1goF5QH7?mLG5`LofEUIAco
3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_ooool000cooooo
7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo7OmVIVHLoginOQcoJ6QX
7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P7OmBDU8LoeMGEacoC4a<7OmH
F5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYjNQgoH61P6ol;
2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<C1goF5QH7?mLG5`LofEUIAco3@d=5_oooolM
ofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_ooool000cooooo7?mPH60Moe9B
DQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQX
J1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1co
IFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`00
3?oooolLof1PH1goDU9B7?mGEeLLoda<C1goF5QH7?mLG5`LofEUIAco3@d=5_oooolMofIVIQcoOWin
7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<
C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmP
H60Ko`/;2`kooooo000<oooooacoH61P7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dF
oooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1P
H1goDU9B7?mGEeLLoda<C1goF5QH7?mLG5`LofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4
Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1co
G5aL7?mUIFDLo`d=3AKooooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`ko
oooo000<oooooacoH61P7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV
7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mG
EeLLoda<C1goF5QH7?mLG5`LofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mj
NWXMof1PH1_o2`/;3_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDL
o`d=3AKooooo7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooo
oacoH61P7OmBDU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQX
J1goQ8B47?mXJ6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<C1go
F5QH7?mLG5`LofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o
2`/;3_ooool000cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo
7OmVIVHLoginOQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P7OmB
DU8LoeMGEacoC4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mX
J6PLogYjNQgoH61P6ol;2`/>ooooo`003?oooolLof1PH1goDU9B7?mGEeLLoda<C1goF5QH7?mLG5`L
ofEUIAco3@d=5_oooolMofIVIQcoOWin7?mXJ6PMohB4Q1coJ6QX7?mjNWXMof1PH1_o2`/;3_ooool0
00cooooo7?mPH60Moe9BDQcoEeMG7?m<C4`MoeQHF1coG5aL7?mUIFDLo`d=3AKooooo7OmVIVHLogin
OQcoJ6QX7On4Q8@LofQXJ1coNWYj7OmPH60Ko`/;2`kooooo000<oooooacoH61P7OmBDU8LoeMGEaco
C4a<7OmHF5PLoeaLG1coIFEU7?l=3@dFoooooagoIVIV7?mnOWhLofQXJ1goQ8B47?mXJ6PLogYjNQgo
H61P6ol;2`/>ooooo`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@41
5_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6
ATHLodm?Caco?clo7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?me
MGDMog9bLQ_o20P83_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDL
o`410AKooooo7Om`L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaL
G1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAd
M3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6ATHLodm?Caco?clo7OmADE4Locdm?Aco
EEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?meMGDMog9bLQ_o20P83_ooool000cooooo
7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDLo`410AKooooo7Om`L70Lofi^KQcoMGEe
7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm
?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<
oooooacoG5aL7Om6ATHLodm?Caco?clo7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhL
ogEeMAgoM7Ad>?meMGDMog9bLQ_o20P83_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5A
DAco?Cdm7?mEEEDLo`410AKooooo7Om`L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>oooo
o`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1co
KVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6ATHLodm?Caco?clo
7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?meMGDMog9bLQ_o20P8
3_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDLo`410AKooooo7Om`
L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaLG1goATI67?m?CdlL
oclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8K
o`P820kooooo000<oooooacoG5aL7Om6ATHLodm?Caco?clo7OmADE4Locdm?AcoEEEE7?l10@4Foooo
oagoL71`7?m^KVhLogEeMAgoM7Ad>?meMGDMog9bLQ_o20P83_ooool000cooooo7?mLG5`ModI6AQco
Cdm?7?lo?clMoe5ADAco?Cdm7?mEEEDLo`410AKooooo7Om`L70Lofi^KQcoMGEe7OmdM7@hogEeMAgo
LW9b6ol820P>ooooo`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@41
5_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6
ATHLodm?Caco?clo7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?me
MGDMog9bLQ_o20P83_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDL
o`410AKooooo7Om`L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaL
G1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAd
M3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6ATHLodm?Caco?clo7OmADE4Locdm?Aco
EEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?meMGDMog9bLQ_o20P83_ooool000cooooo
7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDLo`410AKooooo7Om`L70Lofi^KQcoMGEe
7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm
?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<
oooooacoG5aL7Om6ATHLodm?Caco?clo7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhL
ogEeMAgoM7Ad>?meMGDMog9bLQ_o20P83_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5A
DAco?Cdm7?mEEEDLo`410AKooooo7Om`L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>oooo
o`003?oooolLoeaLG1goATI67?m?CdlLoclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1co
KVi^7?meMGDMogAdM3SoMGEe7OmbLW8Ko`P820kooooo000<oooooacoG5aL7Om6ATHLodm?Caco?clo
7OmADE4Locdm?AcoEEEE7?l10@4FoooooagoL71`7?m^KVhLogEeMAgoM7Ad>?meMGDMog9bLQ_o20P8
3_ooool000cooooo7?mLG5`ModI6AQcoCdm?7?lo?clMoe5ADAco?Cdm7?mEEEDLo`410AKooooo7Om`
L70Lofi^KQcoMGEe7OmdM7@hogEeMAgoLW9b6ol820P>ooooo`003?oooolLoeaLG1goATI67?m?CdlL
oclo?agoDE5A7?lm?CdLoeEEEAco0@415_oooolMog1`L1coKVi^7?meMGDMogAdM3SoMGEe7OmbLW8K
o`P820kooooo000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/Foooo
oagoGemO7?mjNWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLago
GEeM7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQco
HV9R7?mhN7PMoeiNGQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R
7?m]KFdLoa/K6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo
000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mj
NWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLagoGEeM7?mUIFDL
ofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R7?mhN7PM
oeiNGQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K
6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<oooooaco
Lg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXLof=SHago
NWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLagoGEeM7?mUIFDLofATI1goJVYZ
7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R7?mhN7PMoeiNGQ_o1PH6
3_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K6aKooooo7OmO
GelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<oooooacoLg=c7OmMGEdL
ofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXLof=SHagoNWYj7?mRHV8L
ogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLagoGEeM7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]
KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R7?mhN7PMoeiNGQ_o1PH63_ooool000co
oooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K6aKooooo7OmOGelLogYjNQco
Hf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT
7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN
6ol61PH>ooooo`003?oooolLog=cLagoGEeM7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oo
oolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R7?mhN7PMoeiNGQ_o1PH63_ooool000cooooo7?mcLg<M
oeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXL
of9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9R
HQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>oooo
o`003?oooolLog=cLagoGEeM7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGaco
NWYj7?mSHf<MogYjNQcoHV9R7?mhN7PMoeiNGQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU
7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh
7OmNGUhKo`H61Pkooooo000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK
6a/FoooooagoGemO7?mjNWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolL
og=cLagoGEeM7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<M
ogYjNQcoHV9R7?mhN7PMoeiNGQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZ
JQcoHV9R7?m]KFdLoa/K6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H6
1Pkooooo000<oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/Foooooago
GemO7?mjNWXLof=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLagoGEeM
7?mUIFDLofATI1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R
7?mhN7PMoeiNGQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]
KFdLoa/K6aKooooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<
oooooacoLg=c7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXL
of=SHagoNWYj7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLog=cLagoGEeM7?mUIFDLofAT
I1goJVYZ7?mRHV8Lofe]KAco6a/K5_oooolMoemOGacoNWYj7?mSHf<MogYjNQcoHV9R7?mhN7PMoeiN
GQ_o1PH63_ooool000cooooo7?mcLg<MoeeMGAcoIFEU7?mTI6@MofYZJQcoHV9R7?m]KFdLoa/K6aKo
oooo7OmOGelLogYjNQcoHf=S7OmjNWXLof9RHQcoN7Qh7OmNGUhKo`H61Pkooooo000<oooooacoLg=c
7OmMGEdLofEUIAcoI6AT7OmZJVXLof9RHQcoKFe]7?lK6a/FoooooagoGemO7?mjNWXLof=SHagoNWYj
7?mRHV8LogQhN1goGUiN6ol61PH>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oo
oolLonKViQcoc/k>5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_oo
ool000cooooo7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTL
onWYjAcooooo7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3P
h1cooooo7OoZj^XLoooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/
k1gono_k6on3Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQco
c/k>5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool000cooooo
7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTLonWYjAcooooo
7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3Ph1cooooo7OoZ
j^XLoooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/k1gono_k6on3
Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQcoc/k>5_oooolM
ooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool000cooooo7?o`l?0Moogm
oAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTLonWYjAcooooo7Oo]kNdLoo_k
nacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3Ph1cooooo7OoZj^XLoooooaco
i^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/k1gono_k6on3Ph<>ooooo`00
3?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQcoc/k>5_oooolMooWinAcojNWY
7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool000cooooo7?o`l?0MoogmoAcoh>3P7?oo
oolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTLonWYjAcooooo7Oo]kNdLoo_knacok>c/7Ook
no/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3Ph1cooooo7OoZj^XLoooooacoi^KV7?o>c/hF
oooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/k1gono_k6on3Ph<>ooooo`003?oooolLoo3`
l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQcoc/k>5_oooolMooWinAcojNWY7?oooolMong]
kAcono_k7?o/k>`Moo_kna_oPh>33_ooool000cooooo7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQco
oooo7?oVi^HLolk>cQKooooo7OoinOTLonWYjAcooooo7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`ko
oooo000<oooooacol?3`7OomoOdLon3Ph1cooooo7OoZj^XLoooooacoi^KV7?o>c/hFoooooagonOWi
7?oYjNTLoooooagokNg]7?okno/Lonc/k1gono_k6on3Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oP
h>0Loooooagoj^[Z7?oooolLonKViQcoc/k>5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/
k>`Moo_kna_oPh>33_ooool000cooooo7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HL
olk>cQKooooo7OoinOTLonWYjAcooooo7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooo
oacol?3`7OomoOdLon3Ph1cooooo7OoZj^XLoooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooo
oagokNg]7?okno/Lonc/k1gono_k6on3Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooago
j^[Z7?oooolLonKViQcoc/k>5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_o
Ph>33_ooool000cooooo7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo
7OoinOTLonWYjAcooooo7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7Oom
oOdLon3Ph1cooooo7OoZj^XLoooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?ok
no/Lonc/k1gono_k6on3Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolL
onKViQcoc/k>5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool0
00cooooo7?o`l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTLonWY
jAcooooo7Oo]kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3Ph1co
oooo7OoZj^XLoooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/k1go
no_k6on3Ph<>ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQcoc/k>
5_oooolMooWinAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool000cooooo7?o`
l?0MoogmoAcoh>3P7?oooolMon[ZjQcooooo7?oVi^HLolk>cQKooooo7OoinOTLonWYjAcooooo7Oo]
kNdLoo_knacok>c/7Ookno/Koh>3P`kooooo000<oooooacol?3`7OomoOdLon3Ph1cooooo7OoZj^XL
oooooacoi^KV7?o>c/hFoooooagonOWi7?oYjNTLoooooagokNg]7?okno/Lonc/k1gono_k6on3Ph<>
ooooo`003?oooolLoo3`l1gooOgm7?oPh>0Loooooagoj^[Z7?oooolLonKViQcoc/k>5_oooolMooWi
nAcojNWY7?oooolMong]kAcono_k7?o/k>`Moo_kna_oPh>33_ooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.440797, -0.201592, 0.0354378, 0.0354378}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-9.24044, -0.201592, 0.0354378, 0.0354378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C091D0E210C18FF
0804080F150312ED
12001506150013F8
01070B0C13030EE9
13051609110015F1
050B110D0E0812E6
190F1D1014071EEB
010D090E06060CC7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9CE4ABC896C397C4
CDA1D37B9F9B9D7F
B6FABBDBB6E8A1D5
EDA4CD90ACA5B29D
B6E3BBC9CBE19EF5
DC91B68AC597A7AC
A6AFAAA1C7BA85FF
4B0534003E151AA8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;o
oooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L
7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF
7?o3`l<MoiNGUa_oa<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH
61PboooooagoW9bL7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolL
oa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PL
oiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<
31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_oa<C43_ooool000co
oooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH61PboooooagoW9bL7?oTi>@Loj^[Zago
b<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q
7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo
000<oooooaco71`L7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[
Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_oa<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhM
ob4Q8Aco30`<7?lH61PboooooagoW9bL7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>
ooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCT
i1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L7Ol92@TLoadM7Aco
3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_o
a<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH61PboooooagoW9bL
7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolLoa`L71go2@T97?lM
7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnG
UiLKolC4a0kooooo000<oooooaco71`L7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<31co61PH<_oooolM
oibLW1coi>CT7?n[Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_oa<C43_ooool000cooooo7?lL71`Mo`T9
2Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH61PboooooagoW9bL7?oTi>@Loj^[Zagob<S87?nFUYHLol?3
`agoUiNG6oo4a<@>ooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;o
oooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L
7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF
7?o3`l<MoiNGUa_oa<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH
61PboooooagoW9bL7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolL
oa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PL
oiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<
31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_oa<C43_ooool000co
oooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH61PboooooagoW9bL7?oTi>@Loj^[Zago
b<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q
7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo
000<oooooaco71`L7Ol92@TLoadM7Aco3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[
Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_oa<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhM
ob4Q8Aco30`<7?lH61PboooooagoW9bL7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>
ooooo`003?oooolLoa`L71go2@T97?lM7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCT
i1coZj^[7Oo8b<PLoiJFUQco`l?37OnGUiLKolC4a0kooooo000<oooooaco71`L7Ol92@TLoadM7Aco
3Ph>7OlQ8B4Lo``<31co61PH<_oooolMoibLW1coi>CT7?n[Zj/MolS8b1coUYJF7?o3`l<MoiNGUa_o
a<C43_ooool000cooooo7?lL71`Mo`T92Aco7AdM7?l>3PhMob4Q8Aco30`<7?lH61PboooooagoW9bL
7?oTi>@Loj^[Zagob<S87?nFUYHLol?3`agoUiNG6oo4a<@>ooooo`003?oooolLoa`L71go2@T97?lM
7AdLo`h>3Qgo8B4Q7?l<30`LoaPH63;ooooo7OnLW9`LonCTi1coZj^[7Oo8b<PLoiJFUQco`l?37OnG
UiLKolC4a0kooooo000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdF
oooooagocLg=7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P8
21go10@47?l820PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]k
NacoWinO7?nKVi/MoifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco
0`<37?lB4Q8Long]kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`ko
oooo000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=
7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P821go10@47?l8
20PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nK
Vi/MoifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco0`<37?lB4Q8L
ong]kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`kooooo000<oooo
oaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQXJ4Lom?C
dagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P821go10@47?l820PLo`l?3ago
5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nKVi/MoifMWA_o
Ogmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco0`<37?lB4Q8Long]kAKooooo
7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`kooooo000<oooooaco20P87Ol4
10@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQXJ4Lom?CdagoNg]k7?nO
WilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P821go10@47?l820PLo`l?3ago5ADE7?l30`<L
oa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nKVi/MoifMWA_oOgmo3_ooool0
00cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco0`<37?lB4Q8Long]kAKooooo7Oo=cLdLoj6Q
XAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`kooooo000<oooooaco20P87Ol410@Lo`P821co
3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVago
WIfM6omoOgl>ooooo`003?oooolLo`P821go10@47?l820PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]
5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nKVi/MoifMWA_oOgmo3_ooool000cooooo7?l8
20PMo`@411co20P87?l?3`lMoaDE5Aco0`<37?lB4Q8Long]kAKooooo7Oo=cLdLoj6QXAcodm?C7Omk
Ng/LoinOWacoVi^K7OnMWIdKogmoO`kooooo000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADL
o`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>
ooooo`003?oooolLo`P821go10@47?l820PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=
cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nKVi/MoifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co
20P87?l?3`lMoaDE5Aco0`<37?lB4Q8Long]kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWaco
Vi^K7OnMWIdKogmoO`kooooo000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B
7?o]kNdFoooooagocLg=7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oo
oolLo`P821go10@47?l820PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oC
dm<Mog]kNacoWinO7?nKVi/MoifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lM
oaDE5Aco0`<37?lB4Q8Long]kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdK
ogmoO`kooooo000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooo
oagocLg=7?nQXJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P821go
10@47?l820PLo`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNaco
WinO7?nKVi/MoifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco0`<3
7?lB4Q8Long]kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`kooooo
000<oooooaco20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQ
XJ4Lom?CdagoNg]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLo`P821go10@47?l820PL
o`l?3ago5ADE7?l30`<Loa8B4QcokNg]5_oooolMolg=cAcoXJ6Q7?oCdm<Mog]kNacoWinO7?nKVi/M
oifMWA_oOgmo3_ooool000cooooo7?l820PMo`@411co20P87?l?3`lMoaDE5Aco0`<37?lB4Q8Long]
kAKooooo7Oo=cLdLoj6QXAcodm?C7OmkNg/LoinOWacoVi^K7OnMWIdKogmoO`kooooo000<oooooaco
20P87Ol410@Lo`P821co3`l?7OlE5ADLo`<30aco4Q8B7?o]kNdFoooooagocLg=7?nQXJ4Lom?Cdago
Ng]k7?nOWilLoi^KVagoWIfM6omoOgl>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE
7?l0000Loa<C4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE
3_ooool000cooooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf
][HLoo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000L
oaDE5Aco1PH67OlE5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HL
onSXj1goXJ6Q6ooEeMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C
4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000co
oooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf][HLoo[jnQco
^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000LoaDE5Aco1PH6
7OlE5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSXj1goXJ6Q
6ooEeMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4acon?Sh5_oo
oolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo7?lB4Q8M
o`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf][HLoo[jnQco^k^k7OoKfm/L
okJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000LoaDE5Aco1PH67OlE5ADLo`00
01co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSXj1goXJ6Q6ooEeMD>oooo
o`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4acon?Sh5_oooolMokJf]Qco
n_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo7?lB4Q8Mo`0001co5ADE
7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf][HLoo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX
7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000LoaDE5Aco1PH67OlE5ADLo`0001co4a<C7?oh
n?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSXj1goXJ6Q6ooEeMD>ooooo`003?oooolL
oa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/M
om_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE
5Aco00007?lC4a<LooShn1Kooooo7Onf][HLoo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGE
e@kooooo000<oooooaco4Q8B7Ol0000LoaDE5Aco1PH67OlE5ADLo`0001co4a<C7?ohn?PFoooooago
][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSXj1goXJ6Q6ooEeMD>ooooo`003?oooolLoa8B4Qgo0000
7?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf
7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC
4a<LooShn1Kooooo7Onf][HLoo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<
oooooaco4Q8B7Ol0000LoaDE5Aco1PH67OlE5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XL
ok^k^agofm_K7?nf][HLonSXj1goXJ6Q6ooEeMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H6
1Qgo5ADE7?l0000Loa<C4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6Q
XA_oeMGE3_ooool000cooooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Ko
oooo7Onf][HLoo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B
7Ol0000LoaDE5Aco1PH67OlE5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K
7?nf][HLonSXj1goXJ6Q6ooEeMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0
000Loa<C4acon?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_oo
ool000cooooo7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf][HL
oo[jnQco^k^k7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000LoaDE
5Aco1PH67OlE5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSX
j1goXJ6Q6ooEeMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4aco
n?Sh5_oooolMokJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo
7?lB4Q8Mo`0001co5ADE7?l61PHMoaDE5Aco00007?lC4a<LooShn1Kooooo7Onf][HLoo[jnQco^k^k
7OoKfm/LokJf]Qcoj>SX7OnQXJ4KomGEe@kooooo000<oooooaco4Q8B7Ol0000LoaDE5Aco1PH67OlE
5ADLo`0001co4a<C7?ohn?PFoooooago][Jf7?ojn_XLok^k^agofm_K7?nf][HLonSXj1goXJ6Q6ooE
eMD>ooooo`003?oooolLoa8B4Qgo00007?lE5ADLo`H61Qgo5ADE7?l0000Loa<C4acon?Sh5_oooolM
okJf]Qcon_[j7?nk^k/Mom_Kfaco][Jf7?oXj>PMoj6QXA_oeMGE3_ooool000cooooo7?l10@4Mo`L7
1aco2`/;7?l<30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/
[1coYJFU7Onb/[8KoifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco
3Ph>7?oYjNTFoooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`00
3?oooolLo`410Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT
7?o=cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<
30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb
/[8KoifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTF
oooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`003?oooolLo`41
0Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=cLdMoi2@
T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<30`Moa<C4aco
0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8KoifMW@ko
oooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTFoooooagokNg]
7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`003?oooolLo`410Ago1`L77?l;
2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=cLdMoi2@T1co[:b/7?nU
YJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<30`Moa<C4aco0`<37?l>3PhL
onWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8KoifMW@kooooo000<oooo
oaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTFoooooagokNg]7?nTY:@Lolg=
cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`003?oooolLo`410Ago1`L77?l;2`/Lo``<31go
4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_o
WIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo
7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8KoifMW@kooooo000<oooooaco0@417Ol7
1`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTFoooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/
[:`LojFUYAgo/[:b6onMWId>ooooo`003?oooolLo`410Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<L
o`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool0
00cooooo7?l10@4Mo`L71aco2`/;7?l<30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBT
Y1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8KoifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco
30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTFoooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo
/[:b6onMWId>ooooo`003?oooolLo`410Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY
5_oooolMong]kAcoY:BT7?o=cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l1
0@4Mo`L71aco2`/;7?l<30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@
T90Lojb/[1coYJFU7Onb/[8KoifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<L
o`<30aco3Ph>7?oYjNTFoooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>
ooooo`003?oooolLo`410Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]
kAcoY:BT7?o=cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco
2`/;7?l<30`Moa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1co
YJFU7Onb/[8KoifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>
7?oYjNTFoooooagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`003?oo
oolLo`410Ago1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=
cLdMoi2@T1co[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<30`M
oa<C4aco0`<37?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8K
oifMW@kooooo000<oooooaco0@417Ol71`LLo`/;2aco30`<7OlC4a<Lo`<30aco3Ph>7?oYjNTFoooo
oagokNg]7?nTY:@Lolg=cAgoT92@7?n/[:`LojFUYAgo/[:b6onMWId>ooooo`003?oooolLo`410Ago
1`L77?l;2`/Lo``<31go4a<C7?l30`<Lo`h>3QcojNWY5_oooolMong]kAcoY:BT7?o=cLdMoi2@T1co
[:b/7?nUYJDMok:b/Q_oWIfM3_ooool000cooooo7?l10@4Mo`L71aco2`/;7?l<30`Moa<C4aco0`<3
7?l>3PhLonWYjAKooooo7Oo]kNdLojBTY1cocLg=7On@T90Lojb/[1coYJFU7Onb/[8KoifMW@kooooo
000<oooooaco4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oS
hn<Lok^k^agobLW97?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHL
o`T92Ago4A4A7?l0000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4M
oijNWQ_omOGe3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7a
lAKooooo7Onf][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco
4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^ago
bLW97?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A
7?l0000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe
3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKooooo7Onf
][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco4a<C7Ol51@DL
oaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^agobLW97?o;bl/L
on7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0000LoaDE
5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_ooool000co
oooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKooooo7Onf][HLon?Shaco
^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco4a<C7Ol51@DLoaHF5Qco2@T9
7OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^agobLW97?o;bl/Lon7QhAgoWYjN
6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0000LoaDE5AcolO7a5_oo
oolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_ooool000cooooo7?lC4a<M
o`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKooooo7Onf][HLon?Shaco^k^k7Oo9bLTL
ol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`00
01co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^agobLW97?o;bl/Lon7QhAgoWYjN6ooemOD>oooo
o`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0000LoaDE5AcolO7a5_oooolMokJf]Qco
hn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF
7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKooooo7Onf][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q
7OnNWYhKooGem@kooooo000<oooooaco4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oa
lO4Foooooago][Jf7?oShn<Lok^k^agobLW97?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolL
oa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/M
olW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A
4Aco00007?lE5ADLoo7alAKooooo7Onf][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGe
m@kooooo000<oooooaco4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago
][Jf7?oShn<Lok^k^agobLW97?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D5
7?lF5QHLo`T92Ago4A4A7?l0000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;
7?oQhN4MoijNWQ_omOGe3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE
5ADLoo7alAKooooo7Onf][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<
oooooaco4a<C7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<L
ok^k^agobLW97?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T9
2Ago4A4A7?l0000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijN
WQ_omOGe3_ooool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKo
oooo7Onf][HLon?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco4a<C
7Ol51@DLoaHF5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^agobLW9
7?o;bl/Lon7QhAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0
000LoaDE5AcolO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_oo
ool000cooooo7?lC4a<Mo`D51Aco5QHF7?l92@TMoa4A4Aco00007?lE5ADLoo7alAKooooo7Onf][HL
on?Shaco^k^k7Oo9bLTLol_;bacohN7Q7OnNWYhKooGem@kooooo000<oooooaco4a<C7Ol51@DLoaHF
5Qco2@T97OlA4A4Lo`0001co5ADE7?oalO4Foooooago][Jf7?oShn<Lok^k^agobLW97?o;bl/Lon7Q
hAgoWYjN6ooemOD>ooooo`003?oooolLoa<C4ago1@D57?lF5QHLo`T92Ago4A4A7?l0000LoaDE5Aco
lO7a5_oooolMokJf]Qcohn?S7?nk^k/MolW9bAcobl_;7?oQhN4MoijNWQ_omOGe3_ooool000cooooo
7?l51@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf
7On:RXXLolG5aAcoUiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>
3PhLo`P821co4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/
[:`>ooooo`003?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolM
omcLg1coTI6A7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;
2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5
aAcoUiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co
4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>ooooo`00
3?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcLg1coTI6A
7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;2aco4A4A7?l=
3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAcoUiNG7OnW
YjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co4Q8B7?oVi^HF
oooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>ooooo`003?oooolLo`D5
1Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcLg1coTI6A7?nf][HMohZ:
RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco
20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAcoUiNG7OnWYjLKojb/[0ko
oooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co4Q8B7?oVi^HFoooooagog=cL
7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>ooooo`003?oooolLo`D51Ago2`/;7?lA
4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcLg1coTI6A7?nf][HMohZ:RQcoaLG57?nG
UiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8L
onKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAcoUiNG7OnWYjLKojb/[0kooooo000<oooo
oaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf
]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>ooooo`003?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago
3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcLg1coTI6A7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o
[:b/3_ooool000cooooo7?l51@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo
7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAcoUiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;
2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5
aLDLoiNGUagoYjNW6on/[:`>ooooo`003?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PL
oa8B4Qcoi^KV5_oooolMomcLg1coTI6A7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool0
00cooooo7?l51@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6A
TAco][Jf7On:RXXLolG5aAcoUiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco
3@d=7Ol>3PhLo`P821co4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUago
YjNW6on/[:`>ooooo`003?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV
5_oooolMomcLg1coTI6A7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l5
1@DMo`/;2aco4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:
RXXLolG5aAcoUiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhL
o`P821co4Q8B7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>
ooooo`003?oooolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcL
g1coTI6A7?nf][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;2aco
4A4A7?l=3@dMo`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAco
UiNG7OnWYjLKojb/[0kooooo000<oooooaco1@D57Ol;2`/Loa4A4Aco3@d=7Ol>3PhLo`P821co4Q8B
7?oVi^HFoooooagog=cL7?nATI4LokJf]QgoRXZ:7?o5aLDLoiNGUagoYjNW6on/[:`>ooooo`003?oo
oolLo`D51Ago2`/;7?lA4A4Lo`d=3Ago3Ph>7?l820PLoa8B4Qcoi^KV5_oooolMomcLg1coTI6A7?nf
][HMohZ:RQcoaLG57?nGUiLMojNWYa_o[:b/3_ooool000cooooo7?l51@DMo`/;2aco4A4A7?l=3@dM
o`h>3Qco20P87?lB4Q8LonKViQKooooo7OoLg=`Loi6ATAco][Jf7On:RXXLolG5aAcoUiNG7OnWYjLK
ojb/[0kooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/Foooo
oagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco
7AdM7?l@410Moa@D51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco
^[Zj7On5QHDYooooo`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[
5_oooolMojJVYQco[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?
3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7
alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco7AdM7?l@410Moa@D51co1`L77?lN7QhL
on_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco^[Zj7On5QHDYooooo`003?oooolLoaTI
6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[5_oooolMojJVYQco[jn_7?nZZZXMoj6Q
XAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco
7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo
7?lI6ATMo`l?3aco7AdM7?l@410Moa@D51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ
7OnQXJ4LolO7aaco^[Zj7On5QHDYooooo`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l7
1`LLoahN7Qcojn_[5_oooolMojJVYQco[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<
oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlL
ojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco7AdM7?l@410Moa@D
51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco^[Zj7On5QHDYoooo
o`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[5_oooolMojJVYQco
[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@
7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5
:Oooool000cooooo7?lI6ATMo`l?3aco7AdM7?l@410Moa@D51co1`L77?lN7QhLon_[jaKooooo7OnV
YZHLojn_[acoZZZZ7OnQXJ4LolO7aaco^[Zj7On5QHDYooooo`003?oooolLoaTI6Ago3`l?7?lM7AdL
oa0@41go51@D7?l71`LLoahN7Qcojn_[5_oooolMojJVYQco[jn_7?nZZZXMoj6QXAcoalO77?nj^[XM
ohF5QBWooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/Foooo
oagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco
7AdM7?l@410Moa@D51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco
^[Zj7On5QHDYooooo`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[
5_oooolMojJVYQco[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?
3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7
alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco7AdM7?l@410Moa@D51co1`L77?lN7QhL
on_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco^[Zj7On5QHDYooooo`003?oooolLoaTI
6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[5_oooolMojJVYQco[jn_7?nZZZXMoj6Q
XAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco
7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo
7?lI6ATMo`l?3aco7AdM7?l@410Moa@D51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ
7OnQXJ4LolO7aaco^[Zj7On5QHDYooooo`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l7
1`LLoahN7Qcojn_[5_oooolMojJVYQco[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<
oooooaco6ATI7Ol?3`lLoadM7Aco410@7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlL
ojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5:Oooool000cooooo7?lI6ATMo`l?3aco7AdM7?l@410Moa@D
51co1`L77?lN7QhLon_[jaKooooo7OnVYZHLojn_[acoZZZZ7OnQXJ4LolO7aaco^[Zj7On5QHDYoooo
o`003?oooolLoaTI6Ago3`l?7?lM7AdLoa0@41go51@D7?l71`LLoahN7Qcojn_[5_oooolMojJVYQco
[jn_7?nZZZXMoj6QXAcoalO77?nj^[XMohF5QBWooooo000<oooooaco6ATI7Ol?3`lLoadM7Aco410@
7OlD51@Lo`L71aco7QhN7?o[jn/FoooooagoYZJV7?n_[jlLojZZZQgoXJ6Q7?o7alLLokZj^QgoQHF5
:Oooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l5
1@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TL
o`h>3SWo1PH67?l<30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXK
ojRXZ0kooooo000<oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];
Baco1@D57?ld=3@Mo`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco
2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago
6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TLo`h>3SWo1PH67?l<30`LolO7aaKooooo
7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXKojRXZ0kooooo000<oooooaco0@417Ol=
3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];Baco1@D57?ld=3@Mo`0001co?Shn7?lE
5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLF
oooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`41
0Ago3@d=7?l92@TLo`h>3SWo1PH67?l<30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn
?Qco5ADE7OlJ6QXKojRXZ0kooooo000<oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31co
alO75_oooolMod];Baco1@D57?ld=3@Mo`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo
7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go0000
7?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TLo`h>3SWo1PH67?l<
30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXKojRXZ0kooooo000<
oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];Baco1@D57?ld=3@M
o`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H6
1Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>oooo
o`003?oooolLo`410Ago3@d=7?l92@TLo`h>3SWo1PH67?l<30`LolO7aaKooooo7Om;Bd/Lo`D51Aco
=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXKojRXZ0kooooo000<oooooaco0@417Ol=3@dLo`T92Aco3Ph>
>Ol61PHLo``<31coalO75_oooolMod];Baco1@D57?ld=3@Mo`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX
3_ooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l5
1@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TL
o`h>3SWo1PH67?l<30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXK
ojRXZ0kooooo000<oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];
Baco1@D57?ld=3@Mo`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco
2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago
6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TLo`h>3SWo1PH67?l<30`LolO7aaKooooo
7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXKojRXZ0kooooo000<oooooaco0@417Ol=
3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];Baco1@D57?ld=3@Mo`0001co?Shn7?lE
5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLF
oooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`41
0Ago3@d=7?l92@TLo`h>3SWo1PH67?l<30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn
?Qco5ADE7OlJ6QXKojRXZ0kooooo000<oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31co
alO75_oooolMod];Baco1@D57?ld=3@Mo`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo
7?l10@4Mo`d=3Aco2@T97?l>3Phio`H61Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go0000
7?ln?ShLoaDE5Ago6QXJ6onXZ:P>ooooo`003?oooolLo`410Ago3@d=7?l92@TLo`h>3SWo1PH67?l<
30`LolO7aaKooooo7Om;Bd/Lo`D51Aco=3@d7Ol0000Lochn?Qco5ADE7OlJ6QXKojRXZ0kooooo000<
oooooaco0@417Ol=3@dLo`T92Aco3Ph>>Ol61PHLo``<31coalO75_oooolMod];Baco1@D57?ld=3@M
o`0001co?Shn7?lE5ADMoaXJ6Q_oZ:RX3_ooool000cooooo7?l10@4Mo`d=3Aco2@T97?l>3Phio`H6
1Qco30`<7?o7alLFoooooagoBd];7?l51@DLoc@d=1go00007?ln?ShLoaDE5Ago6QXJ6onXZ:P>oooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.440797, -0.201592, 0.0354378, 0.0354378}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-9.24044, -0.201592, 0.0354378, 0.0354378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
14191417171F1A76
02030306050B145E
0C130C120F181674
020001030307115B
0D120D120D0F1373
0A060B050A0A1562
191A1B1A181A1A77
A89BA69DADA0B7FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000E0412040701FA
11151011130B00F8
0B180F1A0F1206FD
121D1518181205F8
0C1C101C141F0DFF
09150917110F01EE
011003100B0E07F8
20262424222113F1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKo
oooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D
7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@4
7?l71`LMo`410A_on_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mf
MWHFoooooago00007?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolL
oa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8L
o`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ
6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@47?l71`LMo`410A_on_[j3_ooool000co
oooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mfMWHFoooooago00007?l>3PhLo`@411go
4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO
7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo
000<oooooaco51@D7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l4
10@Moa8B4Qco10@47?l71`LMo`410A_on_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLL
oalO7aco6QXJ7?mfMWHFoooooago00007?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>
ooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>
3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D7OlI6ATLoa@D53Wo
5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@47?l71`LMo`410A_o
n_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mfMWHFoooooago0000
7?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolLoa@D51go6ATI7?lD
51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol1
0@4Koo[jnPkooooo000<oooooaco51@D7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ6QcoMWIf5_oooolM
o`0001co3Ph>7?l410@Moa8B4Qco10@47?l71`LMo`410A_on_[j3_ooool000cooooo7?lD51@MoaTI
6Aco51@D>OlG5aLLoalO7aco6QXJ7?mfMWHFoooooago00007?l>3PhLo`@411go4Q8B7?l410@Lo`L7
1ago0@416oojn_X>ooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKo
oooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D
7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@4
7?l71`LMo`410A_on_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mf
MWHFoooooago00007?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolL
oa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8L
o`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ
6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@47?l71`LMo`410A_on_[j3_ooool000co
oooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mfMWHFoooooago00007?l>3PhLo`@411go
4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO
7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo
000<oooooaco51@D7OlI6ATLoa@D53Wo5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l4
10@Moa8B4Qco10@47?l71`LMo`410A_on_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLL
oalO7aco6QXJ7?mfMWHFoooooago00007?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>
ooooo`003?oooolLoa@D51go6ATI7?lD51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>
3Qco10@47OlB4Q8Lo`@411co1`L77Ol10@4Koo[jnPkooooo000<oooooaco51@D7OlI6ATLoa@D53Wo
5aLG7?lO7alLoaXJ6QcoMWIf5_oooolMo`0001co3Ph>7?l410@Moa8B4Qco10@47?l71`LMo`410A_o
n_[j3_ooool000cooooo7?lD51@MoaTI6Aco51@D>OlG5aLLoalO7aco6QXJ7?mfMWHFoooooago0000
7?l>3PhLo`@411go4Q8B7?l410@Lo`L71ago0@416oojn_X>ooooo`003?oooolLoa@D51go6ATI7?lD
51@ioaLG5aco7alO7?lJ6QXLogIfMQKooooo7Ol0000Lo`h>3Qco10@47OlB4Q8Lo`@411co1`L77Ol1
0@4Koo[jnPkooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolM
oa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<3
0aco1PH67Ol51@DLo`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;
2ago00006oohn?P>ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKo
oooo7OlA4A4LoaDE5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82
>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C
7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<30aco1PH67Ol51@DLo`/;2aco51@D7?mN
GUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;2ago00006oohn?P>ooooo`003?oooolL
o`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKooooo7OlA4A4LoaDE5Aco410@7OlA4A4L
oa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D
51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000co
oooo7?l20P8io`<30aco1PH67Ol51@DLo`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go
4A4A7?lC4a<Lo`/;2ago00006oohn?P>ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;
7?lD51@LoeiNGQKooooo7OlA4A4LoaDE5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo
000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@
410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<30aco1PH67Ol51@DL
o`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;2ago00006oohn?P>
ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKooooo7OlA4A4LoaDE
5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo
1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_o
n?Sh3_ooool000cooooo7?l20P8io`<30aco1PH67Ol51@DLo`/;2aco51@D7?mNGUhFoooooago4A4A
7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;2ago00006oohn?P>ooooo`003?oooolLo`820SWo0`<37?l6
1PHMo`D51Aco2`/;7?lD51@LoeiNGQKooooo7OlA4A4LoaDE5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0
000KooShn0kooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolM
oa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<3
0aco1PH67Ol51@DLo`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;
2ago00006oohn?P>ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKo
oooo7OlA4A4LoaDE5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82
>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C
7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<30aco1PH67Ol51@DLo`/;2aco51@D7?mN
GUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;2ago00006oohn?P>ooooo`003?oooolL
o`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKooooo7OlA4A4LoaDE5Aco410@7OlA4A4L
oa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D
51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000co
oooo7?l20P8io`<30aco1PH67Ol51@DLo`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go
4A4A7?lC4a<Lo`/;2ago00006oohn?P>ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;
7?lD51@LoeiNGQKooooo7OlA4A4LoaDE5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo
000<oooooaco0P82>Ol30`<Lo`H61Qgo1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@
410Moa4A4Aco4a<C7?l;2`/Mo`0001_on?Sh3_ooool000cooooo7?l20P8io`<30aco1PH67Ol51@DL
o`/;2aco51@D7?mNGUhFoooooago4A4A7?lE5ADLoa0@41go4A4A7?lC4a<Lo`/;2ago00006oohn?P>
ooooo`003?oooolLo`820SWo0`<37?l61PHMo`D51Aco2`/;7?lD51@LoeiNGQKooooo7OlA4A4LoaDE
5Aco410@7OlA4A4Loa<C4aco2`/;7Ol0000KooShn0kooooo000<oooooaco0P82>Ol30`<Lo`H61Qgo
1@D57?l;2`/Loa@D51coGUiN5_oooolMoa4A4Aco5ADE7?l@410Moa4A4Aco4a<C7?l;2`/Mo`0001_o
n?Sh3_ooool000cooooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo
7Ol;2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC
4a<Lo``<31co4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?
3`lLoa8B4Qgo1PH66oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PL
oaHF5QcoM7Ad5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool0
00cooooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH
61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC4a<Lo``<31co
4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo
1PH66oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad
5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000cooooo7?l<
30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ
6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC4a<Lo``<31co4Q8B7Ol?3`lL
oaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo1PH66oomoOd>
ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad5_oooolMo`/;
2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000cooooo7?l<30`Moa<C4aco
30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco
4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC4a<Lo``<31co4Q8B7Ol?3`lLoaPH61co5QHF
7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo1PH66oomoOd>ooooo`003?oo
oolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad5_oooolMo`/;2aco61PH7?l?
3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000cooooo7?l<30`Moa<C4aco30`<7?lB4Q8M
o`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHK
oogmo@kooooo000<oooooaco30`<7OlC4a<Lo``<31co4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooo
oago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo1PH66oomoOd>ooooo`003?oooolLo``<31go
4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco
3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000cooooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH
7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo
000<oooooaco30`<7OlC4a<Lo``<31co4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH
61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo1PH66oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`L
oa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8M
o`H61Q_ooOgm3_ooool000cooooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAd
M1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco
30`<7OlC4a<Lo``<31co4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago
6QXJ7?l?3`lLoa8B4Qgo1PH66oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?
7?lH61PLoaHF5QcoM7Ad5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm
3_ooool000cooooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;
2`/LoaPH61co3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC4a<L
o``<31co4Q8B7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lL
oa8B4Qgo1PH66oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF
5QcoM7Ad5_oooolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000co
oooo7?l<30`Moa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co
3`l?7OlJ6QXLo`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco30`<7OlC4a<Lo``<31co4Q8B
7Ol?3`lLoaPH61co5QHF7?mdM7@Foooooago2`/;7?lH61PLo`l?3ago6QXJ7?l?3`lLoa8B4Qgo1PH6
6oomoOd>ooooo`003?oooolLo``<31go4a<C7?l<30`Loa8B4Qgo3`l?7?lH61PLoaHF5QcoM7Ad5_oo
oolMo`/;2aco61PH7?l?3`lMoaXJ6Qco3`l?7?lB4Q8Mo`H61Q_ooOgm3_ooool000cooooo7?l<30`M
oa<C4aco30`<7?lB4Q8Mo`l?3aco61PH7?lF5QHLogAdM1Kooooo7Ol;2`/LoaPH61co3`l?7OlJ6QXL
o`l?3aco4Q8B7Ol61PHKoogmo@kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A
4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco
0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co
4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K
5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0
000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol5
1@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolM
oa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`41
0CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooSh
n0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco
7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<3
7?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo
000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE
5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LL
oa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooo
oaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH
61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4Aco
Fe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P82
7Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B
7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oo
oolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000L
o`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DK
ooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B
4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo
0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0ko
oooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM
7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l7
1`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<
oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADi
oaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A
4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco
0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co
4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K
5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0
000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol5
1@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolM
oa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`41
0CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooSh
n0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<37?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco
7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo000<oooooaco0P827Ol0000Lo`410CWo0`<3
7?l71`LLoa4A4AcoFe]K5_oooolMoa8B4Qco7AdM7?lE5ADioaPH61co4Q8B7Ol51@DKooShn0kooooo
000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL
71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8M
o`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dY
ooooo`003?oooolLo`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<
31co71`L7?l@410Moa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco
4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago
3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo
7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolLo`d=3Ago4Q8B7?l=
3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<31co71`L7?l@410Moa`L71co51@D7?lO
7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<F
oooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B
4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D
51co7alO7Ol=3@dYooooo`003?oooolLo`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4aco
Lg=c5_oooolMo``<31co71`L7?l@410Moa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=
7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L
7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC
4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolL
o`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<31co71`L7?l@410M
oa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?
3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000co
oooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co
410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolLo`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=
7?l?3`lLoa<C4acoLg=c5_oooolMo``<31co71`L7?l@410Moa`L71co51@D7?lO7alMo`d=3BWooooo
000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL
71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8M
o`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dY
ooooo`003?oooolLo`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<
31co71`L7?l@410Moa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco
4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago
3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo
7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolLo`d=3Ago4Q8B7?l=
3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<31co71`L7?l@410Moa`L71co51@D7?lO
7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<F
oooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B
4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D
51co7alO7Ol=3@dYooooo`003?oooolLo`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4aco
Lg=c5_oooolMo``<31co71`L7?l@410Moa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=
7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L
7?lD51@LoalO7ago3@d=:Oooool000cooooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC
4a<Log=cLaKooooo7Ol<30`Loa`L71co410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolL
o`d=3Ago4Q8B7?l=3@dLoa8B4Qgo3@d=7?l?3`lLoa<C4acoLg=c5_oooolMo``<31co71`L7?l@410M
oa`L71co51@D7?lO7alMo`d=3BWooooo000<oooooaco3@d=7OlB4Q8Lo`d=3Aco4Q8B7Ol=3@dLo`l?
3aco4a<C7?mcLg<Foooooago30`<7?lL71`Loa0@41go71`L7?lD51@LoalO7ago3@d=:Oooool000co
oooo7?l=3@dMoa8B4Qco3@d=7?lB4Q8Mo`d=3Aco3`l?7?lC4a<Log=cLaKooooo7Ol<30`Loa`L71co
410@7OlL71`Loa@D51co7alO7Ol=3@dYooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:
7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo
000<oooooaco2PX:7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l9
2@TMoaLG5aco4A4A7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Di
o`X:2Qco5ADE7?mRHV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>
ooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE
5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco2PX:7Ol61PHLo`/;2aco
1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l92@TMoaLG5aco4A4A7?l?3`lMo`410A_o
k^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Dio`X:2Qco5ADE7?mRHV8Foooooago2@T9
7?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>ooooo`003?oooolLo`X:2Qgo1PH67?l;
2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol1
0@4Konk^kPkooooo000<oooooaco2PX:7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolM
o`T92Aco5ADE7?l92@TMoaLG5aco4A4A7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H6
1Qco2`/;7?l51@Dio`X:2Qco5ADE7?mRHV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?
3ago0@416oo^k^h>ooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKo
oooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco2PX:
7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l92@TMoaLG5aco4A4A
7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Dio`X:2Qco5ADE7?mR
HV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>ooooo`003?oooolL
o`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLL
oa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco2PX:7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE
5AcoHV9R5_oooolMo`T92Aco5ADE7?l92@TMoaLG5aco4A4A7?l?3`lMo`410A_ok^k^3_ooool000co
oooo7?l:2PXMo`H61Qco2`/;7?l51@Dio`X:2Qco5ADE7?mRHV8Foooooago2@T97?lE5ADLo`T92Ago
5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>ooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:
7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo
000<oooooaco2PX:7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l9
2@TMoaLG5aco4A4A7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Di
o`X:2Qco5ADE7?mRHV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>
ooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE
5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco2PX:7Ol61PHLo`/;2aco
1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l92@TMoaLG5aco4A4A7?l?3`lMo`410A_o
k^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Dio`X:2Qco5ADE7?mRHV8Foooooago2@T9
7?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>ooooo`003?oooolLo`X:2Qgo1PH67?l;
2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol1
0@4Konk^kPkooooo000<oooooaco2PX:7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolM
o`T92Aco5ADE7?l92@TMoaLG5aco4A4A7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H6
1Qco2`/;7?l51@Dio`X:2Qco5ADE7?mRHV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?
3ago0@416oo^k^h>ooooo`003?oooolLo`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKo
oooo7Ol92@TLoaDE5Aco2@T97OlG5aLLoa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco2PX:
7Ol61PHLo`/;2aco1@D5>Ol:2PXLoaDE5AcoHV9R5_oooolMo`T92Aco5ADE7?l92@TMoaLG5aco4A4A
7?l?3`lMo`410A_ok^k^3_ooool000cooooo7?l:2PXMo`H61Qco2`/;7?l51@Dio`X:2Qco5ADE7?mR
HV8Foooooago2@T97?lE5ADLo`T92Ago5aLG7?lA4A4Lo`l?3ago0@416oo^k^h>ooooo`003?oooolL
o`X:2Qgo1PH67?l;2`/Lo`D51CWo2PX:7?lE5ADLof9RHQKooooo7Ol92@TLoaDE5Aco2@T97OlG5aLL
oa4A4Aco3`l?7Ol10@4Konk^kPkooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ
6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000co
oooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago
410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH
>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo
000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l3
0`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXM
oaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>
ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@
41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco
6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_o
n?Sh3_ooool000cooooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@41
7?l@410Lo`<30ago410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK
6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol7
1`LKooShn0kooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolM
o`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?lI6ATMoaXJ
6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago410@7?l;2`/Lo`h>
3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKo
oooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo000<oooooaco6ATI
7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;
7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mg
MgLFoooooago0@417?l@410Lo`<30ago410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>ooooo`003?oooolL
oaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@41co0`<37Ol@410L
o`/;2aco3Ph>7Ol71`LKooShn0kooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ
6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000co
oooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago
410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH
>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo
000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l3
0`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXM
oaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>
ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@
41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco
6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_o
n?Sh3_ooool000cooooo7?lI6ATMoaXJ6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@41
7?l@410Lo`<30ago410@7?l;2`/Lo`h>3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK
6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKooooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol7
1`LKooShn0kooooo000<oooooaco6ATI7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolM
o`410Aco410@7?l30`<Moa0@41co2`/;7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?lI6ATMoaXJ
6Qco6a/K7?lJ6QXMoaPH63So6QXJ7?mgMgLFoooooago0@417?l@410Lo`<30ago410@7?l;2`/Lo`h>
3Qgo1`L76oohn?P>ooooo`003?oooolLoaTI6Ago6QXJ7?lK6a/LoaXJ6Qgo61PH>?lJ6QXLogMgMaKo
oooo7Ol10@4Loa0@41co0`<37Ol@410Lo`/;2aco3Ph>7Ol71`LKooShn0kooooo000<oooooaco6ATI
7OlJ6QXLoa/K6aco6QXJ7OlH61PhoaXJ6QcoMgMg5_oooolMo`410Aco410@7?l30`<Moa0@41co2`/;
7?l>3PhMo`L71a_on?Sh3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng
]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PM
oi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4M
oa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooo
oago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVaco
YZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_o
lO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P
7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nM
WIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_oo
ool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHi
ob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf]
[AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000co
oooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co
8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P
7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nX
Z:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ
8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLb
oooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^K
VacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C
4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago
820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV
7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a
3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV
9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdM
ojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool0
00cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T
91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][Aco
X:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo
7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R
7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng
]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PM
oi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4M
oa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooo
oago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVaco
YZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_o
lO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P
7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nM
WIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_oo
ool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf][AcoX:2P7?ng]kLboooooago820P7?lV9RHi
ob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool000cooooo7?nXZ:PMoi^KVacoYZJV7?nMWIdMojf]
[AcoX:2P7?ng]kLboooooago820P7?lV9RHiob@T91co8R8R7?lQ8B4Moa<C4a_olO7a3_ooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.440797, -0.201592, 0.0354378, 0.0354378}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-9.24044, -0.201592, 0.0354378, 0.0354378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0104109A
0700088F
383A38D0
61656BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5455540B
50585911
3E3F4600
FFFEFF98
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSo
E5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD
>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;
2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>
ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>oooo
o`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`00
3?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oo
oolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?ooooli
o`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`41
0CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo
10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4
>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@
410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410h
oiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJ
VQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKo
oooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo
>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmD
E5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@i
oeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEE
ECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSo
E5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD
>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;
2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>
ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>oooo
o`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`00
3?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oo
oolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?ooooli
o`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`41
0CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo
10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4
>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@
410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410h
oiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJ
VQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKo
oooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo
>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmD
E5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@i
oeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEE
ECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSo
E5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD
>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;
2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>
ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>oooo
o`003?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`00
3?oooolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oo
oolio`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?ooooli
o`410CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`41
0CSo10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo
10@4>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4
>Ol@410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@
410hoiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410h
oiZJVQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJ
VQKooooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`410CSo10@4>Ol@410hoiZJVQKo
oooo>OmDE5@ioeEEECSoE5AD>?l;2`/>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo
>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@
D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50i
oeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQH
F3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3So
FEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI
>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA
4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>
ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>oooo
o`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`00
3?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oo
oolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?ooooli
o`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L7
1cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo
0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000
>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol8
20Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Ph
ohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?
SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKo
oooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo
>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@
D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50i
oeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQH
F3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3So
FEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI
>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA
4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>
ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>oooo
o`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`00
3?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oo
oolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?ooooli
o`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L7
1cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo
0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000
>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol8
20Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Ph
ohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?
SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKo
oooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo
>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@
D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50i
oeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQH
F3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3So
FEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI
>?lA4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA
4A4>ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>
ooooo`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>oooo
o`003?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`00
3?oooolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oo
oolio`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?ooooli
o`L71cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L7
1cSo0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo
0000>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?oooolio`L71cSo0000
>Ol820Phohn?SaKooooo>Om@D50ioeQHF3SoFEUI>?lA4A4>ooooo`003?ooooliocPh>3So>SXj>Olh
>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Ph
om3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@
d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Ko
oooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo
>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln
?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shi
oclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo
?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSo
ATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6
>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0
000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>
ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>oooo
o`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`00
3?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?oo
ooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooli
ocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh
>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So
>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj
>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh
>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Ph
om3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@
d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Ko
oooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo
>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln
?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shi
oclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo
?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSo
ATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6
>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0
000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>
ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>oooo
o`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`00
3?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?oo
ooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooli
ocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh
>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So
>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj
>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh
>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Ph
om3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@
d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Ko
oooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo
>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln
?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shi
oclo?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo
?cSoATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSo
ATI6>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6
>?l0000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0
000>ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>
ooooo`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>oooo
o`003?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`00
3?ooooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?oo
ooliocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooli
ocPh>3So>SXj>Olh>3Phom3@d1Kooooo>Oln?Shioclo?cSoATI6>?l0000>ooooo`003?ooooliof5Q
HCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOo
oooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo
>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<
ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEU
ICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWo
o_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH
3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooli
of5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][
JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSo
oooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo
000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4h
ofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7oooo
ocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSo
V9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?oo
ooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDi
of][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][Qoooooliookn
oSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0ko
oooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQ
HF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7
ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhoooo
ocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`00
3?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mU
IFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][Qoooooli
ooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRH
V0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo
>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[
Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hh
ooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>oooo
o`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q
>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][Qooo
ooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolh
oiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000co
oooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU
>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oon
o_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>
ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWo
HF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][
QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oo
oolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool0
00cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nHV9P>ooooo`003?ooooliof5QHCSo
IFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<ooooocWoHF5Q>?mUIFDiof][JhOooooo
>Oono_hhooooocSoV9RH3_ooool000cooooo>OmQHF4hofEUICWoJf][QoooooliooknoSSooooo>?nH
V9P>ooooo`003?ooooliof5QHCSoIFEU>Om[Jf^7ooooocWoo_kn>?oooolhoiRHV0kooooo000<oooo
ocWoHF5Q>?mUIFDiof][JhOooooo>Oono_hhooooocSoV9RH3_ooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.220399, -0.100796, 0.0177189, 0.0177189}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-4.62022, -0.100796, 0.0177189, 0.0177189}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B7FFB8B0
618A5117
787B531B
65593500
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
37355DE0
464A6FFB
475073FF
000A259F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSo
GEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM
>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oP
h>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>
ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>oooo
o`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`00
3?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?oo
ooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooli
okNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg
]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSo
oooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo
>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh
^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Ph
ok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`
/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Ko
oooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo
>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg
=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLi
ocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe
=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSo
GEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM
>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oP
h>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>
ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>oooo
o`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`00
3?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?oo
ooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooli
okNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg
]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSo
oooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo
>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh
^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Ph
ok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`
/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Ko
oooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo
>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg
=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLi
ocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe
=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSo
GEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM
>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oP
h>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>
ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>oooo
o`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`00
3?ooooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?oo
ooliokNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooli
okNg]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg
]cSooooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSo
oooo>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo
>Onh^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh
^;Phok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Ph
ok2`/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`
/1Kooooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliokNg]cSooooo>Onh^;Phok2`/1Ko
oooo>Olg=cLiocDe=CSoGEeM>?oPh>0>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo
>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6
ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHi
odY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:
BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSo
Kfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_
>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?ok
no/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>
ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>oooo
o`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`00
3?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?oo
ooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooli
of5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5Q
HCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSo
RXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:
>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmA
DE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4h
oaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG
5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKo
oooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo
>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6
ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHi
odY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:
BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSo
Kfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_
>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?ok
no/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>
ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>oooo
o`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`00
3?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?oo
ooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooli
of5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5Q
HCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSo
RXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:
>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmA
DE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4h
oaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG
5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKo
oooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo
>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6
ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHi
odY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:
BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSo
Kfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_
>?okno/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?ok
no/>ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>
ooooo`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>oooo
o`003?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`00
3?ooooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?oo
ooliof5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooli
of5QHCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5Q
HCSoRXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSo
RXZ:>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliof5QHCSoRXZ:
>OmADE4hoaLG5aKooooo>Om6ATHiodY:BSSoKfm_>?okno/>ooooo`003?ooooliogQhN3SoNg]k>OmC
De<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/F
ooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7
AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3So
Lg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo
000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooli
ogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]k
NcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo
6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo
>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@
D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6
ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000co
oooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh
>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmC
De<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/F
ooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7
AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3So
Lg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo
000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooli
ogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]k
NcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo
6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo
>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@
D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6
ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000co
oooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh
>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmC
De<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/F
ooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7
AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3So
Lg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo
000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooli
ogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]k
NcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo
6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo
>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@
D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6
ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000co
oooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh
>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmC
De<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/F
ooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7
AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3So
Lg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo
000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooli
ogQhN3SoNg]k>OmCDe<hoa/K6aKooooo>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]k
NcWoDe=C>?lK6a/FooooocWoAdM7>Om@D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo
6a/K5_ooooliodM7AcWoD51@>?mcLg=6ooooo`003?ooooliogQhN3SoNg]k>OmCDe<hoa/K6aKooooo
>Om7AdLioe1@D3SoLg=cA_ooool000cooooo>OmhN7Phog]kNcWoDe=C>?lK6a/FooooocWoAdM7>Om@
D50hog=cLdKooooo000<ooooocWoN7Qh>?mkNg/ioe=CDcSo6a/K5_ooooliodM7AcWoD51@>?mcLg=6
ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>oooo
o`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`00
3?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?oo
ooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooli
ofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEU
ICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSo
FEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI
>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole
=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDh
o`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`00
01Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Ko
oooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo
>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0
000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000i
o`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:
2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo
9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU
>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nO
Wil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>
ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>oooo
o`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`00
3?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?oo
ooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooli
ofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEU
ICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSo
FEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI
>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole
=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDh
o`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`00
01Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Ko
oooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo
>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0
000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000i
o`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:
2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo
9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU
>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nO
Wil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>
ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>oooo
o`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`00
3?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?oo
ooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooli
ofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEU
ICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSo
FEUI>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI
>Ole=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole
=CDho`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDh
o`0001Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`00
01Kooooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Ko
oooo>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo
>Ol0000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0
000io`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000i
o`X:2SSo9BDU>?nOWil>ooooo`003?ooooliofEUICSoFEUI>Ole=CDho`0001Kooooo>Ol0000io`X:
2SSo9BDU>?nOWil>ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.220399, -0.100796, 0.0177189, 0.0177189}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-4.62022, -0.100796, 0.0177189, 0.0177189}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 500 238.095 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F180025
1D150724
2F321631
ECDDEAFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8B8B004D
92950051
FFF9659E
EBF761F1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 238.062},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000kR000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003So
CDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo
000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?ooooli
oalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH
63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So
9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKooooo
L_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0
000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>
ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000co
oooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO
>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0
000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDF
ooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;
RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003So
CDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo
000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?ooooli
oalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH
63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So
9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKooooo
L_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0
000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>
ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000co
oooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO
>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0
000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDF
ooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;
RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003So
CDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo
000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?ooooli
oalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH
63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So
9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKooooo
L_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0
000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>
ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000co
oooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO
>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0
000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDF
ooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;
RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003So
CDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo
000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?ooooli
oalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH
63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So
9BDU5_oooomboh^;RcSo0000>?m=CDd>ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKooooo
L_n;Rh/ho`0003SoCDe=3_ooool000cooooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0
000hode=C@kooooo000<ooooocWo7alO>?lH61Pio`0003So9BDU5_oooomboh^;RcSo0000>?m=CDd>
ooooo`003?oooolioalO7cSo61PH>Ol0000hobDU9AKoooooL_n;Rh/ho`0003SoCDe=3_ooool000co
oooo>OlO7alhoaPH63Wo0000>?lU9BDFooooog;oRh^;>?l0000hode=C@kooooo000<ooooocWo7AdM
>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE
5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADi
o`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L7
1cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo
92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T
5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oo
oolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_ooooli
oi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:B
TSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWo
UIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE
>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0
000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000h
oe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5A
D@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@ko
oooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo
000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<
ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<oooo
ocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo
7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM
>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE
5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADi
o`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L7
1cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo
92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T
5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oo
oolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_ooooli
oi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:B
TSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWo
UIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE
>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0
000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000h
oe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5A
D@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@ko
oooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo
000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<
ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<oooo
ocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo
7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM
>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE
5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADi
o`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L7
1cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo
92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T
5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oo
oolioi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_ooooli
oi:BTSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:B
TSWoUIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWo
UIFE>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE
>?l0000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0
000hoe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000h
oe5AD@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5A
D@kooooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@ko
oooo000<ooooocWo7AdM>?lE5ADio`L71cSo92@T5_oooolioi:BTSWoUIFE>?l0000hoe5AD@kooooo
000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooli
obl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b
<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo
<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo
>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mU
IFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>
ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000co
oooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_
>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF
5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?
ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWi
nCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSo
WYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo
000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooli
obl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b
<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo
<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo
>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mU
IFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>
ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000co
oooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_
>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF
5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?
ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWi
nCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSo
WYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo
000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooli
obl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b
<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo
<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo
>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mU
IFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>
ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000co
oooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_
>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF
5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?
ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWi
nCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSo
WYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo
000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooli
obl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b
<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo
<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo
>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mU
IFDhoijNWPkooooo000<ooooocWo;bl_>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>
ooooo`003?ooooliobl_;cSo<S8b>OlF5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000co
oooo>Ol_;blhoc8b<SWo5QHF>?la<C5?ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWo;bl_
>?lb<S8ioaHF5SSo<C4aCoooooliooWinCSoIFEU>?nNWYh>ooooo`003?ooooliobl_;cSo<S8b>OlF
5QHhoc4a<Doooooo>OoinOThofEUICSoWYjN3_ooool000cooooo>Ol_;blhoc8b<SWo5QHF>?la<C5?
ooooocWonOWi>?mUIFDhoijNWPkooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOg
mcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSo
lO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo
000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?ooooli
onc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgM
gCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTko
oooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[
>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQ
HF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>
ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000co
oooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/
>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZ
j^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_ooooli
on_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOg
mcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSo
lO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo
000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?ooooli
onc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgM
gCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTko
oooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[
>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQ
HF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>
ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000co
oooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/
>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZ
j^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_ooooli
on_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOg
mcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSo
lO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo
000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?ooooli
onc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgM
gCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTko
oooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[
>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQ
HF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>
ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000co
oooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/
>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZ
j^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_ooooli
on_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOg
mcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSo
lO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo
000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?ooooli
onc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgM
gCWoj^[ZC_oooolion_[jcWomoOg>?mQHF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTko
oooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[
>OogmoLhof5QHCSolO7a3_ooool000cooooo>Oo/k>`homgMgCWoj^[ZC_oooolion_[jcWomoOg>?mQ
HF4hoo7al@kooooo000<ooooocWok>c/>?oMgMdion[ZjTkooooo>Oo[jn/iooOgmcSoHF5Q>?oalO4>
ooooo`003?oooolionc/k3SogMgM>OoZj^Y>ooooocWojn_[>OogmoLhof5QHCSolO7a3_ooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {237.062, 0}} -> {-0.0524745, -0.0238146, \
0.00421834, 0.00421834}, {{12.4375, 238.188}, {231.375, 5.625}} -> \
{-0.220399, -0.100796, 0.0177189, 0.0177189}, {{260.75, 486.5}, {231.375, \
5.625}} -> {-4.62022, -0.100796, 0.0177189, 0.0177189}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.591093 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13293 -18 -4.5 ]
[-0.0125 .13293 0 4.5 ]
[-0.0125 .25115 -18 -4.5 ]
[-0.0125 .25115 0 4.5 ]
[-0.0125 .36937 -18 -4.5 ]
[-0.0125 .36937 0 4.5 ]
[-0.0125 .48759 -18 -4.5 ]
[-0.0125 .48759 0 4.5 ]
[-0.0125 .60581 -6 -4.5 ]
[-0.0125 .60581 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13293 m
.00625 .13293 L
s
[(0.2)] -0.0125 .13293 1 0 Mshowa
0 .25115 m
.00625 .25115 L
s
[(0.4)] -0.0125 .25115 1 0 Mshowa
0 .36937 m
.00625 .36937 L
s
[(0.6)] -0.0125 .36937 1 0 Mshowa
0 .48759 m
.00625 .48759 L
s
[(0.8)] -0.0125 .48759 1 0 Mshowa
0 .60581 m
.00625 .60581 L
s
[(1)] -0.0125 .60581 1 0 Mshowa
.125 Mabswid
0 .04427 m
.00375 .04427 L
s
0 .07382 m
.00375 .07382 L
s
0 .10338 m
.00375 .10338 L
s
0 .16249 m
.00375 .16249 L
s
0 .19204 m
.00375 .19204 L
s
0 .2216 m
.00375 .2216 L
s
0 .28071 m
.00375 .28071 L
s
0 .31026 m
.00375 .31026 L
s
0 .33982 m
.00375 .33982 L
s
0 .39893 m
.00375 .39893 L
s
0 .42848 m
.00375 .42848 L
s
0 .45804 m
.00375 .45804 L
s
0 .51714 m
.00375 .51714 L
s
0 .5467 m
.00375 .5467 L
s
0 .57625 m
.00375 .57625 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13293 m
1 .13293 L
s
.99375 .25115 m
1 .25115 L
s
.99375 .36937 m
1 .36937 L
s
.99375 .48759 m
1 .48759 L
s
.99375 .60581 m
1 .60581 L
s
.125 Mabswid
.99625 .04427 m
1 .04427 L
s
.99625 .07382 m
1 .07382 L
s
.99625 .10338 m
1 .10338 L
s
.99625 .16249 m
1 .16249 L
s
.99625 .19204 m
1 .19204 L
s
.99625 .2216 m
1 .2216 L
s
.99625 .28071 m
1 .28071 L
s
.99625 .31026 m
1 .31026 L
s
.99625 .33982 m
1 .33982 L
s
.99625 .39893 m
1 .39893 L
s
.99625 .42848 m
1 .42848 L
s
.99625 .45804 m
1 .45804 L
s
.99625 .51714 m
1 .51714 L
s
.99625 .5467 m
1 .5467 L
s
.99625 .57625 m
1 .57625 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .0199 L
.18182 .0199 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .0199 L
.18182 .0199 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .60062 L
.63636 .60062 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .60062 L
.63636 .60062 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .56431 L
.27273 .56431 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .56431 L
.27273 .56431 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .05621 L
.72727 .05621 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .05621 L
.72727 .05621 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .0172 L
.81818 .0172 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .0172 L
.81818 .0172 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .07654 L
.45455 .07654 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .07654 L
.45455 .07654 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .54398 L
.90909 .54398 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .54398 L
.90909 .54398 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`1?ooooobWo
0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0
:?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02Wo003o:_ooO`0XooooobWoo`00:_l0o`0Xooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Z
o`3o02Sooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0:?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWo
o`00:_l0o`0Xooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oo
oolYool002[o0?l0:?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWoo`00:_l0o`0Xooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo
02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
0000CooooolYo`3o02Wo003o:_ooO`0XooooobWoo`00:_l0o`0Xooooob[oogl09oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0
:?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02Wo003o:_ooO`0XooooobWoo`00:_l0o`0Xooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Z
o`3o02Sooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0:?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWo
o`00:_l0o`0Xooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol0
0?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0004oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo
003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000
oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01_ooool4o`0004kooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl09Oooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
0ol0001?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo1Ol00006ooooo`Co0000C_oooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Uooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0001?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`Co00001oooool4o`0004kooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09Ooo
ool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`Co0000C_oooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Uooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002?ooool3o`00
00Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00009
ooooo`?o00001oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZool00:;ooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooob[o
003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
N?oooolZo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooob[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool0
02?ooooo0ol0001hooooob[o003oDOoooolZool00:;ooooo0_l0000=ooooo`008oooool00ol0003o
ooooooooo`1hooooob[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0N?oooolZo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1hooooob[o003oDOoooolZool00:?ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?oooolZo`00oe7ooooo:_oo002Soooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo07Sooooo:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooob[o003o
DOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?oo
oolZo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1hooooob[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool001Wo
oooo0ol00007ooooo`03o`000?oooooooooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003o
ooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo
:_l00?oooooooaoooooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo_Oooool4o`0000gooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`;o
00002?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0b_oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00_ooooo000Soooooooo0000aOl0000=
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOoo
ool00ol0003oooooooooo`39ooooo`04o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0Qoooool009gooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`26ooooo`00WOooool00ol0003oooooooooo`38ooooo`05o`000?oooooooooo
ooooool00000Qoooool009cooooo0_l0003:ooooo`05o`000?ooooooooooooooool00000Qoooool0
09gooooo00?o0000ooooooooool0bOooool3o`0008Sooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.0798091, \
0.00487821, 0.0037513}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.641029 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14292 -18 -4.5 ]
[-0.0125 .14292 0 4.5 ]
[-0.0125 .27113 -18 -4.5 ]
[-0.0125 .27113 0 4.5 ]
[-0.0125 .39933 -18 -4.5 ]
[-0.0125 .39933 0 4.5 ]
[-0.0125 .52754 -18 -4.5 ]
[-0.0125 .52754 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14292 m
.00625 .14292 L
s
[(0.2)] -0.0125 .14292 1 0 Mshowa
0 .27113 m
.00625 .27113 L
s
[(0.4)] -0.0125 .27113 1 0 Mshowa
0 .39933 m
.00625 .39933 L
s
[(0.6)] -0.0125 .39933 1 0 Mshowa
0 .52754 m
.00625 .52754 L
s
[(0.8)] -0.0125 .52754 1 0 Mshowa
.125 Mabswid
0 .04677 m
.00375 .04677 L
s
0 .07882 m
.00375 .07882 L
s
0 .11087 m
.00375 .11087 L
s
0 .17497 m
.00375 .17497 L
s
0 .20702 m
.00375 .20702 L
s
0 .23908 m
.00375 .23908 L
s
0 .30318 m
.00375 .30318 L
s
0 .33523 m
.00375 .33523 L
s
0 .36728 m
.00375 .36728 L
s
0 .43138 m
.00375 .43138 L
s
0 .46344 m
.00375 .46344 L
s
0 .49549 m
.00375 .49549 L
s
0 .55959 m
.00375 .55959 L
s
0 .59164 m
.00375 .59164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14292 m
1 .14292 L
s
.99375 .27113 m
1 .27113 L
s
.99375 .39933 m
1 .39933 L
s
.99375 .52754 m
1 .52754 L
s
.125 Mabswid
.99625 .04677 m
1 .04677 L
s
.99625 .07882 m
1 .07882 L
s
.99625 .11087 m
1 .11087 L
s
.99625 .17497 m
1 .17497 L
s
.99625 .20702 m
1 .20702 L
s
.99625 .23908 m
1 .23908 L
s
.99625 .30318 m
1 .30318 L
s
.99625 .33523 m
1 .33523 L
s
.99625 .36728 m
1 .36728 L
s
.99625 .43138 m
1 .43138 L
s
.99625 .46344 m
1 .46344 L
s
.99625 .49549 m
1 .49549 L
s
.99625 .55959 m
1 .55959 L
s
.99625 .59164 m
1 .59164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .06714 L
.18182 .06714 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .06714 L
.18182 .06714 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .60332 L
.63636 .60332 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .60332 L
.63636 .60332 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .53559 L
.27273 .53559 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .53559 L
.27273 .53559 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .13487 L
.72727 .13487 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .13487 L
.72727 .13487 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .09617 L
.36364 .09617 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .09617 L
.36364 .09617 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .57429 L
.81818 .57429 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .57429 L
.81818 .57429 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .59972 L
.45455 .59972 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .59972 L
.45455 .59972 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .07074 L
.90909 .07074 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .07074 L
.90909 .07074 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo
:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Y
o`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o
02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0
:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Y
o`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolYool0
02Wo0?l0:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`?o00009_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo
:Ooo000Yo`3o02Wo003o:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool09_oo
oolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0X
ooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00
:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZ
oomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWoo`00
:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolY
ool002Wo0?l0:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo
0?l0:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02Wo003o
:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe3ooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Y
o`3o02[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o
003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o003oDOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZ
oomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02So
oooo:Ooo000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:Ooo
000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooob[o0?l0:?oooolZoomo02Sooooo:Ooo000Yo`3o02[o003oDOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:Ooo000Yo`3o
02[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:_l0o`0Xooooob[o
ogl0:?oooolYool002Wo0?l0:_l00?m@ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0
o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZ
o`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00
oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02So
oooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_oo
O`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xoooo
obWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00:Ol0o`0Zo`00oe7ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0XooooobWoo`00
:Ol0o`0Zo`00oe7ooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00001_ooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo
:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0CooooolZo`3o02So
oooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool4o`0004ko
oooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?m>ooooo`Co00003Oooool000gooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZ
o`00oe7ooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001oooool00ol0
003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02So
oooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo
000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xoooo
ob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o
0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003o
DOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oo
oolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo
02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oo
oooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?m@ooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_oo
O`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xoooo
ob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00
:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZ
o`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o
02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo
:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0X
ooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo0ol0001?oooo
ob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oD?ooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0
:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l0
0?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0X
ooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[o
ogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oo
oolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o0000CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00
oe3ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02So
oooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo
000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xoooo
ob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o
0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003o
DOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oo
oolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo
02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003o
ooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Kooooo
00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo
:_l00?mAooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
1Ol00006ooooo`Co0000C_oooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00odkooooo
1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7o
oooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00007ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo
:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0
o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mA
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xoooo
ob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0
:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o0000CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe3ooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000X
ooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
ob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o
003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0
:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZ
oomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02So
oooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo
000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xoooo
ob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o
0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0004oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?m@ooooo`;o0000
3Oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oo
oolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZ
o`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00
oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02So
oooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_oo
O`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xoooo
ob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00
:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZ
o`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o
02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7o
oooo00?o0000ooooooooool02oooool002?ooooo0ol0001?ooooob[o0?l0:?oooolZoomo02Sooooo
:_oo000Xooooob[o003oD?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0
o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mA
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xoooo
ob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0
:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l0
0?mAooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000X
ooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1?ooooob[o0?l0:?oo
oolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool4o`0004kooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?m>ooooo`Co00003Oooool000gooooo00Co
0000oooooooooooo00001oooool4o`0000Oooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo
:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo04oooooo:_l0
o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mA
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xoooo
ob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0
:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l0
0?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolZo`3o02Sooooo:_ooO`0X
ooooob[oo`00:?oooolZo`00oe3ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?oooo
ob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o
003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0
:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZ
oomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02So
oooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo
000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xoooo
ob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o
0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003o
DOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:_l0o`0Xooooob[oogl0:?oo
oolZool002Sooooo:_l00?m@ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolZ
o`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00
oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02So
oooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_oo
O`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xoooo
ob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00
:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZ
o`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o
02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo
:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo0ol0
001?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oD?ooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mA
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xoooo
ob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0
:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002So
oooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l0
0?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`0X
ooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000>oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`1?oooo
ob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool4o`0004kooooo:_l0o`0Xooooob[oogl0:?oooolZool002Sooooo:_l0
0?m>ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002?ooool3o`0000Oooooo00?o
0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o
0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0CooooolZo`3o02Sooooo:_ooO`0Xooooob[oo`00
:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0CooooolZo`3o02So
oooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool000kooooo
0_l00009ooooo`?o00001oooool00ol0003oooooooooo`1?ooooob[o0?l0:?oooolZoomo02Sooooo
:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`2Qooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0XOoooolZoomo02Sooooo:_oo000Xoooo
ob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`2Qooooob[o
ogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0XOoooolZoomo02Sooooo:_oo000Xooooob[o003oDOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`2Qooooob[oogl0:?oooolZ
ool002Sooooo:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
0:7ooooo:_ooO`0Xooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0XOoooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`2Qooooob[oogl0:?oooolZool002Sooooo
:_l00?mAooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000XOoooolZoomo02Sooooo:_oo
000Xooooob[o003oD?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo0:7ooooo:_ooO`0X
ooooob[oo`00:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0XOoooolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`2Qooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00
:?oooolZo`00oe7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0XOoo
oolZoomo02Sooooo:_oo000Xooooob[o003oDOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`2Qooooob[oogl0:?oooolZool002Sooooo:_l00?mAooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`2Qooooob[oogl0:?oooolZool00:?o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0XOoooolZoomo02Sooooo
:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0:7ooooo:_oo
O`0Xooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`2Q
ooooob[oogl0:?oooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0XOoooolZoomo02Sooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`000:7ooooo:_ooO`0Xooooob[oo`00X_ooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo0:7ooooo:_ooO`0Xooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`2Qooooob[oogl0:?oooolZool00:?ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0XOoooolZoomo02Sooooo:_oo002Sooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo0:7ooooo:_ooO`0Xooooob[oo`00Xoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3cooooob[oo`00Xoooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool009cooooo
0ol00039ooooo`Go0000Qoooool009gooooo00?o0000ooooooooool0bOooool01?l0003ooooooooo
ool00027ooooo`00WOooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo08Oooooo002M
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0Q_ooool009gooooo00?o0000oooo
ooooool0b?ooool01Ol0003ooooooooooooooooo000008Oooooo002Looooo`;o0000b_ooool01Ol0
003ooooooooooooooooo000008Oooooo002Mooooo`03o`000?oooooooooo0<Wooooo0ol00028oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.073592, 0.00487821, \
0.00345907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.589846 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13268 -18 -4.5 ]
[-0.0125 .13268 0 4.5 ]
[-0.0125 .25065 -18 -4.5 ]
[-0.0125 .25065 0 4.5 ]
[-0.0125 .36862 -18 -4.5 ]
[-0.0125 .36862 0 4.5 ]
[-0.0125 .48659 -18 -4.5 ]
[-0.0125 .48659 0 4.5 ]
[-0.0125 .60456 -6 -4.5 ]
[-0.0125 .60456 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13268 m
.00625 .13268 L
s
[(0.2)] -0.0125 .13268 1 0 Mshowa
0 .25065 m
.00625 .25065 L
s
[(0.4)] -0.0125 .25065 1 0 Mshowa
0 .36862 m
.00625 .36862 L
s
[(0.6)] -0.0125 .36862 1 0 Mshowa
0 .48659 m
.00625 .48659 L
s
[(0.8)] -0.0125 .48659 1 0 Mshowa
0 .60456 m
.00625 .60456 L
s
[(1)] -0.0125 .60456 1 0 Mshowa
.125 Mabswid
0 .04421 m
.00375 .04421 L
s
0 .0737 m
.00375 .0737 L
s
0 .10319 m
.00375 .10319 L
s
0 .16218 m
.00375 .16218 L
s
0 .19167 m
.00375 .19167 L
s
0 .22116 m
.00375 .22116 L
s
0 .28015 m
.00375 .28015 L
s
0 .30964 m
.00375 .30964 L
s
0 .33913 m
.00375 .33913 L
s
0 .39812 m
.00375 .39812 L
s
0 .42761 m
.00375 .42761 L
s
0 .4571 m
.00375 .4571 L
s
0 .51608 m
.00375 .51608 L
s
0 .54558 m
.00375 .54558 L
s
0 .57507 m
.00375 .57507 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13268 m
1 .13268 L
s
.99375 .25065 m
1 .25065 L
s
.99375 .36862 m
1 .36862 L
s
.99375 .48659 m
1 .48659 L
s
.99375 .60456 m
1 .60456 L
s
.125 Mabswid
.99625 .04421 m
1 .04421 L
s
.99625 .0737 m
1 .0737 L
s
.99625 .10319 m
1 .10319 L
s
.99625 .16218 m
1 .16218 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .22116 m
1 .22116 L
s
.99625 .28015 m
1 .28015 L
s
.99625 .30964 m
1 .30964 L
s
.99625 .33913 m
1 .33913 L
s
.99625 .39812 m
1 .39812 L
s
.99625 .42761 m
1 .42761 L
s
.99625 .4571 m
1 .4571 L
s
.99625 .51608 m
1 .51608 L
s
.99625 .54558 m
1 .54558 L
s
.99625 .57507 m
1 .57507 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .02217 L
.18182 .02217 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .02217 L
.18182 .02217 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .59711 L
.63636 .59711 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .59711 L
.63636 .59711 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .57744 L
.27273 .57744 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .57744 L
.27273 .57744 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .04184 L
.72727 .04184 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .04184 L
.72727 .04184 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .01596 L
.81818 .01596 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .01596 L
.81818 .01596 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .23852 L
.45455 .23852 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .23852 L
.45455 .23852 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .38076 L
.90909 .38076 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .38076 L
.90909 .38076 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0:?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWoo`00
:_l0o`0Xooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolY
ool002[o0?l0:?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02Wo003o:_ooO`0XooooobWoo`00:_l0o`0Xooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02So
oooo:Ooo000Zo`3o02Sooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolYool002[o0?l0:?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_oo
O`0XooooobWoo`00:_l0o`0Xooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:Ooo000Zo`3o02Sooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00
ob[oogl0:?oooolYool002[o0?l0:?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo0ol0001?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl09oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00
ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0
:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02Wo003o:_ooO`0X
ooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZ
oomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02So
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Yo`00ob[oogl0:?oo
oolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo
003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_oo
O`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00001_ooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0CooooolYo`3o02Wo
003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool4o`0004ko
oooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Uooooo`Co00003Oooool000gooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001oooool00ol0
003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02So
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol0
0?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0
057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo
003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_oo
O`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o
:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo0ol0001?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001A
ooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00
ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0
:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Y
o`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[o
ogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZ
oomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02So
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001_oo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Go00001_oo
ool4o`0004kooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09Oooool4o`0000gooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o00001oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool000kooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
0ol0001?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0001?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09oooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool4o`0004kooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09Oooool4o`0000gooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool000kooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Rooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0001?ooooobWo0?l0:_l00?mAooooob[oo`00X_ooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002S
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002S
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002S
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZool0
0:;ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oo
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool3o`0000Oooooo1?l0001>
ooooobWo0?l0:_l00?mAooooob[oo`00X?ooool4o`0000gooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Ooo
ool3o`0000Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool0
2oooool002?ooooo0ol0001?ooooobWo0?l0:_l00?mAooooob[oo`00X_ooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Soooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Soooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Sooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Soooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZool00:;o
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Z
o`00oe7ooooo:_oo002Rooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0N?oooolZo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1hooooob[o003oDOoooolZool00:?ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?oooolZo`00oe7ooooo:_oo002Soooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo07Sooooo:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooob[o003o
DOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?oo
oolZo`00oe7ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo07Sooooo:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`006Oooool3o`00
00Oooooo00?o0000ooooooooool0N?oooolZo`00oooooooo7oooool00ol0003oooooooooo`0;oooo
o`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo:_l00?oooooooaoo
oooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1hooooob[o003ooooooolOooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooookgooooo1?l0000=ooooo`006_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool2o`00
00Sooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3:ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3:ooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool02oooool002?oooooool00035o`0000gooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo002Looooo`?o0000bOooool5o`0008Oooooo002Mooooo`03o`000?oo
oooooooo0<Wooooo00Co0000oooooooooooo0000Qoooool009gooooo00?o0000ooooooooool0b_oo
ool00ol0003oooooooooo`27ooooo`00WOooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo08Kooooo002Mooooo`03o`000?oooooooooo0<Sooooo00Go0000ooooooooooooooooo`000027
ooooo`00W?ooool2o`000<[ooooo00Go0000ooooooooooooooooo`000027ooooo`00WOooool00ol0
003oooooooooo`39ooooo`?o0000R?ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.0799779, \
0.00487821, 0.00375923}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.588604 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .59877 L
.18182 .59877 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .59877 L
.18182 .59877 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .01926 L
.63636 .01926 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .01926 L
.63636 .01926 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .60291 L
.27273 .60291 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .60291 L
.27273 .60291 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .01513 L
.72727 .01513 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .01513 L
.72727 .01513 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .60332 L
.36364 .60332 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .01472 L
.81818 .01472 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .01472 L
.81818 .01472 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .05066 L
.45455 .05066 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .05066 L
.45455 .05066 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .56737 L
.90909 .56737 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .56737 L
.90909 .56737 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool001[ooooo0_l00007ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo
003o:_ooO`2Sooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0XooooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo0:?ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Y
o`3o02Wo003o:_ooO`2Sooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0XooooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo0:?o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02Wo003o:_ooO`2Sooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0XooooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZ
oomo0:?ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`2Sooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0002Kooooo:Ooo000Yo`3o02Wo003o:_ooO`2Sooooob[oogl09oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`2Sooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Yo`00ob[oogl0XooooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo0:?ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00009_oooolY
ool002Wo0?l0:_l00?o<ooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo0ol0000VooooobWoo`00:Ol0o`0Zo`00olcooooo:_oo
O`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool4o`0002Gooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Gooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00
olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Kooooo:Ooo000Y
o`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00009oooo
o`?o00001oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00009_oooolYool002Wo0?l0:_l00?o<ooooob[oogl09oooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00009_oooolYool002Wo0?l0:_l00?o<ooooob[oogl09ooo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00
olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
0ol0000VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02So
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol00006ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool5o`0000Kooooo
00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0000UooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Uooooo`Co00003Oooool000gooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Oooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00009_oooolYool002Wo0?l0:_l00?o<ooooob[oogl09oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000VooooobWo
o`00:Ol0o`0Zo`00olcooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo0ol0000VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Wooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`Co00009Ooo
oolYool002Wo0?l0:_l00?o<ooooob[oogl09Oooool4o`0000gooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l0000:ooooo`;o00001oooool0
0ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Kooooo:Ooo000Yo`3o02[o003oc?oo
oolZoomo02Oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Z
o`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00009_oooolYool002Wo0?l0:_l00?o<ooooob[oogl09oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00009_oooolYool002Wo0?l0:_l00?o<oooo
ob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool4o`0002Gooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Gooooo1?l0000=
ooooo`003Oooool01?l0003oooooooooool00008ooooo`?o00001oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o
003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00009_oooolYool002Wo0?l0:_l00?o<ooooob[oogl09oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0
o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olco
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oc?oooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000VooooobWo
o`00:Ol0o`0Zo`00olcooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:_l00?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?o<ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:Ol0o`0Zo`00olcooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oc?oooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?o<ooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00oooooooo7oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Zo`00oooooooo7oooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0002Kooooo:Ooo000Yo`3o02[o003ooooooolNooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?oooooooaoooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?oooooooaoooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?oooooooaoooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?oooooooaoooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?oooooooaoooooo00?o0000ooooooooool02oooool001Wooooo0ol00007oooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003ooooooolOooooo`03o`000?oooooooooo
00_ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0CooooolYo`3o02[o
003ooooooolOooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Kooooo
1?l0001>ooooobWo0?l0:_l00?oooooooacooooo1?l0000=ooooo`006_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool2o`0000Sooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo
00_ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`3:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`3:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02oooool002?oooooool00035
o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo002Looooo`?o0000bOooool5o`0008Oooooo
002Mooooo`03o`000?oooooooooo0<Wooooo00Co0000oooooooooooo0000Qoooool009gooooo00?o
0000ooooooooool0b_ooool00ol0003oooooooooo`27ooooo`00WOooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo08Kooooo002Mooooo`03o`000?oooooooooo0<Sooooo00Go0000oooo
ooooooooooooo`000027ooooo`00W?ooool2o`000<[ooooo00Go0000ooooooooooooooooo`000027
ooooo`00WOooool00ol0003oooooooooo`39ooooo`?o0000R?ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.0801466, \
0.00487821, 0.00376716}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.607364 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13619 -18 -4.5 ]
[-0.0125 .13619 0 4.5 ]
[-0.0125 .25766 -18 -4.5 ]
[-0.0125 .25766 0 4.5 ]
[-0.0125 .37913 -18 -4.5 ]
[-0.0125 .37913 0 4.5 ]
[-0.0125 .50061 -18 -4.5 ]
[-0.0125 .50061 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13619 m
.00625 .13619 L
s
[(0.2)] -0.0125 .13619 1 0 Mshowa
0 .25766 m
.00625 .25766 L
s
[(0.4)] -0.0125 .25766 1 0 Mshowa
0 .37913 m
.00625 .37913 L
s
[(0.6)] -0.0125 .37913 1 0 Mshowa
0 .50061 m
.00625 .50061 L
s
[(0.8)] -0.0125 .50061 1 0 Mshowa
.125 Mabswid
0 .04508 m
.00375 .04508 L
s
0 .07545 m
.00375 .07545 L
s
0 .10582 m
.00375 .10582 L
s
0 .16656 m
.00375 .16656 L
s
0 .19692 m
.00375 .19692 L
s
0 .22729 m
.00375 .22729 L
s
0 .28803 m
.00375 .28803 L
s
0 .3184 m
.00375 .3184 L
s
0 .34877 m
.00375 .34877 L
s
0 .4095 m
.00375 .4095 L
s
0 .43987 m
.00375 .43987 L
s
0 .47024 m
.00375 .47024 L
s
0 .53097 m
.00375 .53097 L
s
0 .56134 m
.00375 .56134 L
s
0 .59171 m
.00375 .59171 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13619 m
1 .13619 L
s
.99375 .25766 m
1 .25766 L
s
.99375 .37913 m
1 .37913 L
s
.99375 .50061 m
1 .50061 L
s
.125 Mabswid
.99625 .04508 m
1 .04508 L
s
.99625 .07545 m
1 .07545 L
s
.99625 .10582 m
1 .10582 L
s
.99625 .16656 m
1 .16656 L
s
.99625 .19692 m
1 .19692 L
s
.99625 .22729 m
1 .22729 L
s
.99625 .28803 m
1 .28803 L
s
.99625 .3184 m
1 .3184 L
s
.99625 .34877 m
1 .34877 L
s
.99625 .4095 m
1 .4095 L
s
.99625 .43987 m
1 .43987 L
s
.99625 .47024 m
1 .47024 L
s
.99625 .53097 m
1 .53097 L
s
.99625 .56134 m
1 .56134 L
s
.99625 .59171 m
1 .59171 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .53574 L
.18182 .53574 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .53574 L
.18182 .53574 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .10106 L
.63636 .10106 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .10106 L
.63636 .10106 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .60332 L
.27273 .60332 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .60332 L
.27273 .60332 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .03348 L
.72727 .03348 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .03348 L
.72727 .03348 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .3136 L
.36364 .3136 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .3136 L
.36364 .3136 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .32319 L
.81818 .32319 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .32319 L
.81818 .32319 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .13794 L
.45455 .13794 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .13794 L
.45455 .13794 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .49886 L
.90909 .49886 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .49886 L
.90909 .49886 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo
:Ooo000Yo`3o02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Y
o`00ob[oogl0:?oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:Ooo000Yo`3o
02Wo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02Wo003o:_ooO`0XooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0
:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Y
o`3o02Wo003o:_ooO`0Xooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool0
02Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Oooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo
:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oo
oolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0X
ooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00
:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZ
oomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00:?oooolYo`00
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo
:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00:?oooolYo`00ob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Y
o`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo0ol0000VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo
02Oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[o
ogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZ
ool002Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo
003o:_ooO`0Xooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo
:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oo
oolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0X
ooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`0Xooooob[oo`00
:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Yo`00ob[oogl0N_oooolYo`00ob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0002Kooooo:Ooo000Yo`3o02Wo003o:_ooO`1jooooobWo003o:_ooO`0W
ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo
07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo07[ooooo
:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oo
oolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0
:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZ
oomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Y
o`00ob[oogl0N_oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool09_oo
oolYool002Wo0?l0:Ol00?lZoomo07[ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Yo`3o02Wo003o:_ooO`1jooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Ooo
ool4o`0002Gooooo:Ooo000Yo`3o02Wo003o:_ooO`1jooooobWo003o:_ooO`0Uooooo`Co00003Ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol0
0?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?o
oooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Z
o`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Kooooo:Ooo000Yo`3o02[o003o
XooooolYo`00ob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSoooo
obWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol0
0?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool3o`0002Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003o
XooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo
000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSoooo
obWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l0
0?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0002Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl09oooool2o`00
00gooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolY
o`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003o
XooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool09_oooolYool002Wo
0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00001oooool5o`0000Kooooo1?l0000UooooobWoo`00:Ol0o`0Zo`00oj?o
oooo:Ol00?lZoomo02Gooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSoooo
obWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00
oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00002Oooool2o`0000Oooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSoooo
obWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolY
o`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Voooo
obWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003o
XooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o
02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Ko
oooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl09oooool2o`0000gooooo000Sooooo`03o`00
0?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?ooooo:Ol0
0?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolY
ool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Zo`00oj?o
oooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
9_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:Ol0o`0Z
o`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Yo`3o02[o003oXooooolYo`00ob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:Ol0o`0Zo`00oj?ooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002Wo0?l0:_l00?nSooooobWo003o:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0<cooooo:Ol00?lZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000VooooobWoo`00:_l0o`3<oooo
obWo003o:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o
0?l0c?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0VooooobWoo`00:_l0o`3<ooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o
0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o
0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00009_oooolYool002[o0?l0mOoooolZoomo02Oooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00
:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000oooo
ooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
00gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0
000UooooobWoo`00:_l0o`3eooooob[oogl09Oooool4o`0000gooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool000kooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`0V
ooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0
o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0
o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Kooooo:Ooo000Z
o`3o0?Gooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo0ol0000VooooobWoo`00:_l0o`3eooooob[oogl09oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Go
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Go
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo
:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?Gooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00009_oooolYool002[o0?l0mOoooolZoomo02Oo
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0
o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0
o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0V
ooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3eooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo
00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool09_oooolYool002[o0?l0mOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool3o`0000Oooooo1?l0000Uoooo
obWoo`00:_l0o`3oooooodGooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3o
ooooodSooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09_oooolYool002[o0?l0oooo
oom8ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000
ooooooooool09_oooolYool002[o0?l0oooooom8ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?ooooooB?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3oooooodSooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002[o0?l0oooooom8ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?ooooooB?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3o
ooooodSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool09_oooolYool0
02[o0?l0oooooom8ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Ko
oooo:Ooo000Zo`3o0?ooooooB?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0VooooobWoo`00:_l0o`3oooooodSooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool09_oooolYool002[o0?l0oooooom8ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?ooooooB?ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0002Kooooo:Ooo000Zo`3o0?ooooooAoooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo02Kooooo:Ooo000Zo`3o0?ooooooB?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0VooooobWoo`00:_l0o`3oooooodSooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?oooooo
B?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:_l0o`3oooooodOooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?oooooo
B?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooo
oom8ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3o
ooooodSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o
0?ooooooB?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o
0?l0oooooom8ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolZo`3o0?oooooo
Aoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`3oooooodSo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?oooooo
B?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool009cooooo0ol00039ooooo`Go0000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool01?l0003oooooooooool00027ooooo`00WOooool00ol0003oooooooooo`3:ooooo`03o`000?oo
oooooooo08Oooooo002Mooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0Q_ooool0
09gooooo00?o0000ooooooooool0b?ooool01Ol0003ooooooooooooooooo000008Oooooo002Loooo
o`;o0000b_ooool01Ol0003ooooooooooooooooo000008Oooooo002Mooooo`03o`000?oooooooooo
0<Wooooo0ol00028ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.0776711, \
0.00487821, 0.0036508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.318182 0.454545 0.0147151 0.589431 [
[.27273 -0.0125 -3 -9 ]
[.27273 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1326 -18 -4.5 ]
[-0.0125 .1326 0 4.5 ]
[-0.0125 .25049 -18 -4.5 ]
[-0.0125 .25049 0 4.5 ]
[-0.0125 .36837 -18 -4.5 ]
[-0.0125 .36837 0 4.5 ]
[-0.0125 .48626 -18 -4.5 ]
[-0.0125 .48626 0 4.5 ]
[-0.0125 .60415 -6 -4.5 ]
[-0.0125 .60415 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -3 0 ]
[.27273 .63053 3 9 ]
[.72727 .63053 -3 0 ]
[.72727 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
[(1)] .27273 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(2)] .72727 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1326 m
.00625 .1326 L
s
[(0.2)] -0.0125 .1326 1 0 Mshowa
0 .25049 m
.00625 .25049 L
s
[(0.4)] -0.0125 .25049 1 0 Mshowa
0 .36837 m
.00625 .36837 L
s
[(0.6)] -0.0125 .36837 1 0 Mshowa
0 .48626 m
.00625 .48626 L
s
[(0.8)] -0.0125 .48626 1 0 Mshowa
0 .60415 m
.00625 .60415 L
s
[(1)] -0.0125 .60415 1 0 Mshowa
.125 Mabswid
0 .04419 m
.00375 .04419 L
s
0 .07366 m
.00375 .07366 L
s
0 .10313 m
.00375 .10313 L
s
0 .16207 m
.00375 .16207 L
s
0 .19154 m
.00375 .19154 L
s
0 .22102 m
.00375 .22102 L
s
0 .27996 m
.00375 .27996 L
s
0 .30943 m
.00375 .30943 L
s
0 .3389 m
.00375 .3389 L
s
0 .39785 m
.00375 .39785 L
s
0 .42732 m
.00375 .42732 L
s
0 .45679 m
.00375 .45679 L
s
0 .51573 m
.00375 .51573 L
s
0 .5452 m
.00375 .5452 L
s
0 .57467 m
.00375 .57467 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
[(1)] .27273 .63053 0 -1 Mshowa
.72727 .61178 m
.72727 .61803 L
s
[(2)] .72727 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1326 m
1 .1326 L
s
.99375 .25049 m
1 .25049 L
s
.99375 .36837 m
1 .36837 L
s
.99375 .48626 m
1 .48626 L
s
.99375 .60415 m
1 .60415 L
s
.125 Mabswid
.99625 .04419 m
1 .04419 L
s
.99625 .07366 m
1 .07366 L
s
.99625 .10313 m
1 .10313 L
s
.99625 .16207 m
1 .16207 L
s
.99625 .19154 m
1 .19154 L
s
.99625 .22102 m
1 .22102 L
s
.99625 .27996 m
1 .27996 L
s
.99625 .30943 m
1 .30943 L
s
.99625 .3389 m
1 .3389 L
s
.99625 .39785 m
1 .39785 L
s
.99625 .42732 m
1 .42732 L
s
.99625 .45679 m
1 .45679 L
s
.99625 .51573 m
1 .51573 L
s
.99625 .5452 m
1 .5452 L
s
.99625 .57467 m
1 .57467 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.09091 .01472 m
.09091 .02465 L
.18182 .02465 L
.18182 .01472 L
F
.5 Mabswid
.09091 .01472 m
.09091 .02465 L
.18182 .02465 L
.18182 .01472 L
.09091 .01472 L
s
.54545 .01472 m
.54545 .59422 L
.63636 .59422 L
.63636 .01472 L
F
.54545 .01472 m
.54545 .59422 L
.63636 .59422 L
.63636 .01472 L
.54545 .01472 L
s
0 1 0 r
.18182 .01472 m
.18182 .60332 L
.27273 .60332 L
.27273 .01472 L
F
.18182 .01472 m
.18182 .60332 L
.27273 .60332 L
.27273 .01472 L
.18182 .01472 L
s
.63636 .01472 m
.63636 .01554 L
.72727 .01554 L
.72727 .01472 L
F
.63636 .01472 m
.63636 .01554 L
.72727 .01554 L
.72727 .01472 L
.63636 .01472 L
s
0 0 1 r
.27273 .01472 m
.27273 .58035 L
.36364 .58035 L
.36364 .01472 L
F
.27273 .01472 m
.27273 .58035 L
.36364 .58035 L
.36364 .01472 L
.27273 .01472 L
s
.72727 .01472 m
.72727 .03851 L
.81818 .03851 L
.81818 .01472 L
F
.72727 .01472 m
.72727 .03851 L
.81818 .03851 L
.81818 .01472 L
.72727 .01472 L
s
1 .5 0 r
.36364 .01472 m
.36364 .0683 L
.45455 .0683 L
.45455 .01472 L
F
.36364 .01472 m
.36364 .0683 L
.45455 .0683 L
.45455 .01472 L
.36364 .01472 L
s
.81818 .01472 m
.81818 .55056 L
.90909 .55056 L
.90909 .01472 L
F
.81818 .01472 m
.81818 .55056 L
.90909 .55056 L
.90909 .01472 L
.81818 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00W?ooool3o`000<Wooooo1Ol00027ooooo`00WOooool00ol0003oooooooooo`39ooooo`04
o`000?ooooooooooo`0008Oooooo002Mooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0Qoooool009gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`26ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`05o`000?ooooooooooooooool00000Qoooool009cooooo0_l0
003:ooooo`05o`000?ooooooooooooooool00000Qoooool009gooooo00?o0000ooooooooool0bOoo
ool3o`0008Sooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=ooooo`00
8oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0<[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04
o`000?ooooooooooo`0000Kooooo:Ol0000Yool002Wo0?l0:Ol00?lZoomo02So0000:Ooo000Yo`3o
02Wo003o:_ooO`0Yo`0000gooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`0VooooobWo
o`00:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool09_oooolYool002Wo0?l0:Ol00?lZoomo02Sooooo
:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0X
ooooob[oo`00:?oooolYo`00ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[o
ogl0:?oooolZool002Sooooo:Ol00?lZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02Wo003o:_ooO`0Xooooob[oo`00:?oooolYo`00ob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:Ol0
0?lZoomo02Sooooo:_oo000XooooobWo003o:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool002Sooooo:Ol00?lZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02Wo003o:_ooO`0Xooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo0ol0001?ooooobWo0?l0:Ol00?lZoomo02Sooooo:_oo001Aooooob[oogl09oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00
ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0
:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Yo`00ob[oogl0:?oooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Yo`00ob[oogl0:?oooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09ooo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool01?l0003ooooooooo
ooooool5o`0000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00Gooooo1?l0001>ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Gooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000>oooo
o`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o0000CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0001?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Oooooo
0_l0000=ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00006ooooo`Co0000C_oooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Uooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00
oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0
057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oo
oooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0X
ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`Co0000C_oooolYo`3o02[o003oDOoo
oolZool0057ooooo:_ooO`0Uooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001ooo
ool4o`0000Oooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0
:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l0
0?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aoooo
ob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o
02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00
DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0Cooo
oolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o0000
3Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057o
oooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo
:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZ
ool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003o
DOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0001?ooooobWo0?l0:_l00?mAoooo
ob[oo`00DOoooolZoomo02Oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1?ooooobWo
0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo
001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?
ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7o
oooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Z
o`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03
o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo1?l0001>ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZ
oomo02Gooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00008ooooo`?o00001oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_oo
O`0Xooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol0
0007ooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[o
ogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001A
ooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
obWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo
:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0004oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl09oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoooolZoomo
02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o
003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00DOoo
oolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolY
o`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo04oooooo:Ol0o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mA
ooooob[oo`00DOoooolZoomo02Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Xooooo`03o`000?oooooooooo
00_ooooo000Sooooo`?o0000CooooolYo`3o02[o003oDOoooolZool0057ooooo:_ooO`0Wooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool0057ooooo
:_ooO`0Xooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:Ol0
o`0Zo`00oe7ooooo:_oo001Aooooob[oogl0:?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0:_l00?mAooooob[o
o`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?ooooobWo0?l0
:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1?ooooobWo0?l0:_l00?mAooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0004oooooo:Ol0o`0Zo`00oe7ooooo:_oo002Rooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0CooooolYo`3o02[o003oDOoooolZool00:?ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0CooooolZo`3o07[ooooo:_oo
002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo04oooooo:_l0o`1j
ooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`1?oooo
ob[o0?l0N_oooolZool00:?ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0CooooolZo`3o07[ooooo:_oo002Sooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo04oooooo:_l0o`1jooooob[oo`00Xoooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1?ooooob[o0?l0N_oooolZool00:?ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool00ol0003oooooooooo`0;
ooooo`006Oooool3o`0000Oooooo00?o0000ooooooooool0CooooolZo`3o0?ooooooB?ooool00ol0
003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo:_l0o`3oooooodSooooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1?ooooob[o0?l0oooooom8ooooo`03o`000?oooooooooo00_ooooo
000Jooooo`03o`000?oooooooooo00Kooooo1?l0003ooooookgooooo1?l0000=ooooo`006_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool2o`0000Sooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo
00_ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`3:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`3:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02oooool002?oooooool00035
o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo002Looooo`?o0000bOooool5o`0008Oooooo
002Mooooo`03o`000?oooooooooo0<Wooooo00Co0000oooooooooooo0000Qoooool009gooooo00?o
0000ooooooooool0b_ooool00ol0003oooooooooo`27ooooo`00WOooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo08Kooooo002Mooooo`03o`000?oooooooooo0<Sooooo00Go0000oooo
ooooooooooooo`000027ooooo`00W?ooool2o`000<[ooooo00Go0000ooooooooooooooooo`000027
ooooo`00WOooool00ol0003oooooooooo`39ooooo`?o0000R?ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.525539, -0.0800342, \
0.00487821, 0.00376188}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(225.277758`8.804263308811889\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .5976 L
.2381 .5976 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .5976 L
.2381 .5976 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .02044 L
.47619 .02044 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .02044 L
.47619 .02044 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01209 L
.2381 .01209 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01209 L
.2381 .01209 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .60594 L
.47619 .60594 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .60594 L
.47619 .60594 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .03149 L
.2381 .03149 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .03149 L
.2381 .03149 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .58654 L
.47619 .58654 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .58654 L
.47619 .58654 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .53648 L
.2381 .53648 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .53648 L
.2381 .53648 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .08155 L
.47619 .08155 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .08155 L
.47619 .08155 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF000000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF00FF000000FF00FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .49643 L
.47619 .49643 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .49643 L
.47619 .49643 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .1216 L
.95238 .1216 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .1216 L
.95238 .1216 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF800000FF00FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000
00FF00FF8000FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .56089 L
.47619 .56089 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .56089 L
.47619 .56089 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05715 L
.95238 .05715 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05715 L
.95238 .05715 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .34688 L
.47619 .34688 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .34688 L
.47619 .34688 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .27116 L
.95238 .27116 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .27116 L
.95238 .27116 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00
FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00
00FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF00FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .18689 L
.47619 .18689 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .18689 L
.47619 .18689 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .43114 L
.95238 .43114 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .43114 L
.95238 .43114 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00
FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF0000FF00
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
00FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF00FF800000FF00FF800000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF00FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .5807 L
.71429 .5807 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .5807 L
.71429 .5807 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03733 L
.95238 .03733 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03733 L
.95238 .03733 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .60469 L
.71429 .60469 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .60469 L
.71429 .60469 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01335 L
.95238 .01335 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01335 L
.95238 .01335 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .60594 L
.71429 .60594 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .60594 L
.71429 .60594 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .06674 L
.71429 .06674 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .06674 L
.71429 .06674 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .55129 L
.95238 .55129 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .55129 L
.95238 .55129 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .60281 L
.2381 .60281 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .60281 L
.2381 .60281 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01522 L
.71429 .01522 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01522 L
.71429 .01522 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .06257 L
.2381 .06257 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .06257 L
.2381 .06257 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .55546 L
.71429 .55546 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .55546 L
.71429 .55546 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FFFF00000000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01647 L
.2381 .01647 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01647 L
.2381 .01647 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .60156 L
.71429 .60156 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .60156 L
.71429 .60156 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .3062 L
.2381 .3062 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .3062 L
.2381 .3062 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .31183 L
.71429 .31183 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .31183 L
.71429 .31183 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FFFF00000000FFFF00000000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF
0000FF0000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FFFF00000000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
0000FF0000FF0000FFFF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .58341 L
.2381 .58341 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .58341 L
.2381 .58341 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03462 L
.95238 .03462 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03462 L
.95238 .03462 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .16728 L
.2381 .16728 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .16728 L
.2381 .16728 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .45075 L
.95238 .45075 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .45075 L
.95238 .45075 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .45972 L
.2381 .45972 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .45972 L
.2381 .45972 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .15831 L
.95238 .15831 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .15831 L
.95238 .15831 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .03295 L
.2381 .03295 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .03295 L
.2381 .03295 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .58508 L
.95238 .58508 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .58508 L
.95238 .58508 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .60573 L
.2381 .60573 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .60573 L
.2381 .60573 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .06737 L
.2381 .06737 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .06737 L
.2381 .06737 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .55066 L
.71429 .55066 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .55066 L
.71429 .55066 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02127 L
.2381 .02127 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02127 L
.2381 .02127 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .59676 L
.71429 .59676 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .59676 L
.71429 .59676 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .53565 L
.2381 .53565 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .53565 L
.2381 .53565 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .08239 L
.71429 .08239 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .08239 L
.71429 .08239 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolGo`00o`Cooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool000Cooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool000Cooooo5ol0o`0jooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolG
o`3o03[ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0jooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaOo0?l0>_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o03[ooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool000Cooooo5ol0o`0jooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaOo0?l0>_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o03[ooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
0_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
og;o00009ooooomao`0002OoooooLOl0000Wooooog;o00008oooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool001KoooooRP3o000>ooooohX00?l03_oooon:003o00kooooo?@3o0002003o
04/0o`006?ooool001KoooooRP3o000>ooooohX00?l03_oooon:003o00kooooo?@3o0002003o04/0
o`006?ooool001Kooooo903o0002003o06@0o`003_oooon:003o00koooooO`00o`060?l000D00?l0
3_oooon:0?l001Sooooo000Fooooob@0o`000P00o`1T0?l000koooooRP00o`0>ooooogl00?l01P3o
0005003o00koooooRP3o000Hooooo`005_oooon:0?l000koooooRP00o`0>oooooc000?l01P3o000@
003o0080o`00<000o`090?l000T00?l03_ooool40?l000D00?l06`3o0002003o02h0o`000P00o`0d
0?l001Sooooo000Fooooog<0o`0000<00?l00?l0003o0000403o0002003o0080o`003_oooomj003o
0080o`003P00o`0>oooooa000?l01`3o000I003o00@0o`007@00o`030?l002@00?l02@3o0009003o
00kooooo103o0005003o0300o`001P00o`090?l000<00?l09P3o0002003o01L0o`006?ooool001Ko
ooooL`3o00000`00o`00o`000?l0000@0?l000800?l00P3o000>ooooogX00?l00P3o000>003o00ko
oooo4000o`070?l001T00?l0103o000M003o00<0o`009000o`090?l000T00?l03_ooool40?l000D0
0?l0<03o0006003o00T0o`000`00o`0V0?l000800?l05`3o000Hooooo`005_oooon60?l000@00?l0
3_oooon:003o00kooooo8P00o`050?l000T00?l00P3o000D003o0080o`0000<00?l00?l0003o0000
1000o`020?l00003003o003o0000o`0002P00?l01@3o0009003o00kooooo5`3o0002003o0080o`00
0P00o`000`3o00000?l0003o001?0?l000800?l06@3o000Hooooo`005_oooon60?l000@00?l03_oo
oon:003o00kooooo8P00o`050?l000T00?l00P3o000D003o0080o`0000<00?l00?l0003o00001000
o`020?l00003003o003o0000o`0002P00?l01@3o0009003o00kooooo5`3o0002003o0080o`000P00
o`000`3o00000?l0003o001?0?l000800?l06@3o000Hooooo`005_oooomj0?l000800?l0303o0002
003o00koooooRP00o`0>oooood/00?l01`3o000h003o00koooooF`3o0004003o00D0o`000P00o`07
0?l000@00?l06@3o000Hooooo`005_oooomj0?l000800?l0303o0002003o00koooooRP00o`0>oooo
od/00?l01`3o000h003o00koooooF`3o0004003o00D0o`000P00o`070?l000@00?l06@3o000Hoooo
o`005_oooomh0?l000800?l02@3o0002003o00<0o`000P00o`0>ooooohX00?l03_oooom;003o00T0
o`006000o`000`3o00000?l0003o000K003o00koooooI03o0002003o00T0o`000P00o`0;0?l000<0
0?l02`3o000Hooooo`005_oooon:0?l000koooooRP00o`0>oooood/00?l02@3o000f003o00kooooo
;`3o0005003o02l0o`0000<00?l00?l0003o00005P3o0003003o00/0o`006?ooool001KoooooRP3o
000>ooooohX00?l03_oooom;003o00T0o`00=P00o`0>ooooobl0o`001@00o`0_0?l00003003o003o
0000o`0001H0o`000`00o`0;0?l001Sooooo000FooooohX0o`003_oooon:003o00kooooo>@00o`04
0?l001000?l01@3o000h003o00kooooo3P3o0002003o0280o`000P00o`0V0?l00003003o003o0000
o`0000H0o`0000<00?l00?l0003o00004P3o0009003o00T0o`006?ooool001KoooooRP3o000>oooo
ohX00?l03_ooooli003o00@0o`004000o`050?l003P00?l03_ooool>0?l000800?l08P3o0002003o
02H0o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l0000B0?l000T00?l02@3o000Hoooo
o`005_oooomB0?l000800?l0=P3o000>ooooohX00?l03_oooolk003o0080o`004000o`070?l003H0
0?l03_ooool70?l000800?l00P3o0005003o04H0o`000P00o`0;0?l00003003o003o0000o`0000/0
o`000P00o`090?l000`00?l00P3o000Hooooo`005_oooomB0?l000800?l0=P3o000>ooooohX00?l0
3_oooolk003o0080o`004000o`070?l003H00?l03_ooool70?l000800?l00P3o0005003o04H0o`00
0P00o`0;0?l00003003o003o0000o`0000/0o`000P00o`090?l000`00?l00P3o000Hooooo`005_oo
oomh0?l000800?l02`3o00000`00o`00o`000?l000020?l000koooooRP00o`0>ooooohX00?l03_oo
ool=0?l000<00?l01`3o0004003o02H0o`0000<00?l00?l0003o00006`3o0005003o00d0o`000P00
o`070?l000<00?l00P3o0002003o00@0o`0000<00?l00?l0003o00000P3o000Hooooo`005_oooomh
0?l000800?l02`3o00000`00o`00o`000?l000020?l000koooooRP00o`0>ooooohX00?l03_ooool=
0?l000<00?l01`3o0004003o02H0o`0000<00?l00?l0003o00006`3o0005003o00d0o`000P00o`07
0?l000<00?l00P3o0002003o00@0o`0000<00?l00?l0003o00000P3o000Hooooo`005_oooon10?l0
00@00?l01@3o000>ooooohX00?l03_oooon:003o00kooooo1`3o0004003o0080o`000`00o`070?l0
00@00?l0?`3o00000`00o`00o`000?l0000D0?l000<00?l0203o0007003o0080o`0000<00?l00?l0
003o00000P3o000Hooooo`005_oooolR0?l000800?l0:`3o0002003o0380o`000P00o`050?l000ko
ooooRP00o`0>ooooohP00?l00P3o000>ooooo`800?l02`3o00000`00o`00o`000?l000070?l000@0
0?l00P3o00000`00o`00o`000?l000090?l000800?l0C`3o0005003o00/0o`006?ooool001Kooooo
8P3o0002003o02/0o`000P00o`0b0?l000800?l01@3o000>ooooohX00?l03_oooon8003o0080o`00
3_ooool2003o00/0o`0000<00?l00?l0003o00001`3o0004003o0080o`0000<00?l00?l0003o0000
2@3o0002003o04l0o`001@00o`0;0?l001Sooooo000Fooooob80o`000P00o`1O0?l000800?l01@3o
000>ooooohX00?l03_oooon:003o00kooooo0P00o`0E0?l000H00?l0G@3o0003003o00d0o`006?oo
ool001Kooooo8P3o0002003o05l0o`000P00o`050?l000koooooRP00o`0>ooooohX00?l03_ooool2
003o01D0o`001P00o`1M0?l000<00?l03@3o000Hooooo`005_oooolb0?l000800?l0EP3o000>oooo
ohX00?l03_oooon:003o00kooooo6@3o0004003o00X0o`000P00o`1A0?l000<00?l03@3o000Hoooo
o`005_oooolb0?l000800?l0EP3o000>ooooohX00?l03_oooon:003o00kooooo6@3o0004003o00X0
o`000P00o`1A0?l000<00?l03@3o000Hooooo`005_oooon:0?l000koooooRP00o`0>oooooe800?l0
103o000d003o00kooooo0P00o`0T0?l00003003o003o0000o`0001H0o`001@00o`040?l00003003o
003o0000o`0000@0o`001@00o`070?l000800?l0;@3o000Hooooo`005_oooon:0?l000koooooRP00
o`0>oooooe800?l0103o000d003o00kooooo0P00o`0T0?l00003003o003o0000o`0001H0o`001@00
o`040?l00003003o003o0000o`0000@0o`001@00o`070?l000800?l0;@3o000Hooooo`005_oooon:
0?l000koooooRP00o`0>ooooof<00?l00`3o000T003o00kooooo1000o`0:0?l000800?l05P3o0000
0`00o`00o`000?l0000F0?l000L00?l00P3o0003003o02@0o`000P00o`0;0?l000<00?l02`3o000H
ooooo`005_oooolR0?l000800?l0IP3o000>ooooohX00?l03_oooolY003o00H0o`00F`00o`0>oooo
o`D00?l08@3o00000`00o`00o`000?l0000F0?l000D00?l03P3o0002003o00@0o`001@00o`0D0?l0
00800?l000<0o`00003o0000o`001`3o0006003o0080o`0000<00?l00?l0003o00000P00o`0Hoooo
o`005_oooolR0?l000800?l0IP3o000>ooooohX00?l03_oooolY003o00H0o`00F`00o`0>ooooo`D0
0?l08@3o00000`00o`00o`000?l0000F0?l000D00?l03P3o0002003o00@0o`001@00o`0D0?l00080
0?l000<0o`00003o0000o`001`3o0006003o0080o`0000<00?l00?l0003o00000P00o`0Hooooo`00
5_oooon:0?l000koooooRP00o`0>ooooobT00?l01P3o000L003o0080o`00?@00o`0>ooooo`D00?l0
7@3o0002003o01/0o`000P00o`0I0?l000<00?l05`3o000=003o00T0o`006?ooool001KoooooRP3o
000>ooooohX00?l03_oooolY003o00H0o`007000o`020?l003d00?l03_ooool5003o01d0o`000P00
o`0K0?l000800?l06@3o0003003o01L0o`003@00o`090?l001Sooooo000FooooohX0o`003_oooon:
003o00kooooo:`00o`020?l005d00?l03_ooool5003o01@0o`000P00o`0T0?l000800?l0403o0000
0`00o`00o`000?l000060?l000<00?l05P3o0005003o0080o`001`00o`090?l001Sooooo000Foooo
ohX0o`003_oooon:003o00kooooo:`00o`020?l005d00?l03_ooool5003o01@0o`000P00o`0T0?l0
00800?l0403o00000`00o`00o`000?l000060?l000<00?l05P3o0005003o0080o`001`00o`090?l0
01Sooooo000FooooohX0o`003_oooon:003o00kooooo9P00o`000`3o00000?l0003o00040?l001`0
0?l0203o0003003o0080o`00=000o`0>ooooo`@00?l0B@3o0005003o0240o`0000<00?l00?l0003o
00003@00o`070?l001Sooooo000FooooohX0o`003_oooon:003o00koooooB@00o`040?l000800?l0
0P3o000i003o00kooooo1@3o0002003o0440o`0000<00?l00?l0003o0000;`3o0007003o00T0o`00
6?ooool001KoooooRP3o000>ooooohX00?l03_oooom9003o00@0o`000P00o`020?l003T00?l03_oo
ool50?l000800?l0@@3o00000`00o`00o`000?l0000_0?l000L00?l02@3o000Hooooo`005_oooon:
0?l000koooooRP00o`0>ooooodd00?l01`3o000f003o00kooooo2`3o0005003o05@0o`000P00o`0D
0?l000D00?l02`3o000Hooooo`005_oooon:0?l000koooooRP00o`0>ooooodd00?l01`3o000f003o
00kooooo2`3o0005003o05@0o`000P00o`0D0?l000D00?l02`3o000Hooooo`005_ooool50?l00080
0?l0P`3o000>ooooohX00?l03_oooom?003o0080o`00>@00o`0>ooooo`h0o`000P00o`0D0?l00080
0?l000<0o`00003o0000o`000P3o0002003o0180o`001`00o`0;0?l000L00?l03P3o0002003o0180
o`000P00o`0>0?l001Sooooo000Fooooo`D0o`000P00o`230?l000koooooRP00o`0>ooooodl00?l0
0P3o000i003o00kooooo3P3o0002003o01@0o`000P00o`000`3o00000?l0003o00020?l000800?l0
4P3o0007003o00/0o`001`00o`0>0?l000800?l04P3o0002003o00h0o`006?ooool001Kooooo?@3o
0002003o04H0o`0000<00?l00?l0003o00000P3o000>ooooohX00?l03_oooon:003o00kooooo3P3o
0004003o0180o`000P00o`0G0?l000@00?l0>@3o0003003o00d0o`006?ooool001Kooooo?@3o0002
003o04H0o`0000<00?l00?l0003o00000P3o000>ooooohX00?l03_oooon:003o00kooooo3P3o0004
003o0180o`000P00o`0G0?l000@00?l0>@3o0003003o00d0o`006?ooool001Kooooo>@3o0004003o
04d0o`003_oooon:003o00koooooRP00o`0>oooooa00o`001000o`0<0?l000L00?l0103o0004003o
00h0o`001000o`0U0?l000800?l08P3o000Hooooo`005_oooon:0?l000koooooRP00o`0>ooooohX0
0?l03_ooool@0?l000@00?l03P3o0005003o00@0o`000P00o`0B0?l000800?l09@3o0002003o0280
o`006?ooool001KoooooRP3o000>ooooohX00?l03_oooon:003o00kooooo403o0004003o00h0o`00
1@00o`040?l000800?l04P3o0002003o02D0o`000P00o`0R0?l001Sooooo000Foooooh40o`001000
o`050?l000koooooRP00o`0>ooooohX00?l03_ooool5003o00/0o`000P00o`070?l000800?l01`3o
0002003o01/0o`000P00o`150?l000@00?l06?ooool001KoooooP@3o0004003o00D0o`003_oooon:
003o00koooooRP00o`0>ooooo`D00?l02`3o0002003o00L0o`000P00o`070?l000800?l06`3o0002
003o04D0o`001000o`0Hooooo`005_oooomf0?l000@00?l01`3o0004003o00D0o`003_oooon:003o
00kooooo;@00o`020?l005/00?l03_ooool20?l000<00?l0;@3o0002003o00L0o`001P00o`0>0?l0
00D00?l0=03o0002003o01Sooooo000FooooogH0o`001000o`070?l000@00?l01@3o000>ooooohX0
0?l03_ooool]003o0080o`00F`00o`0>ooooo`80o`000`00o`0]0?l000800?l01`3o0006003o00h0
o`001@00o`0d0?l000800?l06?ooool001KoooooP@3o0004003o00D0o`003_oooon:003o00kooooo
RP00o`0>ooooo`D0o`001P00o`030?l000800?l02@3o0002003o00L0o`001@00o`080?l000D00?l0
2`3o0002003o00h0o`000P00o`0g0?l000800?l06?ooool001KoooooP@3o0004003o00D0o`003_oo
oon:003o00koooooRP00o`0>ooooo`D0o`001P00o`030?l000800?l02@3o0002003o00L0o`001@00
o`080?l000D00?l02`3o0002003o00h0o`000P00o`0g0?l000800?l06?ooool001KoooooO`3o0002
003o0080o`000P00o`050?l000koooooRP00o`0>ooooohX00?l03_ooool90?l000800?l03P3o0002
003o00L0o`000P00o`0;0?l000D00?l0EP3o000Hooooo`005_oooomo0?l000800?l01`3o0002003o
00koooooRP00o`0>ooooohX00?l03_oooolI0?l000800?l01`3o0004003o00X0o`000P00o`0@0?l0
00800?l06`3o0005003o01l0o`000`00o`040?l001Sooooo000Fooooogl0o`000P00o`070?l00080
0?l03_oooon:003o00koooooRP00o`0>oooooaT0o`000P00o`070?l000@00?l02P3o0002003o0100
o`000P00o`0K0?l000D00?l07`3o0003003o00@0o`006?ooool001KoooooRP3o000>ooooohX00?l0
3_oooon:003o00kooooo6@3o0004003o00D0o`000P00o`1V0?l001Sooooo000FooooohX0o`003_oo
oon:003o00koooooRP00o`0>oooooaT0o`001000o`050?l000800?l0IP3o000Hooooo`005_oooom4
0?l000800?l0A03o000>ooooohX00?l03_oooon:003o00kooooo5`3o0006003o00D0o`000P00o`0N
0?l000800?l0@@3o00000`00o`00o`000?l000020?l001Sooooo000Foooood@0o`000P00o`140?l0
00koooooRP00o`0>ooooohX00?l03_oooolG0?l000H00?l01@3o0002003o01h0o`000P00o`110?l0
0003003o003o0000o`000080o`006?ooool001KoooooRP3o000>ooooohX00?l03_oooon:003o00ko
oooo0P3o0007003o0100o`002@00o`140?l000@00?l01@3o0005003o0140o`000`00o`020?l001So
oooo000Foooooh40o`000P00o`070?l000koooooRP00o`0>ooooohX00?l03_ooool7003o0180o`00
1@00o`020?l000@00?l0C@3o0003003o01H0o`006?ooool001KoooooP@3o0002003o00L0o`003_oo
oon:003o00koooooRP00o`0>ooooo`L00?l04P3o0005003o0080o`001000o`1=0?l000<00?l05P3o
000Hooooo`005_oooon:0?l000koooooRP00o`0>ooooo`80o`000P00o`000`3o00000?l0003o0011
003o00030?l00000o`000?l003l00?l03_ooool;003o05/0o`001000o`0B0?l00003003o003o0000
o`0000/0o`006?ooool001KoooooRP3o000>ooooohX00?l03_ooool20?l000800?l000<0o`00003o
0000o`00@@00o`000`3o00000?l0003o000o003o00kooooo2`00o`1K0?l000@00?l04P3o00000`00
o`00o`000?l0000;0?l001Sooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000W
ooooog7o00009ooooomao`0002Cooooo000Rooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`0Nooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0Mooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0Mooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0Mooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool07?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo
003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`0NoooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o01oooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0OoooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0OoooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0NoooooaKo0?l07ooooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l07ooooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o01oo
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o01oo
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo
5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0
o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_oo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0O
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0Ooooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0OoooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0OoooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0OoooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?l007oo001o01ko001o5_l0o`0jo`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`0Mo`00OaKo0?l08?l007lFoomo00Co001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`0Mo`00OaKo0?l08?l007lFoomo00Co001o00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool07_oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool07_oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l07_l007lFo`3o03[o001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003ooooo
ooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0Po`00OaKoogl01?l007l00ol0003ooooo
ooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0N
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool07_oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003o001oo`00O`0No`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`04o`00O`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`0NoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool07_oooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01kooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0NoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
7_oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo01kooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003o001oo`00O`0No`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo
001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l0
0ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool07_oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000W
ooooog7o00009?ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool001Kooooo6@00o`02
0?n000<00?l00P3oP00H003o00L0oh004000o`020?n000<00?l00P3oP00;003o0080oh0000<00?l0
0?n0003oP0005000o`020?n000<00?l00P3oP004003o00D0oh003_ooool40?n002000?l01`3oP01F
003o00T0oh003_ooool=003o00030?n00000o`000?l001800?l01`3oP00F003o00<0oh003@00o`02
0?n00003003o003oP000oh0000H00?l000<0oh00003o0000o`001`3oP009003o00@0oh000P00o`00
0`3oP0000?l0003o00090?n000800?l02@3oP00>ooooo`80oh002@00o`030?n000800?l03@3oP000
0`00o`00oh000?n00007003o00P0oh0000<00?l00?n0003oP0001`3oP002003o0080oh000P00o`03
0?n000800?l00P3oP002003o00030?n00000o`000?l000/0oh001000o`000`3oP0000?l0003o0002
003o00@0oh001@00o`020?n000800?l000<0oh00003o0000o`000P00o`020?n000L00?l0403oP00H
ooooo`005_oooolI003o0080oh000`00o`020?n001P00?l01`3oP00@003o0080oh000`00o`020?n0
00/00?l00P3oP0000`00o`00oh000?n0000D003o0080oh000`00o`020?n000@00?l01@3oP00>oooo
o`@0oh008000o`070?n005H00?l02@3oP00>ooooo`d00?l000<0oh00003o0000o`004P00o`070?n0
01H00?l00`3oP00=003o0080oh0000<00?l00?n0003oP0001P00o`000`3oP0000?l0003o00070?n0
00T00?l0103oP002003o00030?n00000o`000?l000T0oh000P00o`090?n000kooooo0P3oP009003o
00<0oh000P00o`0=0?n00003003o003oP000oh0000L00?l0203oP0000`00o`00oh000?n000070?n0
00800?l00P3oP002003o00<0oh000P00o`020?n000800?l000<0oh00003o0000o`002`3oP004003o
00030?n00000o`000?l000800?l0103oP005003o0080oh000P00o`000`3oP0000?l0003o0002003o
0080oh001`00o`0@0?n001Sooooo000FoooooaH00?l000<0oh00003o0000o`000P3oP007003o00@0
oh004P00o`050?n000`00?l00P3oP004003o00L0oh007P00o`020?n000@00?l00P3oP003003o0080
oh001000o`050?n000kooooo103oP00P003o00L0oh005`00o`020?n003d00?l02@3oP00>ooooo`d0
0?l000<0oh00003o0000o`004P00o`070?n001P00?l00`3oP009003o00T0oh001000o`0:0?n000T0
0?l01`3oP002003o00T0oh000P00o`090?n000kooooo0P3oP007003o00D0oh000P00o`070?n00080
0?l00P3oP003003o00@0oh001000o`090?n00003003o003oP000oh0000800?l01@3oP009003o0080
oh001000o`000`3oP0000?l0003o000;0?n000@00?l000<0oh00003o0000o`001`3oP002003o00@0
oh000P00o`030?n000800?l00P3oP0000`00o`00oh000?n0000B0?n000800?l06?ooool001Kooooo
5P00o`000`3oP0000?l0003o00020?n000L00?l0103oP00B003o00D0oh003000o`020?n000@00?l0
1`3oP00N003o0080oh001000o`020?n000<00?l00P3oP004003o00D0oh003_ooool40?n002000?l0
1`3oP00G003o0080oh00?@00o`090?n000kooooo3@00o`000`3oP0000?l0003o000B003o00L0oh00
6000o`030?n000T00?l02@3oP004003o00X0oh002@00o`070?n000800?l02@3oP002003o00T0oh00
3_ooool20?n000L00?l01@3oP002003o00L0oh000P00o`020?n000<00?l0103oP004003o00T0oh00
00<00?l00?n0003oP0000P00o`050?n000T00?l00P3oP004003o00030?n00000o`000?l000/0oh00
1000o`000`3oP0000?l0003o00070?n000800?l0103oP002003o00<0oh000P00o`020?n00003003o
003oP000oh000180oh000P00o`0Hooooo`005_ooool;003o0080oh002@00o`000`3oP0000?l0003o
00020?n000L00?l0103oP00:003o0080oh001000o`020?n00003003o003oP000oh000080oh003000
o`040?n000800?l00P3oP003003o0080oh000P00o`020?n000X00?l00P3oP00>003o0080oh000P00
o`040?n000<00?l00P3oP002003o00D0oh000P00o`0>ooooo`@0oh008000o`070?n005800?l00P3o
P002003o00T0oh003_ooool=003o00030?n00000o`000?l001800?l01`3oP002003o0080oh000P00
o`000`3oP0000?l0003o000;003o00L0oh001`00o`0I0?n000H00?l01`3oP009003o0080oh0000<0
0?l00?n0003oP0000P00o`090?n000kooooo0P3oP005003o01@0oh001@00o`020?n000@00?l02@3o
P0000`00o`00oh000?n00006003o00<0oh001`00o`020?n000L00?l02@3oP006003o00030?n00000
o`000?l000d0oh000P00o`030?n000800?l05`3oP002003o01Sooooo000Fooooo`/00?l00P3oP009
003o00030?n00000o`000?l00080oh001`00o`070?n000L00?l00P3oP007003o00@0oh002`00o`09
0?n00003003o003oP000oh000080oh000P00o`020?n00003003o003oP000oh000080oh000P00o`02
0?n00003003o003oP000oh0000d00?l02@3oP003003o00H0oh0000<00?l00?n0003oP0000P00o`0>
ooooob@00?l01`3oP01=003o0080oh000`00o`020?n000800?l02@3oP00>ooooo`d00?l000<0oh00
003o0000o`003@00o`000`3oP0000?l0003o0002003o00h0oh003@00o`070?n000L00?l06@3oP002
003o00/0oh004000o`090?n000kooooo0P3oP002003o00h0oh000P00o`030?n000800?l00P3oP005
003o0080oh001`00o`060?n00003003o003oP000oh0000L00?l03@3oP007003o00T0oh001000o`00
0`3oP0000?l0003o000?0?n00003003o003oP000oh0000@00?l05@3oP002003o01Sooooo000Foooo
o`/00?l00P3oP009003o00030?n00000o`000?l00080oh001`00o`070?n000L00?l00P3oP007003o
00@0oh002`00o`090?n00003003o003oP000oh000080oh000P00o`020?n00003003o003oP000oh00
0080oh000P00o`020?n00003003o003oP000oh0000d00?l02@3oP003003o00H0oh0000<00?l00?n0
003oP0000P00o`0>ooooob@00?l01`3oP01=003o0080oh000`00o`020?n000800?l02@3oP00>oooo
o`d00?l000<0oh00003o0000o`003@00o`000`3oP0000?l0003o0002003o00h0oh003@00o`070?n0
00L00?l06@3oP002003o00/0oh004000o`090?n000kooooo0P3oP002003o00h0oh000P00o`030?n0
00800?l00P3oP005003o0080oh001`00o`060?n00003003o003oP000oh0000L00?l03@3oP007003o
00T0oh001000o`000`3oP0000?l0003o000?0?n00003003o003oP000oh0000@00?l05@3oP002003o
01Sooooo000Fooooo`/00?l00P3oP009003o00030?n00000o`000?l000T00?l01`3oP002003o0080
oh003000o`040?n000L00?l00P3oP002003o00T0oh0000<00?l00?n0003oP0000P3oP002003o0080
oh0000<00?l00?n0003oP0001P3oP0000`00o`00oh000?n0000=003o00<0oh000P00o`040?n000<0
0?l01P3oP0000`00o`00oh000?n00002003o00kooooo9000o`070?n004d00?l00P3oP002003o00<0
oh000P00o`040?n00003003o003oP000oh000080oh003_ooool40?n000X00?l00P3oP002003o0080
oh003P00o`0>0?n000l00?l02@3oP0000`00o`00oh000?n0000V0?n000L00?l0103oP007003o00L0
oh003_ooool20?n000800?l02P3oP006003o00L0oh004P00o`020?n00003003o003oP000oh0001@0
oh001`00o`090?n000800?l05`3oP004003o00030?n00000o`000?l00100oh001000o`0Hooooo`00
5_ooool;003o0080oh002@00o`000`3oP0000?l0003o0009003o00L0oh000P00o`020?n000`00?l0
103oP007003o0080oh000P00o`090?n00003003o003oP000oh000080oh000P00o`020?n00003003o
003oP000oh0000H0oh0000<00?l00?n0003oP0003@00o`030?n000800?l0103oP003003o00H0oh00
00<00?l00?n0003oP0000P00o`0>ooooob@00?l01`3oP01=003o0080oh000P00o`030?n000800?l0
103oP0000`00o`00oh000?n000020?n000kooooo103oP00:003o0080oh000P00o`020?n000h00?l0
3P3oP00?003o00T0oh0000<00?l00?n0003oP0009P3oP007003o00@0oh001`00o`070?n000kooooo
0P3oP002003o00X0oh001P00o`070?n001800?l00P3oP0000`00o`00oh000?n0000D0?n000L00?l0
2@3oP002003o01L0oh001000o`000`3oP0000?l0003o000@0?n000@00?l06?ooool001Kooooo8P00
o`020?n000<00?l00P3oP00B003o0080oh001`00o`020?n000<00?l00P3oP004003o0080oh0000<0
0?l00?n0003oP0001000o`020?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0002`00
o`050?n000800?l0103oP003003o00H0oh0000<00?l00?n0003oP0000P00o`0>ooooob@00?l01`3o
P01=003o0080oh000`00o`020?n000800?l02@3oP00>ooooo`@0oh002P00o`020?n000800?l00P3o
P002003o00030?n00000o`000?l000L00?l0403oP00?003o01h0oh000P00o`090?n000@00?l01@3o
P007003o00T0oh001000o`050?n000kooooo3@3oP007003o00L0oh004000o`040?n000<00?l05`3o
P004003o00T0oh000P00o`020?n000<00?l04P3oP002003o00/0oh0000<00?l00?n0003oP0000P3o
P002003o00<0oh001000o`0Hooooo`005_oooolR003o0080oh000`00o`020?n001800?l00P3oP007
003o0080oh000`00o`020?n000@00?l00P3oP0000`00o`00oh000?n00004003o0080oh0000<00?l0
0?n0003oP0001P3oP0000`00o`00oh000?n0000;003o00D0oh000P00o`040?n000<00?l01P3oP000
0`00o`00oh000?n00002003o00kooooo9000o`070?n004d00?l00P3oP003003o0080oh000P00o`09
0?n000kooooo103oP00:003o0080oh000P00o`020?n000800?l000<0oh00003o0000o`001`00o`0@
0?n000l00?l07P3oP002003o00T0oh001000o`050?n000L00?l02@3oP004003o00D0oh003_ooool=
0?n000L00?l01`3oP00@003o00@0oh000`00o`0G0?n000@00?l02@3oP002003o0080oh000`00o`0B
0?n000800?l02`3oP0000`00o`00oh000?n000020?n000800?l00`3oP004003o01Sooooo000Foooo
ob800?l00P3oP00G003o0080oh001`00o`020?n000<00?l00P3oP004003o0080oh002P00o`080?n0
00X00?l00P3oP002003o00D0oh002@00o`0;0?n000kooooo9000o`070?n002@00?l00P3oP00/003o
0080oh000P00o`090?n000kooooo103oP00:003o0080oh004000o`0@0?n001400?l06P3oP004003o
00T0oh001@00o`040?n000800?l000<0oh00003o0000o`000P00o`090?n000@00?l01@3oP00>oooo
o`80oh000P00o`000`3oP0000?l0003o0002003o00@0oh001@00o`090?n000`00?l00P3oP002003o
00@0oh000`00o`0I0?n000800?l03@3oP0000`00o`00oh000?n0000K0?n000800?l00P3oP0000`00
o`00oh000?n000020?n000800?l00`3oP004003o01Sooooo000Foooooad00?l000<0oh00003o0000
o`006`00o`020?n000800?l00P3oP003003o0080oh000`00o`020?n000@00?l00P3oP0000`00o`00
oh000?n00004003o0080oh0000<00?l00?n0003oP0005P00o`030?n000800?l00P3oP009003o0080
oh0000<00?l00?n0003oP0000P3oP00>ooooob@00?l01`3oP01B003o0080oh000P00o`090?n000ko
oooo103oP00:003o0080oh003P00o`020?n000800?l02@3oP00F003o01T0oh001@00o`070?n000L0
0?l01`3oP004003o00T0oh001000o`050?n000kooooo0P00o`030?n000@00?l00P3oP007003o00/0
oh0000<00?l00?n0003oP000103oP002003o00<0oh002`00o`180?n00003003o003oP000oh0000/0
oh006?ooool001Kooooo7@00o`000`3oP0000?l0003o000K003o0080oh000P00o`020?n000<00?l0
0P3oP003003o0080oh001000o`020?n00003003o003oP000oh0000@00?l00P3oP0000`00o`00oh00
0?n0000F003o00<0oh000P00o`020?n000T00?l00P3oP0000`00o`00oh000?n000020?n000kooooo
9000o`070?n005800?l00P3oP002003o00T0oh003_ooool40?n000X00?l00P3oP00>003o0080oh00
0P00o`090?n001H00?l06@3oP005003o00L0oh001`00o`070?n000@00?l02@3oP004003o00D0oh00
3_ooool2003o00<0oh001000o`020?n000L00?l02`3oP0000`00o`00oh000?n000040?n000800?l0
0`3oP00;003o04P0oh0000<00?l00?n0003oP0002`3oP00Hooooo`005_ooool@003o0080oh000P00
o`020?n000L00?l000<0oh00003o0000o`000P00o`020?n001D00?l0103oP002003o00<0oh000P00
o`020?n000<00?l00P3oP004003o0080oh0000<00?l00?n0003oP0001000o`020?n00003003o003o
P000oh0001H00?l00`3oP002003o0080oh001@00o`020?n000800?l00`3oP002003o0080oh003_oo
oolT003o00L0oh008P00o`020?n003800?l01`3oP002003o00kooooo6@00o`040?n00003003o003o
P000oh0000@00?l02`3oP00B003o00L0oh000`00o`0?0?n000D00?l01`3oP009003o00@0oh001@00
o`090?n000@00?l01@3oP00>ooooo`@00?l000<0oh00003o0000o`000P00o`020?n000D00?l07@3o
P003003o0080oh000P00o`050?n000800?l0@@3oP0000`00o`00oh000?n0000;0?n001Sooooo000F
oooooa000?l00P3oP002003o0080oh001`00o`000`3oP0000?l0003o0002003o0080oh005@00o`04
0?n000800?l00`3oP002003o0080oh000`00o`020?n000@00?l00P3oP0000`00o`00oh000?n00004
003o0080oh0000<00?l00?n0003oP0005P00o`030?n000800?l00P3oP005003o0080oh000P00o`03
0?n000800?l00P3oP00>ooooob@00?l01`3oP00R003o0080oh00<P00o`070?n000800?l03_oooolI
003o00@0oh0000<00?l00?n0003oP0001000o`0;0?n001800?l01`3oP003003o00l0oh001@00o`07
0?n000T00?l0103oP005003o00T0oh001000o`050?n000kooooo1000o`000`3oP0000?l0003o0002
003o0080oh001@00o`0M0?n000<00?l00P3oP002003o00D0oh000P00o`110?n00003003o003oP000
oh0000/0oh006?ooool001Kooooo4000o`020?n000/00?l000<0oh00003o0000o`00103oP00E003o
00@0oh000P00o`020?n000<00?l00P3oP003003o0080oh000P00o`040?n00003003o003oP000oh00
00@00?l00P3oP0000`00o`00oh000?n0000G003o0080oh000P00o`040?n000`00?l00P3oP00>oooo
ob@00?l01`3oP00R003o0080oh00<P00o`040?n00003003o003oP000oh0000800?l03_oooolN003o
0080oh001000o`0;0?n001000?l01@3oP002003o0080oh000`00o`090?n000/00?l00P3oP00G003o
00D0oh000P00o`020?n000@00?l01@3oP00>ooooo`@00?l00`3oP002003o0080oh001`00o`070?n0
00800?l00P3oP0000`00o`00oh000?n000020?n000800?l02@3oP003003o0080oh000P00o`050?n0
00800?l0C`3oP00Hooooo`005_ooool@003o0080oh002`00o`000`3oP0000?l0003o00040?n001D0
0?l0103oP002003o0080oh000`00o`020?n000<00?l00P3oP002003o00@0oh0000<00?l00?n0003o
P0001000o`020?n00003003o003oP000oh0001L00?l00P3oP002003o00@0oh003000o`020?n000ko
oooo9000o`070?n002800?l00P3oP00b003o00@0oh0000<00?l00?n0003oP0000P00o`0>oooooah0
0?l00P3oP004003o00/0oh004000o`050?n000800?l00P3oP003003o00T0oh002`00o`020?n001L0
0?l01@3oP002003o0080oh001000o`050?n000kooooo1000o`030?n000800?l00P3oP007003o00L0
oh000P00o`020?n00003003o003oP000oh000080oh000P00o`090?n000<00?l00P3oP002003o00D0
oh000P00o`1?0?n001Sooooo000Foooooa000?l00P3oP007003o0080oh000P00o`000`3oP0000?l0
003o0002003o0080oh005@00o`040?n000800?l00`3oP002003o0080oh000`00o`020?n000800?l0
103oP0000`00o`00oh000?n00004003o0080oh0000<00?l00?n0003oP0001000o`020?n001400?l0
0P3oP002003o00@0oh002@00o`000`3oP0000?l0003o00020?n000kooooo9000o`070?n005P00?l0
0P3oP005003o00kooooo8000o`020?n000800?l00`3oP004003o00D0oh003@00o`070?n000L00?l0
2@3oP00@003o00H0oh000P00o`030?n000T00?l01@3oP002003o0080oh001000o`000`3oP0000?l0
003o0002003o00kooooo0P00o`020?n00003003o003oP000oh0001000?l00P3oP004003o00030?n0
0000o`000?l00080oh001000o`070?n000L00?l06`3oP002003o00<0oh001000o`0b0?n001Sooooo
000Foooooa000?l00P3oP007003o0080oh000P00o`000`3oP0000?l0003o0002003o0080oh005@00
o`040?n000800?l00`3oP002003o0080oh000`00o`020?n000800?l0103oP0000`00o`00oh000?n0
0004003o0080oh0000<00?l00?n0003oP0001000o`020?n001400?l00P3oP002003o00@0oh002@00
o`000`3oP0000?l0003o00020?n000kooooo9000o`070?n005P00?l00P3oP005003o00kooooo8000
o`020?n000800?l00`3oP004003o00D0oh003@00o`070?n000L00?l02@3oP00@003o00H0oh000P00
o`030?n000T00?l01@3oP002003o0080oh001000o`000`3oP0000?l0003o0002003o00kooooo0P00
o`020?n00003003o003oP000oh0001000?l00P3oP004003o00030?n00000o`000?l00080oh001000
o`070?n000L00?l06`3oP002003o00<0oh001000o`0b0?n001Sooooo000FoooooaT00?l00P3oP002
003o00030?n00000o`000?l000800?l00P3oP00<003o0080oh001000o`070?n000800?l00P3oP003
003o0080oh001`00o`040?n00003003o003oP000oh0000@00?l00P3oP0000`00o`00oh000?n00004
003o0080oh004@00o`020?n000800?l0103oP003003o0080oh000P00o`030?n000@00?l03_oooolV
003o00030?n00000o`000?l00080oh008000o`040?n003H00?l00`3oP002003o00kooooo8000o`02
0?n000800?l00`3oP008003o00030?n00000o`000?l000d00?l01@3oP009003o00L0oh004000o`06
0?n000800?l00`3oP007003o00L0oh002000o`050?n000kooooo0P00o`020?n00003003o003oP000
oh0000@0oh000P00o`000`3oP0000?l0003o0002003o0080oh001`00o`020?n000T00?l000<0oh00
003o0000o`003@3oP003003o01T0oh001P00o`0b0?n001Sooooo000FoooooaT00?l00P3oP002003o
00030?n00000o`000?l001H00?l00P3oP0000`00o`00oh000?n000020?n000800?l00P3oP003003o
0080oh002@00o`020?n002<00?l0203oP005003o00D0oh001000o`0>ooooobT00?l00P3oP00P003o
00L0oh00>000o`0>ooooo`80oh008P00o`030?n000P00?l000<0oh00003o0000o`004000o`020?n0
00/00?l00`3oP00A003o00L0oh000P00o`050?n000<00?l02`3oP004003o00L0oh003_ooool2003o
00L0oh002@00o`040?n00003003o003oP000oh0000T00?l01`3oP004003o0080oh000`00o`040?n0
00<00?l05P3oP002003o00030?n00000o`000?l000800?l0=03oP00Hooooo`005_oooolI003o0080
oh000P00o`000`3oP0000?l0003o000F003o0080oh0000<00?l00?n0003oP0000P3oP002003o0080
oh000`00o`020?n000T00?l00P3oP00S003o00P0oh001@00o`050?n000@00?l03_oooolY003o0080
oh008000o`070?n003P00?l03_ooool20?n002800?l00`3oP008003o00030?n00000o`000?l00100
0?l00P3oP00;003o00<0oh004@00o`070?n000800?l01@3oP003003o00/0oh001000o`070?n000ko
oooo0P00o`070?n000T00?l0103oP0000`00o`00oh000?n00009003o00L0oh001000o`020?n000<0
0?l0103oP003003o01H0oh000P00o`000`3oP0000?l0003o0002003o03@0oh006?ooool001Kooooo
0P00o`020?n001D00?l00P3oP002003o00030?n00000o`000?l000L00?l00P3oP00@003o00@0oh00
0P00o`020?n000h00?l01@3oP00P003o00P0oh001@00o`050?n000@00?l03_oooom;003o0080oh00
1000o`000`3oP0000?l0003o000f003o00kooooo0P3oP00B003o0080oh003P00o`020?n00003003o
003oP000oh000080oh001@00o`020?n001d00?l00`3oP002003o00@0oh001`00o`070?n000800?l0
0P3oP002003o01<0oh001000o`020?n000<00?l00P3oP00>ooooo`800?l01`3oP007003o00T0oh00
1@00o`060?n000T00?l00`3oP002003o0080oh001000o`0:0?n000800?l02@3oP004003o00030?n0
0000o`000?l00200oh000P00o`0D0?n001Sooooo000Fooooo`800?l00P3oP00E003o0080oh000P00
o`000`3oP0000?l0003o0007003o0080oh004000o`040?n000800?l00P3oP00>003o00D0oh008000
o`080?n000D00?l01@3oP004003o00koooooB`00o`020?n000@00?l000<0oh00003o0000o`00=P00
o`0>ooooo`80oh004P00o`020?n000h00?l00P3oP0000`00o`00oh000?n000020?n000D00?l00P3o
P00M003o00<0oh000P00o`040?n000L00?l01`3oP002003o0080oh000P00o`0C0?n000@00?l00P3o
P003003o0080oh003_ooool2003o00L0oh001`00o`090?n000D00?l01P3oP009003o00<0oh000P00
o`020?n000@00?l02P3oP002003o00T0oh001000o`000`3oP0000?l0003o000P0?n000800?l0503o
P00Hooooo`005_ooooli003o00@0oh000P00o`020?n000<00?l00P3oP009003o00D0oh008000o`02
0?n000800?l0103oP005003o00L0oh000P00o`0>oooood/00?l00P3oP002003o00<0oh00>000o`0>
ooooo`80oh004P00o`020?n000P00?l00P3oP004003o00/0oh0000<00?l00?n0003oP0007@00o`07
0?n000D00?l00P3oP002003o00L0oh001P00o`000`3oP0000?l0003o000@0?n000@00?l00P3oP003
003o0080oh003_ooool4003o00030?n00000o`000?l000@0oh000`00o`0;0?n000@00?l01`3oP007
003o00/0oh000P00o`0:0?n000800?l02@3oP004003o0200oh001@00o`0D0?n001Sooooo000Foooo
ocT00?l0103oP002003o0080oh000`00o`020?n000T00?l01@3oP00P003o0080oh000P00o`040?n0
00D00?l01`3oP002003o00koooooB`00o`020?n000800?l00`3oP00h003o00kooooo0P3oP00B003o
0080oh002000o`020?n000@00?l02`3oP0000`00o`00oh000?n0000M003o00L0oh001@00o`020?n0
00800?l01`3oP006003o00030?n00000o`000?l00100oh001000o`020?n000<00?l00P3oP00>oooo
o`@00?l000<0oh00003o0000o`00103oP003003o00/0oh001000o`070?n000L00?l02`3oP002003o
00X0oh000P00o`090?n000@00?l0803oP005003o01@0oh006?ooool001Kooooo1`00o`020?n000/0
0?l00P3oP00<003o0080oh000`00o`020?n001000?l00P3oP004003o0080oh000`00o`020?n000`0
0?l00P3oP00P003o0080oh000P00o`040?n000D00?l01@3oP004003o00koooooB`00o`070?n003P0
0?l03_ooool;003o0080oh000`00o`020?n000800?l00P3oP0000`00o`00oh000?n000040?n00003
003o003oP000oh000080oh000P00o`0>0?n000d00?l01@3oP009003o00T0oh001@00o`020?n00080
0?l0103oP0000`00o`00oh000?n00006003o00030?n00000o`000?l000@0oh0000<00?l00?n0003o
P0002@3oP007003o00@0oh003_ooool2003o00<0oh002000o`0<0?n000@00?l01`3oP007003o0080
oh000P00o`070?n000800?l02P3oP002003o00T0oh000P00o`0R0?n000D00?l0503oP00Hooooo`00
5_ooool7003o0080oh002`00o`020?n000`00?l00P3oP003003o0080oh004000o`020?n000@00?l0
0P3oP003003o0080oh003000o`020?n002000?l00P3oP002003o00@0oh001@00o`050?n000@00?l0
3_oooom;003o00L0oh00>000o`0>ooooo`/00?l00P3oP003003o0080oh000P00o`020?n00003003o
003oP000oh0000@0oh0000<00?l00?n0003oP0000P3oP002003o00h0oh003@00o`050?n000T00?l0
2@3oP005003o0080oh000P00o`040?n00003003o003oP000oh0000H00?l000<0oh00003o0000o`00
103oP0000`00o`00oh000?n000090?n000L00?l0103oP00>ooooo`800?l00`3oP008003o00`0oh00
1000o`070?n000L00?l00P3oP002003o00L0oh000P00o`0:0?n000800?l02@3oP002003o0280oh00
1@00o`0D0?n001Sooooo000Fooooo`L00?l00P3oP004003o00030?n00000o`000?l000d00?l000<0
oh00003o0000o`000P00o`020?n001/00?l00P3oP003003o0080oh001`00o`020?n000<00?l00P3o
P00P003o0080oh000P00o`020?n000T00?l00`3oP004003o00koooooB`00o`070?n002l00?l00P3o
P007003o00kooooo2`00o`020?n000<00?l00P3oP002003o00T0oh0000<00?l00?n0003oP0004P3o
P00?003o00D0oh001`00o`090?n000D00?l0103oP002003o0080oh002@00o`070?n00003003o003o
P000oh000080oh000P00o`050?n000@00?l00P3oP0000`00o`00oh000?n000020?n000kooooo1@3o
P008003o00X0oh001P00o`070?n000L00?l05`3oP002003o00T0oh000P00o`0<0?n000800?l02@3o
P002003o00T0oh000P00o`000`3oP0000?l0003o00020?n000D00?l02`3oP002003o01Sooooo000F
ooooo`L00?l00P3oP007003o0080oh002`00o`000`3oP0000?l0003o0002003o0080oh006`00o`02
0?n000<00?l00P3oP002003o00<0oh000P00o`020?n001L00?l00P3oP00<003o0080oh000P00o`04
0?n000<00?l00P3oP009003o00koooooB`00o`070?n002l00?l00P3oP007003o00kooooo2`00o`02
0?n000<00?l00P3oP004003o00L0oh000`00o`0B0?n000l00?l01`3oP005003o00T0oh001000o`05
0?n000T00?l02`3oP00:003o0080oh000P00o`040?n00003003o003oP000oh000080oh003_ooool7
0?n000@00?l01`3oP002003o00<0oh001P00o`070?n000L00?l00P3oP002003o01<0oh001000o`07
0?n000800?l00P3oP0000`00o`00oh000?n000070?n000800?l02@3oP002003o00h0oh000P00o`02
0?n000L00?l01`3oP002003o01Sooooo000Fooooo`L00?l00P3oP007003o0080oh002`00o`000`3o
P0000?l0003o0002003o0080oh006`00o`020?n000<00?l00P3oP002003o00<0oh000P00o`020?n0
01L00?l00P3oP00<003o0080oh000P00o`040?n000<00?l00P3oP009003o00koooooB`00o`070?n0
02l00?l00P3oP007003o00kooooo2`00o`020?n000<00?l00P3oP004003o00L0oh000`00o`0B0?n0
00l00?l01`3oP005003o00T0oh001000o`050?n000T00?l02`3oP00:003o0080oh000P00o`040?n0
0003003o003oP000oh000080oh003_ooool70?n000@00?l01`3oP002003o00<0oh001P00o`070?n0
00L00?l00P3oP002003o01<0oh001000o`070?n000800?l00P3oP0000`00o`00oh000?n000070?n0
00800?l02@3oP002003o00h0oh000P00o`020?n000L00?l01`3oP002003o01Sooooo000Foooooa00
0?l00P3oP00;003o00030?n00000o`000?l002P00?l000<0oh00003o0000o`000P00o`020?n002D0
0?l00P3oP002003o00@0oh000`00o`020?n000T00?l03_oooolk003o0080oh000P00o`030?n000T0
0?l01`3oP00h003o00kooooo5P00o`000`3oP0000?l0003o00040?n000<00?l04P3oP00@003o00L0
oh001000o`090?n000800?l01`3oP004003o0100oh002P00o`0=0?n000kooooo3P3oP002003o00L0
oh001P00o`070?n000L00?l00P3oP002003o00T0oh000`00o`070?n000@00?l02`3oP003003o00L0
oh000P00o`0;0?n000800?l0303oP002003o00@0oh001`00o`030?n000@00?l06?ooool001Kooooo
4000o`020?n000/00?l000<0oh00003o0000o`00:000o`000`3oP0000?l0003o0002003o0080oh00
9@00o`020?n000800?l0103oP003003o0080oh002@00o`0>oooooc/00?l00P3oP002003o00<0oh00
2@00o`070?n003P00?l03_oooolF003o00030?n00000o`000?l000@0oh000`00o`0B0?n001000?l0
1`3oP004003o00T0oh000P00o`070?n000@00?l0403oP00:003o00d0oh003_ooool>0?n000800?l0
1`3oP006003o00L0oh001`00o`020?n000800?l02@3oP003003o00L0oh001000o`0;0?n000<00?l0
1`3oP002003o00/0oh000P00o`0<0?n000800?l0103oP007003o00<0oh001000o`0Hooooo`005_oo
oom=003o0080oh009@00o`080?n00003003o003oP000oh000080oh002@00o`0>oooooc/00?l00P3o
P002003o00<0oh002@00o`070?n003P00?l03_oooolF003o00030?n00000o`000?l00080oh002@00
o`0<0?n001800?l01`3oP004003o00T0oh000P00o`0K0?n000`00?l02`3oP00>ooooo`80oh000P00
o`0:0?n000@00?l0103oP0000`00o`00oh000?n000020?n000800?l01`3oP002003o00030?n00000
o`000?l000800?l06@3oP002003o00/0oh0000<00?l00?n0003oP0001`3oP002003o00H0oh0000<0
0?l00?n0003oP0000P3oP002003o0080oh000`00o`070?n000800?l0103oP007003o00L0oh006?oo
ool001KoooooC@00o`020?n002D00?l0203oP0000`00o`00oh000?n000020?n000T00?l03_oooolk
003o0080oh000P00o`030?n000T00?l01`3oP00h003o00kooooo5P00o`000`3oP0000?l0003o0002
0?n000T00?l0303oP00B003o00L0oh001000o`090?n000800?l06`3oP00<003o00/0oh003_ooool2
0?n000800?l02P3oP004003o00@0oh0000<00?l00?n0003oP0000P3oP002003o00L0oh000P00o`00
0`3oP0000?l0003o0002003o01T0oh000P00o`0;0?n00003003o003oP000oh0000L0oh000P00o`06
0?n00003003o003oP000oh000080oh000P00o`020?n000<00?l01`3oP002003o00@0oh001`00o`07
0?n001Sooooo000FooooocT00?l00P3oP00B003o0080oh002`00o`000`3oP0000?l0003o000F003o
00L0oh004000o`0>oooooc/00?l00P3oP002003o00<0oh002@00o`070?n003P00?l03_ooool2003o
00<0oh002`00o`020?n000@00?l000<0oh00003o0000o`002`00o`020?n00003003o003oP000oh00
00H0oh004`00o`040?n000L00?l02@3oP002003o00L0oh001000o`0>0?n000D00?l00P3oP007003o
00/0oh003_ooool5003o00P0oh001@00o`040?n00003003o003oP000oh000080oh000P00o`070?n0
00800?l01`3oP002003o00X0oh000P00o`020?n000800?l04P3oP0000`00o`00oh000?n000070?n0
00800?l00P3oP002003o0080oh000`00o`020?n000800?l00P3oP0000`00o`00oh000?n000070?n0
00800?l0103oP0000`00o`00oh000?n00004003o00L0oh006?ooool001Kooooo;`00o`000`3oP000
0?l0003o000X003o00030?n00000o`000?l001H00?l000<0oh00003o0000o`000P3oP00B003o00ko
oooo>`00o`020?n000800?l00`3oP009003o00L0oh00>000o`0>oooooa000?l00P3oP00;003o0003
0?n00000o`000?l000@00?l00P3oP0000`00o`00oh000?n000060?n001000?l01`3oP007003o00T0
oh000P00o`070?n000L00?l02`3oP002003o00L0oh001`00o`090?n000kooooo1@00o`080?n000D0
0?l0103oP0000`00o`00oh000?n000020?n000800?l0303oP002003o0080oh000P00o`070?n00080
0?l000<0oh00003o0000o`000P3oP002003o0100oh000`00o`040?n000@00?l01@3oP002003o0080
oh000`00o`020?n000800?l00P3oP0000`00o`00oh000?n000020?n000<00?l00P3oP004003o0080
oh001`00o`070?n001Sooooo000Fooooobl00?l000<0oh00003o0000o`00:000o`000`3oP0000?l0
003o000F003o00030?n00000o`000?l00080oh004P00o`0>oooooc/00?l00P3oP002003o00<0oh00
2@00o`070?n003P00?l03_ooool@003o0080oh002`00o`000`3oP0000?l0003o0004003o0080oh00
00<00?l00?n0003oP0001P3oP00@003o00L0oh001`00o`090?n000800?l01`3oP007003o00/0oh00
0P00o`070?n000L00?l02@3oP00>ooooo`D00?l0203oP005003o00@0oh0000<00?l00?n0003oP000
0P3oP002003o00`0oh000P00o`020?n000800?l01`3oP002003o00030?n00000o`000?l00080oh00
0P00o`0@0?n000<00?l0103oP004003o00D0oh000P00o`020?n000<00?l00P3oP002003o0080oh00
00<00?l00?n0003oP0000P3oP003003o0080oh001000o`020?n000L00?l01`3oP00Hooooo`005_oo
oomJ003o00030?n00000o`000?l001H00?l000<0oh00003o0000o`00103oP00@003o00kooooo<000
o`020?n001T00?l01`3oP00h003o00kooooo4000o`020?n001D00?l0203oP00@003o00L0oh001`00
o`090?n000800?l01@3oP009003o00/0oh000`00o`020?n000800?l00P3oP002003o00030?n00000
o`000?l000800?l02@3oP00>ooooo`D00?l0203oP005003o00T0oh001@00o`0=0?n000800?l05`3o
P002003o00X0oh000P00o`040?n000<00?l0103oP007003o00T0oh001@00o`020?n000@00?l01@3o
P004003o00L0oh006?ooool001KoooooFP00o`000`3oP0000?l0003o000F003o00030?n00000o`00
0?l000@0oh004000o`0>oooooc000?l00P3oP00I003o00L0oh00>000o`0>oooooa000?l00P3oP00E
003o00P0oh004000o`070?n000L00?l02@3oP002003o00D0oh002@00o`0;0?n000<00?l00P3oP002
003o0080oh000P00o`000`3oP0000?l0003o0002003o00T0oh003_ooool5003o00P0oh001@00o`09
0?n000D00?l03@3oP002003o01L0oh000P00o`0:0?n000800?l0103oP003003o00@0oh001`00o`09
0?n000D00?l00P3oP004003o00D0oh001000o`070?n001Sooooo000FoooooeX00?l000<0oh00003o
0000o`003`00o`000`3oP0000?l0003o0002003o00<0oh000P00o`040?n000/00?l000<0oh00003o
0000o`000P00o`0>ooooob000?l00P3oP00>003o0080oh006`00o`050?n003P00?l03_ooool@003o
0080oh005`00o`060?n001000?l00`3oP002003o0080oh001@00o`0;0?n000800?l01@3oP004003o
0080oh003000o`020?n000T00?l00`3oP002003o00@0oh000P00o`050?n000kooooo1@00o`090?n0
00800?l02`3oP003003o00l0oh000P00o`0L0?n000800?l01@3oP002003o00@0oh000`00o`090?n0
00800?l02`3oP002003o00030?n00000o`000?l000H00?l02P3oP004003o01Sooooo000FoooooeX0
0?l000<0oh00003o0000o`003`00o`000`3oP0000?l0003o0002003o00<0oh000P00o`040?n000/0
0?l000<0oh00003o0000o`000P00o`0>ooooob000?l00P3oP00>003o0080oh006`00o`050?n003P0
0?l03_ooool@003o0080oh005`00o`060?n001000?l00`3oP002003o0080oh001@00o`0;0?n00080
0?l01@3oP004003o0080oh003000o`020?n000T00?l00`3oP002003o00@0oh000P00o`050?n000ko
oooo1@00o`090?n000800?l02`3oP003003o00l0oh000P00o`0L0?n000800?l01@3oP002003o00@0
oh000`00o`090?n000800?l02`3oP002003o00030?n00000o`000?l000H00?l02P3oP004003o01So
oooo000FooooocP00?l000<0oh00003o0000o`007@00o`030?n001800?l00P3oP002003o00<0oh00
0P00o`040?n001000?l03_oooolP003o0080oh00;`00o`000`3oP0000?l0003o000f003o00kooooo
:`00o`040?n00003003o003oP000oh0000d00?l01`3oP003003o00@0oh000P00o`0>0?n000800?l0
103oP00<003o0080oh002@00o`0@0?n000kooooo1@00o`090?n000@00?l01`3oP005003o00d0oh00
0P00o`090?n000800?l02@3oP003003o00h0oh001000o`020?n000<00?l06@3oP009003o00T0oh00
0P00o`020?n001Sooooo000FooooocP00?l000<0oh00003o0000o`007@00o`030?n001800?l00P3o
P002003o00<0oh000P00o`040?n001000?l03_oooolP003o0080oh00;`00o`000`3oP0000?l0003o
000f003o00kooooo:`00o`040?n00003003o003oP000oh0000d00?l01`3oP003003o00@0oh000P00
o`0>0?n000800?l0103oP00<003o0080oh002@00o`0@0?n000kooooo1@00o`090?n000@00?l01`3o
P005003o00d0oh000P00o`090?n000800?l02@3oP003003o00h0oh001000o`020?n000<00?l06@3o
P009003o00T0oh000P00o`020?n001Sooooo000Foooooa/00?l00P3oP00`003o00@0oh001`00o`05
0?n000800?l0103oP0000`00o`00oh000?n0000;003o0080oh000`00o`020?n000@00?l000<0oh00
003o0000o`000P00o`020?n000L00?l03_oooolP003o0080oh00J000o`0>oooooaL00?l00P3oP00>
003o00/0oh003@00o`020?n00003003o003oP000oh000080oh002@00o`0D0?n001T00?l03P3oP00>
ooooo`80oh000`00o`090?n000@00?l01`3oP005003o00@0oh000P00o`090?n000800?l00`3oP002
003o0080oh000`00o`080?n000<00?l0103oP0000`00o`00oh000?n0000=0?n000D00?l06@3oP006
003o00h0oh006?ooool001Kooooo6`00o`020?n002`00?l00P3oP002003o00@0oh000`00o`090?n0
00800?l0103oP0000`00o`00oh000?n0000;003o0080oh000`00o`020?n000@00?l000<0oh00003o
0000o`000P00o`020?n000L00?l03_oooolP003o0080oh00J000o`0>ooooo`80oh009000o`0<0?n0
00d00?l00P3oP003003o0080oh002@00o`0D0?n000L00?l00P3oP0000`00o`00oh000?n000020?n0
00/00?l03P3oP00>ooooo`80oh001@00o`020?n000800?l00P3oP005003o00T0oh000P00o`0C0?n0
00l00?l02@3oP003003o00T0oh000P00o`020?n000T00?l0303oP002003o00L0oh001P00o`050?n0
00@00?l01@3oP00Hooooo`005_oooolK003o0080oh00;000o`020?n000800?l0103oP003003o00T0
oh000P00o`040?n00003003o003oP000oh0000/00?l00P3oP003003o0080oh001000o`000`3oP000
0?l0003o0002003o0080oh001`00o`0>ooooob000?l00P3oP01X003o00kooooo0P3oP00T003o00`0
oh003@00o`020?n000<00?l00P3oP009003o01@0oh001`00o`020?n00003003o003oP000oh000080
oh002`00o`0>0?n000kooooo0P3oP005003o0080oh000P00o`020?n000D00?l02@3oP002003o01<0
oh003`00o`090?n000<00?l02@3oP002003o0080oh002@00o`0<0?n000800?l01`3oP006003o00D0
oh001000o`050?n001Sooooo000FooooodP00?l00`3oP002003o00@0oh000`00o`020?n000800?l0
0`3oP004003o0080oh000`00o`020?n000/00?l00P3oP003003o0080oh001000o`000`3oP0000?l0
003o0002003o00@0oh001@00o`0>ooooohX00?l03_ooool20?n002@00?l0303oP00M003o00h0oh00
0P00o`040?n000L00?l01`3oP00;003o00h0oh003_ooool20?n000D00?l00P3oP002003o0080oh00
00<00?l00?n0003oP0001`3oP006003o00030?n00000o`000?l00100oh002`00o`0;0?n000D00?l0
0P3oP002003o0080oh0000<00?l00?n0003oP0000P00o`070?n000@00?l05`3oP002003o00L0oh00
1000o`050?n001Sooooo000FooooodP00?l00`3oP002003o00@0oh000`00o`020?n000800?l00`3o
P004003o0080oh000`00o`020?n000/00?l00P3oP003003o0080oh001000o`000`3oP0000?l0003o
0002003o00@0oh001@00o`0>ooooohX00?l03_ooool20?n002@00?l0303oP00M003o00h0oh000P00
o`040?n000L00?l01`3oP00;003o00h0oh003_ooool20?n000D00?l00P3oP002003o0080oh0000<0
0?l00?n0003oP0001`3oP006003o00030?n00000o`000?l00100oh002`00o`0;0?n000D00?l00P3o
P002003o0080oh0000<00?l00?n0003oP0000P00o`070?n000@00?l05`3oP002003o00L0oh001000
o`050?n001Sooooo000Fooooob800?l00P3oP002003o00<0oh007`00o`030?n000800?l0103oP005
003o0080oh000P00o`000`3oP0000?l0003o0007003o0080oh002`00o`020?n00003003o003oP000
oh0000/00?l0103oP005003o00koooooC@00o`020?n003/00?l03_ooool20?n000T00?l00P3oP00C
003o0080oh001000o`000`3oP0000?l0003o00090?n000l00?l000<0oh00003o0000o`002`00o`07
0?n000800?l00`3oP004003o0080oh002@00o`090?n000<00?l00P3oP004003o00h0oh003_ooool7
003o0080oh000P00o`020?n00003003o003oP000oh0000L0oh001P00o`000`3oP0000?l0003o0004
003o00L0oh001000o`000`3oP0000?l0003o0009003o01l0oh0000<00?l00?n0003oP0001000o`05
0?n000800?l00P3oP002003o01D0oh001000o`050?n001Sooooo000Fooooob800?l00P3oP002003o
00<0oh007`00o`030?n000800?l0103oP005003o0080oh000P00o`000`3oP0000?l0003o0007003o
0080oh002`00o`020?n00003003o003oP000oh0000/00?l0103oP005003o00koooooC@00o`020?n0
03/00?l03_ooool20?n000T00?l00P3oP00C003o0080oh001000o`000`3oP0000?l0003o00090?n0
00l00?l000<0oh00003o0000o`002`00o`070?n000800?l00`3oP004003o0080oh002@00o`090?n0
00<00?l00P3oP004003o00h0oh003_ooool7003o0080oh000P00o`020?n00003003o003oP000oh00
00L0oh001P00o`000`3oP0000?l0003o0004003o00L0oh001000o`000`3oP0000?l0003o0009003o
01l0oh0000<00?l00?n0003oP0001000o`050?n000800?l00P3oP002003o01D0oh001000o`050?n0
01Sooooo000Fooooob800?l00P3oP002003o00<0oh007`00o`030?n000800?l00P3oP00U003o0080
oh002`00o`040?n000D00?l03_oooolm003o0080oh003P00o`020?n003/00?l03_ooool20?n000T0
0?l00P3oP00C003o0080oh001000o`000`3oP0000?l0003o00090?n000l00?l000<0oh00003o0000
o`002`00o`070?n000@00?l000<0oh00003o0000o`003@00o`090?n000<00?l00P3oP004003o00h0
oh003_ooool2003o01D0oh000P00o`020?n000800?l000<0oh00003o0000o`001000o`050?n00080
0?l0103oP00<003o00@0oh000P00o`0I0?n00003003o003oP000oh0000@00?l0803oP004003o00D0
oh006?ooool001Kooooo8P00o`020?n000800?l00`3oP00O003o00<0oh000P00o`020?n002D00?l0
0P3oP00;003o00@0oh001@00o`0>ooooocd00?l00P3oP00>003o0080oh00>`00o`0>ooooo`80oh00
2@00o`020?n001<00?l00P3oP004003o00030?n00000o`000?l000T0oh003`00o`000`3oP0000?l0
003o000;003o00L0oh001000o`000`3oP0000?l0003o000=003o00T0oh000`00o`020?n000@00?l0
3P3oP00>ooooo`800?l05@3oP002003o0080oh000P00o`000`3oP0000?l0003o0004003o00D0oh00
0P00o`040?n000`00?l0103oP002003o01T0oh0000<00?l00?n0003oP0001000o`0P0?n000@00?l0
1@3oP00Hooooo`005_ooool@003o0080oh004000o`020?n000800?l00`3oP002003o0080oh006`00
o`000`3oP0000?l0003o0002003o0080oh00<000o`060?n000D00?l03_oooolm003o0080oh000`00
o`020?n000D00?l00P3oP002003o0080oh00>@00o`020?n000kooooo0P3oP009003o0080oh003P00
o`070?n000@00?l000<0oh00003o0000o`000P00o`070?n000l00?l00`3oP007003o00/0oh001000
o`000`3oP0000?l0003o0009003o00d0oh000`00o`020?n000800?l00P3oP003003o00/0oh003_oo
ool2003o01D0oh003`00o`090?n00003003o003oP000oh0000L0oh000P00o`040?n000L00?l0503o
P009003o00`0oh000P00o`0@0?n000800?l01`3oP00Hooooo`005_ooool@003o0080oh002`00o`00
0`3oP0000?l0003o00040?n000800?l000<0oh00003o0000o`007`00o`000`3oP0000?l0003o0002
003o0080oh00;P00o`060?n000L00?l03_oooolm003o0080oh000`00o`020?n000D00?l00P3oP00m
003o0080oh003_ooool20?n001T00?l01`3oP004003o00030?n00000o`000?l000T0oh003`00o`03
0?n000L00?l02`3oP00@003o00h0oh000P00o`060?n000<00?l02`3oP00>ooooo`800?l05@3oP006
003o0180oh0000<00?l00?n0003oP0004P3oP002003o01@0oh002@00o`0<0?n000@00?l05`3oP00H
ooooo`005_ooool@003o0080oh002`00o`000`3oP0000?l0003o00040?n000800?l000<0oh00003o
0000o`007`00o`000`3oP0000?l0003o0002003o0080oh00;P00o`060?n000L00?l03_oooolm003o
0080oh000`00o`020?n000D00?l00P3oP00m003o0080oh003_ooool20?n001T00?l01`3oP004003o
00030?n00000o`000?l000T0oh003`00o`030?n000L00?l02`3oP00@003o00h0oh000P00o`060?n0
00<00?l02`3oP00>ooooo`800?l05@3oP006003o0180oh0000<00?l00?n0003oP0004P3oP002003o
01@0oh002@00o`0<0?n000@00?l05`3oP00Hooooo`005_oooolM003o00030?n00000o`000?l000@0
oh000P00o`000`3oP0000?l0003o0006003o00030?n00000o`000?l000800?l00P3oP002003o0003
0?n00000o`000?l000d00?l000<0oh00003o0000o`00103oP003003o0080oh008000o`020?n000L0
0?l0203oP005003o00kooooo?@00o`020?n000<00?l02@3oP00m003o0080oh003_ooool20?n000T0
0?l00P3oP00>003o00<0oh000P00o`040?n000800?l000<0oh00003o0000o`000P00o`070?n000l0
0?l00`3oP005003o00d0oh004000o`0=0?n000<00?l01P3oP003003o0080oh000P00o`070?n000ko
oooo5`3oP006003o03L0oh001000o`090?n000800?l0303oP002003o00L0oh000P00o`070?n00080
0?l01`3oP00Hooooo`005_oooolM003o00030?n00000o`000?l000@0oh000P00o`000`3oP0000?l0
003o0006003o00030?n00000o`000?l000800?l00P3oP002003o00030?n00000o`000?l000d00?l0
00<0oh00003o0000o`00103oP003003o0080oh008000o`020?n000L00?l0203oP005003o00kooooo
?@00o`020?n000<00?l02@3oP00m003o0080oh003_ooool20?n000T00?l00P3oP00>003o00<0oh00
0P00o`040?n000800?l000<0oh00003o0000o`000P00o`070?n000l00?l00`3oP005003o00d0oh00
4000o`0=0?n000<00?l01P3oP003003o0080oh000P00o`070?n000kooooo5`3oP006003o03L0oh00
1000o`090?n000800?l0303oP002003o00L0oh000P00o`070?n000800?l01`3oP00Hooooo`005_oo
ool>003o0080oh001`00o`020?n000L00?l00P3oP00B003o0080oh004000o`030?n000800?l0103o
P00[003o0080oh0000<00?l00?n0003oP0000P3oP009003o00kooooo@P00o`090?n003l00?l03_oo
ool;003o0080oh003P00o`030?n000800?l0103oP002003o00<0oh000P00o`040?n00003003o003o
P000oh0001000?l00P3oP004003o0180oh003P00o`0;0?n000<00?l01P3oP003003o0080oh000P00
o`070?n000kooooo103oP003003o0100oh001P00o`0G0?n000800?l00P3oP003003o01T0oh000P00
o`0G0?n000L00?l00P3oP004003o00`0oh000P00o`020?n001Sooooo000Fooooo`h00?l00P3oP007
003o0080oh001`00o`020?n001800?l00P3oP00@003o00<0oh000P00o`040?n002/00?l00P3oP000
0`00o`00oh000?n000020?n000T00?l03_oooom2003o00T0oh00?`00o`0>ooooo`/00?l00P3oP00>
003o00<0oh000P00o`040?n000800?l00`3oP002003o00@0oh0000<00?l00?n0003oP0004000o`02
0?n000@00?l04P3oP00>003o00/0oh000`00o`060?n000<00?l00P3oP002003o00L0oh003_ooool4
0?n000<00?l0403oP006003o01L0oh000P00o`020?n000<00?l06@3oP002003o01L0oh001`00o`02
0?n000@00?l0303oP002003o0080oh006?ooool001Kooooo3P00o`020?n003800?l00P3oP002003o
00<0oh000P00o`040?n002000?l00P3oP003003o0080oh001000o`020?n00003003o003oP000oh00
0080oh002@00o`0>oooood800?l02@3oP00o003o00kooooo5P00o`000`3oP0000?l0003o0002003o
00<0oh000P00o`0?0?n001T00?l04P3oP00>003o00/0oh000`00o`060?n000<00?l00P3oP002003o
00L0oh003_ooool40?n000<00?l01`3oP002003o00L0oh001P00o`070?n000<00?l02@3oP002003o
0080oh002`00o`0B0?n000L00?l05@3oP007003o0080oh001P00o`0>0?n001Sooooo000Fooooo`h0
0?l00P3oP00I003o0080oh005`00o`020?n000800?l00`3oP002003o00@0oh008000o`020?n00080
0?l000<0oh00003o0000o`005000o`0>ooooodP00?l00`3oP00o003o00kooooo5P00o`080?n00080
0?l03`3oP00I003o00T0oh0000<00?l00?n0003oP0001P3oP00>003o00/0oh004000o`070?n000ko
oooo1`00o`020?n000800?l03P3oP004003o00030?n00000o`000?l000800?l00P3oP003003o00P0
oh000`00o`020?n000/00?l01`3oP002003o00T0oh001@00o`0G0?n000l00?l000<0oh00003o0000
o`001000o`070?n001Sooooo000Fooooo`h00?l00P3oP00I003o0080oh005`00o`020?n000800?l0
0`3oP002003o00@0oh008000o`020?n000800?l000<0oh00003o0000o`005000o`0>ooooodP00?l0
0`3oP00o003o00kooooo5P00o`080?n000800?l03`3oP00I003o00T0oh0000<00?l00?n0003oP000
1P3oP00>003o00/0oh004000o`070?n000kooooo1`00o`020?n000800?l03P3oP004003o00030?n0
0000o`000?l000800?l00P3oP003003o00P0oh000`00o`020?n000/00?l01`3oP002003o00T0oh00
1@00o`0G0?n000l00?l000<0oh00003o0000o`001000o`070?n001Sooooo000FooooobL00?l0103o
P00G003o0080oh000P00o`020?n000D00?l00P3oP00I003o0080oh004P00o`000`3oP0000?l0003o
000;003o00koooooB000o`030?n000l00?l000<0oh00003o0000o`00;@00o`0>ooooo`T00?l00P3o
P00<003o00L0oh000P00o`0@0?n001P00?l000<0oh00003o0000o`00103oP003003o00P0oh003P00
o`0;0?n000<00?l00P3oP00=003o00D0oh003_ooool;003o0100oh000P00o`070?n000L00?l01@3o
P002003o0080oh001000o`030?n000H00?l01@3oP002003o00T0oh004000o`050?n000800?l00P3o
P00@003o00<0oh001000o`020?n000800?l01@3oP00Hooooo`005_oooolW003o00@0oh005`00o`02
0?n000800?l00P3oP005003o0080oh006@00o`020?n001800?l000<0oh00003o0000o`002`00o`0>
ooooodP00?l00`3oP00?003o00030?n00000o`000?l002d00?l03_ooool9003o0080oh003000o`07
0?n000800?l0403oP00H003o00030?n00000o`000?l000@0oh000`00o`080?n000h00?l02`3oP003
003o0080oh003@00o`050?n000kooooo2`00o`0@0?n000800?l01`3oP007003o00D0oh000P00o`02
0?n000@00?l00`3oP006003o00D0oh000P00o`090?n001000?l01@3oP002003o0080oh004000o`03
0?n000@00?l00P3oP002003o00D0oh006?ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Rooooog;o00009ooo
oomao`0002OoooooLOl0000Wooooog;o00008oooool002;ooooo00?o0000ooooooooool00ooooolF
ool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolF
o`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0>?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`0hoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Go
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo03Sooooo
5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo03Sooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`0hoooo
oaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolG
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l0>?l007lGo`00oaoo001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oo
oolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000o`00Ool007l0>?l007lGo`00oaoo001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolG
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oo
oolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000o`00Ool007l0>?l007lGo`00oaoo001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo
001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lF
oomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolG
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l0>?l007lGo`00oaoo001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oo
oolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0>?oooolGo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0>?oooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`0hoooooaOo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo03Sooooo5ol0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;oooooL_l0000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`005_oooolT0000o`80oh0040000?l20?n001h0003o
0P3oP0050000o`H0oh0030000?l20?n000L0003o103oP00>0000o`koooooRP000?l>ooooohX0003o
3_ooool>0?n00080003o5P3oP0030000o`T0oh000P000?l40?n000<0003o2`3oP0020000ob00oh00
10000?l50?n000<0003o203oP0000`000?l0oh000?n0000;0?n001Sooooo000Fooooob@0003o0P3o
P00@0000o`80oh007P000?l20?n000D0003o1P3oP00<0000o`80oh001`000?l40?n000h0003o3_oo
oon:0000o`koooooRP000?l>ooooo`h0oh000P000?lF0?n000<0003o2@3oP0020000o`@0oh000`00
0?l;0?n00080003o803oP0040000o`D0oh000`000?l80?n000030000o`3oP000oh0000/0oh006?oo
ool001Kooooo90000?l20?n000h0003o1@3oP00H0000o`<0oh0090000?l70?n000@0003o1`3oP00>
ooooohX0003o3_oooon:0000o`kooooo4P3oP0020000o`<0oh000P000?l=0?n000030000o`3oP000
oh0001/0oh001@000?l20?n00080003o1`3oP0020000oc@0oh006?ooool001Kooooo90000?l20?n0
00h0003o1@3oP00H0000o`<0oh0090000?l70?n000@0003o1`3oP00>ooooohX0003o3_oooon:0000
o`kooooo4P3oP0020000o`<0oh000P000?l=0?n000030000o`3oP000oh0001/0oh001@000?l20?n0
0080003o1`3oP0020000oc@0oh006?ooool001Kooooo=0000?l70?n000@0003o0P3oP0070000o`<0
oh001P000?l30?n000H0003o00<0oh000000o`000?l07@000?l30?n000P0003o1@3oP00>ooooohX0
003o3_oooon:0000o`kooooo2@3oP0020000o`D0oh0010000?lP0?n000D0003o203oP00C0000oad0
oh001@000?lD0?n001Sooooo000FooooocH0003o1@3oP00F0000o`<0oh001P000?l00`3oP000003o
0000o`0X0000o`D0oh003_oooon:0000o`koooooRP000?l>ooooo`d0oh001`000?lT0?n000030000
o`3oP000oh000100oh000P000?l90?n00080003o6@3oP0030000o`T0oh0010000?l90?n001Sooooo
000FooooocH0003o1@3oP00F0000o`<0oh001P000?l00`3oP000003o0000o`0X0000o`D0oh003_oo
oon:0000o`koooooRP000?l>ooooo`d0oh001`000?lT0?n000030000o`3oP000oh000100oh000P00
0?l90?n00080003o6@3oP0030000o`T0oh0010000?l90?n001Sooooo000Fooooob80003o0P3oP00^
0000o`80oh00<P000?l40?n000koooooRP000?l>ooooohX0003o3_oooolB0?n00080003o803oP005
0000o`d0oh001@000?lQ0?n000030000o`3oP000oh000100oh000P000?l20?n00080003o1@3oP00H
ooooo`005_oooolR0000o`80oh00;P000?l20?n00380003o103oP00>ooooohX0003o3_oooon:0000
o`kooooo4P3oP0020000ob00oh001@000?l=0?n000D0003o8@3oP0000`000?l0oh000?n0000@0?n0
0080003o0P3oP0020000o`D0oh006?ooool001Kooooo1@000?l20?n006`0003o00<0oh000000o`00
0?l050000?l>ooooohX0003o3_oooon:0000o`kooooo403oP0040000oah0oh0010000?lB0?n000<0
003o2`3oP0040000o`L0oh000P000?lW0?n001Sooooo000Fooooo`D0003o0P3oP01/0000o`030?n0
00000?l0003o01@0003o3_oooon:0000o`koooooRP000?l>oooooa00oh0010000?lN0?n000@0003o
4P3oP0030000o`/0oh0010000?l70?n00080003o9`3oP00Hooooo`005_oooon:0000o`koooooRP00
0?l>ooooohX0003o3_oooolI0?n00080003oK`3oP00Hooooo`005_ooool70000o`80oh00?`000?l0
0`3oP000003o0000o`0]0000o`80oh0040000?l>ooooohX0003o3_oooon:0000o`koooooB03oP000
0`000?l0oh000?n0000[0?n00080003o4P3oP00Hooooo`005_ooool70000o`80oh00?`000?l00`3o
P000003o0000o`0]0000o`80oh0040000?l>ooooohX0003o3_oooon:0000o`koooooB03oP0000`00
0?l0oh000?n0000[0?n00080003o4P3oP00Hooooo`005_oooom80000o`<0oh00>P000?l00`3oP000
003o0000o`020000o`koooooRP000?l>ooooohX0003o3_ooool>0?n00080003o0P3oP0020000od00
oh000P000?lI0?n00080003o6@3oP00Hooooo`005_oooom80000o`<0oh00>P000?l00`3oP000003o
0000o`020000o`koooooRP000?l>ooooohX0003o3_ooool>0?n00080003o0P3oP0020000od00oh00
0P000?lI0?n00080003o6@3oP00Hooooo`005_oooon50000o`030?n000000?l0003o0080003o3_oo
oom=0000o`@0oh00>@000?l>ooooohX0003o3_oooolF0?n000P0003o9P3oP0020000o`/0oh001@00
0?lK0?n000D0003o2@3oP0040000o`L0oh006?ooool001KoooooQ@000?l00`3oP000003o0000o`02
0000o`koooooC@000?l40?n003T0003o3_oooon:0000o`kooooo5P3oP0080000obH0oh000P000?l;
0?n000D0003o6`3oP0050000o`T0oh0010000?l70?n001Sooooo000FooooohX0003o3_oooon:0000
o`koooooRP000?l>oooooa80oh0030000?m/0?n001Sooooo000FooooohX0003o3_oooon:0000o`ko
ooooRP000?l>oooooa80oh0030000?m/0?n001Sooooo000FooooocH0003o0`3oP01A0000o`kooooo
RP000?l>ooooohX0003o3_oooolG0?n000H0003oA`3oP0020000ob@0oh006?ooool001Kooooo4000
0?l20?n002@0003o0`3oP00Z0000o`030?n000000?l0003o00L0003o103oP00I0000o`koooooRP00
0?l>ooooohX0003o3_ooool=0?n000030000o`3oP000oh0000/0oh001`000?l@0?n00080003o1`3o
P0020000o`80oh000P000?m90?n001Sooooo000Foooooa00003o0P3oP00T0000o`<0oh00:P000?l0
0`3oP000003o0000o`070000o`@0oh006@000?l>ooooohX0003o3_oooon:0000o`kooooo3@3oP000
0`000?l0oh000?n0000;0?n000L0003o403oP0020000o`L0oh000P000?l20?n00080003oB@3oP00H
ooooo`005_ooool@0000o`80oh009P000?l00`3oP000003o0000o`0d0000o`@0oh001@000?l40?n0
00h0003o3_oooon:0000o`koooooRP000?l>oooooc80oh000P000?m00?n000@0003o4P3oP00Hoooo
o`005_ooool@0000o`80oh009P000?l00`3oP000003o0000o`0d0000o`@0oh001@000?l40?n000h0
003o3_oooon:0000o`koooooRP000?l>oooooc80oh000P000?m00?n000@0003o4P3oP00Hooooo`00
5_oooom_0000o`@0oh001@000?l40?n000T0003o00<0oh000000o`000?l00P000?l>ooooohX0003o
3_oooon:0000o`kooooo5`3oP0020000o`/0oh000`000?lD0?n000@0003o1@3oP0040000obh0oh00
10000?l@0?n001Sooooo000Fooooofl0003o103oP0050000o`@0oh002@000?l00`3oP000003o0000
o`020000o`koooooRP000?l>ooooohX0003o3_oooolG0?n00080003o2`3oP0030000oa@0oh001000
0?l50?n000@0003o;P3oP0040000oa00oh006?ooool001KoooooK`000?l40?n00100003o1@3oP002
0000o`koooooRP000?l>ooooohX0003o3_ooooli0?n000H0003o1@3oP0020000obh0oh001P000?l@
0?n001Sooooo000Fooooofl0003o103oP00@0000o`D0oh000P000?l>ooooohX0003o3_oooon:0000
o`kooooo>@3oP0060000o`D0oh000P000?l^0?n000H0003o403oP00Hooooo`005_oooolY0000o`@0
oh00EP000?l50?n00080003o3_oooon:0000o`koooooRP000?l>ooooo`/0oh000`000?lf0?n000@0
003o303oP0020000ob80oh000P000?l@0?n001Sooooo000Fooooocd0003o0P3oP01;0000o`kooooo
RP000?l>ooooohX0003o3_ooool;0?n000<0003o0P3oP0020000oe80oh0010000?l@0?n000@0003o
3P3oP00Hooooo`005_oooolm0000o`80oh00B`000?l>ooooohX0003o3_oooon:0000o`kooooo2`3o
P0030000o`80oh000P000?mB0?n000@0003o403oP0040000o`h0oh006?ooool001Kooooo?@000?l2
0?n000L0003o0P3oP0120000o`koooooRP000?l>ooooohX0003o3_ooool=0?n000030000o`3oP000
oh000180oh0010000?lL0?n000H0003o1@3oP0040000obL0oh002@000?l90?n001Sooooo000Foooo
ocd0003o0P3oP0070000o`80oh00@P000?l>ooooohX0003o3_oooon:0000o`kooooo3@3oP0000`00
0?l0oh000?n0000B0?n000@0003o703oP0060000o`D0oh0010000?lW0?n000T0003o2@3oP00Hoooo
o`005_oooom80000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l0=P000?l>ooooohX0
003o3_oooon:0000o`kooooo2`3oP0030000obH0oh000P000?l[0?n00080003o6P3oP0040000o`D0
oh0010000?lHooooo`005_oooom80000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l0
=P000?l>ooooohX0003o3_oooon:0000o`kooooo2`3oP0030000obH0oh000P000?l[0?n00080003o
6P3oP0040000o`D0oh0010000?lHooooo`005_ooool50000o`80oh00@@000?l30?n000H0003o00<0
oh000000o`000?l0=P000?l>ooooohX0003o3_ooool[0000o`80oh00G@000?l>ooooo`d0003o5@3o
P0070000ob@0oh000P000?l^0?n000H0003o0P3oP0050000oaSooooo000Fooooo`D0003o0P3oP011
0000o`<0oh001P000?l00`3oP000003o0000o`0_0000o`80oh001@000?l>ooooohX0003o3_oooon:
0000o`koooooB03oP0000`000?l0oh000?n0000X0?n000030000o`3oP000oh0000L0oh001P000?l7
0?n001Sooooo000Fooooo`D0003o0P3oP0110000o`<0oh001P000?l00`3oP000003o0000o`0_0000
o`80oh001@000?l>ooooohX0003o3_oooon:0000o`koooooB03oP0000`000?l0oh000?n0000X0?n0
00030000o`3oP000oh0000L0oh001P000?l70?n001Sooooo000Fooooo`h0003o0P3oP01c0000o`<0
oh0010000?l>ooooohX0003o3_oooon:0000o`koooooB03oP0000`000?l0oh000?n0000@0?n00080
003o;@3oP00Hooooo`005_ooool>0000o`80oh00L`000?l30?n000@0003o3_oooon:0000o`kooooo
RP000?l>ooooodP0oh0000<0003o0?n0003oP000403oP0020000obd0oh006?ooool001Kooooo3P00
0?l20?n002/0003o1P3oP0140000o`030?n000000?l0003o0080003o3_oooon:0000o`koooooRP00
0?l>oooood80oh000P000?l40?n000030000o`3oP000oh000080003o2@3oP0040000oc00oh006?oo
ool001Kooooo3P000?l20?n002/0003o1P3oP0140000o`030?n000000?l0003o0080003o3_oooon:
0000o`koooooRP000?l>oooood80oh000P000?l40?n000030000o`3oP000oh000080003o2@3oP004
0000oc00oh006?ooool001Kooooo?@000?l20?n004/0003o3_oooon:0000o`koooooRP000?l>oooo
ocP0oh001@000?l50?n00080003o103oP0000`000?l0oh000?n0000o0?n001Sooooo000Fooooocd0
003o0P3oP01;0000o`koooooRP000?l>ooooohX0003o3_oooolh0?n000D0003o1@3oP0020000o`@0
oh0000<0003o0?n0003oP000?`3oP00Hooooo`005_oooon:0000o`koooooRP000?l>ooooohX0003o
3_oooolF0?n000`0003o5P3oP0070000o`L0oh000`000?l]0?n00080003o4P3oP00Hooooo`005_oo
ool=0000o`030?n000000?l0003o07X0003o3_oooon:0000o`koooooRP000?l>ooooo`80003o3P3o
P0060000o`<0oh001@000?lH0?n000T0003o?@3oP0000`000?l0oh000?n0000;0?n001Sooooo000F
ooooo`d0003o00<0oh000000o`000?l0NP000?l>ooooohX0003o3_oooon:0000o`kooooo0P000?l>
0?n000H0003o0`3oP0050000oaP0oh002@000?lm0?n000030000o`3oP000oh0000/0oh006?ooool0
01Kooooo3@000?l00`3oP000003o0000o`0Y0000o`80oh00A0000?l40?n000L0003o3_oooon:0000
o`koooooRP000?l>ooooocd0oh000P000?l90?n000030000o`3oP000oh0003l0oh006?ooool001Ko
oooo3@000?l00`3oP000003o0000o`0Y0000o`80oh00A0000?l40?n000L0003o3_oooon:0000o`ko
ooooRP000?l>ooooocd0oh000P000?l90?n000030000o`3oP000oh0003l0oh006?ooool001Kooooo
P@000?l20?n000L0003o3_oooon:0000o`koooooRP000?l>ooooodP0oh0000<0003o0?n0003oP000
<P3oP0020000o`/0oh006?ooool001KoooooP@000?l20?n000L0003o3_oooon:0000o`koooooRP00
0?l>ooooodP0oh0000<0003o0?n0003oP000<P3oP0020000o`/0oh006?ooool001KoooooP`000?l2
0?n000D0003o3_oooon:0000o`koooooRP000?l>ooooob00oh001P000?lS0?n00080003o:03oP000
0`000?l0oh000?n000070?n00080003o2`3oP00Hooooo`005_oooon30000o`80oh001@000?l>oooo
ohX0003o3_oooon:0000o`kooooo803oP0060000ob<0oh000P000?lX0?n000030000o`3oP000oh00
00L0oh000P000?l;0?n001Sooooo000Fooooodd0003o0P3oP00k0000o`koooooA0000?l50?n00440
003o3_oooon:0000o`kooooo=P3oP0030000oe40oh006?ooool001KoooooC@000?l40?n003T0003o
3_oooom80000o`<0oh00?`000?l>ooooohX0003o3_oooolb0?n00080003o7P3oP0020000obP0oh00
0`000?l;0?n001Sooooo000Fooooodd0003o103oP00i0000o`koooooB0000?l30?n003l0003o3_oo
oon:0000o`kooooo<P3oP0020000oah0oh000P000?lX0?n000<0003o2`3oP00Hooooo`005_oooon:
0000o`koooooRP000?l>ooooohX0003o3_oooom/0?n000030000o`3oP000oh0000/0oh000`000?l=
0?n001Sooooo000FooooohX0003o3_oooon:0000o`koooooRP000?l>ooooof`0oh0000<0003o0?n0
003oP0002`3oP0030000o`d0oh006?ooool001KoooooRP000?l>ooooohX0003o3_oooon:0000o`ko
oooo=P3oP0020000o`L0oh000P000?l`0?n00080003o5`3oP00Hooooo`005_oooon:0000o`kooooo
RP000?l>ooooohX0003o3_oooolf0?n00080003o1`3oP0020000oc00oh000P000?lG0?n001Sooooo
000FooooohX0003o3_oooon:0000o`koooooRP000?l>ooooocl0oh000P000?lC0?n00080003o=03o
P00Hooooo`005_oooon:0000o`koooooRP000?l>ooooohX0003o3_ooool50?n00080003o3`3oP003
0000o`T0oh001`000?l[0?n00080003o803oP0020000oa80oh006?ooool001KoooooRP000?l>oooo
ohX0003o3_oooon:0000o`kooooo1@3oP0020000o`l0oh000`000?l90?n000L0003o:`3oP0020000
ob00oh000P000?lB0?n001Sooooo000FooooohX0003o3_oooon:0000o`koooooRP000?l>ooooo`80
oh001`000?m]0?n00080003o4P3oP00Hooooo`005_oooon:0000o`koooooRP000?l>ooooohX0003o
3_ooool20?n000L0003oK@3oP0020000oa80oh006?ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Rooooog;o
00009ooooomao`0002OoooooLOl0000Wooooog;o00008oooool002;ooooo00?o0000ooooooooool0
7_ooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo01kooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo01kooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo01gooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo01gooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`03ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolFool0023ooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaKoo`008?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5_oo000PoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?lPooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0023ooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`007ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lPoooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
7ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lPooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00
ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l00_l007lGool001oo001o5_l00?lPo`00O`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool001oooooo5_l00?lPooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000Ooooo
oaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool001oooooo5_l00?lPooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o8?oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
01oooooo5_l00?lPooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l0
0?lPooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001E
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0>?l007lFo`00oaoo001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o00;o001o5ooo000Oo`00OaKo003o8?l007l00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`007ooooolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lPooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lPooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3o
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0K_l007l00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooog;o
00009ooooomao`0002OoooooLOl0000Wooooog;o00008oooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool001KoooooK@3o00020000oa/0o`003_oooolR0000o`@0o`006@000?l30?l000H0
003o1`3o000>0000o`80o`000P000?l70?l000/0003o00<0o`000000o`000?l00P000?l70?l000/0
003o3_oooon:0000o`kooooo1`000?l70?l002@0003o0P3o00040000o`<0o`000P000?l20?l00080
003o0`3o000B0000o`/0o`002`000?lL0?l00080003o6?ooool001KoooooK@3o00020000oa/0o`00
3_oooolR0000o`@0o`006@000?l30?l000H0003o1`3o000>0000o`80o`000P000?l70?l000/0003o
00<0o`000000o`000?l00P000?l70?l000/0003o3_oooon:0000o`kooooo1`000?l70?l002@0003o
0P3o00040000o`<0o`000P000?l20?l00080003o0`3o000B0000o`/0o`002`000?lL0?l00080003o
6?ooool001Kooooo<P3o00040000oe@0o`003_oooolR0000o`@0o`006@000?l30?l00080003o2`3o
000>0000o`80o`000P000?l70?l000T0003o1@3o00020000o`80o`000P000?l30?l000/0003o3_oo
oon:0000o`kooooo0P3o00070000o`D0o`002`000?l20?l000/0003o0`3o000?0000o`h0o`004P00
0?l;0?l000L0003o7P3o00020000oaSooooo000Foooooc80o`0010000?mD0?l000kooooo8P000?l4
0?l001T0003o0`3o00020000o`/0o`003P000?l20?l00080003o1`3o00090000o`D0o`000P000?l2
0?l00080003o0`3o000;0000o`koooooRP000?l>ooooo`80o`001`000?l50?l000/0003o0P3o000;
0000o`<0o`003`000?l>0?l00180003o2`3o00070000oah0o`000P000?lHooooo`005_oooon:0?l0
00kooooo?`000?l>0?l001@0003o1`3o00090000o`D0o`0050000?l>ooooohX0003o3_ooool90000
o`L0o`0010000?l90?l000T0003o0`3o00020000o`/0o`000P000?l>0?l00180003o<03o00020000
oaSooooo000FooooohX0o`003_oooom10000o`D0o`0040000?l40?l000L0003o0P3o00000`000?l0
o`000?l000020?l000T0003o0P3o000>0000o`80o`000P000?l30?l00080003o3_oooom?0000o`80
o`005`000?l20?l00080003o00<0o`000000o`000?l06`000?l>ooooo`80o`001`000?l;0?l00080
003o1`3o00090000o`<0o`0010000?l90?l000<0003o2@3o000=0000o`<0o`001P000?l70?l000D0
003o903o00020000oaSooooo000FooooohX0o`003_oooom10000o`D0o`0040000?l40?l000L0003o
0P3o00000`000?l0o`000?l000020?l000T0003o0P3o000>0000o`80o`000P000?l30?l00080003o
3_oooom?0000o`80o`005`000?l20?l00080003o00<0o`000000o`000?l06`000?l>ooooo`80o`00
1`000?l;0?l00080003o1`3o00090000o`<0o`0010000?l90?l000<0003o2@3o000=0000o`<0o`00
1P000?l70?l000D0003o903o00020000oaSooooo000FooooohX0o`003_oooon:0000o`koooooB`00
0?l20?l00080003o0P3o00050000o`L0o`002`000?l20?l00200003o3_ooool20?l000L0003o2@3o
00040000o`L0o`001`000?l20?l000030000o`3o0000o`0000@0003o1`3o00050000o`d0o`002@00
0?l30?l000H0003o1@3o00070000ob@0o`000P000?lHooooo`005_oooon:0?l000koooooRP000?l>
oooood/0003o0P3o00020000o`80o`001@000?l70?l000/0003o0P3o000P0000o`kooooo0P3o0007
0000o`T0o`0010000?l70?l000L0003o0P3o00000`000?l0o`000?l000040000o`L0o`001@000?l=
0?l000T0003o0`3o00060000o`D0o`001`000?lT0?l00080003o6?ooool001KoooooRP3o000>oooo
ohX0003o3_oooom;0000o`80o`002@000?l20?l00380003o3_ooool50?l00080003o2`3o00050000
o`80o`003P000?l60?l00080003o5`3o00090000o`D0o`004P000?l90?l00080003o0`3o00020000
oa00o`0010000?lHooooo`005_oooon:0?l000koooooRP000?l>oooood/0003o0P3o00090000o`80
o`00<P000?l>ooooo`D0o`000P000?l;0?l000D0003o0P3o000>0000o`H0o`000P000?lG0?l000T0
003o1@3o000B0000o`T0o`000P000?l30?l00080003o403o00040000oaSooooo000FooooohX0o`00
3_oooolR0000o`80o`00IP000?l>oooood/0003o0P3o000m0000o`kooooo2`3o00020000o`<0o`00
0P000?l70?l000d0003o1`3o000;0000ob00o`0040000?l<0?l00080003o1`3o00020000o`80o`00
2@000?lHooooo`005_oooon30?l00080003o1@3o000>oooooh40003o0P3o00070000o`koooooB`00
0?l40?l003/0003o3_ooool20000o`L0o`003@000?l30?l000h0003o1P3o000;0000oa00o`000`00
0?l20?l00080003o2@3o00070000o`@0o`000`000?l=0?l001L0003o6?ooool001KoooooP`3o0002
0000o`D0o`003_oooon10000o`80o`001`000?l>oooood/0003o103o000k0000o`kooooo0P000?l7
0?l000d0003o0`3o000>0000o`H0o`002`000?l@0?l000<0003o0P3o00020000o`T0o`001`000?l4
0?l000<0003o3@3o000G0000oaSooooo000FooooohX0o`003_oooolR0000o`80o`00G@000?l20?l0
00L0003o3_oooom;0000o`80o`00?@000?l>ooooo`80003o1`3o000;0000o`D0o`001@000?l60?l0
0080003o1`3o000;0000oa00o`001`000?l90?l000D0003o1P3o00030000o`@0o`000P000?l30?l0
0080003o0`3o000=0000o`@0o`0000<0003o0?l0003o00000P3o000Hooooo`005_oooon:0?l000ko
oooo8P000?l20?l005d0003o0P3o00070000o`koooooB`000?l20?l003d0003o3_ooool20000o`L0
o`002`000?l50?l000D0003o1P3o00020000o`L0o`002`000?l@0?l000L0003o2@3o00050000o`H0
o`000`000?l40?l00080003o0`3o00020000o`<0o`003@000?l40?l000030000o`3o0000o`000080
o`006?ooool001KoooooRP3o000>oooood/0003o1P3o000^0000o`@0o`001`000?l>ooooohX0003o
3_ooool20000o`L0o`003P000?l20?l000D0003o0P3o00020000o`80o`000P000?l70?l000`0003o
0P3o00020000o`T0o`002@000?l90?l000<0003o203o000N0000o`@0o`0000<0003o0?l0003o0000
0P3o000Hooooo`005_oooon:0?l000koooooB`000?l60?l002h0003o103o00070000o`koooooRP00
0?l>ooooo`80003o1`3o000>0000o`80o`001@000?l20?l00080003o0P3o00020000o`L0o`003000
0?l20?l00080003o2@3o00090000o`T0o`000`000?l80?l001h0003o103o00000`000?l0o`000?l0
00020?l001Sooooo000Foooooc@0o`000P000?mD0?l000kooooo@P000?l70?l00080003o1P3o000/
0000o`H0o`001`000?l>ooooohX0003o3_ooool40000o`D0o`005@000?l20?l00080003o3@3o0000
0`000?l0o`000?l000020000oa@0o`002@000?l50?l00100003o0P3o00040000o`030?l000000?l0
003o0180003o0P3o00030000o`@0o`006?ooool001Kooooo=03o00020000oe@0o`003_oooom20000
o`L0o`000P000?l60?l002`0003o1P3o00070000o`koooooRP000?l>ooooo`@0003o1@3o000E0000
o`80o`000P000?l=0?l000030000o`3o0000o`000080003o503o00090000o`D0o`0040000?l20?l0
00@0003o00<0o`000000o`000?l04P000?l20?l000<0003o103o000Hooooo`005_oooon:0?l000ko
oooo@P000?l?0?l002`0003o203o00050000o`koooooRP000?l>ooooo`@0003o2@3o000G0000o`D0
o`000P000?l70?l00080003o2`3o00020000o`X0o`001`000?l20?l001P0003o00<0o`000000o`00
0?l01`3o000@0000o`@0o`006?ooool001KoooooRP3o000>oooood80003o3`3o000/0000o`H0o`00
1`000?l>ooooohX0003o3_ooool40000o`X0o`002`000?l40?l000X0003o0P3o00020000o`@0o`00
00<0003o0?l0003o000010000?l70?l000D0003o2@3o00020000o`80o`000`000?l60?l000`0003o
1P3o00050000o`T0o`0040000?l20?l001Sooooo000FooooohX0o`003_oooom20000o`l0o`00;000
0?l60?l000L0003o3_oooon:0000o`kooooo10000?l:0?l000/0003o103o000:0000o`80o`000P00
0?l40?l000030000o`3o0000o`0000@0003o1`3o00050000o`T0o`000P000?l20?l000<0003o1P3o
000<0000o`H0o`001@000?l90?l00100003o0P3o000Hooooo`005_oooon:0?l000kooooo@P000?l;
0?l00080003o0P3o00050000o`D0o`009P000?l20?l000L0003o3_oooon:0000o`kooooo0P000?l;
0?l000D0003o2`3o00090000o`030?l000000?l0003o0080003o103o00000`000?l0o`000?l00004
0000o`L0o`001@000?l=0?l000<0003o1P3o000;0000o`<0o`000P000?l20?l00080003o1@3o0003
0000o`@0o`000P000?l20?l000T0003o00<0o`000000o`000?l00P3o000Hooooo`005_oooon:0?l0
00kooooo@P000?l;0?l00080003o0P3o00050000o`D0o`009P000?l20?l000L0003o3_oooon:0000
o`kooooo0P000?l;0?l000D0003o2`3o00090000o`030?l000000?l0003o0080003o103o00000`00
0?l0o`000?l000040000o`L0o`001@000?l=0?l000<0003o1P3o000;0000o`<0o`000P000?l20?l0
0080003o1@3o00030000o`@0o`000P000?l20?l000T0003o00<0o`000000o`000?l00P3o000Hoooo
o`005_oooon:0?l000koooooAP000?l;0?l000D0003o0P3o00020000o`030?l000000?l0003o02@0
003o0P3o00070000o`koooooRP000?l>ooooo`80003o2`3o00050000o`L0o`000P000?l20?l000<0
003o0P3o00090000o`L0o`000P000?l90?l000D0003o3@3o00050000o`@0o`001`000?l70?l00080
003o0P3o00020000o`<0o`001`000?l70?l00080003o0P3o00020000o`<0o`000P000?l20?l001So
oooo000FooooohX0o`003_oooom60000o`/0o`001@000?l20?l00080003o00<0o`000000o`000?l0
90000?l20?l000L0003o3_oooon:0000o`kooooo0P000?l;0?l000D0003o1`3o00020000o`80o`00
0`000?l20?l000T0003o1`3o00020000o`T0o`001@000?l=0?l000D0003o103o00070000o`L0o`00
0P000?l20?l00080003o0`3o00070000o`L0o`000P000?l20?l00080003o0`3o00020000o`80o`00
6?ooool001Kooooo9`3o00020000of40o`003_oooom;0000o`H0o`001@000?l20?l002T0003o0P3o
00070000o`koooooRP000?l>ooooo`80003o2@3o00050000o`T0o`001`000?l20?l000T0003o4P3o
00070000o`L0o`0010000?l20?l000030000o`3o0000o`0000@0o`001`000?l70?l00100003o103o
00090000o`<0o`0010000?lHooooo`005_oooolW0?l00080003oH@3o000>oooood/0003o1P3o0005
0000o`80o`00:@000?l20?l000L0003o3_oooon:0000o`kooooo0P000?l90?l000D0003o2@3o0007
0000o`80o`002@000?lB0?l000L0003o1`3o00040000o`80o`0000<0003o0?l0003o0000103o0007
0000o`L0o`0040000?l40?l000T0003o0`3o00040000oaSooooo000FooooobL0o`000P000?mQ0?l0
00kooooo@P000?l70?l000@0003o103o00050000o`80o`00:@000?l40?l000D0003o3_oooon10000
o`80o`001`000?l>ooooo`80003o1`3o00050000o`P0o`002P000?l60?l000D0003o3P3o000=0000
o`80o`0000<0003o0?l0003o000010000?l70?l000T0003o2`3o000>0000o`80o`002@000?l30?l0
00@0003o6?ooool001KoooooRP3o000>oooood80003o3`3o000`0000o`@0o`001@000?l>oooooh40
003o0P3o00070000o`kooooo0P000?l50?l000@0003o0P3o00000`000?l0o`000?l000020?l000h0
003o1`3o00040000oa00o`002`000?l20?l000030000o`3o0000o`0000@0003o1`3o00090000o`80
o`000P000?l:0?l001P0003o00<0o`000000o`000?l00P000?lHooooo`005_oooon:0?l000kooooo
@P000?l?0?l00300003o103o00050000o`koooooP@000?l20?l000L0003o3_ooool20000o`D0o`00
10000?l20?l000030000o`3o0000o`000080o`003P000?l70?l000@0003o403o000;0000o`80o`00
00<0003o0?l0003o000010000?l70?l000T0003o0P3o00020000o`X0o`0060000?l00`3o0000003o
0000o`020000oaSooooo000FooooohX0o`003_oooom20000o`80o`000P000?l;0?l000L0003o1`3o
000T0000o`80o`001@000?l>ooooohX0003o3_ooool50000o`@0o`000P000?l70?l00100003o2`3o
00020000o`X0o`002`000?l40?l000030000o`3o0000o`0000H0003o1@3o00090000o`80o`000P00
0?l30?l000H0003o00<0o`000000o`000?l00P3o000G0000o`80o`006?ooool001KoooooRP3o000>
oooood80003o0P3o00020000o`/0o`001`000?l70?l002@0003o0P3o00050000o`koooooRP000?l>
ooooo`D0003o103o00020000o`L0o`0040000?l;0?l00080003o2P3o000;0000o`@0o`0000<0003o
0?l0003o00001P000?l50?l000T0003o0P3o00020000o`<0o`001P000?l00`3o0000003o0000o`02
0?l001L0003o0P3o000Hooooo`005_oooon10?l00080003o1`3o000>ooooodP0003o00<0o`000000
o`000?l03@000?l50?l002H0003o0P3o00050000o`koooooRP000?l>ooooo`/0003o2`3o000@0000
o`D0o`001@000?l;0?l000@0003o303o000H0000o`L0o`000P000?l30?l00080003o0P3o000C0000
o`@0o`006?ooool001KoooooP@3o00020000o`L0o`003_oooom80000o`030?l000000?l0003o00d0
003o1@3o000V0000o`80o`001@000?l>ooooohX0003o3_ooool;0000o`/0o`0040000?l50?l000D0
003o2`3o00040000o``0o`0060000?l70?l00080003o0`3o00020000o`80o`004`000?l40?l001So
oooo000Foooooh40o`000P000?l70?l000koooooF`000?l20?l002H0003o0P3o00050000o`kooooo
C`000?l20?l003T0003o3_ooool>0000o`P0o`005`000?l90?l00080003o0`3o00040000o``0o`00
7@000?l50?l001P0003o1@3o000Hooooo`005_oooon:0?l000koooooC`000?l20?l000X0003o0P3o
000]0000o`koooooC@000?l40?l003T0003o3_ooool90000o`80o`001@000?l70?l000T0003o4P3o
00060000o`030?l000000?l0003o00@0003o0P3o00000`000?l0o`000?l000070?l000H0003o00<0
o`000000o`000?l04P000?l90?l00080003o0P3o000B0000o`<0o`000P000?lHooooo`005_oooon:
0?l000koooooC`000?l20?l000X0003o0P3o000]0000o`koooooC@000?l40?l003T0003o3_ooool9
0000o`80o`001@000?l70?l000T0003o4P3o00060000o`030?l000000?l0003o00@0003o0P3o0000
0`000?l0o`000?l000070?l000H0003o00<0o`000000o`000?l04P000?l90?l00080003o0P3o000B
0000o`<0o`000P000?lHooooo`005_oooon:0?l000kooooo>@000?l20?l00080003o0P3o000@0000
o`80o`00>@000?l>ooooohX0003o3_ooool50000o`80o`000P000?l20?l000D0003o1`3o00070000
o`@0o`000P000?l30?l000@0003o103o00000`000?l0o`000?l0000F0000o``0o`0050000?l;0?l0
00h0003o2@3o000Hooooo`005_oooon:0?l000kooooo>@000?l20?l00080003o0P3o000@0000o`80
o`00>@000?l>ooooohX0003o3_ooool50000o`80o`000P000?l20?l000D0003o1`3o00070000o`@0
o`000P000?l30?l000@0003o103o00000`000?l0o`000?l0000F0000o``0o`0050000?l;0?l000h0
003o2@3o000Hooooo`005_oooon:0?l000kooooo>@000?l60?l000`0003o2@3o00040000o`80o`00
<0000?l>ooooohX0003o3_ooool20?l000<0003o203o00050000o`D0o`003@000?l30?l000P0003o
1@3o00050000o`@0o`000P000?l20?l000L0003o1@3o00070000o`80o`004P000?l;0?l000030000
o`3o0000o`0000T0003o2`3o000Hooooo`005_oooon:0?l000kooooo>@000?l60?l000`0003o2@3o
00040000o`80o`00<0000?l>ooooohX0003o3_ooool20?l000<0003o203o00050000o`D0o`003@00
0?l30?l000P0003o1@3o00050000o`@0o`000P000?l20?l000L0003o1@3o00070000o`80o`004P00
0?l;0?l000030000o`3o0000o`0000T0003o2`3o000Hooooo`005_oooon:0?l000kooooo>@000?l8
0?l000X0003o1`3o00060000o`80o`00<0000?l>ooooohX0003o3_ooool=0?l000L0003o0`3o0004
0000o`80o`001`000?l20?l000030000o`3o0000o`0000L0003o0P3o00040000o`80o`0000<0003o
0?l0003o00002@3o00020000o`h0o`001`000?l60?l000L0003o3P3o00070000o`/0o`000P000?lH
ooooo`005_oooon:0?l000kooooo>@000?l80?l000X0003o1`3o00060000o`80o`00<0000?l>oooo
ohX0003o3_ooool=0?l000L0003o0`3o00040000o`80o`001`000?l20?l000030000o`3o0000o`00
00L0003o0P3o00040000o`80o`0000<0003o0?l0003o00002@3o00020000o`h0o`001`000?l60?l0
00L0003o3P3o00070000o`/0o`000P000?lHooooo`005_oooon:0?l000kooooo>@000?l60?l000D0
003o1`3o00020000o`@0o`00>@000?l>ooooohX0003o3_ooool=0?l000T0003o00<0o`000000o`00
0?l03P000?l20?l001H0003o1@3o00020000o`80o`0000<0003o0?l0003o00002`3o00020000o`T0
o`001@000?l@0?l000L0003o2`3o00020000oaSooooo000FooooohX0o`003_oooom20000o`d0o`00
2`000?l00`3o0000003o0000o`0]0000o`koooooRP000?l>ooooo`h0o`006@000?l20?l000@0003o
0P3o000B0000o`<0o`001`000?l40?l00080003o403o00050000oa80o`001@000?l40?l00080003o
0P3o00000`000?l0o`000?l000020?l001Sooooo000FooooohX0o`003_oooom20000o`d0o`002`00
0?l00`3o0000003o0000o`0]0000o`koooooRP000?l>ooooo`h0o`006@000?l20?l000@0003o0P3o
000B0000o`<0o`001`000?l40?l00080003o403o00050000oa80o`001@000?l40?l00080003o0P3o
00000`000?l0o`000?l000020?l001Sooooo000FooooohX0o`003_oooom40000o`D0o`000P000?l4
0?l003/0003o3_oooon:0000o`kooooo103o00000`000?l0o`000?l000070?l000/0003o1`3o0007
0000o`80o`0010000?l20?l000h0003o0P3o00020000o`<0o`002@000?l20?l00080003o403o0002
0000oaL0o`000P000?l:0?l000@0003o6?ooool001KoooooRP3o000>oooood@0003o1@3o00020000
o`@0o`00>`000?l>ooooohX0003o3_ooool40?l000030000o`3o0000o`0000L0o`002`000?l70?l0
00L0003o0P3o00040000o`80o`003P000?l20?l00080003o0`3o00090000o`80o`000P000?l@0?l0
0080003o5`3o00020000o`X0o`0010000?lHooooo`005_oooom20?l00080003oAP3o000>ooooodP0
003o1`3o000k0000o`koooooRP000?l>oooooa00o`003@000?l00`3o0000003o0000o`070000o`P0
o`003P000?l20?l001T0003o2@3o00020000oaL0o`000P000?l90?l000<0003o0P3o000Hooooo`00
5_oooom20?l00080003oAP3o000>ooooodP0003o1`3o000k0000o`koooooRP000?l>oooooa00o`00
3@000?l00`3o0000003o0000o`070000o`P0o`003P000?l20?l001T0003o2@3o00020000oaL0o`00
0P000?l90?l000<0003o0P3o000Hooooo`005_oooon:0?l000koooooB0000?l00`3o0000003o0000
o`0o0000o`koooooRP000?l>ooooo`@0003o2@3o000@0000o`030?l000000?l0003o00L0003o1P3o
000@0000o`80o`000P000?l30?l00080003o1`3o000;0000o`T0o`000P000?l<0?l00080003o2@3o
00020000o`D0o`0010000?l00`3o0000003o0000o`020000oaSooooo000FooooohX0o`003_oooom8
0000o`030?l000000?l0003o03l0003o3_oooon:0000o`kooooo10000?l90?l00100003o00<0o`00
0000o`000?l01`000?l60?l00100003o0P3o00020000o`<0o`000P000?l70?l000/0003o2@3o0002
0000o``0o`000P000?l90?l00080003o1@3o00040000o`030?l000000?l0003o0080003o6?ooool0
01KoooooO03o00050000o`T0o`003_oooolk0000o`80o`00C@000?l>ooooohX0003o3_ooool90?l0
00/0003o0P3o000C0000o`@0o`0050000?l<0?l000D0003o7@3o00040000o`h0o`002@000?lHoooo
o`005_oooomo0?l00080003o2@3o000>ooooohX0003o3_oooon:0000o`kooooo1`3o000P0000o`P0
o`003P000?l@0?l000D0003o6`3o00060000o`X0o`003@000?lHooooo`005_oooomo0?l00080003o
2@3o000>ooooohX0003o3_oooon:0000o`kooooo1`3o000P0000o`P0o`003P000?l@0?l000D0003o
6`3o00060000o`X0o`003@000?lHooooo`005_oooon:0?l000kooooo>`000?l20?l000`0003o0P3o
000o0000o`koooooJ0000?l20?l00200003o3_ooool20?l00100003o0P3o000C0000o`/0o`002@00
0?lb0?l000H0003o2P3o00020000o`80o`0010000?l50?l001Sooooo000FooooohX0o`003_oooolk
0000o`80o`0030000?l20?l003l0003o3_oooomX0000o`80o`0080000?l>ooooo`80o`0040000?l2
0?l001<0003o2`3o00090000oc80o`001P000?l:0?l00080003o0P3o00040000o`D0o`006?ooool0
01Kooooo0P000?n80?l000koooooB0000?l30?l003l0003o3_oooon:0000o`kooooo103o000U0000
o`T0o`002@000?la0?l000P0003o3@3o00040000o`D0o`006?ooool001Kooooo0P000?n80?l000ko
ooooB0000?l30?l003l0003o3_oooon:0000o`kooooo103o000U0000o`T0o`002@000?la0?l000P0
003o3@3o00040000o`D0o`006?ooool001Kooooo0P000?n80?l000kooooo?@000?l40?l000L0003o
0`3o00020000o`80o`00>`000?l>ooooohX0003o3_ooool=0000o`030?l000000?l0003o01T0003o
2@3o00020000o`80o`001@000?lI0?l00080003o1`3o00040000o``0o`002@000?lD0?l001Sooooo
000FooooohX0o`003_oooolo0000o`80o`001`000?l70?l003/0003o3_oooon:0000o`kooooo3@00
0?l00`3o0000003o0000o`0M0000o`L0o`000P000?l50?l00080003o2`3o00000`000?l0o`000?l0
00090?l000d0003o303o000;0000o`d0o`0000<0003o0?l0003o00000P3o000Hooooo`005_oooon:
0?l000kooooo?`000?l20?l000L0003o1`3o000k0000o`koooooRP000?l>ooooo`d0003o00<0o`00
0000o`000?l07@000?l70?l00080003o1@3o00020000o`/0o`0000<0003o0?l0003o00002@3o000=
0000o``0o`002`000?l=0?l000030000o`3o0000o`000080o`006?ooool001KoooooRP3o000>oooo
ocl0003o1`3o00030000o`80o`000P000?l20?l00300003o0P3o00090000o`koooooRP000?l>oooo
o`d0003o1@3o00050000o`@0o`000`000?l20?l00080003o103o00000`000?l0o`000?l000020?l0
0080003o2`3o00070000o`L0o`001`000?l20?l00080003o0`3o000=0000oa80o`002@000?l90?l0
00030000o`3o0000o`000080o`006?ooool001KoooooRP3o000>ooooocl0003o1`3o00030000o`80
o`000P000?l20?l00300003o0P3o00090000o`koooooRP000?l>ooooo`d0003o1@3o00050000o`@0
o`000`000?l20?l00080003o103o00000`000?l0o`000?l000020?l00080003o2`3o00070000o`L0
o`001`000?l20?l00080003o0`3o000=0000oa80o`002@000?l90?l000030000o`3o0000o`000080
o`006?ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000Woooo
og7o00009?ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo
003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKo
o`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaOo
003o1?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool003[ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKo
o`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolFool003[ooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o
00;o001o5_oo000jo`00OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o
00;o001o5ooo000jo`00OaKoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o
05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool003[o
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[o
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o05;o001o5oooO`04o`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l00_l007lGool005Co001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1Co`00OaKoogl01?l007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;o
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o05;o001o5oooO`04o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l00_l007lGool005Co001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKo
ogl01?l007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool0
05Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo
02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o
05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000W
ooooog7o00009?ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool001KoooooRP3o000>
ooooob80oh000P3o000I0?n000D0o`002@3oP0020?l00080oh001@3o00070?n000@0o`000P3oP007
0?l000T0oh000P3o000>0?n000@0o`001@3oP00>ooooo`D0o`002@3oP0060?l000<0oh003@3o0007
0?n000h0o`000P3oP00Y0?l00080oh003@3o00070?n00100o`003_oooomK0?n00080o`001`3oP002
0?l00080oh000P3o000>0?n000L0o`002`3oP00Hooooo`005_oooon:0?l000kooooo8P3oP0020?l0
01T0oh001@3o00090?n00080o`000P3oP0050?l000L0oh00103o00020?n000L0o`002@3oP0020?l0
00h0oh00103o00050?n000kooooo1@3o00090?n000H0o`000`3oP00=0?l000L0oh003P3o00020?n0
02T0o`000P3oP00=0?l000L0oh00403o000>oooooe/0oh000P3o00070?n00080o`000P3oP0020?l0
00h0oh001`3o000;0?n001Sooooo000FooooohX0o`003_oooolR0?n00080o`006@3oP0050?l000T0
oh000P3o00020?n000D0o`003@3oP0030?l000d0oh000P3o000G0?n000kooooo1@3o00080?n000L0
o`000`3oP00=0?l000D0oh001`3o00060?n00080o`000`3oP00Y0?l00080oh003@3o00050?n000d0
o`0000<0oh000?l0003o00000P3o000>oooooe/0oh000P3o000;0?n000@0o`003P3oP0050?l000/0
oh006?ooool001KoooooRP3o000>ooooob80oh000P3o000I0?n000D0o`002@3oP0020?l00080oh00
1@3o000=0?n000<0o`003@3oP0020?l001L0oh003_ooool50?l000P0oh001`3o00030?n000d0o`00
1@3oP0070?l000H0oh000P3o00030?n002T0o`000P3oP00=0?l000D0oh003@3o00000`3oP000o`00
0?l000020?l000koooooF`3oP0020?l000/0oh00103o000>0?n000D0o`002`3oP00Hooooo`005_oo
oon:0?l000kooooo8P3oP0020?l001T0oh001@3o00090?n00080o`000P3oP0050?l000L0oh000P3o
00040?n000D0o`002`3oP0020?l001L0oh003_ooool50?l000P0oh002@3o00000`3oP000o`000?l0
000=0?l000D0oh001@3o00060?n000<0o`000P3oP00Y0?l00080oh003@3o00050?n000d0o`0000<0
oh000?l0003o00000P3o000>ooooofP0oh001@3o000;0?n000L0o`002`3oP00Hooooo`005_oooomc
0?l000<0oh00503o000>ooooob80oh000P3o000G0?n000T0o`001`3oP0090?l00080oh000P3o0003
0?n000/0o`002@3oP0040?l000h0oh000P3o00070?n000kooooo1@3o00080?n000L0o`000`3oP00H
0?l000T0oh005@3o00020?n001/0o`000P3oP0080?l00080oh003`3o00050?n000koooooJ03oP004
0?l000`0oh001`3o000;0?n001Sooooo000Fooooog<0o`000`3oP00D0?l000kooooo8P3oP0020?l0
01L0oh002@3o00070?n000T0o`000P3oP0020?l000<0oh002`3o00090?n000@0o`003P3oP0020?l0
00L0oh003_ooool50?l000P0oh001`3o00030?n001P0o`002@3oP00E0?l00080oh006`3o00020?n0
00P0o`000P3oP00?0?l000D0oh003_oooomX0?n000@0o`00303oP0070?l000/0oh006?ooool001Ko
ooooL`3o00030?n001@0o`003_ooool20?l00200oh000P3o000G0?n000T0o`001@3oP00;0?l00080
oh000P3o00030?n000T0o`002@3oP0060?l000X0oh000P3o00020?n000@0o`001@3oP00>ooooo`D0
o`00203oP0090?l000<0oh005P3o00090?n001<0o`000P3oP00M0?l00080oh00203o00040?n00100
o`000P3oP00>ooooofX0oh000P3o000<0?n000@0o`003P3oP00Hooooo`005_oooomc0?l000<0oh00
503o000>ooooo`80o`00803oP0020?l001L0oh002@3o00050?n000/0o`000P3oP0020?l000<0oh00
2@3o00090?n000H0o`002P3oP0020?l00080oh00103o00050?n000kooooo1@3o00080?n000T0o`00
0`3oP00F0?l000T0oh004`3o00020?n001d0o`000P3oP0080?l000@0oh00403o00020?n000kooooo
JP3oP0020?l000`0oh00103o000>0?n001Sooooo000FooooohX0o`003_oooolF0?n000<0o`002@3o
P0020?l001L0oh003@3o00000`3oP000o`000?l000090?l00080oh00403o00070?n000H0o`005`3o
P00>ooooo`D0o`00203oP0070?l000D0oh005`3o00060?n001D0o`00103oP00U0?l000P0oh003P3o
000>ooooogH0oh001P3o000>0?n001Sooooo000FooooohX0o`003_oooolF0?n000<0o`002@3oP002
0?l001L0oh003@3o00000`3oP000o`000?l000090?l00080oh00403o00070?n000H0o`005`3oP00>
ooooo`D0o`00203oP0070?l000D0oh005`3o00060?n001D0o`00103oP00U0?l000P0oh003P3o000>
ooooogH0oh001P3o000>0?n001Sooooo000FooooohX0o`003_oooolF0?n000D0o`001`3oP0020?l0
01L0oh002@3o00020?n00080o`0000<0oh000?l0003o00006`3o00070?n000H0o`005`3oP00>oooo
o`@0o`00303oP0060?l000<0oh005`3o00060?n001L0o`000P3oP00U0?l000d0oh002@3o000>oooo
ohX0oh006?ooool001KoooooR03o00020?n000kooooo5P3oP0050?l000<0oh001P3o000G0?n000T0
o`001@3oP00H0?l00080oh000`3o00090?n000@0o`005`3oP00>ooooo`@0o`00303oP0060?l000D0
oh003P3o00020?n000D0o`001P3oP00G0?l000@0oh008P3o000<0?n000/0o`003_ooool40?n00003
0?l0003oP000oh0008<0oh006?ooool001KoooooR03o00020?n000kooooo5P3oP0050?l000<0oh00
1P3o000G0?n000T0o`001@3oP00H0?l00080oh000`3o00090?n000@0o`005`3oP00>ooooo`@0o`00
303oP0060?l000D0oh003P3o00020?n000D0o`001P3oP00G0?l000@0oh008P3o000<0?n000/0o`00
3_ooool40?n000030?l0003oP000oh0008<0oh006?ooool001KoooooRP3o000>ooooocd0oh001`3o
00050?n001@0o`000P3oP0090?l000T0oh000P3o000:0?n00080o`000P3oP0050?l000@0oh003_oo
ool70?l000@0oh000`3o000=0?n000h0o`000P3oP0050?l000H0oh005`3o00040?n00200o`002@3o
P00@0?l000koooooRP3oP00Hooooo`005_oooon:0?l000kooooo?@3oP0070?l000D0oh00503o0002
0?n000T0o`002@3oP0020?l000X0oh000P3o00020?n000D0o`00103oP00>ooooo`L0o`00103oP003
0?l000d0oh003P3o00020?n000D0o`001P3oP00G0?l000@0oh00803o00090?n00100o`003_oooon:
0?n001Sooooo000Foooooh<0o`000P3oP0050?l000kooooo?@3oP0050?l000L0oh00503o00040?n0
00D0o`005P3oP00<0?l00080oh003_ooool70?l000@0oh000P3o000>0?n001@0o`001@3oP00I0?l0
00D0oh007`3o00090?n00080o`0000<0oh000?l0003o00002`3o000>ooooohX0oh006?ooool001Ko
ooooP`3o00020?n000D0o`003_oooolm0?n000D0o`001`3oP00D0?l000@0oh001@3o000F0?n000`0
o`000P3oP00>ooooo`L0o`00103oP0020?l000h0oh00503o00050?n001T0o`001@3oP00O0?l000T0
oh000P3o00000`3oP000o`000?l0000;0?l000koooooRP3oP00Hooooo`005_oooon30?l00080oh00
1@3o000>ooooocd0oh001@3o00070?n00140o`001`3oP0020?l001L0oh003P3o00020?n000kooooo
1`3o00060?n000<0o`002@3oP00F0?l000D0oh006@3o00050?n001@0o`000P3oP00;0?l000L0oh00
0P3o00000`3oP000o`000?l0000;0?l000koooooRP3oP00Hooooo`005_oooon30?l00080oh001@3o
000>ooooocd0oh001@3o00070?n00140o`001`3oP0020?l001L0oh003P3o00020?n000kooooo1`3o
00060?n000<0o`002@3oP00F0?l000D0oh006@3o00050?n001@0o`000P3oP00;0?l000L0oh000P3o
00000`3oP000o`000?l0000;0?l000koooooRP3oP00Hooooo`005_oooon30?l00080oh001@3o000>
ooooocd0oh001@3o00070?n000d0o`000P3oP0020?l000L0oh000P3o000G0?n000h0o`000P3oP00>
ooooo`L0o`001`3oP0020?l000T0oh00C@3o00020?n000@0o`000`3oP0050?l000T0oh00203o0000
0`3oP000o`000?l000020?l000koooooH@3oP0020?l000L0oh000P3o000N0?n001Sooooo000Foooo
oh<0o`000P3oP0050?l000kooooo?@3oP0050?l000L0oh003@3o000I0?n00080o`002`3oP00<0?l0
0080oh003_ooool40?l001D0oh00D`3o00030?n000D0o`002@3oP00=0?l000kooooo1@3oP0040?l0
05H0oh00103o00000`3oP000o`000?l0000T0?n001Sooooo000Foooooh<0o`000P3oP0050?l000ko
oooo?@3oP0050?l000L0oh003@3o000I0?n00080o`002`3oP00<0?l00080oh003_ooool40?l001D0
oh00D`3o00030?n000D0o`002@3oP00=0?l000kooooo1@3oP0040?l005H0oh00103o00000`3oP000
o`000?l0000T0?n001Sooooo000Fooooo`80o`000P3oP0260?l000kooooo>`3oP0090?l000@0oh00
3P3o00020?n00080o`005@3oP0020?l000`0oh002@3o00040?n000kooooo0P3o000I0?n00540o`00
1@3oP0030?l000T0oh003@3o000>ooooof40oh000P3o00090?n000<0o`006`3oP00Hooooo`005_oo
ool20?l00080oh00QP3o000>oooooc/0oh002@3o00040?n000h0o`000P3oP0020?l001D0oh000P3o
000<0?n000T0o`00103oP00>ooooo`80o`006@3oP01A0?l000D0oh000`3o00090?n000d0o`003_oo
oomQ0?n00080o`002@3oP0030?l001/0oh006?ooool001Kooooo:`3o00020?n000<0o`000P3oP01H
0?l000kooooo>`3oP0090?l000@0oh004P3o00000`3oP000o`000?l0000B0?n00080o`00303oP009
0?l000@0oh003_ooool40?l00180oh0000<0o`000?n0003oP0000P3oP01A0?l00100oh003P3o000>
oooooeX0oh0000<0o`000?n0003oP000;@3oP00Hooooo`005_ooool[0?l00080oh000`3o00020?n0
05P0o`003_oooolk0?n000T0o`00103oP00B0?l000030?n0003o0000o`000180oh000P3o000<0?n0
00T0o`00103oP00>ooooo`@0o`004P3oP0000`3o0000oh000?n000020?n00540o`00403oP00>0?l0
00koooooFP3oP0000`3o0000oh000?n0000]0?n001Sooooo000Fooooo`80o`000P3oP0070?l00080
oh006P3o00020?n00640o`003_ooooli0?n000/0o`00103oP00E0?l00180oh000P3o000@0?n000@0
o`001@3oP00>ooooo`T0o`000P3oP0050?l000H0oh0000<0o`000?n0003oP0000P3oP00K0?l000L0
oh00<03o000?0?n000h0o`003_oooon:0?n001Sooooo000Fooooo`80o`000P3oP0070?l00080oh00
6P3o00020?n00640o`003_ooooli0?n000/0o`00103oP00E0?l00180oh000P3o000@0?n000@0o`00
1@3oP00>ooooo`T0o`000P3oP0050?l000H0oh0000<0o`000?n0003oP0000P3oP00K0?l000L0oh00
<03o000?0?n000h0o`003_oooon:0?n001Sooooo000Fooooo`80o`000P3oP0000`3o0000oh000?n0
00020?n00080o`000`3oP00I0?l00080oh00H@3o000>ooooocT0oh002`3o00020?n001L0o`00;@3o
P00>ooooo`D0o`000P3oP0020?l00080oh001`3o00040?n000030?l0003oP000oh000080oh001`3o
00020?n00180o`001`3oP00`0?l000@0oh000`3o00060?n00100o`003_oooomh0?n000@0o`003P3o
P00Hooooo`005_ooool50?l000@0oh000P3o00020?n001X0o`000P3oP00@0?l00080oh00BP3o0000
0`3oP000o`000?l000020?n000kooooo>`3oP0070?l000@0oh005`3o00090?n00080o`001@3oP002
0?l001/0oh003_ooool20?l00080oh0000<0o`000?n0003oP0000P3o00020?n000L0o`00103oP000
0`3o0000oh000?n0000I0?l000L0oh005P3o00030?n003P0o`003_oooomh0?n000@0o`003P3oP00H
ooooo`005_ooool50?l000@0oh000P3o00020?n001X0o`000P3oP00@0?l00080oh00BP3o00000`3o
P000o`000?l000020?n000kooooo>`3oP0070?l000@0oh005`3o00090?n00080o`001@3oP0020?l0
01/0oh003_ooool20?l00080oh0000<0o`000?n0003oP0000P3o00020?n000L0o`00103oP0000`3o
0000oh000?n0000I0?l000L0oh005P3o00030?n003P0o`003_oooomh0?n000@0o`003P3oP00Hoooo
o`005_ooooli0?l00080oh00C@3o00020?n000kooooo>`3oP0070?l000@0oh005`3o000@0?n000H0
o`00303oP0040?l000L0oh003_ooool20?l000D0oh000P3o00020?n000D0o`001P3oP0000`3o0000
oh000?n0000O0?l000030?n0003o0000o`0001L0o`000P3oP00D0?l00080oh00803o000>ooooogP0
oh000P3o000@0?n001Sooooo000FooooocT0o`000P3oP01=0?l00080oh003_oooolk0?n000L0o`00
103oP00G0?l00100oh001P3o000<0?n000@0o`001`3oP00>ooooo`80o`001@3oP0020?l00080oh00
1@3o00060?n000030?l0003oP000oh0001l0o`0000<0oh000?l0003o00005`3o00020?n001@0o`00
0P3oP00P0?l000koooooN03oP0020?l00100oh006?ooool001Kooooo>03o00050?n004d0o`003_oo
oolP0?n000@0o`005`3oP0070?l000@0oh006@3o000>0?n00080o`000P3oP0020?l000`0oh00103o
00070?n000kooooo2`3oP0070?l000@0oh0000<0o`000?n0003oP0000P3oP00M0?l000030?n0003o
0000o`0001L0o`000P3oP00B0?l000@0oh000P3o00030?n001/0o`003_oooon50?n000030?l0003o
P000oh000080oh006?ooool001Kooooo>03o00050?n004d0o`003_oooolP0?n000@0o`005`3oP007
0?l000@0oh006@3o000>0?n00080o`000P3oP0020?l000`0oh00103o00070?n000kooooo2`3oP007
0?l000@0oh0000<0o`000?n0003oP0000P3oP00M0?l000030?n0003o0000o`0001L0o`000P3oP00B
0?l000@0oh000P3o00030?n001/0o`003_oooon50?n000030?l0003oP000oh000080oh006?ooool0
01Kooooo>03o00030?n004l0o`003_oooolR0?n00080o`005`3oP0070?l000H0oh005`3o000>0?n0
00H0o`00303oP0060?l000D0oh003_ooool20?l000/0oh0000<0o`000?n0003oP0002`3oP00K0?l0
00<0oh006`3o00060?n000`0o`00103oP0020?l000<0oh001`3o00040?n00100o`003_oooon50?n0
00030?l0003oP000oh000080oh006?ooool001Kooooo1@3o00020?n002P0o`0000<0oh000?l0003o
00000P3oP0040?l000030?n0003o0000o`0004l0o`003_oooolk0?n000L0o`000P3oP0020?l00080
oh005`3o000>0?n000H0o`002P3oP0080?l000D0oh003_ooool20?l000/0oh0000<0o`000?n0003o
P0000P3o00090?n000h0o`00103oP0090?l000<0oh00;`3o00020?n00080o`000`3oP0070?l000H0
oh003P3o000>ooooohD0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool50?l00080oh00
:03o00000`3oP000o`000?l000020?n000@0o`0000<0oh000?l0003o0000C`3o000>oooooc/0oh00
1`3o00020?n00080o`000P3oP00G0?l000h0oh001P3o000:0?n000P0o`001@3oP00>ooooo`80o`00
2`3oP0000`3o0000oh000?n000020?l000T0oh003P3o00040?n000T0o`000`3oP00_0?l00080oh00
0P3o00030?n000L0o`001P3oP00>0?l000koooooQ@3oP0000`3o0000oh000?n000020?n001Sooooo
000Fooooo`@0o`000`3oP00R0?l00080oh001`3o00020?n005H0o`003_oooolk0?n000L0o`000P3o
P00I0?l00100oh00103o000<0?n000T0o`00103oP00>ooooo`80o`002`3oP0000`3o0000oh000?n0
00020?l00080oh000P3o00080?n000/0o`001P3oP0070?l000D0oh00<@3o00030?n000T0o`00103o
P00>0?l000koooooJP3oP0030?l000H0oh0000<0o`000?n0003oP0003`3oP0030?l00080oh006?oo
ool001Kooooo103o00030?n00280o`000P3oP0070?l00080oh00EP3o000>oooooc/0oh001`3o0002
0?n001T0o`00403oP0040?l000`0oh002@3o00040?n000kooooo0P3o000;0?n000030?l0003oP000
oh000080o`000P3oP0020?l000P0oh002`3o00060?n000L0o`001@3oP00a0?l000<0oh002@3o0004
0?n000h0o`003_oooomZ0?n000<0o`001P3oP0000`3o0000oh000?n0000?0?n000<0o`000P3oP00H
ooooo`005_ooool40?l000<0oh000P3o00020?n001h0o`000P3oP0020?l00080oh0000<0o`000?n0
003oP0000P3oP01?0?l00080oh001@3o000>oooooc/0oh001`3o00060?n001D0o`004P3oP0020?l0
00/0oh002P3o00040?n000kooooo103o00030?n00080o`001`3oP0020?l00080oh000P3o00080?n0
00/0o`001`3oP0060?l000D0oh00<@3o00030?n000T0o`00103oP00>0?l000koooooJ03oP0050?l0
00H0oh000`3o000?0?n000<0o`000P3oP00Hooooo`005_ooool40?l000<0oh000P3o00020?n001h0
o`000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP01?0?l00080oh001@3o000>oooooc/0
oh001`3o00060?n001D0o`004P3oP0020?l000/0oh002P3o00040?n000kooooo103o00030?n00080
o`001`3oP0020?l00080oh000P3o00080?n000/0o`001`3oP0060?l000D0oh00<@3o00030?n000T0
o`00103oP00>0?l000koooooJ03oP0050?l000H0oh000`3o000?0?n000<0o`000P3oP00Hooooo`00
5_ooool50?n002P0o`000P3oP0000`3o0000oh000?n000020?n005H0o`003_oooolk0?n000L0o`00
1P3oP00<0?l00080oh001`3o000O0?n000T0o`001@3oP00>ooooo`T0o`000P3oP0030?l00080oh00
0P3o00020?n00080o`00203oP00=0?l000D0oh00203o00070?n002h0o`000P3oP00K0?l000kooooo
D@3oP0030?l001@0oh001@3o00060?n000030?l0003oP000oh0001@0oh006?ooool001Kooooo1@3o
P00X0?l00080oh0000<0o`000?n0003oP0000P3oP01F0?l000kooooo>`3oP0070?l000H0oh00303o
00020?n000L0o`007`3oP0090?l000D0oh003_ooool90?l00080oh000`3o00020?n00080o`000P3o
P0020?l000P0oh003@3o00050?n000P0o`001`3oP00^0?l00080oh006`3o000>oooooe40oh000`3o
000D0?n000D0o`001P3oP0000`3o0000oh000?n0000D0?n001Sooooo000Fooooo`D0oh00:`3o0004
0?n005H0o`003_ooooli0?n000T0o`001`3oP00;0?l00080oh000P3o00020?n000<0o`000P3oP004
0?l001T0oh002@3o00050?n000kooooo103o00000`3oP000o`000?l000090?n00080o`000P3oP002
0?l000P0oh003@3o00050?n000P0o`001`3oP00]0?l000<0oh006`3o000>oooooe80oh000P3o000D
0?n000@0o`006P3oP0020?l00080oh006?ooool001Kooooo1@3oP00A0?l000030?n0003o0000o`00
01H0o`001@3oP01F0?l000kooooo>@3oP0090?l000H0oh002P3o00090?n000/0o`005P3oP0070?l0
00L0oh003_ooool40?l001X0oh006P3o00070?n000L0o`000`3oP00O0?l000L0oh006`3o000>oooo
oe80oh000P3o000b0?n00080o`000P3oP00Hooooo`005_ooool50?n00140o`0000<0oh000?l0003o
00005P3o00050?n005H0o`003_ooooli0?n000T0o`001P3oP00:0?l000T0oh002`3o000F0?n000L0
o`001`3oP00>ooooo`@0o`006P3oP00J0?l000L0oh001`3o00030?n001l0o`001`3oP00K0?l000ko
ooooDP3oP0020?l00380oh000P3o00020?n001Sooooo000Fooooo`L0o`000P3oP0040?l000030?n0
003o0000o`0000H0o`0000<0oh000?l0003o00005`3o00020?n005P0o`003_ooooli0?n000T0o`00
0P3oP00>0?l000T0oh002`3o00090?n00080o`001`3oP0020?l00080oh000`3o00020?n00080o`00
1`3oP00>ooooo`@0o`006@3oP00L0?l000H0oh00:@3o00090?n001T0o`003_oooon:0?n001Sooooo
000Fooooo`L0o`000P3oP0040?l000030?n0003o0000o`0000H0o`0000<0oh000?l0003o00005`3o
00020?n005P0o`003_ooooli0?n000T0o`000P3oP00>0?l000T0oh002`3o00090?n00080o`001`3o
P0020?l00080oh000`3o00020?n00080o`001`3oP00>ooooo`@0o`006@3oP00L0?l000H0oh00:@3o
00090?n001T0o`003_oooon:0?n001Sooooo000Foooooc00o`000P3oP01H0?l000kooooo>`3oP007
0?l00080oh003P3o00090?n000T0o`002`3oP0020?l000L0oh001`3o000;0?n000kooooo0P3o0003
0?n00080o`003`3oP0030?l000@0oh007P3o00040?n002T0o`002@3oP00I0?l000kooooo@@3oP003
0?l004H0oh006?ooool001Kooooo<03o00020?n005P0o`003_oooolk0?n000L0o`000P3oP00>0?l0
00T0oh002@3o000;0?n00080o`001`3oP0070?l000/0oh003_ooool20?l000<0oh000P3o000?0?n0
00<0o`00103oP00N0?l000@0oh00:@3o00090?n001T0o`003_oooom10?n000<0o`00AP3oP00Hoooo
o`005_oooon:0?l000kooooo?@3oP0050?l000@0oh00303o00080?n000<0o`00103oP0030?l000/0
oh000P3o000;0?n000<0o`002`3oP00>ooooo`80o`000`3oP0040?l000d0oh009@3o00040?n002T0
o`002@3oP00I0?l000kooooo@@3oP0030?l001L0oh000P3o000]0?n001Sooooo000FooooohX0o`00
3_oooolm0?n000D0o`00103oP00<0?l000P0oh000`3o00040?n000<0o`002`3oP0020?l000/0oh00
0`3o000;0?n000kooooo0P3o00030?n000@0o`003@3oP00U0?l000@0oh00:@3o00090?n001T0o`00
3_oooom10?n000<0o`005`3oP0020?l002d0oh006?ooool001KoooooRP3o000>ooooocd0oh001@3o
00070?n000T0o`00203oP0030?l00200oh00103o00090?n000kooooo103o00000`3oP000o`000?l0
000;0?n000@0o`0000<0oh000?l0003o0000803o00060?n002T0o`002@3oP00I0?l000kooooo@@3o
P0000`3o0000oh000?n0000F0?n000<0o`00;@3oP00Hooooo`005_ooool40?n001h0o`000P3oP002
0?l000030?n0003o0000o`000640o`003_oooolm0?n000D0o`003@3oP0050?l00080oh000P3o000b
0?n000kooooo0P3oP0020?l000030?n0003o0000o`000100oh007`3o00090?n002T0o`002@3oP00I
0?l000kooooo3@3oP0050?l002T0oh001P3o000I0?n000<0o`00;@3oP00Hooooo`005_ooool40?n0
01h0o`000P3oP0020?l000030?n0003o0000o`000640o`003_oooolm0?n000D0o`003@3oP0050?l0
0080oh000P3o000b0?n000kooooo0P3oP0020?l000030?n0003o0000o`000100oh007`3o00090?n0
02T0o`002@3oP00I0?l000kooooo3@3oP0050?l002T0oh001P3o000I0?n000<0o`00;@3oP00Hoooo
o`005_ooool40?n00280o`0000<0oh000?l0003o0000H@3o000>ooooocd0oh001@3o000;0?n000L0
o`000P3oP0020?l00380oh003_ooool>0?n000@0o`001@3oP00O0?l000T0oh00:@3o00090?n001T0
o`003_ooool=0?n000<0o`00:`3oP0040?l001/0oh000`3o000;0?n000@0o`007P3oP00Hooooo`00
5_ooool40?n00280o`0000<0oh000?l0003o0000H@3o000>ooooocd0oh001@3o000;0?n000L0o`00
0P3oP0020?l00380oh003_ooool>0?n000@0o`001@3oP00O0?l000T0oh00:@3o00090?n001T0o`00
3_ooool=0?n000<0o`00:`3oP0040?l001/0oh000`3o000;0?n000@0o`007P3oP00Hooooo`005_oo
ool40?n001<0o`000P3oP00F0?l000030?n0003o0000o`000080o`000P3oP01;0?l000D0oh00103o
000>ooooocT0oh002@3o000?0?n000<0o`000P3oP0020?l00080oh000`3o000]0?n000kooooo3P3o
P0080?l000D0oh006`3o00090?n000`0o`000P3oP00K0?l000/0oh005`3o000>ooooodd0oh000P3o
000k0?n001Sooooo000Fooooo`@0oh004`3o00020?n001H0o`0000<0oh000?l0003o00000P3o0002
0?n004/0o`001@3oP0040?l000kooooo>@3oP0090?l000l0oh000`3o00020?n00080o`000P3oP003
0?l002d0oh003_ooool>0?n000P0o`001@3oP00K0?l000T0oh00303o00020?n001/0o`002`3oP00G
0?l000koooooC@3oP0020?l003/0oh006?ooool001Kooooo0P3oP00E0?l00080oh006@3o00040?n0
00<0o`000P3oP01:0?l000<0oh000P3o000>ooooocT0oh002@3o00020?n00080o`000P3oP0000`3o
0000oh000?n000020?n000L0o`000P3oP0020?l00080oh000`3o000]0?n000kooooo3P3oP0080?l0
00D0oh006`3o00020?n000030?l0003oP000oh000080oh006`3o00020?n00100o`002@3oP00G0?l0
00koooooRP3oP00Hooooo`005_ooool20?n00300o`00103oP0020?l000<0oh00AP3o00020?n00080
o`000`3oP0020?l000kooooo>@3oP00O0?l00080oh001@3o000>0?n00080o`006`3oP00>ooooo`@0
o`002P3oP0090?l000@0oh006`3o00020?n000030?l0003oP000oh000080oh006`3o00020?n00100
o`002@3oP00G0?l000koooooRP3oP00Hooooo`005_ooool20?n00300o`00103oP0020?l000<0oh00
AP3o00020?n00080o`000`3oP0020?l000kooooo>@3oP00O0?l00080oh001@3o000>0?n00080o`00
6`3oP00>ooooo`@0o`002P3oP0090?l000@0oh006`3o00020?n000030?l0003oP000oh000080oh00
6`3o00020?n00100o`002@3oP00G0?l000koooooRP3oP00Hooooo`005_ooool20?n00300o`000P3o
P0040?l000030?n0003o0000o`0002P0o`0000<0oh000?l0003o0000803o00020?n00080o`003_oo
ooli0?n001l0o`000P3oP00:0?l000T0oh000P3o000K0?n000kooooo103o00000`3oP000o`000?l0
00060?n000X0o`00103oP00K0?l00080oh000`3o00020?n001/0o`000P3oP00@0?l000L0oh006@3o
000>ooooohX0oh006?ooool001Kooooo0P3oP00`0?l00080oh00103o00000`3oP000o`000?l0000X
0?l000030?n0003o0000o`000200o`000P3oP0020?l000kooooo>@3oP00O0?l00080oh002P3o0009
0?n00080o`006`3oP00>ooooo`@0o`0000<0oh000?l0003o00001P3oP00:0?l000@0oh006`3o0002
0?n000<0o`000P3oP00K0?l00080oh00403o00070?n001T0o`003_oooon:0?n001Sooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaOo0?l01?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo000PoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool001oooooo5_l00?lPooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolF
ool0023ooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolF
o`00ob3ooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o8?ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000PoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lPooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000OoooooaKo003o8?ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00ob3ooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l0
07lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003ooooo
ooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo
00?o0000o`00Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000oooo
ooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00
Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l0
07lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
05Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo000FooooohX0o`003_ooool20?l001h0003o1`3o
000?0000o`<0o`001P000?l70?l000T0003o0P3o000<0000o`T0o`002@000?l50?l000H0003o0P3o
000<0000o`80o`003_oooon:0000o`kooooo5P3o00000`000?l0o`000?l000050?l000H0003o3P3o
000=0000obd0o`0000<0003o0?l0003o00001@3o00020000o`l0o`0000<0003o0?l0003o00000P3o
000Hooooo`005_oooon:0?l000kooooo0P3o000N0000o`L0o`003`000?l30?l000H0003o1`3o0009
0000o`80o`0030000?l90?l000T0003o1@3o00060000o`80o`0030000?l20?l000koooooRP000?l>
oooooaH0o`0000<0003o0?l0003o00001@3o00060000o`h0o`003@000?l]0?l000030000o`3o0000
o`0000D0o`000P000?l?0?l000030000o`3o0000o`000080o`006?ooool001KoooooRP3o000>oooo
o`@0o`007P000?l50?l001@0003o0P3o00020000o`L0o`002@000?l20?l000X0003o3@3o000;0000
o`030?l000000?l0003o0080003o2`3o00070000o`koooooRP000?l>oooooc80o`0010000?lK0?l0
00T0003o403o00030000oad0o`006?ooool001KoooooRP3o000>ooooo`@0o`007P000?l50?l001@0
003o0P3o00020000o`L0o`002@000?l20?l000X0003o3@3o000;0000o`030?l000000?l0003o0080
003o2`3o00070000o`koooooRP000?l>oooooc80o`0010000?lK0?l000T0003o403o00030000oad0
o`006?ooool001KoooooRP3o000>ooooo`@0o`007P000?l40?l001D0003o0P3o00020000o`L0o`00
1`000?l50?l000/0003o2`3o000@0000o`80o`000`000?l80?l000D0003o3_oooon:0000o`kooooo
5P3o00000`000?l0o`000?l0000I0?l000H0003o303o00040000o`h0o`001@000?lK0?l00080003o
4P3o000Hooooo`005_oooon:0?l000kooooo0P000?l20?l003d0003o1@3o00070000o`@0o`002@00
0?l70?l001L0003o3@3o00050000o`koooooRP000?l>oooooad0o`000`000?lD0?l00080003o3P3o
00070000o`/0o`0010000?lC0?l00080003o2`3o00020000o`h0o`006?ooool001KoooooRP3o000>
ooooo`80003o0P3o000m0000o`D0o`001`000?l40?l000T0003o1`3o000G0000o`d0o`001@000?l>
ooooohX0003o3_oooolM0?l000<0003o503o00020000o`h0o`001`000?l;0?l000@0003o4`3o0002
0000o`/0o`000P000?l>0?l001Sooooo000FooooohX0o`003_oooom?0000o`80o`001@000?l20?l0
0080003o00<0o`000000o`000?l07@000?l50?l00080003o0P3o00070000o`koooooD@000?l00`3o
0000003o0000o`0f0000o`kooooo0P000?l>0?l00100003o7`3o00090000oah0o`0010000?l20?l0
00030000o`3o0000o`0001/0o`006?ooool001KoooooRP3o000>ooooodl0003o0P3o00050000o`80
o`000P000?l00`3o0000003o0000o`0M0000o`D0o`000P000?l20?l000L0003o3_oooomA0000o`03
0?l000000?l0003o03H0003o3_ooool20000o`h0o`0040000?lO0?l000T0003o7P3o00040000o`80
o`0000<0003o0?l0003o00006`3o000Hooooo`005_oooon:0?l000koooooEP000?l50?l002H0003o
0P3o00070000o`koooooC@000?l90?l003@0003o3_oooolB0?l000D0003o1`3o00020000oad0o`00
1@000?l20?l000T0003o2`3o00020000o`L0o`000`000?l20?l00080003o103o00000`000?l0o`00
0?l0000F0?l000030000o`3o0000o`000080o`006?ooool001KoooooRP3o000>oooooeH0003o1@3o
000V0000o`80o`001`000?l>ooooodd0003o2@3o000d0000o`kooooo4P3o00050000o`L0o`000P00
0?lM0?l000D0003o0P3o00090000o`/0o`000P000?l70?l000<0003o0P3o00020000o`@0o`0000<0
003o0?l0003o00005P3o00000`000?l0o`000?l000020?l001Sooooo000FooooohX0o`003_oooolT
0000o`80o`00E`000?l60?l000L0003o3_oooom=0000o`L0o`0060000?l00`3o0000003o0000o`0K
0000o`kooooo7@3o00050000oad0o`000`000?l70?l000@0003o503o00050000ob@0o`006?ooool0
01KoooooRP3o000>ooooogd0003o1P3o00070000o`koooooC@000?l70?l003H0003o3_ooool;0?l0
00D0003o403o00040000obL0o`000P000?lm0?l001Sooooo000FooooohX0o`003_oooomm0000o`H0
o`001`000?l>ooooodd0003o1`3o000f0000o`kooooo2`3o00050000oa00o`0010000?lW0?l00080
003o?@3o000Hooooo`005_oooon:0?l000koooooO`000?l60?l000D0003o3_oooom?0000o`<0o`00
>0000?l>ooooo`/0o`001`000?lN0?l000@0003oEP3o000Hooooo`005_oooon:0?l000koooooO`00
0?l60?l000D0003o3_oooom?0000o`<0o`00>0000?l>ooooo`/0o`001`000?lN0?l000@0003oEP3o
000Hooooo`005_oooon:0?l000kooooo?`000?l70?l000L0003o103o000W0000o`d0o`001@000?l>
ooooohX0003o3_ooool90?l000T0003o>@3o00060000ob80o`001@000?lB0?l001Sooooo000Foooo
ohX0o`003_oooolo0000o`L0o`001`000?l40?l002L0003o3@3o00050000o`koooooRP000?l>oooo
o`T0o`002@000?li0?l000H0003o8P3o00050000oa80o`006?ooool001KoooooRP3o000>ooooocT0
003o3@3o00070000o`D0o`0020000?l00`3o0000003o0000o`0K0000o`@0o`001@000?l50?l000@0
003o3_oooon:0000o`kooooo3@3o00030000ogX0o`006?ooool001KoooooRP3o000>ooooocT0003o
3@3o00070000o`D0o`0020000?l00`3o0000003o0000o`0K0000o`@0o`001@000?l50?l000@0003o
3_oooon:0000o`kooooo3@3o00030000ogX0o`006?ooool001KoooooRP3o000>ooooocP0003o3P3o
00050000o`T0o`001P000?l00`3o0000003o0000o`0K0000o`@0o`001@000?l50?l000@0003o3_oo
oon:0000o`kooooo5`3o00040000oc00o`000P000?l20?l00080003o>@3o000Hooooo`005_oooon:
0?l000kooooo>`000?l=0?l000<0003o603o000P0000o`<0o`0010000?l>ooooohX0003o3_oooolR
0?l00080003o7P3o00040000o`T0o`000P000?li0?l001Sooooo000FooooohX0o`003_oooolk0000
o`d0o`000`000?lH0?l00200003o0`3o00040000o`koooooRP000?l>ooooob80o`000P000?lN0?l0
00@0003o2@3o00020000ocT0o`006?ooool001KoooooRP3o000>oooooc/0003o1`3o00090000o`d0
o`002@000?l30?l002H0003o3_oooon:0000o`kooooo8P3o00020000o`h0o`000P000?l;0?l000<0
003o103o00020000o`L0o`000P000?ld0?l000030000o`3o0000o`000080o`006?ooool001Kooooo
RP3o000>oooooc/0003o1`3o00090000o`d0o`002@000?l30?l002H0003o3_oooon:0000o`kooooo
8P3o00020000o`h0o`000P000?l;0?l000<0003o103o00020000o`L0o`000P000?ld0?l000030000
o`3o0000o`000080o`006?ooool001KoooooRP3o000>oooooc/0003o1`3o00090000o`@0o`00>`00
0?l>ooooohX0003o3_oooolR0?l000@0003o5`3o00040000odT0o`006?ooool001KoooooRP3o000>
oooooc/0003o1`3o00090000o`@0o`00>`000?l>ooooohX0003o3_oooolR0?l000@0003o5`3o0004
0000odT0o`006?ooool001KoooooRP3o000>oooooc/0003o1P3o00190000o`koooooRP000?l>oooo
ocl0o`000P000?l<0?l000@0003o;P3o000;0000oaSooooo000FooooohX0o`003_oooolk0000o`H0
o`00B@000?l>ooooohX0003o3_oooolo0?l00080003o303o00040000obh0o`002`000?lHooooo`00
5_oooon:0?l000kooooo?`000?l20?l00200003o0P3o000W0000o`kooooo9`000?l40?l005l0003o
3_oooolT0?l000L0003o503o00020000o`030?l000000?l0003o0080003o0P3o00000`000?l0o`00
0?l0000=0?l000<0003o;`3o000Hooooo`005_oooon:0?l000kooooo?`000?l20?l004T0003o3_oo
oom;0000o`80o`00?@000?l>ooooob@0o`001`000?l]0?l000<0003o:P3o00000`000?l0o`000?l0
00020?l001Sooooo000FooooohX0o`003_oooolo0000o`80o`00B@000?l>oooood/0003o0P3o000m
0000o`kooooo903o00070000obd0o`000`000?lZ0?l000030000o`3o0000o`000080o`006?ooool0
01KoooooRP3o000>oooooed0003o0P3o000P0000o`L0o`0010000?l>ooooobL0003o0P3o000R0000
o`L0o`00:P000?l30?l000/0003o3_oooolR0?l000D0003o6P3o000>0000obd0o`0000<0003o0?l0
003o00002`3o000Hooooo`005_oooon:0?l000koooooG@000?l20?l00200003o1`3o00040000o`ko
oooo9`000?l20?l00280003o1`3o000Z0000o`<0o`002`000?l>ooooob80o`001@000?lJ0?l000h0
003o;@3o00000`000?l0o`000?l0000;0?l001Sooooo000FooooohX0o`003_oooomM0000o`80o`00
8P000?l50?l000@0003o3_oooom90000o`80o`00<P000?l40?l000T0003o3_oooolP0?l000L0003o
8@3o00090000o`D0o`001`000?l?0?l000030000o`3o0000o`0001/0o`006?ooool001KoooooRP3o
000>oooooed0003o0P3o000R0000o`D0o`0010000?l>ooooodT0003o0P3o000b0000o`@0o`002@00
0?l>ooooob00o`001`000?lQ0?l000T0003o1@3o00070000o`l0o`0000<0003o0?l0003o00006`3o
000Hooooo`005_oooon:0?l000kooooo?`000?l20?l004T0003o3_oooolY0000o`@0o`008P000?l7
0?l002H0003o1@3o00090000o`kooooo10000?lL0?l000@0003o9`3o000;0000o`80o`000P000?lB
0?l000P0003o0P3o00020000o`L0o`0010000?l70?l001Sooooo000FooooohX0o`003_oooom=0000
o`80o`00>`000?l>ooooobT0003o103o000T0000o`<0o`00=P000?l>ooooocd0o`0010000?l70?l0
00030000o`3o0000o`0000H0o`000`000?lI0?l00080003o1`3o00020000o`L0o`0010000?l70?l0
01Sooooo000FooooohX0o`003_oooom=0000o`80o`00>`000?l>ooooobT0003o103o000T0000o`<0
o`00=P000?l>ooooocd0o`0010000?l70?l000030000o`3o0000o`0000H0o`000`000?lI0?l00080
003o1`3o00020000o`L0o`0010000?l70?l001Sooooo000FooooohX0o`003_oooolo0000o`80o`00
B@000?l>ooooob/0003o0P3o001M0000o`kooooo5`3o00020000obH0o`000P000?li0?l000L0003o
2@3o000Hooooo`005_oooon:0?l000kooooo?`000?l20?l004T0003o3_ooool[0000o`80o`00G@00
0?l>oooooaL0o`000P000?lV0?l00080003o>@3o00070000o`T0o`006?ooool001KoooooRP3o000>
ooooohX0003o3_oooon:0000o`kooooo5`3o00020000o`80o`000P000?lT0?l000L0003o3P3o0004
0000ob00o`000`000?l=0?l001Sooooo000FooooohX0o`003_oooon:0000o`koooooRP000?l>oooo
oaL0o`000P000?l20?l00080003o903o00070000o`h0o`0010000?lP0?l000<0003o3@3o000Hoooo
o`005_oooon:0?l000kooooo?`000?l20?l000`0003o0P3o000k0000o`koooooRP000?l>ooooo`d0
o`000`000?mZ0?l000<0003o3@3o000Hooooo`005_oooon:0?l000kooooo?`000?l20?l000`0003o
0P3o000k0000o`koooooRP000?l>ooooo`d0o`000`000?mZ0?l000<0003o3@3o000Hooooo`005_oo
oon:0?l000kooooo?`000?l20?l004T0003o3_oooon:0000o`kooooo0P3o00050000o`H0o`003000
0?l40?l000L0003o8P3o00050000obl0o`001@000?l;0?l001Sooooo000FooooohX0o`003_oooolo
0000o`80o`00B@000?l>ooooohX0003o3_ooool50000o`P0o`002@000?l70?l000030000o`3o0000
o`0001P0o`0000<0003o0?l0003o00003@3o00030000obl0o`001@000?l;0?l001Sooooo000Foooo
ohX0o`003_oooolo0000o`80o`00B@000?l>ooooohX0003o3_ooool50000o`P0o`002@000?l70?l0
00030000o`3o0000o`0001P0o`0000<0003o0?l0003o00003@3o00030000obl0o`001@000?l;0?l0
01Sooooo000FooooohX0o`003_oooolm0000o`@0o`0070000?l20?l00080003o0P3o000W0000o`ko
ooooRP000?l>ooooo`D0003o<@3o00090000o`T0o`0000<0003o0?l0003o0000?`3o000Hooooo`00
5_oooon:0?l000kooooo?@000?l40?l001`0003o0P3o00020000o`80o`009`000?l>ooooohX0003o
3_ooool50000oc40o`002@000?l90?l000030000o`3o0000o`0003l0o`006?ooool001KoooooRP3o
000>ooooocd0003o103o00190000o`koooooRP000?l>oooooc80o`000P000?l20?l000T0003o1`3o
00020000ob00o`000P000?l90?l000<0003o503o000Hooooo`005_oooon:0?l000kooooo?@000?l4
0?l004T0003o3_oooon:0000o`kooooo<P3o00020000o`80o`002@000?l70?l00080003o803o0002
0000o`T0o`000`000?lD0?l001Sooooo000FooooohX0o`003_oooolm0000o`@0o`00B@000?l>oooo
ohX0003o3_ooool_0?l000D0003o103o00000`000?l0o`000?l0000>0?l00080003o?`3o000Hoooo
o`005_oooon:0?l000kooooo?@000?l40?l004T0003o3_oooon:0000o`kooooo;`3o00050000o`@0
o`0000<0003o0?l0003o00003P3o00020000ocl0o`006?ooool001KoooooRP3o000>ooooob00003o
0P3o000M0000o`80o`00B@000?l>ooooohX0003o3_oooolR0?l000@0003oI03o000Hooooo`005_oo
oon:0?l000kooooo?@000?l40?l000030000o`3o0000o`0004H0003o3_oooon:0000o`kooooo803o
00070000oel0o`0010000?lHooooo`005_oooon:0?l000kooooo?@000?l40?l000030000o`3o0000
o`0004H0003o3_oooon:0000o`kooooo803o00070000oel0o`0010000?lHooooo`005_oooon:0?l0
00kooooo0P000?l20?l007/0003o0P3o00090000o`koooooRP000?l>oooooah0o`002@000?mS0?l0
01Sooooo000FooooohX0o`003_ooool20000o`80o`00N`000?l20?l000T0003o3_oooon:0000o`ko
oooo7P3o00090000of<0o`006?ooool001KoooooO`3o00020000o`T0o`003_oooom80000o`L0o`00
;P000?l80?l000D0003o3_oooon:0000o`kooooo903o00070000obL0o`0010000?lI0?l000@0003o
3P3o00040000o`D0o`006?ooool001KoooooO`3o00020000o`T0o`003_oooom80000o`L0o`00;P00
0?l80?l000D0003o3_oooon:0000o`kooooo903o00070000obL0o`0010000?lI0?l000@0003o3P3o
00040000o`D0o`006?ooool001KoooooO`3o00020000o`T0o`003_ooool20000o`<0o`00@`000?l7
0?l002h0003o1P3o00070000o`koooooRP000?l>ooooo`@0o`0000<0003o0?l0003o00007@3o0005
0000obT0o`0010000?lI0?l000@0003o5`3o000Hooooo`005_oooon:0?l000kooooo0P000?l30?l0
04<0003o1`3o000;0000o`D0o`0080000?l40?l000L0003o3_oooon:0000o`kooooo103o00030000
oa/0o`002`000?lW0?l00080003o=03o000Hooooo`005_oooon:0?l000kooooo0P000?l30?l004<0
003o1`3o000;0000o`D0o`0080000?l40?l000L0003o3_oooon:0000o`kooooo103o00030000oa/0
o`002`000?lW0?l00080003o=03o000Hooooo`005_oooon:0?l000koooooB@000?l20?l000l0003o
00<0o`000000o`000?l08P000?l40?l000L0003o3_oooomo0000o`80o`002@000?l>ooooo`T0003o
P@3o000Hooooo`005_oooon:0?l000koooooB@000?l20?l000l0003o00<0o`000000o`000?l08P00
0?l40?l000L0003o3_oooomo0000o`80o`002@000?l>ooooo`T0003oP@3o000Hooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6D69372C281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F3753
4D373648AA898568262423252B3229262638262421532F60918F8C592938451918151515
1515152695776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E
1D222426376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A568731
557753738F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D47
61ABB19F9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B893
66B0E0C6997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9
DFBCAC8F63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C
2529354C6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
8446312725211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B
2B3237323D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A25423617171617
15141D4EA8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F21
26262A2C2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D68
33456475937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F
5388AA7A6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B
7490D5626897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DA
DBB796545F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A
2D293140564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
643E333837271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E2420
22202633424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B4818131417
21405A4543819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C
2F333B5966A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C
4E243B9293A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1
B96EA7A6D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8
A39BC46D98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CE
CEAA654451694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD78845
3E3134546A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
9D826A5E5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624
221E24242B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F40205117173144
403237394F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E4446
67554B3F626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B
542C377E93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4
C1787FA0BB875764736D94D4A6A089472F47462227307CB291464970A15247803C546345
91C4C0B99F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7
B57BA2514B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176
432C3080ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
9F7149453D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA7955138322721
1F1F1D1D1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E613421
2726354A38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E
4B36437C614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227
314E3B8391A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD
6765508D915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C38446136
76ACDFD6D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6
987854A15231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA
903753ADD0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
C4AC5F52496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F3322
1E201F1D1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F
474A442C1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C49
4E4D6B8E3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F20
24748282A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B
4C547968AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65
BA94DCD7CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F98
8A7246428A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AF
D2C0B5CECDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
DEC9BA928D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26
211D202027231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872
443A29201C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E
3E3C3B6B5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E
205FB9B19C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB5951
56939572B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0
B1AACCA3BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F21222492775067939296
90772F23297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7
DCDFDECCB0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
D0BDAF8561545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625
231C1C1C20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA9148
3C231D2F3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A28
2B30365BAFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22
225FA3514B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50
816093B1C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B0
9DBBC59EC8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96
A58A231C1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CA
C5C4D5D49C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
D2C49D7F6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C23
25201E1B1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E84
49264047574427434A33313B315A635640262B2C37353436919E76693A4F617F74252725
232328337FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D
20639B58486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C446483
4D4C4E92CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8C
ACCDCEC98E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95
964F241E1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08D
C3A691BCD6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
C7B8B37158544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B416662
53372E231D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C497
7B576548281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26
252A293D81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D
2A599FB09C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B
4D436493984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BF
CCD28C905E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA0
92592025253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BD
C0B7B69CC6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
A186A1A76841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F25
3C5B5B4E2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8
BF78331F1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E
23232557765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C
5756B8B88873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E60
42416D843C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2
D0C36B7F664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5
B2958A98A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABC
AFC0D0CFC8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
6756648EAC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C
2D1E2C3A43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6
A3241D1A171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58
483C5A9559604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375B
AE8ECAA07B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A45
3C5E77562425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B2
9E93ABA74F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897
B0B5644E494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9
B75C63A5D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
5146414C5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C674259
6C5F5574828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C7
8A1C18161619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B
92A9D5A73F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CB
CAC4D9CCAB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443
566E78281E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B159
3F88807E4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71
B98E615C5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A
7F3F3A79CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
634C413844468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86
AFC3978791785472783D6E6B78A36C384147845018191517171B1916171517229F8881A7
9F1C1515151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F
394680AD793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7
A9BEB6AFB6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9D
C27D361D1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E
36747C7F624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB
6E434B53436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F2760
76444453C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
404C5248403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0
CACA8E6D523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5
C64F47332B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29
282C3CC1BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE
91C4C7B6B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675
A479201C1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F
5E716C97844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E
9F4E3B535B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A
64374F8BCC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5A3D33353A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392
A3AD694C578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5
CE8C4A3334383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147
302C56AF6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7
C9C0B8ACD1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8
B45F1D1E1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C
87514C91A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B
608550354D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047
606F8E6A77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
A049332C2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AF
B3C1AB988B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2
CCC1B98B502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C988668
60559B7C4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1
D1BFC8A18AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5
CA712F281F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D
88483B3DB7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D
78586A6239495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327F
A0883C2C467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
667F462A2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662
B3B5706974796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BC
BC9A7C81A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F55
4968C56B6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CE
A154957E646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C876
796763313C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7B
D8CB9B76C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C35
3B5A706582353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE
84443D3344538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
886E81372226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965D
A5A772673B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBF
C1B4A389787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E26
3D80A47E767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA3
6D465A4837405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3
844A5190B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBC
C3997B5EB4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A
2935527A869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B43
7E70473739316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
709A9A93543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8D
AC7B4E583F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCE
A7A7A5AABD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F20
2B9A5A99A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086
794B462F2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83
B49165A6E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CD
B3774C60ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D59
2D2A303C5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B
9FA4302D2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
807A696682C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8
D5BA3627303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E
586D91BFBEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B33
81694A77B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8
B1675F2B27282B32373F79882B202488746662684C45491F283B53503D3233424748536C
7FAF99A9DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CC
CDB488AEC6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C5284
8B6734303F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E31
83DB98452F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
90808A949DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F88
94A9572524354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F
605779B7BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88
D07A4E5CA9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892
B1AD61352B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D81
6E8CB5D1E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7
BAB9C0C9D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E
4B81AB6C2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA73037
9FB1C2A15582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
737A95979196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C
454D9B67292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E526164
545463874B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F52
85B98A656C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D
6C66755E3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C4458
7094C7DFBEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0
C9B3B0DACC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638
383F4C5621222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB04777
3B273F67C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
94B99F9D595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E44
34315B945B2C2320273F58526C442522212C616C656D4630312D397C69322C2E45371829
2A323362261515151515151D562F3F6A9AD2DDD198693F413F475572873C282750837156
73C2A2A198583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381
AD64475A6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65
679DC5B696B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB18280
8EAADADB93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F31
34373B3E3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F
2C4F91C3B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
4879709499506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C
443330427C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A
1518265224151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C
8CD29A614C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B68366
74524C484B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526F
AD9A7C9AA0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB6
6D56A6C09362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B
2D31352D413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A6
9585715A5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
3D3C7E558B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47
464F3C263797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F485660441917
15151A522F151615151515164597954A265395697776484243443F3C3D4860443D48A781
818F5C42413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D
3252474238375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A2
76666351AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E
493CAB92C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D35
2E2D353C3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166
524C3F444966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
3D36406E50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C73
38231F2E253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B3823
1515184A4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43
282D70413936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F30
2D294E40393733486141232027274E9584B1958FB78D773A25242C2A282A35545B599165
74A58D98A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D
6B41A6707930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C
302C30383F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A34
3731343744667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
362E32BFA5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E382650
5B261B1C1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D26253949
44151D356619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A
26266653312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E4528
2827325F3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C
726982BEC7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56
656BA97273211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C39
3E2C2D313C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B36
30293034497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
384280ACB58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F7235212517
5A431C1A1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E
423C51619866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A
242EACD496524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B56726
27272536533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41
455F80B9B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD765650505460
81CCAF8F602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931
423D414B76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932
342E354483ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
52564B51B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B27151514
2A5E1D1C191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D6440
365469524037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E4253
71ACA59DA5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E
31252629495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A
7AA7C69EBB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0
D2E0C6B565494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A1502928
42A29A9BB8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B47060
6A8A9ABFC1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
4E53576CA89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A
248E4221266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B6579
7055505D705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC6
997350404C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F56
4F42454A437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D
5FA19D9DA29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D
95C6D8BF4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E7058
7CB3A2C8C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46
659097C0907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
5651504A3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B65
6CB5A9686CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F
6E50495F883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB
744B493E4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A
517C8C9284A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC82
839176554B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B
7098B0AB895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679E
D3C9C5D5D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A
6A4C79B7BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
4B3E363A6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A34
1F2BABADB2735A3D3F47596D887CC48B4E332C26357A5B44345D77673828252322274771
727561579A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D75
76523951886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99
A963596D90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892AB
AC4F413C62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F
88A9C691772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AF
C0C6D6C6C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B705148588586
8CA1D2CEAD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
425B7D93BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B67
3630989A392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D
949156557299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A
5F5D688F8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778
A54A5F5B6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED4
7E464C68A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89
C8AD869F87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5
DED5BE929A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87
BDC9D0D07B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
7D6A5B5C719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F29478161
4E5F593C4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA8
8368212F4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E
8078C9938487665564645B462535539E92474462B16B7196996D6A9399918147312F334D
B75E386C8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC
9683919A5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55
B0C2B8ABAFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDA
E0D8997BC1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A81
9F836E9E7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
56504C4946455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C6468
5A776367565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F
8B6E1E1C20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4B
C9B38472765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D303241
80CDA97A699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CD
D1A4663124292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA1
8A668EAF9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1
BEBEC9BB7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F
6F864C7B8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
554B42393937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779
392B2220242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B67
7F88291C1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E3350
8B9C7F7C7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477D
A3C7A8496B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1
DC602625232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C
504548808391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C
93A8ABAA585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E212124222025343638
5A666C5585985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
413937373B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083
331A1C1A1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E
6855641C1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A
6470907C8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D55
5B8DC57E4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539E
CD4121232423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E51
3E396BCA5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA095
8B4B3F67936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D34
4465816E6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
6E787774756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650
211B1B1C1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D
712A5C4D2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F7979
8076806F5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABF
ABCEB284211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54
A9501F272B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61
456EB58153808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD29054
715539435E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B32
3F576990A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
68433227211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F
1C1B1D1D1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C36
83274E70634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19A
B7ABB9AA412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D
65957B9C5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F
866C23282F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD
9BA4661F1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C
53565449475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D2122222426
2F4664B6E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
4A45423A2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B15
15161B181C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C1943
9C43597E90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAE
BDA3B6B3602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E
4643634196613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F64
7E892829364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7
C65E1F1A1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C48
434147555D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E
26498BACCAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
4E4943384046382F2142514A4773C6C7AC45209C91525A855E7C513A4440292522251714
15131517181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368D
C55C4D4C6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B84
9DA9B296645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A
403D4A596E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56
ACC78846436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC
851F1C225D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A
4744464B54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E
52A8D1D7E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
484440332E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C171515
1212151B1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697D
BD9D786F5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E
64BC7E796569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A433234
3E3F426A6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7A
C2CE97B0ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67
601B319AACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B361
4A4547474D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC
945293B7D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
3C3A3E3F312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C16171515
15151517191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D
81AA93948E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B8679
7882AF767B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F
334452A6844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538A
B185B39AC4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE60672975
976785507F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B
966B48494F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8D
A597ACB3ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
43342F38432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B
171515151C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155
694F6A7767808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60
232460AABF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F32
2B3F51A38A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B35295678
6A7AA79F97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0
BBC8B98A5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D48
85826D9DAEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969A
BBCBD8C99C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
7B737379858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A22202532
29171914151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398
644C434384C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050
281C226EC7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C
2D32418F725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044
456382B18AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886AB
C4D3D28B6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E
415F819163453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B
3F5DBAC59E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6958525356515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C
261F1A1513191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592
844C4745777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C24
5B1F1C259873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C
302B4093734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24
233E5296AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6
CAD58856504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C2328
2E3D8155443E4D805D705D6B6A888DA05E6B62624B565C74BED085756846393233363433
4E87B099AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
5B565246403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F756957
5550362F2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88
A890544A595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C
55371B1C5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD67
32375CB8A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F
1E30477D763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C0
93CA603B2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A4134
3040777D72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F
6476B19C48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
4C474F6D60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E
7568655D546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F
8CABAD93829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D
25591C1C2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B2
8476B6DCDAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C
1E394D846A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D
75B45D3627263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452
505E7B816E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F57
76A3934D3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
4A43414047958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F7757
5B7B8D9C9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A
5579BECF9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23
184D2C191D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C3
9DC6C38CA4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C
1E394D8A65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888
A4BFB5A08A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44
413C5A877D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAF
A7C3534036282651243F5695573435627A4A8946372B2A7DACAB994239373A46
7E61505551988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D
61644C7097504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E51
4E4B5DC58E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C
1B374E1D2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5
D6B96B7D88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D
1D305B825A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB860
7ACAB4855E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A
5F65838C5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7
C39947453D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
4440382E324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23
387D714EA0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF
929197CEBA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D76
5567996F54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4
D7BD80777A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D
1D28696B506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C746060
91CE86352626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C
4361937B3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1
C6AC352D2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
342D29262220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D
8B7EAE95C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC
9E839FB79E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA7
7E4F4DA4B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDC
C1A29DA891A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B
1C33778654582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C27
41847C241E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F38
40578C8E48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB
8A7B4C2A2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
43322B28251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A49
7E8F9093C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C86
65425485734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B
78424E8190525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2
AE664D69668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D
3258A9A4606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D372621
3D6F953D1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B3435
3B414D76602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0
C287513C25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
724D3325201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D
696F7943667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B
795B77696A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A
7EC570689D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8
CF633548494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C
8381BDAEA771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C2923
3D60885121201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F978937
2A303C756F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B
99ACA5634B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
3D636E48271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75
563D344F37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A
96B9934C481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A2
92A3ACAFBF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9
D1752D45504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B0
91A4B2BB86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26
385794B69B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2
444876BD8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D
8EA0AC98919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
472B3683876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B5541
3C252424495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7
BA7E9FAE621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648
BFC0A4D9BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5
B7AA5E3E44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9
AAC2AB9E9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827
345EB7E0E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2
D5AF9DA19EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860
666F767B95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
4F4D3228798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C352826
26252421324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3
CEA67B3950261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C20252225243883
82BCC6DDC1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5
C5B4985F69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1
B08F8F858CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C3492327
3B7CBA8B6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A5
91A7BEA07DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A
87796E6A849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
41475C81AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE7758413323
1E1C191C1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9
A8BF6E242D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A6550
55B4A7CFBFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3
889ABD9D92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CA
C9CD9A83779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E23
376590453974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B15542
5240366899DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B
353B6177ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
B4BBB3ADC690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C
57564033232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B89
8A4F863F282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E584854
64677AC8A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B5
7B6D8E6F6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A89
71976B4F4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF7035
4E965E1D1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638
201C1C2B5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D
2124346A6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
7A7995689672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46
584C4C51595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D
7877668145383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D484247
7E5183D1BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A
796463403636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB777942
30544034403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74
968A401617171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB14225
1D1A1B1E61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E202027
25232C5C87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
5C766958925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F
4642382E2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B1922412725
3D9E6D64833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D
7849B1E4D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D2930
76575838342F324F7D688C60728B43342F3A6926181617171818278851887CD090643122
222751272B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBA
BF6828171717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B
1A1C1D216FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C262425
27232A5BD5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
AF975E4C6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1
888894ABB4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C
277B9B557CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C
3C68C6D7D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D
7262622F2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C19
1B192A43283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EA
D57A211D1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A
221C1B287AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34
415A94B6B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
A68867493233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C160
5060626F86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E
1E308A7A6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A444351
99C6C0B6B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C2045
5E95662F2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A1817
19171E31422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5
DAC14B1A17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE51
3728296445847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F
748DB0A4A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
5A7B90987A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1
394B3E3B3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75
624984D4B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA0
77AF8A7668A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C
3B925F48433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A230181916
1616161931422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCE
BED695461A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC961
54627B582C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A
70959E9A8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
494F414E69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A
7E473A33353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A
66798298D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443
376C5F4B427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C
4091634B44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E251516
171518161A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AF
A3BCD49C382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B6
8A72514F3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86
827A605B5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
3B312727282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D33435252
854129261F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F
544B444298BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439
212C7145357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D
684B595C4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B2919
15171716151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F46
7F6E82D3C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C188
98C6AEA28BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63
443A2C443D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
332A2423221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434
497E28232022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E72
5345352F779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669
281F546E6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF
9B1E2178DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F37
18171515151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C
56896163DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D
558FD2BFC6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035
302D405B8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
2C2C2624211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F2437
3E5A4F2422304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A
5C2B27275D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA
493E4DABC2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698
912B43848B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A
3329161315181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F2439539242
4B54998BC6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD77
43A159393D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD89890
94A6BFB3AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
332925231E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D
6890BE846B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9
AB2D1D1F58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29A
A6A1BEBA957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989C
C2A37B7E89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632
352C221718171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA84
5B4774BAD2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A5
8F572B1F1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389
806E5C60483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
3C2F2824201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A
3B7BCE9891B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CB
CDA5421A62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798
C7D1B2844E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AE
CAD3A48262678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E45
2A282D2A1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A
474F64AAD2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A2
2D221B1A171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E
3F3326221F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
3C342824201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E
2F3E952D263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F50
65A3BA87A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9
D4C1B4A7ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8
BCD39E755655512D344060729E7367464565715447236FA2CD9842382A1B1B2581614969
4D2C23384D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26
282E427CA5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD779
2220223A362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C28
252524241D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
423527231D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E
3C5F4F2B393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D402323
21499CD4CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674
C5AC75A8C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2
C8CC8947302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F4859
5962484F894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29
272A426B78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B697
83606152434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E27
29252523221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
585C33201D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A399
6783515444322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C
1932ADCCC88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447
706A314877B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489
ADD5BB686F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A43
4F4F6090813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727
252F7CA99DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596
914B433F4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D334625
25252221221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
734D4B3B2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A
83B24C352932684B33685A4670A364455429177A501F25221915151515151616348F986A
74AF9B879CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6
464E1C24384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9F
B1E7E6A54E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B85
41428AA28F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E
63747586BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F
96634F453D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B26
25252321221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
83575C60607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63
A1714D3E55643E46523579784B46899D58493080331E181515151515151515151734BDC3
8548393858C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A
5C3B1D1C203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B91
77D7D17829202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A
5573A987ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D
49404D649DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CD
D8C9C1B08F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C23
25252523201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
6C674E494A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C7477
943533565F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB
5C5E6B8FBBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F22404165
9C301915171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C315976
8CBD96452E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173F
C1B396B99B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A
3744384E7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3
CD928C7E9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F
22241F1C1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
39617BA0BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE
6F3268493C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D
7E918B8194CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86
BA35151519171B1D62814D50231213153920245C7853543D363E222721211C1C19266492
9FB88D35301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643
B89ABF91398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D
4E3C2F5B772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC384
8B76513F3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D
1D211D1C1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
2C57CFDCD7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4
627D46454C2A202534421D1717171E37574C92A766501713111311141514131314217A39
2B3D312B44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D
936E17171615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AF
DECB923320161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1
947BBB99585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C4749
52513E65591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B687037
4D7B3E464333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C33
1F1F1D1D1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
4185B47D7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9
C6713A321F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B
1C26242B4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076
A8A63A19151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BA
E5E1D5683817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181
603B5CA8A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A
394C5EA262491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F23
28544D293C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B4373
5C31313E84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
564E4F46434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5
D26A2B22282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE55
2224252F4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F
62A7836B3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9
E0E9D5D185352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E62
422842677B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E
26357BB28B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A33526
2129592C29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D
51767A736A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
4B453F4F5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7
C8B12B1C1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC0
59251F28598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D
5B656D6280692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8
B1D2D2C1CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E
2D3437465A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B55
87B3CACD764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A78046
2622394B2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E8635304268
7367799990806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
96855D33223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B
9C9C8F333D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D
92653D43778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A2647
96688B3356627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A
5C99CEBEB6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56
313B42434A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE82
5F4F5A90703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B9271
5748355D40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A
63595D6F95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
8A9D36251F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C788
97989BA55E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A
968C97B09E906724171515181715171A192C8A563D727C8519183C311A1515151C1D1517
55979A312248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135
324EB6C5938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C72
464933191D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C
2C35466CB7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A
4D453D6E636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A83
8C96848178787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
507756251E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B3
6C4A6384A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B46383231232630
6BB4B5896598494B1915151515151517161748945146678617172539191A1C191D1F1C17
1D76B67220203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748
436A8DBA73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F
4F1815171735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B25
2F322B2DC6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44
233E68678B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F8068
524242414B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
484D7B2B1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D
894B35385E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C3337
5A77939E83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C
1931DCBC4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C
989C9BA56E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B18349
33171514172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C
2D181739AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C5164
1F238A9FA76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C
3F3F454B6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
56445267242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D
43784F4D3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E
2B315485A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B
3871DDD5AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D
403E688B6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F52
3215161515222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C47
3D3B394C8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A
3B557D433894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F38
4861584F2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
7C5D495779858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B49
38386A52625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B
201F2256A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B
797996B5D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A21
24262618536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B419875
3617171515151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760
272A3E637677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756
A97D393129B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A556435858
4B2F201C1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
806A52638C7D656351352319231915151513131313105C9B748652A426191B2070857489
59785A653A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D281917193382
35313449B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A82
6C421B2888DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C
2F1514151C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D
5529151515161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B45
4F3734596C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E
682D1D1F669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C
18151A1D1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
515D5059768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D33
1E2315175A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589
CFA6A4B4C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C36
1D1C15151FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C16
10151514121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B74
4B5427151515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A1722
3B616C5E8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A1920
3F1C2066C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD58161718
18181918191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
493A4C5563877E5452572F22462013161513120E12155071726E477F46161010100D0F12
10151413195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87
A5655567A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C
2120201A36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E351610
1015141613152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C39504972
5E53602F151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B19
19275FAC945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D
322361BB6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D1516
19171918171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
6F5C52846B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E
0D1115121435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D
52466A9A9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C36425560
6A77315B8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B362514
1315151114131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258
804B445F5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15
171C3F705E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C29
2C6CB3705140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A18
15151518162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
3F445B509A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D
0E100F121B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C
616E4E476D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D2834
3756AE9B4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C15
131111111314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B59
52793F77B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A2517
1A2E54656354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C36
81A37154361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215
151B15181A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
34292E8C5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D
0E0D0F2E60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644
424E283C6B7193908B71A58F66504030323F5062756E9386BDA0CC952C29171513162121
3226917296AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E3719
1313130E10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64
474A7A9EAE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148
525F765C854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F
906E6D261718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C314721
1717151A17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
372A275A775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12
233B4A3D2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E40723933
3944552D201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A15
1522A4C3B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D
141315151015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4
A554A7B38031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C44
46446181BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE82
7964241A151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B45
17161719192522202868B596634780532126338E5C3F54569C5AA5895B645159
372D262887495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C
3A281E1F211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A
3E2F2E1B15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F
4A9E8096A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C
1311101013133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB7254
54699CA26C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733
373950B79A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B
6A351C1717191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45
321B1A1B201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
38292922549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B18
151818161A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A3822
1D231D1C1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4
AB554EA48979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A
53311B111C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F
4A8EAA8A514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D96432927
2C3849C38C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD93
3140161817171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F
783F34363844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
352A292558D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C18
19151E1D1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E
1D1E1E1B1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF
7671A2C3ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E
52404D4F64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86
AFC5CF765D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728
242C55AE82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C6
694816151715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709D
C6C19B7E7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
41485F666B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E
191B3D484B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C
39354843619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B131415165242
252448775F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C
5D7E59566E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772
BBB9CCC7704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C
3E2C7E8D5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8
AC915025171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2
B48E8DA0ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
786A564641396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A6752
4C76664F4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F
674954899770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F1518424121
1D1D1D455541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E43
7FA0AFA3977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F
6C64759431192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6
ADA9BC8795B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674
B47B9C988C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3
B9B2839C9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
56554B2A1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D73
42362D2D2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F8076
6991AD6A49382A322C3D70875E4130758B924215372524211C2959706D5B332A43312719
1D1D1F365A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E6964
6AD1BD9B8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F
2535356A74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBA
BEAA7C94B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D66
9A4B404D73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B070
8CCFA594766583A953A1A238374472CC8C80A08C331D202857594282642F334D
403B32201D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA07864
5A4F515E5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B80
7EAA643D322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C
2226262E5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A1965
4EAF8862615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D18
15243547AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D82
8BA5C7D9DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4C
AF4A221F283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E77
9FB0B26899C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
36382B1D211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4
583E2B201B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064
976E484835261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D
1E262E255359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B
4D483E3F42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33
162F272B79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C
304090C1DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87
CF71232A2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA9919898
5853AC823D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
34362B24242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B
1713131415151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A2
90584140211615151515152230365166623E303765A54D37353F59638D90A176604C3C34
3936454E7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF77
6F61371B1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F
1929212A6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E47
2B29478FCF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F66
5163552B2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A45
333353896849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
3037302546433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F
1311101512141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F
6F4A4B2415151514151515152523335B694045333F8F7E4946537791A8C4C89B663B4959
66748594A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC06553
75AD691B223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B
18292C2B701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D3963
3D414978C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D7736
2D3346574126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B22
3359292477CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
344F73423E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D40
1810111415191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD
915542171313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B30
37414244475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A787
6A4A653640474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C
171C343473171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B68
3D2B3291D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454
483B3A4D4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224
351E1C1D7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
6C6B50553626234C42171B686057585721151113110E101013174D984C819B9B35327486
723835373D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1
BE9C2415141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E
1E2021273660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF
5B2C306043303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C
1D1A3F4691171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D
414EA6D1D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E
566A38404C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B084639393432823
1D1A1D44AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
AF554435292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C
6C574231281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7F
D09E1C1115111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C
6649476F7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3
AA3D2A2458422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A
1D215E6CB21310151517372E2C6238352C79803828272C2F2F353C4558A0978069433636
91A07C979DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515
174E7B2E383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C
191B417955904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
917B6F545671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A
2B1A15131313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CAD
B18A53373D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7A
A0899E92B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A
6676552B275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921
252C4CCACA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229
A38C6737409CAAB57729201B42C04817171522579784A43E276E7A3B34661F3223151515
15174085403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B
1E356D5E795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
AD644F536E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B
1413101011141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC9
55277D321E191615151515151515153F4A624256C592791F1B181515151118986A58549D
B0BF948E9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E653643
594454603C257047304E6A945C5653919B624453301315182466642A1515192542743B39
375AA4D6A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC4329292487
9859221B32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D32151515
1515164A8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B3742
31507B6892272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
A6736991B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C4219
1513110F101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C
7B334C141511151315141415151515161F388264A6643E15151515151411275B332B3493
698D585A86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C
2839444B55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A
83B3BD7683665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A34328997
55171517795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A40171515
151513153FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255
558B6CB12C35684D5774553A455668903F314377A192361C266F31191719236D
B2644F445C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F
141512130E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA0
6EB79219151315131315151515151511111A69AAA9983A151513131511154F361D244A79
3D8241252F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E585252
4F575551524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2
CDC5842D1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F56
2C1C174C433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A1515
15151213157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B
877AAE6427538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
C658392E30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F
1F151515151615151415151315151D7446371915172040B2A0735F6851372432702D379B
7DCDC35A1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F
3F91532B29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A27151514
18283B3346567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1
D67F44314B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B27
2027474C302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D64391613
151513151852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B354670
97BB80326C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
72643F3B928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C
4F321915121515151515141315153E673C2B181413173A665676301F1C1A161B3F532747
77B8BC785218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D70
4F47484C37466094929A873E2A386517101013162D38353D628F946A883A5B4414141311
13151D28202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CA
D566545F797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B
225F5236312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D
202D374C39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94
ABBA97A18F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
5B4C5BB19A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B
6D241D16151515151515151515155961372C1513102665393A47261C1A191C1C192D281F
4997A18B6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F
351C15265A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E631711151514
1313131B2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64
B690668291845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A537047
716540362C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE92
5B443E6EC2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BB
C18FC5C4492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
98B9D3B58C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022
868C5A4C392F271C1713141515215B4E3321181515475F25293D2B1716172F1F15131115
1B80769483829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D
1915152B3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC595311515111513
111011152344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142
ABDDD4BDA4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9
A59AA6A3B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5
C79690C8A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC
97866C8F1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
4CBCA5656D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783
686B59544B4C50564E3A2512114B503D2C25181526663E1F1D4627191D44211515111415
178451869F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B2029
2019263A323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E
0E11131315465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F
98C59D928E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1
EAEAE6ECF5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698F
B1DCDB90607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB2
5373476A1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
6F94534B4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC
9B502B333B46504947425E5C558E4623262A181C6A59241C1D7230171514141515111514
2FB46158A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149
292B3840605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC7686221513131410
111013111551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E
9FA63C6B6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDF
FFF5F5EAEAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2
BFC6D38F6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE63
556445622D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
A664534F52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9
A29A2D231F2229374B4A48448EB4745B546850647E342F40518646161510121013101553
99626A56AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB87889159
2C3553583B1C151788B6C19875555054523F362F222326286AAF909F78536B1314151310
0E101115355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807B
AA9E6C3B151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4
C9C5C0CFCFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B76
6AAAB73320476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C32
6869415F561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A24B45575C3025261F1C20306874A594997A564134362926271E286B1313131949BCA388
9F8A9A3B1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63
291E534F8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA8
905522151315151563568C7397704A3F332F2D29241F234D73A791595D4D854415111315
11131A494D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262
C15970231515141316171B4357478F744F81A53E574125171716174068454C8688B69CC9
96778B9F8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C2455
40736C1C23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D36736
7053325A672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
CAA0908E61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B1
8E9F98A6673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D6124
1615209DA6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B4143
6D26141515151522734070444B2723262A2A303B3243655A5B7051585572689A2D191510
113645392345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965
A463501514140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C8
9175935B443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A183472
2D7443223F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A
92482B475D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
D2D0AF875F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5E
A0A4A2BCD9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F242415
15172F98AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486
865C4C48484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B4431
43352825428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094
A44A1A12131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A9
90473B3D5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F32668987
79763B17432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93AB
ADB36F4555AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
8A7B98C586564D57616540304F7492A4874536263632302B2B30501A1317171315323D25
3FAECCDAC194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D1615
1418425C474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D6060
78523F38362A35468DACAFA3781B15151415131740342F3A31151517276535799372A269
3D35366099545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CE
C86120171115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B91
83495485C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D517765443634
7EC64F1517211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77
578AC4C8C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
7B6F476D6C7E785450618A877587A6D8C293474153443F35377C251A12182A2822335034
1D50D2D3CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E7456
46586B453764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E
5264362F2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0
C8CCCCDAB1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A
708A7D6F3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB0537127
88AB989B7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC865935262129
4EAABC301921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0
D8C9BBC3CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
AE7E5D5F5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A
36747F88C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283
B5DE9731317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729E
B09B6253504A473024858F686F5542382F292931303738161515151528351735A9878C97
B9AAB4C1AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F
1F2C2833385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54
918D78546D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6D
A3CEA69851372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A587
6F8DAFBED5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
766E7072748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C
797E4A3B9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F212731
53BD942C3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B
66773C201C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C
5AA5D79C815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C
1C222D291A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA
6C3138629CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D
929E9A547677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217
181A2D5581A8A79095886757474540445A82B48244426C17181C1C5763533839
4E494C4E4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D
8D7F4637813A152F3213100D1049501A1B171E743F29151515193334362617151519171A
206DA131552C151111111516161515235B54695F504337293F85526578202C6488392C29
2B471716151515161515334C73AFA481594C5A785C262F54271615171B25185034182E30
4359BD93564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C3962926
1D1F252B231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD43
23232C21AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B75875729
1D22836B5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A17
1B171C2F687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
4333452F2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B
714D58328336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C
1D4481405821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A
2D301615151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F
2041A26C27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C
231F242E2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24
252F41534737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F
1F1C6F9E773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C517134
1D191A1F9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
3C303A261F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E
2519393584361113120F100D0F1C9189231B1933913D111011111314141314132021161C
1D506451481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A
342A151515151515151515453A6B84764C60BF56452821222E487465314429421B161F24
1E2C8964241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B
394C5B4C5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644
467A5731171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E25
3D3DA2585963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F7050
4D3E222F774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
363337251F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C6227
15131B2C823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A
1C6E8C77331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B
30291516151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D
1D21838C2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D
445A98A69DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF59
4041211B1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F
809CBE6754748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D365864
2D3C6AA7613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
374031231D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D17
1415152E84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F
2A90AC732B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23
342C15151515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B
202389CA7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34
322C3770A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94
352F1B191B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365
403C3C4F7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C792727294078
4D2A3B5368512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
42482D221F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A
1815151B8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F
4CA48458211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D
2F311514151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A
2F61B3A0A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515
264D3F3F506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D53
59651A171B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C43
6A6D5C4769B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E
973D4944583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
5F7A3F2C221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A2
6017152FBF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0
D7CB7C663011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D
3440151313151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E
99A948244D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F3431501518
15194AB4A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E
36451B171A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817
172248B7B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F34
8C863D404B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
5A824F2A241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7A
AB33194FD5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857F
C7D6DA91761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D3661
81811E1515181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397B
C26F221D1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D531516
1515238054423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D
3A271B16161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B181717
15162F96BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E
51947A345884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
8C658A3B241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B265050
91AE92C7C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F25
2A67B3C2CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E25
72CD90767A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA
93A6321A171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D15
151531431D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C051
472818151B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617
183E649E7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B
29458DA1A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
4F6D548C4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D
8CD5C67D4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3
784DBFC3B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295
B4BEA6855A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D499
57A17F2E1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B
171A4D341A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F
56472B3254436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E16161619
48606C60353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A181918
2B2C4397C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
9D80705B9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A49481
83BEAC2C1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A
7CD5C5ABC0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090
D24B25353F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A1
2E3D9E7D2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B
78A38726171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4
BEAC9098AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B
5A5351384C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A
21303F75A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
B2A29A8388CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E50322532
3D42975A1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B19
2AC2CB95D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB67
7E5C1C1C1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA
6D2E55C2A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA56636
4272A23A15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148
553A2F4D83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F51
54584549231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747
486587A0B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
4A98AF78BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C1721
2B2546761F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F
76BDA75CD6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD
5661241D1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E
9F4D356ECEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B8669
7068546046256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B41
312629434446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB26245
4E5F381915161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F
776E8EA6D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
4B7496A9CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C
1B2F25494817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B
5DAC5366C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754
A5744E211E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758
A7A45959CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F70
61423F414D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C661738993
85724E52A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B
60231915151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E314659
80B1BCD4CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
5959717EBCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C52
181938509E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E10
115723429C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E1519
66AB8E4C2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F
7AD48095A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A
2F282B68AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338
363D68AEDABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D
3015151619171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F52
88AAD8D8D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
42373B3D7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F
3B2B569761291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E10
254319439173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D16
4464BF8E42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D
9EC4BC7A948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A
844F75B0D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A311715
14151841AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983
571D15151517151516255D6983808E834242384F5B94828497987E7B423933415055716F
6DCFD8D6B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
372D2941688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F
2C335E6441392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E
1F401B408F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E
384460D7D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D
6FA4C6B88874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BA
C66E67ACCBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B36
22151738645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080
693D151315151515152048667F7884634339223A509361C2AEA8C2646265859F72513133
AEBFB0AC7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
352A2678CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E10
10134E281D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E10
10482A479C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285
B17EA2DEE289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168AD
A1A2A5A08D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A0
8345395D94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F
38424C965F4C572F27375F9980131515151515151A598EA8C0B2BA64729C332523212549
72683F151515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AAD
A9695A82968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
312A3249AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D
0E1F241511111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F
0E304278CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111C
B2DFE7DBAABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C
79B5C78D815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E
3647509EA165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E76
79725B88B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F2526
59645E52271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A489
4D2931827266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
3B3F4764846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E10
21311615130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11
103E8E98877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B5517131013
8CE2EAD8C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B39
4595CA664A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A87566
62869BD9891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A15151519
24354E8CB0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B32834024242424
2C6E5545534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B
2920265B376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
493C342722554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D6365
7019131010110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B
637D7B59735A5447586023100E10100E123340212558130E10100E0E10191D4733151647
B9DBE7BCAD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87
906A774E51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C0
8E775287A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B7817151515
151518654F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24
264D7E4A474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C
221F35362C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
38302C251F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E
8C4913130E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C7880
61525A5969B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735B
A7B4BDCCB26E51703C14141514233844191517358155462F1F4355162352685C59617BB0
B8731D131A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B
2620232A69AF7B4854636752938827345A719270723834353D4CA1BF2E3E655215141315
15151F865B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D76
5E61A3836F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB342922
1D21452D5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
322C2625201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F817068683024294846
3584371210141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C65
5C333C76599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E
77A6ACCF8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D57
8629151513173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37
221D352C258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B6419151717
29383F46806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A
8697547297C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C
1C49334A586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
342A252738595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B42
2C38944715133D622B17151527541110120E0E23676946673048686C6E768E9271725653
527376A05C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E
5370BB87596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B3222
7F7C3B14111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D
27204532293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39
301D21222E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E2025272729
73837D7A6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30
564E2D2E404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
333448655A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E41
32244DAB5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E
403E558B6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A
636095421F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C58
974953604C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E75
3E36342C292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A6047322320
22212326262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468
483C4C799E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959F
AA462F2F376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
61745B3E3D40362519183A483787BC9BB93019191517151418182938486844495550584E
3B392753D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B1515
10255F2E254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B47
5C5B7D3A2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E
38443432476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3
A161503F45422F192F69A78FCDBDAC9158171515151515151516215C5D5E547655222125
2A262019171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A
2A23242B3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4
A38F878C938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
6B4C4A3A291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72
593F362FC1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F1215
23662F0E0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F
2D2C6C18171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C
18333B3C323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBF
C493A387948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33
322D241F1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26
301F1E1D2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A
856D717FC8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
75483229241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B
6A71708CC8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D
6F280E0D0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B
1C28891D1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A
151619243D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E
9C4545413846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F
81604A332D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F29
2B1E2125375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D
884F4161A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
893D362B271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29
424884C6DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB
730F0E0D0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E53
2544654D4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F
271C1F1C3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C
9E46512F1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F
3E618285817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D
232E464F36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C55
6F7D6C81898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
91464141341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C
3A5DBCC8CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C2
8C2715100D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D606054
5E8517141F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C
8B6559535C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5B
CB7E401E1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B5261515
171617192D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D1517
19192B3A3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77
515B884C3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
8E633D39373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D35
84D1BA8FC1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88
B0B590583118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6
C9A93B161615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B8
8C392D2B203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E
6A3F704D20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B1811
161613111315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F2415
151519387FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C63
7A5773504C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
7A8A433B322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63
CBB8593D83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C3521
28566D6D6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0
846D63624F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C
7B1A1815151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194
521E12446F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F15
151515151516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C29
172858716B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E594439
47758C6CA4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
758F52352C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2
A246293868B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C29
1D1E3451432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A
69652C242D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82
891C17171C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9
972B121319625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC6462926
18151113151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D
57615883B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830
363CAFBE9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
6483B96B413A2E355B7950411711110E16423175695F321311141917151E1F252550A493
78693B6B6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B
5955454E3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A81
7A7D8357565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6
B1231D24586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBF
C07745211217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B
3E23151F1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB2
8F80A0784E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC6582527
2D3CA9A36D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .57528 L
.2381 .57528 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .57528 L
.2381 .57528 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04192 L
.95238 .04192 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04192 L
.95238 .04192 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02169 L
.2381 .02169 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02169 L
.2381 .02169 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .4641 L
.47619 .4641 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .4641 L
.47619 .4641 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .14121 L
.71429 .14121 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .14121 L
.71429 .14121 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01481 L
.95238 .01481 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01481 L
.95238 .01481 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF800000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FFFF000000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF800000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF0000FF000000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
FF000000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
0000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF80000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF000000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
FF00000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
FF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF0000FF0000FF000000FF0000FF00FF00FF000000FF000000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF00FF8000FF800000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF800000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FFFF0000FF800000FF00FF00000000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FFFF00000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .1118 L
.47619 .1118 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .1118 L
.47619 .1118 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .50123 L
.71429 .50123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .50123 L
.71429 .50123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01355 L
.95238 .01355 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01355 L
.95238 .01355 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF8000
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01543 L
.2381 .01543 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01543 L
.2381 .01543 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01898 L
.47619 .01898 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01898 L
.47619 .01898 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02106 L
.71429 .02106 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02106 L
.71429 .02106 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .58633 L
.95238 .58633 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .58633 L
.95238 .58633 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF000000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF000000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooooaKoo`001?oooolG
o`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0
003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
ooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooo
ooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo
5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo
001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03
o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
1?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0goooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?l007oo001o00;o
001o5_oo001Eo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l07Ol007lGo`3o00Co
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0=ol007lGo`00oaoo
001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`1Bo`00OaOoogl01?l007l00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000oooo
ooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00
Ool007l0D_l007lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?oo
ool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l0
07lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
001oo`00O`02o`00OaKoo`00EOl007l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o06go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0go`00OaOo003o7ol007l00ol0003o
ooooooooo`0Tooooo`03o`000?l007oo001o05;o001o5oooO`04o`00O`03o`000?oooooooooo02?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02
oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03
o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`00
9?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;o
oooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02?ooooo000Tooooog7o
00009_oooomao`0002OoooooLOl0000Vooooog7o00009Oooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Goooo
ob@0o`000P3oP00@0?l00080oh007P3o00020?n000D0o`001P3oP00<0?l00080oh001`3o00040?n0
00h0o`003_ooool2003o0080003o7P00o`020?l000030?n00000o`000?l000@0003o4@00o`020000
o`@0o`003P00o`040000o`L00?l00P000?l00`3o00000?l0003o00050?l001/00?l01`000?l2003o
00kooooo1@000?l7003o00P0003o0`00o`0B0000o`800?l03P000?l2003o02T0003o00<00?l00000
o`000?l03@000?l00`00o`00003o0000o`0B0000o`koooooJ03oP0020?l000T0oh0000<0o`000?n0
003oP0001P3oP0000`3o0000oh000?n0000;0?n001Wooooo000Gooooob@0o`000P3oP00@0?l00080
oh007P3o00020?n000D0o`001P3oP00<0?l00080oh001`3o00040?n000h0o`003_ooool2003o0080
003o7P00o`020?l000030?n00000o`000?l000@0003o4@00o`020000o`@0o`003P00o`040000o`L0
0?l00P000?l00`3o00000?l0003o00050?l001/00?l01`000?l2003o00kooooo1@000?l7003o00P0
003o0`00o`0B0000o`800?l03P000?l2003o02T0003o00<00?l00000o`000?l03@000?l00`00o`00
003o0000o`0B0000o`koooooJ03oP0020?l000T0oh0000<0o`000?n0003oP0001P3oP0000`3o0000
oh000?n0000;0?n001Wooooo000Gooooob@0o`000P3oP00>0?l000D0oh00603o00030?n002@0o`00
1`3oP0040?l000L0oh003_oooolR003o0080o`0000<0oh00003o0000o`0010000?lA003o0080003o
103o000>003o00@0003o3000o`040?l001h00?l01`000?l>ooooo`D0003o1`00o`080000o`<00?l0
6@000?l5003o0080003o1000o`0Y0000o`03003o00000?l0003o00d0003o00<00?l00000o`000?l0
4P000?l>oooood@0oh000P3o000>0?n00080003o=03oP00Iooooo`005ooooolT0?l00080oh003P3o
00050?n001P0o`000`3oP00T0?l000L0oh00103o00070?n000kooooo8P00o`020?l000030?n00000
o`000?l000@0003o4@00o`020000o`@0o`003P00o`040000o``00?l0103o000N003o00L0003o3_oo
ool50000o`L00?l020000?l3003o01T0003o1@00o`020000o`@00?l0:@000?l00`00o`00003o0000
o`0=0000o`03003o00000?l0003o0180003o3_oooom40?n00080o`003P3oP0020000oc@0oh006Ooo
ool001Oooooo=03o00070?n000@0o`000P3oP0070?l000<0oh001P3o00030?n000H0o`0000<0oh00
0?l0003o00007@3o00030?n000P0o`001@3oP00>ooooobD00?l01P000?lA003o0080003o103o000@
003o0080003o1`00o`020000o`<00?l01@3o000O003o00D0003o3_ooool50000o`L00?l02@000?l2
003o0180003o0P00o`0>0000o`800?l0:@000?l00`00o`00003o0000o`0;0000o`D00?l04P000?l>
ooooocH0oh000P000?l90?n000030?l0003oP000oh000080oh000P000?m20?n001Wooooo000Goooo
ocH0o`001@3oP00F0?l000<0oh001P3o00000`3oP000o`000?l0000F0?l000<0oh003`3o00050?n0
00kooooo8P00o`090000oa000?l01@000?l40?l000L00?l00P000?l3003o00@0003o3P00o`020000
o`X00?l00P000?l9003o0080oh001@00o`020?l000D00?l00P000?l>ooooo`D0003o1`00o`0X0000
o`<00?l0?@000?l00`00o`00003o0000o`0B0000o`kooooo4P3oP0020?l00480oh000P000?lI0?n0
00800?l02P3oP0020?l000/0oh006Oooool001Oooooo=P3o00050?n001H0o`000`3oP0060?l00003
0?n0003o0000o`0001H0o`000`3oP00?0?l000D0oh003_oooolR003o00T0003o4000o`050000o`@0
o`001`00o`020000o`<00?l010000?l>003o0080003o2P00o`020000o`T00?l00P3oP005003o0080
o`001@00o`020000o`kooooo1@000?l7003o02P0003o0`00o`0m0000o`03003o00000?l0003o0180
003o3_oooolB0?n00080o`00@P3oP0020000oaT0oh000P00o`0:0?n00080o`002`3oP00Iooooo`00
5ooooolR0?l00080oh00;P3o00020?n001l0o`000`3oP00@0?l000@0oh003_ooool20000ob000?l0
2@000?l@003o00T0003o1@00o`050000o`800?l010000?l7003o00T0003o2@00o`050000o`D00?l0
0P000?l4003o00030000o`00o`000?l000@0003o00<00?l00000o`000?l00P000?l>ooooo`D0003o
1`00o`090000o`@00?l06@000?l5003o01@0003o0P00o`000`000?l0o`000?l0000T0000o`<00?l0
4P000?l>oooooa80oh000P000?lb0?n00080003o@P3oP00Iooooo`005ooooolR0?l00080oh00;P3o
00020?n001l0o`000`3oP00@0?l000@0oh003_ooool20000ob000?l02@000?l@003o00T0003o1@00
o`050000o`800?l010000?l7003o00T0003o2@00o`050000o`D00?l00P000?l4003o00030000o`00
o`000?l000@0003o00<00?l00000o`000?l00P000?l>ooooo`D0003o1`00o`090000o`@00?l06@00
0?l5003o01@0003o0P00o`000`000?l0o`000?l0000T0000o`<00?l04P000?l>oooooa80oh000P00
0?lb0?n00080003o@P3oP00Iooooo`005oooool50?l00080oh00K03o00000`3oP000o`000?l0000D
0?l000kooooo5@00o`040000o`T00?l02@000?l@003o00`0003o0P00o`0;0000o`L00?l02P000?l8
003o00D0003o1@00o`020000o`@00?l000<0003o003o0000o`000P00o`070000o`kooooo1@000?l7
003o00P0003o00<00?l00000o`000?l00P00o`0G0000o`D00?l05P000?l30?n000@0o`008P000?l3
003o0180003o3_ooool@0?n00080o`000P000?ld0?n000<0003o3@3oP0020000o`L0oh000P000?lW
0?n001Wooooo000Gooooo`D0o`000P3oP01/0?l000030?n0003o0000o`0001@0o`003_oooolE003o
00@0003o2@00o`090000oa000?l030000?l2003o00/0003o1`00o`0:0000o`P00?l01@000?l5003o
0080003o1000o`000`000?l00?l0003o0002003o00L0003o3_ooool50000o`L00?l020000?l00`00
o`00003o0000o`02003o01L0003o1@00o`0F0000o`<0oh00103o000R0000o`<00?l04P000?l>oooo
oa00oh000P3o00020000oc@0oh000`000?l=0?n00080003o1`3oP0020000obL0oh006Oooool001Oo
ooooRP3o000>oooooaD00?l01P000?l:003o00H0003o4000o`090000o`03003o00000?l0003o0080
0?l070000?l8003o00D0003o4000o`070000o`kooooo10000?l:003o00L0003o1000o`0G0000o`D0
0?l05P000?l20?l000030?n0003o0000o`0000@0o`005`000?l20?l000L0003o0`00o`0B0000o`ko
ooooRP3oP00Iooooo`005oooool70?l00080oh00?`3o00000`3oP000o`000?l0000]0?l00080oh00
3P3o00020?n000kooooo5@00o`060000o`<00?l03@000?l@003o00T0003o1@00o`0G0000o`800?l0
0`000?l9003o00@0003o3P00o`020?n000L0003o3_ooool40000o`X00?l01`000?l6003o01D0003o
1@00o`0F0000o`80o`000`3oP0040?l00200003o0`00o`0B0000o`koooooRP3oP00Iooooo`005ooo
ool70?l00080oh00?`3o00000`3oP000o`000?l0000]0?l00080oh003P3o00020?n000kooooo5@00
o`060000o`<00?l03@000?l@003o00T0003o1@00o`0G0000o`800?l00`000?l9003o00@0003o3P00
o`020?n000L0003o3_ooool40000o`X00?l01`000?l6003o01D0003o1@00o`0F0000o`80o`000`3o
P0040?l00200003o0`00o`0B0000o`koooooRP3oP00Iooooo`005ooooom80?l000<0oh00>P3o0000
0`3oP000o`000?l000020?l000kooooo9000o`070000oa400?l020000?l5003o01@0003o00<00?l0
0000o`000?l01`000?l9003o0080003o2`00o`000`000?l00?l0003o00020?l000D0003o0P00o`0>
ooooo`L0003o1000o`030000o`/00?l05`000?l5003o01T0003o0P3oP0020?l00200003o1@00o`0B
0000o`kooooo3P3oP002003o07X0oh006Oooool001OoooooB03o00030?n003X0o`0000<0oh000?l0
003o00000P3o000>ooooob@00?l01`000?lA003o00P0003o1@00o`0D0000o`03003o00000?l0003o
00L0003o2@00o`020000o`/00?l000<0003o003o0000o`000P3o00050000o`800?l03_ooool70000
o`@00?l00`000?l;003o01L0003o1@00o`0I0000o`80oh000P3o000P0000o`D00?l04P000?l>oooo
o`h0oh000P00o`1j0?n001Wooooo000GooooohD0o`0000<0oh000?l0003o00000P3o000>ooooob@0
0?l01`000?lA003o0080003o2`00o`020000o`800?l00`3oP00=0000o`<00?l01@000?lI003o00@0
o`001@000?l2003o00kooooo1`000?l4003o00030000o`00o`000?l000d00?l04`000?l6003o03`0
003o1`00o`0B0000o`koooooL@3oP002003o00<0003o2@3oP002003o00T0oh006Oooool001Oooooo
Q@3o00000`3oP000o`000?l000020?l000kooooo9000o`070000oa400?l00P000?l;003o0080003o
0P00o`030?n000d0003o0`00o`050000oaT00?l0103o00050000o`800?l03_ooool70000o`@00?l0
00<0003o003o0000o`003@00o`0C0000o`H00?l0?0000?l7003o0180003o3_ooooma0?n000800?l0
0`000?l90?n000800?l02@3oP00Iooooo`005ooooon:0?l000kooooo9000o`070000oah00?l00P00
0?l2003o00<0o`000P00o`070000o`L00?l00P000?lI003o0080003o0`00o`020?l00080003o00<0
0?l00000o`000?l00P00o`0>ooooo`L0003o1@00o`040000o`T00?l05`000?l4003o03h0003o1@00
o`0B0000o`kooooo5`3oP004003o06l0oh006Oooool001OoooooRP3o000>ooooob@00?l01`000?lN
003o0080003o0P00o`030?l000800?l01`000?l7003o0080003o6@00o`020000o`<00?l00P3o0002
0000o`03003o00000?l0003o00800?l03_ooool70000o`D00?l010000?l9003o01L0003o1000o`0n
0000o`D00?l04P000?l>oooooaL0oh001000o`1_0?n001Wooooo000GooooocH0o`000`3oP01:0?l0
0080oh001@3o000>ooooobD00?l00P000?l2003o0080003o8000o`050?l000@00?l000<0003o003o
0000o`000P000?l7003o0080003o6@00o`020000o`<00?l0103o00030000o`800?l03_ooool70000
o`L00?l00P000?l9003o05/0003o00<00?l00000o`000?l04P000?l>oooooaL0oh001000o`1_0?n0
01Wooooo000Goooooa00o`000P3oP00T0?l000<0oh00:P3o00000`3oP000o`000?l000070?l000@0
oh004P3o00020?n000D0o`003_oooolY003o0080003o8000o`050?l00080003o7000o`020000o`/0
0?l00P000?l8003o0080003o0P00o`0>ooooo`@0003o5@00o`1`0000o`kooooo3@3oP0000`00o`00
oh000?n0000;0?n00080o`0000<00?l00?n0003oP000JP3oP00Iooooo`005oooool@0?l00080oh00
903o00030?n002X0o`0000<0oh000?l0003o00001`3o00040?n00180o`000P3oP0050?l000kooooo
:@00o`020000ob000?l01@3o00020000oa`00?l00P000?l;003o0080003o2000o`020000o`800?l0
3_ooool40000oaD00?l0L0000?l>ooooo`d0oh0000<00?l00?n0003oP0002`3oP0020?l00003003o
003oP000oh0006X0oh006Oooool001Oooooo0P3o00020?n000`0o`000P3oP00V0?l000030?n0003o
0000o`0003@0o`00103oP0050?l000@0oh003P3o000>oooood/00?l00P3o00000`00o`00o`000?l0
00020000oa`00?l00P000?l=003o00<0003o0P00o`030000o`@00?l03_ooool20000oa800?l000<0
003o003o0000o`001000o`1^0000o`kooooo<P3oP0020000od00oh000P3o000D0?n001Wooooo000G
ooooo`80o`000P3oP00<0?l00080oh009P3o00000`3oP000o`000?l0000d0?l000@0oh001@3o0004
0?n000h0o`003_oooom;003o0080o`0000<00?l00?l0003o00000P000?lL003o0080003o3@00o`03
0000o`800?l00`000?l4003o00kooooo0P000?lB003o00030000o`00o`000?l000@00?l0KP000?l>
oooooc80oh000P000?m00?n00080o`00503oP00Iooooo`005ooooom_0?l000@0oh001@3o00040?n0
00T0o`0000<0oh000?l0003o00000P3o000>oooood800?l00P000?l7003o00<0o`001`000?l2003o
0080003o0P00o`020000oa400?l00P000?l=003o00<0003o0P00o`030000o`@00?l03_ooool40000
oa000?l00`000?l4003o0580003o00<00?l00000o`000?l06@000?l>ooooob@0oh000P000?lG0?n0
0080003oB`3oP00Iooooo`005ooooom_0?l000@0oh001@3o00040?n000T0o`0000<0oh000?l0003o
00000P3o000>oooood800?l00P000?l7003o00<0o`001`000?l2003o0080003o0P00o`020000oa40
0?l00P000?l=003o00<0003o0P00o`030000o`@00?l03_ooool40000oa000?l00`000?l4003o0580
003o00<00?l00000o`000?l06@000?l>ooooob@0oh000P000?lG0?n00080003oB`3oP00Iooooo`00
5ooooolW0?l00080oh00AP3o00040?n00100o`001@3oP0020?l000kooooo>@00o`020000o`D00?l0
10000?l3003o00h0003o0P00o`060000oa400?l00P000?lB003o0080003o1@00o`0>ooooo`T0003o
0P00o`070000o`800?l08@000?l7003o0340003o00<00?l00000o`000?l00P000?l2003o01D0003o
3_oooon:0?n001Wooooo000GooooobL0o`000P3oP0160?l000@0oh00403o00050?n00080o`003_oo
ooli003o0080003o1@00o`040000o`<00?l03P000?l2003o00H0003o4@00o`020000oa800?l00P00
0?l5003o00kooooo2@000?l2003o00L0003o0P00o`0Q0000o`L00?l0<@000?l00`00o`00003o0000
o`020000o`800?l05@000?l>ooooohX0oh006Oooool001Oooooo1`3o00020?n000@0o`0000<0oh00
0?l0003o00005`3o00060?n005H0o`001@3oP0020?l000kooooo>@00o`050000o`800?l00P000?l7
003o00`0003o0P00o`060000ob`00?l03_ooool50000o`800?l00P000?l2003o00L0003o0P00o`0Q
0000o`L00?l0>`000?l2003o00L0003o0P00o`070000o`koooooA03oP0020000oc80oh000P3o000@
0?n001Wooooo000Gooooo`L0o`000P3oP00d0?l00080oh00B`3o000>oooooc/00?l00`000?l2003o
0080003o2@00o`0B0000o`P00?l00P000?l6003o00030000o`00o`000?l001T00?l03_ooool20000
o`800?l000<0003o003o0000o`000P000?l2003o00L0003o0`00o`0M0000o`L00?l04P000?l2003o
03`0003o3_oooomV0?n00080o`00403oP0040?l000h0oh006Oooool001Oooooo1`3o00020?n003@0
o`000P3oP01;0?l000kooooo>`00o`030000o`800?l00P000?l9003o0180003o2000o`020000o`H0
0?l000<0003o003o0000o`006@00o`0>ooooo`80003o0P00o`000`000?l00?l0003o00020000o`80
0?l01`000?l3003o01d0003o1`00o`0B0000o`800?l0?0000?l>ooooofH0oh000P3o000@0?n000@0
o`003P3oP00Iooooo`005ooooolm0?l00080oh001`3o00020?n00480o`003_oooolk003o00L0003o
2@00o`0<0000oaH00?l01@000?lG003o00kooooo0P000?l5003o0080003o0P00o`050000o`D00?l0
0P000?l2003o01h0003o0P00o`0B0000o`80o`00;P000?l2003o00`0003o3_oooolR0?n000800?l0
7P3oP0020000o`T0oh000P000?lY0?n00080003o1`00o`090?n001Wooooo000Gooooocd0o`000P3o
P0070?l00080oh00@P3o000>oooooc/00?l01`000?l9003o00`0003o5P00o`050000oaL00?l03_oo
ool20000o`D00?l00P000?l2003o00D0003o1@00o`020000o`800?l07P000?l2003o0180003o0P3o
000^0000o`800?l030000?l>ooooob80oh000P00o`0N0?n00080003o2@3oP0020000obT0oh000P00
0?l7003o00T0oh006Oooool001OoooooB03o00000`3oP000o`000?l000060?l000030?n0003o0000
o`0003H0o`003_oooolP003o00@0003o5`00o`070000o`<00?l00P000?l2003o00h0003o5P00o`00
0`000?l00?l0003o00020000o``00?l00P000?l9003o00kooooo2`00o`070000o`<00?l00P000?l2
003o01h0003o0P00o`0@0000o`800?l0<P000?l00`00o`00003o0000o`090000o`koooooO@3oP004
003o00T0oh006Oooool001OoooooB03o00000`3oP000o`000?l000060?l000030?n0003o0000o`00
03H0o`003_oooolP003o00@0003o5`00o`070000o`<00?l00P000?l2003o00h0003o5P00o`000`00
0?l00?l0003o00020000o``00?l00P000?l9003o00kooooo2`00o`070000o`<00?l00P000?l2003o
01h0003o0P00o`0@0000o`800?l0<P000?l00`00o`00003o0000o`090000o`koooooO@3oP004003o
00T0oh006Oooool001Oooooo1@3o00020?n00380o`000P3oP00=0?l000<0oh001P3o00000`3oP000
o`000?l0000f0?l000kooooo8P00o`020000oaL00?l01`000?l5003o01@0003o0P00o`000`000?l0
0?l0003o000=003o00D0003o3000o`040000o`L00?l03_ooool50000o`L00?l00P000?l2003o0080
003o0`00o`020000o`@00?l03P000?l20?l000030?n000000?l0003o00L0003o1000o`0E0000o`80
o`0010000?l00`3oP0000?l0003o000P0000o`800?l00P000?l3003o00/0003o3_ooool4003o01h0
oh000P000?lY0?n00080003o;P3oP006003o0080oh0000<0o`000?n0003oP0000P3oP00Iooooo`00
5oooool50?l00080oh00:03o00000`3oP000o`000?l0000F0?l000<0oh001P3o00000`3oP000o`00
0?l0000_0?l00080oh001@3o000>oooooc/00?l01`000?l2003o00030000o`00o`000?l001@0003o
0P00o`000`000?l00?l0003o000=003o00D0003o2`00o`070000o`D00?l03_ooool20000o`X00?l0
0P000?l2003o0080003o2@00o`0>0000o`<00?l02@000?l4003o01D0003o0P3o000Y0000o`800?l0
3P000?l>ooooodP0oh0000<00?l00?n0003oP000<P3oP004003o0080003o1`3oP00Iooooo`005ooo
ool50?l00080oh00:03o00000`3oP000o`000?l0000F0?l000<0oh001P3o00000`3oP000o`000?l0
000_0?l00080oh001@3o000>oooooc/00?l01`000?l2003o00030000o`00o`000?l001@0003o0P00
o`000`000?l00?l0003o000=003o00D0003o2`00o`070000o`D00?l03_ooool20000o`X00?l00P00
0?l2003o0080003o2@00o`0>0000o`<00?l02@000?l4003o01D0003o0P3o000Y0000o`800?l03P00
0?l>ooooodP0oh0000<00?l00?n0003oP000<P3oP004003o0080003o1`3oP00Iooooo`005oooool>
0?l00080oh00L`3o00030?n000@0o`003_ooool`003o0080003o2@00o`000`000?l00?l0003o0002
003o0080003o0P00o`0I0000oa000?l00`000?l=003o00P0003o1000o`0>ooooo`80003o2P00o`02
0000o`800?l00P000?l2003o00030000o`00o`000?l000L00?l03@000?l00`00o`00003o0000o`07
0000o`H00?l0?P000?l2003o00h0003o3_oooon:0?n001Wooooo000Gooooo`h0o`000P3oP01c0?l0
00<0oh00103o000>oooooc000?l00P000?l9003o00030000o`00o`000?l000800?l00P000?l2003o
01T0003o4000o`030000o`d00?l020000?l4003o00kooooo0P000?l:003o0080003o0P00o`020000
o`800?l000<0003o003o0000o`001`00o`0=0000o`03003o00000?l0003o00L0003o1P00o`0n0000
o`800?l03P000?l>ooooohX0oh006Oooool001Oooooo1@3o0002003o00L0o`000P3oP00[0?l000H0
oh00A03o00000`3oP000o`000?l000020?l000kooooo8000o`020000o`h00?l00P000?l<003o00@0
003o1@00o`040000o`800?l01@000?l2003o00<0003o0P00o`040000oa400?l00P000?l;003o00X0
003o1000o`0>ooooo`@0003o0`00o`020000o`L00?l00P000?l2003o00030000o`00o`000?l000L0
0?l040000?l2003o00D0003o1P00o`0`0000o`<00?l02@000?l2003o0100003o3_oooom20?n00080
003o1`3oP0020?l000T0oh0010000?l`0?n001Wooooo000Gooooo`D0o`000P00o`070?l00080oh00
:`3o00060?n004@0o`0000<0oh000?l0003o00000P3o000>ooooob000?l00P000?l>003o0080003o
3000o`040000o`D00?l010000?l2003o00D0003o0P00o`030000o`800?l010000?lA003o0080003o
2`00o`0:0000o`@00?l03_ooool40000o`<00?l00P000?l7003o0080003o0P00o`000`000?l00?l0
003o0007003o0100003o0P00o`050000o`H00?l0<0000?l3003o00T0003o0P00o`0@0000o`kooooo
@P3oP0020000o`L0oh000P3o00090?n000@0003o<03oP00Iooooo`005ooooolm0?l00080oh00B`3o
000>ooooob000?l00P000?lL003o0080o`000P000?l5003o00@0003o0P00o`000`3o00000?l0003o
00040000o`03003o00000?l0003o00800?l010000?lN003o00T0003o1@00o`0>ooooo`T0003o0P00
o`030000o`800?l00P000?l2003o00030000o`00o`000?l000L00?l040000?l2003o00L0003o1`00
o`0_0000o`03003o00000?l0003o01T0003o3_oooom20?n00080o`00AP3oP00Iooooo`005ooooolm
0?l00080oh00B`3o000>ooooob000?l00P000?lL003o0080o`000P000?l5003o00@0003o0P00o`00
0`3o00000?l0003o00040000o`03003o00000?l0003o00800?l010000?lN003o00T0003o1@00o`0>
ooooo`T0003o0P00o`030000o`800?l00P000?l2003o00030000o`00o`000?l000L00?l040000?l2
003o00L0003o1`00o`0_0000o`03003o00000?l0003o01T0003o3_oooom20?n00080o`00AP3oP00I
ooooo`005ooooon:0?l000kooooo8000o`020000oah00?l00P000?l9003o0080003o0`00o`040000
o`03003o00000?l0003o00800?l010000?l00`00o`00003o0000o`020000oaT00?l02@000?l5003o
00kooooo10000?l00`00o`00003o0000o`09003o0080003o0P00o`000`000?l00?l0003o00020000
o`D00?l06@000?l7003o02d0003o0`00o`0K0000o`kooooo5`3oP0020000o`@0oh001@000?lK0?n0
00800?l02@3oP0000`000?l0oh000?n0000o0?n001Wooooo000Gooooo`d0o`0000<0oh000?l0003o
0000NP3o000>ooooob000?l00P000?lG003o00D0003o0P00o`020000o``00?l010000?l9003o00X0
003o5P00o`070000o`L00?l03_ooool40000oaX00?l06@000?l7003o00L0003o1000o`0N0000o`80
0?l00P000?l2003o01`0003o3_ooool@0?n000800?l010000?l70?n000030000o`3oP000oh0001P0
oh0000<0003o0?n0003oP000@@3oP0000`000?l0oh000?n0000;0?n001Wooooo000Gooooo`d0o`00
00<0oh000?l0003o0000NP3o000>ooooob000?l00P000?lG003o00D0003o0P00o`020000o``00?l0
10000?l9003o00X0003o5P00o`070000o`L00?l03_ooool40000oaX00?l06@000?l7003o00L0003o
1000o`0N0000o`800?l00P000?l2003o01`0003o3_ooool@0?n000800?l010000?l70?n000030000
o`3oP000oh0001P0oh0000<0003o0?n0003oP000@@3oP0000`000?l0oh000?n0000;0?n001Wooooo
000Gooooo`d0o`0000<0oh000?l0003o0000:@3o00020?n004@0o`00103oP0070?l000kooooo>@00
o`030000o`@00?l00P000?l7003o0080003o0`00o`040000o`T00?l00P000?l00`00o`00003o0000
o`02003o00<0003o2@00o`020000o`L00?l00P000?l2003o00<0003o0P00o`020000o`L00?l03_oo
ool40000oaP00?l07@000?l5003o02T0003o0P00o`0P0000o`koooooB03oP0000`000?l0oh000?n0
000o0?n001Wooooo000Gooooo`d0o`0000<0oh000?l0003o0000:@3o00020?n004@0o`00103oP007
0?l000kooooo>@00o`030000o`@00?l00P000?l7003o0080003o0`00o`040000o`T00?l00P000?l0
0`00o`00003o0000o`02003o00<0003o2@00o`020000o`L00?l00P000?l2003o00<0003o0P00o`02
0000o`L00?l03_ooool40000oaP00?l07@000?l5003o02T0003o0P00o`0P0000o`koooooB03oP000
0`000?l0oh000?n0000o0?n001Wooooo000Goooooh40o`000P3oP0070?l000kooooo>`00o`000`00
0?l00?l0003o0002003o0080003o0P00o`030000o`H00?l01@000?l9003o00T0003o2P00o`020000
o`L00?l01`000?l;003o00kooooo0P000?l3003o0080003o1000o`000`000?l00?l0003o0007003o
00@0003o0`00o`0O0000o`<00?l0:@000?l2003o0200003o3_oooon:0?n001Wooooo000Goooooh40
o`000P3oP0070?l000kooooo>`00o`000`000?l00?l0003o0002003o0080003o0P00o`030000o`H0
0?l01@000?l9003o00T0003o2P00o`020000o`L00?l01`000?l;003o00kooooo0P000?l3003o0080
003o1000o`000`000?l00?l0003o0007003o00@0003o0`00o`0O0000o`<00?l0:@000?l2003o0200
003o3_oooon:0?n001Wooooo000Goooooh<0o`000P3oP0050?l000kooooo?000o`020000o`800?l0
0P000?l3003o0080003o0P00o`090000o`L00?l010000?l3003o00@0003o2P00o`020000o`/00?l0
0`000?l;003o00kooooo0P000?l3003o00@0003o0P00o`000`000?l00?l0003o0007003o02H0003o
0`00o`0Y0000o`800?l080000?l>ooooob80oh001000o`1T0?n001Wooooo000Goooooh<0o`000P3o
P0050?l000kooooo?000o`020000o`800?l00P000?l3003o0080003o0P00o`090000o`L00?l01000
0?l3003o00@0003o2P00o`020000o`/00?l00`000?l;003o00kooooo0P000?l3003o00@0003o0P00
o`000`000?l00?l0003o0007003o02H0003o0`00o`0Y0000o`800?l080000?l>ooooob80oh001000
o`1T0?n001Wooooo000Gooooodd0o`000P3oP00`0?l00080003o2@3o000>oooooc`00?l00P000?l2
003o00@0003o1@3oP0090000o`L00?l010000?lP003o00<0003o1`00o`020000o`kooooo10000?l0
0`00o`00003o0000o`04003o00030000o`00o`000?l000@00?l00`000?l2003o0280003o1@00o`1;
0000o`koooooRP3oP00Iooooo`005ooooolR0?l00080oh000P3o00000`3oP000o`000?l0000T0?l0
00@0oh00;P3o00020000o`T0o`003_ooooll003o0080003o0P00o`020000o`D00?l0103oP003003o
00H0003o00<00?l00000o`000?l0<000o`020000o`kooooo10000?l00`00o`00003o0000o`0@003o
01h0003o2@00o`1;0000o`koooooRP3oP00Iooooo`005ooooolR0?l00080oh000P3o00000`3oP000
o`000?l0000T0?l000@0oh00;P3o00020000o`T0o`003_ooooll003o0080003o0P00o`020000o`D0
0?l0103oP003003o00H0003o00<00?l00000o`000?l0<000o`020000o`kooooo10000?l00`00o`00
003o0000o`0@003o01h0003o2@00o`1;0000o`koooooRP3oP00Iooooo`005ooooolV0?l000030?n0
003o0000o`000640o`003_ooooll003o00d0003o1000o`070000o`03003o00000?l0003o03000?l0
0P000?l>ooooo`80003o2@00o`000`000?l00?l0003o00040000o`D00?l07P000?l9003o02T0003o
0P00o`0P0000o`koooooRP3oP00Iooooo`005ooooolV0?l000030?n0003o0000o`000640o`003_oo
ooll003o00d0003o1000o`070000o`03003o00000?l0003o03000?l00P000?l>ooooo`80003o2@00
o`000`000?l00?l0003o00040000o`D00?l07P000?l9003o02T0003o0P00o`0P0000o`koooooRP3o
P00Iooooo`005oooool20?n001D0o`000P3oP00K0?l00080oh00E03o000>ooooocT00?l03P000?l4
0?n000D00?l010000?l00`00o`00003o0000o`02003o00@0003o;000o`0>ooooo`/00?l000<0003o
003o0000o`001`000?l6003o01X0003o2@00o`1;0000o`koooooL@3oP0020000oaL0oh006Oooool0
01Oooooo0P3oP00E0?l00080oh006`3o00020?n005@0o`003_ooooli003o00h0003o103oP005003o
00@0003o00<00?l00000o`000?l00P00o`040000ob`00?l03_ooool;003o00030000o`00o`000?l0
00L0003o1P00o`0J0000o`T00?l0B`000?l>ooooog40oh000P000?lG0?n001Wooooo000Gooooo`80
oh00R03o000>ooooocT00?l00`000?l4003o00L0003o0P3o00020?n000800?l000<0o`000000o`00
0?l010000?l00`00o`00003o0000o`02003o00@0003o;000o`0>ooooo`h00?l02@000?l4003o01X0
003o0P00o`020000o`<00?l0C@000?l>oooooe@0oh000P000?ld0?n001Wooooo000Goooooh40o`00
0P00o`070?l000kooooo>@00o`050000o`800?l01`000?l70?l000T0003o5P00o`000`000?l00?l0
003o000I003o00kooooo10000?l:003o02L0003o0P00o`020000o`<00?l0C@000?l>ooooo`D0oh00
0P00o`0K0?n000L0003o:`3oP0020000oc@0oh006Oooool001OoooooP@3o0002003o00L0o`003_oo
ooli003o00D0003o0P00o`070000o`L0o`002@000?lF003o00030000o`00o`000?l001T00?l03_oo
ool40000o`X00?l09`000?l2003o0080003o0`00o`1=0000o`kooooo1@3oP002003o01/0oh001`00
0?l[0?n00080003o=03oP00Iooooo`005ooooon:0?l000kooooo>@00o`050000o`L00?l010000?l2
0?l00080003o00<00?l00000o`000?l01`000?l2003o00/0003o2@00o`000`000?l00?l0003o000I
003o00kooooo1`000?l2003o0080003o00<00?l00000o`000?l09`000?l2003o00@0003o00<00?l0
0000o`000?l0@0000?l2003o00T0003o3_ooool20?n000L00?l0P@3oP00Iooooo`005ooooon:0?l0
00kooooo>@00o`050000o`L00?l010000?l20?l00080003o00<00?l00000o`000?l01`000?l2003o
00/0003o2@00o`000`000?l00?l0003o000I003o00kooooo1`000?l2003o0080003o00<00?l00000
o`000?l09`000?l2003o00@0003o00<00?l00000o`000?l0@0000?l2003o00T0003o3_ooool20?n0
00L00?l0P@3oP00Iooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.0058881 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13248 -12 -4.5 ]
[-0.0125 .13248 0 4.5 ]
[-0.0125 .25024 -12 -4.5 ]
[-0.0125 .25024 0 4.5 ]
[-0.0125 .368 -12 -4.5 ]
[-0.0125 .368 0 4.5 ]
[-0.0125 .48576 -12 -4.5 ]
[-0.0125 .48576 0 4.5 ]
[-0.0125 .60353 -18 -4.5 ]
[-0.0125 .60353 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13248 m
1 .13248 L
s
0 .25024 m
1 .25024 L
s
0 .368 m
1 .368 L
s
0 .48576 m
1 .48576 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13248 m
.00625 .13248 L
s
[(20)] -0.0125 .13248 1 0 Mshowa
0 .25024 m
.00625 .25024 L
s
[(40)] -0.0125 .25024 1 0 Mshowa
0 .368 m
.00625 .368 L
s
[(60)] -0.0125 .368 1 0 Mshowa
0 .48576 m
.00625 .48576 L
s
[(80)] -0.0125 .48576 1 0 Mshowa
0 .60353 m
.00625 .60353 L
s
[(100)] -0.0125 .60353 1 0 Mshowa
.125 Mabswid
0 .04416 m
.00375 .04416 L
s
0 .0736 m
.00375 .0736 L
s
0 .10304 m
.00375 .10304 L
s
0 .16192 m
.00375 .16192 L
s
0 .19136 m
.00375 .19136 L
s
0 .2208 m
.00375 .2208 L
s
0 .27968 m
.00375 .27968 L
s
0 .30912 m
.00375 .30912 L
s
0 .33856 m
.00375 .33856 L
s
0 .39744 m
.00375 .39744 L
s
0 .42688 m
.00375 .42688 L
s
0 .45632 m
.00375 .45632 L
s
0 .5152 m
.00375 .5152 L
s
0 .54464 m
.00375 .54464 L
s
0 .57409 m
.00375 .57409 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13248 m
1 .13248 L
s
.99375 .25024 m
1 .25024 L
s
.99375 .368 m
1 .368 L
s
.99375 .48576 m
1 .48576 L
s
.99375 .60353 m
1 .60353 L
s
.125 Mabswid
.99625 .04416 m
1 .04416 L
s
.99625 .0736 m
1 .0736 L
s
.99625 .10304 m
1 .10304 L
s
.99625 .16192 m
1 .16192 L
s
.99625 .19136 m
1 .19136 L
s
.99625 .2208 m
1 .2208 L
s
.99625 .27968 m
1 .27968 L
s
.99625 .30912 m
1 .30912 L
s
.99625 .33856 m
1 .33856 L
s
.99625 .39744 m
1 .39744 L
s
.99625 .42688 m
1 .42688 L
s
.99625 .45632 m
1 .45632 L
s
.99625 .5152 m
1 .5152 L
s
.99625 .54464 m
1 .54464 L
s
.99625 .57409 m
1 .57409 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .60311 L
.06452 .60311 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .60311 L
.06452 .60311 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .581 L
.22581 .581 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .581 L
.22581 .581 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .60022 L
.3871 .60022 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .60022 L
.3871 .60022 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .01472 L
.54839 .01472 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .01472 L
.54839 .01472 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .01472 L
.70968 .01472 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .01472 L
.70968 .01472 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .59505 L
.87097 .59505 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .59505 L
.87097 .59505 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .01472 L
.09677 .01472 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .01472 L
.09677 .01472 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .01472 L
.25806 .01472 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .01472 L
.25806 .01472 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .01472 L
.58065 .01472 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .01472 L
.58065 .01472 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .55868 L
.74194 .55868 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .55868 L
.74194 .55868 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .60332 L
.90323 .60332 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .60332 L
.90323 .60332 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .59423 L
.12903 .59423 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .59423 L
.12903 .59423 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .01472 L
.29032 .01472 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .01472 L
.29032 .01472 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .59898 L
.45161 .59898 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .59898 L
.45161 .59898 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .60332 L
.6129 .60332 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .60332 L
.6129 .60332 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .01472 L
.77419 .01472 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .01472 L
.77419 .01472 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .01472 L
.93548 .01472 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .01472 L
.93548 .01472 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .01472 L
.16129 .01472 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .01472 L
.16129 .01472 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .58265 L
.32258 .58265 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .58265 L
.32258 .58265 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .01472 L
.48387 .01472 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .01472 L
.48387 .01472 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .54917 L
.64516 .54917 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .54917 L
.64516 .54917 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .43013 L
.80645 .43013 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .43013 L
.80645 .43013 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .01472 L
.96774 .01472 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .01472 L
.96774 .01472 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`0002kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Qoooooooo0000IOl0000;ooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`googl02_l0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000;ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`006?ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl0
5_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_oo
ool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]
ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEoooo
o`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`co
o`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co
0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o
3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=
ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;
o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Pooooo`?o00002oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:
ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=
oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo
00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co
003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=
ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;
o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0Pooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`go
ogl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl0
2_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l0
0?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lE
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=
o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0F
ooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o
023ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo
3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol0
0?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000F
ooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=
oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;oooo
o`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo
3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo1Ol00003ooooo`;o00001ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0017ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
2?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o
;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`00
0?oooooooooo00Wooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`?o00002?l007l=ool000[o001o3Ol00?lEo`00O`goo`005_l007l<oomo00_o001o
3?oo000;o`00O`co003o;Ol007l;o`00o`googl05_l007l<o`3o00[o001o3OooO`0:o`00O`coo`00
3?l0o`0Oo`00O`Co00002oooool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`go
o`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00
obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0
003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:
ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=
oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo
00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co
003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool2o`0000Wooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08?oo
ool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:
ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o
02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`go
ogl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl0
2_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l0
0?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lE
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`go003o5Oooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:
ooooo`googl02_ooool<ool000co0?l08?ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00
obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo
3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol0
0?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000F
ooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=
oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;oooo
o`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo
3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Ooo
ool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<
oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0Pooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
00[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00
o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Ko
oooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`go
ogl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol0
0?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_oo
ool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;
ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<
ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]oooo
o`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`go
o`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Booooo`?o0000
0oooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Cooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo
2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`004?ooool5o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo
00?o0000ooooooooool02Oooool0013ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00006ooooo`?o00002?l007l=ool000[o001o3Ol00?lEo`00O`goo`005_l007l<oomo00_o
001o3?oo000;o`00O`co003o;Ol007l;o`00o`googl05_l007l<o`3o00[o001o3OooO`0:o`00O`co
o`003?l0o`0Oo`00O`Co00002oooool0017ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Ko
oooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`go
ogl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool001?ooooo
00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl0
5_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_oo
ool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]
ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEoooo
o`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`co
o`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co
0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o
3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=
ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;
o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Pooooo`?o00002oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:
ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=
oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo
00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co
003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`002_ooool=
o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0F
ooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o023ooooo0ol0000;ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o
02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`go
ogl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl0
2_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l0
0?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lE
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=
o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0F
ooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o
023ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo
3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol0
0?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000F
ooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=
oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;oooo
o`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo
3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0017ooooo0ol00004ooooo`;o00001ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl0
5_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`?o
00002?l007l=ool000[o001o3Ol00?lEo`00O`goo`005_l007l<oomo00_o001o3?oo000;o`00O`co
003o;Ol007l;o`00o`googl05_l007l<o`3o00[o001o3OooO`0:o`00O`coo`003?l0o`0Oo`00O`Co
00002oooool0013ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co
003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000@ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`co
ogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[o
oooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
4_ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=
ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;
o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool0
01Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:oooo
o`googl02_ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_o
oooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl0
5_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_oo
ool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000:
ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=
oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08?ooool3o`0000_ooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=
o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0F
ooooo`co0?l02_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0:ooooo`googl02_ooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3Ol00?lE
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Pooooo`?o00002oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;oooo
o`co003o;Oooool;o`00o`googl05_ooool<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Ooo
ool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0
o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<
o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool0
01Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qoooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgo
oooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol0
0?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;
ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0R
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3Ol00?lEoooo
o`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o
027ooooo3?oo000<o`3o023ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l0
8_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_oo
ool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3Ooo
O`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<
ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00
oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Foooo
o`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_o
oooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l0
8Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo
3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`?o00002?l007l=ool000[o
001o3Ol00?lEo`00O`goo`005_l007l<oomo00_o001o3?oo000;o`00O`co003o;Ol007l;o`00o`go
ogl05_l007l<o`3o027o001o3?oo000<o`3o01oo001o1?l0000;ooooo`004Oooool3o`0000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08oooo
o`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]oooo
o`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09oooo
o`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<
ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool0
0ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00
obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Ko
oooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`co
o`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo
2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:
ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=
oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo2ol00?l=oomo01Ko
oooo3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
2Oooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o
;Oooool;o`00o`googl05_ooool<o`3o027ooooo3?oo000<o`3o023ooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=
o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0F
ooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGo
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co
0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo
000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Ooo
ool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]
ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o003o3OooO`0Fooooo`co0?l08Oooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?l]ooooo`_o
003o3OooO`0Fooooo`co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool2o`0000Wooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool<o`00obgooooo2ol00?l=oomo01Kooooo3?l0o`0Qooooo`coo`003?l0o`0Pooooo`?o0000
2oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;o`00o`googl05_ooool<o`3o027ooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=
ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool;
o`00o`googl05_ooool<o`3o027ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o;Oooool<o`00ob;ooooo3?l0o`0Qooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo3?l00?lRooooo`co
0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
3?l00?l]ooooo`co003o8_ooool<o`3o027ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool<o`00odoooooo3?oo000<o`3o02;ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lE
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool<o`00odoooooo3?oo000<
o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
00[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool<o`00
odoooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co
003o;Oooool<o`00odoooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo
0_l00009ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
3?l00?l]ooooo`co003oCoooool<ool000co0?l08?ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00obgooooo3?l00?m?ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;
ooooo`coo`002oooool<o`00obgooooo3?l00?m?ooooo`coo`003?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool0
01Kooooo3?ooO`0;ooooo`coo`002oooool<o`00obgooooo3?l00?m?ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o;Oooool<o`00odoooooo3?oo000<o`3o02;o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?m?ooooo`coo`002oooool<o`00obgooooo3?l00?m?ooooo`coo`003?l0o`0Rooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003oCooo
ool<ool000_ooooo3?l00?l]ooooo`co003oCoooool<ool000co0?l08_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00odoooooo3?oo000;
ooooo`co003o;Oooool<o`00odoooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
00_ooooo0ol00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool0
00[ooooo3Ol00?m?ooooo`coo`002oooool<o`00obgooooo3?l00?m?ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo001V
ooooo`coo`002oooool<o`00obgooooo3?l00?mKooooo`co0?l08_ooool00ol0003oooooooooo`09
ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004Cooooo3?l0
0?mKooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`003?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool3o`0000Sooooo
3Ooo002fooooo`co003oFoooool<o`3o01oooooo1?l0000;ooooo`003?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`3oooooof7ooooo00?o0000ooooooooool02Oooool000_ooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`3ooooo
of7ooooo00?o0000ooooooooool02Oooool000cooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l00007ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`008Oooooooo`0006Go00002ooo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool0047ooooo0ol0000eooooo`Go0000=_ooool3o`0003Oooooo0ol0000eoooo
o`?o0000=_ooool3o`0002kooooo0012ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooo
oooo0000=Oooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0<oooool0
1Ol0003ooooooooooooooooo000003Cooooo00Go0000ooooooooooooooooo`00000]ooooo`00@_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_oo
ool5o`0003Sooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002gooooo
0012ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool2o`0003Gooooo00Co
0000oooooooooooo0000>Oooool00ol0003oooooooooo`0booooo`Co0000;_ooool004;ooooo00?o
0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0
<oooool00ol0003oooooo`00000eooooo`Co0000=Oooool00ol0003oooooooooo`0_ooooo`00@Ooo
ool2o`0003Kooooo00Go0000ooooooooooooooooo`00000eooooo`05o`000?ooooooooooooooool0
0000=_ooool2o`0003Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`00
@_ooool00ol0003oooooooooo`0eooooo`?o0000=oooool3o`0003Sooooo00?o0000ooooooooool0
<oooool5o`0003Kooooo0_l0000^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.119489, -8.92996, \
0.0174717, 0.478595}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.00608908 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1365 -12 -4.5 ]
[-0.0125 .1365 0 4.5 ]
[-0.0125 .25828 -12 -4.5 ]
[-0.0125 .25828 0 4.5 ]
[-0.0125 .38006 -12 -4.5 ]
[-0.0125 .38006 0 4.5 ]
[-0.0125 .50184 -12 -4.5 ]
[-0.0125 .50184 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1365 m
.00625 .1365 L
s
[(20)] -0.0125 .1365 1 0 Mshowa
0 .25828 m
.00625 .25828 L
s
[(40)] -0.0125 .25828 1 0 Mshowa
0 .38006 m
.00625 .38006 L
s
[(60)] -0.0125 .38006 1 0 Mshowa
0 .50184 m
.00625 .50184 L
s
[(80)] -0.0125 .50184 1 0 Mshowa
.125 Mabswid
0 .04516 m
.00375 .04516 L
s
0 .07561 m
.00375 .07561 L
s
0 .10605 m
.00375 .10605 L
s
0 .16694 m
.00375 .16694 L
s
0 .19739 m
.00375 .19739 L
s
0 .22783 m
.00375 .22783 L
s
0 .28872 m
.00375 .28872 L
s
0 .31917 m
.00375 .31917 L
s
0 .34961 m
.00375 .34961 L
s
0 .41051 m
.00375 .41051 L
s
0 .44095 m
.00375 .44095 L
s
0 .4714 m
.00375 .4714 L
s
0 .53229 m
.00375 .53229 L
s
0 .56273 m
.00375 .56273 L
s
0 .59318 m
.00375 .59318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1365 m
1 .1365 L
s
.99375 .25828 m
1 .25828 L
s
.99375 .38006 m
1 .38006 L
s
.99375 .50184 m
1 .50184 L
s
.125 Mabswid
.99625 .04516 m
1 .04516 L
s
.99625 .07561 m
1 .07561 L
s
.99625 .10605 m
1 .10605 L
s
.99625 .16694 m
1 .16694 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .22783 m
1 .22783 L
s
.99625 .28872 m
1 .28872 L
s
.99625 .31917 m
1 .31917 L
s
.99625 .34961 m
1 .34961 L
s
.99625 .41051 m
1 .41051 L
s
.99625 .44095 m
1 .44095 L
s
.99625 .4714 m
1 .4714 L
s
.99625 .53229 m
1 .53229 L
s
.99625 .56273 m
1 .56273 L
s
.99625 .59318 m
1 .59318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .59199 L
.2381 .59199 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .59199 L
.2381 .59199 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .47807 L
.47619 .47807 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .47807 L
.47619 .47807 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .51612 L
.71429 .51612 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .51612 L
.71429 .51612 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00C_ooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`00043ooooo001?ooooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0?oooool004oooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol00010ooooo`00Coooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
047ooooo001?ooooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000@Oooool004kooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l00011
ooooo`00Coooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0?oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool001koooooool0001Uo`0000kooooo000Nooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`005Oooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00cooooo000Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00003_ooool0
01Cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00003_ooool001kooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?oo
ool001kooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3
o`0000kooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00co
oooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000N
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000>ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool5o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000>ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03Oooool4o`0000kooooo000@ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo
000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00cooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000>ooooo`?o00001?ooool2o`0000Oo
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
3?ooool001kooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_oo
ool3o`0000kooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Noooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00003ooooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000>ooooo`007_ooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0>ooooo`?o00003_ooool001kooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool000oooooo0ol00003ooooo`;o00001ooo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`0<ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003Oooool5o`0000;ooooo00Co0000
oooooooooooo00001_ooool3o`0000koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0=ooooo`Co00003_ooool000gooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003oooool2o`0000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003ooooooooo
o`02ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0>ooooo`?o00003_ooool001kooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?oo
ool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001ko
oooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000ko
oooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000N
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00003ooooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000>ooooo`007_ooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_oo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003_ooool3o`00
00Cooooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000=ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000=oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00cooooo000=ooooo`Co00000oooool01?l0003oooooooooool00006ooooo`?o00003_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00gooooo1?l0000>ooooo`003Oooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00cooooo000?ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo0_l0000?ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000kooooo000Nooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00co
oooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000N
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00cooooo000Nooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo00kooooo0ol0000>ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_oo
ool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>ooooo`?o00003_oo
ool001kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001ko
oooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo
001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00cooooo000>ooooo`?o00001?ooool2o`0000Oooooo00?o0000oooooooo
ool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`00
3Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00cooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool03?ooool000kooooo0ol00003ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000>
ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0=ooooo`Co00003_ooool000gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oo
oom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`003Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo
000>ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>
ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Noooo
o`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl0
4?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00^Ooo
oom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4
ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo
00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000oo
ooooA?oo002iooooodGoogl03_ooool3o`0000kooooo000Nooooo`03o`000?oooooooooo00kooooo
A?oo002iooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooooooo
o`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Noooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`00
0?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?oo
ool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5
oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool0
0;WoooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00003ooooom4ool00;Wo
ooooAOooO`0>ooooo`?o00003_ooool001kooooo00?o0000ooooooooool03_oooom4ool00;Wooooo
AOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo
002iooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>
ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooo
ooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool0
3?ooool001kooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo
013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool03_oooom4ool00;Wo
ooooAOooO`0@ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00003ooooom4ool00;Wooooo
AOooO`0>ooooo`?o00003_ooool001kooooo00?o0000ooooooooool0ooooool<ooooodGoogl04?oo
ool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`3oooooo`coooooAOooO`0@
ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo0?oooooo3?oooom5oomo
013ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0ooooool<ooooodGo
ogl04?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`3oooooof7ooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03?ooool001koooooool0001Uo`0000kooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
001>ooooo`?o0000DOooool5o`00053ooooo0ol0001Cooooo`?o0000@?ooool004oooooo00?o0000
ooooooooool0DOooool01?l0003oooooooooool0001?ooooo`05o`000?ooooooooooooooool00000
Doooool00ol0003oooooooooo`0oooooo`00Coooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool0C_ooool5o`00043ooooo001?ooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool0D?ooool2o`00057ooooo00Co0000oooooooooooo0000@Ooo
ool004oooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o
0000ooooooooool0Coooool00ol0003oooooo`000011ooooo`00C_ooool2o`0005;ooooo00Go0000
ooooooooooooooooo`00001?ooooo`05o`000?ooooooooooooooool00000D_ooool2o`00047ooooo
001?ooooo`03o`000?oooooooooo057ooooo0ol0001Aooooo`?o0000E?ooool00ol0003ooooooooo
o`0oooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.0422587, -8.63521, \
0.0118357, 0.462799}}],

Cell[BoxData[
    \(87.47806247806248`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #2 (4 clusters per band)", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 2;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7467666A6E676E1C
5E55524D55505808
817675707A6A7D13
78535F4B52485605
735F6C606C6E7717
68535B4C5E516500
886478667B677B13
F1FFD9F4EAFCF0CA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36343E403F44362A
22131F16251F201C
0915061005161117
0B0007020B0E1212
10150F150B150D10
2B1D231A1C181B14
2C35293324322325
E5E9FFF7FEF1F3C2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B4E980764700D54
0A7B990090632250
17BA8726CC4B3A54
29EF7A54E836864B
48FF6595E832AF33
71F24EC1DD3DDB35
78B636D1944AD514
5C1B5241126B4220
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9C9028CA5958B60E
DE8157FF5890CB27
E14A79EB35BCB12C
D62895C728D77C3B
AE10957E19D44758
7000A23B1EBE1D51
512D9C17459A035C
37612933620D3D18
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>ogAdM0koIfMW3_mV
IVH=ofYZJPkoKVi^3_mWIfL>ofi^KPgo71`L2oooool>ocHf=Pgo=3@d3_ln?Sh>od10@0ko?clo3_m4
A4@>ocHf=Pgo:RXZ2_ooool>ob/[:`koCTi>3_nHV9P>o`L71`koI6AT3_m`L70=o`d=3@goE5AD2ooo
ool>oibLW0koT92@3_lX:2P>ol[:bPgoFEUI3_mHF5P>okJf]Pgo3Ph>3oooool000gooooo3_mdM7@>
ofMWI`koIVIV3OmZJVX>ofi^KPkoIfMW3_m^KVh=oa`L70_ooooo3_lf=SH=oc@d=0ko?Shn3_m0@40>
oclo?`koA4A43_lf=SH=obXZ:P[ooooo3_l[:b/>odi>CPkoV9RH3_l71`L>ofATI0koL71`3Ol=3@d=
oeADE0_ooooo3_nLW9`>oi2@T0ko:2PX3_o:b/X=oeUIF@koF5QH3_nf][H=o`h>3Poooooo000=oooo
o`koM7Ad3_mWIfL>ofIVIPgoJVYZ3_m^KVh>ofMWI`koKVi^3OlL71`;ooooo`ko=SHf3Old=3@>ochn
?Pko@4103_lo?cl>odA4A0ko=SHf3OlZ:RX:ooooo`ko:b/[3_m>CTh>oiRHV0ko1`L73_mTI6@>og1`
L0go3@d=3OmDE5@;ooooo`koW9bL3_n@T90>obPX:0kob/[:3OmIFET>oeQHF0ko][Jf3Ol>3Ph?oooo
o`003Oooool>ogAdM0koIfMW3_mVIVH=ofYZJPkoKVi^3_mWIfL>ofi^KPgo71`L2oooool>ocHf=Pgo
=3@d3_ln?Sh>od10@0ko?clo3_m4A4@>ocHf=Pgo:RXZ2_ooool>ob/[:`koCTi>3_nHV9P>o`L71`ko
I6AT3_m`L70=o`d=3@goE5AD2oooool>oibLW0koT92@3_lX:2P>ol[:bPgoFEUI3_mHF5P>okJf]Pgo
3Ph>3oooool000gooooo3_mdM7@>ofMWI`koIVIV3OmZJVX>ofi^KPkoIfMW3_m^KVh=oa`L70_ooooo
3_lf=SH=oc@d=0ko?Shn3_m0@40>oclo?`koA4A43_lf=SH=obXZ:P[ooooo3_l[:b/>odi>CPkoV9RH
3_l71`L>ofATI0koL71`3Ol=3@d=oeADE0_ooooo3_nLW9`>oi2@T0ko:2PX3_o:b/X=oeUIF@koF5QH
3_nf][H=o`h>3Poooooo000=ooooo`koM7Ad3_mWIfL>ofIVIPgoJVYZ3_m^KVh>ofMWI`koKVi^3OlL
71`;ooooo`ko=SHf3Old=3@>ochn?Pko@4103_lo?cl>odA4A0ko=SHf3OlZ:RX:ooooo`ko:b/[3_m>
CTh>oiRHV0ko1`L73_mTI6@>og1`L0go3@d=3OmDE5@;ooooo`koW9bL3_n@T90>obPX:0kob/[:3OmI
FET>oeQHF0ko][Jf3Ol>3Ph?ooooo`003Oooool>ogAdM0koIfMW3_mVIVH=ofYZJPkoKVi^3_mWIfL>
ofi^KPgo71`L2oooool>ocHf=Pgo=3@d3_ln?Sh>od10@0ko?clo3_m4A4@>ocHf=Pgo:RXZ2_ooool>
ob/[:`koCTi>3_nHV9P>o`L71`koI6AT3_m`L70=o`d=3@goE5AD2oooool>oibLW0koT92@3_lX:2P>
ol[:bPgoFEUI3_mHF5P>okJf]Pgo3Ph>3oooool000gooooo3_mdM7@>ofMWI`koIVIV3OmZJVX>ofi^
KPkoIfMW3_m^KVh=oa`L70_ooooo3_lf=SH=oc@d=0ko?Shn3_m0@40>oclo?`koA4A43_lf=SH=obXZ
:P[ooooo3_l[:b/>odi>CPkoV9RH3_l71`L>ofATI0koL71`3Ol=3@d=oeADE0_ooooo3_nLW9`>oi2@
T0ko:2PX3_o:b/X=oeUIF@koF5QH3_nf][H=o`h>3Poooooo000=ooooo`koM7Ad3_mWIfL>ofIVIPgo
JVYZ3_m^KVh>ofMWI`koKVi^3OlL71`;ooooo`ko=SHf3Old=3@>ochn?Pko@4103_lo?cl>odA4A0ko
=SHf3OlZ:RX:ooooo`ko:b/[3_m>CTh>oiRHV0ko1`L73_mTI6@>og1`L0go3@d=3OmDE5@;ooooo`ko
W9bL3_n@T90>obPX:0kob/[:3OmIFET>oeQHF0ko][Jf3Ol>3Ph?ooooo`003Oooool>ogAdM0koIfMW
3_mVIVH=ofYZJPkoKVi^3_mWIfL>ofi^KPgo71`L2oooool>ocHf=Pgo=3@d3_ln?Sh>od10@0ko?clo
3_m4A4@>ocHf=Pgo:RXZ2_ooool>ob/[:`koCTi>3_nHV9P>o`L71`koI6AT3_m`L70=o`d=3@goE5AD
2oooool>oibLW0koT92@3_lX:2P>ol[:bPgoFEUI3_mHF5P>okJf]Pgo3Ph>3oooool000gooooo3_md
M7@>ofMWI`koIVIV3OmZJVX>ofi^KPkoIfMW3_m^KVh=oa`L70_ooooo3_lf=SH=oc@d=0ko?Shn3_m0
@40>oclo?`koA4A43_lf=SH=obXZ:P[ooooo3_l[:b/>odi>CPkoV9RH3_l71`L>ofATI0koL71`3Ol=
3@d=oeADE0_ooooo3_nLW9`>oi2@T0ko:2PX3_o:b/X=oeUIF@koF5QH3_nf][H=o`h>3Poooooo000=
ooooo`koM7Ad3_mWIfL>ofIVIPgoJVYZ3_m^KVh>ofMWI`koKVi^3OlL71`;ooooo`ko=SHf3Old=3@>
ochn?Pko@4103_lo?cl>odA4A0ko=SHf3OlZ:RX:ooooo`ko:b/[3_m>CTh>oiRHV0ko1`L73_mTI6@>
og1`L0go3@d=3OmDE5@;ooooo`koW9bL3_n@T90>obPX:0kob/[:3OmIFET>oeQHF0ko][Jf3Ol>3Ph?
ooooo`003Oooool>ogAdM0koIfMW3_mVIVH=ofYZJPkoKVi^3_mWIfL>ofi^KPgo71`L2oooool>ocHf
=Pgo=3@d3_ln?Sh>od10@0ko?clo3_m4A4@>ocHf=Pgo:RXZ2_ooool>ob/[:`koCTi>3_nHV9P>o`L7
1`koI6AT3_m`L70=o`d=3@goE5AD2oooool>oibLW0koT92@3_lX:2P>ol[:bPgoFEUI3_mHF5P>okJf
]Pgo3Ph>3oooool000gooooo3_mdM7@>ofMWI`koIVIV3OmZJVX>ofi^KPkoIfMW3_m^KVh=oa`L70_o
oooo3_lf=SH=oc@d=0ko?Shn3_m0@40>oclo?`koA4A43_lf=SH=obXZ:P[ooooo3_l[:b/>odi>CPko
V9RH3_l71`L>ofATI0koL71`3Ol=3@d=oeADE0_ooooo3_nLW9`>oi2@T0ko:2PX3_o:b/X=oeUIF@ko
F5QH3_nf][H=o`h>3Poooooo000=ooooo`koGUiN3_mEEED>oe9BDPgoCDe=3_mEEED>oe1@D0koF5QH
3Ol820P;ooooo`ko8R8R3OlC4a<>oalO7`ko5QHF3_lU9BD>oalO7`ko820P3OlL71`:ooooo`ko2PX:
3_mkNg/>oiVIV@ko00003_n@T90>of=SH`go8R8R3Om@D50;ooooo`kog]kN3_n1PH4>oeMGE`kooooo
3OmHF5P>oi2@T0kobl_;3OlW9bL?ooooo`003Oooool>oeiNGPkoEEEE3_mBDU8=ode=C@koEEEE3_m@
D50>oeQHF0go20P82oooool>ob8R8Pgo4a<C3_lO7al>oaHF5Pko9BDU3_lO7al>ob0P80go71`L2_oo
ool>o`X:2PkoNg]k3_nIVIT>o`0000koT92@3_mSHf<=ob8R8PgoD51@2oooool>omkNgPkoPH613_mG
EeL>ooooo`goF5QH3_n@T90>ol_;b`go9bLW3oooool000gooooo3_mNGUh>oeEEE@koDU9B3Om=CDd>
oeEEE@koD51@3_mHF5P=o`P820_ooooo3_lR8R8=oa<C4`ko7alO3_lF5QH>obDU9@ko7alO3_lP820=
oa`L70[ooooo3_l:2PX>og]kN`koVIVI3_l0000>oi2@T0koHf=S3OlR8R8=oe1@D0_ooooo3_oNg]h>
oh61P@koEeMG3_ooool=oeQHF0koT92@3_o;bl/=obLW9`oooooo000=ooooo`koGUiN3_mEEED>oe9B
DPgoCDe=3_mEEED>oe1@D0koF5QH3Ol820P;ooooo`ko8R8R3OlC4a<>oalO7`ko5QHF3_lU9BD>oalO
7`ko820P3OlL71`:ooooo`ko2PX:3_mkNg/>oiVIV@ko00003_n@T90>of=SH`go8R8R3Om@D50;oooo
o`kog]kN3_n1PH4>oeMGE`kooooo3OmHF5P>oi2@T0kobl_;3OlW9bL?ooooo`003Oooool>oeiNGPko
EEEE3_mBDU8=ode=C@koEEEE3_m@D50>oeQHF0go20P82oooool>ob8R8Pgo4a<C3_lO7al>oaHF5Pko
9BDU3_lO7al>ob0P80go71`L2_ooool>o`X:2PkoNg]k3_nIVIT>o`0000koT92@3_mSHf<=ob8R8Pgo
D51@2oooool>omkNgPkoPH613_mGEeL>ooooo`goF5QH3_n@T90>ol_;b`go9bLW3oooool000gooooo
3_mNGUh>oeEEE@koDU9B3Om=CDd>oeEEE@koD51@3_mHF5P=o`P820_ooooo3_lR8R8=oa<C4`ko7alO
3_lF5QH>obDU9@ko7alO3_lP820=oa`L70[ooooo3_l:2PX>og]kN`koVIVI3_l0000>oi2@T0koHf=S
3OlR8R8=oe1@D0_ooooo3_oNg]h>oh61P@koEeMG3_ooool=oeQHF0koT92@3_o;bl/=obLW9`oooooo
000=ooooo`koGUiN3_mEEED>oe9BDPgoCDe=3_mEEED>oe1@D0koF5QH3Ol820P;ooooo`ko8R8R3OlC
4a<>oalO7`ko5QHF3_lU9BD>oalO7`ko820P3OlL71`:ooooo`ko2PX:3_mkNg/>oiVIV@ko00003_n@
T90>of=SH`go8R8R3Om@D50;ooooo`kog]kN3_n1PH4>oeMGE`kooooo3OmHF5P>oi2@T0kobl_;3OlW
9bL?ooooo`003Oooool>oeiNGPkoEEEE3_mBDU8=ode=C@koEEEE3_m@D50>oeQHF0go20P82oooool>
ob8R8Pgo4a<C3_lO7al>oaHF5Pko9BDU3_lO7al>ob0P80go71`L2_ooool>o`X:2PkoNg]k3_nIVIT>
o`0000koT92@3_mSHf<=ob8R8PgoD51@2oooool>omkNgPkoPH613_mGEeL>ooooo`goF5QH3_n@T90>
ol_;b`go9bLW3oooool000gooooo3_mNGUh>oeEEE@koDU9B3Om=CDd>oeEEE@koD51@3_mHF5P=o`P8
20_ooooo3_lR8R8=oa<C4`ko7alO3_lF5QH>obDU9@ko7alO3_lP820=oa`L70[ooooo3_l:2PX>og]k
N`koVIVI3_l0000>oi2@T0koHf=S3OlR8R8=oe1@D0_ooooo3_oNg]h>oh61P@koEeMG3_ooool=oeQH
F0koT92@3_o;bl/=obLW9`oooooo000=ooooo`koGUiN3_mEEED>oe9BDPgoCDe=3_mEEED>oe1@D0ko
F5QH3Ol820P;ooooo`ko8R8R3OlC4a<>oalO7`ko5QHF3_lU9BD>oalO7`ko820P3OlL71`:ooooo`ko
2PX:3_mkNg/>oiVIV@ko00003_n@T90>of=SH`go8R8R3Om@D50;ooooo`kog]kN3_n1PH4>oeMGE`ko
oooo3OmHF5P>oi2@T0kobl_;3OlW9bL?ooooo`003Oooool>oeiNGPkoEEEE3_mBDU8=ode=C@koEEEE
3_m@D50>oeQHF0go20P82oooool>ob8R8Pgo4a<C3_lO7al>oaHF5Pko9BDU3_lO7al>ob0P80go71`L
2_ooool>o`X:2PkoNg]k3_nIVIT>o`0000koT92@3_mSHf<=ob8R8PgoD51@2oooool>omkNgPkoPH61
3_mGEeL>ooooo`goF5QH3_n@T90>ol_;b`go9bLW3oooool000gooooo3_mNGUh>oeEEE@koDU9B3Om=
CDd>oeEEE@koD51@3_mHF5P=o`P820_ooooo3_lR8R8=oa<C4`ko7alO3_lF5QH>obDU9@ko7alO3_lP
820=oa`L70[ooooo3_l:2PX>og]kN`koVIVI3_l0000>oi2@T0koHf=S3OlR8R8=oe1@D0_ooooo3_oN
g]h>oh61P@koEeMG3_ooool=oeQHF0koT92@3_o;bl/=obLW9`oooooo000=ooooo`koGUiN3_mEEED>
oe9BDPgoCDe=3_mEEED>oe1@D0koF5QH3Ol820P;ooooo`ko8R8R3OlC4a<>oalO7`ko5QHF3_lU9BD>
oalO7`ko820P3OlL71`:ooooo`ko2PX:3_mkNg/>oiVIV@ko00003_n@T90>of=SH`go8R8R3Om@D50;
ooooo`kog]kN3_n1PH4>oeMGE`kooooo3OmHF5P>oi2@T0kobl_;3OlW9bL?ooooo`003Oooool>oh61
P@koMWIf3_meMGD=og1`L0koNWYj3_mZJVX>ogemO@go4a<C2oooool>o`T92@go5ADE3_l61PH>oa0@
40ko1@D53_lF5QH>oa4A4@go5aLG2_ooool>oaLG5`ko^[Zj3_n7QhL>obHV9Pkoc<c<3_m;Bd/=ocXj
>PgoE5AD2oooool>on7Qh@koBTY:3_miNGT>on_[j`go=CDe3_nl_;`>ok6a/@go;2`/3oooool000go
oooo3_n1PH4>ogIfMPkoMGEe3Om`L70>ogYjNPkoJVYZ3_mmOGd=oa<C4`_ooooo3_l92@T=oaDE5@ko
1PH63_l@410>o`D51@ko5QHF3_lA4A4=oaLG5`[ooooo3_lG5aL>okZj^PkoQhN73_lV9RH>olc<c0ko
Bd];3Olj>SX=oeADE0_ooooo3_oQhN4>odY:BPkoNGUi3_o[jn/=ocDe=@ko_;bl3_na/K4=ob`/;0oo
oooo000=ooooo`koPH613_mfMWH>ogEeM@goL71`3_mjNWX>ofYZJPkoOGem3OlC4a<;ooooo`ko2@T9
3OlE5AD>o`H61Pko410@3_l51@D>oaHF5Pko4A4A3OlG5aL:ooooo`ko5aLG3_nj^[X>ohN7Q`ko9RHV
3_o<c<`>od];B`go>SXj3OmDE5@;ooooo`kohN7Q3_m:BTX>ogUiN@kojn_[3Ole=CD>okbl_0ko/K6a
3Ol/;2`?ooooo`003Oooool>oh61P@koMWIf3_meMGD=og1`L0koNWYj3_mZJVX>ogemO@go4a<C2ooo
ool>o`T92@go5ADE3_l61PH>oa0@40ko1@D53_lF5QH>oa4A4@go5aLG2_ooool>oaLG5`ko^[Zj3_n7
QhL>obHV9Pkoc<c<3_m;Bd/=ocXj>PgoE5AD2oooool>on7Qh@koBTY:3_miNGT>on_[j`go=CDe3_nl
_;`>ok6a/@go;2`/3oooool000gooooo3_n1PH4>ogIfMPkoMGEe3Om`L70>ogYjNPkoJVYZ3_mmOGd=
oa<C4`_ooooo3_l92@T=oaDE5@ko1PH63_l@410>o`D51@ko5QHF3_lA4A4=oaLG5`[ooooo3_lG5aL>
okZj^PkoQhN73_lV9RH>olc<c0koBd];3Olj>SX=oeADE0_ooooo3_oQhN4>odY:BPkoNGUi3_o[jn/=
ocDe=@ko_;bl3_na/K4=ob`/;0oooooo000=ooooo`koPH613_mfMWH>ogEeM@goL71`3_mjNWX>ofYZ
JPkoOGem3OlC4a<;ooooo`ko2@T93OlE5AD>o`H61Pko410@3_l51@D>oaHF5Pko4A4A3OlG5aL:oooo
o`ko5aLG3_nj^[X>ohN7Q`ko9RHV3_o<c<`>od];B`go>SXj3OmDE5@;ooooo`kohN7Q3_m:BTX>ogUi
N@kojn_[3Ole=CD>okbl_0ko/K6a3Ol/;2`?ooooo`003Oooool>oh61P@koMWIf3_meMGD=og1`L0ko
NWYj3_mZJVX>ogemO@go4a<C2oooool>o`T92@go5ADE3_l61PH>oa0@40ko1@D53_lF5QH>oa4A4@go
5aLG2_ooool>oaLG5`ko^[Zj3_n7QhL>obHV9Pkoc<c<3_m;Bd/=ocXj>PgoE5AD2oooool>on7Qh@ko
BTY:3_miNGT>on_[j`go=CDe3_nl_;`>ok6a/@go;2`/3oooool000gooooo3_n1PH4>ogIfMPkoMGEe
3Om`L70>ogYjNPkoJVYZ3_mmOGd=oa<C4`_ooooo3_l92@T=oaDE5@ko1PH63_l@410>o`D51@ko5QHF
3_lA4A4=oaLG5`[ooooo3_lG5aL>okZj^PkoQhN73_lV9RH>olc<c0koBd];3Olj>SX=oeADE0_ooooo
3_oQhN4>odY:BPkoNGUi3_o[jn/=ocDe=@ko_;bl3_na/K4=ob`/;0oooooo000=ooooo`koPH613_mf
MWH>ogEeM@goL71`3_mjNWX>ofYZJPkoOGem3OlC4a<;ooooo`ko2@T93OlE5AD>o`H61Pko410@3_l5
1@D>oaHF5Pko4A4A3OlG5aL:ooooo`ko5aLG3_nj^[X>ohN7Q`ko9RHV3_o<c<`>od];B`go>SXj3OmD
E5@;ooooo`kohN7Q3_m:BTX>ogUiN@kojn_[3Ole=CD>okbl_0ko/K6a3Ol/;2`?ooooo`003Oooool>
oh61P@koMWIf3_meMGD=og1`L0koNWYj3_mZJVX>ogemO@go4a<C2oooool>o`T92@go5ADE3_l61PH>
oa0@40ko1@D53_lF5QH>oa4A4@go5aLG2_ooool>oaLG5`ko^[Zj3_n7QhL>obHV9Pkoc<c<3_m;Bd/=
ocXj>PgoE5AD2oooool>on7Qh@koBTY:3_miNGT>on_[j`go=CDe3_nl_;`>ok6a/@go;2`/3oooool0
00gooooo3_n1PH4>ogIfMPkoMGEe3Om`L70>ogYjNPkoJVYZ3_mmOGd=oa<C4`_ooooo3_l92@T=oaDE
5@ko1PH63_l@410>o`D51@ko5QHF3_lA4A4=oaLG5`[ooooo3_lG5aL>okZj^PkoQhN73_lV9RH>olc<
c0koBd];3Olj>SX=oeADE0_ooooo3_oQhN4>odY:BPkoNGUi3_o[jn/=ocDe=@ko_;bl3_na/K4=ob`/
;0oooooo000=ooooo`koPH613_mfMWH>ogEeM@goL71`3_mjNWX>ofYZJPkoOGem3OlC4a<;ooooo`ko
2@T93OlE5AD>o`H61Pko410@3_l51@D>oaHF5Pko4A4A3OlG5aL:ooooo`ko5aLG3_nj^[X>ohN7Q`ko
9RHV3_o<c<`>od];B`go>SXj3OmDE5@;ooooo`kohN7Q3_m:BTX>ogUiN@kojn_[3Ole=CD>okbl_0ko
/K6a3Ol/;2`?ooooo`003Oooool>oh61P@koMWIf3_meMGD=og1`L0koNWYj3_mZJVX>ogemO@go4a<C
2oooool>o`T92@go5ADE3_l61PH>oa0@40ko1@D53_lF5QH>oa4A4@go5aLG2_ooool>oaLG5`ko^[Zj
3_n7QhL>obHV9Pkoc<c<3_m;Bd/=ocXj>PgoE5AD2oooool>on7Qh@koBTY:3_miNGT>on_[j`go=CDe
3_nl_;`>ok6a/@go;2`/3oooool000gooooo3_n1PH4>ogIfMPkoMGEe3Om`L70>ogYjNPkoJVYZ3_mm
OGd=oa<C4`_ooooo3_l92@T=oaDE5@ko1PH63_l@410>o`D51@ko5QHF3_lA4A4=oaLG5`[ooooo3_lG
5aL>okZj^PkoQhN73_lV9RH>olc<c0koBd];3Olj>SX=oeADE0_ooooo3_oQhN4>odY:BPkoNGUi3_o[
jn/=ocDe=@ko_;bl3_na/K4=ob`/;0oooooo000=ooooo`koN7Qh3_mCDe<>oemOG`goBd];3_mBDU8>
odQ8B0koEUIF3Ol51@D;ooooo`ko2`/;3Ol0000>o`L71`ko0P823_l;2`/>o`h>3Q_o4Q8B2_ooool>
obTY:@kokno_3_mjNWX>oeADE0koj>SX3_lf=SH=ohJ6QPgoBd];2oooool>omKFePko:2PX3_nEUID>
olO7a`go:2PX3_oGemL>ogalO0go>c/k3oooool000gooooo3_mhN7P>oe=CD`koGemO3Om;Bd/>oe9B
DPkoB4Q83_mFEUH=o`D51@_ooooo3_l;2`/=o`0000ko1`L73_l20P8>o`/;2`ko3Ph>6olB4Q8:oooo
o`ko:BTY3_o_knl>ogYjNPkoE5AD3_oXj>P>ocHf=PgoQXJ63Om;Bd/;ooooo`koe]KF3_lX:2P>oiFE
U@koalO73OlX:2P>omOGe`koO7al3Olk>c/?ooooo`003Oooool>ogQhN0koDe=C3_mOGel=od];B`ko
DU9B3_m8B4P>oeIFEPgo1@D52oooool>o`/;2`go00003_l71`L>o`820Pko2`/;3_l>3PhKoa8B4P[o
oooo3_lY:BT>ono_k`koNWYj3_mDE5@>onSXj0ko=SHf3On6QXH=od];B`_ooooo3_oFe]H>obPX:0ko
UIFE3_o7alL=obPX:0koemOG3_mlO7`=oc/k>`oooooo000=ooooo`koN7Qh3_mCDe<>oemOG`goBd];
3_mBDU8>odQ8B0koEUIF3Ol51@D;ooooo`ko2`/;3Ol0000>o`L71`ko0P823_l;2`/>o`h>3Q_o4Q8B
2_ooool>obTY:@kokno_3_mjNWX>oeADE0koj>SX3_lf=SH=ohJ6QPgoBd];2oooool>omKFePko:2PX
3_nEUID>olO7a`go:2PX3_oGemL>ogalO0go>c/k3oooool000gooooo3_mhN7P>oe=CD`koGemO3Om;
Bd/>oe9BDPkoB4Q83_mFEUH=o`D51@_ooooo3_l;2`/=o`0000ko1`L73_l20P8>o`/;2`ko3Ph>6olB
4Q8:ooooo`ko:BTY3_o_knl>ogYjNPkoE5AD3_oXj>P>ocHf=PgoQXJ63Om;Bd/;ooooo`koe]KF3_lX
:2P>oiFEU@koalO73OlX:2P>omOGe`koO7al3Olk>c/?ooooo`003Oooool>ogQhN0koDe=C3_mOGel=
od];B`koDU9B3_m8B4P>oeIFEPgo1@D52oooool>o`/;2`go00003_l71`L>o`820Pko2`/;3_l>3PhK
oa8B4P[ooooo3_lY:BT>ono_k`koNWYj3_mDE5@>onSXj0ko=SHf3On6QXH=od];B`_ooooo3_oFe]H>
obPX:0koUIFE3_o7alL=obPX:0koemOG3_mlO7`=oc/k>`oooooo000=ooooo`koN7Qh3_mCDe<>oemO
G`goBd];3_mBDU8>odQ8B0koEUIF3Ol51@D;ooooo`ko2`/;3Ol0000>o`L71`ko0P823_l;2`/>o`h>
3Q_o4Q8B2_ooool>obTY:@kokno_3_mjNWX>oeADE0koj>SX3_lf=SH=ohJ6QPgoBd];2oooool>omKF
ePko:2PX3_nEUID>olO7a`go:2PX3_oGemL>ogalO0go>c/k3oooool000gooooo3_mhN7P>oe=CD`ko
GemO3Om;Bd/>oe9BDPkoB4Q83_mFEUH=o`D51@_ooooo3_l;2`/=o`0000ko1`L73_l20P8>o`/;2`ko
3Ph>6olB4Q8:ooooo`ko:BTY3_o_knl>ogYjNPkoE5AD3_oXj>P>ocHf=PgoQXJ63Om;Bd/;ooooo`ko
e]KF3_lX:2P>oiFEU@koalO73OlX:2P>omOGe`koO7al3Olk>c/?ooooo`003Oooool>ogQhN0koDe=C
3_mOGel=od];B`koDU9B3_m8B4P>oeIFEPgo1@D52oooool>o`/;2`go00003_l71`L>o`820Pko2`/;
3_l>3PhKoa8B4P[ooooo3_lY:BT>ono_k`koNWYj3_mDE5@>onSXj0ko=SHf3On6QXH=od];B`_ooooo
3_oFe]H>obPX:0koUIFE3_o7alL=obPX:0koemOG3_mlO7`=oc/k>`oooooo000=ooooo`koN7Qh3_mC
De<>oemOG`goBd];3_mBDU8>odQ8B0koEUIF3Ol51@D;ooooo`ko2`/;3Ol0000>o`L71`ko0P823_l;
2`/>o`h>3Q_o4Q8B2_ooool>obTY:@kokno_3_mjNWX>oeADE0koj>SX3_lf=SH=ohJ6QPgoBd];2ooo
ool>omKFePko:2PX3_nEUID>olO7a`go:2PX3_oGemL>ogalO0go>c/k3oooool000gooooo3_mhN7P>
oe=CD`koGemO3Om;Bd/>oe9BDPkoB4Q83_mFEUH=o`D51@_ooooo3_l;2`/=o`0000ko1`L73_l20P8>
o`/;2`ko3Ph>6olB4Q8:ooooo`ko:BTY3_o_knl>ogYjNPkoE5AD3_oXj>P>ocHf=PgoQXJ63Om;Bd/;
ooooo`koe]KF3_lX:2P>oiFEU@koalO73OlX:2P>omOGe`koO7al3Olk>c/?ooooo`003Oooool>ogQh
N0koDe=C3_mOGel=od];B`koDU9B3_m8B4P>oeIFEPgo1@D52oooool>o`/;2`go00003_l71`L>o`82
0Pko2`/;3_l>3PhKoa8B4P[ooooo3_lY:BT>ono_k`koNWYj3_mDE5@>onSXj0ko=SHf3On6QXH=od];
B`_ooooo3_oFe]H>obPX:0koUIFE3_o7alL=obPX:0koemOG3_mlO7`=oc/k>`oooooo000=ooooo`ko
N7Qh3_mCDe<>oemOG`goBd];3_mBDU8>odQ8B0koEUIF3Ol51@D;ooooo`ko2`/;3Ol0000>o`L71`ko
0P823_l;2`/>o`h>3Q_o4Q8B2_ooool>obTY:@kokno_3_mjNWX>oeADE0koj>SX3_lf=SH=ohJ6QPgo
Bd];2oooool>omKFePko:2PX3_nEUID>olO7a`go:2PX3_oGemL>ogalO0go>c/k3oooool000gooooo
3_mcLg<>oemOG`koK6a/3OmPH60>ofa/K0koKVi^3_mgMgL=oaLG5`_ooooo3_l@410=oaDE5@ko3`l?
3_lE5AD>o`/;2`ko5ADE3_l=3@d=oa0@40[ooooo3_m8B4P>ooooo`koIFEU3_nEUID>onSXj0ko<S8b
3On_[jl=oc<c<`_ooooo3_n^[Zh>oa0@40koUIFE3_mnOWh=oaTI6@koe=CD3_m7AdL=oeQHF0oooooo
000=ooooo`koLg=c3_mOGel>ofa/K0goH61P3_m/K6`>ofi^KPkoMgMg3OlG5aL;ooooo`ko410@3OlE
5AD>o`l?3`ko5ADE3_l;2`/>oaDE5@ko3@d=3Ol@410:ooooo`koB4Q83_ooool>ofEUI@koUIFE3_oX
j>P>oc8b<Pgo[jn_3Olc<c<;ooooo`ko[Zj^3_l@410>oiFEU@koOWin3OlI6AT>omCDe0koAdM73OmH
F5P?ooooo`003Oooool>og=cL`koGemO3_m/K6`=of1PH0koK6a/3_m^KVh>ogMgM`go5aLG2oooool>
oa0@40go5ADE3_l?3`l>oaDE5@ko2`/;3_lE5AD>o`d=3@go410@2_ooool>odQ8B0kooooo3_mUIFD>
oiFEU@koj>SX3_lb<S8=ojn_[`go<c<c2oooool>ojj^[Pko410@3_nEUID>oginOPgo6ATI3_oDe=@>
odM7A`goF5QH3oooool000gooooo3_mcLg<>oemOG`koK6a/3OmPH60>ofa/K0koKVi^3_mgMgL=oaLG
5`_ooooo3_l@410=oaDE5@ko3`l?3_lE5AD>o`/;2`ko5ADE3_l=3@d=oa0@40[ooooo3_m8B4P>oooo
o`koIFEU3_nEUID>onSXj0ko<S8b3On_[jl=oc<c<`_ooooo3_n^[Zh>oa0@40koUIFE3_mnOWh=oaTI
6@koe=CD3_m7AdL=oeQHF0oooooo000=ooooo`koLg=c3_mOGel>ofa/K0goH61P3_m/K6`>ofi^KPko
MgMg3OlG5aL;ooooo`ko410@3OlE5AD>o`l?3`ko5ADE3_l;2`/>oaDE5@ko3@d=3Ol@410:ooooo`ko
B4Q83_ooool>ofEUI@koUIFE3_oXj>P>oc8b<Pgo[jn_3Olc<c<;ooooo`ko[Zj^3_l@410>oiFEU@ko
OWin3OlI6AT>omCDe0koAdM73OmHF5P?ooooo`003Oooool>og=cL`koGemO3_m/K6`=of1PH0koK6a/
3_m^KVh>ogMgM`go5aLG2oooool>oa0@40go5ADE3_l?3`l>oaDE5@ko2`/;3_lE5AD>o`d=3@go410@
2_ooool>odQ8B0kooooo3_mUIFD>oiFEU@koj>SX3_lb<S8=ojn_[`go<c<c2oooool>ojj^[Pko410@
3_nEUID>oginOPgo6ATI3_oDe=@>odM7A`goF5QH3oooool000gooooo3_mcLg<>oemOG`koK6a/3OmP
H60>ofa/K0koKVi^3_mgMgL=oaLG5`_ooooo3_l@410=oaDE5@ko3`l?3_lE5AD>o`/;2`ko5ADE3_l=
3@d=oa0@40[ooooo3_m8B4P>ooooo`koIFEU3_nEUID>onSXj0ko<S8b3On_[jl=oc<c<`_ooooo3_n^
[Zh>oa0@40koUIFE3_mnOWh=oaTI6@koe=CD3_m7AdL=oeQHF0oooooo000=ooooo`koLg=c3_mOGel>
ofa/K0goH61P3_m/K6`>ofi^KPkoMgMg3OlG5aL;ooooo`ko410@3OlE5AD>o`l?3`ko5ADE3_l;2`/>
oaDE5@ko3@d=3Ol@410:ooooo`koB4Q83_ooool>ofEUI@koUIFE3_oXj>P>oc8b<Pgo[jn_3Olc<c<;
ooooo`ko[Zj^3_l@410>oiFEU@koOWin3OlI6AT>omCDe0koAdM73OmHF5P?ooooo`003Oooool>og=c
L`koGemO3_m/K6`=of1PH0koK6a/3_m^KVh>ogMgM`go5aLG2oooool>oa0@40go5ADE3_l?3`l>oaDE
5@ko2`/;3_lE5AD>o`d=3@go410@2_ooool>odQ8B0kooooo3_mUIFD>oiFEU@koj>SX3_lb<S8=ojn_
[`go<c<c2oooool>ojj^[Pko410@3_nEUID>oginOPgo6ATI3_oDe=@>odM7A`goF5QH3oooool000go
oooo3_mcLg<>oemOG`koK6a/3OmPH60>ofa/K0koKVi^3_mgMgL=oaLG5`_ooooo3_l@410=oaDE5@ko
3`l?3_lE5AD>o`/;2`ko5ADE3_l=3@d=oa0@40[ooooo3_m8B4P>ooooo`koIFEU3_nEUID>onSXj0ko
<S8b3On_[jl=oc<c<`_ooooo3_n^[Zh>oa0@40koUIFE3_mnOWh=oaTI6@koe=CD3_m7AdL=oeQHF0oo
oooo000=ooooo`koLg=c3_mOGel>ofa/K0goH61P3_m/K6`>ofi^KPkoMgMg3OlG5aL;ooooo`ko410@
3OlE5AD>o`l?3`ko5ADE3_l;2`/>oaDE5@ko3@d=3Ol@410:ooooo`koB4Q83_ooool>ofEUI@koUIFE
3_oXj>P>oc8b<Pgo[jn_3Olc<c<;ooooo`ko[Zj^3_l@410>oiFEU@koOWin3OlI6AT>omCDe0koAdM7
3OmHF5P?ooooo`003Oooool>og=cL`koGemO3_m/K6`=of1PH0koK6a/3_m^KVh>ogMgM`go5aLG2ooo
ool>oa0@40go5ADE3_l?3`l>oaDE5@ko2`/;3_lE5AD>o`d=3@go410@2_ooool>odQ8B0kooooo3_mU
IFD>oiFEU@koj>SX3_lb<S8=ojn_[`go<c<c2oooool>ojj^[Pko410@3_nEUID>oginOPgo6ATI3_oD
e=@>odM7A`goF5QH3oooool000gooooo3_mcLg<>oemOG`koK6a/3OmPH60>ofa/K0koKVi^3_mgMgL=
oaLG5`_ooooo3_l@410=oaDE5@ko3`l?3_lE5AD>o`/;2`ko5ADE3_l=3@d=oa0@40[ooooo3_m8B4P>
ooooo`koIFEU3_nEUID>onSXj0ko<S8b3On_[jl=oc<c<`_ooooo3_n^[Zh>oa0@40koUIFE3_mnOWh=
oaTI6@koe=CD3_m7AdL=oeQHF0oooooo000=ooooo`koLg=c3_mOGel>ofa/K0goH61P3_m/K6`>ofi^
KPkoMgMg3OlG5aL;ooooo`ko410@3OlE5AD>o`l?3`ko5ADE3_l;2`/>oaDE5@ko3@d=3Ol@410:oooo
o`koB4Q83_ooool>ofEUI@koUIFE3_oXj>P>oc8b<Pgo[jn_3Olc<c<;ooooo`ko[Zj^3_l@410>oiFE
U@koOWin3OlI6AT>omCDe0koAdM73OmHF5P?ooooo`003Oooool>ofQXJ0koDe=C3_mKFe/=oda<C0ko
GUiN3_mADE4>ofEUI@go00002oooool>ob/[:`go7AdM3_lS8b<>oaXJ6Pko71`L3_lH61P>oa/K6`go
51@D2_ooool>og5aL@kol_;b3_m>CTh>ol71`@kogMgM3_lm?Cd=om_Kf`go=CDe2oooool>og1`L0ko
00003_nRXZ8>oc/k>`go7QhN3_nn_[h>oadM7@goDE5A3oooool000gooooo3_mXJ6P>oe=CD`koFe]K
3Om<C4`>oeiNGPkoDE5A3_mUIFD=o`0000_ooooo3_l[:b/=oadM7@ko8b<S3_lJ6QX>oa`L70ko61PH
3_lK6a/=oa@D50[ooooo3_maLG4>oo;blPkoCTi>3_o1`L4>omgMg@ko?Cdm3OoKfm/=ocDe=@_ooooo
3_m`L70>o`0000koXZ:R3_lk>c/=oahN7Pko_[jn3_lM7Ad=oe5AD@oooooo000=ooooo`koJ6QX3_mC
De<>oe]KF`goC4a<3_mNGUh>oe5AD@koIFEU3Ol0000;ooooo`ko:b/[3OlM7Ad>ob<S8`ko6QXJ3_lL
71`>oaPH60ko6a/K3OlD51@:ooooo`koLG5a3_obl_8>odi>CPko`L713_oMgMd>ocdm?@gofm_K3Ole
=CD;ooooo`koL71`3_l0000>oj:RXPko>c/k3OlN7Qh>okjn_Pko7AdM3OmADE4?ooooo`003Oooool>
ofQXJ0koDe=C3_mKFe/=oda<C0koGUiN3_mADE4>ofEUI@go00002oooool>ob/[:`go7AdM3_lS8b<>
oaXJ6Pko71`L3_lH61P>oa/K6`go51@D2_ooool>og5aL@kol_;b3_m>CTh>ol71`@kogMgM3_lm?Cd=
om_Kf`go=CDe2oooool>og1`L0ko00003_nRXZ8>oc/k>`go7QhN3_nn_[h>oadM7@goDE5A3oooool0
00gooooo3_mXJ6P>oe=CD`koFe]K3Om<C4`>oeiNGPkoDE5A3_mUIFD=o`0000_ooooo3_l[:b/=oadM
7@ko8b<S3_lJ6QX>oa`L70ko61PH3_lK6a/=oa@D50[ooooo3_maLG4>oo;blPkoCTi>3_o1`L4>omgM
g@ko?Cdm3OoKfm/=ocDe=@_ooooo3_m`L70>o`0000koXZ:R3_lk>c/=oahN7Pko_[jn3_lM7Ad=oe5A
D@oooooo000=ooooo`koJ6QX3_mCDe<>oe]KF`goC4a<3_mNGUh>oe5AD@koIFEU3Ol0000;ooooo`ko
:b/[3OlM7Ad>ob<S8`ko6QXJ3_lL71`>oaPH60ko6a/K3OlD51@:ooooo`koLG5a3_obl_8>odi>CPko
`L713_oMgMd>ocdm?@gofm_K3Ole=CD;ooooo`koL71`3_l0000>oj:RXPko>c/k3OlN7Qh>okjn_Pko
7AdM3OmADE4?ooooo`003Oooool>ofQXJ0koDe=C3_mKFe/=oda<C0koGUiN3_mADE4>ofEUI@go0000
2oooool>ob/[:`go7AdM3_lS8b<>oaXJ6Pko71`L3_lH61P>oa/K6`go51@D2_ooool>og5aL@kol_;b
3_m>CTh>ol71`@kogMgM3_lm?Cd=om_Kf`go=CDe2oooool>og1`L0ko00003_nRXZ8>oc/k>`go7QhN
3_nn_[h>oadM7@goDE5A3oooool000gooooo3_mXJ6P>oe=CD`koFe]K3Om<C4`>oeiNGPkoDE5A3_mU
IFD=o`0000_ooooo3_l[:b/=oadM7@ko8b<S3_lJ6QX>oa`L70ko61PH3_lK6a/=oa@D50[ooooo3_ma
LG4>oo;blPkoCTi>3_o1`L4>omgMg@ko?Cdm3OoKfm/=ocDe=@_ooooo3_m`L70>o`0000koXZ:R3_lk
>c/=oahN7Pko_[jn3_lM7Ad=oe5AD@oooooo000=ooooo`koJ6QX3_mCDe<>oe]KF`goC4a<3_mNGUh>
oe5AD@koIFEU3Ol0000;ooooo`ko:b/[3OlM7Ad>ob<S8`ko6QXJ3_lL71`>oaPH60ko6a/K3OlD51@:
ooooo`koLG5a3_obl_8>odi>CPko`L713_oMgMd>ocdm?@gofm_K3Ole=CD;ooooo`koL71`3_l0000>
oj:RXPko>c/k3OlN7Qh>okjn_Pko7AdM3OmADE4?ooooo`003Oooool>ofQXJ0koDe=C3_mKFe/=oda<
C0koGUiN3_mADE4>ofEUI@go00002oooool>ob/[:`go7AdM3_lS8b<>oaXJ6Pko71`L3_lH61P>oa/K
6`go51@D2_ooool>og5aL@kol_;b3_m>CTh>ol71`@kogMgM3_lm?Cd=om_Kf`go=CDe2oooool>og1`
L0ko00003_nRXZ8>oc/k>`go7QhN3_nn_[h>oadM7@goDE5A3oooool000gooooo3_mXJ6P>oe=CD`ko
Fe]K3Om<C4`>oeiNGPkoDE5A3_mUIFD=o`0000_ooooo3_l[:b/=oadM7@ko8b<S3_lJ6QX>oa`L70ko
61PH3_lK6a/=oa@D50[ooooo3_maLG4>oo;blPkoCTi>3_o1`L4>omgMg@ko?Cdm3OoKfm/=ocDe=@_o
oooo3_m`L70>o`0000koXZ:R3_lk>c/=oahN7Pko_[jn3_lM7Ad=oe5AD@oooooo000=ooooo`koJ6QX
3_mCDe<>oe]KF`goC4a<3_mNGUh>oe5AD@koIFEU3Ol0000;ooooo`ko:b/[3OlM7Ad>ob<S8`ko6QXJ
3_lL71`>oaPH60ko6a/K3OlD51@:ooooo`koLG5a3_obl_8>odi>CPko`L713_oMgMd>ocdm?@gofm_K
3Ole=CD;ooooo`koL71`3_l0000>oj:RXPko>c/k3OlN7Qh>okjn_Pko7AdM3OmADE4?ooooo`003Ooo
ool>ofQXJ0koDe=C3_mKFe/=oda<C0koGUiN3_mADE4>ofEUI@go00002oooool>ob/[:`go7AdM3_lS
8b<>oaXJ6Pko71`L3_lH61P>oa/K6`go51@D2_ooool>og5aL@kol_;b3_m>CTh>ol71`@kogMgM3_lm
?Cd=om_Kf`go=CDe2oooool>og1`L0ko00003_nRXZ8>oc/k>`go7QhN3_nn_[h>oadM7@goDE5A3ooo
ool000gooooo3_mXJ6P>oe=CD`koFe]K3Om<C4`>oeiNGPkoDE5A3_mUIFD=o`0000_ooooo3_l[:b/=
oadM7@ko8b<S3_lJ6QX>oa`L70ko61PH3_lK6a/=oa@D50[ooooo3_maLG4>oo;blPkoCTi>3_o1`L4>
omgMg@ko?Cdm3OoKfm/=ocDe=@_ooooo3_m`L70>o`0000koXZ:R3_lk>c/=oahN7Pko_[jn3_lM7Ad=
oe5AD@oooooo000=ooooo`koR8R83_mTI6@>ogQhN0goIVIV3_mkNg/>ofMWI`koNg]k3OlC4a<;oooo
o`ko;2`/3Ole=CD>obTY:@ko<c<c3_lT92@>oc8b<Pko8b<S3OlU9BD:ooooo`koN7Qh3_nf][H>ocHf
=PkodM7A3_nDU9@>odY:BPgoeMGE3OlD51@;ooooo`koDE5A3_l];Bd>oibLW0ko5aLG3Om5ADD>oiZJ
VPko0`<33OmLG5`?ooooo`003Oooool>ohR8R0koI6AT3_mhN7P=ofIVIPkoNg]k3_mWIfL>og]kN`go
4a<C2oooool>ob`/;0go=CDe3_lY:BT>oc<c<`ko92@T3_lb<S8>ob<S8`go9BDU2_ooool>ogQhN0ko
][Jf3_lf=SH>om7Ad@koU9BD3_m:BTX=omGEe@go51@D2oooool>oe5AD@ko;Bd]3_nLW9`>oaLG5`go
ADE53_nJVYX>o`<30`goG5aL3oooool000gooooo3_n8R8P>ofATI0koN7Qh3OmVIVH>og]kN`koIfMW
3_mkNg/=oa<C4`_ooooo3_l/;2`=ocDe=@ko:BTY3_lc<c<>ob@T90ko<S8b3_lS8b<=obDU9@[ooooo
3_mhN7P>okJf]Pko=SHf3_oAdM4>oiBDU0koBTY:3OoEeMD=oa@D50_ooooo3_mADE4>obd];@koW9bL
3_lG5aL=odE5A@koVYZJ3_l30`<=oeaLG0oooooo000=ooooo`koR8R83_mTI6@>ogQhN0goIVIV3_mk
Ng/>ofMWI`koNg]k3OlC4a<;ooooo`ko;2`/3Ole=CD>obTY:@ko<c<c3_lT92@>oc8b<Pko8b<S3OlU
9BD:ooooo`koN7Qh3_nf][H>ocHf=PkodM7A3_nDU9@>odY:BPgoeMGE3OlD51@;ooooo`koDE5A3_l]
;Bd>oibLW0ko5aLG3Om5ADD>oiZJVPko0`<33OmLG5`?ooooo`003Oooool>ohR8R0koI6AT3_mhN7P=
ofIVIPkoNg]k3_mWIfL>og]kN`go4a<C2oooool>ob`/;0go=CDe3_lY:BT>oc<c<`ko92@T3_lb<S8>
ob<S8`go9BDU2_ooool>ogQhN0ko][Jf3_lf=SH>om7Ad@koU9BD3_m:BTX=omGEe@go51@D2oooool>
oe5AD@ko;Bd]3_nLW9`>oaLG5`goADE53_nJVYX>o`<30`goG5aL3oooool000gooooo3_n8R8P>ofAT
I0koN7Qh3OmVIVH>og]kN`koIfMW3_mkNg/=oa<C4`_ooooo3_l/;2`=ocDe=@ko:BTY3_lc<c<>ob@T
90ko<S8b3_lS8b<=obDU9@[ooooo3_mhN7P>okJf]Pko=SHf3_oAdM4>oiBDU0koBTY:3OoEeMD=oa@D
50_ooooo3_mADE4>obd];@koW9bL3_lG5aL=odE5A@koVYZJ3_l30`<=oeaLG0oooooo000=ooooo`ko
R8R83_mTI6@>ogQhN0goIVIV3_mkNg/>ofMWI`koNg]k3OlC4a<;ooooo`ko;2`/3Ole=CD>obTY:@ko
<c<c3_lT92@>oc8b<Pko8b<S3OlU9BD:ooooo`koN7Qh3_nf][H>ocHf=PkodM7A3_nDU9@>odY:BPgo
eMGE3OlD51@;ooooo`koDE5A3_l];Bd>oibLW0ko5aLG3Om5ADD>oiZJVPko0`<33OmLG5`?ooooo`00
3Oooool>ohR8R0koI6AT3_mhN7P=ofIVIPkoNg]k3_mWIfL>og]kN`go4a<C2oooool>ob`/;0go=CDe
3_lY:BT>oc<c<`ko92@T3_lb<S8>ob<S8`go9BDU2_ooool>ogQhN0ko][Jf3_lf=SH>om7Ad@koU9BD
3_m:BTX=omGEe@go51@D2oooool>oe5AD@ko;Bd]3_nLW9`>oaLG5`goADE53_nJVYX>o`<30`goG5aL
3oooool000gooooo3_n8R8P>ofATI0koN7Qh3OmVIVH>og]kN`koIfMW3_mkNg/=oa<C4`_ooooo3_l/
;2`=ocDe=@ko:BTY3_lc<c<>ob@T90ko<S8b3_lS8b<=obDU9@[ooooo3_mhN7P>okJf]Pko=SHf3_oA
dM4>oiBDU0koBTY:3OoEeMD=oa@D50_ooooo3_mADE4>obd];@koW9bL3_lG5aL=odE5A@koVYZJ3_l3
0`<=oeaLG0oooooo000=ooooo`koR8R83_mTI6@>ogQhN0goIVIV3_mkNg/>ofMWI`koNg]k3OlC4a<;
ooooo`ko;2`/3Ole=CD>obTY:@ko<c<c3_lT92@>oc8b<Pko8b<S3OlU9BD:ooooo`koN7Qh3_nf][H>
ocHf=PkodM7A3_nDU9@>odY:BPgoeMGE3OlD51@;ooooo`koDE5A3_l];Bd>oibLW0ko5aLG3Om5ADD>
oiZJVPko0`<33OmLG5`?ooooo`003Oooool>ohR8R0koI6AT3_mhN7P=ofIVIPkoNg]k3_mWIfL>og]k
N`go4a<C2oooool>ob`/;0go=CDe3_lY:BT>oc<c<`ko92@T3_lb<S8>ob<S8`go9BDU2_ooool>ogQh
N0ko][Jf3_lf=SH>om7Ad@koU9BD3_m:BTX=omGEe@go51@D2oooool>oe5AD@ko;Bd]3_nLW9`>oaLG
5`goADE53_nJVYX>o`<30`goG5aL3oooool000gooooo3_n8R8P>ofATI0koN7Qh3OmVIVH>og]kN`ko
IfMW3_mkNg/=oa<C4`_ooooo3_l/;2`=ocDe=@ko:BTY3_lc<c<>ob@T90ko<S8b3_lS8b<=obDU9@[o
oooo3_mhN7P>okJf]Pko=SHf3_oAdM4>oiBDU0koBTY:3OoEeMD=oa@D50_ooooo3_mADE4>obd];@ko
W9bL3_lG5aL=odE5A@koVYZJ3_l30`<=oeaLG0oooooo000=ooooo`koR8R83_mTI6@>ogQhN0goIVIV
3_mkNg/>ofMWI`koNg]k3OlC4a<;ooooo`ko;2`/3Ole=CD>obTY:@ko<c<c3_lT92@>oc8b<Pko8b<S
3OlU9BD:ooooo`koN7Qh3_nf][H>ocHf=PkodM7A3_nDU9@>odY:BPgoeMGE3OlD51@;ooooo`koDE5A
3_l];Bd>oibLW0ko5aLG3Om5ADD>oiZJVPko0`<33OmLG5`?ooooo`003Oooool>oo7al@kooooo3_oI
fMT=ooCdm0koj^[Z3_olo?`>oo3`l0gob/[:2oooool>onGUi@gojNWY3_ooool>ooOgm`koo_kn3_oa
lO4>oo?cl`go`/;22_ooool>oeaLG0ko6a/K3_mBDU8>od51@@ko4Q8B3_m[Jf/=od92@Pgo820P2ooo
ool>ocLg=`koHF5Q3_lY:BT>oc<c<`goHV9R3_l=3@d>ocdm?@go61PH3oooool000gooooo3_oalO4>
ooooo`kofMWI3Oodm?@>on[ZjPkoo?cl3_o`l?0=ol[:bP_ooooo3_oUiND=onWYj@kooooo3_ogmoL>
ooknoPkolO7a3_oclo<=ol;2`P[ooooo3_mLG5`>oa/K6`koDU9B3_m1@D4>oa8B4PkoJf][3Om2@T8=
ob0P80_ooooo3_lg=cL>of5QH@ko:BTY3_lc<c<=of9RHPko3@d=3_lm?Cd=oaPH60oooooo000=oooo
o`kolO7a3_ooool>omWIf@gom?Cd3_oZj^X>ooclo0kol?3`3Oo:b/X;ooooo`koiNGU3OoYjNT>oooo
o`komoOg3_ono_h>oo7al@kolo?c3Oo2`/8:ooooo`koG5aL3_lK6a/>oe9BDPko@D513_lB4Q8>of][
J`go@T923OlP820;ooooo`ko=cLg3_mQHF4>obTY:@ko<c<c3OmRHV8>o`d=3@ko?Cdm3OlH61P?oooo
o`003Oooool>oo7al@kooooo3_oIfMT=ooCdm0koj^[Z3_olo?`>oo3`l0gob/[:2oooool>onGUi@go
jNWY3_ooool>ooOgm`koo_kn3_oalO4>oo?cl`go`/;22_ooool>oeaLG0ko6a/K3_mBDU8>od51@@ko
4Q8B3_m[Jf/=od92@Pgo820P2oooool>ocLg=`koHF5Q3_lY:BT>oc<c<`goHV9R3_l=3@d>ocdm?@go
61PH3oooool000gooooo3_oalO4>ooooo`kofMWI3Oodm?@>on[ZjPkoo?cl3_o`l?0=ol[:bP_ooooo
3_oUiND=onWYj@kooooo3_ogmoL>ooknoPkolO7a3_oclo<=ol;2`P[ooooo3_mLG5`>oa/K6`koDU9B
3_m1@D4>oa8B4PkoJf][3Om2@T8=ob0P80_ooooo3_lg=cL>of5QH@ko:BTY3_lc<c<=of9RHPko3@d=
3_lm?Cd=oaPH60oooooo000=ooooo`kolO7a3_ooool>omWIf@gom?Cd3_oZj^X>ooclo0kol?3`3Oo:
b/X;ooooo`koiNGU3OoYjNT>ooooo`komoOg3_ono_h>oo7al@kolo?c3Oo2`/8:ooooo`koG5aL3_lK
6a/>oe9BDPko@D513_lB4Q8>of][J`go@T923OlP820;ooooo`ko=cLg3_mQHF4>obTY:@ko<c<c3OmR
HV8>o`d=3@ko?Cdm3OlH61P?ooooo`003Oooool>oo7al@kooooo3_oIfMT=ooCdm0koj^[Z3_olo?`>
oo3`l0gob/[:2oooool>onGUi@gojNWY3_ooool>ooOgm`koo_kn3_oalO4>oo?cl`go`/;22_ooool>
oeaLG0ko6a/K3_mBDU8>od51@@ko4Q8B3_m[Jf/=od92@Pgo820P2oooool>ocLg=`koHF5Q3_lY:BT>
oc<c<`goHV9R3_l=3@d>ocdm?@go61PH3oooool000gooooo3_oalO4>ooooo`kofMWI3Oodm?@>on[Z
jPkoo?cl3_o`l?0=ol[:bP_ooooo3_oUiND=onWYj@kooooo3_ogmoL>ooknoPkolO7a3_oclo<=ol;2
`P[ooooo3_mLG5`>oa/K6`koDU9B3_m1@D4>oa8B4PkoJf][3Om2@T8=ob0P80_ooooo3_lg=cL>of5Q
H@ko:BTY3_lc<c<=of9RHPko3@d=3_lm?Cd=oaPH60oooooo000=ooooo`kolO7a3_ooool>omWIf@go
m?Cd3_oZj^X>ooclo0kol?3`3Oo:b/X;ooooo`koiNGU3OoYjNT>ooooo`komoOg3_ono_h>oo7al@ko
lo?c3Oo2`/8:ooooo`koG5aL3_lK6a/>oe9BDPko@D513_lB4Q8>of][J`go@T923OlP820;ooooo`ko
=cLg3_mQHF4>obTY:@ko<c<c3OmRHV8>o`d=3@ko?Cdm3OlH61P?ooooo`003Oooool>oo7al@kooooo
3_oIfMT=ooCdm0koj^[Z3_olo?`>oo3`l0gob/[:2oooool>onGUi@gojNWY3_ooool>ooOgm`koo_kn
3_oalO4>oo?cl`go`/;22_ooool>oeaLG0ko6a/K3_mBDU8>od51@@ko4Q8B3_m[Jf/=od92@Pgo820P
2oooool>ocLg=`koHF5Q3_lY:BT>oc<c<`goHV9R3_l=3@d>ocdm?@go61PH3oooool000gooooo3_oa
lO4>ooooo`kofMWI3Oodm?@>on[ZjPkoo?cl3_o`l?0=ol[:bP_ooooo3_oUiND=onWYj@kooooo3_og
moL>ooknoPkolO7a3_oclo<=ol;2`P[ooooo3_mLG5`>oa/K6`koDU9B3_m1@D4>oa8B4PkoJf][3Om2
@T8=ob0P80_ooooo3_lg=cL>of5QH@ko:BTY3_lc<c<=of9RHPko3@d=3_lm?Cd=oaPH60oooooo000=
ooooo`kolO7a3_ooool>omWIf@gom?Cd3_oZj^X>ooclo0kol?3`3Oo:b/X;ooooo`koiNGU3OoYjNT>
ooooo`komoOg3_ono_h>oo7al@kolo?c3Oo2`/8:ooooo`koG5aL3_lK6a/>oe9BDPko@D513_lB4Q8>
of][J`go@T923OlP820;ooooo`ko=cLg3_mQHF4>obTY:@ko<c<c3OmRHV8>o`d=3@ko?Cdm3OlH61P?
ooooo`003Oooool>oo7al@kooooo3_oIfMT=ooCdm0koj^[Z3_olo?`>oo3`l0gob/[:2oooool>onGU
i@gojNWY3_ooool>ooOgm`koo_kn3_oalO4>oo?cl`go`/;22_ooool>oeaLG0ko6a/K3_mBDU8>od51
@@ko4Q8B3_m[Jf/=od92@Pgo820P2oooool>ocLg=`koHF5Q3_lY:BT>oc<c<`goHV9R3_l=3@d>ocdm
?@go61PH3oooool000gooooo3_oalO4>ooooo`kofMWI3Oodm?@>on[ZjPkoo?cl3_o`l?0=ol[:bP_o
oooo3_oUiND=onWYj@kooooo3_ogmoL>ooknoPkolO7a3_oclo<=ol;2`P[ooooo3_mLG5`>oa/K6`ko
DU9B3_m1@D4>oa8B4PkoJf][3Om2@T8=ob0P80_ooooo3_lg=cL>of5QH@ko:BTY3_lc<c<=of9RHPko
3@d=3_lm?Cd=oaPH60oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.984105, \
-0.202776, 0.0728937, 0.0728937}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-9.78601, -0.202776, 0.0728937, 0.0728937}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-18.5834, -0.202776, 0.0728937, 0.0728937}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-27.3853, -0.202776, 0.0728937, 0.0728937}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C1B210D221F34FF
29141306131E30F6
3213160017192DFB
23141002111E2DF7
30131700161A2FFA
2418100811212DFA
32191D0B1D2635FA
21140F0F101F27DF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3EBFE37C211F603F
3DD6E75E131A6527
59E9DE560D257126
5CF4DC36002B801D
7AFFC92F07398225
7FFABE150647931D
95F8A317184F8B2C
8BDA90070D519137
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3D0C36C3C76717A3
33003CD8D04A098F
1F0059EDC0450A9F
18035FF9C5280081
0E0C7DFFAC260D8A
0B1587F9A50F0D6D
0C2795F084121F73
092F8CCF770C155C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C7892E0C63D0CE88
DE6C25086FE6D99F
D06A10108BF4CDAB
E2490D1797FCC7BE
C0400026ACFFB5C9
C6280138B5F7A2D3
A3200B48C2EE93D7
910D044EB6CB74C2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>oc`l?0ko6a/K3_lQ
8B4=o`d=3@ko8R8R3_lO7al>oc@d=1Sooooo3_ln?Sh=okno_`kohn?S3_mlO7`>ob4Q8@ko7alO3_mP
H60=oclo?`[ooooo3_lm?Cd>o``<30ko=SHf3_o3`l<>olO7a`koIfMW3OlG5aL=oj>SX`_ooooo3_o7
alL>ohV9R@ko;Rh^3_l<30`=of=SH`kod=3@3_o>c/h=ohR8R0oooooo000=ooooo`ko?3`l3_lK6a/>
ob4Q8@go3@d=3_lR8R8>oalO7`ko=3@d6?ooool>ochn?Pgo_kno3_oShn<>ogalO0ko8B4Q3_lO7al>
of1PH0go?clo2_ooool>ocdm?@ko30`<3_lf=SH>ol?3``koalO73_mWIfL=oaLG5`goXj>S2oooool>
olO7a`koRHV93_l^;Rh>o``<30goHf=S3_o@d=0>olk>cPgoR8R83oooool000gooooo3_ll?3`>oa/K
6`ko8B4Q3Ol=3@d>ob8R8Pko7alO3_ld=3@Hooooo`ko?Shn3Ono_kl>on?Sh`koO7al3_lQ8B4>oalO
7`koH61P3Olo?cl:ooooo`ko?Cdm3_l<30`>ocHf=Pko`l?33_o7alL>ofMWI`go5aLG3OnSXj<;oooo
o`koalO73_n9RHT>obh^;Pko30`<3OmSHf<>om3@d0koc/k>3On8R8P?ooooo`003Oooool>oc`l?0ko
6a/K3_lQ8B4=o`d=3@ko8R8R3_lO7al>oc@d=1Sooooo3_ln?Sh=okno_`kohn?S3_mlO7`>ob4Q8@ko
7alO3_mPH60=oclo?`[ooooo3_lm?Cd>o``<30ko=SHf3_o3`l<>olO7a`koIfMW3OlG5aL=oj>SX`_o
oooo3_o7alL>ohV9R@ko;Rh^3_l<30`=of=SH`kod=3@3_o>c/h=ohR8R0oooooo000=ooooo`ko?3`l
3_lK6a/>ob4Q8@go3@d=3_lR8R8>oalO7`ko=3@d6?ooool>ochn?Pgo_kno3_oShn<>ogalO0ko8B4Q
3_lO7al>of1PH0go?clo2_ooool>ocdm?@ko30`<3_lf=SH>ol?3``koalO73_mWIfL=oaLG5`goXj>S
2oooool>olO7a`koRHV93_l^;Rh>o``<30goHf=S3_o@d=0>olk>cPgoR8R83oooool000gooooo3_ll
?3`>oa/K6`ko8B4Q3Ol=3@d>ob8R8Pko7alO3_ld=3@Hooooo`ko?Shn3Ono_kl>on?Sh`koO7al3_lQ
8B4>oalO7`koH61P3Olo?cl:ooooo`ko?Cdm3_l<30`>ocHf=Pko`l?33_o7alL>ofMWI`go5aLG3OnS
Xj<;ooooo`koalO73_n9RHT>obh^;Pko30`<3OmSHf<>om3@d0koc/k>3On8R8P?ooooo`003Oooool>
oc`l?0ko6a/K3_lQ8B4=o`d=3@ko8R8R3_lO7al>oc@d=1Sooooo3_ln?Sh=okno_`kohn?S3_mlO7`>
ob4Q8@ko7alO3_mPH60=oclo?`[ooooo3_lm?Cd>o``<30ko=SHf3_o3`l<>olO7a`koIfMW3OlG5aL=
oj>SX`_ooooo3_o7alL>ohV9R@ko;Rh^3_l<30`=of=SH`kod=3@3_o>c/h=ohR8R0oooooo000=oooo
o`ko?3`l3_lK6a/>ob4Q8@go3@d=3_lR8R8>oalO7`ko=3@d6?ooool>ochn?Pgo_kno3_oShn<>ogal
O0ko8B4Q3_lO7al>of1PH0go?clo2_ooool>ocdm?@ko30`<3_lf=SH>ol?3``koalO73_mWIfL=oaLG
5`goXj>S2oooool>olO7a`koRHV93_l^;Rh>o``<30goHf=S3_o@d=0>olk>cPgoR8R83oooool000go
oooo3_ll?3`>oa/K6`ko8B4Q3Ol=3@d>ob8R8Pko7alO3_ld=3@Hooooo`ko?Shn3Ono_kl>on?Sh`ko
O7al3_lQ8B4>oalO7`koH61P3Olo?cl:ooooo`ko?Cdm3_l<30`>ocHf=Pko`l?33_o7alL>ofMWI`go
5aLG3OnSXj<;ooooo`koalO73_n9RHT>obh^;Pko30`<3OmSHf<>om3@d0koc/k>3On8R8P?ooooo`00
3Oooool>oc`l?0ko6a/K3_lQ8B4=o`d=3@ko8R8R3_lO7al>oc@d=1Sooooo3_ln?Sh=okno_`kohn?S
3_mlO7`>ob4Q8@ko7alO3_mPH60=oclo?`[ooooo3_lm?Cd>o``<30ko=SHf3_o3`l<>olO7a`koIfMW
3OlG5aL=oj>SX`_ooooo3_o7alL>ohV9R@ko;Rh^3_l<30`=of=SH`kod=3@3_o>c/h=ohR8R0oooooo
000=ooooo`ko?3`l3_lK6a/>ob4Q8@go3@d=3_lR8R8>oalO7`ko=3@d6?ooool>ochn?Pgo_kno3_oS
hn<>ogalO0ko8B4Q3_lO7al>of1PH0go?clo2_ooool>ocdm?@ko30`<3_lf=SH>ol?3``koalO73_mW
IfL=oaLG5`goXj>S2oooool>olO7a`koRHV93_l^;Rh>o``<30goHf=S3_o@d=0>olk>cPgoR8R83ooo
ool000gooooo3_ll?3`>oa/K6`ko8B4Q3Ol=3@d>ob8R8Pko7alO3_ld=3@Hooooo`ko?Shn3Ono_kl>
on?Sh`koO7al3_lQ8B4>oalO7`koH61P3Olo?cl:ooooo`ko?Cdm3_l<30`>ocHf=Pko`l?33_o7alL>
ofMWI`go5aLG3OnSXj<;ooooo`koalO73_n9RHT>obh^;Pko30`<3OmSHf<>om3@d0koc/k>3On8R8P?
ooooo`003Oooool>oc`l?0ko6a/K3_lQ8B4=o`d=3@ko8R8R3_lO7al>oc@d=1Sooooo3_ln?Sh=okno
_`kohn?S3_mlO7`>ob4Q8@ko7alO3_mPH60=oclo?`[ooooo3_lm?Cd>o``<30ko=SHf3_o3`l<>olO7
a`koIfMW3OlG5aL=oj>SX`_ooooo3_o7alL>ohV9R@ko;Rh^3_l<30`=of=SH`kod=3@3_o>c/h=ohR8
R0oooooo000=ooooo`ko?3`l3_lK6a/>ob4Q8@go3@d=3_lR8R8>oalO7`ko=3@d6?ooool>ochn?Pgo
_kno3_oShn<>ogalO0ko8B4Q3_lO7al>of1PH0go?clo2_ooool>ocdm?@ko30`<3_lf=SH>ol?3``ko
alO73_mWIfL=oaLG5`goXj>S2oooool>olO7a`koRHV93_l^;Rh>o``<30goHf=S3_o@d=0>olk>cPgo
R8R83oooool000gooooo3_lY:BT>oa@D50ko4a<C3Ol61PH>oa<C4`ko7QhN3_l`<30=ooKfmP_ooooo
3_lm?Cd=omKFePkoinOW3_mNGUh>oa<C4`ko6QXJ3_mUIFD=obLW9`[ooooo3_lc<c<>o`0000ko?3`l
3_oHf=P>om3@d0koBTY:3Ol92@T=ohn?S`_ooooo3_oNg]h>ofa/K0ko9BDU3_l820P=ofm_K`koi^KV
3_oIfMT=oinOW`oooooo000=ooooo`ko:BTY3_lD51@>oa<C4`go1PH63_lC4a<>oahN7Pko<30`3Oof
m_H;ooooo`ko?Cdm3OoFe]H>onOWi`koGUiN3_lC4a<>oaXJ6PkoIFEU3OlW9bL:ooooo`ko<c<c3_l0
000>oc`l?0kof=SH3_o@d=0>odY:BPgo2@T93On?Shl;ooooo`kog]kN3_m/K6`>obDU9@ko20P83Om_
Kfl>onKViPkofMWI3OnOWil?ooooo`003Oooool>obTY:@ko51@D3_lC4a<=o`H61Pko4a<C3_lN7Qh>
oc0`<0gom_Kf2oooool>ocdm?@goe]KF3_oWinL>oeiNGPko4a<C3_lJ6QX>ofEUI@go9bLW2_ooool>
oc<c<`ko00003_ll?3`>omSHf0kod=3@3_m:BTX=o`T92@goShn?2oooool>omkNgPkoK6a/3_lU9BD>
o`P820goKfm_3_oVi^H>omWIf@goWinO3oooool000gooooo3_lY:BT>oa@D50ko4a<C3Ol61PH>oa<C
4`ko7QhN3_l`<30=ooKfmP_ooooo3_lm?Cd=omKFePkoinOW3_mNGUh>oa<C4`ko6QXJ3_mUIFD=obLW
9`[ooooo3_lc<c<>o`0000ko?3`l3_oHf=P>om3@d0koBTY:3Ol92@T=ohn?S`_ooooo3_oNg]h>ofa/
K0ko9BDU3_l820P=ofm_K`koi^KV3_oIfMT=oinOW`oooooo000=ooooo`ko:BTY3_lD51@>oa<C4`go
1PH63_lC4a<>oahN7Pko<30`3Oofm_H;ooooo`ko?Cdm3OoFe]H>onOWi`koGUiN3_lC4a<>oaXJ6Pko
IFEU3OlW9bL:ooooo`ko<c<c3_l0000>oc`l?0kof=SH3_o@d=0>odY:BPgo2@T93On?Shl;ooooo`ko
g]kN3_m/K6`>obDU9@ko20P83Om_Kfl>onKViPkofMWI3OnOWil?ooooo`003Oooool>obTY:@ko51@D
3_lC4a<=o`H61Pko4a<C3_lN7Qh>oc0`<0gom_Kf2oooool>ocdm?@goe]KF3_oWinL>oeiNGPko4a<C
3_lJ6QX>ofEUI@go9bLW2_ooool>oc<c<`ko00003_ll?3`>omSHf0kod=3@3_m:BTX=o`T92@goShn?
2oooool>omkNgPkoK6a/3_lU9BD>o`P820goKfm_3_oVi^H>omWIf@goWinO3oooool000gooooo3_lY
:BT>oa@D50ko4a<C3Ol61PH>oa<C4`ko7QhN3_l`<30=ooKfmP_ooooo3_lm?Cd=omKFePkoinOW3_mN
GUh>oa<C4`ko6QXJ3_mUIFD=obLW9`[ooooo3_lc<c<>o`0000ko?3`l3_oHf=P>om3@d0koBTY:3Ol9
2@T=ohn?S`_ooooo3_oNg]h>ofa/K0ko9BDU3_l820P=ofm_K`koi^KV3_oIfMT=oinOW`oooooo000=
ooooo`ko:BTY3_lD51@>oa<C4`go1PH63_lC4a<>oahN7Pko<30`3Oofm_H;ooooo`ko?Cdm3OoFe]H>
onOWi`koGUiN3_lC4a<>oaXJ6PkoIFEU3OlW9bL:ooooo`ko<c<c3_l0000>oc`l?0kof=SH3_o@d=0>
odY:BPgo2@T93On?Shl;ooooo`kog]kN3_m/K6`>obDU9@ko20P83Om_Kfl>onKViPkofMWI3OnOWil?
ooooo`003Oooool>obTY:@ko51@D3_lC4a<=o`H61Pko4a<C3_lN7Qh>oc0`<0gom_Kf2oooool>ocdm
?@goe]KF3_oWinL>oeiNGPko4a<C3_lJ6QX>ofEUI@go9bLW2_ooool>oc<c<`ko00003_ll?3`>omSH
f0kod=3@3_m:BTX=o`T92@goShn?2oooool>omkNgPkoK6a/3_lU9BD>o`P820goKfm_3_oVi^H>omWI
f@goWinO3oooool000gooooo3_lY:BT>oa@D50ko4a<C3Ol61PH>oa<C4`ko7QhN3_l`<30=ooKfmP_o
oooo3_lm?Cd=omKFePkoinOW3_mNGUh>oa<C4`ko6QXJ3_mUIFD=obLW9`[ooooo3_lc<c<>o`0000ko
?3`l3_oHf=P>om3@d0koBTY:3Ol92@T=ohn?S`_ooooo3_oNg]h>ofa/K0ko9BDU3_l820P=ofm_K`ko
i^KV3_oIfMT=oinOW`oooooo000=ooooo`ko:BTY3_lD51@>oa<C4`go1PH63_lC4a<>oahN7Pko<30`
3Oofm_H;ooooo`ko?Cdm3OoFe]H>onOWi`koGUiN3_lC4a<>oaXJ6PkoIFEU3OlW9bL:ooooo`ko<c<c
3_l0000>oc`l?0kof=SH3_o@d=0>odY:BPgo2@T93On?Shl;ooooo`kog]kN3_m/K6`>obDU9@ko20P8
3Om_Kfl>onKViPkofMWI3OnOWil?ooooo`003Oooool>obTY:@ko51@D3_lC4a<=o`H61Pko4a<C3_lN
7Qh>oc0`<0gom_Kf2oooool>ocdm?@goe]KF3_oWinL>oeiNGPko4a<C3_lJ6QX>ofEUI@go9bLW2_oo
ool>oc<c<`ko00003_ll?3`>omSHf0kod=3@3_m:BTX=o`T92@goShn?2oooool>omkNgPkoK6a/3_lU
9BD>o`P820goKfm_3_oVi^H>omWIf@goWinO3oooool000gooooo3_lY:BT>oa@D50ko4a<C3Ol61PH>
oa<C4`ko7QhN3_l`<30=ooKfmP_ooooo3_lm?Cd=omKFePkoinOW3_mNGUh>oa<C4`ko6QXJ3_mUIFD=
obLW9`[ooooo3_lc<c<>o`0000ko?3`l3_oHf=P>om3@d0koBTY:3Ol92@T=ohn?S`_ooooo3_oNg]h>
ofa/K0ko9BDU3_l820P=ofm_K`koi^KV3_oIfMT=oinOW`oooooo000=ooooo`ko<S8b3_lC4a<>oaHF
5Pgo00003_lG5aL>oaTI6@ko;Bd]3Ookno/;ooooo`koFEUI3OoYjNT>omkNgPkoEUIF3_l=3@d>obDU
9@koLG5a3OlV9RH:ooooo`ko7alO3_l0000>oeUIF@kokNg]3_o0`<0>odE5A@go2PX:3OnOWil;oooo
o`kod=3@3_mZJVXLoa0@40goRh^;3_odm?@>olg=c@goZj^[3oooool000gooooo3_lb<S8>oa<C4`ko
5QHF3Ol0000>oaLG5`ko6ATI3_l];Bd=oo_kn`_ooooo3_mIFET=onWYj@kog]kN3_mFEUH>o`d=3@ko
9BDU3_maLG4=obHV9P[ooooo3_lO7al>o`0000koFEUI3_o]kNd>ol30`0koADE53Ol:2PX=oinOW`_o
oooo3_o@d=0>ofYZJQco410@3On;Rh/>ooCdm0kocLg=3On[Zj/?ooooo`003Oooool>oc8b<Pko4a<C
3_lF5QH=o`0000ko5aLG3_lI6AT>obd];@gono_k2oooool>oeUIF@gojNWY3_oNg]h>oeIFEPko3@d=
3_lU9BD>og5aL@go9RHV2_ooool>oalO7`ko00003_mIFET>ong]k@ko`<303_m5ADD=o`X:2PgoWinO
2oooool>om3@d0koJVYZ7?l@410=oh^;R`kom?Cd3_o=cLd=oj^[Z`oooooo000=ooooo`ko<S8b3_lC
4a<>oaHF5Pgo00003_lG5aL>oaTI6@ko;Bd]3Ookno/;ooooo`koFEUI3OoYjNT>omkNgPkoEUIF3_l=
3@d>obDU9@koLG5a3OlV9RH:ooooo`ko7alO3_l0000>oeUIF@kokNg]3_o0`<0>odE5A@go2PX:3OnO
Wil;ooooo`kod=3@3_mZJVXLoa0@40goRh^;3_odm?@>olg=c@goZj^[3oooool000gooooo3_lb<S8>
oa<C4`ko5QHF3Ol0000>oaLG5`ko6ATI3_l];Bd=oo_kn`_ooooo3_mIFET=onWYj@kog]kN3_mFEUH>
o`d=3@ko9BDU3_maLG4=obHV9P[ooooo3_lO7al>o`0000koFEUI3_o]kNd>ol30`0koADE53Ol:2PX=
oinOW`_ooooo3_o@d=0>ofYZJQco410@3On;Rh/>ooCdm0kocLg=3On[Zj/?ooooo`003Oooool>oc8b
<Pko4a<C3_lF5QH=o`0000ko5aLG3_lI6AT>obd];@gono_k2oooool>oeUIF@gojNWY3_oNg]h>oeIF
EPko3@d=3_lU9BD>og5aL@go9RHV2_ooool>oalO7`ko00003_mIFET>ong]k@ko`<303_m5ADD=o`X:
2PgoWinO2oooool>om3@d0koJVYZ7?l@410=oh^;R`kom?Cd3_o=cLd=oj^[Z`oooooo000=ooooo`ko
<S8b3_lC4a<>oaHF5Pgo00003_lG5aL>oaTI6@ko;Bd]3Ookno/;ooooo`koFEUI3OoYjNT>omkNgPko
EUIF3_l=3@d>obDU9@koLG5a3OlV9RH:ooooo`ko7alO3_l0000>oeUIF@kokNg]3_o0`<0>odE5A@go
2PX:3OnOWil;ooooo`kod=3@3_mZJVXLoa0@40goRh^;3_odm?@>olg=c@goZj^[3oooool000gooooo
3_lb<S8>oa<C4`ko5QHF3Ol0000>oaLG5`ko6ATI3_l];Bd=oo_kn`_ooooo3_mIFET=onWYj@kog]kN
3_mFEUH>o`d=3@ko9BDU3_maLG4=obHV9P[ooooo3_lO7al>o`0000koFEUI3_o]kNd>ol30`0koADE5
3Ol:2PX=oinOW`_ooooo3_o@d=0>ofYZJQco410@3On;Rh/>ooCdm0kocLg=3On[Zj/?ooooo`003Ooo
ool>oc8b<Pko4a<C3_lF5QH=o`0000ko5aLG3_lI6AT>obd];@gono_k2oooool>oeUIF@gojNWY3_oN
g]h>oeIFEPko3@d=3_lU9BD>og5aL@go9RHV2_ooool>oalO7`ko00003_mIFET>ong]k@ko`<303_m5
ADD=o`X:2PgoWinO2oooool>om3@d0koJVYZ7?l@410=oh^;R`kom?Cd3_o=cLd=oj^[Z`oooooo000=
ooooo`ko<S8b3_lC4a<>oaHF5Pgo00003_lG5aL>oaTI6@ko;Bd]3Ookno/;ooooo`koFEUI3OoYjNT>
omkNgPkoEUIF3_l=3@d>obDU9@koLG5a3OlV9RH:ooooo`ko7alO3_l0000>oeUIF@kokNg]3_o0`<0>
odE5A@go2PX:3OnOWil;ooooo`kod=3@3_mZJVXLoa0@40goRh^;3_odm?@>olg=c@goZj^[3oooool0
00gooooo3_lb<S8>oa<C4`ko5QHF3Ol0000>oaLG5`ko6ATI3_l];Bd=oo_kn`_ooooo3_mIFET=onWY
j@kog]kN3_mFEUH>o`d=3@ko9BDU3_maLG4=obHV9P[ooooo3_lO7al>o`0000koFEUI3_o]kNd>ol30
`0koADE53Ol:2PX=oinOW`_ooooo3_o@d=0>ofYZJQco410@3On;Rh/>ooCdm0kocLg=3On[Zj/?oooo
o`003Oooool>oc8b<Pko4a<C3_lF5QH=o`0000ko5aLG3_lI6AT>obd];@gono_k2oooool>oeUIF@go
jNWY3_oNg]h>oeIFEPko3@d=3_lU9BD>og5aL@go9RHV2_ooool>oalO7`ko00003_mIFET>ong]k@ko
`<303_m5ADD=o`X:2PgoWinO2oooool>om3@d0koJVYZ7?l@410=oh^;R`kom?Cd3_o=cLd=oj^[Z`oo
oooo000=ooooo`ko<S8b3_lC4a<>oaHF5Pgo00003_lG5aL>oaTI6@ko;Bd]3Ookno/;ooooo`koFEUI
3OoYjNT>omkNgPkoEUIF3_l=3@d>obDU9@koLG5a3OlV9RH:ooooo`ko7alO3_l0000>oeUIF@kokNg]
3_o0`<0>odE5A@go2PX:3OnOWil;ooooo`kod=3@3_mZJVXLoa0@40goRh^;3_odm?@>olg=c@goZj^[
3oooool000gooooo3_lb<S8>oa<C4`ko5QHF3Ol0000>oaLG5`ko6ATI3_l];Bd=oo_kn`_ooooo3_mI
FET=onWYj@kog]kN3_mFEUH>o`d=3@ko9BDU3_maLG4=obHV9P[ooooo3_lO7al>o`0000koFEUI3_o]
kNd>ol30`0koADE53Ol:2PX=oinOW`_ooooo3_o@d=0>ofYZJQco410@3On;Rh/>ooCdm0kocLg=3On[
Zj/?ooooo`003Oooool>ob<S8`ko51@D3_l@410=o`820Pko4A4A3_lN7Qh>obd];@gomoOg2oooool>
oeaLG0gom?Cd3_oLg=`>ocHf=Pko00003_l[:b/>oh20P0go7AdM2_ooool>oaPH60ko0`<33_mOGel>
ooWin@koaLG53_lX:2P=o`0000goPH612oooool>on;RhPkoBDU93_l=3@d>oaLG5`goUiNG3_olo?`>
olO7a`go_[jn3oooool000gooooo3_lS8b<>oa@D50ko410@3Ol20P8>oa4A4@ko7QhN3_l];Bd=ooOg
m`_ooooo3_mLG5`=ooCdm0kog=cL3_lf=SH>o`0000ko:b/[3_n0P80=oadM7@[ooooo3_lH61P>o`<3
0`koGemO3_oinOT>olG5a@ko:2PX3Ol0000=oh61P@_ooooo3_oRh^8>odU9B@ko3@d=3_lG5aL=oiNG
U`koo?cl3_o7alL=okjn_Poooooo000=ooooo`ko8b<S3_lD51@>oa0@40go0P823_lA4A4>oahN7Pko
;Bd]3OogmoL;ooooo`koG5aL3Oodm?@>omcLg0ko=SHf3_l0000>ob/[:`koP8203OlM7Ad:ooooo`ko
61PH3_l30`<>oemOG`konOWi3_o5aLD>obPX:0go00003On1PH4;ooooo`koh^;R3_m9BDT>o`d=3@ko
5aLG3OnGUiL>ooclo0koalO73Onn_[h?ooooo`003Oooool>ob<S8`ko51@D3_l@410=o`820Pko4A4A
3_lN7Qh>obd];@gomoOg2oooool>oeaLG0gom?Cd3_oLg=`>ocHf=Pko00003_l[:b/>oh20P0go7AdM
2_ooool>oaPH60ko0`<33_mOGel>ooWin@koaLG53_lX:2P=o`0000goPH612oooool>on;RhPkoBDU9
3_l=3@d>oaLG5`goUiNG3_olo?`>olO7a`go_[jn3oooool000gooooo3_lS8b<>oa@D50ko410@3Ol2
0P8>oa4A4@ko7QhN3_l];Bd=ooOgm`_ooooo3_mLG5`=ooCdm0kog=cL3_lf=SH>o`0000ko:b/[3_n0
P80=oadM7@[ooooo3_lH61P>o`<30`koGemO3_oinOT>olG5a@ko:2PX3Ol0000=oh61P@_ooooo3_oR
h^8>odU9B@ko3@d=3_lG5aL=oiNGU`koo?cl3_o7alL=okjn_Poooooo000=ooooo`ko8b<S3_lD51@>
oa0@40go0P823_lA4A4>oahN7Pko;Bd]3OogmoL;ooooo`koG5aL3Oodm?@>omcLg0ko=SHf3_l0000>
ob/[:`koP8203OlM7Ad:ooooo`ko61PH3_l30`<>oemOG`konOWi3_o5aLD>obPX:0go00003On1PH4;
ooooo`koh^;R3_m9BDT>o`d=3@ko5aLG3OnGUiL>ooclo0koalO73Onn_[h?ooooo`003Oooool>ob<S
8`ko51@D3_l@410=o`820Pko4A4A3_lN7Qh>obd];@gomoOg2oooool>oeaLG0gom?Cd3_oLg=`>ocHf
=Pko00003_l[:b/>oh20P0go7AdM2_ooool>oaPH60ko0`<33_mOGel>ooWin@koaLG53_lX:2P=o`00
00goPH612oooool>on;RhPkoBDU93_l=3@d>oaLG5`goUiNG3_olo?`>olO7a`go_[jn3oooool000go
oooo3_lS8b<>oa@D50ko410@3Ol20P8>oa4A4@ko7QhN3_l];Bd=ooOgm`_ooooo3_mLG5`=ooCdm0ko
g=cL3_lf=SH>o`0000ko:b/[3_n0P80=oadM7@[ooooo3_lH61P>o`<30`koGemO3_oinOT>olG5a@ko
:2PX3Ol0000=oh61P@_ooooo3_oRh^8>odU9B@ko3@d=3_lG5aL=oiNGU`koo?cl3_o7alL=okjn_Poo
oooo000=ooooo`ko8b<S3_lD51@>oa0@40go0P823_lA4A4>oahN7Pko;Bd]3OogmoL;ooooo`koG5aL
3Oodm?@>omcLg0ko=SHf3_l0000>ob/[:`koP8203OlM7Ad:ooooo`ko61PH3_l30`<>oemOG`konOWi
3_o5aLD>obPX:0go00003On1PH4;ooooo`koh^;R3_m9BDT>o`d=3@ko5aLG3OnGUiL>ooclo0koalO7
3Onn_[h?ooooo`003Oooool>ob<S8`ko51@D3_l@410=o`820Pko4A4A3_lN7Qh>obd];@gomoOg2ooo
ool>oeaLG0gom?Cd3_oLg=`>ocHf=Pko00003_l[:b/>oh20P0go7AdM2_ooool>oaPH60ko0`<33_mO
Gel>ooWin@koaLG53_lX:2P=o`0000goPH612oooool>on;RhPkoBDU93_l=3@d>oaLG5`goUiNG3_ol
o?`>olO7a`go_[jn3oooool000gooooo3_lS8b<>oa@D50ko410@3Ol20P8>oa4A4@ko7QhN3_l];Bd=
ooOgm`_ooooo3_mLG5`=ooCdm0kog=cL3_lf=SH>o`0000ko:b/[3_n0P80=oadM7@[ooooo3_lH61P>
o`<30`koGemO3_oinOT>olG5a@ko:2PX3Ol0000=oh61P@_ooooo3_oRh^8>odU9B@ko3@d=3_lG5aL=
oiNGU`koo?cl3_o7alL=okjn_Poooooo000=ooooo`ko8b<S3_lD51@>oa0@40go0P823_lA4A4>oahN
7Pko;Bd]3OogmoL;ooooo`koG5aL3Oodm?@>omcLg0ko=SHf3_l0000>ob/[:`koP8203OlM7Ad:oooo
o`ko61PH3_l30`<>oemOG`konOWi3_o5aLD>obPX:0go00003On1PH4;ooooo`koh^;R3_m9BDT>o`d=
3@ko5aLG3OnGUiL>ooclo0koalO73Onn_[h?ooooo`003Oooool>ob<S8`ko51@D3_l@410=o`820Pko
4A4A3_lN7Qh>obd];@gomoOg2oooool>oeaLG0gom?Cd3_oLg=`>ocHf=Pko00003_l[:b/>oh20P0go
7AdM2_ooool>oaPH60ko0`<33_mOGel>ooWin@koaLG53_lX:2P=o`0000goPH612oooool>on;RhPko
BDU93_l=3@d>oaLG5`goUiNG3_olo?`>olO7a`go_[jn3oooool000gooooo3_l`<30>oa<C4`ko5aLG
3Ol0000>oaHF5Pko6QXJ3_l_;bl=oo[jnP_ooooo3_mjNWX=ooooo`kobLW93_l_;bl>o`L71`ko>CTi
3_n2PX8=obDU9@[ooooo3_l>3Ph>o``<30koOGem3_ooool>ojb/[0ko9RHV3Ol=3@d=ohZ:RP_ooooo
3_o0`<0>od10@0ko00003_lV9RH=ojb/[0kooooo3_ne]KD=olW9b@oooooo000=ooooo`ko<30`3_lC
4a<>oaLG5`go00003_lF5QH>oaXJ6Pko;bl_3Oojn_X;ooooo`koNWYj3Oooool>olW9b@ko;bl_3_l7
1`L>ocTi>@koPX:23OlU9BD:ooooo`ko3Ph>3_l<30`>ogemO@kooooo3_n/[:`>obHV9Pgo3@d=3On:
RXX;ooooo`ko`<303_m0@40>o`0000ko9RHV3On/[:`>ooooo`ko]KFe3Oo9bLT?ooooo`003Oooool>
oc0`<0ko4a<C3_lG5aL=o`0000ko5QHF3_lJ6QX>obl_;`gon_[j2oooool>ogYjNPgooooo3_o9bLT>
obl_;`ko1`L73_li>CT>oh:2PPgo9BDU2_ooool>o`h>3Pko30`<3_mmOGd>ooooo`ko[:b/3_lV9RH=
o`d=3@goRXZ:2oooool>ol30`0ko@4103_l0000>obHV9Pgo[:b/3_ooool>okFe]@gobLW93oooool0
00gooooo3_l`<30>oa<C4`ko5aLG3Ol0000>oaHF5Pko6QXJ3_l_;bl=oo[jnP_ooooo3_mjNWX=oooo
o`kobLW93_l_;bl>o`L71`ko>CTi3_n2PX8=obDU9@[ooooo3_l>3Ph>o``<30koOGem3_ooool>ojb/
[0ko9RHV3Ol=3@d=ohZ:RP_ooooo3_o0`<0>od10@0ko00003_lV9RH=ojb/[0kooooo3_ne]KD=olW9
b@oooooo000=ooooo`ko<30`3_lC4a<>oaLG5`go00003_lF5QH>oaXJ6Pko;bl_3Oojn_X;ooooo`ko
NWYj3Oooool>olW9b@ko;bl_3_l71`L>ocTi>@koPX:23OlU9BD:ooooo`ko3Ph>3_l<30`>ogemO@ko
oooo3_n/[:`>obHV9Pgo3@d=3On:RXX;ooooo`ko`<303_m0@40>o`0000ko9RHV3On/[:`>ooooo`ko
]KFe3Oo9bLT?ooooo`003Oooool>oc0`<0ko4a<C3_lG5aL=o`0000ko5QHF3_lJ6QX>obl_;`gon_[j
2oooool>ogYjNPgooooo3_o9bLT>obl_;`ko1`L73_li>CT>oh:2PPgo9BDU2_ooool>o`h>3Pko30`<
3_mmOGd>ooooo`ko[:b/3_lV9RH=o`d=3@goRXZ:2oooool>ol30`0ko@4103_l0000>obHV9Pgo[:b/
3_ooool>okFe]@gobLW93oooool000gooooo3_l`<30>oa<C4`ko5aLG3Ol0000>oaHF5Pko6QXJ3_l_
;bl=oo[jnP_ooooo3_mjNWX=ooooo`kobLW93_l_;bl>o`L71`ko>CTi3_n2PX8=obDU9@[ooooo3_l>
3Ph>o``<30koOGem3_ooool>ojb/[0ko9RHV3Ol=3@d=ohZ:RP_ooooo3_o0`<0>od10@0ko00003_lV
9RH=ojb/[0kooooo3_ne]KD=olW9b@oooooo000=ooooo`ko<30`3_lC4a<>oaLG5`go00003_lF5QH>
oaXJ6Pko;bl_3Oojn_X;ooooo`koNWYj3Oooool>olW9b@ko;bl_3_l71`L>ocTi>@koPX:23OlU9BD:
ooooo`ko3Ph>3_l<30`>ogemO@kooooo3_n/[:`>obHV9Pgo3@d=3On:RXX;ooooo`ko`<303_m0@40>
o`0000ko9RHV3On/[:`>ooooo`ko]KFe3Oo9bLT?ooooo`003Oooool>oc0`<0ko4a<C3_lG5aL=o`00
00ko5QHF3_lJ6QX>obl_;`gon_[j2oooool>ogYjNPgooooo3_o9bLT>obl_;`ko1`L73_li>CT>oh:2
PPgo9BDU2_ooool>o`h>3Pko30`<3_mmOGd>ooooo`ko[:b/3_lV9RH=o`d=3@goRXZ:2oooool>ol30
`0ko@4103_l0000>obHV9Pgo[:b/3_ooool>okFe]@gobLW93oooool000gooooo3_l`<30>oa<C4`ko
5aLG3Ol0000>oaHF5Pko6QXJ3_l_;bl=oo[jnP_ooooo3_mjNWX=ooooo`kobLW93_l_;bl>o`L71`ko
>CTi3_n2PX8=obDU9@[ooooo3_l>3Ph>o``<30koOGem3_ooool>ojb/[0ko9RHV3Ol=3@d=ohZ:RP_o
oooo3_o0`<0>od10@0ko00003_lV9RH=ojb/[0kooooo3_ne]KD=olW9b@oooooo000=ooooo`ko<30`
3_lC4a<>oaLG5`go00003_lF5QH>oaXJ6Pko;bl_3Oojn_X;ooooo`koNWYj3Oooool>olW9b@ko;bl_
3_l71`L>ocTi>@koPX:23OlU9BD:ooooo`ko3Ph>3_l<30`>ogemO@kooooo3_n/[:`>obHV9Pgo3@d=
3On:RXX;ooooo`ko`<303_m0@40>o`0000ko9RHV3On/[:`>ooooo`ko]KFe3Oo9bLT?ooooo`003Ooo
ool>oc0`<0ko4a<C3_lG5aL=o`0000ko5QHF3_lJ6QX>obl_;`gon_[j2oooool>ogYjNPgooooo3_o9
bLT>obl_;`ko1`L73_li>CT>oh:2PPgo9BDU2_ooool>o`h>3Pko30`<3_mmOGd>ooooo`ko[:b/3_lV
9RH=o`d=3@goRXZ:2oooool>ol30`0ko@4103_l0000>obHV9Pgo[:b/3_ooool>okFe]@gobLW93ooo
ool000gooooo3_l`<30>oa<C4`ko5aLG3Ol0000>oaHF5Pko6QXJ3_l_;bl=oo[jnP_ooooo3_mjNWX=
ooooo`kobLW93_l_;bl>o`L71`ko>CTi3_n2PX8=obDU9@[ooooo3_l>3Ph>o``<30koOGem3_ooool>
ojb/[0ko9RHV3Ol=3@d=ohZ:RP_ooooo3_o0`<0>od10@0ko00003_lV9RH=ojb/[0kooooo3_ne]KD=
olW9b@oooooo000=ooooo`ko<30`3_lC4a<>oaLG5`go00003_lF5QH>oaXJ6Pko;bl_3Oojn_X;oooo
o`koNWYj3Oooool>olW9b@ko;bl_3_l71`L>ocTi>@koPX:23OlU9BD:ooooo`ko3Ph>3_l<30`>ogem
O@kooooo3_n/[:`>obHV9Pgo3@d=3On:RXX;ooooo`ko`<303_m0@40>o`0000ko9RHV3On/[:`>oooo
o`ko]KFe3Oo9bLT?ooooo`003Oooool>ob@T90ko61PH3_l@410=o`P820ko4A4A3_lQ8B4>obd];@go
n_[j2oooool>ogmoO`gon_[j3_nn_[h>oaDE5@ko1PH63_m7AdL>oi>CT`go7AdM2_ooool>o`/;2`ko
5ADE3_n7QhL>ooWin@koYJFU3_l?3`l=o`d=3@goKFe]2oooool>olK6aPko:2PX3_l10@4>ocPh>0go
]KFe3_ogmoL>oj:RXPgodm?C3oooool000gooooo3_lT92@>oaPH60ko410@3Ol820P>oa4A4@ko8B4Q
3_l];Bd=oo[jnP_ooooo3_moOgl=oo[jnPko_[jn3_lE5AD>o`H61PkoAdM73_nCTi<=oadM7@[ooooo
3_l;2`/>oaDE5@koQhN73_oinOT>ojFUY@ko3`l?3Ol=3@d=ofe]K@_ooooo3_o6a/H>obPX:0ko0@41
3_lh>3P=okFe]@komoOg3_nRXZ8=om?Cd`oooooo000=ooooo`ko92@T3_lH61P>oa0@40go20P83_lA
4A4>ob4Q8@ko;Bd]3Oojn_X;ooooo`koOgmo3Oojn_X>okjn_Pko5ADE3_l61PH>odM7A`koTi>C3OlM
7Ad:ooooo`ko2`/;3_lE5AD>ohN7Q`konOWi3_nUYJD>o`l?3`go3@d=3Om]KFd;ooooo`koa/K63_lX
:2P>o`410@ko>3Ph3One]KD>ooOgm`koXZ:R3OoCdm<?ooooo`003Oooool>ob@T90ko61PH3_l@410=
o`P820ko4A4A3_lQ8B4>obd];@gon_[j2oooool>ogmoO`gon_[j3_nn_[h>oaDE5@ko1PH63_m7AdL>
oi>CT`go7AdM2_ooool>o`/;2`ko5ADE3_n7QhL>ooWin@koYJFU3_l?3`l=o`d=3@goKFe]2oooool>
olK6aPko:2PX3_l10@4>ocPh>0go]KFe3_ogmoL>oj:RXPgodm?C3oooool000gooooo3_lT92@>oaPH
60ko410@3Ol820P>oa4A4@ko8B4Q3_l];Bd=oo[jnP_ooooo3_moOgl=oo[jnPko_[jn3_lE5AD>o`H6
1PkoAdM73_nCTi<=oadM7@[ooooo3_l;2`/>oaDE5@koQhN73_oinOT>ojFUY@ko3`l?3Ol=3@d=ofe]
K@_ooooo3_o6a/H>obPX:0ko0@413_lh>3P=okFe]@komoOg3_nRXZ8=om?Cd`oooooo000=ooooo`ko
92@T3_lH61P>oa0@40go20P83_lA4A4>ob4Q8@ko;Bd]3Oojn_X;ooooo`koOgmo3Oojn_X>okjn_Pko
5ADE3_l61PH>odM7A`koTi>C3OlM7Ad:ooooo`ko2`/;3_lE5AD>ohN7Q`konOWi3_nUYJD>o`l?3`go
3@d=3Om]KFd;ooooo`koa/K63_lX:2P>o`410@ko>3Ph3One]KD>ooOgm`koXZ:R3OoCdm<?ooooo`00
3Oooool>ob@T90ko61PH3_l@410=o`P820ko4A4A3_lQ8B4>obd];@gon_[j2oooool>ogmoO`gon_[j
3_nn_[h>oaDE5@ko1PH63_m7AdL>oi>CT`go7AdM2_ooool>o`/;2`ko5ADE3_n7QhL>ooWin@koYJFU
3_l?3`l=o`d=3@goKFe]2oooool>olK6aPko:2PX3_l10@4>ocPh>0go]KFe3_ogmoL>oj:RXPgodm?C
3oooool000gooooo3_lT92@>oaPH60ko410@3Ol820P>oa4A4@ko8B4Q3_l];Bd=oo[jnP_ooooo3_mo
Ogl=oo[jnPko_[jn3_lE5AD>o`H61PkoAdM73_nCTi<=oadM7@[ooooo3_l;2`/>oaDE5@koQhN73_oi
nOT>ojFUY@ko3`l?3Ol=3@d=ofe]K@_ooooo3_o6a/H>obPX:0ko0@413_lh>3P=okFe]@komoOg3_nR
XZ8=om?Cd`oooooo000=ooooo`ko92@T3_lH61P>oa0@40go20P83_lA4A4>ob4Q8@ko;Bd]3Oojn_X;
ooooo`koOgmo3Oojn_X>okjn_Pko5ADE3_l61PH>odM7A`koTi>C3OlM7Ad:ooooo`ko2`/;3_lE5AD>
ohN7Q`konOWi3_nUYJD>o`l?3`go3@d=3Om]KFd;ooooo`koa/K63_lX:2P>o`410@ko>3Ph3One]KD>
ooOgm`koXZ:R3OoCdm<?ooooo`003Oooool>ob@T90ko61PH3_l@410=o`P820ko4A4A3_lQ8B4>obd]
;@gon_[j2oooool>ogmoO`gon_[j3_nn_[h>oaDE5@ko1PH63_m7AdL>oi>CT`go7AdM2_ooool>o`/;
2`ko5ADE3_n7QhL>ooWin@koYJFU3_l?3`l=o`d=3@goKFe]2oooool>olK6aPko:2PX3_l10@4>ocPh
>0go]KFe3_ogmoL>oj:RXPgodm?C3oooool000gooooo3_lT92@>oaPH60ko410@3Ol820P>oa4A4@ko
8B4Q3_l];Bd=oo[jnP_ooooo3_moOgl=oo[jnPko_[jn3_lE5AD>o`H61PkoAdM73_nCTi<=oadM7@[o
oooo3_l;2`/>oaDE5@koQhN73_oinOT>ojFUY@ko3`l?3Ol=3@d=ofe]K@_ooooo3_o6a/H>obPX:0ko
0@413_lh>3P=okFe]@komoOg3_nRXZ8=om?Cd`oooooo000=ooooo`ko92@T3_lH61P>oa0@40go20P8
3_lA4A4>ob4Q8@ko;Bd]3Oojn_X;ooooo`koOgmo3Oojn_X>okjn_Pko5ADE3_l61PH>odM7A`koTi>C
3OlM7Ad:ooooo`ko2`/;3_lE5AD>ohN7Q`konOWi3_nUYJD>o`l?3`go3@d=3Om]KFd;ooooo`koa/K6
3_lX:2P>o`410@ko>3Ph3One]KD>ooOgm`koXZ:R3OoCdm<?ooooo`003Oooool>ob@T90ko61PH3_l@
410=o`P820ko4A4A3_lQ8B4>obd];@gon_[j2oooool>ogmoO`gon_[j3_nn_[h>oaDE5@ko1PH63_m7
AdL>oi>CT`go7AdM2_ooool>o`/;2`ko5ADE3_n7QhL>ooWin@koYJFU3_l?3`l=o`d=3@goKFe]2ooo
ool>olK6aPko:2PX3_l10@4>ocPh>0go]KFe3_ogmoL>oj:RXPgodm?C3oooool000gooooo3_lT92@>
oaPH60ko410@3Ol820P>oa4A4@ko8B4Q3_l];Bd=oo[jnP_ooooo3_moOgl=oo[jnPko_[jn3_lE5AD>
o`H61PkoAdM73_nCTi<=oadM7@[ooooo3_l;2`/>oaDE5@koQhN73_oinOT>ojFUY@ko3`l?3Ol=3@d=
ofe]K@_ooooo3_o6a/H>obPX:0ko0@413_lh>3P=okFe]@komoOg3_nRXZ8=om?Cd`oooooo000=oooo
o`ko<S8b3_lI6AT>oadM7@go2`/;3_lM7Ad>obHV9Pko=CDe3Oojn_X;ooooo`koUIFE3Oohn?P>oj>S
X`ko5aLG3_lH61P>odm?C`koRh^;3Ol/;2`:ooooo`ko30`<3_lW9bL>oiFEU@kol?3`3_n4Q8@>oa8B
4Pgo7alO3OmcLg<;ooooo`koXj>S3_lP820>o`/;2`koB4Q83Oo2`/8>onk^kPkoTi>C3OoGemL?oooo
o`003Oooool>oc8b<Pko6ATI3_lM7Ad=o`/;2`ko7AdM3_lV9RH>ocDe=@gon_[j2oooool>oiFEU@go
n?Sh3_nSXj<>oaLG5`ko61PH3_m?Cdl>oh^;R`go;2`/2_ooool>o``<30ko9bLW3_nEUID>oo3`l0ko
Q8B43_lB4Q8=oalO7`goLg=c2oooool>oj>SX`ko820P3_l;2`/>odQ8B0go`/;23_o^k^h>oi>CT`go
emOG3oooool000gooooo3_lb<S8>oaTI6@ko7AdM3Ol;2`/>oadM7@ko9RHV3_le=CD=oo[jnP_ooooo
3_nEUID=ooShn0koXj>S3_lG5aL>oaPH60koCdm?3_n;Rh/=ob`/;0[ooooo3_l<30`>obLW9`koUIFE
3_o`l?0>ohB4Q0ko4Q8B3OlO7al=og=cL`_ooooo3_nSXj<>ob0P80ko2`/;3_m8B4P=ol;2`Pkok^k^
3_nCTi<=omOGe`oooooo000=ooooo`ko<S8b3_lI6AT>oadM7@go2`/;3_lM7Ad>obHV9Pko=CDe3Ooj
n_X;ooooo`koUIFE3Oohn?P>oj>SX`ko5aLG3_lH61P>odm?C`koRh^;3Ol/;2`:ooooo`ko30`<3_lW
9bL>oiFEU@kol?3`3_n4Q8@>oa8B4Pgo7alO3OmcLg<;ooooo`koXj>S3_lP820>o`/;2`koB4Q83Oo2
`/8>onk^kPkoTi>C3OoGemL?ooooo`003Oooool>oc8b<Pko6ATI3_lM7Ad=o`/;2`ko7AdM3_lV9RH>
ocDe=@gon_[j2oooool>oiFEU@gon?Sh3_nSXj<>oaLG5`ko61PH3_m?Cdl>oh^;R`go;2`/2_ooool>
o``<30ko9bLW3_nEUID>oo3`l0koQ8B43_lB4Q8=oalO7`goLg=c2oooool>oj>SX`ko820P3_l;2`/>
odQ8B0go`/;23_o^k^h>oi>CT`goemOG3oooool000gooooo3_lb<S8>oaTI6@ko7AdM3Ol;2`/>oadM
7@ko9RHV3_le=CD=oo[jnP_ooooo3_nEUID=ooShn0koXj>S3_lG5aL>oaPH60koCdm?3_n;Rh/=ob`/
;0[ooooo3_l<30`>obLW9`koUIFE3_o`l?0>ohB4Q0ko4Q8B3OlO7al=og=cL`_ooooo3_nSXj<>ob0P
80ko2`/;3_m8B4P=ol;2`Pkok^k^3_nCTi<=omOGe`oooooo000=ooooo`ko<S8b3_lI6AT>oadM7@go
2`/;3_lM7Ad>obHV9Pko=CDe3Oojn_X;ooooo`koUIFE3Oohn?P>oj>SX`ko5aLG3_lH61P>odm?C`ko
Rh^;3Ol/;2`:ooooo`ko30`<3_lW9bL>oiFEU@kol?3`3_n4Q8@>oa8B4Pgo7alO3OmcLg<;ooooo`ko
Xj>S3_lP820>o`/;2`koB4Q83Oo2`/8>onk^kPkoTi>C3OoGemL?ooooo`003Oooool>oc8b<Pko6ATI
3_lM7Ad=o`/;2`ko7AdM3_lV9RH>ocDe=@gon_[j2oooool>oiFEU@gon?Sh3_nSXj<>oaLG5`ko61PH
3_m?Cdl>oh^;R`go;2`/2_ooool>o``<30ko9bLW3_nEUID>oo3`l0koQ8B43_lB4Q8=oalO7`goLg=c
2oooool>oj>SX`ko820P3_l;2`/>odQ8B0go`/;23_o^k^h>oi>CT`goemOG3oooool000gooooo3_lb
<S8>oaTI6@ko7AdM3Ol;2`/>oadM7@ko9RHV3_le=CD=oo[jnP_ooooo3_nEUID=ooShn0koXj>S3_lG
5aL>oaPH60koCdm?3_n;Rh/=ob`/;0[ooooo3_l<30`>obLW9`koUIFE3_o`l?0>ohB4Q0ko4Q8B3OlO
7al=og=cL`_ooooo3_nSXj<>ob0P80ko2`/;3_m8B4P=ol;2`Pkok^k^3_nCTi<=omOGe`oooooo000=
ooooo`ko<S8b3_lI6AT>oadM7@go2`/;3_lM7Ad>obHV9Pko=CDe3Oojn_X;ooooo`koUIFE3Oohn?P>
oj>SX`ko5aLG3_lH61P>odm?C`koRh^;3Ol/;2`:ooooo`ko30`<3_lW9bL>oiFEU@kol?3`3_n4Q8@>
oa8B4Pgo7alO3OmcLg<;ooooo`koXj>S3_lP820>o`/;2`koB4Q83Oo2`/8>onk^kPkoTi>C3OoGemL?
ooooo`003Oooool>oc8b<Pko6ATI3_lM7Ad=o`/;2`ko7AdM3_lV9RH>ocDe=@gon_[j2oooool>oiFE
U@gon?Sh3_nSXj<>oaLG5`ko61PH3_m?Cdl>oh^;R`go;2`/2_ooool>o``<30ko9bLW3_nEUID>oo3`
l0koQ8B43_lB4Q8=oalO7`goLg=c2oooool>oj>SX`ko820P3_l;2`/>odQ8B0go`/;23_o^k^h>oi>C
T`goemOG3oooool000gooooo3_lb<S8>oaTI6@ko7AdM3Ol;2`/>oadM7@ko9RHV3_le=CD=oo[jnP_o
oooo3_nEUID=ooShn0koXj>S3_lG5aL>oaPH60koCdm?3_n;Rh/=ob`/;0[ooooo3_l<30`>obLW9`ko
UIFE3_o`l?0>ohB4Q0ko4Q8B3OlO7al=og=cL`_ooooo3_nSXj<>ob0P80ko2`/;3_m8B4P=ol;2`Pko
k^k^3_nCTi<=omOGe`oooooo000=ooooo`ko<S8b3_lI6AT>oadM7@go2`/;3_lM7Ad>obHV9Pko=CDe
3Oojn_X;ooooo`koUIFE3Oohn?P>oj>SX`ko5aLG3_lH61P>odm?C`koRh^;3Ol/;2`:ooooo`ko30`<
3_lW9bL>oiFEU@kol?3`3_n4Q8@>oa8B4Pgo7alO3OmcLg<;ooooo`koXj>S3_lP820>o`/;2`koB4Q8
3Oo2`/8>onk^kPkoTi>C3OoGemL?ooooo`003Oooool>ob4Q8@ko51@D6ol?3`l>oa0@40ko7alO3_lW
9bL=omoOg`_ooooo3_n;Rh/=om[JfPkoT92@3_l71`L>o`d=3@koDE5A3_nATI4=ocLg=`[ooooo3_l9
2@T>obl_;`koS8b<3_o?cll>ogMgM`ko30`<3OlE5AD=oeaLG0_ooooo3_nATI4>o`d=3@ko10@43_m>
CTh=okJf]Pkobl_;3_mdM7@=ol;2`Poooooo000=ooooo`ko8B4Q3_lD51@Ko`l?3`ko410@3_lO7al>
obLW9`gogmoO2oooool>oh^;R`gof][J3_n@T90>o`L71`ko3@d=3_mADE4>oi6AT@go=cLg2_ooool>
o`T92@ko;bl_3_n<S8`>olo?c`koMgMg3_l<30`=oaDE5@goG5aL2oooool>oi6AT@ko3@d=3_l410@>
odi>CPgo][Jf3_o;bl/>ogAdM0go`/;23oooool000gooooo3_lQ8B4>oa@D51_o3`l?3_l@410>oalO
7`ko9bLW3OoOgml;ooooo`koRh^;3OoJf]X>oi2@T0ko1`L73_l=3@d>oe5AD@koTI6A3Olg=cL:oooo
o`ko2@T93_l_;bl>ohb<S0koclo?3_mgMgL>o``<30go5ADE3OmLG5`;ooooo`koTI6A3_l=3@d>o`@4
10koCTi>3Onf][H>ol_;b`koM7Ad3Oo2`/8?ooooo`003Oooool>ob4Q8@ko51@D6ol?3`l>oa0@40ko
7alO3_lW9bL=omoOg`_ooooo3_n;Rh/=om[JfPkoT92@3_l71`L>o`d=3@koDE5A3_nATI4=ocLg=`[o
oooo3_l92@T>obl_;`koS8b<3_o?cll>ogMgM`ko30`<3OlE5AD=oeaLG0_ooooo3_nATI4>o`d=3@ko
10@43_m>CTh=okJf]Pkobl_;3_mdM7@=ol;2`Poooooo000=ooooo`ko8B4Q3_lD51@Ko`l?3`ko410@
3_lO7al>obLW9`gogmoO2oooool>oh^;R`gof][J3_n@T90>o`L71`ko3@d=3_mADE4>oi6AT@go=cLg
2_ooool>o`T92@ko;bl_3_n<S8`>olo?c`koMgMg3_l<30`=oaDE5@goG5aL2oooool>oi6AT@ko3@d=
3_l410@>odi>CPgo][Jf3_o;bl/>ogAdM0go`/;23oooool000gooooo3_lQ8B4>oa@D51_o3`l?3_l@
410>oalO7`ko9bLW3OoOgml;ooooo`koRh^;3OoJf]X>oi2@T0ko1`L73_l=3@d>oe5AD@koTI6A3Olg
=cL:ooooo`ko2@T93_l_;bl>ohb<S0koclo?3_mgMgL>o``<30go5ADE3OmLG5`;ooooo`koTI6A3_l=
3@d>o`@410koCTi>3Onf][H>ol_;b`koM7Ad3Oo2`/8?ooooo`003Oooool>ob4Q8@ko51@D6ol?3`l>
oa0@40ko7alO3_lW9bL=omoOg`_ooooo3_n;Rh/=om[JfPkoT92@3_l71`L>o`d=3@koDE5A3_nATI4=
ocLg=`[ooooo3_l92@T>obl_;`koS8b<3_o?cll>ogMgM`ko30`<3OlE5AD=oeaLG0_ooooo3_nATI4>
o`d=3@ko10@43_m>CTh=okJf]Pkobl_;3_mdM7@=ol;2`Poooooo000=ooooo`ko8B4Q3_lD51@Ko`l?
3`ko410@3_lO7al>obLW9`gogmoO2oooool>oh^;R`gof][J3_n@T90>o`L71`ko3@d=3_mADE4>oi6A
T@go=cLg2_ooool>o`T92@ko;bl_3_n<S8`>olo?c`koMgMg3_l<30`=oaDE5@goG5aL2oooool>oi6A
T@ko3@d=3_l410@>odi>CPgo][Jf3_o;bl/>ogAdM0go`/;23oooool000gooooo3_lQ8B4>oa@D51_o
3`l?3_l@410>oalO7`ko9bLW3OoOgml;ooooo`koRh^;3OoJf]X>oi2@T0ko1`L73_l=3@d>oe5AD@ko
TI6A3Olg=cL:ooooo`ko2@T93_l_;bl>ohb<S0koclo?3_mgMgL>o``<30go5ADE3OmLG5`;ooooo`ko
TI6A3_l=3@d>o`@410koCTi>3Onf][H>ol_;b`koM7Ad3Oo2`/8?ooooo`003Oooool>ob4Q8@ko51@D
6ol?3`l>oa0@40ko7alO3_lW9bL=omoOg`_ooooo3_n;Rh/=om[JfPkoT92@3_l71`L>o`d=3@koDE5A
3_nATI4=ocLg=`[ooooo3_l92@T>obl_;`koS8b<3_o?cll>ogMgM`ko30`<3OlE5AD=oeaLG0_ooooo
3_nATI4>o`d=3@ko10@43_m>CTh=okJf]Pkobl_;3_mdM7@=ol;2`Poooooo000=ooooo`ko8B4Q3_lD
51@Ko`l?3`ko410@3_lO7al>obLW9`gogmoO2oooool>oh^;R`gof][J3_n@T90>o`L71`ko3@d=3_mA
DE4>oi6AT@go=cLg2_ooool>o`T92@ko;bl_3_n<S8`>olo?c`koMgMg3_l<30`=oaDE5@goG5aL2ooo
ool>oi6AT@ko3@d=3_l410@>odi>CPgo][Jf3_o;bl/>ogAdM0go`/;23oooool000gooooo3_lQ8B4>
oa@D51_o3`l?3_l@410>oalO7`ko9bLW3OoOgml;ooooo`koRh^;3OoJf]X>oi2@T0ko1`L73_l=3@d>
oe5AD@koTI6A3Olg=cL:ooooo`ko2@T93_l_;bl>ohb<S0koclo?3_mgMgL>o``<30go5ADE3OmLG5`;
ooooo`koTI6A3_l=3@d>o`@410koCTi>3Onf][H>ol_;b`koM7Ad3Oo2`/8?ooooo`003Oooool>ob4Q
8@ko51@D6ol?3`l>oa0@40ko7alO3_lW9bL=omoOg`_ooooo3_n;Rh/=om[JfPkoT92@3_l71`L>o`d=
3@koDE5A3_nATI4=ocLg=`[ooooo3_l92@T>obl_;`koS8b<3_o?cll>ogMgM`ko30`<3OlE5AD=oeaL
G0_ooooo3_nATI4>o`d=3@ko10@43_m>CTh=okJf]Pkobl_;3_mdM7@=ol;2`Poooooo000=ooooo`ko
8B4Q3_lD51@Ko`l?3`ko410@3_lO7al>obLW9`gogmoO2oooool>oh^;R`gof][J3_n@T90>o`L71`ko
3@d=3_mADE4>oi6AT@go=cLg2_ooool>o`T92@ko;bl_3_n<S8`>olo?c`koMgMg3_l<30`=oaDE5@go
G5aL2oooool>oi6AT@ko3@d=3_l410@>odi>CPgo][Jf3_o;bl/>ogAdM0go`/;23oooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.984105, \
-0.202776, 0.0728937, 0.0728937}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-9.78601, -0.202776, 0.0728937, 0.0728937}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-18.5834, -0.202776, 0.0728937, 0.0728937}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-27.3853, -0.202776, 0.0728937, 0.0728937}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
191A1F1F1D201A72
180B13001109145E
2323231B1828187F
210C190C110F1B6B
2628211E1B231885
1B0A130B10132066
212126251B252185
E2C8E0CAD8CDD9FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CB0795862DB10078
EB35AB8D43BB127C
EF389EA742D92862
FF5EB6B258DA3061
EB5493C72EE93D6B
DA6097CA38CE3E70
BD5665CD0CD04184
B52D91733C911D91
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F36231F2F2B368D
06200D1C231E2C6E
081F0E1923172D74
001A031317162466
0F1D151924192C6F
13221318221A216D
2B2D261E36202F81
5F7369677C6F83FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
056D1F3C521566E0
0861293B531862EE
02672D3457115AFF
00532C2A560E56FB
00593123610B52FE
054B31185F0E4FED
02493A13660D4ADB
175524394A1E5196
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>oaTI6@ko6QXJ6olO
7al>oadM7@ko820P3_lJ6QX=og9bLP_ooooo3_o;bl/=o`L71`koUIFE3_n6QXH>obd];@ko/K6a3_l0
000=ogQhN0[ooooo3_lO7al>ocHf=Pko8b<S3_lO7al>obl_;`ko:b/[3Olf=SH=ohf=S@_ooooo3_l5
1@D>ofe]K@ko7alO3_ll?3`=oe9BDPko5ADE3_mVIVH=on3Ph0oooooo000=ooooo`ko6ATI3_lJ6QXK
oalO7`ko7AdM3_lP820>oaXJ6PgoLW9b2oooool>ol_;b`go1`L73_nEUID>ohJ6QPko;Bd]3_na/K4>
o`0000goN7Qh2_ooool>oalO7`ko=SHf3_lS8b<>oalO7`ko;bl_3_l[:b/=ocHf=PgoSHf=2oooool>
o`D51@koKFe]3_lO7al>oc`l?0goDU9B3_lE5AD>ofIVIPgoh>3P3oooool000gooooo3_lI6AT>oaXJ
6Q_o7alO3_lM7Ad>ob0P80ko6QXJ3OmbLW8;ooooo`kobl_;3Ol71`L>oiFEU@koQXJ63_l];Bd>ok6a
/@ko00003OmhN7P:ooooo`ko7alO3_lf=SH>ob<S8`ko7alO3_l_;bl>ob/[:`go=SHf3On=SHd;oooo
o`ko1@D53_m]KFd>oalO7`ko?3`l3OmBDU8>oaDE5@koIVIV3OoPh>0?ooooo`003Oooool>oaTI6@ko
6QXJ6olO7al>oadM7@ko820P3_lJ6QX=og9bLP_ooooo3_o;bl/=o`L71`koUIFE3_n6QXH>obd];@ko
/K6a3_l0000=ogQhN0[ooooo3_lO7al>ocHf=Pko8b<S3_lO7al>obl_;`ko:b/[3Olf=SH=ohf=S@_o
oooo3_l51@D>ofe]K@ko7alO3_ll?3`=oe9BDPko5ADE3_mVIVH=on3Ph0oooooo000=ooooo`ko6ATI
3_lJ6QXKoalO7`ko7AdM3_lP820>oaXJ6PgoLW9b2oooool>ol_;b`go1`L73_nEUID>ohJ6QPko;Bd]
3_na/K4>o`0000goN7Qh2_ooool>oalO7`ko=SHf3_lS8b<>oalO7`ko;bl_3_l[:b/=ocHf=PgoSHf=
2oooool>o`D51@koKFe]3_lO7al>oc`l?0goDU9B3_lE5AD>ofIVIPgoh>3P3oooool000gooooo3_lI
6AT>oaXJ6Q_o7alO3_lM7Ad>ob0P80ko6QXJ3OmbLW8;ooooo`kobl_;3Ol71`L>oiFEU@koQXJ63_l]
;Bd>ok6a/@ko00003OmhN7P:ooooo`ko7alO3_lf=SH>ob<S8`ko7alO3_l_;bl>ob/[:`go=SHf3On=
SHd;ooooo`ko1@D53_m]KFd>oalO7`ko?3`l3OmBDU8>oaDE5@koIVIV3OoPh>0?ooooo`003Oooool>
oaTI6@ko6QXJ6olO7al>oadM7@ko820P3_lJ6QX=og9bLP_ooooo3_o;bl/=o`L71`koUIFE3_n6QXH>
obd];@ko/K6a3_l0000=ogQhN0[ooooo3_lO7al>ocHf=Pko8b<S3_lO7al>obl_;`ko:b/[3Olf=SH=
ohf=S@_ooooo3_l51@D>ofe]K@ko7alO3_ll?3`=oe9BDPko5ADE3_mVIVH=on3Ph0oooooo000=oooo
o`ko6ATI3_lJ6QXKoalO7`ko7AdM3_lP820>oaXJ6PgoLW9b2oooool>ol_;b`go1`L73_nEUID>ohJ6
QPko;Bd]3_na/K4>o`0000goN7Qh2_ooool>oalO7`ko=SHf3_lS8b<>oalO7`ko;bl_3_l[:b/=ocHf
=PgoSHf=2oooool>o`D51@koKFe]3_lO7al>oc`l?0goDU9B3_lE5AD>ofIVIPgoh>3P3oooool000go
oooo3_lI6AT>oaXJ6Q_o7alO3_lM7Ad>ob0P80ko6QXJ3OmbLW8;ooooo`kobl_;3Ol71`L>oiFEU@ko
QXJ63_l];Bd>ok6a/@ko00003OmhN7P:ooooo`ko7alO3_lf=SH>ob<S8`ko7alO3_l_;bl>ob/[:`go
=SHf3On=SHd;ooooo`ko1@D53_m]KFd>oalO7`ko?3`l3OmBDU8>oaDE5@koIVIV3OoPh>0?ooooo`00
3Oooool>oaTI6@ko6QXJ6olO7al>oadM7@ko820P3_lJ6QX=og9bLP_ooooo3_o;bl/=o`L71`koUIFE
3_n6QXH>obd];@ko/K6a3_l0000=ogQhN0[ooooo3_lO7al>ocHf=Pko8b<S3_lO7al>obl_;`ko:b/[
3Olf=SH=ohf=S@_ooooo3_l51@D>ofe]K@ko7alO3_ll?3`=oe9BDPko5ADE3_mVIVH=on3Ph0oooooo
000=ooooo`ko6ATI3_lJ6QXKoalO7`ko7AdM3_lP820>oaXJ6PgoLW9b2oooool>ol_;b`go1`L73_nE
UID>ohJ6QPko;Bd]3_na/K4>o`0000goN7Qh2_ooool>oalO7`ko=SHf3_lS8b<>oalO7`ko;bl_3_l[
:b/=ocHf=PgoSHf=2oooool>o`D51@koKFe]3_lO7al>oc`l?0goDU9B3_lE5AD>ofIVIPgoh>3P3ooo
ool000gooooo3_lI6AT>oaXJ6Q_o7alO3_lM7Ad>ob0P80ko6QXJ3OmbLW8;ooooo`kobl_;3Ol71`L>
oiFEU@koQXJ63_l];Bd>ok6a/@ko00003OmhN7P:ooooo`ko7alO3_lf=SH>ob<S8`ko7alO3_l_;bl>
ob/[:`go=SHf3On=SHd;ooooo`ko1@D53_m]KFd>oalO7`ko?3`l3OmBDU8>oaDE5@koIVIV3OoPh>0?
ooooo`003Oooool>oaTI6@ko6QXJ6olO7al>oadM7@ko820P3_lJ6QX=og9bLP_ooooo3_o;bl/=o`L7
1`koUIFE3_n6QXH>obd];@ko/K6a3_l0000=ogQhN0[ooooo3_lO7al>ocHf=Pko8b<S3_lO7al>obl_
;`ko:b/[3Olf=SH=ohf=S@_ooooo3_l51@D>ofe]K@ko7alO3_ll?3`=oe9BDPko5ADE3_mVIVH=on3P
h0oooooo000=ooooo`ko6ATI3_lJ6QXKoalO7`ko7AdM3_lP820>oaXJ6PgoLW9b2oooool>ol_;b`go
1`L73_nEUID>ohJ6QPko;Bd]3_na/K4>o`0000goN7Qh2_ooool>oalO7`ko=SHf3_lS8b<>oalO7`ko
;bl_3_l[:b/=ocHf=PgoSHf=2oooool>o`D51@koKFe]3_lO7al>oc`l?0goDU9B3_lE5AD>ofIVIPgo
h>3P3oooool000gooooo3_lH61P>o`/;2`ko4a<C3Ol0000>oa4A4@ko2@T93_lD51@=oeiNGP_ooooo
3_o[jn/=ocDe=@koZj^[3_n=SHd>od=3@`ko^k^k3_lB4Q8=ogalO0[ooooo3_l61PH>ob0P80ko3@d=
3_lL71`>ob<S8`ko7QhN3Ol/;2`=ofi^KP_ooooo3_l820P>of5QH@ko:BTY3_lk>c/=oe=CD`ko61PH
3_mRHV8=onk^kPoooooo000=ooooo`ko61PH3_l;2`/>oa<C4`go00003_lA4A4>o`T92@ko51@D3OmN
GUh;ooooo`kojn_[3Ole=CD>oj^[Z`koSHf=3_m3@d<>ok^k^`ko4Q8B3OmlO7`:ooooo`ko1PH63_lP
820>o`d=3@ko71`L3_lS8b<>oahN7Pgo;2`/3Om^KVh;ooooo`ko20P83_mQHF4>obTY:@ko>c/k3OmC
De<>oaPH60koHV9R3Oo^k^h?ooooo`003Oooool>oaPH60ko2`/;3_lC4a<=o`0000ko4A4A3_l92@T>
oa@D50goGUiN2oooool>on_[j`go=CDe3_n[Zj/>ohf=S@ko@d=33_nk^k/>oa8B4PgoO7al2_ooool>
o`H61Pko820P3_l=3@d>oa`L70ko8b<S3_lN7Qh=ob`/;0goKVi^2oooool>o`P820koHF5Q3_lY:BT>
oc/k>`goDe=C3_lH61P>of9RHPgok^k^3oooool000gooooo3_lH61P>o`/;2`ko4a<C3Ol0000>oa4A
4@ko2@T93_lD51@=oeiNGP_ooooo3_o[jn/=ocDe=@koZj^[3_n=SHd>od=3@`ko^k^k3_lB4Q8=ogal
O0[ooooo3_l61PH>ob0P80ko3@d=3_lL71`>ob<S8`ko7QhN3Ol/;2`=ofi^KP_ooooo3_l820P>of5Q
H@ko:BTY3_lk>c/=oe=CD`ko61PH3_mRHV8=onk^kPoooooo000=ooooo`ko61PH3_l;2`/>oa<C4`go
00003_lA4A4>o`T92@ko51@D3OmNGUh;ooooo`kojn_[3Ole=CD>oj^[Z`koSHf=3_m3@d<>ok^k^`ko
4Q8B3OmlO7`:ooooo`ko1PH63_lP820>o`d=3@ko71`L3_lS8b<>oahN7Pgo;2`/3Om^KVh;ooooo`ko
20P83_mQHF4>obTY:@ko>c/k3OmCDe<>oaPH60koHV9R3Oo^k^h?ooooo`003Oooool>oaPH60ko2`/;
3_lC4a<=o`0000ko4A4A3_l92@T>oa@D50goGUiN2oooool>on_[j`go=CDe3_n[Zj/>ohf=S@ko@d=3
3_nk^k/>oa8B4PgoO7al2_ooool>o`H61Pko820P3_l=3@d>oa`L70ko8b<S3_lN7Qh=ob`/;0goKVi^
2oooool>o`P820koHF5Q3_lY:BT>oc/k>`goDe=C3_lH61P>of9RHPgok^k^3oooool000gooooo3_lH
61P>o`/;2`ko4a<C3Ol0000>oa4A4@ko2@T93_lD51@=oeiNGP_ooooo3_o[jn/=ocDe=@koZj^[3_n=
SHd>od=3@`ko^k^k3_lB4Q8=ogalO0[ooooo3_l61PH>ob0P80ko3@d=3_lL71`>ob<S8`ko7QhN3Ol/
;2`=ofi^KP_ooooo3_l820P>of5QH@ko:BTY3_lk>c/=oe=CD`ko61PH3_mRHV8=onk^kPoooooo000=
ooooo`ko61PH3_l;2`/>oa<C4`go00003_lA4A4>o`T92@ko51@D3OmNGUh;ooooo`kojn_[3Ole=CD>
oj^[Z`koSHf=3_m3@d<>ok^k^`ko4Q8B3OmlO7`:ooooo`ko1PH63_lP820>o`d=3@ko71`L3_lS8b<>
oahN7Pgo;2`/3Om^KVh;ooooo`ko20P83_mQHF4>obTY:@ko>c/k3OmCDe<>oaPH60koHV9R3Oo^k^h?
ooooo`003Oooool>oaPH60ko2`/;3_lC4a<=o`0000ko4A4A3_l92@T>oa@D50goGUiN2oooool>on_[
j`go=CDe3_n[Zj/>ohf=S@ko@d=33_nk^k/>oa8B4PgoO7al2_ooool>o`H61Pko820P3_l=3@d>oa`L
70ko8b<S3_lN7Qh=ob`/;0goKVi^2oooool>o`P820koHF5Q3_lY:BT>oc/k>`goDe=C3_lH61P>of9R
HPgok^k^3oooool000gooooo3_lH61P>o`/;2`ko4a<C3Ol0000>oa4A4@ko2@T93_lD51@=oeiNGP_o
oooo3_o[jn/=ocDe=@koZj^[3_n=SHd>od=3@`ko^k^k3_lB4Q8=ogalO0[ooooo3_l61PH>ob0P80ko
3@d=3_lL71`>ob<S8`ko7QhN3Ol/;2`=ofi^KP_ooooo3_l820P>of5QH@ko:BTY3_lk>c/=oe=CD`ko
61PH3_mRHV8=onk^kPoooooo000=ooooo`ko61PH3_l;2`/>oa<C4`go00003_lA4A4>o`T92@ko51@D
3OmNGUh;ooooo`kojn_[3Ole=CD>oj^[Z`koSHf=3_m3@d<>ok^k^`ko4Q8B3OmlO7`:ooooo`ko1PH6
3_lP820>o`d=3@ko71`L3_lS8b<>oahN7Pgo;2`/3Om^KVh;ooooo`ko20P83_mQHF4>obTY:@ko>c/k
3OmCDe<>oaPH60koHV9R3Oo^k^h?ooooo`003Oooool>oaPH60ko2`/;3_lC4a<=o`0000ko4A4A3_l9
2@T>oa@D50goGUiN2oooool>on_[j`go=CDe3_n[Zj/>ohf=S@ko@d=33_nk^k/>oa8B4PgoO7al2_oo
ool>o`H61Pko820P3_l=3@d>oa`L70ko8b<S3_lN7Qh=ob`/;0goKVi^2oooool>o`P820koHF5Q3_lY
:BT>oc/k>`goDe=C3_lH61P>of9RHPgok^k^3oooool000gooooo3_lH61P>o`/;2`ko4a<C3Ol0000>
oa4A4@ko2@T93_lD51@=oeiNGP_ooooo3_o[jn/=ocDe=@koZj^[3_n=SHd>od=3@`ko^k^k3_lB4Q8=
ogalO0[ooooo3_l61PH>ob0P80ko3@d=3_lL71`>ob<S8`ko7QhN3Ol/;2`=ofi^KP_ooooo3_l820P>
of5QH@ko:BTY3_lk>c/=oe=CD`ko61PH3_mRHV8=onk^kPoooooo000=ooooob[o8b<S3OlK6a/>oaPH
60ko:2PX3_lH61P=ogmoO`_ooooo3_o_knl=ocPh>0koWYjN3_nWYjL>od92@PkofMWI3_lX:2P=of9R
HP[ooooo3_l820P>oalO7`ko3Ph>3_lI6AT>ob<S8`ko5aLG3Ol];Bd=ogAdM0_ooooo3_l20P8>ofMW
I`ko;Bd]3_ld=3@=oeMGE`ko4A4A3_mJFUXLooooo`003OoooolZob<S8`go6a/K3_lH61P>obPX:0ko
61PH3OmoOgl;ooooo`kokno_3Olh>3P>oijNWPkoYjNW3_m2@T8>omWIf@ko:2PX3OmRHV8:ooooo`ko
20P83_lO7al>o`h>3Pko6ATI3_lS8b<>oaLG5`go;Bd]3OmdM7@;ooooo`ko0P823_mWIfL>obd];@ko
=3@d3OmGEeL>oa4A4@koFUYJ7?ooool000gooooo:_lS8b<=oa/K6`ko61PH3_lX:2P>oaPH60goOgmo
2oooool>ono_k`go>3Ph3_nNWYh>ojNWY`ko@T923_oIfMT>obPX:0goHV9R2_ooool>o`P820ko7alO
3_l>3Ph>oaTI6@ko8b<S3_lG5aL=obd];@goM7Ad2oooool>o`820PkoIfMW3_l];Bd>oc@d=0goEeMG
3_lA4A4>oeYJFQcooooo000=ooooob[o8b<S3OlK6a/>oaPH60ko:2PX3_lH61P=ogmoO`_ooooo3_o_
knl=ocPh>0koWYjN3_nWYjL>od92@PkofMWI3_lX:2P=of9RHP[ooooo3_l820P>oalO7`ko3Ph>3_lI
6AT>ob<S8`ko5aLG3Ol];Bd=ogAdM0_ooooo3_l20P8>ofMWI`ko;Bd]3_ld=3@=oeMGE`ko4A4A3_mJ
FUXLooooo`003OoooolZob<S8`go6a/K3_lH61P>obPX:0ko61PH3OmoOgl;ooooo`kokno_3Olh>3P>
oijNWPkoYjNW3_m2@T8>omWIf@ko:2PX3OmRHV8:ooooo`ko20P83_lO7al>o`h>3Pko6ATI3_lS8b<>
oaLG5`go;Bd]3OmdM7@;ooooo`ko0P823_mWIfL>obd];@ko=3@d3OmGEeL>oa4A4@koFUYJ7?ooool0
00gooooo:_lS8b<=oa/K6`ko61PH3_lX:2P>oaPH60goOgmo2oooool>ono_k`go>3Ph3_nNWYh>ojNW
Y`ko@T923_oIfMT>obPX:0goHV9R2_ooool>o`P820ko7alO3_l>3Ph>oaTI6@ko8b<S3_lG5aL=obd]
;@goM7Ad2oooool>o`820PkoIfMW3_l];Bd>oc@d=0goEeMG3_lA4A4>oeYJFQcooooo000=ooooob[o
8b<S3OlK6a/>oaPH60ko:2PX3_lH61P=ogmoO`_ooooo3_o_knl=ocPh>0koWYjN3_nWYjL>od92@Pko
fMWI3_lX:2P=of9RHP[ooooo3_l820P>oalO7`ko3Ph>3_lI6AT>ob<S8`ko5aLG3Ol];Bd=ogAdM0_o
oooo3_l20P8>ofMWI`ko;Bd]3_ld=3@=oeMGE`ko4A4A3_mJFUXLooooo`003OoooolZob<S8`go6a/K
3_lH61P>obPX:0ko61PH3OmoOgl;ooooo`kokno_3Olh>3P>oijNWPkoYjNW3_m2@T8>omWIf@ko:2PX
3OmRHV8:ooooo`ko20P83_lO7al>o`h>3Pko6ATI3_lS8b<>oaLG5`go;Bd]3OmdM7@;ooooo`ko0P82
3_mWIfL>obd];@ko=3@d3OmGEeL>oa4A4@koFUYJ7?ooool000gooooo:_lS8b<=oa/K6`ko61PH3_lX
:2P>oaPH60goOgmo2oooool>ono_k`go>3Ph3_nNWYh>ojNWY`ko@T923_oIfMT>obPX:0goHV9R2_oo
ool>o`P820ko7alO3_l>3Ph>oaTI6@ko8b<S3_lG5aL=obd];@goM7Ad2oooool>o`820PkoIfMW3_l]
;Bd>oc@d=0goEeMG3_lA4A4>oeYJFQcooooo000=ooooob[o8b<S3OlK6a/>oaPH60ko:2PX3_lH61P=
ogmoO`_ooooo3_o_knl=ocPh>0koWYjN3_nWYjL>od92@PkofMWI3_lX:2P=of9RHP[ooooo3_l820P>
oalO7`ko3Ph>3_lI6AT>ob<S8`ko5aLG3Ol];Bd=ogAdM0_ooooo3_l20P8>ofMWI`ko;Bd]3_ld=3@=
oeMGE`ko4A4A3_mJFUXLooooo`003OoooolZob<S8`go6a/K3_lH61P>obPX:0ko61PH3OmoOgl;oooo
o`kokno_3Olh>3P>oijNWPkoYjNW3_m2@T8>omWIf@ko:2PX3OmRHV8:ooooo`ko20P83_lO7al>o`h>
3Pko6ATI3_lS8b<>oaLG5`go;Bd]3OmdM7@;ooooo`ko0P823_mWIfL>obd];@ko=3@d3OmGEeL>oa4A
4@koFUYJ7?ooool000gooooo:_lS8b<=oa/K6`ko61PH3_lX:2P>oaPH60goOgmo2oooool>ono_k`go
>3Ph3_nNWYh>ojNWY`ko@T923_oIfMT>obPX:0goHV9R2_ooool>o`P820ko7alO3_l>3Ph>oaTI6@ko
8b<S3_lG5aL=obd];@goM7Ad2oooool>o`820PkoIfMW3_l];Bd>oc@d=0goEeMG3_lA4A4>oeYJFQco
oooo000=ooooob[o8b<S3OlK6a/>oaPH60ko:2PX3_lH61P=ogmoO`_ooooo3_o_knl=ocPh>0koWYjN
3_nWYjL>od92@PkofMWI3_lX:2P=of9RHP[ooooo3_l820P>oalO7`ko3Ph>3_lI6AT>ob<S8`ko5aLG
3Ol];Bd=ogAdM0_ooooo3_l20P8>ofMWI`ko;Bd]3_ld=3@=oeMGE`ko4A4A3_mJFUXLooooo`003Ooo
oolZob<S8`go6a/K3_lH61P>obPX:0ko61PH3OmoOgl;ooooo`kokno_3Olh>3P>oijNWPkoYjNW3_m2
@T8>omWIf@ko:2PX3OmRHV8:ooooo`ko20P83_lO7al>o`h>3Pko6ATI3_lS8b<>oaLG5`go;Bd]3Omd
M7@;ooooo`ko0P823_mWIfL>obd];@ko=3@d3OmGEeL>oa4A4@koFUYJ7?ooool000gooooo3_lQ8B4>
o``<30ko6ATI3Ol<30`>oa4A4@ko3`l?3_lK6a/=of][JaWooooo3OmNGUh>okJf]Pko/[:b3_mHF5P>
om[JfPko<30`3OmQHF4:ooooo`ko00003_lJ6QX>o`<30`ko4a<C3_lG5aL>oaHF5Pgo92@T3OmVIVH;
ooooo`ko00003_mCDe<>ob`/;0ko:RXZ3OmFEUH>o`h>3PkoEUIF3Ookno/?ooooo`003Oooool>ob4Q
8@ko30`<3_lI6AT=o``<30ko4A4A3_l?3`l>oa/K6`goJf][6Oooool=oeiNGPko][Jf3_nb/[8>oeQH
F0kof][J3_l`<30=of5QH@[ooooo3_l0000>oaXJ6Pko0`<33_lC4a<>oaLG5`ko5QHF3OlT92@=ofIV
IP_ooooo3_l0000>oe=CD`ko;2`/3_lZ:RX=oeIFEPko3Ph>3_mFEUH=oo_kn`oooooo000=ooooo`ko
8B4Q3_l<30`>oaTI6@go30`<3_lA4A4>o`l?3`ko6a/K3Om[Jf/Iooooo`goGUiN3_nf][H>ok:b/Pko
F5QH3_oJf]X>oc0`<0goHF5Q2_ooool>o`0000ko6QXJ3_l30`<>oa<C4`ko5aLG3_lF5QH=ob@T90go
IVIV2oooool>o`0000koDe=C3_l/;2`>obXZ:PgoEUIF3_l>3Ph>oeIFEPgono_k3oooool000gooooo
3_lQ8B4>o``<30ko6ATI3Ol<30`>oa4A4@ko3`l?3_lK6a/=of][JaWooooo3OmNGUh>okJf]Pko/[:b
3_mHF5P>om[JfPko<30`3OmQHF4:ooooo`ko00003_lJ6QX>o`<30`ko4a<C3_lG5aL>oaHF5Pgo92@T
3OmVIVH;ooooo`ko00003_mCDe<>ob`/;0ko:RXZ3OmFEUH>o`h>3PkoEUIF3Ookno/?ooooo`003Ooo
ool>ob4Q8@ko30`<3_lI6AT=o``<30ko4A4A3_l?3`l>oa/K6`goJf][6Oooool=oeiNGPko][Jf3_nb
/[8>oeQHF0kof][J3_l`<30=of5QH@[ooooo3_l0000>oaXJ6Pko0`<33_lC4a<>oaLG5`ko5QHF3OlT
92@=ofIVIP_ooooo3_l0000>oe=CD`ko;2`/3_lZ:RX=oeIFEPko3Ph>3_mFEUH=oo_kn`oooooo000=
ooooo`ko8B4Q3_l<30`>oaTI6@go30`<3_lA4A4>o`l?3`ko6a/K3Om[Jf/Iooooo`goGUiN3_nf][H>
ok:b/PkoF5QH3_oJf]X>oc0`<0goHF5Q2_ooool>o`0000ko6QXJ3_l30`<>oa<C4`ko5aLG3_lF5QH=
ob@T90goIVIV2oooool>o`0000koDe=C3_l/;2`>obXZ:PgoEUIF3_l>3Ph>oeIFEPgono_k3oooool0
00gooooo3_lQ8B4>o``<30ko6ATI3Ol<30`>oa4A4@ko3`l?3_lK6a/=of][JaWooooo3OmNGUh>okJf
]Pko/[:b3_mHF5P>om[JfPko<30`3OmQHF4:ooooo`ko00003_lJ6QX>o`<30`ko4a<C3_lG5aL>oaHF
5Pgo92@T3OmVIVH;ooooo`ko00003_mCDe<>ob`/;0ko:RXZ3OmFEUH>o`h>3PkoEUIF3Ookno/?oooo
o`003Oooool>ob4Q8@ko30`<3_lI6AT=o``<30ko4A4A3_l?3`l>oa/K6`goJf][6Oooool=oeiNGPko
][Jf3_nb/[8>oeQHF0kof][J3_l`<30=of5QH@[ooooo3_l0000>oaXJ6Pko0`<33_lC4a<>oaLG5`ko
5QHF3OlT92@=ofIVIP_ooooo3_l0000>oe=CD`ko;2`/3_lZ:RX=oeIFEPko3Ph>3_mFEUH=oo_kn`oo
oooo000=ooooo`ko8B4Q3_l<30`>oaTI6@go30`<3_lA4A4>o`l?3`ko6a/K3Om[Jf/Iooooo`goGUiN
3_nf][H>ok:b/PkoF5QH3_oJf]X>oc0`<0goHF5Q2_ooool>o`0000ko6QXJ3_l30`<>oa<C4`ko5aLG
3_lF5QH=ob@T90goIVIV2oooool>o`0000koDe=C3_l/;2`>obXZ:PgoEUIF3_l>3Ph>oeIFEPgono_k
3oooool000gooooo3_lQ8B4>o``<30ko6ATI3Ol<30`>oa4A4@ko3`l?3_lK6a/=of][JaWooooo3OmN
GUh>okJf]Pko/[:b3_mHF5P>om[JfPko<30`3OmQHF4:ooooo`ko00003_lJ6QX>o`<30`ko4a<C3_lG
5aL>oaHF5Pgo92@T3OmVIVH;ooooo`ko00003_mCDe<>ob`/;0ko:RXZ3OmFEUH>o`h>3PkoEUIF3Ook
no/?ooooo`003Oooool>ob4Q8@ko30`<3_lI6AT=o``<30ko4A4A3_l?3`l>oa/K6`goJf][6Oooool=
oeiNGPko][Jf3_nb/[8>oeQHF0kof][J3_l`<30=of5QH@[ooooo3_l0000>oaXJ6Pko0`<33_lC4a<>
oaLG5`ko5QHF3OlT92@=ofIVIP_ooooo3_l0000>oe=CD`ko;2`/3_lZ:RX=oeIFEPko3Ph>3_mFEUH=
oo_kn`oooooo000=ooooo`ko8B4Q3_l<30`>oaTI6@go30`<3_lA4A4>o`l?3`ko6a/K3Om[Jf/Ioooo
o`goGUiN3_nf][H>ok:b/PkoF5QH3_oJf]X>oc0`<0goHF5Q2_ooool>o`0000ko6QXJ3_l30`<>oa<C
4`ko5aLG3_lF5QH=ob@T90goIVIV2oooool>o`0000koDe=C3_l/;2`>obXZ:PgoEUIF3_l>3Ph>oeIF
EPgono_k3oooool000gooooo3_lQ8B4>o``<30ko6ATI3Ol<30`>oa4A4@ko3`l?3_lK6a/=of][JaWo
oooo3OmNGUh>okJf]Pko/[:b3_mHF5P>om[JfPko<30`3OmQHF4:ooooo`ko00003_lJ6QX>o`<30`ko
4a<C3_lG5aL>oaHF5Pgo92@T3OmVIVH;ooooo`ko00003_mCDe<>ob`/;0ko:RXZ3OmFEUH>o`h>3Pko
EUIF3Ookno/?ooooo`003Oooool>obHV9Pko:2PX3_lQ8B4=oahN7Pko6a/K3_lS8b<>oaPH60goQHF5
2oooool>on_[j`goE5AD3_nCTi<>olO7a`ko;Rh^3_oYjNT>ocdm?@goJf][2_ooool>o`l?3`ko7AdM
3_lE5AD>oaTI6@ko92@T3_lI6AT=ob`/;0goKfm_2oooool>o`0000koFEUI3_la<C4>ob<S8`goHF5Q
3_l;2`/>oe9BDPgoo_kn3oooool000gooooo3_lV9RH>obPX:0ko8B4Q3OlN7Qh>oa/K6`ko8b<S3_lH
61P=ohF5Q@_ooooo3_o[jn/=oeADE0koTi>C3_o7alL>obh^;PkojNWY3_lm?Cd=of][J`[ooooo3_l?
3`l>oadM7@ko5ADE3_lI6AT>ob@T90ko6ATI3Ol/;2`=ofm_K`_ooooo3_l0000>oeUIF@ko<C4a3_lS
8b<=of5QH@ko2`/;3_mBDU8=ooknoPoooooo000=ooooo`ko9RHV3_lX:2P>ob4Q8@go7QhN3_lK6a/>
ob<S8`ko61PH3On5QHD;ooooo`kojn_[3OmDE5@>oi>CT`koalO73_l^;Rh>onWYj@ko?Cdm3Om[Jf/:
ooooo`ko3`l?3_lM7Ad>oaDE5@ko6ATI3_lT92@>oaTI6@go;2`/3Om_Kfl;ooooo`ko00003_mIFET>
oc4a<@ko8b<S3OmQHF4>o`/;2`koDU9B3Oono_h?ooooo`003Oooool>obHV9Pko:2PX3_lQ8B4=oahN
7Pko6a/K3_lS8b<>oaPH60goQHF52oooool>on_[j`goE5AD3_nCTi<>olO7a`ko;Rh^3_oYjNT>ocdm
?@goJf][2_ooool>o`l?3`ko7AdM3_lE5AD>oaTI6@ko92@T3_lI6AT=ob`/;0goKfm_2oooool>o`00
00koFEUI3_la<C4>ob<S8`goHF5Q3_l;2`/>oe9BDPgoo_kn3oooool000gooooo3_lV9RH>obPX:0ko
8B4Q3OlN7Qh>oa/K6`ko8b<S3_lH61P=ohF5Q@_ooooo3_o[jn/=oeADE0koTi>C3_o7alL>obh^;Pko
jNWY3_lm?Cd=of][J`[ooooo3_l?3`l>oadM7@ko5ADE3_lI6AT>ob@T90ko6ATI3Ol/;2`=ofm_K`_o
oooo3_l0000>oeUIF@ko<C4a3_lS8b<=of5QH@ko2`/;3_mBDU8=ooknoPoooooo000=ooooo`ko9RHV
3_lX:2P>ob4Q8@go7QhN3_lK6a/>ob<S8`ko61PH3On5QHD;ooooo`kojn_[3OmDE5@>oi>CT`koalO7
3_l^;Rh>onWYj@ko?Cdm3Om[Jf/:ooooo`ko3`l?3_lM7Ad>oaDE5@ko6ATI3_lT92@>oaTI6@go;2`/
3Om_Kfl;ooooo`ko00003_mIFET>oc4a<@ko8b<S3OmQHF4>o`/;2`koDU9B3Oono_h?ooooo`003Ooo
ool>obHV9Pko:2PX3_lQ8B4=oahN7Pko6a/K3_lS8b<>oaPH60goQHF52oooool>on_[j`goE5AD3_nC
Ti<>olO7a`ko;Rh^3_oYjNT>ocdm?@goJf][2_ooool>o`l?3`ko7AdM3_lE5AD>oaTI6@ko92@T3_lI
6AT=ob`/;0goKfm_2oooool>o`0000koFEUI3_la<C4>ob<S8`goHF5Q3_l;2`/>oe9BDPgoo_kn3ooo
ool000gooooo3_lV9RH>obPX:0ko8B4Q3OlN7Qh>oa/K6`ko8b<S3_lH61P=ohF5Q@_ooooo3_o[jn/=
oeADE0koTi>C3_o7alL>obh^;PkojNWY3_lm?Cd=of][J`[ooooo3_l?3`l>oadM7@ko5ADE3_lI6AT>
ob@T90ko6ATI3Ol/;2`=ofm_K`_ooooo3_l0000>oeUIF@ko<C4a3_lS8b<=of5QH@ko2`/;3_mBDU8=
ooknoPoooooo000=ooooo`ko9RHV3_lX:2P>ob4Q8@go7QhN3_lK6a/>ob<S8`ko61PH3On5QHD;oooo
o`kojn_[3OmDE5@>oi>CT`koalO73_l^;Rh>onWYj@ko?Cdm3Om[Jf/:ooooo`ko3`l?3_lM7Ad>oaDE
5@ko6ATI3_lT92@>oaTI6@go;2`/3Om_Kfl;ooooo`ko00003_mIFET>oc4a<@ko8b<S3OmQHF4>o`/;
2`koDU9B3Oono_h?ooooo`003Oooool>obHV9Pko:2PX3_lQ8B4=oahN7Pko6a/K3_lS8b<>oaPH60go
QHF52oooool>on_[j`goE5AD3_nCTi<>olO7a`ko;Rh^3_oYjNT>ocdm?@goJf][2_ooool>o`l?3`ko
7AdM3_lE5AD>oaTI6@ko92@T3_lI6AT=ob`/;0goKfm_2oooool>o`0000koFEUI3_la<C4>ob<S8`go
HF5Q3_l;2`/>oe9BDPgoo_kn3oooool000gooooo3_lV9RH>obPX:0ko8B4Q3OlN7Qh>oa/K6`ko8b<S
3_lH61P=ohF5Q@_ooooo3_o[jn/=oeADE0koTi>C3_o7alL>obh^;PkojNWY3_lm?Cd=of][J`[ooooo
3_l?3`l>oadM7@ko5ADE3_lI6AT>ob@T90ko6ATI3Ol/;2`=ofm_K`_ooooo3_l0000>oeUIF@ko<C4a
3_lS8b<=of5QH@ko2`/;3_mBDU8=ooknoPoooooo000=ooooo`ko9RHV3_lX:2P>ob4Q8@go7QhN3_lK
6a/>ob<S8`ko61PH3On5QHD;ooooo`kojn_[3OmDE5@>oi>CT`koalO73_l^;Rh>onWYj@ko?Cdm3Om[
Jf/:ooooo`ko3`l?3_lM7Ad>oaDE5@ko6ATI3_lT92@>oaTI6@go;2`/3Om_Kfl;ooooo`ko00003_mI
FET>oc4a<@ko8b<S3OmQHF4>o`/;2`koDU9B3Oono_h?ooooo`003Oooool>obHV9Pko:2PX3_lQ8B4=
oahN7Pko6a/K3_lS8b<>oaPH60goQHF52oooool>on_[j`goE5AD3_nCTi<>olO7a`ko;Rh^3_oYjNT>
ocdm?@goJf][2_ooool>o`l?3`ko7AdM3_lE5AD>oaTI6@ko92@T3_lI6AT=ob`/;0goKfm_2oooool>
o`0000koFEUI3_la<C4>ob<S8`goHF5Q3_l;2`/>oe9BDPgoo_kn3oooool000gooooo3_lV9RH>obPX
:0ko8B4Q3OlN7Qh>oa/K6`ko8b<S3_lH61P=ohF5Q@_ooooo3_o[jn/=oeADE0koTi>C3_o7alL>obh^
;PkojNWY3_lm?Cd=of][J`[ooooo3_l?3`l>oadM7@ko5ADE3_lI6AT>ob@T90ko6ATI3Ol/;2`=ofm_
K`_ooooo3_l0000>oeUIF@ko<C4a3_lS8b<=of5QH@ko2`/;3_mBDU8=ooknoPoooooo000=ooooo`ko
6a/K3_l:2PX>oa<C4`go2`/;3_l@410>oa<C4`ko820P3OmVIVH;ooooo`kof][J3OmPH60>oiNGU`ko
b/[:3_lh>3P>olk>cPko?Shn3Om`L70:ooooo`ko4a<C3_lR8R8>oa<C4`ko61PH3_lR8R8>oaXJ6Pgo
8B4Q3Om]KFd;ooooo`ko1@D53_m;Bd/>oc4a<@ko61PH3OmOGel>o`h>3PkoCdm?3Oo]kNd?ooooo`00
3Oooool>oa/K6`ko2PX:3_lC4a<=o`/;2`ko410@3_lC4a<>ob0P80goIVIV2oooool>om[JfPgoH61P
3_nGUiL>ol[:bPko>3Ph3_o>c/h>ochn?PgoL71`2_ooool>oa<C4`ko8R8R3_lC4a<>oaPH60ko8R8R
3_lJ6QX=ob4Q8@goKFe]2oooool>o`D51@koBd];3_la<C4>oaPH60goGemO3_l>3Ph>odm?C`gokNg]
3oooool000gooooo3_lK6a/>o`X:2Pko4a<C3Ol;2`/>oa0@40ko4a<C3_lP820=ofIVIP_ooooo3_oJ
f]X=of1PH0koUiNG3_o:b/X>ocPh>0koc/k>3_ln?Sh=og1`L0[ooooo3_lC4a<>ob8R8Pko4a<C3_lH
61P>ob8R8Pko6QXJ3OlQ8B4=ofe]K@_ooooo3_l51@D>od];B`ko<C4a3_lH61P=oemOG`ko3Ph>3_m?
Cdl=ong]k@oooooo000=ooooo`ko6a/K3_l:2PX>oa<C4`go2`/;3_l@410>oa<C4`ko820P3OmVIVH;
ooooo`kof][J3OmPH60>oiNGU`kob/[:3_lh>3P>olk>cPko?Shn3Om`L70:ooooo`ko4a<C3_lR8R8>
oa<C4`ko61PH3_lR8R8>oaXJ6Pgo8B4Q3Om]KFd;ooooo`ko1@D53_m;Bd/>oc4a<@ko61PH3OmOGel>
o`h>3PkoCdm?3Oo]kNd?ooooo`003Oooool>oa/K6`ko2PX:3_lC4a<=o`/;2`ko410@3_lC4a<>ob0P
80goIVIV2oooool>om[JfPgoH61P3_nGUiL>ol[:bPko>3Ph3_o>c/h>ochn?PgoL71`2_ooool>oa<C
4`ko8R8R3_lC4a<>oaPH60ko8R8R3_lJ6QX=ob4Q8@goKFe]2oooool>o`D51@koBd];3_la<C4>oaPH
60goGemO3_l>3Ph>odm?C`gokNg]3oooool000gooooo3_lK6a/>o`X:2Pko4a<C3Ol;2`/>oa0@40ko
4a<C3_lP820=ofIVIP_ooooo3_oJf]X=of1PH0koUiNG3_o:b/X>ocPh>0koc/k>3_ln?Sh=og1`L0[o
oooo3_lC4a<>ob8R8Pko4a<C3_lH61P>ob8R8Pko6QXJ3OlQ8B4=ofe]K@_ooooo3_l51@D>od];B`ko
<C4a3_lH61P=oemOG`ko3Ph>3_m?Cdl=ong]k@oooooo000=ooooo`ko6a/K3_l:2PX>oa<C4`go2`/;
3_l@410>oa<C4`ko820P3OmVIVH;ooooo`kof][J3OmPH60>oiNGU`kob/[:3_lh>3P>olk>cPko?Shn
3Om`L70:ooooo`ko4a<C3_lR8R8>oa<C4`ko61PH3_lR8R8>oaXJ6Pgo8B4Q3Om]KFd;ooooo`ko1@D5
3_m;Bd/>oc4a<@ko61PH3OmOGel>o`h>3PkoCdm?3Oo]kNd?ooooo`003Oooool>oa/K6`ko2PX:3_lC
4a<=o`/;2`ko410@3_lC4a<>ob0P80goIVIV2oooool>om[JfPgoH61P3_nGUiL>ol[:bPko>3Ph3_o>
c/h>ochn?PgoL71`2_ooool>oa<C4`ko8R8R3_lC4a<>oaPH60ko8R8R3_lJ6QX=ob4Q8@goKFe]2ooo
ool>o`D51@koBd];3_la<C4>oaPH60goGemO3_l>3Ph>odm?C`gokNg]3oooool000gooooo3_lK6a/>
o`X:2Pko4a<C3Ol;2`/>oa0@40ko4a<C3_lP820=ofIVIP_ooooo3_oJf]X=of1PH0koUiNG3_o:b/X>
ocPh>0koc/k>3_ln?Sh=og1`L0[ooooo3_lC4a<>ob8R8Pko4a<C3_lH61P>ob8R8Pko6QXJ3OlQ8B4=
ofe]K@_ooooo3_l51@D>od];B`ko<C4a3_lH61P=oemOG`ko3Ph>3_m?Cdl=ong]k@oooooo000=oooo
o`ko6a/K3_l:2PX>oa<C4`go2`/;3_l@410>oa<C4`ko820P3OmVIVH;ooooo`kof][J3OmPH60>oiNG
U`kob/[:3_lh>3P>olk>cPko?Shn3Om`L70:ooooo`ko4a<C3_lR8R8>oa<C4`ko61PH3_lR8R8>oaXJ
6Pgo8B4Q3Om]KFd;ooooo`ko1@D53_m;Bd/>oc4a<@ko61PH3OmOGel>o`h>3PkoCdm?3Oo]kNd?oooo
o`003Oooool>oa/K6`ko2PX:3_lC4a<=o`/;2`ko410@3_lC4a<>ob0P80goIVIV2oooool>om[JfPgo
H61P3_nGUiL>ol[:bPko>3Ph3_o>c/h>ochn?PgoL71`2_ooool>oa<C4`ko8R8R3_lC4a<>oaPH60ko
8R8R3_lJ6QX=ob4Q8@goKFe]2oooool>o`D51@koBd];3_la<C4>oaPH60goGemO3_l>3Ph>odm?C`go
kNg]3oooool000gooooo3_lK6a/>o`X:2Pko4a<C3Ol;2`/>oa0@40ko4a<C3_lP820=ofIVIP_ooooo
3_oJf]X=of1PH0koUiNG3_o:b/X>ocPh>0koc/k>3_ln?Sh=og1`L0[ooooo3_lC4a<>ob8R8Pko4a<C
3_lH61P>ob8R8Pko6QXJ3OlQ8B4=ofe]K@_ooooo3_l51@D>od];B`ko<C4a3_lH61P=oemOG`ko3Ph>
3_m?Cdl=ong]k@oooooo000=ooooo`ko6a/K3_l:2PX>oa<C4`go2`/;3_l@410>oa<C4`ko820P3OmV
IVH;ooooo`kof][J3OmPH60>oiNGU`kob/[:3_lh>3P>olk>cPko?Shn3Om`L70:ooooo`ko4a<C3_lR
8R8>oa<C4`ko61PH3_lR8R8>oaXJ6Pgo8B4Q3Om]KFd;ooooo`ko1@D53_m;Bd/>oc4a<@ko61PH3OmO
Gel>o`h>3PkoCdm?3Oo]kNd?ooooo`003Oooool>oa/K6`ko2PX:3_lC4a<=o`/;2`ko410@3_lC4a<>
ob0P80goIVIV2oooool>om[JfPgoH61P3_nGUiL>ol[:bPko>3Ph3_o>c/h>ochn?PgoL71`2_ooool>
oa<C4`ko8R8R3_lC4a<>oaPH60ko8R8R3_lJ6QX=ob4Q8@goKFe]2oooool>o`D51@koBd];3_la<C4>
oaPH60goGemO3_l>3Ph>odm?C`gokNg]3oooool000gooooo7?lQ8B4>obHV9Pgo9BDU3_lK6a/>obDU
9@ko8B4Q3On5QHD;ooooo`ko_Kfm3OmFEUH>ofEUI@kocLg=3_l<30`>om3@d0ko@D513On4Q8@:oooo
o`ko:b/[3_l];Bd>obHV9Pko7QhN3_lf=SH>ob0P80go;bl_3On1PH4;ooooo`ko0P823_m9BDT>ocXj
>Pko4a<C3OmVIVH>o`d=3@koBTY:3OoKfm/?ooooo`003OoooolLob4Q8@ko9RHV3OlU9BD>oa/K6`ko
9BDU3_lQ8B4=ohF5Q@_ooooo3_nm_Kd=oeIFEPkoIFEU3_o=cLd>o``<30kod=3@3_m1@D4=ohB4Q0[o
oooo3_l[:b/>obd];@ko9RHV3_lN7Qh>ocHf=Pko820P3Ol_;bl=oh61P@_ooooo3_l20P8>odU9B@ko
>SXj3_lC4a<=ofIVIPko3@d=3_m:BTX=om_Kf`oooooo000=oooooaco8B4Q3_lV9RH=obDU9@ko6a/K
3_lU9BD>ob4Q8@goQHF52oooool>okfm_@goEUIF3_mUIFD>olg=c@ko30`<3_o@d=0>od51@@goQ8B4
2_ooool>ob/[:`ko;Bd]3_lV9RH>oahN7Pko=SHf3_lP820=obl_;`goPH612oooool>o`820PkoBDU9
3_lj>SX>oa<C4`goIVIV3_l=3@d>odY:BPgofm_K3oooool000gooooo7?lQ8B4>obHV9Pgo9BDU3_lK
6a/>obDU9@ko8B4Q3On5QHD;ooooo`ko_Kfm3OmFEUH>ofEUI@kocLg=3_l<30`>om3@d0ko@D513On4
Q8@:ooooo`ko:b/[3_l];Bd>obHV9Pko7QhN3_lf=SH>ob0P80go;bl_3On1PH4;ooooo`ko0P823_m9
BDT>ocXj>Pko4a<C3OmVIVH>o`d=3@koBTY:3OoKfm/?ooooo`003OoooolLob4Q8@ko9RHV3OlU9BD>
oa/K6`ko9BDU3_lQ8B4=ohF5Q@_ooooo3_nm_Kd=oeIFEPkoIFEU3_o=cLd>o``<30kod=3@3_m1@D4=
ohB4Q0[ooooo3_l[:b/>obd];@ko9RHV3_lN7Qh>ocHf=Pko820P3Ol_;bl=oh61P@_ooooo3_l20P8>
odU9B@ko>SXj3_lC4a<=ofIVIPko3@d=3_m:BTX=om_Kf`oooooo000=oooooaco8B4Q3_lV9RH=obDU
9@ko6a/K3_lU9BD>ob4Q8@goQHF52oooool>okfm_@goEUIF3_mUIFD>olg=c@ko30`<3_o@d=0>od51
@@goQ8B42_ooool>ob/[:`ko;Bd]3_lV9RH>oahN7Pko=SHf3_lP820=obl_;`goPH612oooool>o`82
0PkoBDU93_lj>SX>oa<C4`goIVIV3_l=3@d>odY:BPgofm_K3oooool000gooooo7?lQ8B4>obHV9Pgo
9BDU3_lK6a/>obDU9@ko8B4Q3On5QHD;ooooo`ko_Kfm3OmFEUH>ofEUI@kocLg=3_l<30`>om3@d0ko
@D513On4Q8@:ooooo`ko:b/[3_l];Bd>obHV9Pko7QhN3_lf=SH>ob0P80go;bl_3On1PH4;ooooo`ko
0P823_m9BDT>ocXj>Pko4a<C3OmVIVH>o`d=3@koBTY:3OoKfm/?ooooo`003OoooolLob4Q8@ko9RHV
3OlU9BD>oa/K6`ko9BDU3_lQ8B4=ohF5Q@_ooooo3_nm_Kd=oeIFEPkoIFEU3_o=cLd>o``<30kod=3@
3_m1@D4=ohB4Q0[ooooo3_l[:b/>obd];@ko9RHV3_lN7Qh>ocHf=Pko820P3Ol_;bl=oh61P@_ooooo
3_l20P8>odU9B@ko>SXj3_lC4a<=ofIVIPko3@d=3_m:BTX=om_Kf`oooooo000=oooooaco8B4Q3_lV
9RH=obDU9@ko6a/K3_lU9BD>ob4Q8@goQHF52oooool>okfm_@goEUIF3_mUIFD>olg=c@ko30`<3_o@
d=0>od51@@goQ8B42_ooool>ob/[:`ko;Bd]3_lV9RH>oahN7Pko=SHf3_lP820=obl_;`goPH612ooo
ool>o`820PkoBDU93_lj>SX>oa<C4`goIVIV3_l=3@d>odY:BPgofm_K3oooool000gooooo7?lQ8B4>
obHV9Pgo9BDU3_lK6a/>obDU9@ko8B4Q3On5QHD;ooooo`ko_Kfm3OmFEUH>ofEUI@kocLg=3_l<30`>
om3@d0ko@D513On4Q8@:ooooo`ko:b/[3_l];Bd>obHV9Pko7QhN3_lf=SH>ob0P80go;bl_3On1PH4;
ooooo`ko0P823_m9BDT>ocXj>Pko4a<C3OmVIVH>o`d=3@koBTY:3OoKfm/?ooooo`003OoooolLob4Q
8@ko9RHV3OlU9BD>oa/K6`ko9BDU3_lQ8B4=ohF5Q@_ooooo3_nm_Kd=oeIFEPkoIFEU3_o=cLd>o``<
30kod=3@3_m1@D4=ohB4Q0[ooooo3_l[:b/>obd];@ko9RHV3_lN7Qh>ocHf=Pko820P3Ol_;bl=oh61
P@_ooooo3_l20P8>odU9B@ko>SXj3_lC4a<=ofIVIPko3@d=3_m:BTX=om_Kf`oooooo000=oooooaco
8B4Q3_lV9RH=obDU9@ko6a/K3_lU9BD>ob4Q8@goQHF52oooool>okfm_@goEUIF3_mUIFD>olg=c@ko
30`<3_o@d=0>od51@@goQ8B42_ooool>ob/[:`ko;Bd]3_lV9RH>oahN7Pko=SHf3_lP820=obl_;`go
PH612oooool>o`820PkoBDU93_lj>SX>oa<C4`goIVIV3_l=3@d>odY:BPgofm_K3oooool000gooooo
7?lQ8B4>obHV9Pgo9BDU3_lK6a/>obDU9@ko8B4Q3On5QHD;ooooo`ko_Kfm3OmFEUH>ofEUI@kocLg=
3_l<30`>om3@d0ko@D513On4Q8@:ooooo`ko:b/[3_l];Bd>obHV9Pko7QhN3_lf=SH>ob0P80go;bl_
3On1PH4;ooooo`ko0P823_m9BDT>ocXj>Pko4a<C3OmVIVH>o`d=3@koBTY:3OoKfm/?ooooo`003Ooo
ool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mc
Lg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3
Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>
on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>
oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<H
ooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;R
hPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l
?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hoooo
o`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPko
b<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0ko
TI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko
5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S8
3_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A
3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG
3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oP
h>0=ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM
7Ad=oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mE
EED>ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=
ol[:bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=
oi6AT@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>
ob@T90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:
bPkof=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6A
T@[ooooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T
90ko>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPko
f=SH3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[o
oooo3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko
>CTi3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH
3_o=cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo
3_mOGel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi
3Om:BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=
cLd>omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mO
Gel>og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:
BTX>oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>
omWIfASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>
og=cL`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>
oahN7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWI
fASooooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=c
L`koJFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN
7PkoDE5A3OnFUYH?ooooo`003Oooool>on;RhPkob<S83_oPh>0=ol[:bPkof=SH3_o=cLd>omWIfASo
oooo3_ne]KD=obd];@koTI6A3_mcLg<>oc`l?0koTI6A3_lM7Ad=oi6AT@[ooooo3_mOGel>og=cL`ko
JFUY3_mWIfL>ogalO0koKfm_3On3Ph<Hooooo`ko5aLG3_mEEED>ob@T90ko>CTi3Om:BTX>oahN7Pko
DE5A3OnFUYH?ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.984105, \
-0.202776, 0.0728937, 0.0728937}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-9.78601, -0.202776, 0.0728937, 0.0728937}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-18.5834, -0.202776, 0.0728937, 0.0728937}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-27.3853, -0.202776, 0.0728937, 0.0728937}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
82272F23
96391A00
BD8A5353
FFBBE5F6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A65C5825
FFFED24E
C8D4D057
F70F0062
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
165059F2
003C5AFD
264265FF
3A6769EE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2649491B
0200140C
04020600
91FFFE74
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003OoooolLoh:2PQ_o9bLW7?l_
;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooo
oolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHL
oeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?
ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooo
oaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o
9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[o
l_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo
6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU9
6olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU
9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolL
oh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50L
oeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S
8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV
9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1co
F5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`00
3OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF
7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_
;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooo
oolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHL
oeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?
ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooo
oaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o
9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[o
l_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo
6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU9
6olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU
9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolL
oh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50L
oeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S
8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV
9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1co
F5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`00
3OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF
7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_
;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooo
oolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHL
oeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?
ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooo
oaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o
9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[o
l_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo
6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU9
6olK6a/?ooooo`003OoooolLoh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU
9BD:oooooaco5QHF7?m@D50LoeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolL
oh:2PQ_o9bLW7?l_;blKob<S8`_ooooo6onVYZHLoeaLG1coF5QH6olU9BD:oooooaco5QHF7?m@D50L
oeUIFA[ol_;b2ooooolLobHV9SOoBDU96olK6a/?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`00
02Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`00
01_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_o
CTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`00
3OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l
7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ
6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l2
0P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hL
om;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?
ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`00
01co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o
>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_o
oooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo
7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D
6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oo
oolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolL
oiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJ
oogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`00
02Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`00
01_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_o
CTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`00
3OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l
7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ
6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l2
0P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hL
om;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?
ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`00
01co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o
>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_o
oooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo
7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D
6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oo
oolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolL
oiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJ
oogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`00
02Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`00
01_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_o
CTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`00
3OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l
7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ
6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l2
0P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hL
om;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?
ooooo`003OoooolLoiJFUQ_o>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`00
01co?3`l7?mJFUXJoogmo@_ooooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLoiJFUQ_o
>CTi7?lJ6QXKo`0002Kooooo7?ono_hLom;BdQ_oCTi>2_oooolLo`0001co?3`l7?mJFUXJoogmo@_o
oooo7?l20P8Lo`0001_o51@D6ol<30`?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S8
7?oDe=@Lom3@d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o0000
3oooool000gooooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV
9RHLod92@QcoIFEU9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXg
oe=CD`_ooooo6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@L
o`820Q_o1PH66ol0000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@
d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003oooool000go
oooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHLod92@Qco
IFEU9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXgoe=CD`_ooooo
6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`820Q_o1PH6
6ol0000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_oEeMG2_oo
oolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003oooool000gooooo7?nm_KdK
ohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHLod92@QcoIFEU9OoooolL
o`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXgoe=CD`_ooooo6oo8b<PLomCD
e1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`820Q_o1PH66ol0000?oooo
o`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_oEeMG2_oooolLobHV9Qco
@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003oooool000gooooo7?nm_KdKohZ:RSOoDe=C
2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHLod92@QcoIFEU9OoooolLo`@411co0P82
6ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXgoe=CD`_ooooo6oo8b<PLomCDe1cod=3@6omG
EeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`820Q_o1PH66ol0000?ooooo`003OoooolL
okfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDU
oooooaco10@47?l20P8Ko`H61Q_o00003oooool000gooooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8
b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHLod92@QcoIFEU9OoooolLo`@411co0P826ol61PHKo`00
00oooooo000=oooooaco_Kfm6on:RXXgoe=CD`_ooooo6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco
9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`820Q_o1PH66ol0000?ooooo`003OoooolLokfm_A_oRXZ:
=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@4
7?l20P8Ko`H61Q_o00003oooool000gooooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@
d=0KoeMGE`[ooooo7?lV9RHLod92@QcoIFEU9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=
oooooaco_Kfm6on:RXXgoe=CD`_ooooo6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8L
ofEUIBGooooo7?l410@Lo`820Q_o1PH66ol0000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooo
oa_ob<S87?oDe=@Lom3@d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H6
1Q_o00003oooool000gooooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[o
oooo7?lV9RHLod92@QcoIFEU9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm
6on:RXXgoe=CD`_ooooo6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo
7?l410@Lo`820Q_o1PH66ol0000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oD
e=@Lom3@d1_oEeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003ooo
ool000gooooo7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHL
od92@QcoIFEU9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXgoe=C
D`_ooooo6oo8b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`82
0Q_o1PH66ol0000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_o
EeMG2_oooolLobHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003oooool000gooooo
7?nm_KdKohZ:RSOoDe=C2ooooolKolS8b1coe=CD7?o@d=0KoeMGE`[ooooo7?lV9RHLod92@QcoIFEU
9OoooolLo`@411co0P826ol61PHKo`0000oooooo000=oooooaco_Kfm6on:RXXgoe=CD`_ooooo6oo8
b<PLomCDe1cod=3@6omGEeL:oooooaco9RHV7?m2@T8LofEUIBGooooo7?l410@Lo`820Q_o1PH66ol0
000?ooooo`003OoooolLokfm_A_oRXZ:=omCDe<;oooooa_ob<S87?oDe=@Lom3@d1_oEeMG2_oooolL
obHV9Qco@T927?mUIFDUoooooaco10@47?l20P8Ko`H61Q_o00003oooool002Wooooo6onk^k/LonGU
iA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooo
oacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco
3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_o
M7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo
7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk
^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^
k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolK
ooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolK
ooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9R
HP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wo
oooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIaco
JFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf
2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A
7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0
000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3ooo
ool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXL
ofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGU
iA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooo
oacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco
3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_o
M7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo
7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk
^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^
k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolK
ooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolK
ooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9R
HP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wo
oooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIaco
JFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf
2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A
7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0
000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3ooo
ool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXL
ofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGU
iA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooo
oacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco
3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_o
M7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo
7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk
^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^
k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolK
ooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolK
ooknoQ_oM7Ad3oooool002Wooooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9R
HP[ooooo7?lj>SXLofMWIacoJFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool002Wo
oooo6onk^k/LonGUiA_om_Kf2ooooolKooOgmaco3`l?7?l0000Kof9RHP[ooooo7?lj>SXLofMWIaco
JFUY6_o^k^h;oooooacoTI6A7?oooolKooknoQ_oM7Ad3oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.492052, \
-0.101388, 0.0364468, 0.0364468}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-4.89301, -0.101388, 0.0364468, 0.0364468}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-9.29169, -0.101388, 0.0364468, 0.0364468}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-13.6926, -0.101388, 0.0364468, 0.0364468}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
789221FF
6D5E0BD8
7F3704DE
651A00D9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F101DF1
4F051AFF
4D081AFF
310013C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A899F716
92A7F400
8DB3FF00
8DB4E000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
35D4C000
4FF8D509
57FFD40D
37B18B0A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003OoooolLogQhN1_oTY:B7?lQ
8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le
=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410L
oadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?
ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRX
Z1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_o
TY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_o
oooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?
7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<30
6ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oo
oolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolL
ogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJ
oaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooo
oa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCD
e1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_o
lO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`00
3OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI
7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ
8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le
=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410L
oadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?
ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRX
Z1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_o
TY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_o
oooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?
7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<30
6ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oo
oolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolL
ogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJ
oaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooo
oa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCD
e1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_o
lO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`00
3OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI
7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ
8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le
=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410L
oadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?
ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRX
Z1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_o
TY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_o
oooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?
7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<30
6ol0000?ooooo`003OoooolLogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oo
oolLojRXZ1coVIVI7?ogmoLJoaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolL
ogQhN1_oTY:B7?lQ8B4Voooooa_oCdm?7?l@410LoadM7A_olO7a2_oooolLojRXZ1coVIVI7?ogmoLJ
oaHF5P_ooooo7?le=CDLomCDe1_o`<306ol0000?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSH
f0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooSh
n1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco
6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`00
3OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW
7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;
2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?
CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlL
o`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?
ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:B
TQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_o
GUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_o
oooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo
6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE
6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9Ooo
oolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolL
ofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@J
o`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSH
f0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooSh
n1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco
6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`00
3OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW
7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;
2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?
CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlL
o`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?
ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:B
TQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_o
GUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_o
oooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo
6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE
6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9Ooo
oolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolL
ofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@J
o`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSH
f0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooSh
n1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco
6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`00
3OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW
7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;
2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?
CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlL
o`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?
ooooo`003OoooolLofe]KA_oGUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:B
TQcoYjNW7?odm?@Jo`0000_ooooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLofe]KA_o
GUiN7?l;2`/KomSHf0_ooooo6om?CdlLo`D51Aco6QXJ9OoooolLoi:BTQcoYjNW7?odm?@Jo`0000_o
oooo7?m?CdlLooShn1_oeMGE6ol92@T?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo
6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD
6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9Ooo
oolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolL
ogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJ
o`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkN
gP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooo
oa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co
6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`00
3OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c
7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l4
10@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mG
EeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdL
o`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?
ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=
SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o
=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_o
oooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo
6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD
6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9Ooo
oolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolL
ogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJ
o`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkN
gP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooo
oa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co
6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`00
3OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c
7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l4
10@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mG
EeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdL
o`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?
ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=
SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o
=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_o
oooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo
6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD
6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9Ooo
oolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolL
ogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJ
o`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkN
gP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooo
oa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co
6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`00
3OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c
7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l4
10@KomkNgP_ooooo6om=CDdLo`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mG
EeLLoooooa_oe=CD6ol=3@d?ooooo`003OoooolLogmoOa_o=cLg7?l410@KomkNgP_ooooo6om=CDdL
o`P821co6QXJ9OoooolLohf=SAco/k>c7?oooolJo`0000_ooooo7?mGEeLLoooooa_oe=CD6ol=3@d?
ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0`<0:oooo
oacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=oooooaco
IFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdLokBd]1co
h>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ6Qco0000
6ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`0000_ooooo
7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_ooooo6ola
<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco/K6a6on;
Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco00007?lC4a<K
ol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:3oooool0
00gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oooolLohf=
SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolLofEUIA_o
6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@Lon3Ph1[o
00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`0001_ofMWI
2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooooaco=cLg
7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o<C4a7?l0
000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_oRh^;6ol:
2PX?ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0`<0:
oooooacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=oooo
oacoIFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdLokBd
]1coh>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ6Qco
00006ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`0000_o
oooo7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_ooooo
6ola<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco/K6a
6on;Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco00007?lC
4a<Kol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:3ooo
ool000gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oooolL
ohf=SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolLofEU
IA_o6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@Lon3P
h1[o00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`0001_o
fMWI2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooooaco
=cLg7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o<C4a
7?l0000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_oRh^;
6ol:2PX?ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0
`<0:oooooacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=
oooooacoIFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdL
okBd]1coh>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ
6Qco00006ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`00
00_ooooo7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolLofEUIA_o6QXJ7?l0000KomWIf@_o
oooo6ola<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@Lon3Ph1[o00002ooooolLocLg=aco
/K6a6on;Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`0001_ofMWI2ooooolKoc4a<Aco0000
7?lC4a<Kol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooooaco=cLg7?na/K4Koh^;Ra_o2PX:
3oooool000gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o<C4a7?l0000Loa<C4a_o`<302_oo
oolLohf=SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_oRh^;6ol:2PX?ooooo`003OoooolL
ofEUIA_o6QXJ7?l0000KomWIf@_ooooo6ola<C4Lo`0001co4a<C6oo0`<0:oooooacoSHf=7?nd];@L
on3Ph1[o00002ooooolLocLg=aco/K6a6on;Rh/Ko`X:2Poooooo000=oooooacoIFEU6olJ6QXLo`00
01_ofMWI2ooooolKoc4a<Aco00007?lC4a<Kol30`0[ooooo7?n=SHdLokBd]1coh>3P6_l0000;oooo
oaco=cLg7?na/K4Koh^;Ra_o2PX:3oooool000gooooo7?mUIFDKoaXJ6Qco00006ooIfMT;oooooa_o
<C4a7?l0000Loa<C4a_o`<302_oooolLohf=SAco];Bd7?oPh>0Jo`0000_ooooo7?lg=cLLok6a/A_o
Rh^;6ol:2PX?ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.492052, \
-0.101388, 0.0364468, 0.0364468}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-4.89301, -0.101388, 0.0364468, 0.0364468}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-9.29169, -0.101388, 0.0364468, 0.0364468}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-13.6926, -0.101388, 0.0364468, 0.0364468}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .23256 
%%ImageSize: 500 116.279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0055371 0.238095 [
[ 0 0 0 0 ]
[ 1 .23256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23256 L
0 .23256 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0055371 0.245293 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2920001F
1A1E0627
2834172F
FFE7EBF8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0055371 0.488926 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7C0053B0
DA390B65
E98B0437
4A228FFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0055371 0.732558 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00AAC37D
0532CFC4
5F05AEE1
4DFFAB43
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0055371 0.97619 0.227021 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E1BE0401
6DFF500E
28F8A748
F0650027
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 116.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000M2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003OoooolLobTY:A_o820P7?l0
000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[oOGem2ooo
oolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO2ooooolK
ogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q7?nn_[hK
o`@411_o0@413oooool000gooooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0000Loe=C
Da_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol10@4?oooo
o`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:oooooaco
00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooooaco:BTY
6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZZQco`l?3
6_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413oooool000gooooo7?lY:BTKob0P81co00006olO
7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_ooooo7?oQ
hN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo6omlO7`L
o`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn6ol410@K
o`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mCDe<Kok2`
/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413oooool000go
oooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolLo`0001co
ZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLobTY:A_o820P
7?l0000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[oOGem
2ooooolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO2ooo
oolKogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q7?nn
_[hKo`@411_o0@413oooool000gooooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0000L
oe=CDa_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol10@4?
ooooo`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:oooo
oaco00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooooaco
:BTY6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZZQco
`l?36_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413oooool000gooooo7?lY:BTKob0P81co0000
6olO7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_ooooo
7?oQhN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo6oml
O7`Lo`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn6ol4
10@Ko`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mCDe<K
ok2`/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413oooool0
00gooooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolLo`00
01coZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLobTY:A_o
820P7?l0000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[o
OGem2ooooolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO
2ooooolKogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q
7?nn_[hKo`@411_o0@413oooool000gooooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0
000Loe=CDa_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol1
0@4?ooooo`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo6omlO7`Lo`0001coDe=C6on`/;0:
oooooaco00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn6ol410@Ko`410@oooooo000=oooo
oaco:BTY6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mCDe<Kok2`/0[ooooo7?l0000LojZZ
ZQco`l?36_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413oooool000gooooo7?lY:BTKob0P81co
00006olO7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolLo`0001coZZZZ7?o3`l<JogemO@_o
oooo7?oQhN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLobTY:A_o820P7?l0000KoalO7`_ooooo
6omlO7`Lo`0001coDe=C6on`/;0:oooooaco00007?nZZZXLol?3`a[oOGem2ooooolLon7QhAco_[jn
6ol410@Ko`410@oooooo000=oooooaco:BTY6olP820Lo`0001_o7alO2ooooolKogalO1co00007?mC
De<Kok2`/0[ooooo7?l0000LojZZZQco`l?36_mmOGd;oooooacohN7Q7?nn_[hKo`@411_o0@413ooo
ool000gooooo7?lY:BTKob0P81co00006olO7al;oooooa_oO7al7?l0000Loe=CDa_o/;2`2_oooolL
o`0001coZZZZ7?o3`l<JogemO@_ooooo7?oQhN4Lokjn_Q_o10@46ol10@4?ooooo`003OoooolLoaXJ
6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb<S8Lolo?
ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhLo`H61Q_o
9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;oooooaco
KFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooooa_of][J
7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooooa_oD51@
6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco2`/;6omU
IFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poooooo000=
oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo7?l51@DL
oc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ6QXKoahN
7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?cllJolC4
a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHKobLW9`_o
oooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolLofe]KAco
oooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[JfQco>CTi
7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@D1_o3Ph>
3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_oIFEU2_oo
oolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`003OoooolL
oaXJ6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb<S8L
olo?ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhLo`H6
1Q_o9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;oooo
oacoKFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooooa_o
f][J7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooooa_o
D51@6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco2`/;
6omUIFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poooooo
000=oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo7?l5
1@DLoc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ6QXK
oahN7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?cllJ
olC4a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHKobLW
9`_ooooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolLofe]
KAcooooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[JfQco
>CTi7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@D1_o
3Ph>3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_oIFEU
2_oooolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`003Ooo
oolLoaXJ6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb
<S8Lolo?ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhL
o`H61Q_o9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;
oooooacoKFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooo
oa_of][J7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooo
oa_oD51@6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHKobLW9`_ooooo6ooJf]XLocTi>Aco
2`/;6omUIFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolLofe]KAcooooo6om@D50Ko`h>3Poo
oooo000=oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[JfQco>CTi7?l;2`/KofEUI@[ooooo
7?l51@DLoc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@D1_o3Ph>3oooool000gooooo7?lJ
6QXKoahN7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_oIFEU2_oooolLo`D51Aco<S8b7?o?
cllJolC4a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`003OoooolLoaXJ6Q_o7QhN7?l61PHK
obLW9`_ooooo6ooJf]XLocTi>Aco2`/;6omUIFD:oooooaco1@D57?lb<S8Lolo?ca[oa<C42ooooolL
ofe]KAcooooo6om@D50Ko`h>3Poooooo000=oooooaco6QXJ6olN7QhLo`H61Q_o9bLW2ooooolKom[J
fQco>CTi7?l;2`/KofEUI@[ooooo7?l51@DLoc8b<Qcoclo?6_o4a<@;oooooacoKFe]7?oooolKoe1@
D1_o3Ph>3oooool000gooooo7?lJ6QXKoahN7Qco1PH66olW9bL;oooooa_of][J7?li>CTLo`/;2a_o
IFEU2_oooolLo`D51Aco<S8b7?o?cllJolC4a0_ooooo7?m]KFdLoooooa_oD51@6ol>3Ph?ooooo`00
3OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooooacoGemO
7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco:2PX6old
=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQ
hN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG6ol_;bl;
oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PL
ooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;
Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8
B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@KocLg=`[o
oooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool000gooooo
7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemOGaco1@D5
7?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o=3@d7?lG
5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[ohN7Q2ooo
oolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_2ooooolK
onWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX7?ohn?PK
ojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;Rh/Lo`@4
11_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8B4P?oooo
o`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooooaco
GemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco:2PX
6old=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco[Zj^
6_oQhN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG6ol_
;bl;oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo7?lX
:2PLooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTL
oh^;Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLK
odQ8B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@KocLg
=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool000go
oooo7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemOGaco
1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o=3@d
7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[ohN7Q
2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_2ooo
oolKonWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX7?oh
n?PKojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;Rh/L
o`@411_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8B4P?
ooooo`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooo
oacoGemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco
:2PX6old=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco
[Zj^6_oQhN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG
6ol_;bl;oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo
7?lX:2PLooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooY
jNTLoh^;Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onW
YjLKodQ8B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_2ooooolKonWYjAcoRh^;7?l410@K
ocLg=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX7?ohn?PKojNWYa_oB4Q83oooool0
00gooooo7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;Rh/Lo`@411_o=cLg2_oooolLoemO
Gaco1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8B4P?ooooo`003OoooolLobPX:1_o
=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:oooooacoGemO7?l51@DLojj^[Q[o
hN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000=oooooaco:2PX6old=3@LoaLG5a_o;bl_
2ooooolKonWYjAcoRh^;7?l410@KocLg=`[ooooo7?mOGelLo`D51Aco[Zj^6_oQhN4;oooooaco:2PX
7?ohn?PKojNWYa_oB4Q83oooool000gooooo7?lX:2PKoc@d=1co5aLG6ol_;bl;oooooa_ojNWY7?n;
Rh/Lo`@411_o=cLg2_oooolLoemOGaco1@D57?n^[ZhJon7Qh@_ooooo7?lX:2PLooShn1_oYjNW6om8
B4P?ooooo`003OoooolLobPX:1_o=3@d7?lG5aLKobl_;`_ooooo6ooYjNTLoh^;Raco10@46olg=cL:
oooooacoGemO7?l51@DLojj^[Q[ohN7Q2ooooolLobPX:1con?Sh6onWYjLKodQ8B0oooooo000Yoooo
oa_oinOW7?o[jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3
@`_ooooo7?o`l?0LofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_o
BTY:7?lR8R8Lohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o
9bLW3oooool002Wooooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=
7?oooolLoj^[Za[o@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo000Yoooooa_oinOW7?o[
jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`
l?0LofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_oBTY:7?lR8R8L
ohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW3oooool0
02Wooooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=7?oooolLoj^[
Za[o@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo000Yoooooa_oinOW7?o[jn/KooShn0_o
oooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`l?0LofEUIA_o
00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_oBTY:7?lR8R8Lohn?SbGooooo
7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW3oooool002Wooooo6ooW
inLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=7?oooolLoj^[Za[o@d=32ooo
oolLoo3`l1coIFEU6ol0000KobLW9`oooooo000Yoooooa_oinOW7?o[jn/KooShn0_ooooo6om:BTXL
ob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`l?0LofEUIA_o00006olW9bL?
ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_oBTY:7?lR8R8Lohn?SbGooooo7?m=CDdLoooo
oacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW3oooool002Wooooo6ooWinLLon_[ja_o
n?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=7?oooolLoj^[Za[o@d=32ooooolLoo3`l1co
IFEU6ol0000KobLW9`oooooo000Yoooooa_oinOW7?o[jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?
9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`l?0LofEUIA_o00006olW9bL?ooooo`00:Ooo
oolKonOWiacojn_[6oohn?P;oooooa_oBTY:7?lR8R8Lohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3
@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW3oooool002Wooooo6ooWinLLon_[ja_on?Sh2ooooolK
odY:BQco8R8R7?n?ShlUoooooacoCDe=7?oooolLoj^[Za[o@d=32ooooolLoo3`l1coIFEU6ol0000K
obLW9`oooooo000Yoooooa_oinOW7?o[jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=
CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`l?0LofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiaco
jn_[6oohn?P;oooooa_oBTY:7?lR8R8Lohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooaco
l?3`7?mUIFDKo`0001_o9bLW3oooool002Wooooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R
7?n?ShlUoooooacoCDe=7?oooolLoj^[Za[o@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo
000Yoooooa_oinOW7?o[jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[
Zj/Jod=3@`_ooooo7?o`l?0LofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;
oooooa_oBTY:7?lR8R8Lohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDK
o`0001_o9bLW3oooool002Wooooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooo
oacoCDe=7?oooolLoj^[Za[o@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo000Yoooooa_o
inOW7?o[jn/KooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_o
oooo7?o`l?0LofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_oBTY:
7?lR8R8Lohn?SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW
3oooool002Wooooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=7?oo
oolLoj^[Za[o@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo000Yoooooa_oinOW7?o[jn/K
ooShn0_ooooo6om:BTXLob8R8QcoShn?9OoooolLode=CAcooooo7?n[Zj/Jod=3@`_ooooo7?o`l?0L
ofEUIA_o00006olW9bL?ooooo`00:OoooolKonOWiacojn_[6oohn?P;oooooa_oBTY:7?lR8R8Lohn?
SbGooooo7?m=CDdLoooooacoZj^[6_m3@d<;oooooacol?3`7?mUIFDKo`0001_o9bLW3oooool002Wo
oooo6ooWinLLon_[ja_on?Sh2ooooolKodY:BQco8R8R7?n?ShlUoooooacoCDe=7?oooolLoj^[Za[o
@d=32ooooolLoo3`l1coIFEU6ol0000KobLW9`oooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {115.25, 0}} -> {-0.114552, -0.0232607, \
0.00847516, 0.00847516}, {{13.5, 123.25}, {112.5, 2.6875}} -> {-0.492052, \
-0.101388, 0.0364468, 0.0364468}, {{134.25, 244}, {112.5, 2.6875}} -> \
{-4.89301, -0.101388, 0.0364468, 0.0364468}, {{254.938, 364.688}, {112.5, \
2.6875}} -> {-9.29169, -0.101388, 0.0364468, 0.0364468}, {{375.688, 485.438}, \
{112.5, 2.6875}} -> {-13.6926, -0.101388, 0.0364468, 0.0364468}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.592137 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13314 -18 -4.5 ]
[-0.0125 .13314 0 4.5 ]
[-0.0125 .25157 -18 -4.5 ]
[-0.0125 .25157 0 4.5 ]
[-0.0125 .37 -18 -4.5 ]
[-0.0125 .37 0 4.5 ]
[-0.0125 .48842 -18 -4.5 ]
[-0.0125 .48842 0 4.5 ]
[-0.0125 .60685 -6 -4.5 ]
[-0.0125 .60685 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13314 m
.00625 .13314 L
s
[(0.2)] -0.0125 .13314 1 0 Mshowa
0 .25157 m
.00625 .25157 L
s
[(0.4)] -0.0125 .25157 1 0 Mshowa
0 .37 m
.00625 .37 L
s
[(0.6)] -0.0125 .37 1 0 Mshowa
0 .48842 m
.00625 .48842 L
s
[(0.8)] -0.0125 .48842 1 0 Mshowa
0 .60685 m
.00625 .60685 L
s
[(1)] -0.0125 .60685 1 0 Mshowa
.125 Mabswid
0 .04432 m
.00375 .04432 L
s
0 .07393 m
.00375 .07393 L
s
0 .10354 m
.00375 .10354 L
s
0 .16275 m
.00375 .16275 L
s
0 .19236 m
.00375 .19236 L
s
0 .22196 m
.00375 .22196 L
s
0 .28118 m
.00375 .28118 L
s
0 .31078 m
.00375 .31078 L
s
0 .34039 m
.00375 .34039 L
s
0 .3996 m
.00375 .3996 L
s
0 .42921 m
.00375 .42921 L
s
0 .45882 m
.00375 .45882 L
s
0 .51803 m
.00375 .51803 L
s
0 .54764 m
.00375 .54764 L
s
0 .57725 m
.00375 .57725 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13314 m
1 .13314 L
s
.99375 .25157 m
1 .25157 L
s
.99375 .37 m
1 .37 L
s
.99375 .48842 m
1 .48842 L
s
.99375 .60685 m
1 .60685 L
s
.125 Mabswid
.99625 .04432 m
1 .04432 L
s
.99625 .07393 m
1 .07393 L
s
.99625 .10354 m
1 .10354 L
s
.99625 .16275 m
1 .16275 L
s
.99625 .19236 m
1 .19236 L
s
.99625 .22196 m
1 .22196 L
s
.99625 .28118 m
1 .28118 L
s
.99625 .31078 m
1 .31078 L
s
.99625 .34039 m
1 .34039 L
s
.99625 .3996 m
1 .3996 L
s
.99625 .42921 m
1 .42921 L
s
.99625 .45882 m
1 .45882 L
s
.99625 .51803 m
1 .51803 L
s
.99625 .54764 m
1 .54764 L
s
.99625 .57725 m
1 .57725 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .01887 L
.09524 .01887 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .01887 L
.09524 .01887 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .03612 L
.33333 .03612 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .03612 L
.33333 .03612 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .29821 L
.57143 .29821 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .29821 L
.57143 .29821 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .29779 L
.80952 .29779 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .29779 L
.80952 .29779 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .56196 L
.14286 .56196 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .56196 L
.14286 .56196 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .0222 L
.38095 .0222 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .0222 L
.38095 .0222 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .03695 L
.61905 .03695 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .03695 L
.61905 .03695 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .02989 L
.85714 .02989 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .02989 L
.85714 .02989 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .60332 L
.19048 .60332 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .60332 L
.19048 .60332 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .01679 L
.42857 .01679 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .01679 L
.42857 .01679 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .01534 L
.66667 .01534 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .01534 L
.66667 .01534 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .01555 L
.90476 .01555 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .01555 L
.90476 .01555 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .05836 L
.2381 .05836 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .05836 L
.2381 .05836 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .33001 L
.47619 .33001 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .33001 L
.47619 .33001 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .13464 L
.71429 .13464 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .13464 L
.71429 .13464 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .12799 L
.95238 .12799 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .12799 L
.95238 .12799 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Ko0?l0
5OoooolFoomo01Gooooo5Ooo000Go`3o01Cooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5Ol00?lGoomo01Cooooo5_oo000Fo`3o01Gooooo5_ooO`0DoooooaKoo`005_l0o`0EoooooaKoogl0
5OoooolEool001Oo0?l05?oooolGoomo01Cooooo00?o0000ooooooooool02oooool001[ooooo0_l0
0007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolFool001Ko0?l05Ooo
oolFoomo01Cooooo5_oo000Fo`3o01Gooooo5_ooO`0EoooooaGoo`005ol0o`0DoooooaOoogl05?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lG
oomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool001Ko0?l05OoooolFoomo01Gooooo5Ooo000G
o`3o01Cooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005_l0o`0Eoooo
oaKoogl05OoooolEool001Oo0?l05?oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo01Co
oooo5_oo000Fo`3o01Gooooo5_ooO`0EoooooaGoo`005ol0o`0DoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo
5ooo000ZoooooaKoogl05?oooolFool001Ko0?l05OoooolFoomo01Gooooo5Ooo000Go`3o01Cooooo
5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005_l0o`0EoooooaKoogl05Ooo
oolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005_l0o`0E
oooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl0EOoooolFoomo01Cooooo5_oo000Fo`3o
01Gooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`1EoooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`1EoooooaKoogl05?oooolGool002[ooooo
5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo0ol0
000XoooooaKo0?l05Ol00?lGoomo05Gooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
000ZoooooaOoogl04oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0E
o`00oaOoogl0EOoooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0D
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00
oaOoogl0EOoooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOo
ogl0EOoooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl0
EOoooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl0EOoo
oolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl0EOoooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0Doooo
oaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003oJooooolFoomo01Co
oooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Cooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo
000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolF
oomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0Eoooo
oaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[o
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000Zoooo
oaKoogl05OoooolFool002[ooooo5oooO`0Cooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[o
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0Doooo
oaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003oJooooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool01?l0003oooooooooooooool5o`00
00Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo000Zoooo
oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo1?l0000WoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0E
oooooaKoo`00D_ooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Co
oooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo
001EoooooaKoo`00E?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Co
oooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
0000:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00E?ooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Co
oooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
JooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003oJooooolF
oomo01Cooooo5ooo001EoooooaKoo`00E?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Co
oooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
JooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool0
00kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool0
05Gooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool5o`00
00Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Oooooo1?l0000WoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool005Gooooo5_oo001Booooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0D
oooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002Oooool2o`0000Oooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolF
oomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
JooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolG
ool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o
01Ko003oJooooolFoomo01Cooooo5ooo001EoooooaKoo`00E?ooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
JooooolFoomo01Cooooo5ooo001EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`00EOoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo001Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?m[oooooaKoogl05?oooolGool005Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
EOoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`3[ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`3[oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_o
oooo5_ooO`3[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00of_ooooo5_ooO`3[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oo
oolFo`3o01Ko003oJooooolFoomo0>[ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0
joooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?m[oooooaKoogl0joooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0joooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0
joooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oo
ooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0000WoooooaKo0?l05_l00?ooooooof[o
oooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool2o`0000Oooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooo
ooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?o
oooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oo
ooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00ooooooooK?oo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Oooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1_ooool4o`0002Oooooo5_l0o`0Fo`00ooooooooJ_ooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo0ol00007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
0000:?oooolFo`3o01Ko003ooooooom/ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooo
oom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
?_oooolFo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo03kooooo5_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_oooolF
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooo
oaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03ko
oooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool001Wooooo0ol0
0007ooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0noooooaKo003ooooooom]
ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Ko
oooo1?l0003ooooookgooooo1?l0000=ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool2o`0000Sooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo000J
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool006;ooooo0ol0001Wooooo`Go0000Ioooool3o`0006[ooooo0ol0001<
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`0006Kooooo00Go0000
ooooooooooooooooo`00001Zooooo`03o`000?oooooooooo04_ooooo001Sooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Uooooo`Go0000C?ooool0
06?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Wooooo`;o0000J?ooool01?l0
003oooooooooool0001=ooooo`00Hoooool00ol0003oooooooooo`1Vooooo`05o`000?oooooooooo
ooooool00000J_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000004gooooo001Roooo
o`;o0000J?ooool01Ol0003ooooooooooooooooo000006Kooooo00Go0000ooooooooooooooooo`00
001Yooooo`;o0000COooool006?ooooo00?o0000ooooooooool0Ioooool3o`0006Sooooo0ol0001[
ooooo`03o`000?oooooooooo04_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0796684, \
0.00931295, 0.00374469}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.712376 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15719 -18 -4.5 ]
[-0.0125 .15719 0 4.5 ]
[-0.0125 .29967 -18 -4.5 ]
[-0.0125 .29967 0 4.5 ]
[-0.0125 .44214 -18 -4.5 ]
[-0.0125 .44214 0 4.5 ]
[-0.0125 .58462 -18 -4.5 ]
[-0.0125 .58462 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15719 m
.00625 .15719 L
s
[(0.2)] -0.0125 .15719 1 0 Mshowa
0 .29967 m
.00625 .29967 L
s
[(0.4)] -0.0125 .29967 1 0 Mshowa
0 .44214 m
.00625 .44214 L
s
[(0.6)] -0.0125 .44214 1 0 Mshowa
0 .58462 m
.00625 .58462 L
s
[(0.8)] -0.0125 .58462 1 0 Mshowa
.125 Mabswid
0 .05033 m
.00375 .05033 L
s
0 .08595 m
.00375 .08595 L
s
0 .12157 m
.00375 .12157 L
s
0 .19281 m
.00375 .19281 L
s
0 .22843 m
.00375 .22843 L
s
0 .26405 m
.00375 .26405 L
s
0 .33528 m
.00375 .33528 L
s
0 .3709 m
.00375 .3709 L
s
0 .40652 m
.00375 .40652 L
s
0 .47776 m
.00375 .47776 L
s
0 .51338 m
.00375 .51338 L
s
0 .549 m
.00375 .549 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15719 m
1 .15719 L
s
.99375 .29967 m
1 .29967 L
s
.99375 .44214 m
1 .44214 L
s
.99375 .58462 m
1 .58462 L
s
.125 Mabswid
.99625 .05033 m
1 .05033 L
s
.99625 .08595 m
1 .08595 L
s
.99625 .12157 m
1 .12157 L
s
.99625 .19281 m
1 .19281 L
s
.99625 .22843 m
1 .22843 L
s
.99625 .26405 m
1 .26405 L
s
.99625 .33528 m
1 .33528 L
s
.99625 .3709 m
1 .3709 L
s
.99625 .40652 m
1 .40652 L
s
.99625 .47776 m
1 .47776 L
s
.99625 .51338 m
1 .51338 L
s
.99625 .549 m
1 .549 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .02897 L
.09524 .02897 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .02897 L
.09524 .02897 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .25201 L
.33333 .25201 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .25201 L
.33333 .25201 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .26426 L
.57143 .26426 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .26426 L
.57143 .26426 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .226 L
.80952 .226 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .226 L
.80952 .226 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .54156 L
.14286 .54156 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .54156 L
.14286 .54156 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .08823 L
.38095 .08823 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .08823 L
.38095 .08823 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .09223 L
.61905 .09223 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .09223 L
.61905 .09223 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .04922 L
.85714 .04922 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .04922 L
.85714 .04922 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .07573 L
.19048 .07573 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .07573 L
.19048 .07573 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .235 L
.42857 .235 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .235 L
.42857 .235 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .1985 L
.66667 .1985 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .1985 L
.66667 .1985 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .26201 L
.90476 .26201 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .26201 L
.90476 .26201 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .60332 L
.2381 .60332 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .60332 L
.2381 .60332 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .04447 L
.47619 .04447 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .04447 L
.47619 .04447 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .08573 L
.71429 .08573 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .08573 L
.71429 .08573 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .03772 L
.95238 .03772 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .03772 L
.95238 .03772 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l0
5_l00?lFoomo01Gooooo5Ooo000Fo`3o01Go003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5Ol00?lGoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0
5OoooolEool001Ko0?l05Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool001[ooooo0_l0
0007ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5Ooo000Fo`3o01Go003o5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000F
o`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lF
oomo01Gooooo5Ooo000Fo`3o01Go003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00
oaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5Ooo000Fo`3o01Go003o5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go
003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Go
oooo5Ooo000Fo`3o01Go003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolFool001Go0?l05_l00?lFoomo01Cooooo
5_oo000Eo`3o01Ko003o5_ooO`0EoooooaGoo`005_l0o`0Eo`00oaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5_oo
000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolEool001Ko0?l05Ol0
0?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lF
oomo01Gooooo5Ooo000Fo`3o01Go003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolFool001Go0?l05_l00?lFoomo
01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaGoo`005_l0o`0Eo`00oaOoogl05?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Co
oooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolEool001Ko
0?l05_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Eo`00oaOoogl05?oooolFool001Go0?l05_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o
5_ooO`0EoooooaGoo`005_l0o`0Fo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oo
oolFool001Go0?l05_l00?lFoomo01Gooooo5Ooo000Fo`3o01Ko003o:_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5_oo000E
o`3o01Oo003o:OoooolFool001Go0?l05_l00?lFoomo01Gooooo5Ooo000Fo`3o01Ko003o:_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo
01Cooooo5_oo000Eo`3o01Oo003o:OoooolFool001Go0?l05_l00?lFoomo01Gooooo5Ooo000Fo`3o
01Ko003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Eo`00oaOo
ogl05?oooolFool001Go0?l05ol00?lYoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool001Go
oooo5_l00?lYooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o
5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`00
5OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_oo
O`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000E
o`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00
obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKo
o`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o
5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`00
5OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_oo
O`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000E
o`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Go`00
obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaKo
o`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o
5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`00
5OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o01Cooooo5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_oo
O`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaKoo`005Ol0o`0Go`00obWooooo5_oo000E
o`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaKoo`005Ol0o`0Go`00
obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaKo
o`005Ol0o`0Go`00obWooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`005OoooolFo`00ob[o
oooo00?o0000ooooooooool02oooool002?ooooo0ol0000XoooooaOo0?l05?oooolGoomo01Cooooo
5_oo000Eo`3o01Oo003o:OoooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000EoooooaKo003o
:Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oo
oolFool001Go0?l05ol00?lYoooooaKoo`005Ol0o`0Go`00ob[ooooo5_oo000EoooooaKo003o:_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolG
oomo01Cooooo5ooo000DoooooaOo003o:OoooolFool001Go0?l05ol00?lZoooooaKoo`005OoooolF
o`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5_oo000Eo`3o01Oo003o:_oooolFool0
01Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[o
oooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo
5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo
000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lY
oooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000Doooo
oaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOo
o`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0
5?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o
:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oo
oolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005Ooo
oolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolG
o`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolF
ool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00
ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Co
oooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo
5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o0000:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo
000DoooooaOo003o:_oooolFool001Gooooo5_l00?lYooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000D
oooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooo
oaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo
003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`00
5?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oo
oolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolG
oomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolF
o`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool0
01Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[o
oooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo
5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo
000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lY
oooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000Doooo
oaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOo
o`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03
o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Ko
oooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWo
oooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool0
01Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00009ooooolGo`3o
01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool0
01Gooooo5_l00?lWooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool0
01Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000D
oooooaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oo
oolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool0:?oooolG
o`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolF
ool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00
ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Co
oooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo
5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol0
0?lYoooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000D
oooooaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0Doooo
oaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo
003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0
5?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo5ol00?lZoooooaKoo`00
5OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo000DoooooaOo003o:_oo
oolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`005?oooolG
o`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool0
01Cooooo5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?o
oooo0ol0000XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Co
oooo5ol00?lZoooooaKoo`005OoooolFo`00obWooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool001Cooooo
5ol00?lZoooooaKoo`005OoooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo
000DoooooaOo003o:_oooolFool001Gooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lY
oooooaOoo`005?oooolGo`00ob[ooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000Doooo
oaOo003o:OoooolGool005Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo
003o:OoooolGool005Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o
:OoooolGool005Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:Ooo
oolGool005Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolG
ool005Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool0
05Gooooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Go
oooo5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Gooooo
5_oo000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Gooooo5_oo
000EoooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Gooooo5_oo000E
oooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Gooooo5_oo000Eoooo
oaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:OoooolGool005Gooooo5_oo000EoooooaKo
003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5ol0o`0DoooooaOoogl0
5?oooolGool001Cooooo5ol00?lYoooooaOoo`00P?oooolFo`00obWooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo000DoooooaOo003o:Ooo
oolGool0083ooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`0DoooooaOoogl05?oooolGool001Cooooo5ol00?lYoooooaOoo`00P?oooolF
o`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`0DoooooaOoo`005?oooolGo`00obWooooo5ooo0020oooooaKo003o:_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Co
oooo5ooo001DoooooaOoo`00P?oooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`00E?oooolGool0083ooooo
5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0
o`0DoooooaOoogl05?oooolGool005Cooooo5ooo0020oooooaKo003o:_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo001D
oooooaOoo`00P?oooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolGo`3o01Cooooo5oooO`0DoooooaOoo`00E?oooolGool0083ooooo5_l00?lZoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl05?oooolGool005Cooooo5ooo0020oooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo01Cooooo5ooo001DoooooaOoo`00
P?oooolFo`00ob[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o01Cooooo5oooO`0DoooooaOoo`00E?oooolGool0083ooooo5_l00?lZooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0OooooolG
ool0083ooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`0DoooooaOoogl0OooooolGool0083ooooo5_l00?lZooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0OooooolGool0083o
oooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0OooooolGool0083ooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o0000:?oooolGo`3o01Cooooo5oooO`1ooooooaOoo`00_oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`?o00001_ooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?oooooo
Eoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool5o`0000Kooooo
1?l0000WoooooaOo0?l05?oooolGoomo0?ooooooE?ooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0XoooooaOo
0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0:?oooolGo`3o01Co
oooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002Oooool2o`0000Oooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOo
oooo00?o0000ooooooooool02oooool000kooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3o
oooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3o
oooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo0ol0000XoooooaOo0?l05?oooolGoomo0?ooooooE_ooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o0000:?oooolGo`3o01Cooooo5oooO`3ooooooeKooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?oooooo
Eoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oo
oolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?oooooo
Eoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oo
oolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?oooooo
Eoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oo
oolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0002Sooooo5ol0o`0DoooooaOoogl0oooooomFooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3o
oooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3o
oooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3o
oooooeOooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00007ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGoooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomG
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooo
oomGooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0007ooooo`Co00009ooooolGo`3o01Cooooo5oooO`3ooooooeCooooo1?l0000=ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?oo
oolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo5ol0
o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool2
o`0000Oooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooo
oeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Co
oooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooo
oeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Co
oooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooooeOooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Cooooo5oooO`3ooooo
oeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o01Co
oooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo0ol0000XoooooaOo0?l0
5?oooolGoomo0?ooooooE_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0
o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0
oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0
o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0
oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0
o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0oooooomGooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`0DoooooaOoogl0
oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolGo`3o01Cooooo5ooo
O`3ooooooeKooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolG
oomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolG
oomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolGoomo0?ooooooEooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l05?oooolG
oomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaOo0?l05?oooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0005?ooooo5oooO`3ooooooeKooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`1Coooo
oaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo05?o
oooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0
DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1CoooooaOo
ogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05?ooooo5oooO`3ooooo
oeOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool3o`00
00Oooooo1?l0001BoooooaOoogl0oooooomDooooo`Co00003Oooool000gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0DooooolG
oomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1CoooooaOoogl0oooo
oomGooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000
ooooooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0DooooolGoomo0?ooooooEoooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`1CoooooaOoogl0oooooomGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo05?ooooo5oooO`3ooooooeOooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02oooool002?o
ooooool00035o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo001Rooooo`?o0000Ioooool5
o`0006Oooooo0ol0001Zooooo`?o0000C?ooool006?ooooo00?o0000ooooooooool0Ioooool01?l0
003oooooooooool0001Vooooo`05o`000?ooooooooooooooool00000J_ooool00ol0003ooooooooo
o`1;ooooo`00Hoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0IOooool5o`0004cooooo001Sooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0Ioooool2o`0006Sooooo00Co0000oooooooooooo0000COooool006?ooooo00?o0000oooo
ooooool0I_ooool01Ol0003ooooooooooooooooo000006[ooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooo`00001=ooooo`00H_ooool2o`0006Sooooo00Go0000ooooooooooooooooo`00001V
ooooo`05o`000?ooooooooooooooool00000JOooool2o`0004gooooo001Sooooo`03o`000?oooooo
oooo06Oooooo0ol0001Xooooo`?o0000Joooool00ol0003oooooooooo`1;ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0662215, \
0.00931295, 0.00311264}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.688113 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15234 -18 -4.5 ]
[-0.0125 .15234 0 4.5 ]
[-0.0125 .28996 -18 -4.5 ]
[-0.0125 .28996 0 4.5 ]
[-0.0125 .42758 -18 -4.5 ]
[-0.0125 .42758 0 4.5 ]
[-0.0125 .56521 -18 -4.5 ]
[-0.0125 .56521 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15234 m
.00625 .15234 L
s
[(0.2)] -0.0125 .15234 1 0 Mshowa
0 .28996 m
.00625 .28996 L
s
[(0.4)] -0.0125 .28996 1 0 Mshowa
0 .42758 m
.00625 .42758 L
s
[(0.6)] -0.0125 .42758 1 0 Mshowa
0 .56521 m
.00625 .56521 L
s
[(0.8)] -0.0125 .56521 1 0 Mshowa
.125 Mabswid
0 .04912 m
.00375 .04912 L
s
0 .08353 m
.00375 .08353 L
s
0 .11793 m
.00375 .11793 L
s
0 .18674 m
.00375 .18674 L
s
0 .22115 m
.00375 .22115 L
s
0 .25555 m
.00375 .25555 L
s
0 .32437 m
.00375 .32437 L
s
0 .35877 m
.00375 .35877 L
s
0 .39318 m
.00375 .39318 L
s
0 .46199 m
.00375 .46199 L
s
0 .49639 m
.00375 .49639 L
s
0 .5308 m
.00375 .5308 L
s
0 .59961 m
.00375 .59961 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15234 m
1 .15234 L
s
.99375 .28996 m
1 .28996 L
s
.99375 .42758 m
1 .42758 L
s
.99375 .56521 m
1 .56521 L
s
.125 Mabswid
.99625 .04912 m
1 .04912 L
s
.99625 .08353 m
1 .08353 L
s
.99625 .11793 m
1 .11793 L
s
.99625 .18674 m
1 .18674 L
s
.99625 .22115 m
1 .22115 L
s
.99625 .25555 m
1 .25555 L
s
.99625 .32437 m
1 .32437 L
s
.99625 .35877 m
1 .35877 L
s
.99625 .39318 m
1 .39318 L
s
.99625 .46199 m
1 .46199 L
s
.99625 .49639 m
1 .49639 L
s
.99625 .5308 m
1 .5308 L
s
.99625 .59961 m
1 .59961 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .01472 L
.09524 .01472 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .36396 L
.33333 .36396 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .36396 L
.33333 .36396 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .07099 L
.57143 .07099 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .07099 L
.57143 .07099 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .2973 L
.80952 .2973 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .2973 L
.80952 .2973 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .5398 L
.14286 .5398 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .5398 L
.14286 .5398 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .0222 L
.38095 .0222 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .0222 L
.38095 .0222 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .16881 L
.61905 .16881 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .16881 L
.61905 .16881 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .01616 L
.85714 .01616 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .01616 L
.85714 .01616 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .60332 L
.19048 .60332 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .60332 L
.19048 .60332 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .01472 L
.42857 .01472 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .01472 L
.42857 .01472 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .11422 L
.66667 .11422 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .11422 L
.66667 .11422 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .07848 L
.2381 .07848 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .07848 L
.2381 .07848 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .1833 L
.47619 .1833 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .1833 L
.47619 .1833 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .41879 L
.71429 .41879 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .41879 L
.71429 .41879 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .0664 L
.95238 .0664 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .0664 L
.95238 .0664 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Eo`00oaOoogl05?oooolFool001Ko0?l05OoooolFoomo01Cooooo5_oo000Eo`3o01Ko003o
5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo
5_oo000Fo`3o01Gooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo
5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5_oo000Fo`3o01Gooooo5_ooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0D
oooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool0
02[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOo
ogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[o
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0D
oooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool0
02[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOo
ogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[o
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0D
oooooaKoo`005Ol0o`0Fo`00oaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo
01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0EoooooaKoo`00:_oooolGoomo01?ooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKo
ogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo
5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol0
0?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo
000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lF
oomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool0
01Go0?l05_l00?lFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKo
ogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo
5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol0
0?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo
000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolFool001Go0?l05_l00?lF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00
oaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKo
ogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl05Ooo
oolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl05OoooolF
ool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaGo0?l05_l00?lFoomo01Gooooo5_oo001Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003o:_oooolGool002[o
oooo5_ooO`0ZoooooaGo0?l05_l00?lFoomo01Gooooo5_oo001Dooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaGo0?l0
5_l00?lFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolEo`3o01Ko003o5_oo
O`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl05OoooolF
ool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaGo0?l05_l00?lFoomo01Gooooo5_oo001Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo000ZoooooaKoogl0:_oooolEo`3o01Ko003o5_ooO`0EoooooaKoo`00EOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl05OoooolFool005Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_oo
O`0ZoooooaGo0?l05_l00?lFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolE
o`3o01Ko003o5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00
oaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaGo0?l05_l00?lFoomo01Go
oooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolEo`3o01Ko003o5_ooO`0EoooooaKoo`00
EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo02[ooooo5Ol0o`0Fo`00oaKoogl05OoooolFool005Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0ZoooooaGo0?l05_l00?lFoomo01Gooooo5_oo001Eooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000Zoooo
oaKoogl0:_oooolEo`3o01Ko003o5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0002Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Go
oooo5_ooO`0EoooooaKoo`00E?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Gooooo5_ooO`0EoooooaKoo`00
EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolFool005Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000Zoooo
oaKoogl0:_oooolFo`3o01Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo02[o
oooo5_l0o`0EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaKo0?l0
5OoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Gooooo5_oo
O`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolF
ool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo001Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_oo
O`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000>
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Gooooo
5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00Gooooo1?l0000WoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolFool005;ooooo1?l0000=ooooo`003Ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo02[ooooo5_l0o`0EoooooaKo
ogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo001Eoooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Go
oooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0:_oooolFo`3o01Gooooo5_ooO`0EoooooaKoo`00
EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo02[ooooo5_l0o`0EoooooaKoogl05OoooolFool005Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0ZoooooaKo0?l05OoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000Zoooo
oaKoogl0:_oooolFo`3o01Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo05Go
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo05Gooooo5_ooO`0EoooooaKoo`00
EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo05Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolF
oomo05Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo05Gooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00:_oooolFoomo05Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo05Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0002Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Cooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Go
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolF
ool005Cooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Go
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo0ol0000X
oooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Dooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Go
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Go
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol00006ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo
5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool5o`0000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000WoooooaKo
0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Booooo`Co00003Oooool000gooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl05OoooolFool005Gooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Oooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003o
ooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo01Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`20oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Go
oooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o
0000ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolF
oomo07oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0
P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`20ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002Eoooo
oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_ooO`20oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00UOoooolFoomo083ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool009Gooooo5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo002EoooooaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0Ooooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo002EoooooaKoogl0P?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
UOoooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
e_oooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
e_oooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003oe_oooolFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo0ol0000XoooooaKo0?l05_l00?oFoooooaKoogl0Ooooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`Co00001oooool4o`0002Oooooo5_l0o`0Fo`00oooo
ooooJ_ooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooo
ooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolF
o`3o01Ko003ooooooom/ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oo
ooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002So
oooo5_l0o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o
0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007
ooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
00gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool4o`0003gooooo
5_l00?ooooooof[ooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00008ooooo`?o0000
1oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0?_oooolFo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wo
oooo0ol00007ooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00ooooooooKOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003ooooooom]
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_oooolFo`00oooo
ooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0noooooaKo003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000?_oooolFo`00ooooooooK?oo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo03kooooo5_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?oooooool00035o`0000gooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo001R
ooooo`?o0000Ioooool5o`0006Oooooo0ol0001Zooooo`?o0000C?ooool006?ooooo00?o0000oooo
ooooool0Ioooool01?l0003oooooooooool0001Vooooo`05o`000?ooooooooooooooool00000J_oo
ool00ol0003oooooooooo`1;ooooo`00Hoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0IOooool5o`0004cooooo001Sooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0Ioooool2o`0006Sooooo00Co0000oooooooooooo0000COooool0
06?ooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000006[ooooo00?o0000
ooooooooool0I_ooool00ol0003oooooo`00001=ooooo`00H_ooool2o`0006Sooooo00Go0000oooo
ooooooooooooo`00001Vooooo`05o`000?ooooooooooooooool00000JOooool2o`0004gooooo001S
ooooo`03o`000?oooooooooo06Oooooo0ol0001Xooooo`?o0000Joooool00ol0003oooooooooo`1;
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0685565, \
0.00931295, 0.00322239}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.614711 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13766 -18 -4.5 ]
[-0.0125 .13766 0 4.5 ]
[-0.0125 .2606 -18 -4.5 ]
[-0.0125 .2606 0 4.5 ]
[-0.0125 .38354 -18 -4.5 ]
[-0.0125 .38354 0 4.5 ]
[-0.0125 .50648 -18 -4.5 ]
[-0.0125 .50648 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13766 m
.00625 .13766 L
s
[(0.2)] -0.0125 .13766 1 0 Mshowa
0 .2606 m
.00625 .2606 L
s
[(0.4)] -0.0125 .2606 1 0 Mshowa
0 .38354 m
.00625 .38354 L
s
[(0.6)] -0.0125 .38354 1 0 Mshowa
0 .50648 m
.00625 .50648 L
s
[(0.8)] -0.0125 .50648 1 0 Mshowa
.125 Mabswid
0 .04545 m
.00375 .04545 L
s
0 .07619 m
.00375 .07619 L
s
0 .10692 m
.00375 .10692 L
s
0 .16839 m
.00375 .16839 L
s
0 .19913 m
.00375 .19913 L
s
0 .22986 m
.00375 .22986 L
s
0 .29134 m
.00375 .29134 L
s
0 .32207 m
.00375 .32207 L
s
0 .35281 m
.00375 .35281 L
s
0 .41428 m
.00375 .41428 L
s
0 .44501 m
.00375 .44501 L
s
0 .47575 m
.00375 .47575 L
s
0 .53722 m
.00375 .53722 L
s
0 .56796 m
.00375 .56796 L
s
0 .59869 m
.00375 .59869 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13766 m
1 .13766 L
s
.99375 .2606 m
1 .2606 L
s
.99375 .38354 m
1 .38354 L
s
.99375 .50648 m
1 .50648 L
s
.125 Mabswid
.99625 .04545 m
1 .04545 L
s
.99625 .07619 m
1 .07619 L
s
.99625 .10692 m
1 .10692 L
s
.99625 .16839 m
1 .16839 L
s
.99625 .19913 m
1 .19913 L
s
.99625 .22986 m
1 .22986 L
s
.99625 .29134 m
1 .29134 L
s
.99625 .32207 m
1 .32207 L
s
.99625 .35281 m
1 .35281 L
s
.99625 .41428 m
1 .41428 L
s
.99625 .44501 m
1 .44501 L
s
.99625 .47575 m
1 .47575 L
s
.99625 .53722 m
1 .53722 L
s
.99625 .56796 m
1 .56796 L
s
.99625 .59869 m
1 .59869 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .28658 L
.09524 .28658 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .28658 L
.09524 .28658 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .01536 L
.33333 .01536 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .01536 L
.33333 .01536 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .35692 L
.57143 .35692 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .35692 L
.57143 .35692 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .01472 L
.80952 .01472 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .01472 L
.38095 .01472 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .01472 L
.38095 .01472 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .04061 L
.61905 .04061 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .04061 L
.61905 .04061 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .01493 L
.85714 .01493 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .01493 L
.85714 .01493 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .55779 L
.19048 .55779 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .55779 L
.19048 .55779 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .01472 L
.42857 .01472 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .01472 L
.42857 .01472 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .08635 L
.66667 .08635 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .08635 L
.66667 .08635 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.90476 .01472 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .01493 L
.2381 .01493 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .01493 L
.2381 .01493 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .32153 L
.47619 .32153 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .32153 L
.47619 .32153 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .09951 L
.71429 .09951 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .09951 L
.71429 .09951 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .2376 L
.95238 .2376 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .2376 L
.95238 .2376 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`1EoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5_oo000Eo`3o01Ko003o
5_ooO`1EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o
0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolFool001Go0?l05_l0
0?lFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`1E
oooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
oaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0EOoooolGoomo
01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko
0?l05_l00?m[oooooaKoogl05?oooolFool001Go0?l05_l00?lFoomo05Gooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003o
JooooolFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`1EoooooaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0EOoooolGoomo01Cooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolF
ool001Go0?l05_l00?lFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5_oo000Eo`3o
01Ko003o5_ooO`1EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKo
ogl0EOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo05Gooooo
5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo
000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1EoooooaOoogl05?oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo5Ooo000Fo`3o01Ko003oJooooolF
oomo01Cooooo5ooo000DoooooaKo003o5_ooO`1EoooooaOoogl04oooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000Doooo
oaKo003o5_ooO`1EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKo
ogl0EOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo05Gooooo
5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo
000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1EoooooaOoogl05?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0F
o`00of_ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0EOoooolGoomo01Cooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooo
oaKoogl05?oooolGool001Cooooo5_l00?lFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Co
oooo5ooo000DoooooaKo003o5_ooO`1EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00
5?oooolFo`00oaKoogl0EOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l0
0?lFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1E
oooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
oaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0EOoooolGoomo
01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko
0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo05Gooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`?o00004ooooolEool001Ko0?l05_l00?m[oooooaKoogl0
5?oooolGool001Cooooo5_l00?lFoomo05Gooooo5oooO`0Cooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l0
0?lFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1E
oooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
oaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0EOoooolGoomo
01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko
0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo05Gooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003o
JooooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1EoooooaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`00:_oooolFoomo05Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo000Z
oooooaKoogl0EOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`1Eoooo
oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGo
o`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo05Gooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003o
JooooolFoomo01Cooooo5ooo000ZoooooaKoogl0EOoooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oo
oolGool002[ooooo5_ooO`1EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool0
01Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo
00_ooooo000Sooooo`?o00004ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Go
oooo5oooO`0Cooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo
002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
oooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooo
oaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOo
ogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`00
5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oo
oolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00
of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Go
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`00
0?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKo
ogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool4o`0001;ooooo5Ooo000Fo`3o01Ko
003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl04Oooool4o`0000gooooo000=ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0CoooooaGo
o`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool0
09Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo5Ooo000F
o`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;
ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o
01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOo
o`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooo
oolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool0
01Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Co
oooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l0
0?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002E
oooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo5Ooo000Fo`3o
01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl04oooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOo
ogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`00
5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oo
oolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00
of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Go
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0D
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o
01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOo
o`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooo
oolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0001?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl04oooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo
01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo
002EoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
oooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooo
oaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOo
ogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`00
5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oo
oolGool009Gooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00
of_ooooo5_ooO`0DoooooaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Go
oooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0001?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo
002EoooooaOoogl04oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000F
o`3o01Ko003oJooooolFoomo01Cooooo5ooo002EoooooaOoogl05?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0Doooo
oaOoo`00UOoooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool009Gooooo5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003o
JooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolF
oomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Co
oooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oJooooolFoomo01Cooooo5ooo
0030ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`?o00001_ooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_ooO`0D
oooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[
oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00001oooool5o`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[
oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00007ooooo`Co00004_oooolEool001Ko0?l05_l0
0?m[oooooaKoogl05?oooolGool00;gooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l0
0?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002Oooool2o`0000Oooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l0
0?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000kooooo0_l0000;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[
oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKo
ogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oo
oolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolE
ool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool0
0<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko
0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooo
oolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOoo`00_oooool2o`00
00gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0DoooooaOo
o`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`0D
oooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo
5_ooO`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo5ooo0030
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
of_ooooo5_ooO`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool00<3ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oJooooolFoomo01Cooooo
5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003oJooo
oolFoomo01Cooooo5ooo002oooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoo
oolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoo
oolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003oUOoooolGool00<3ooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?nEoooooaOoo`00_oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oiGooooo5ooo0030ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oiGooooo5ooo0030
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooo
oom]ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`Co00009ooooolFo`3o01Ko003ooooooomZooooo`Co00003Oooool000gooooo00Co
0000oooooooooooo00001oooool4o`0000Oooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0
o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0002Sooooo5_l0o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooo
oom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00ooooooooK?ooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00002?ooool3o`0000Oooooo1?l0000WoooooaKo0?l05_l00?oooooo
of[ooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooo
ooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolF
o`3o01Ko003ooooooom/ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oo
oolGo`3o0?ooooooPOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3o
oooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo
0ol0000XoooooaOo0?l0oooooon1ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo000Soooooooo0000aOl0000=ooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3
o`0004cooooo001Sooooo`03o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool0
1Ol0003ooooooooooooooooo000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<
ooooo`00Hoooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xoooo
o`04o`000?ooooooooooo`0004gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000oooo
ooooooooooooo`00001Zooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool0
06;ooooo0_l0001Xooooo`05o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooo
oooo000006Wooooo0_l0001=ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3
o`0006_ooooo00?o0000ooooooooool0Boooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0767428, \
0.00931295, 0.00360717}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.73453 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16162 -18 -4.5 ]
[-0.0125 .16162 0 4.5 ]
[-0.0125 .30853 -18 -4.5 ]
[-0.0125 .30853 0 4.5 ]
[-0.0125 .45543 -18 -4.5 ]
[-0.0125 .45543 0 4.5 ]
[-0.0125 .60234 -18 -4.5 ]
[-0.0125 .60234 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16162 m
.00625 .16162 L
s
[(0.2)] -0.0125 .16162 1 0 Mshowa
0 .30853 m
.00625 .30853 L
s
[(0.4)] -0.0125 .30853 1 0 Mshowa
0 .45543 m
.00625 .45543 L
s
[(0.6)] -0.0125 .45543 1 0 Mshowa
0 .60234 m
.00625 .60234 L
s
[(0.8)] -0.0125 .60234 1 0 Mshowa
.125 Mabswid
0 .05144 m
.00375 .05144 L
s
0 .08817 m
.00375 .08817 L
s
0 .12489 m
.00375 .12489 L
s
0 .19835 m
.00375 .19835 L
s
0 .23507 m
.00375 .23507 L
s
0 .2718 m
.00375 .2718 L
s
0 .34525 m
.00375 .34525 L
s
0 .38198 m
.00375 .38198 L
s
0 .41871 m
.00375 .41871 L
s
0 .49216 m
.00375 .49216 L
s
0 .52889 m
.00375 .52889 L
s
0 .56561 m
.00375 .56561 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16162 m
1 .16162 L
s
.99375 .30853 m
1 .30853 L
s
.99375 .45543 m
1 .45543 L
s
.99375 .60234 m
1 .60234 L
s
.125 Mabswid
.99625 .05144 m
1 .05144 L
s
.99625 .08817 m
1 .08817 L
s
.99625 .12489 m
1 .12489 L
s
.99625 .19835 m
1 .19835 L
s
.99625 .23507 m
1 .23507 L
s
.99625 .2718 m
1 .2718 L
s
.99625 .34525 m
1 .34525 L
s
.99625 .38198 m
1 .38198 L
s
.99625 .41871 m
1 .41871 L
s
.99625 .49216 m
1 .49216 L
s
.99625 .52889 m
1 .52889 L
s
.99625 .56561 m
1 .56561 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .19055 L
.09524 .19055 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .19055 L
.09524 .19055 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .04101 L
.33333 .04101 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .04101 L
.33333 .04101 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .53938 L
.57143 .53938 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .53938 L
.57143 .53938 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .02245 L
.80952 .02245 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .02245 L
.80952 .02245 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .04075 L
.38095 .04075 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .04075 L
.38095 .04075 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .13202 L
.61905 .13202 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .13202 L
.61905 .13202 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .01729 L
.85714 .01729 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .01729 L
.85714 .01729 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .16245 L
.19048 .16245 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .16245 L
.19048 .16245 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .15265 L
.42857 .15265 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .15265 L
.42857 .15265 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .29342 L
.66667 .29342 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .29342 L
.66667 .29342 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .18488 L
.90476 .18488 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .18488 L
.90476 .18488 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .04024 L
.2381 .04024 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .04024 L
.2381 .04024 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .33235 L
.47619 .33235 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .33235 L
.47619 .33235 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .24753 L
.71429 .24753 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .24753 L
.71429 .24753 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .17327 L
.95238 .17327 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .17327 L
.95238 .17327 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l0
5_l00?lFoomo01Gooooo5Ooo000Fo`3o01Go003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5Ol00?lGoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0
5OoooolFool001Gooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool001[ooooo0_l0
0007ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go003o5oooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo01Gooooo5_oo000EoooooaGo003o5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000F
o`3o01Go003o5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lF
oomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04ooooolEool001Ko0?l05Ol00?lGoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0Doooo
oaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Eo`00oaOoogl05?oooolFool001Go
0?l05_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go003o
5oooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo
5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
oolEool001Ko0?l05Ol00?lGoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0
o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0CoooooaGoo`005_l0o`0Eo`00oaOoogl05?oooolFool001Go0?l05_l00?lF
oomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Go003o5oooO`0Doooo
oaKoo`005Ol0o`0Fo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo
01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko
0?l05Ol00?lGoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKo
ogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0CoooooaGoo`005_l0o`0Fo`00ob[ooooo5_oo000Eo`3o01Ko003o5_ooO`0DoooooaKoo`00
5Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5_oo
000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolF
ool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_ooO`0Doooo
oaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0001?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolFool001Go
0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01?ooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o
5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolFool001Go0?l05_l0
0?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_ooO`0DoooooaKoo`005Ol0o`0F
o`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5_oo000Eo`3o
01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolFool001Go
0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_ooO`0DoooooaKoo`00
5Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5_oo
000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolF
ool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_ooO`0Doooo
oaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Co
oooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl0
5?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_oo
O`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lF
oomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00
oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo
003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo
5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00004ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_oo
O`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl04oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolF
ool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_ooO`0Doooo
oaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Co
oooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl0
5?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo003o5_oo
O`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo5_l00?lF
oomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00
oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo
003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo
5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoo
oolFo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mE
oooooaKo003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00
oeGooooo5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko
003oEOoooolFo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5_l00?mEoooooaKo003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0
o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004ooooolEool001Ko0?l05_l00?mE
oooooaKo003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl04oooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoooolFo`00
oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mEoooooaKo
003o5_ooO`0DoooooaKoo`005Ol0o`0Fo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00oeGooooo
5_l00?lFoomo01Cooooo5_oo000Eo`3o01Ko003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko003oEOoo
oolFo`00oaKoogl05?oooolFool001Go0?l05_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?mE
oooooaKo003o5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00
oeGooooo5_l00?lFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`10oooooaGo003o5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Fo`3o01Ko
003oEOoooolFo`00oaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol00?lGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5_l00?mEoooooaKo003o5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolEo`00oaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005_l0
o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`10oooooaGo003o5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000F
o`3o01Ko003oEOoooolFo`00oaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol00?lG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool0
01Ko0?l05_l00?mEoooooaKo003o5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolEo`00
oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGo
o`005_l0o`0Fo`00oeGooooo5_l00?lFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`10oooooaGo
003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Ko003oEOoooolFo`00oaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo
5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
oolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol0
0?lGoomo01Cooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00001_ooool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Fo`00of_ooooo5_oo
O`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolEo`00oaOoogl05?ooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool04ooooolEool001Ko0?l05_l00?m[oooooaKoogl05?oooolGool001Cooooo
5_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00004_oooolEool001Ko0?l0
5_l00?m[oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol00?lGoomo017ooooo
1?l0000=ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04ooooolEool001Oo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o
5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?o
oooo5Ooo000Go`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolEo`00oaOo
ogl05?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0CoooooaGoo`005ol0o`20oooo
oaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol00?lGoomo01Cooooo00?o0000oooo
ooooool02oooool000kooooo0_l00009ooooo`?o00001oooool00ol0003oooooooooo`0CoooooaGo
o`005ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo043ooooo5Ol00?lGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Oo0?l0
P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`10oooooaGo003o5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo5Ooo000Go`3o083ooooo5_oo
O`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolFo`00ob[ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04ooooolEool001Oo0?l0P?oooolFoomo01Cooooo5ooo000D
oooooaKo003o5_ooO`10oooooaKo003o:_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0CoooooaGoo`005ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo
043ooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo5Ooo000Go`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0@?oooolFo`00ob[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooooolEool001Oo0?l0
P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`10oooooaKo003o:_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0CoooooaGoo`005ol0o`20oooooaKoogl05?oo
oolGool001Cooooo5_l00?lFoomo043ooooo5_l00?lZooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo5Ooo000Go`3o083ooooo5_ooO`0DoooooaOoo`005?oooolF
o`00oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
oaGoo`005ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo083ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOo
o`005?oooolFo`00oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oo
oolGool001Cooooo5_l00?lFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000X
oooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1oooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00
oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo
5_l00?lFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0P?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000D
oooooaKo003o5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo083ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOo
o`005?oooolFo`00oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oo
oolGool001Cooooo5_l00?lFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0P?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo
01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo083o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo
5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20
oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo083ooooo00?o0000ooooooooool02oooool0
02?ooooo0ol0000XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`1ooooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOo
o`005?oooolFo`00oaKoogl0P?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oo
oolGool001Cooooo5_l00?lFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0P?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo
01Cooooo5ooo000DoooooaKo003o5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5_l00?lFoomo083o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo
5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0D
oooooaOoo`005?oooolGo`00oiGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOo
o`005?oooolGo`00oiGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oo
oolGo`00oiGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolG
o`3o083ooooo5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0DoooooaOoo`005?oooolGo`00
oiGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083o
oooo5_ooO`0DoooooaOoo`005?oooolGo`00oiGooooo00?o0000ooooooooool02oooool002?ooooo
0ol0000XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo000DoooooaOo003oU?ooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5ol0
0?nEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20
oooooaKoogl05?oooolGool001Cooooo5ol00?nEooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5ol00?nEoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKo
ogl05?oooolGool001Cooooo5ol00?nEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5ol00?nEooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oo
oolGool001Cooooo5ol00?nEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5ol00?nEooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool0
01Cooooo5ol00?nEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5ol0o`20oooooaKoogl05?oooolGool001Cooooo5ol00?nEooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_oo
O`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaOo0?l0P?oooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool00<3ooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03
o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool00<3ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool00<3ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool5o`0000Kooooo1?l0000WoooooaOo
0?l0P?oooolFoomo01Cooooo5ooo002mooooo`Co00003Oooool000gooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooo
oaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooo
oaKoogl05?oooolGool00<3ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00002Oooool2o`0000Oooooo00?o0000ooooooooool0:?oooolGo`3o083ooooo5_ooO`0Doooo
oaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo0030ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl0
5?oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o083ooooo5_ooO`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool0
0<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o083o
oooo5_ooO`0DoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0P?oooolFoomo01Cooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`20oooooaKoogl05?oooolGool00<3ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2Zoooo
oaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0002Sooooo5ol0o`2ZoooooaOoo`00_oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOo
o`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0
Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolGo`3o0:[ooooo5ooo002ooooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00
`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oo
oolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolG
o`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOo
o`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0
Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o0000:?oooolGo`3o0:[ooooo5ooo002oooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00
`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oo
oolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolG
o`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030oooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo
00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001oooool4o`0002Oooooo5ol0o`2Z
oooooaOoo`00_Oooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;
ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo02Sooooo5ol0o`2Zoooo
oaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo
0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2Z
oooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0002Sooooo5ol0o`2ZoooooaOoo`00_oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2Zoooo
oaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0Z_oooolGool00<3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0:[ooooo5ooo
0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2Z
oooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5ol0o`2Zoooo
oaOoo`00_oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`2ZoooooaOo
o`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0
Z_oooolGool00<3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolGo`3o0:[ooooo5ooo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5ol0o`2ZoooooaOoo`00`?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol0000XoooooaOo0?l0oooooon1ooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Oooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo02Sooooo5ol0o`3ooooooh;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002?ooool3o`0000Oooooo1?l0000WoooooaOo0?l0oooooomoooooo`Co00003Ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oo
oooo`Oooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;oooo
o`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool006;ooooo0ol0001W
ooooo`Go0000Ioooool3o`0006[ooooo0ol0001<ooooo`00Hoooool00ol0003oooooooooo`1Woooo
o`04o`000?ooooooooooo`0006Kooooo00Go0000ooooooooooooooooo`00001Zooooo`03o`000?oo
oooooooo04_ooooo001Sooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`1Uooooo`Go0000C?ooool006?ooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`1Wooooo`;o0000J?ooool01?l0003oooooooooool0001=ooooo`00Hoooool00ol0
003oooooooooo`1Vooooo`05o`000?ooooooooooooooool00000J_ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooo000004gooooo001Rooooo`;o0000J?ooool01Ol0003ooooooooooooooooo
000006Kooooo00Go0000ooooooooooooooooo`00001Yooooo`;o0000COooool006?ooooo00?o0000
ooooooooool0Ioooool3o`0006Sooooo0ol0001[ooooo`03o`000?oooooooooo04_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0642242, \
0.00931295, 0.00301876}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.238095 0.0147151 0.589846 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13268 -18 -4.5 ]
[-0.0125 .13268 0 4.5 ]
[-0.0125 .25065 -18 -4.5 ]
[-0.0125 .25065 0 4.5 ]
[-0.0125 .36862 -18 -4.5 ]
[-0.0125 .36862 0 4.5 ]
[-0.0125 .48659 -18 -4.5 ]
[-0.0125 .48659 0 4.5 ]
[-0.0125 .60456 -6 -4.5 ]
[-0.0125 .60456 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13268 m
.00625 .13268 L
s
[(0.2)] -0.0125 .13268 1 0 Mshowa
0 .25065 m
.00625 .25065 L
s
[(0.4)] -0.0125 .25065 1 0 Mshowa
0 .36862 m
.00625 .36862 L
s
[(0.6)] -0.0125 .36862 1 0 Mshowa
0 .48659 m
.00625 .48659 L
s
[(0.8)] -0.0125 .48659 1 0 Mshowa
0 .60456 m
.00625 .60456 L
s
[(1)] -0.0125 .60456 1 0 Mshowa
.125 Mabswid
0 .04421 m
.00375 .04421 L
s
0 .0737 m
.00375 .0737 L
s
0 .10319 m
.00375 .10319 L
s
0 .16218 m
.00375 .16218 L
s
0 .19167 m
.00375 .19167 L
s
0 .22116 m
.00375 .22116 L
s
0 .28015 m
.00375 .28015 L
s
0 .30964 m
.00375 .30964 L
s
0 .33913 m
.00375 .33913 L
s
0 .39812 m
.00375 .39812 L
s
0 .42761 m
.00375 .42761 L
s
0 .4571 m
.00375 .4571 L
s
0 .51608 m
.00375 .51608 L
s
0 .54558 m
.00375 .54558 L
s
0 .57507 m
.00375 .57507 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13268 m
1 .13268 L
s
.99375 .25065 m
1 .25065 L
s
.99375 .36862 m
1 .36862 L
s
.99375 .48659 m
1 .48659 L
s
.99375 .60456 m
1 .60456 L
s
.125 Mabswid
.99625 .04421 m
1 .04421 L
s
.99625 .0737 m
1 .0737 L
s
.99625 .10319 m
1 .10319 L
s
.99625 .16218 m
1 .16218 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .22116 m
1 .22116 L
s
.99625 .28015 m
1 .28015 L
s
.99625 .30964 m
1 .30964 L
s
.99625 .33913 m
1 .33913 L
s
.99625 .39812 m
1 .39812 L
s
.99625 .42761 m
1 .42761 L
s
.99625 .4571 m
1 .4571 L
s
.99625 .51608 m
1 .51608 L
s
.99625 .54558 m
1 .54558 L
s
.99625 .57507 m
1 .57507 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .02134 L
.09524 .02134 L
.09524 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .02134 L
.09524 .02134 L
.09524 .01472 L
.04762 .01472 L
s
.28571 .01472 m
.28571 .20125 L
.33333 .20125 L
.33333 .01472 L
F
.28571 .01472 m
.28571 .20125 L
.33333 .20125 L
.33333 .01472 L
.28571 .01472 L
s
.52381 .01472 m
.52381 .20974 L
.57143 .20974 L
.57143 .01472 L
F
.52381 .01472 m
.52381 .20974 L
.57143 .20974 L
.57143 .01472 L
.52381 .01472 L
s
.7619 .01472 m
.7619 .21637 L
.80952 .21637 L
.80952 .01472 L
F
.7619 .01472 m
.7619 .21637 L
.80952 .21637 L
.80952 .01472 L
.7619 .01472 L
s
0 1 0 r
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
F
.09524 .01472 m
.09524 .60332 L
.14286 .60332 L
.14286 .01472 L
.09524 .01472 L
s
.33333 .01472 m
.33333 .01534 L
.38095 .01534 L
.38095 .01472 L
F
.33333 .01472 m
.33333 .01534 L
.38095 .01534 L
.38095 .01472 L
.33333 .01472 L
s
.57143 .01472 m
.57143 .01513 L
.61905 .01513 L
.61905 .01472 L
F
.57143 .01472 m
.57143 .01513 L
.61905 .01513 L
.61905 .01472 L
.57143 .01472 L
s
.80952 .01472 m
.80952 .01492 L
.85714 .01492 L
.85714 .01472 L
F
.80952 .01472 m
.80952 .01492 L
.85714 .01492 L
.85714 .01472 L
.80952 .01472 L
s
0 0 1 r
.14286 .01472 m
.14286 .58117 L
.19048 .58117 L
.19048 .01472 L
F
.14286 .01472 m
.14286 .58117 L
.19048 .58117 L
.19048 .01472 L
.14286 .01472 L
s
.38095 .01472 m
.38095 .02465 L
.42857 .02465 L
.42857 .01472 L
F
.38095 .01472 m
.38095 .02465 L
.42857 .02465 L
.42857 .01472 L
.38095 .01472 L
s
.61905 .01472 m
.61905 .02507 L
.66667 .02507 L
.66667 .01472 L
F
.61905 .01472 m
.61905 .02507 L
.66667 .02507 L
.66667 .01472 L
.61905 .01472 L
s
.85714 .01472 m
.85714 .01782 L
.90476 .01782 L
.90476 .01472 L
F
.85714 .01472 m
.85714 .01782 L
.90476 .01782 L
.90476 .01472 L
.85714 .01472 L
s
1 .5 0 r
.19048 .01472 m
.19048 .0613 L
.2381 .0613 L
.2381 .01472 L
F
.19048 .01472 m
.19048 .0613 L
.2381 .0613 L
.2381 .01472 L
.19048 .01472 L
s
.42857 .01472 m
.42857 .22631 L
.47619 .22631 L
.47619 .01472 L
F
.42857 .01472 m
.42857 .22631 L
.47619 .22631 L
.47619 .01472 L
.42857 .01472 L
s
.66667 .01472 m
.66667 .23997 L
.71429 .23997 L
.71429 .01472 L
F
.66667 .01472 m
.66667 .23997 L
.71429 .23997 L
.71429 .01472 L
.66667 .01472 L
s
.90476 .01472 m
.90476 .12113 L
.95238 .12113 L
.95238 .01472 L
F
.90476 .01472 m
.90476 .12113 L
.95238 .12113 L
.95238 .01472 L
.90476 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00H_ooool3o`0006Oooooo1Ol0001Wooooo`?o0000J_ooool3o`0004cooooo001Sooooo`03
o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000I_ooool01Ol0003ooooooooooooooooo
000006[ooooo00?o0000ooooooooool0Boooool006?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo06Gooooo1Ol0001<ooooo`00Hoooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Oooooo0_l0001Xooooo`04o`000?ooooooooooo`00
04gooooo001Sooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Zoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool00000COooool006;ooooo0_l0001Xooooo`05
o`000?ooooooooooooooool00000I_ooool01Ol0003ooooooooooooooooo000006Wooooo0_l0001=
ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`?o0000J?ooool3o`0006_ooooo00?o0000oooo
ooooool0Boooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035o`0000gooooo000S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003oooooooooo`3ooooool7ooooo
00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co
0000oooooooooooo00001_oooolFo`0001Goo`005_l0o`0Eo`00oaOoogl05?l0000Fool001Go0?l0
5_l00?lFoomo01Co00005_oo000Eo`3o01Ko003o5_ooO`0Eo`0001Goo`005_l0o`0Eo`00oaOoogl0
5Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo
5Ooo000Fo`3o01Go003o5oooO`0DoooooaOoo`005?oooolFo`00oaKoogl05?oooolGool001Cooooo
5_l00?lFoomo01Gooooo5_oo000EoooooaGo003o5oooO`0Dooooo`03o`000?oooooooooo00_ooooo
000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04ooooolEool001Ko0?l0
5Ol00?lGoomo01Cooooo5ooo000DoooooaKo003o5_ooO`0DoooooaOoo`005?oooolFo`00oaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001ooo
ool00ol0003oooooooooo`0CoooooaGoo`005_l0o`0Eo`00oaOoogl05?oooolGool001Cooooo5_l0
0?lFoomo01Cooooo5ooo000DoooooaKo003o5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0D
oooooaOoo`005?oooolFo`00oaKoogl05?oooolGool001Cooooo5_l00?lFoomo01Gooooo5_oo000Z
oooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0Eoooo
oaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKo
ogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaOoo`00
:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oo
oolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool0
02[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Co
oooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o
5oooO`0DoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo
5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Go003o5ooo
O`0DoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5ooo
O`0Cooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0D
oooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0D
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00
oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000Zoooo
oaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKo
o`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl0
5OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oo
oolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05Ol00?lGoomo01Cooooo5ooo000ZoooooaKoogl05?oooolG
ool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Go003o5oooO`0DoooooaOoo`00:_oooolFoomo
01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Eo`00oaOoogl05?oooolGool002[o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003o:_oooolGool002[o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl04oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_oo
O`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000Zoooo
oaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolG
oomo01Cooooo00?o0000ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?lZoooo
oaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Coooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00
:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Dooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolG
ool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl05?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5oooO`0Doooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[o
oooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00:_oooolGoomo01Co
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo000ZoooooaOoogl0
5?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool002[ooooo5ooo
O`0Dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolG
ool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oo
oolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`Co00009ooo
oolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
001Booooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo
5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo
0ol00007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo
000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo001Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0Doooo
oaOoo`00:_oooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo
5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00
E?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo
000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolF
oomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0Doooo
oaOoo`00:_oooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[o
oooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl0
5OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo
001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooo
oaOoo`00:_oooolFoomo01Cooooo5ooo000ZoooooaKoogl05OoooolFool005Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[o
oooo5_ooO`0DoooooaOoo`00:_oooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo
000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00ob[o
oooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00E?ooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?lZoooooaOoo`00:_oooolFoomo01Cooooo5ooo
000ZoooooaKoogl05OoooolFool005Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003o:_oooolGool002[ooooo5_ooO`0DoooooaOoo`00:_oooolF
oomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ob[ooooo5ooo000ZoooooaKoogl05?oooolGool002[ooooo5_ooO`0Eoooo
oaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0
5?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_oo
O`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?m[oooooaKoogl05?oooolGool002[ooooo5_ooO`0EoooooaKoo`00EOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl0EOoooolFoomo01Gooooo5_oo001Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00of_ooooo5_ooO`1EoooooaKoogl05OoooolFool005Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
JooooolFoomo05Gooooo5_ooO`0EoooooaKoo`00EOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooooaKoogl0EOoooolFoomo083ooooo00?o
0000ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?m[oooooaKoogl0EOoooolF
oomo07oooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?m[oooo
oaKoogl0EOoooolFoomo083ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003oJooooolFoomo05Gooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_oo
O`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00omKooooo5_ooO`20ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oo
ooooofgooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol00006ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00006ooooo`Co00009ooooolFo`3o
01Ko003ooooooomZooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooo
oooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0o`0Fo`00ooooooooK?ooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0002Sooooo5_l0
o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
0000:?oooolFo`3o01Ko003ooooooom/ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooo
oom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`Co00009ooooolFo`3o01Ko003ooooooomZoooo
o`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Oooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
ooooooooKOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oooooo
ofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko
003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo
5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0002Sooooo5_l0o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003o
oooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0
o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0X
oooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`?o0000:?oooolFo`3o01Ko003ooooooom/ooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooo
oom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0F
o`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Xoooo
oaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgo
oooo00?o0000ooooooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo
0_l0000=ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00
ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo
0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo
00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0007ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0ol00007ooooo`Co00009ooooolFo`3o01Ko
003ooooooomZooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooo
ooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l0
5_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oo
oolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
02Sooooo5_l0o`0Fo`00ooooooooK?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00oooooooo
KOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l0
0?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolF
o`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o0000:?oooolFo`3o01Ko003ooooooom/ooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOoo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?oo
ooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o
01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02So
oooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000oooo
ooooool02oooool002?ooooo0ol0000XoooooaKo0?l05_l00?ooooooofcooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`0XoooooaKo0?l05_l00?ooooooofgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0:?oooolFo`3o01Ko003ooooooom]ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5_l0o`0Fo`00ooooooooKOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooooon2oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3ooooooh;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o0?oooooo
P_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo0?l0oooo
oon2ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo02Sooooo5ol0o`3o
oooooh;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0:?oooolGo`3o
0?ooooooP_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0XoooooaOo
0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00001oooool00ol0003ooooo
ooooo`0XoooooaOo0?l0oooooon2ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:?oooolGo`3o0?ooooooP_ooool00ol0003ooooooooo
o`0;ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo5ol0o`3o
oooooh;ooooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool01_ooool4o`00
0?oooooo_Oooool4o`0000gooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`;o00002?ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool006;ooooo0ol0001Wooooo`Go0000Ioooool3o`0006[ooooo0ol0001<ooooo`00Hoooool00ol0
003oooooooooo`1Wooooo`04o`000?ooooooooooo`0006Kooooo00Go0000ooooooooooooooooo`00
001Zooooo`03o`000?oooooooooo04_ooooo001Sooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`1Uooooo`Go0000C?ooool006?ooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`1Wooooo`;o0000J?ooool01?l0003oooooooooool0001=
ooooo`00Hoooool00ol0003oooooooooo`1Vooooo`05o`000?ooooooooooooooool00000J_ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooo000004gooooo001Rooooo`;o0000J?ooool01Ol0
003ooooooooooooooooo000006Kooooo00Go0000ooooooooooooooooo`00001Yooooo`;o0000COoo
ool006?ooooo00?o0000ooooooooool0Ioooool3o`0006Sooooo0ol0001[ooooo`03o`000?oooooo
oooo04_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.366938, -0.0799779, \
0.00931295, 0.00375923}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(230.496328`8.814209004601075\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .22631 L
.2381 .22631 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .22631 L
.2381 .22631 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01856 L
.47619 .01856 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01856 L
.47619 .01856 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .38505 L
.95238 .38505 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .38505 L
.95238 .38505 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF800000FF00FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF800000FF00FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF800000FF0000FF00
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF800000FF00FF0000FF8000FF8000
FF8000FF0000FF0000FF800000FF00
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF800000FF00FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF0000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF800000FF00FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF800000FF00FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF800000FF00FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF800000FF00FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF800000FF00FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF800000FF00FF8000FF8000FF0000FF8000
00FF0000FF00FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
00FF0000FF00FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00
FF8000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
00FF00FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .60573 L
.47619 .60573 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .60573 L
.47619 .60573 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .583 L
.47619 .583 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .583 L
.47619 .583 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .12828 L
.2381 .12828 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .12828 L
.2381 .12828 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .073 L
.47619 .073 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .073 L
.47619 .073 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .42864 L
.95238 .42864 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .42864 L
.95238 .42864 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000
FF8000FF800000FF0000FF0000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000
FF0000FF800000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF800000FF00FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF800000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF0000FF0000
FF800000FF0000FF00FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF800000FF0000FF00FF8000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF0000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF0000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00
FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF0000
FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF0000
FF0000FF8000FF0000FF8000FF8000
00FF00FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF800000FF00FF800000FF00FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF800000FF00FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF800000FF0000FF00FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
00FF00FF8000FF0000FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF8000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF0000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF800000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF0000FF00
00FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF00FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF00FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00FF800000FF00FF8000
FF800000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF0000FF8000FF8000FF0000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF800000FF0000FF00
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00
FF800000FF00FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF00
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000
FF8000FF000000FF00FF8000FF0000FF0000FF800000FF00FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF800000FF0000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF800000FF0000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF800000FF00
FF8000FF0000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF0000
FF8000FF800000FF00FF8000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF0000
FF0000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF800000FF00FF8000FF0000FF0000FF800000FF00FF0000FF8000FF8000FF8000
FF0000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF800000FF00FF8000FF8000FF0000FF800000FF0000FF00FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF800000FF00FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF8000
FF8000FF0000FF8000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF00FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000
00FF00FF800000FF0000FF0000FF0000FF00FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF800000FF0000FF00FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .44783 L
.2381 .44783 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .44783 L
.2381 .44783 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .12327 L
.47619 .12327 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .12327 L
.47619 .12327 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01898 L
.71429 .01898 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01898 L
.71429 .01898 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05173 L
.95238 .05173 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05173 L
.95238 .05173 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF000000FF00FF0000FF000000FF00FF00000000FFFF0000FF8000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
00FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FF0000FF
FF0000FF8000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF000000FF00FF00000000FFFF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF80000000FF0000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FF
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FF
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF8000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF80000000FFFF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF800000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF800000FF0000FF00FF0000
0000FFFF8000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF00FF0000
0000FFFF8000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF800000FF00
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF0000FF00FF0000
0000FFFF8000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF0000FF00FF0000
FF0000FF8000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
00FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF000000FF0000FF00
00FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF000000FF00FF0000FF000000FF00FF800000FF0000FF00FF000000FF00
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF000000FF00FF0000
00FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF0000
FF0000FF0000FF8000FF0000FF0000FF000000FF00FF000000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF000000FF00FF000000FF00
00FF00FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF000000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF8000
FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF800000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
00FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF8000
FF0000FF000000FF00FF0000FF0000
00FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
00FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .11785 L
.2381 .11785 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .11785 L
.2381 .11785 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .45743 L
.47619 .45743 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .45743 L
.47619 .45743 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02336 L
.71429 .02336 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02336 L
.71429 .02336 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04317 L
.95238 .04317 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04317 L
.95238 .04317 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
0000FFFF8000FF0000FF8000FF8000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
0000FFFF8000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF8000FF0000
0000FFFF8000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
0000FFFF8000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF000000FF00FF000000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
0000FFFF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF8000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF8000FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF8000FF0000
00FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF800000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF8000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF800000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF000000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF00FF800000FF0000FF00FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
FF800000FF00FF800000FF0000FF00FF00000000FF0000FF0000FFFF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00000000FFFF0000FF8000
FF8000FF0000FF800000FF0000FF00FF00000000FF0000FF0000FFFF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00000000FFFF0000FF8000
FF800000FF0000FF0000FF00FF000000FF000000FF0000FF0000FFFF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF8000
FF800000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000
FF800000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF800000FF0000FF00
FF000000FF00FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF000000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
00FF00FF0000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF8000FF8000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF800000FF0000FF00FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .26678 L
.2381 .26678 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .26678 L
.2381 .26678 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .14246 L
.47619 .14246 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .14246 L
.47619 .14246 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11326 L
.71429 .11326 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11326 L
.71429 .11326 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11931 L
.95238 .11931 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11931 L
.95238 .11931 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000
00FF0000FF00FF0000FF00000000FF0000FF0000FFFF8000FF800000FF00FF0000FF0000
FF00000000FF0000FFFF0000FF8000FF00000000FF0000FFFF80000000FF0000FFFF0000
FF80000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00000000FF0000FFFF8000FF0000
00FF00FF00000000FF0000FF0000FF0000FF0000FFFF8000FF000000FF0000FF00FF0000
FF00000000FF0000FFFF0000FF8000FF0000FF00000000FFFF8000FF0000FF8000FF0000
FF80000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF800000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF00FF0000FF000000FF0000FF00FF00000000FFFF0000
FF8000FF8000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF800000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF8000FF8000
FF8000FF800000FF0000FF0000FF00FF000000FF00FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF80000000FF
0000FFFF0000FF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
0000FF0000FFFF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FFFF0000FF8000FF8000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF800000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000
FF80000000FFFF000000FF00FF8000FF0000FF0000FF0000FF80000000FFFF8000FF0000
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF800000FF0000FF00
FF00000000FF0000FFFF0000FF8000FF00000000FFFF0000FF80000000FFFF8000FF8000
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF000000FF00FF800000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000FF0000
FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF00000000FF0000FFFF8000FF8000FF800000FF0000FF00
FF00000000FF0000FFFF8000FF8000FF0000FF0000FF0000FF80000000FFFF8000FF8000
FF000000FF00FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FFFF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF8000FF800000FF00FF0000FF00000000FF0000FFFF8000FF8000FF000000FF0000FF00
FF0000FF0000FF0000FF8000FF800000FF00FF0000FF00000000FF0000FFFF0000FF8000
00FF0000FF00FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FFFF0000FF800000FF00FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF0000FF800000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00000000FF
FF0000FF8000FF0000FF000000FF00FF00000000FF0000FF0000FFFF8000FF800000FF00
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF00000000FFFF0000FF8000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FFFF8000FF0000FF0000
FF000000FF00FF800000FF0000FF00FF0000FF0000FF0000FF8000FF00000000FFFF0000
FF0000FF8000FF0000FF000000FF00FF00000000FF0000FFFF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF000000FF00FF8000FF000000FF00FF0000FF00000000FFFF8000FF00000000FFFF0000
FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
00FF00FF0000FF0000FF0000FF8000
FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF000000FF00FF8000FF0000FF00000000FF0000FF0000FFFF8000FF0000FF0000FF0000
FF8000FF00000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
00FF00FF8000FF0000FF0000FF8000
FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF000000FF00FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF00000000FF
FF000000FF0000FF00FF000000FF00FF0000FF8000FF0000FF0000FF800000FF00FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF8000
0000FF0000FFFF0000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF8000FF000000FF00FF0000FF0000FF00000000FF0000FFFF8000FF8000
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF00000000FF
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000FF800000FF00FF0000
0000FFFF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF8000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
00FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF00000000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF00000000FFFF8000FF8000FF800000FF0000FF000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF8000FF800000FF0000FF00FF800000FF00FF0000FF00000000FFFF0000
FF0000FF8000FF00000000FF0000FF
00FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000
0000FFFF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF00000000FF
0000FFFF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FFFF0000FF8000FF800000FF0000FF000000FF0000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FFFF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF8000FF800000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
FF0000FF80000000FF0000FF0000FF
00FF00FF8000FF000000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FFFF0000FF0000FF800000FF0000FF000000FF0000FF0000FFFF8000FF8000
FF0000FF80000000FF0000FFFF8000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF000000FF0000FF0000FF00FF00000000FF
FF0000FF80000000FF0000FFFF8000
00FF00FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF800000FF00FF0000FF00000000FF0000FF
0000FFFF8000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF8000FF0000FF8000FF000000FF000000FF0000FF0000FFFF8000FF8000
FF0000FF80000000FF0000FFFF8000FF0000FF00000000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF000000FF0000FF00FF00000000FF
0000FF0000FF0000FF0000FFFF8000
00FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF800000FF00FF0000FF00000000FF0000FF
FF8000FF8000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
0000FFFF0000FF8000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF800000FF00FF0000FF0000FF00000000FF
FF8000FF8000FF0000FF800000FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF
FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF80000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF0000FF000000FF00FF800000FF00FF0000FF00000000FFFF0000FF8000
FF8000FF00000000FF0000FF0000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF8000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF800000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF800000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF8000
FF80000000FFFF00000000FF0000FF
FF800000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF80000000FF0000FF
0000FF0000FFFF0000FF800000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF800000FF00FF000000FF00FF000000FF000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FF
FF00000000FFFF8000FF000000FF0000FF00FF000000FF00FF00000000FF0000FF0000FF
FF80000000FFFF00000000FF0000FF
FF800000FF0000FF00FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000FF8000FF00000000FF
FF00000000FFFF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF0000FF00FF000000FF000000FF0000FFFF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF000000FF0000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF8000FF0000FF0000FF00000000FF
FF800000FF0000FF00FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF8000FF0000FF0000
0000FF0000FFFF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF8000FF8000FF000000FF00FF0000FF00000000FF0000FFFF8000FF8000
00FF00FF0000FF8000FF0000FF0000FF800000FF00FF000000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF8000FF00000000FF0000FF
FF8000FF0000FF00000000FF0000FF
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FFFF0000FF8000FF000000FF00FF8000FF0000FF0000
0000FF0000FFFF8000FF8000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
0000FFFF0000FF8000FF800000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
00FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF
FF8000FF0000FF00000000FF0000FF
FF8000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF00000000FFFF0000FF8000FF000000FF00FF8000FF0000FF0000
0000FF0000FFFF8000FF8000FF800000FF00FF0000FF000000FF0000FF00FF0000FF0000
0000FFFF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000
00FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF00000000FFFF0000FF8000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF80000000FF
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF800000FF0000FF000000FF
FF0000FF0000FF80000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF00000000FFFF0000FF80000000FFFF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FF0000FFFF8000FF80000000FF
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF800000FF0000FF000000FF
0000FFFF0000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF00000000FFFF0000FF80000000FFFF0000FF80000000FFFF0000
FF8000FF0000FF000000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FFFF800000FF0000FF00FF800000FF0000FF00FF000000FF00FF0000FF00000000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF
0000FF0000FFFF80000000FF0000FF
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF00000000FFFF0000FF80000000FFFF0000FF80000000FF0000FFFF80000000FFFF0000
FF8000FF8000FF800000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF80000000FF0000FFFF8000FF800000FF00FF80000000FF
0000FFFF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF80000000FF0000FF
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF00
FF00000000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF8000FF000000FF00FF00000000FF
0000FFFF800000FF0000FF00FF800000FF00FF0000FF000000FF00FF0000FF00000000FF
0000FFFF8000FF80000000FFFF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF00FF0000FF00000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .21609 L
.2381 .21609 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .21609 L
.2381 .21609 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0559 L
.47619 .0559 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0559 L
.47619 .0559 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11388 L
.71429 .11388 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11388 L
.71429 .11388 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .25593 L
.95238 .25593 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .25593 L
.95238 .25593 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF00000000FF0000FFFF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000
FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF0000FF80000000FFFF8000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF000000FF0000FF00
FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF0000
00FF00FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF00000000FFFF8000FF80000000FF
0000FFFF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF00FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF000000FF00FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF00000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000
FF8000FF0000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF000000FF00FF800000FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF00000000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF800000FF00FF00000000FF0000FFFF80000000FF0000FF0000FFFF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF800000FF00FF0000
0000FFFF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000
FF00000000FFFF0000FF0000FF000000FF00FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF800000FF00FF0000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF000000FF0000FF00FF0000FF0000
FF0000FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000FF8000
FF0000FF00000000FFFF0000FF8000FF000000FF00FF8000FF80000000FFFF8000FF8000
00FF00FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000
00FF00FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF00000000FF
0000FFFF8000FF8000FF0000FF0000FF000000FF00FF000000FF00FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000
FF00000000FFFF8000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF00000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF00FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF8000FF00000000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF00000000FF0000FFFF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000
FF0000FF80000000FF0000FFFF8000
00FF00FF0000FF0000FF000000FF00FF800000FF0000FF00FF0000FF80000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000
FF80000000FFFF8000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF0000FF8000FF80000000FFFF0000FF800000FF00FF8000FF8000
FF0000FF00000000FF0000FFFF8000
00FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF00000000FF0000FFFF8000
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF0000FF8000
FF80000000FF0000FF0000FFFF8000
00FF00FF8000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000
FF8000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF8000
FF80000000FF0000FFFF8000FF8000FF80000000FFFF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF80000000FFFF80000000FFFF0000FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF0000
0000FF0000FFFF80000000FF0000FF
FF0000FF8000FF00000000FFFF8000FF0000FF8000FF800000FF00FF0000FF800000FF00
00FF00FF800000FF00FF8000FF000000FF00FF000000FF00FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000
FF80000000FF0000FFFF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF0000
FF00000000FF0000FF0000FFFF80000000FFFF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF0000FF0000
FF80000000FFFF80000000FF0000FF
FF0000FF80000000FF0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000
FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF0000FF8000FF0000FF0000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF00000000FF
0000FF0000FFFF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF
FF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF800000FF00
FF0000FF80000000FFFF0000FF8000FF8000FF0000FF00000000FF0000FFFF8000FF8000
FF8000FF00000000FF0000FFFF8000FF8000FF8000FF000000FF00FF8000FF0000FF0000
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF00000000FF
0000FFFF8000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF00000000FF0000FFFF0000FF8000FF8000FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF00000000FF0000FFFF8000FF800000FF00FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF00000000FF
0000FFFF8000FF8000FF0000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF
FF0000FF0000FF8000FF000000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF
FF8000FF800000FF0000FF00FF8000FF0000FF0000FF800000FF0000FF0000FF0000FF00
FF8000FF00000000FFFF8000FF8000FF8000FF00000000FF0000FF0000FF0000FFFF8000
FF8000FF0000FF00000000FF0000FFFF8000FF800000FF00FF00000000FF0000FFFF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF00000000FF
0000FFFF8000FF800000FF0000FF00FF00000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF80000000FFFF0000FF800000FF0000FF0000FF00FF8000
FF8000FF00000000FFFF8000FF0000FF8000FF0000FF80000000FF0000FF0000FFFF8000
FF800000FF00FF00000000FF0000FFFF8000FF8000FF8000FF8000FF00000000FF0000FF
0000FFFF0000FF8000FF00000000FF0000FF0000FFFF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF800000FF0000FF0000FF00FF80000000FFFF0000FF800000FF00FF8000FF0000FF8000
FF8000FF00000000FFFF8000FF0000FF8000FF0000FF8000FF00000000FF0000FFFF8000
FF8000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF000000FF00FF8000FF000000FF00FF800000FF00
FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF00000000FFFF8000FF0000FF8000FF0000FF0000
FF0000FF800000FF0000FF000000FF0000FFFF8000FF800000FF00FF0000FF0000FF0000
FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF00000000FF0000FFFF8000
FF800000FF00FF00000000FF0000FFFF8000FF8000FF8000FF800000FF00FF00000000FF
0000FFFF0000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF000000FF00FF800000FF00
FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF800000FF000000FF0000FFFF0000FF800000FF00FF0000FF0000FF0000
FF8000FF00000000FF0000FFFF8000FF8000FF0000FF8000FF0000FF80000000FFFF8000
FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF80000000FFFF8000FF8000FF0000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF800000FF00FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF00000000FF0000FF0000FFFF8000FF0000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF00000000FF0000FFFF80000000FFFF8000FF8000FF0000FF8000FF8000
0000FFFF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000
00FF00FF800000FF000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF800000FF00FF00000000FF0000FFFF8000FF80000000FF0000FFFF0000
FF8000FF0000FF80000000FFFF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF8000
00FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00
00FF00FF0000FF8000FF8000FF8000
FF000000FF0000FF00FF00000000FFFF8000FF8000FF800000FF00FF0000FF8000FF8000
FF0000FF8000FF800000FF00FF0000FF00000000FFFF8000FF80000000FF0000FFFF0000
FF8000FF00000000FF0000FF0000FFFF8000FF00000000FF0000FFFF8000FF80000000FF
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF800000FF00FF0000FF80000000FFFF0000
FF8000FF8000FF8000FF0000FF0000FF800000FF00FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF80000000FF0000FFFF8000FF800000FF00FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF80000000FF0000FFFF8000
FF8000FF00000000FF0000FFFF0000FF8000FF00000000FF0000FFFF8000FF0000FF8000
0000FFFF8000FF8000FF00000000FFFF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF800000FF0000FF00FF80000000FFFF0000FF8000FF8000FF0000FF00000000FF0000FF
FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF0000
FF0000FF000000FF00FF8000FF00000000FFFF8000FF800000FF00FF00000000FF0000FF
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00FF0000FF80000000FF
FF8000FF8000FF0000FF0000FF0000
FF0000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF000000FF0000FF
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF00000000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF0000FF800000FF00FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF000000FF00FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FFFF0000
FF8000FF800000FF00FF0000FF8000FF0000FF8000FF0000FF8000FF00000000FFFF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF8000FF8000
FF0000FF8000FF800000FF0000FF00FF800000FF0000FF00FF0000FF0000FF8000FF8000
FF00000000FFFF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF8000FF000000FF00FF0000FF00000000FFFF8000
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF00FF0000FF800000FF00FF8000FF0000FF8000FF80000000FFFF0000
FF8000FF0000FF800000FF00FF0000FF0000FF8000FF00000000FF0000FFFF8000FF8000
FF0000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF8000
FF00000000FFFF8000FF8000FF000000FF00FF8000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF800000FF00FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF8000FF8000FF80000000FF0000FFFF8000FF0000FF0000FF00000000FFFF0000FF8000
00FF00FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF80000000FFFF0000
FF800000FF0000FF0000FF00FF0000FF0000FF8000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF8000FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000
FF8000FF8000FF0000FF800000FF0000FF00FF80000000FFFF8000FF0000FF8000FF0000
0000FFFF8000FF0000FF80000000FFFF80000000FFFF80000000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF80000000FF0000FF
FF8000FF0000FF800000FF00FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF0000FF800000FF0000FF00FF00000000FF0000FFFF0000FF80000000FF
0000FFFF8000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FFFF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
0000FFFF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
FF8000FF8000FF0000FF0000FF000000FF00FF0000FF80000000FFFF00000000FFFF8000
FF8000FF8000FF0000FF8000FF0000FF00000000FF0000FFFF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF800000FF00FF00000000FFFF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF00000000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
FF8000FF8000FF0000FF0000FF800000FF00FF0000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF00000000FF0000FF
FF0000FF80000000FFFF0000FF8000
FF0000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
FF800000FF0000FF00FF00000000FF0000FFFF8000FF80000000FFFF0000FF8000FF8000
0000FFFF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF80000000FF
FF0000FF80000000FFFF0000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
FF800000FF0000FF0000FF000000FF0000FF0000FFFF80000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF00000000FF
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF00000000FF0000FFFF8000
FF8000FF800000FF00FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF00000000FF
FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF800000FF000000FF0000FFFF8000FF8000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF000000FF0000FFFF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF800000FF00FF800000FF00FF0000FF0000FF00000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF0000FF800000FF00
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF8000
FF8000FF8000FF000000FF00FF0000FF800000FF0000FF00FF0000FF8000FF0000FF8000
FF0000FF80000000FFFF0000FF8000
FF0000FF800000FF0000FF00FF8000FF0000FF0000FF80000000FF0000FFFF8000FF0000
FF8000FF800000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF800000FF0000FF00FF8000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF000000FF0000FF00
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF800000FF0000FF00FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF0000FF0000FF00FF800000FF00FF80000000FF0000FF0000FFFF8000FF0000
0000FFFF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF00FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .4666 L
.2381 .4666 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .4666 L
.2381 .4666 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .14455 L
.47619 .14455 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .14455 L
.47619 .14455 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
00FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
00FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF8000FF8000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF8000FF8000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00
00FF0000FF00FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF000000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF8000FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
00FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
00FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
00FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00
FF0000FF000000FF0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .05319 L
.2381 .05319 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .05319 L
.2381 .05319 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .56443 L
.47619 .56443 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .56443 L
.47619 .56443 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .05819 L
.2381 .05819 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .05819 L
.2381 .05819 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .55984 L
.47619 .55984 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .55984 L
.47619 .55984 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01189 L
.95238 .01189 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .12932 L
.2381 .12932 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .12932 L
.2381 .12932 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .4883 L
.95238 .4883 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .4883 L
.95238 .4883 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .58633 L
.2381 .58633 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .58633 L
.2381 .58633 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02211 L
.2381 .02211 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02211 L
.2381 .02211 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .39881 L
.71429 .39881 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .39881 L
.71429 .39881 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .209 L
.95238 .209 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .209 L
.95238 .209 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF80000000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FFFF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF0000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .51896 L
.71429 .51896 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .51896 L
.71429 .51896 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09907 L
.95238 .09907 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09907 L
.95238 .09907 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FFFF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .14225 L
.2381 .14225 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .14225 L
.2381 .14225 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .10658 L
.71429 .10658 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .10658 L
.71429 .10658 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .38108 L
.95238 .38108 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .38108 L
.95238 .38108 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF80000000FFFF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000
0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF80000000FF0000FFFF80000000FF0000FFFF80000000FFFF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF80000000FF
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF80000000FF0000FFFF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF0000FF0000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000
FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF0000FF8000FF8000
0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FFFF8000FF8000FF0000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FFFF8000FF0000FF0000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF80000000FF0000FFFF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF0000
FF0000FF00000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF0000
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .39589 L
.2381 .39589 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .39589 L
.2381 .39589 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .21505 L
.71429 .21505 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .21505 L
.71429 .21505 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01898 L
.95238 .01898 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01898 L
.95238 .01898 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FF
0000FFFF00000000FFFF0000FF8000FF8000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FF
0000FFFF00000000FFFF0000FF8000FF80000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FF
0000FF0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000
0000FF0000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
0000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FF
0000FFFF0000FF0000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF80000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FFFF0000
0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF8000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF80000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF80000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FF0000FFFF0000
FF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FF
FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000
FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF80000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF80000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF0000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF80000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
0000FFFF00000000FF0000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF80000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF8000FF0000FF8000FF80000000FF
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .15915 L
.2381 .15915 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .15915 L
.2381 .15915 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .06069 L
.71429 .06069 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .06069 L
.71429 .06069 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .41008 L
.95238 .41008 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .41008 L
.95238 .41008 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF80000000FFFF8000FF0000FF00000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF8000FF8000
FF80000000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000
FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000
FF0000FF00000000FF0000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF8000FF00000000FFFF0000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF00000000FFFF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF00000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF00000000FFFF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF8000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF00000000FF
FF0000FF0000FF80000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF80000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF80000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF80000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF00000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
0000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000
0000FFFF8000FF80000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
0000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000
0000FFFF80000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FFFF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF0000FF0000
FF0000FF80000000FFFF0000FF00000000FF0000FFFF00000000FFFF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF00000000FF0000FFFF00000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
0000FFFF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .33332 L
.2381 .33332 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .33332 L
.2381 .33332 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .17834 L
.71429 .17834 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .17834 L
.71429 .17834 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11826 L
.95238 .11826 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11826 L
.95238 .11826 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF8000FF8000FF8000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF00000000FFFF00000000FF0000FF
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF8000
FF8000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FFFF8000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FFFF0000
FF8000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF0000
FF8000FF80000000FF0000FFFF00000000FF0000FF0000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF80000000FFFF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF
FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF00000000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF80000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF0000FFFF00000000FF0000FF
FF0000FF00000000FFFF0000FF00000000FFFF0000FF80000000FF0000FFFF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000
0000FF0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FF
0000FFFF0000FF00000000FFFF0000FF00000000FFFF8000FF8000FF80000000FFFF0000
FF00000000FFFF00000000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF
FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000
FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF80000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF8000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FF
FF00000000FFFF00000000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF00000000FFFF00000000FF0000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF00000000FF
FF00000000FFFF00000000FF0000FF
FF00000000FFFF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF0000FFFF0000
FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000
FF00000000FFFF0000FF8000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FFFF8000FF8000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000
FF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF80000000FFFF0000FF00000000FF
FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
0000FFFF00000000FF0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF80000000FFFF00000000FF0000FF0000FFFF0000FF00000000FFFF8000FF80000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF80000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF00000000FF
0000FFFF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF8000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF0000
0000FFFF0000FF0000FF00000000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000
FF80000000FFFF0000FF0000FF00000000FFFF8000FF80000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF0000
FF00000000FF0000FFFF00000000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
0000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000
FF00000000FFFF0000FF00000000FF
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FFFF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF80000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF8000FF8000FF80000000FF
FF0000FF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF80000000FFFF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF80000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF8000FF00000000FF
FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF00000000FF0000FFFF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF8000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF8000
FF8000FF8000FF80000000FFFF0000FF00000000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF8000FF80000000FF
FF0000FF00000000FFFF00000000FF0000FFFF00000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF8000
FF8000FF8000FF80000000FFFF0000FF00000000FF0000FF0000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF8000FF8000FF80000000FF
FF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF8000
FF8000FF8000FF80000000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF00000000FF0000FFFF00000000FF0000FFFF00000000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF8000FF8000FF8000FF80000000FF
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FF
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF00000000FFFF0000FF00000000FF0000FF0000FFFF00000000FF
0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF8000FF80000000FF0000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF8000FF8000FF80000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .05193 L
.2381 .05193 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .05193 L
.2381 .05193 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01856 L
.71429 .01856 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01856 L
.71429 .01856 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .55943 L
.95238 .55943 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .55943 L
.95238 .55943 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF00000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
0000FFFF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF00000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF0000FF00000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .58925 L
.2381 .58925 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .58925 L
.2381 .58925 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02836 L
.95238 .02836 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02836 L
.95238 .02836 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .05673 L
.2381 .05673 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .05673 L
.2381 .05673 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .55046 L
.71429 .55046 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .55046 L
.71429 .55046 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02273 L
.95238 .02273 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02273 L
.95238 .02273 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF00000000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FFFF00000000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF00000000FFFF0000FF8000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF8000
FF0000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FF0000FFFF00000000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF00000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF00000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01856 L
.2381 .01856 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01856 L
.2381 .01856 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .59405 L
.71429 .59405 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .59405 L
.71429 .59405 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01731 L
.95238 .01731 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01731 L
.95238 .01731 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FFFF00000000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .2382 L
.2381 .2382 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .2382 L
.2381 .2382 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .07092 L
.71429 .07092 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .07092 L
.71429 .07092 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .3208 L
.95238 .3208 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .3208 L
.95238 .3208 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
0000FFFF0000FF0000FF8000FF80000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FF
0000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF0000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF8000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF00000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF0000
FF8000FF8000FF00000000FF0000FFFF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF
0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF00000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000
0000FFFF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF00000000FFFF00000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF00000000FFFF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF0000FF00000000FFFF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF0000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
FF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF00000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF80000000FF0000FF0000FFFF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolGo`00o`Cooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo0004oooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
001oo`00O`03o`00OaKoo`00>_l007lGoomo00Co001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go
001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go
001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o05?o001o5oooO`04
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?o
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o05?o001o5oooO`04o`00O`03o`00
0?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo05?ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo05?ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
001oo`00O`1^o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
og;o00009ooooomao`0002OoooooLOl0000Wooooog;o00008oooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool001Kooooo0P3oP0020?l000D0oh000P3o00030?n000H0o`000`3oP0020?l0
00L0oh000P3o00050?n000@0o`001@3oP0040?l000D0oh00103o00050?n00080o`001`3oP0020?l0
00D0oh00103o00040?n000<0o`00103oP0020?l000<0oh00103o00030?n00080o`001@3oP0040?l0
00@0oh001@3o00040?n000030?l0003oP000oh000080oh003_oooon:003o00koooooRP00o`0>oooo
o`80oh000`3o00040?n00080o`001`3oP0020?l000`0oh000P3o000=0?n000<0o`000P3oP0040?l0
00030?n0003o0000o`0000H0oh000`3o000>0?n00080o`00103oP0020?l000`0oh000P3o00040?n0
00030?l0003oP000oh000080oh000P3o00050?n00080o`000`3oP0020?l00080oh000P3o00050?n0
0080o`006?ooool001Kooooo0P3oP0020?l000D0oh000P3o00030?n000H0o`000`3oP0020?l000L0
oh000P3o00050?n000@0o`001@3oP0040?l000D0oh00103o00050?n00080o`001`3oP0020?l000D0
oh00103o00040?n000<0o`00103oP0020?l000<0oh00103o00030?n00080o`001@3oP0040?l000@0
oh001@3o00040?n000030?l0003oP000oh000080oh003_oooon:003o00koooooRP00o`0>ooooo`80
oh000`3o00040?n00080o`001`3oP0020?l000`0oh000P3o000=0?n000<0o`000P3oP0040?l00003
0?n0003o0000o`0000H0oh000`3o000>0?n00080o`00103oP0020?l000`0oh000P3o00040?n00003
0?l0003oP000oh000080oh000P3o00050?n00080o`000`3oP0020?l00080oh000P3o00050?n00080
o`006?ooool001Kooooo103oP0000`3o0000oh000?n000020?n00080o`001`3oP0020?l000D0oh00
0P3o00050?n000@0o`001@3oP0020?l000L0oh000P3o00050?n000H0o`000`3oP0040?l000D0oh00
103o00050?n000@0o`000`3oP0040?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh00
0P3o00050?n000@0o`001@3oP0040?l000D0oh000P3o00020?n000koooooRP00o`0>ooooofP00?l0
0P3oP00E003o00H0oh001@00o`0>ooooo`@0oh0000<0o`000?n0003oP000103oP0020?l000D0oh00
0P3o00020?n000030?l0003oP000oh0000h0oh000P3o00070?n00080o`003`3oP0000`3o0000oh00
0?n000020?l000<0oh000P3o00040?n00080o`001`3oP0030?l000/0oh000P3o00040?n000030?l0
003oP000oh0000@0oh0000<0o`000?n0003oP0000P3oP0020?l000L0oh00103o00030?n00080o`00
6?ooool001Kooooo103oP0000`3o0000oh000?n000020?n00080o`001`3oP0020?l000D0oh000P3o
00050?n000@0o`001@3oP0020?l000L0oh000P3o00050?n000H0o`000`3oP0040?l000D0oh00103o
00050?n000@0o`000`3oP0040?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o
00050?n000@0o`001@3oP0040?l000D0oh000P3o00020?n000koooooRP00o`0>ooooofP00?l00P3o
P00E003o00H0oh001@00o`0>ooooo`@0oh0000<0o`000?n0003oP000103oP0020?l000D0oh000P3o
00020?n000030?l0003oP000oh0000h0oh000P3o00070?n00080o`003`3oP0000`3o0000oh000?n0
00020?l000<0oh000P3o00040?n00080o`001`3oP0030?l000/0oh000P3o00040?n000030?l0003o
P000oh0000@0oh0000<0o`000?n0003oP0000P3oP0020?l000L0oh00103o00030?n00080o`006?oo
ool001Kooooo0P3o00020?n000<0o`00103oP0020?l000D0oh00103o00030?n000@0o`001@3oP004
0?l000<0oh00103o00050?n000@0o`001@3oP0060?l000<0oh00103o00050?n000@0o`001@3oP002
0?l000D0oh000P3o00040?n000030?l0003oP000oh0000L0oh000P3o00070?n000@0o`000`3oP006
0?l000<0oh000P00o`020?n000koooooRP00o`0>oooooc000?l00P3o00040?n004800?l00P3oP003
0?l000@0oh002@00o`0>ooooo`@0oh001@00o`020?n00080o`00403oP0000`3o0000oh000?n00004
0?n000800?l00`3oP002003o00L0oh000P3o000B0?n00080o`00303oP002003o0080oh000`3o000;
0?n00080o`001@3oP0020?l000@0oh000`3o00040?n00080o`0000<0oh000?l0003o0000103oP002
0?l000<0oh000P3o000Hooooo`005_ooool20?l000<0oh000P3o00040?n000<0o`001P3oP0030?l0
00@0oh000`3o00060?n00080o`001@3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0020?l0
00L0oh00103o00030?n000@0o`001@3oP0050?l000@0oh00103o00030?n000@0o`000`3oP0020?l0
00@0oh000P3o00030?n00080o`000P3oP0000`00o`00oh000?n000020?n00080o`001@3oP0060?l0
00030?n00000o`000?l00080oh003_oooomj003o0080oh003P00o`0>oooooa000?l01`3oP00I003o
00@0oh007@00o`030?n002@00?l0103oP0030?l00080oh002@00o`0>ooooo`80o`000P3oP005003o
00@0oh0000<0o`000?n0003oP0001`3oP0020?l00100oh000P3o00090?n00080o`001@3oP004003o
00X0oh001000o`050?n00080o`001P3oP0000`3o0000oh000?n000020?l000D0oh000P3o00020?n0
0080o`000`3oP0020?l00080oh000P00o`000`3oP000o`000?l000040?n00080o`0000<0oh000?l0
003o00001P3oP0000`3o0000oh000?n000020?l001Sooooo000Fooooo`80o`000`3oP0020?l000@0
oh000`3o00060?n000<0o`00103oP0030?l000H0oh000P3o00050?n00080o`000P3oP0000`3o0000
oh000?n000020?n00080o`001`3oP0040?l000<0oh00103o00050?n000D0o`00103oP0040?l000<0
oh00103o00030?n00080o`00103oP0020?l000<0oh000P3o00020?n00003003o003oP000oh000080
oh000P3o00050?n000H0o`0000<0oh00003o0000o`000P3oP00>ooooogX00?l00P3oP00>003o00ko
oooo4000o`070?n001T00?l0103oP00M003o00<0oh009000o`040?n000<0o`000P3oP009003o00ko
oooo0P3o00020?n000D00?l0103oP0000`3o0000oh000?n000070?n00080o`00403oP0020?l000T0
oh000P3o00050?n000@00?l02P3oP004003o00D0oh000P3o00060?n000030?l0003oP000oh000080
o`001@3oP0020?l00080oh000P3o00030?n00080o`000P3oP002003o00030?n0003o0000o`0000@0
oh000P3o00000`3oP000o`000?l000060?n000030?l0003oP000oh000080o`006?ooool001Kooooo
0P3oP0020?l000<0oh000P3o00040?n000<0o`001P3oP0000`3o0000oh000?n000020?n000D0o`00
103oP0030?l000P0oh0000<0o`000?n0003oP000103oP0020?l000L0oh000P3o00070?n000030?l0
003oP000oh0000@0oh000`3o00060?n00080o`001@3oP0020?l000<0oh000P3o00040?n00080o`00
0`3oP0020?l00100oh00103o00000`3oP0000?l0003o0002003o00koooooRP00o`0>oooooaH00?l0
00<0oh00003o0000o`002`00o`030?n000/00?l00P3oP00B003o0080oh0000<00?l00?n0003oP000
1000o`020?n00003003o003oP000oh0002P00?l000<0oh000?l0003o00000P3oP009003o00kooooo
103o000:0?n00080o`001`3oP002003o0080oh000P00o`000`3oP0000?l0003o00020?n000800?l0
1`3oP0020?l000L0oh000P3o000<0?n00080o`000P3oP0020?l000`0oh000P3o00070?n00080o`00
1`3oP0040?l000D0oh000P00o`020?l000<0oh000P3o000B0?n001Sooooo000Fooooo`80oh000P3o
00030?n00080o`00103oP0030?l000H0oh0000<0o`000?n0003oP0000P3oP0050?l000@0oh000`3o
00080?n000030?l0003oP000oh0000@0oh000P3o00070?n00080o`001`3oP0000`3o0000oh000?n0
00040?n000<0o`001P3oP0020?l000D0oh000P3o00030?n00080o`00103oP0020?l000<0oh000P3o
000@0?n000@0o`0000<0oh00003o0000o`000P00o`0>ooooohX00?l03_oooolF003o00030?n00000
o`000?l000/00?l00`3oP00;003o0080oh004P00o`020?n00003003o003oP000oh0000@00?l00P3o
P0000`00o`00oh000?n0000X003o00030?n0003o0000o`000080oh002@00o`0>ooooo`@0o`002P3o
P0020?l000L0oh000P00o`020?n000800?l000<0oh00003o0000o`000P3oP002003o00L0oh000P3o
00070?n00080o`00303oP0020?l00080oh000P3o000<0?n00080o`001`3oP0020?l000L0oh00103o
00050?n000800?l00P3o00030?n00080o`004P3oP00Hooooo`005_ooool20?n000<0o`00103oP002
0?l000D0oh000P3o00040?n000<0o`00103oP0050?l000@0oh000`3o00060?n000<0o`001P3oP003
0?l000H0oh0000<0o`000?n0003oP000103oP0030?l000H0oh000`3o00040?n000<0o`00103oP004
0?l000<0oh000P3o00040?n000030?l0003oP000oh000080oh001@3o00040?n000800?l000<0o`00
0?n0003oP000103oP0030?l00080oh000P00o`0>ooooohX00?l03_oooom;003o00@0oh000P3o0003
0?n002/00?l00P3oP009003o00kooooo0P3oP0020?l000030?n0003o0000o`0000L0oh000P3o000D
0?n000<0o`001P3oP0020?l000L0oh001@3o00090?n00080o`000`3oP0020?l00180oh00103o0003
0?n000800?l00P3oP0040?l000030?n00000o`000?l000800?l00P3oP0000`3o0000oh000?n00004
0?l000L0oh000P3o00020?n000030?l0003oP000oh000080oh006?ooool001Kooooo0P3oP0030?l0
00@0oh000P3o00050?n00080o`00103oP0030?l000@0oh001@3o00040?n000<0o`001P3oP0030?l0
00H0oh000`3o00060?n000030?l0003oP000oh0000@0oh000`3o00060?n000<0o`00103oP0030?l0
00@0oh00103o00030?n00080o`00103oP0000`3o0000oh000?n000020?n000D0o`00103oP002003o
00030?l0003oP000oh0000@0oh000`3o00020?n000800?l03_oooon:003o00koooooB`00o`040?n0
0080o`000`3oP00[003o0080oh002@00o`0>ooooo`80oh000P3o00000`3oP000o`000?l000070?n0
0080o`00503oP0030?l000H0oh000P3o00070?n000D0o`002@3oP0020?l000<0oh000P3o000B0?n0
00@0o`000`3oP002003o0080oh00103o00000`3oP0000?l0003o0002003o0080oh0000<0o`000?n0
003oP000103o00070?n00080o`000P3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`@0
oh0000<0o`000?n0003oP0000P3oP0040?l000D0oh000P3o00050?n00080o`001@3oP0020?l000D0
oh000P3o00070?n000@0o`001@3oP0040?l000@0oh001@3o00030?n000@0o`00103oP0030?l000H0
oh0000<0o`000?n0003oP000103oP0020?l000<0oh000P3o00040?n000030?l0003oP000oh0000@0
oh000`3o00060?n000<0o`00103oP002003o00030?l0003oP000oh000080oh003_oooon:003o00ko
ooooB`00o`040?n00080o`000`3oP00H003o00030?n00000o`000?l001/00?l03_ooool40?l000<0
oh000P3o00070?n00080o`000P3oP0020?l000L0oh000`3o00040?n000D0o`00103oP0020?l000T0
oh000`3o00060?n000030?l0003oP000oh000080oh000P3o00030?n00080o`00103oP0000`3o0000
oh000?n000090?n000@0o`000`3oP002003o00T0oh000P00o`070?n00080o`000P3oP003003o0080
oh000P3o00070?n001Sooooo000Fooooo`80o`000`3oP0020?l000@0oh000P3o00050?n000@0o`00
1@3oP0020?l000D0oh000P3o00050?n000@0o`001@3oP0040?l000D0oh00103o00030?n000@0o`00
1@3oP0020?l000D0oh00103o00050?n00080o`00103oP0030?l000@0oh000P3o00030?n00080o`00
103oP0030?l000H0oh000`3o00070?n000@0o`003_oooon:003o00koooooB`00o`040?n00080o`00
0`3oP00f003o00kooooo0P3o00050?n00080o`003P3oP0020?l00080oh000P00o`000`3oP000o`00
0?l000070?n00080o`002@3oP002003o00D0oh000P3o000;0?n00080o`001@3oP0020?l000<0oh00
0P3o00090?n00080o`00103oP0000`00o`00oh000?n000070?n00080o`00103oP0030?l000H0oh00
0`00o`0;0?n001Sooooo000Fooooo`80o`000`3oP0020?l000@0oh000P3o00050?n000@0o`001@3o
P0020?l000D0oh000P3o00050?n000@0o`001@3oP0040?l000D0oh00103o00030?n000@0o`001@3o
P0020?l000D0oh00103o00050?n00080o`00103oP0030?l000@0oh000P3o00030?n00080o`00103o
P0030?l000H0oh000`3o00070?n000@0o`003_oooon:003o00koooooB`00o`040?n00080o`000`3o
P00f003o00kooooo0P3o00050?n00080o`003P3oP0020?l00080oh000P00o`000`3oP000o`000?l0
00070?n00080o`002@3oP002003o00D0oh000P3o000;0?n00080o`001@3oP0020?l000<0oh000P3o
00090?n00080o`00103oP0000`00o`00oh000?n000070?n00080o`00103oP0030?l000H0oh000`00
o`0;0?n001Sooooo000Fooooo`80o`000`3oP0020?l000@0oh000`3o00060?n000<0o`00103oP003
0?l000H0oh000`3o00060?n00080o`001@3oP0020?l000L0oh00103o00030?n000@0o`000`3oP004
0?l000D0oh00103o00050?n00080o`00103oP0000`3o0000oh000?n000020?n00080o`000`3oP002
0?l000D0oh00103o00050?n000@0o`001`3oP0020?l000koooooRP00o`0>ooooob/00?l00P3oP00<
003o0080o`00103oP00:003o0080oh000P00o`020?n00080o`000`3oP00f003o00kooooo0P3oP002
0?l000X0oh000P00o`070?n00080o`001@3oP0040?l000D0oh000P3o00040?n00080o`000`3oP002
003o00L0oh000P3o00040?n000030?l0003oP000oh000080oh000P3o00050?n000@0o`002@3oP000
0`3o0000oh000?n000060?n00003003o003oP000oh0000@0oh000P3o00080?n00080o`000P3oP009
003o00T0oh006?ooool001Kooooo0P3o00030?n00080o`00103oP0030?l000H0oh000`3o00040?n0
00<0o`001P3oP0030?l000H0oh000P3o00050?n00080o`001`3oP0040?l000<0oh00103o00030?n0
00@0o`001@3oP0040?l000D0oh000P3o00040?n000030?l0003oP000oh000080oh000P3o00030?n0
0080o`001@3oP0040?l000D0oh00103o00070?n00080o`003_oooon:003o00kooooo:`00o`020?n0
00`00?l00P3o00040?n000X00?l00P3oP002003o0080oh000P3o00030?n003H00?l03_ooool20?n0
0080o`002P3oP002003o00L0oh000P3o00050?n000@0o`001@3oP0020?l000@0oh000P3o00030?n0
00800?l01`3oP0020?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000D0oh00103o00090?n0
00030?l0003oP000oh0000H0oh0000<00?l00?n0003oP000103oP0020?l000P0oh000P3o00020?n0
00T00?l02@3oP00Hooooo`005_ooool20?n00080o`000`3oP0020?l000@0oh000`3o00060?n00003
0?l0003oP000oh0000@0oh000`3o00060?n000<0o`00103oP0030?l000H0oh000`3o00060?n00080
o`001@3oP0030?l000@0oh000P3o00030?n000800?l00P3oP0040?l000<0oh000P3o00040?n000<0
o`00103oP0020?l000<0oh000P3o00050?n00080o`001@3oP0060?l000D0oh000P3o000>ooooohX0
0?l03_oooom=003o00L0oh00=P00o`0>ooooo`80oh000P3o00030?n000800?l00P3oP005003o0080
oh000P3o000I0?n00080o`001`3oP0020?l000<0oh000P3o00040?n000030?l0003oP000oh0000@0
oh0000<0o`000?n0003oP0001`3oP0020?l000H0oh0000<0o`000?n0003oP0001P3oP0000`00o`00
oh000?n000060?n000030?l0003oP000oh000080oh000P00o`050?n00080o`000P3oP00<003o0080
oh006?ooool001Kooooo0P3oP0020?l000<0oh000P3o00040?n000<0o`001P3oP0000`3o0000oh00
0?n000040?n000<0o`001P3oP0030?l000@0oh000`3o00060?n000<0o`001P3oP0020?l000D0oh00
0`3o00040?n00080o`000`3oP002003o0080oh00103o00030?n00080o`00103oP0030?l000@0oh00
0P3o00030?n00080o`001@3oP0020?l000D0oh001P3o00050?n00080o`003_oooon:003o00kooooo
C@00o`070?n003H00?l03_ooool20?n00080o`000`3oP002003o0080oh001@00o`020?n00080o`00
6@3oP0020?l000L0oh000P3o00030?n00080o`00103oP0000`3o0000oh000?n000040?n000030?l0
003oP000oh0000L0oh000P3o00060?n000030?l0003oP000oh0000H0oh0000<00?l00?n0003oP000
1P3oP0000`3o0000oh000?n000020?n000800?l01@3oP0020?l00080oh003000o`020?n001Sooooo
000Fooooo`80oh000P3o00050?n00080o`001@3oP0020?l000@0oh000`3o00050?n000@0o`00103o
P0030?l000H0oh0000<0o`000?n0003oP0001P3oP0030?l000H0oh0000<0o`000?n0003oP000103o
P0000`3o0000oh000?n000040?n000<0o`001P3oP0020?l000D0oh000P3o00030?n00080o`00103o
P0020?l000<0oh00103o00050?n000@00?l01@3oP0020?l00080oh0000<00?l00?n0003oP0000P3o
P00>ooooohX00?l03_oooon:003o00kooooo103oP0000`3o0000oh000?n000060?n000<00?l00P3o
P0020?l000<0oh001000o`050?n00080o`000P3oP0020?l000<0oh000P3o00020?n00080o`000`3o
P0020?l000@0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000040?n000030?l0003o
P000oh0000H0oh0000<0o`000?n0003oP0000P3o00090?n000D00?l0203oP0000`3o0000oh000?n0
00020?n000800?l00`3oP0020?l00080oh000`00o`020?n000800?l0103oP003003o0080oh006?oo
ool001Kooooo0P3oP0020?l000D0oh000P3o00050?n00080o`00103oP0030?l000D0oh00103o0004
0?n000<0o`001P3oP0000`3o0000oh000?n000060?n000<0o`001P3oP0000`3o0000oh000?n00004
0?n000030?l0003oP000oh0000@0oh000`3o00060?n00080o`001@3oP0020?l000<0oh000P3o0004
0?n00080o`000`3oP0040?l000D0oh001000o`050?n00080o`000P3oP0000`00o`00oh000?n00002
0?n000koooooRP00o`0>ooooohX00?l03_ooool40?n000030?l0003oP000oh0000H0oh000`00o`02
0?n00080o`000`3oP004003o00D0oh000P3o00020?n00080o`000`3oP0020?l00080oh000P3o0003
0?n00080o`00103oP0000`3o0000oh000?n000060?n000030?l0003oP000oh0000@0oh0000<0o`00
0?n0003oP0001P3oP0000`3o0000oh000?n000020?l000T0oh001@00o`080?n000030?l0003oP000
oh000080oh000P00o`030?n00080o`000P3oP003003o0080oh000P00o`040?n000<00?l00P3oP00H
ooooo`005_ooool40?n000030?l0003oP000oh000080oh00103o00050?n00080o`000`3oP0040?l0
00D0oh00103o00030?n000@0o`00103oP0030?l000L0oh00103o00040?n000<0o`00103oP0030?l0
00H0oh000`3o00060?n000030?l0003oP000oh000080oh000P3o00030?n00080o`00103oP0030?l0
00@0oh000`3o00080?n000030?l0003oP000oh0000@0oh000P3o00030?n00080o`003_oooon:003o
00koooooAP00o`020?n004800?l03_ooool40?n000030?l0003oP000oh0000800?l0103oP003003o
00L0oh001000o`0@0?n00080o`000P3oP0000`3o0000oh000?n000020?l000@0oh0000<0o`000?n0
003oP0000P3oP0020?l000X0oh000P3o000;0?n00080o`001@3oP0020?l000D0oh000P3o00060?n0
00030?l0003oP000oh000080oh000`00o`080?n00003003o003oP000oh0000800?l0103oP0000`00
o`00oh000?n000020?n001Sooooo000Fooooo`80o`000P3oP0030?l000@0oh000P3o00050?n000@0
o`000`3oP0040?l000D0oh000P00o`050?n000@0o`000`3oP0040?l000D0oh00103o00050?n00080
o`001@3oP0040?l000D0oh00103o00040?n000<0o`00103oP0020?l000<0oh000P3o00040?n000<0
o`00103oP0000`3o0000oh000?n000060?n000030?l0003oP000oh0000@0oh000P00o`000`3o0000
oh000?n000020?l000koooooRP00o`0>ooooohP00?l00P3oP00>ooooo`@0oh0000<0o`000?n0003o
P0001P3oP0000`00o`00o`000?l000040?n00080o`0000<0oh00003o0000o`00103oP0000`3o0000
oh000?n0000=0?n00080o`002@3oP0030?l000h0oh000P3o000I0?n00080o`001P3oP0000`3o0000
oh000?n000040?n00003003o003oP000oh0000@0oh000`00o`020?n000@0o`000P3oP0000`3o0000
oh000?n000020?n001Sooooo000Fooooo`80o`000P3oP0030?l000@0oh000P3o00050?n000@0o`00
0`3oP0040?l000D0oh000P00o`050?n000@0o`000`3oP0040?l000D0oh00103o00050?n00080o`00
1@3oP0040?l000D0oh00103o00040?n000<0o`00103oP0020?l000<0oh000P3o00040?n000<0o`00
103oP0000`3o0000oh000?n000060?n000030?l0003oP000oh0000@0oh000P00o`000`3o0000oh00
0?n000020?l000koooooRP00o`0>ooooohP00?l00P3oP00>ooooo`@0oh0000<0o`000?n0003oP000
1P3oP0000`00o`00o`000?l000040?n00080o`0000<0oh00003o0000o`00103oP0000`3o0000oh00
0?n0000=0?n00080o`002@3oP0030?l000h0oh000P3o000I0?n00080o`001P3oP0000`3o0000oh00
0?n000040?n00003003o003oP000oh0000@0oh000`00o`020?n000@0o`000P3oP0000`3o0000oh00
0?n000020?n001Sooooo000Fooooo`80o`000`3oP0020?l000@0oh001@3o00040?n000<0o`00103o
P0030?l000P0oh0000<0o`000?n0003oP0000P3oP0020?l000D0oh00103o00050?n000@0o`000`3o
P0040?l000D0oh000P3o00050?n000@0o`001@3oP0020?l000@0oh000P3o00030?n00080o`001@3o
P0020?l000@0oh000`3o00070?n00080o`00103oP002003o00030?n0003o0000o`000080o`003_oo
oon:003o00koooooRP00o`0>ooooo`800?l00P3oP0000`3o0000oh000?n000020?n00080o`001@3o
P0020?l000D0oh000P00o`020?n000800?l000<0o`000?n0003oP000103oP0020?l000L0oh000P3o
00050?n00080o`000P3oP0000`3o0000oh000?n000020?n00080o`000`3oP0020?l000L0oh000P3o
00050?n000@0o`002@3oP0020?l000<0oh000P3o00060?n000<0o`001@3oP0020?l000@0oh000`00
o`020?n000@0o`001`3oP00Hooooo`005_ooool20?l000<0oh000P3o00040?n000D0o`00103oP003
0?l000@0oh000`3o00080?n000030?l0003oP000oh000080oh000P3o00050?n000@0o`001@3oP004
0?l000<0oh00103o00050?n00080o`001@3oP0040?l000D0oh000P3o00040?n00080o`000`3oP002
0?l000D0oh000P3o00040?n000<0o`001`3oP0020?l000@0oh000P00o`000`3oP000o`000?l00002
0?l000koooooRP00o`0>ooooohX00?l03_ooool2003o0080oh0000<0o`000?n0003oP0000P3oP002
0?l000D0oh000P3o00050?n000800?l00P3oP002003o00030?l0003oP000oh0000@0oh000P3o0007
0?n00080o`001@3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o0007
0?n00080o`001@3oP0040?l000T0oh000P3o00030?n00080o`001P3oP0030?l000D0oh000P3o0004
0?n000<00?l00P3oP0040?l000L0oh006?ooool001Kooooo0P3o00050?n00080o`00103oP0030?l0
00H0oh0000<0o`000?n0003oP000103oP0030?l000H0oh000`3o00040?n00080o`001@3oP0040?l0
00D0oh00103o00030?n000@0o`000`3oP0040?l000D0oh00103o00050?n00080o`00103oP0000`3o
0000oh000?n000020?n00080o`000`3oP0020?l000D0oh00103o00050?n000@0o`001`3oP0020?l0
00koooooRP00o`0>oooooe@00?l00P3oP00d003o00kooooo0P3o00020?n000030?l0003oP000oh00
00T0oh00103o00050?n000@00?l01`3oP0020?l000030?n00000o`000?l000@0oh000P3o00090?n0
00<0o`002@3oP0020?l000D0oh000P3o00050?n00080o`001`3oP0020?l00080oh000P3o00030?n0
00@0o`001@3oP0020?l000D0oh00103o00020?n000<00?l0103oP0020?l000L0oh006?ooool001Ko
oooo0P3o00050?n00080o`00103oP0030?l000H0oh0000<0o`000?n0003oP000103oP0030?l000H0
oh000`3o00040?n00080o`001@3oP0040?l000D0oh00103o00030?n000@0o`000`3oP0040?l000D0
oh00103o00050?n00080o`00103oP0000`3o0000oh000?n000020?n00080o`000`3oP0020?l000D0
oh00103o00050?n000@0o`001`3oP0020?l000koooooRP00o`0>oooooe@00?l00P3oP00d003o00ko
oooo0P3o00020?n000030?l0003oP000oh0000T0oh00103o00050?n000@00?l01`3oP0020?l00003
0?n00000o`000?l000@0oh000P3o00090?n000<0o`002@3oP0020?l000D0oh000P3o00050?n00080
o`001`3oP0020?l00080oh000P3o00030?n000@0o`001@3oP0020?l000D0oh00103o00020?n000<0
0?l0103oP0020?l000L0oh006?ooool001Kooooo0P3oP0020?l000D0oh000P3o00050?n00080o`00
1@3oP0020?l000D0oh00103o00040?n000<0o`00103oP0030?l000H0oh000`3o00060?n00080o`00
1@3oP0030?l000@0oh00103o00050?n000@0o`000`3oP0020?l000@0oh000`3o00070?n000@0o`00
1@3oP0040?l000<0oh00103o00070?n00080o`003_oooon:003o00koooooD@00o`000`3oP000o`00
0?l000020?n003@00?l03_ooool2003o00<0oh000P3o000=0?n00080o`001@3oP0020?l000T0oh00
00<00?l00?n0003oP0001P3oP0000`3o0000oh000?n000070?n00080o`00103oP003003o0080oh00
0P3o00020?n00003003o003oP000oh0000@0oh001@00o`070?n000800?l0103oP0020?l000030?n0
003o0000o`0000@0o`001`3oP0020?l000030?n0003o0000o`000080o`002@3oP0020?l000L0oh00
6?ooool001Kooooo0P3oP0020?l000D0oh000P3o00050?n00080o`001@3oP0020?l000D0oh00103o
00040?n000<0o`00103oP0030?l000H0oh000`3o00060?n00080o`001@3oP0030?l000@0oh00103o
00050?n000@0o`000`3oP0020?l000@0oh000`3o00070?n000@0o`001@3oP0040?l000<0oh00103o
00070?n00080o`003_oooon:003o00koooooD@00o`000`3oP000o`000?l000020?n003@00?l03_oo
ool2003o00<0oh000P3o000=0?n00080o`001@3oP0020?l000T0oh0000<00?l00?n0003oP0001P3o
P0000`3o0000oh000?n000070?n00080o`00103oP003003o0080oh000P3o00020?n00003003o003o
P000oh0000@0oh001@00o`070?n000800?l0103oP0020?l000030?n0003o0000o`0000@0o`001`3o
P0020?l000030?n0003o0000o`000080o`002@3oP0020?l000L0oh006?ooool001Kooooo103oP000
0`3o0000oh000?n000020?n000@0o`001@3oP0020?l000D0oh000P3o00050?n00080o`001@3oP004
0?l000@0oh000`3o00040?n000<0o`00203oP0000`3o0000oh000?n000040?n000030?l0003oP000
oh0000@0oh000`3o00060?n000<0o`00103oP0020?l000<0oh000P3o00040?n00080o`000`3oP002
0?l000D0oh00103o00050?n000H0o`000`3oP0020?l000koooooRP00o`0>ooooof<00?l000<0oh00
003o0000o`009000o`0>ooooo`@00?l02P3oP002003o00@0oh000P3o00050?n00080o`002@3oP000
0`00o`00oh000?n000090?n00080o`001@3oP0020?l000@0oh001`00o`020?n000<00?l00P3oP002
0?l000<0oh000P00o`0@0?n00080o`00103oP0020?l000<0oh000P00o`050?n00080o`001@3oP002
003o00L0oh000P3o00020?n001Sooooo000Fooooo`@0oh0000<0o`000?n0003oP000103oP0030?l0
00H0oh000P3o00050?n00080o`001@3oP002003o00D0oh000P3o00050?n000@0o`00103oP0030?l0
00H0oh000`3o00050?n00080o`001P3oP0030?l000H0oh0000<0o`000?n0003oP0000P3oP0020?l0
00<0oh000P3o00040?n00080o`000`3oP0040?l000D0oh00103o00070?n00080o`001@3oP00>oooo
ohX00?l03_ooool9003o0080oh007000o`040?n00080o`000P3oP01K003o00kooooo1@00o`0A0?n0
00030?l0003oP000oh000080oh000`3o00040?n00080o`000P3oP0000`00o`00oh000?n000040?n0
0080o`001@3oP0020?l000T0oh000`00o`040?n00080o`001@3oP0020?l000<0oh000P00o`040?n0
00D00?l01`3oP0020?l001@0oh000P3o00000`3oP0000?l0003o0007003o0080oh000P00o`0Hoooo
o`005_ooool40?n000030?l0003oP000oh0000@0oh000`3o00060?n00080o`001@3oP0020?l000D0
oh000P00o`050?n00080o`001@3oP0040?l000@0oh000`3o00060?n000<0o`001@3oP0020?l000H0
oh000`3o00060?n000030?l0003oP000oh000080oh000P3o00030?n00080o`00103oP0020?l000<0
oh00103o00050?n000@0o`001`3oP0020?l000D0oh003_oooon:003o00kooooo2@00o`020?n001`0
0?l0103oP0020?l00080oh00F`00o`0>ooooo`D00?l04@3oP0000`3o0000oh000?n000020?n000<0
o`00103oP0020?l00080oh0000<00?l00?n0003oP000103oP0020?l000D0oh000P3o00090?n000<0
0?l0103oP0020?l000D0oh000P3o00030?n000800?l0103oP005003o00L0oh000P3o000D0?n00080
o`0000<0oh00003o0000o`001`00o`020?n000800?l06?ooool001Kooooo0P3o00030?n00080o`00
1P3oP0030?l000@0oh000`3o00040?n000<0o`00103oP0020?l000D0oh00103o00050?n00080o`00
103oP0050?l000D0oh00103o00030?n000@0o`001@3oP0040?l000@0oh0000<0o`000?n0003oP000
103oP0020?l000<0oh000P3o00040?n000030?l0003oP000oh000080oh000`3o00060?n000<0o`00
203oP0000`3o0000oh000?n000020?n000koooooIP00o`020?n002800?l03_oooolW003o00P0oh00
00<00?l00?n0003oP0006@00o`020?n003@00?l00P3oP007003o00kooooo1@00o`020?l000H0oh00
00<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000040?n000030?l0003oP000oh000080oh00
0P00o`090?n00080o`002@3oP0000`3o0000oh000?n000040?n00080o`001@3oP0020?l000L0oh00
0P3o00070?n000D00?l00P3oP0020?l000<0oh00103o00020?n000<0o`001`3oP00=003o00T0oh00
6?ooool001Kooooo0P3o00030?n00080o`001P3oP0030?l000@0oh000`3o00040?n000<0o`00103o
P0020?l000D0oh00103o00050?n00080o`00103oP0050?l000D0oh00103o00030?n000@0o`001@3o
P0040?l000@0oh0000<0o`000?n0003oP000103oP0020?l000<0oh000P3o00040?n000030?l0003o
P000oh000080oh000`3o00060?n000<0o`00203oP0000`3o0000oh000?n000020?n000koooooIP00
o`020?n002800?l03_oooolW003o00P0oh0000<00?l00?n0003oP0006@00o`020?n003@00?l00P3o
P007003o00kooooo1@00o`020?l000H0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n0
00040?n000030?l0003oP000oh000080oh000P00o`090?n00080o`002@3oP0000`3o0000oh000?n0
00040?n00080o`001@3oP0020?l000L0oh000P3o00070?n000D00?l00P3oP0020?l000<0oh00103o
00020?n000<0o`001`3oP00=003o00T0oh006?ooool001Kooooo0P3o00050?n00080o`001@3oP004
0?l000@0oh0000<0o`000?n0003oP000103oP0030?l000@0oh000`3o00040?n00080o`001@3oP002
0?l000D0oh001P3o00050?n00080o`001@3oP0040?l000D0oh00103o00030?n00080o`00103oP002
0?l000<0oh000P3o00040?n000030?l0003oP000oh0000@0oh000`3o00060?n000<0o`001P3oP000
0`3o0000oh000?n000020?n000koooooRP00o`0>ooooobT00?l0103oP01D003o0080oh001`00o`0>
ooooo`@00?l000<0oh000?l0003o00000P3o00050?n00080o`003@3oP0000`3o0000oh000?n00006
0?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0001P3oP0030?l000@0oh001@3o0004
0?n000030?l0003oP000oh0000H0oh0000<00?l00?n0003oP0001P3oP003003o0080oh000P3o0003
0?n000@0o`001@3oP0020?l000@0oh001@00o`020?n000L00?l00P3oP0020?l000D0oh006?ooool0
01Kooooo0P3o00050?n00080o`001@3oP0040?l000@0oh0000<0o`000?n0003oP000103oP0030?l0
00@0oh000`3o00040?n00080o`001@3oP0020?l000D0oh001P3o00050?n00080o`001@3oP0040?l0
00D0oh00103o00030?n00080o`00103oP0020?l000<0oh000P3o00040?n000030?l0003oP000oh00
00@0oh000`3o00060?n000<0o`001P3oP0000`3o0000oh000?n000020?n000koooooRP00o`0>oooo
obT00?l0103oP01D003o0080oh001`00o`0>ooooo`@00?l000<0oh000?l0003o00000P3o00050?n0
0080o`003@3oP0000`3o0000oh000?n000060?n000030?l0003oP000oh0000H0oh0000<0o`000?n0
003oP0001P3oP0030?l000@0oh001@3o00040?n000030?l0003oP000oh0000H0oh0000<00?l00?n0
003oP0001P3oP003003o0080oh000P3o00030?n000@0o`001@3oP0020?l000@0oh001@00o`020?n0
00L00?l00P3oP0020?l000D0oh006?ooool001Kooooo0P3oP0020?l000D0oh000P3o00050?n00080
o`00103oP0030?l000D0oh000P3o00060?n000<0o`00103oP0030?l000@0oh000P3o00050?n000@0
o`001@3oP0040?l000<0oh00103o00050?n000@0o`000`3oP0040?l000@0oh0000<0o`000?n0003o
P000103o00030?n00080o`00103oP0050?l000D0oh000P3o00060?n000<0o`000P3oP00>ooooohX0
0?l03_oooolY003o00@0oh000P00o`000`3oP0000?l0003o000G003o0080o`00103oP00B003o0080
oh000`00o`020?n002800?l03_ooool2003o00D0oh000P3o000=0?n000030?l0003oP000oh0000L0
oh000P3o000F0?n000<0o`004P3oP005003o00l0oh000P3o00050?n000@0o`001`3oP0000`00o`00
oh000?n0000;003o0080oh000`3o00020?n00080o`006?ooool001Kooooo0P3oP0030?l000@0oh00
103o00050?n00080o`002P3oP0040?l000@0oh000`3o00040?n000<0o`001P3oP0020?l000L0oh00
0P3o00050?n00080o`001@3oP0040?l000D0oh000P3o00030?n000@0o`00103oP0000`3o0000oh00
0?n000020?n00080o`000`3oP0020?l000D0oh00103o00050?n000@0o`001@3oP0040?l000kooooo
RP00o`0>ooooodT00?l00P3o00020?n000800?l00P3oP00i003o00kooooo0P3o00030?n000800?l0
2@3oP0020?l000@0oh0000<0o`000?n0003oP0001@3oP0020?l000L0oh000P3o000@0?n00080o`00
2@3oP0020?l000D0oh000P3o00090?n00080o`000P3oP0030?l000T0oh00103o00020?n000030?l0
003oP000oh000080o`002@3oP003003o0080oh000P00o`020?n000<0o`000P3oP0020?l001Sooooo
000Fooooo`80oh000`3o00040?n000@0o`001@3oP0020?l000X0oh00103o00040?n000<0o`00103o
P0030?l000H0oh000P3o00070?n00080o`001@3oP0020?l000D0oh00103o00050?n00080o`000`3o
P0040?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o00050?n000@0o`001@3o
P0040?l000D0oh00103o000>ooooohX00?l03_oooom9003o0080o`000P3oP002003o0080oh00>@00
o`0>ooooo`80o`000`3oP002003o00T0oh000P3o00040?n000030?l0003oP000oh0000D0oh000P3o
00070?n00080o`00403oP0020?l000T0oh000P3o00050?n00080o`002@3oP0020?l00080oh000`3o
00090?n000@0o`000P3oP0000`3o0000oh000?n000020?l000T0oh000`00o`020?n000800?l00P3o
P0030?l00080oh000P3o000Hooooo`005_ooool40?n000030?l0003oP000oh0000@0oh000P3o0005
0?n000@0o`001@3oP0020?l000<0oh000P3o00050?n00080o`001P3oP0030?l000@0oh000`3o0006
0?n000<0o`00103oP0030?l000H0oh000P3o00050?n00080o`001@3oP0020?l000@0oh000`3o0002
0?n000@0o`000`3oP0020?l000D0oh00103o00050?n00080o`001@3oP0040?l000koooooRP00o`0>
ooooodd00?l01`3oP00f003o00kooooo0P3o00050?n00080o`000P3oP005003o0080oh000P3o0003
0?n00080o`001`3oP0020?l000D0oh000P3o00040?n00080o`002@3oP0030?l000d0oh0000<0o`00
0?n0003oP0000P3o00070?n00080o`001`3oP0020?l000/0oh000P3o00050?n00080o`001`3oP002
003o00030?n00000o`000?l00080oh00103o00050?n001Sooooo000Fooooo`@0oh0000<0o`000?n0
003oP000103oP0020?l000D0oh00103o00050?n00080o`000`3oP0020?l000D0oh000P3o00060?n0
00<0o`00103oP0030?l000H0oh000`3o00040?n000<0o`001P3oP0020?l000D0oh000P3o00050?n0
0080o`00103oP0030?l00080oh00103o00030?n00080o`001@3oP0040?l000D0oh000P3o00050?n0
00@0o`003_oooon:003o00koooooC@00o`070?n003H00?l03_ooool20?l000D0oh000P3o00020?n0
00D00?l00P3oP0020?l000<0oh000P3o00070?n00080o`001@3oP0020?l000@0oh000P3o00090?n0
00<0o`003@3oP0000`3o0000oh000?n000020?l000L0oh000P3o00070?n00080o`002`3oP0020?l0
00D0oh000P3o00070?n000800?l000<0oh00003o0000o`000P3oP0040?l000D0oh006?ooool001Ko
oooo0P3o00030?n000800?l0103oP0030?l000H0oh000`3o00040?n00080o`001@3oP0020?l000D0
oh000P3o00050?n00080o`001P3oP0030?l000H0oh0000<0o`000?n0003oP000103oP0030?l000@0
oh000`3o00040?n000@0o`001@3oP0020?l000<0oh000P3o00040?n00080o`000`3oP0040?l000<0
oh00103o00050?n000@0o`001@3oP0020?l000koooooRP00o`0>ooooodl00?l00P3oP00i003o00ko
oooo0P3o00050?n00080o`001@3oP002003o0080oh000P3o000<0?n00080o`000P3oP002003o0003
0?n00000o`000?l000@0oh000P00o`000`3oP000o`000?l000020?l000D0oh000P3o00040?n000L0
0?l00P3oP0000`3o0000oh000?n000020?n00080o`000P3oP007003o00D0oh000P3o00070?n00080
0?l0103oP0030?l000@0oh000`3o00040?n000800?l000<0oh000?l0003o00000P3o00020?n00080
o`001@3oP00Hooooo`005_ooool20?l000<0oh000P00o`040?n000<0o`001P3oP0030?l000@0oh00
0P3o00050?n00080o`001@3oP0020?l000D0oh000P3o00060?n000<0o`001P3oP0000`3o0000oh00
0?n000040?n000<0o`00103oP0030?l000@0oh00103o00050?n00080o`000`3oP0020?l000@0oh00
0P3o00030?n000@0o`000`3oP0040?l000D0oh00103o00050?n00080o`003_oooon:003o00kooooo
C`00o`020?n003T00?l03_ooool20?l000D0oh000P3o00050?n000800?l00P3oP0020?l000`0oh00
0P3o00020?n000800?l000<0oh00003o0000o`00103oP002003o00030?n0003o0000o`000080o`00
1@3oP0020?l000@0oh001`00o`020?n000030?l0003oP000oh000080oh000P3o00020?n000L00?l0
1@3oP0020?l000L0oh000P00o`040?n000<0o`00103oP0030?l000@0oh000P00o`000`3oP000o`00
0?l000020?l00080oh000P3o00050?n001Sooooo000Fooooo`80o`001`3oP0020?l000<0oh000P3o
00060?n000030?l0003oP000oh000080oh000`3o00040?n000@0o`000`3oP0040?l000<0oh00103o
00050?n00080o`000P3oP002003o0080oh000`3o00040?n000<0o`001P3oP0030?l000@0oh000P3o
00050?n00080o`000`3oP0020?l000@0oh000P3o00030?n000@0o`001@3oP0040?l000<0oh00103o
00020?n00003003o003oP000oh000080oh003_oooon:003o00koooooRP00o`0>ooooo`80oh000P3o
00030?n000@0o`000`3oP002003o00@0oh000P3o00050?n00080o`001`3oP002003o00<0oh000P3o
00090?n00080o`000P3oP0000`3o0000oh000?n000020?n000@00?l000<0oh000?l0003o0000103o
P0030?l00180oh000P3o000=0?n000030?l0003oP000oh0000@0oh0000<0o`000?n0003oP000103o
P002003o00<0oh000P3o00040?n000030?l0003oP000oh000080oh006?ooool001Kooooo0P3o0007
0?n00080o`000`3oP0020?l000H0oh0000<0o`000?n0003oP0000P3oP0030?l000@0oh00103o0003
0?n000@0o`000`3oP0040?l000D0oh000P3o00020?n000800?l00P3oP0030?l000@0oh000`3o0006
0?n000<0o`00103oP0020?l000D0oh000P3o00030?n00080o`00103oP0020?l000<0oh00103o0005
0?n000@0o`000`3oP0040?l00080oh0000<00?l00?n0003oP0000P3oP00>ooooohX00?l03_oooon:
003o00kooooo0P3oP0020?l000<0oh00103o00030?n000800?l0103oP0020?l000D0oh000P3o0007
0?n000800?l00`3oP0020?l000T0oh000P3o00020?n000030?l0003oP000oh000080oh001000o`00
0`3oP000o`000?l000040?n000<0o`004P3oP0020?l000d0oh0000<0o`000?n0003oP000103oP000
0`3o0000oh000?n000040?n000800?l00`3oP0020?l000@0oh0000<0o`000?n0003oP0000P3oP00H
ooooo`005_ooool40?l000D0oh000P3o00030?n000@0o`001@3oP002003o00@0oh000`3o00040?n0
00<0o`00103oP0020?l000D0oh000P3o00070?n00080o`001@3oP0020?l000D0oh00103o00050?n0
0080o`001P3oP0000`3o0000oh000?n000020?n000@0o`000`3oP0020?l000@0oh0000<0o`000?n0
003oP0000P3oP0030?l000H0oh000P3o00070?n00080o`001@3oP00>ooooohX00?l03_oooon:003o
00kooooo0P3oP0020?l000D0oh000P3o00050?n000@00?l00P3o00070?n000030?l0003oP000oh00
00L00?l00P3oP002003o0080oh000P00o`050?n00080o`000P3oP0000`3o0000oh000?n000040?n0
00800?l000<0o`000?n0003oP0001@3oP0020?l00080oh000P3o00050?n00080o`001@3oP0040?l0
00L0oh000P3o000;0?n000030?l0003oP000oh0001@0oh006?ooool001Kooooo0P3oP0020?l000D0
oh000P3o00050?n000@0o`000`3oP0020?l000D0oh000P3o00060?n000030?l0003oP000oh000080
oh00103o00030?n000@0o`001`3oP0020?l000D0oh000P3o00050?n000@0o`000`3oP0040?l000@0
oh000`3o00040?n00080o`000`3oP0020?l000@0oh0000<0o`000?n0003oP000103oP0000`3o0000
oh000?n000040?n000<0o`001P3oP0030?l000@0oh003_oooon:003o00koooooRP00o`0>ooooo`@0
oh0000<0o`000?n0003oP000103oP0020?l000<0oh001000o`030?n00080o`00103oP0030?l00080
oh001@00o`0B0?n00080o`00103oP002003o00030?n0003o0000o`0000D0oh000P3o00090?n00080
o`001`3oP0020?l000L0oh000P00o`070?n00080o`000P3oP0030?l00080oh000P3o00050?n000@0
o`001`3oP00Hooooo`005_ooool20?n00080o`001@3oP0020?l000D0oh00103o00030?n00080o`00
1@3oP0020?l000H0oh0000<0o`000?n0003oP0000P3oP0040?l000<0oh00103o00070?n00080o`00
1@3oP0020?l000D0oh00103o00030?n000@0o`00103oP0030?l000@0oh000P3o00030?n00080o`00
103oP0000`3o0000oh000?n000040?n000030?l0003oP000oh0000@0oh000`3o00060?n000<0o`00
103oP00>ooooohX00?l03_oooon:003o00kooooo103oP0000`3o0000oh000?n000040?n00080o`00
0`3oP004003o00<0oh000P3o00040?n000<0o`000P3oP005003o0180oh000P3o00040?n000800?l0
00<0oh000?l0003o00001@3oP0020?l000T0oh000P3o00070?n00080o`001`3oP002003o00L0oh00
0P3o00020?n000<0o`000P3oP0020?l000D0oh00103o00070?n001Sooooo000Fooooo`@0oh0000<0
o`000?n0003oP0000P3oP0040?l000<0oh00103o00050?n00080o`001@3oP0020?l000D0oh000P3o
00040?n00080o`001@3oP0040?l000D0oh00103o00050?n00080o`001@3oP0020?l000D0oh00103o
00030?n00080o`00103oP0030?l000@0oh000P3o00030?n00080o`00103oP0030?l000H0oh000`3o
00040?n000800?l01@3o000>ooooohX00?l03_oooon:003o00kooooo1@00o`060?n00080o`000`3o
P002003o00D0oh000P3o0002003o0080oh000`3o00020?n000800?l00P3oP0000`3o0000oh000?n0
00090?n00080o`000P00o`030?n00080o`001`3oP0040?l001L0oh000P3o000=0?n000030?l0003o
P000oh0000@0oh000`3o00020?n00080o`001@3oP0040?l000<0oh001000o`0Hooooo`005_ooool4
0?n000030?l0003oP000oh000080oh00103o00030?n000@0o`001@3oP0020?l000D0oh000P3o0005
0?n00080o`00103oP0020?l000D0oh00103o00050?n000@0o`001@3oP0020?l000D0oh000P3o0005
0?n000@0o`000`3oP0020?l000@0oh000`3o00040?n00080o`000`3oP0020?l000@0oh000`3o0006
0?n000<0o`00103oP002003o00D0o`003_oooon:003o00koooooRP00o`0>ooooo`D00?l01P3oP002
0?l000<0oh000P00o`050?n00080o`000P00o`020?n000<0o`000P3oP002003o0080oh0000<0o`00
0?n0003oP0002@3oP0020?l000800?l00`3oP0020?l000L0oh00103o000G0?n00080o`003@3oP000
0`3o0000oh000?n000040?n000<0o`000P3oP0020?l000D0oh00103o00030?n000@00?l06?ooool0
01Kooooo103oP0000`3o0000oh000?n000040?n00080o`001@3oP0040?l000<0oh00103o00030?n0
00@0o`002`3oP0000`3o0000oh000?n000040?n000<0o`001P3oP0030?l000@0oh000`3o00080?n0
00030?l0003oP000oh000080oh000P3o00030?n000@0o`00103oP0000`3o0000oh000?n000020?n0
0080o`000`3oP0020?l000D0oh000P3o00020?n000800?l00`3oP0020?l00080oh001000o`000`3o
P000o`000?l000020?l000koooooRP00o`0>ooooobT00?l00P3oP002003o0080oh00F`00o`0>oooo
o`80oh000`00o`080?n000030?l0003oP000oh0000L0oh000P3o00040?n000030?l0003oP000oh00
00L0oh00103o00070?n000800?l01`3oP006003o00<0oh00103o00030?n00080o`000P3oP005003o
0080o`005`3oP0020?l000D0oh000P3o000=0?n000<0o`000P3oP002003o01Sooooo000Fooooo`@0
oh0000<0o`000?n0003oP000103oP0020?l000D0oh00103o00030?n000@0o`000`3oP0040?l000/0
oh0000<0o`000?n0003oP000103oP0030?l000H0oh000`3o00040?n000<0o`00203oP0000`3o0000
oh000?n000020?n00080o`000`3oP0040?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000<0
oh000P3o00050?n00080o`000P3oP002003o00<0oh000P3o00020?n000@00?l000<0oh000?l0003o
00000P3o000>ooooohX00?l03_oooolY003o0080oh000P00o`020?n005/00?l03_ooool20?n000<0
0?l0203oP0000`3o0000oh000?n000070?n00080o`00103oP0000`3o0000oh000?n000070?n000@0
o`001`3oP002003o00L0oh001P00o`030?n000@0o`000`3oP0020?l00080oh001@00o`020?l001L0
oh000P3o00050?n00080o`003@3oP0030?l00080oh000P00o`0Hooooo`005_ooool20?l000<0oh00
0P3o00060?n000030?l0003oP000oh0000@0oh000`3o00040?n00080o`001@3oP0040?l000<0oh00
103o00030?n00080o`001P3oP0000`3o0000oh000?n000060?n000030?l0003oP000oh0000@0oh00
0`3o00060?n000030?l0003oP000oh0000@0oh000P3o00030?n00080o`00103oP0030?l00080oh00
103o00030?n00080o`001@3oP0040?l000<0oh00103o0004003o00<0oh000P3o000>ooooohX00?l0
3_ooool]003o0080oh00F`00o`0>ooooo`80oh000P3o00050?n000800?l00P3oP003003o00@0oh00
0P3o00030?n000800?l00P3oP0000`3o0000oh000?n000020?n000D00?l00P3oP0040?l00080oh00
1@00o`0;0?n000800?l01@3oP0020?l000L0oh000P00o`030?n000@0o`005`3oP0020?l000D0oh00
0P3o00040?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_oo
ool20?l000<0oh000P3o00060?n000030?l0003oP000oh0000@0oh000`3o00040?n00080o`001@3o
P0040?l000<0oh00103o00030?n00080o`001P3oP0000`3o0000oh000?n000060?n000030?l0003o
P000oh0000@0oh000`3o00060?n000030?l0003oP000oh0000@0oh000P3o00030?n00080o`00103o
P0030?l00080oh00103o00030?n00080o`001@3oP0040?l000<0oh00103o0004003o00<0oh000P3o
000>ooooohX00?l03_ooool]003o0080oh00F`00o`0>ooooo`80oh000P3o00050?n000800?l00P3o
P003003o00@0oh000P3o00030?n000800?l00P3oP0000`3o0000oh000?n000020?n000D00?l00P3o
P0040?l00080oh001@00o`0;0?n000800?l01@3oP0020?l000L0oh000P00o`030?n000@0o`005`3o
P0020?l000D0oh000P3o00040?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0000P3o
P00Hooooo`005_ooool20?l000<0oh00103o00040?n000<0o`001P3oP0000`3o0000oh000?n00002
0?n000<0o`00103oP0040?l000D0oh000P3o00030?n000@0o`00103oP0030?l000H0oh000`3o0004
0?n000<0o`001P3oP0030?l000@0oh000P3o00030?n00080o`001@3oP0020?l000@0oh000P3o0003
0?n000@0o`000`3oP0040?l000D0oh000P00o`020?n000800?l01@3oP00>ooooohX00?l03_oooon:
003o00kooooo103oP0000`3o0000oh000?n000020?n000800?l00`3oP0020?l000@0oh000P3o0003
0?n000800?l00P3oP0030?l00080oh000P00o`020?l000D0oh000P3o00020?n000D00?l0503oP003
0?l000@0oh000P3o00030?n00080o`000P3oP0020?l000T0oh0000<0o`000?n0003oP0000P3oP002
0?l000<0oh00103o00050?n00080o`001@3oP0020?l000L0oh000P3o00020?n001Sooooo000Foooo
o`80oh000P3o00030?n00080o`001@3oP0040?l000/0oh0000<0o`000?n0003oP000103oP0030?l0
00@0oh00103o00030?n00080o`001@3oP0040?l000D0oh000P3o00050?n000@0o`001@3oP0020?l0
00@0oh000`3o00040?n00080o`000`3oP0020?l000@0oh000P3o00050?n00080o`001@3oP0040?l0
00<0oh000P00o`020?n00080o`000`3oP002003o00koooooRP00o`0>ooooohX00?l03_ooool>0?n0
0080o`00103oP0020?l000<0oh000P00o`030?n00080o`000P3oP004003o00D0oh000P3o00030?n0
00800?l01`3oP0060?l000<0oh001000o`030?n00080o`003@3oP0020?l000D0oh000P00o`090?n0
0080o`000`3oP0020?l000D0oh00103o00030?n00080o`00103oP002003o00030?n00000o`000?l0
0080oh006?ooool001Kooooo0P3oP0020?l000<0oh000P3o00050?n000@0o`002`3oP0000`3o0000
oh000?n000040?n000<0o`00103oP0040?l000<0oh000P3o00050?n000@0o`001@3oP0020?l000D0
oh00103o00050?n00080o`00103oP0030?l000@0oh000P3o00030?n00080o`00103oP0020?l000D0
oh000P3o00050?n000@0o`000`3oP002003o0080oh000P3o00030?n000800?l03_oooon:003o00ko
ooooRP00o`0>ooooo`h0oh000P3o00040?n00080o`000`3oP002003o00<0oh000P3o00020?n000@0
0?l01@3oP0020?l000<0oh000P00o`070?n000H0o`000`3oP004003o00<0oh000P3o000=0?n00080
o`001@3oP002003o00T0oh000P3o00030?n00080o`001@3oP0040?l000<0oh000P3o00040?n00080
0?l000<0oh00003o0000o`000P3oP00Hooooo`005_ooool70?n000@0o`000`3oP0040?l000D0oh00
0P3o000;0?n000<0o`001P3oP0020?l000<0oh00103o00050?n000@0o`000`3oP0020?l000D0oh00
103o00050?n000@0o`00103oP0000`3o0000oh000?n000020?n00080o`002@3oP0030?l000@0oh00
0`3o00040?n000D0o`001P3oP0030?l000@0oh003_oooon:003o00koooooRP00o`0>oooooa00oh00
0P3o00020?n00080o`000`3oP004003o00D0oh000P00o`020?l000D0oh000P3o00020?n000<0o`00
103oP0020?l000D0oh000P3o000:0?n000@0o`001`3oP0020?l000@0oh0000<0o`000?n0003oP000
0P3o000;0?n00080o`0000<0oh000?l0003o00001`3oP0040?l000D0oh000P3o00090?n001Sooooo
000Fooooo`L0oh00103o00030?n000@0o`001@3oP0020?l000/0oh000`3o00060?n00080o`000`3o
P0040?l000D0oh00103o00030?n00080o`001@3oP0040?l000D0oh00103o00040?n000030?l0003o
P000oh000080oh000P3o00090?n000<0o`00103oP0030?l000@0oh001@3o00060?n000<0o`00103o
P00>ooooohX00?l03_oooon:003o00kooooo403oP0020?l00080oh000P3o00030?n000@00?l01@3o
P002003o0080o`001@3oP0020?l00080oh000`3o00040?n00080o`001@3oP0020?l000X0oh00103o
00070?n00080o`00103oP0000`3o0000oh000?n000020?l000/0oh000P3o00000`3oP000o`000?l0
00070?n000@0o`001@3oP0020?l000T0oh006?ooool001Kooooo103oP0000`3o0000oh000?n00002
0?n00080o`001@3oP0040?l000<0oh000P3o00050?n00080o`001P3oP0000`3o0000oh000?n00004
0?n00080o`000`3oP0040?l000D0oh00103o00050?n00080o`00303oP0040?l000@0oh000`3o0004
0?n00080o`000`3oP0020?l000@0oh0000<0o`000?n0003oP0000P3oP0030?l000P0oh0000<0o`00
0?n0003oP000103oP0030?l000@0oh003_oooon:003o00kooooo=P00o`020?n005800?l03_ooool@
0?n00080o`00103oP0000`3o0000oh000?n00002003o0100oh000P3o00090?n00080o`001@3oP002
0?l000<0oh000P00o`020?l000D0oh000P3o00020?n00080o`002@3oP0000`3o0000oh000?n00002
0?n00080o`00303oP0020?l000T0oh000P3o00020?n000030?l0003oP000oh000080o`00103oP000
0`00o`00oh000?n000020?n001Sooooo000Fooooo`@0oh0000<0o`000?n0003oP0000P3oP0020?l0
00D0oh00103o00030?n00080o`001@3oP0020?l000H0oh0000<0o`000?n0003oP000103oP0020?l0
00<0oh00103o00050?n000@0o`001@3oP0020?l000`0oh00103o00040?n000<0o`00103oP0020?l0
00<0oh000P3o00040?n000030?l0003oP000oh000080oh000`3o00080?n000030?l0003oP000oh00
00@0oh000`3o00040?n000koooooRP00o`0>ooooocH00?l00P3oP01B003o00kooooo403oP0020?l0
00@0oh0000<0o`000?n0003oP0000P00o`0@0?n00080o`002@3oP0020?l000D0oh000P3o00030?n0
00800?l00P3o00050?n00080o`000P3oP0020?l000T0oh0000<0o`000?n0003oP0000P3oP0020?l0
00`0oh000P3o00090?n00080o`000P3oP0000`3o0000oh000?n000020?l000@0oh0000<00?l00?n0
003oP0000P3oP00Hooooo`005_ooool40?n000<0o`00103oP0020?l000D0oh000P3o00050?n00080
o`001@3oP0020?l000@0oh000`3o000;0?n000@0o`001@3oP0040?l000<0oh00103o00050?n000@0
o`000`3oP0020?l000D0oh000P3o00040?n000<0o`000P3oP0020?l000@0oh0000<0o`000?n0003o
P0001@3oP0020?l000H0oh000`3o00060?n000030?l0003oP000oh000080oh003_oooon:003o00ko
ooooRP00o`0>ooooo`80oh001@00o`020?n00080o`000`3oP0020?l000H0oh0000<0o`000?n0003o
P0002@00o`020?n00080o`001`3oP0020?l000030?n0003o0000o`000080o`00103oP0000`3o0000
oh000?n000020?n00080o`001@3oP0020?l000<0oh000P3o00040?n00080o`00403oP0020?l000<0
oh001000o`030?n00080o`00103oP0000`00o`00o`000?l0000?0?n000<00?l00P3oP00Hooooo`00
5_ooool20?l000<0oh000P3o00040?n000<0o`001P3oP0020?l000<0oh00103o00030?n000@0o`00
0`3oP0040?l000@0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000040?n00080o`00
1@3oP0030?l000H0oh000P3o00050?n00080o`001@3oP0020?l000@0oh0000<0o`000?n0003oP000
0P3oP0020?l000<0oh000P3o00020?n000800?l00`3oP0020?l000D0oh000P3o00020?n000800?l0
0P3oP0030?l00080oh003_oooon:003o00koooooRP00o`0>ooooo`L00?l00P3oP0020?l000<0oh00
0P3o00090?n000D00?l00P3oP004003o00T0oh000P3o000:0?n00080o`001P3oP0000`3o0000oh00
0?n000020?n00080o`001`3oP0020?l00100oh000P3o000>0?n000<00?l02@3oP0020?l000H0oh00
00<0o`000?n0003oP0000P3oP00Hooooo`005_ooool20?l000<0oh000P3o00040?n000<0o`001P3o
P0020?l000<0oh00103o00030?n000@0o`000`3oP0040?l000@0oh0000<0o`000?n0003oP0001P3o
P0000`3o0000oh000?n000040?n00080o`001@3oP0030?l000H0oh000P3o00050?n00080o`001@3o
P0020?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o00020?n000800?l00`3o
P0020?l000D0oh000P3o00020?n000800?l00P3oP0030?l00080oh003_oooon:003o00koooooRP00
o`0>ooooo`L00?l00P3oP0020?l000<0oh000P3o00090?n000D00?l00P3oP004003o00T0oh000P3o
000:0?n00080o`001P3oP0000`3o0000oh000?n000020?n00080o`001`3oP0020?l00100oh000P3o
000>0?n000<00?l02@3oP0020?l000H0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool2
0?l000D0oh000P3o00040?n000<0o`00103oP0020?l000D0oh000P3o00050?n00080o`001@3oP002
0?l000@0oh000`3o00060?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP000103oP003
0?l000@0oh000`3o00060?n00080o`000`3oP0020?l000@0oh0000<0o`000?n0003oP0000P3oP002
0?l000<0oh00103o00030?n000@0o`001@3oP0020?l000L0oh000P3o00020?n000koooooRP00o`0>
ooooo`80oh000P3o00000`3oP0000?l0003o0023003o00kooooo0P00o`020?n000L00?l00P3o0009
0?n000030?l0003oP000oh0000L0oh000P3o00040?n000030?l0003oP000oh000100oh000P3o0006
0?n000030?l0003oP000oh000080oh000P3o00000`3oP000o`000?l000090?n00080o`001@3oP002
0?l000H0oh0000<0o`000?n0003oP0001000o`030?n00080o`001`3oP0020?l000@0oh0000<00?l0
0?n0003oP0001P3oP0030?l00080oh006?ooool001Kooooo0P3o00050?n00080o`00103oP0030?l0
00@0oh000P3o00050?n00080o`001@3oP0020?l000D0oh000P3o00040?n000<0o`001P3oP0000`3o
0000oh000?n000060?n000030?l0003oP000oh0000@0oh000`3o00040?n000<0o`001P3oP0020?l0
00<0oh000P3o00040?n000030?l0003oP000oh000080oh000P3o00030?n000@0o`000`3oP0040?l0
00D0oh000P3o00070?n00080o`000P3oP00>ooooohX00?l03_ooool20?n00080o`0000<0oh00003o
0000o`00P`00o`0>ooooo`800?l00P3oP007003o0080o`002@3oP0000`3o0000oh000?n000070?n0
0080o`00103oP0000`3o0000oh000?n0000@0?n00080o`001P3oP0000`3o0000oh000?n000020?n0
0080o`0000<0oh000?l0003o00002@3oP0020?l000D0oh000P3o00060?n000030?l0003oP000oh00
00@00?l00`3oP0020?l000L0oh000P3o00040?n00003003o003oP000oh0000H0oh000`3o00020?n0
01Sooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009oooooma
o`0002Cooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Go
oooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo
5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo
5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_oo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5
oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo
003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01Ooo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
00Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0
00Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Go
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03
o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0j
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool000Co001o5_l0o`0j
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool003[o001o5_ooO`04
o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Doooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l0
0ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0
>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo001Do`00O`03o`00
0?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
o`00Ool007l0K_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l0KOl007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;oooooL_l0000Wooooog7o00009oooooma
o`0002OoooooLOl0000Tooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool2
003o0080oh003000o`0F0?l000L00?l00P3o00000`00o`00o`000?l000020?l000800?l00P3o0000
0`000?l0o`000?l000020?n000L0o`000P00o`090?l00080oh000`3o00020?n000800?l00P3o0000
0`00o`00o`000?l00002003o00/0o`000P00o`0I0?l000030?n000000?l0003o0080003o3_ooool4
0?n000T00?l000<0o`00003o0000o`002@3o0007003o00@0o`000`000?l40?n001L00?l00P3oP009
003o00@0o`00;000o`040?l00080003o1`3oP00>ooooo`L00?l0103o0002003o00030?n00000o`00
0?l000800?l0403o00040000o`030?l0003oP000oh0000@0o`000P3oP00<003o00/0o`001@00o`07
0?l00080oh000P3o0004003o00<0o`001P000?l30?n000800?l01@3o00040000o`80o`0000<0oh00
0?l0003o000010000?l20?n000<0003o0P3o00020?n000<0003o0P3o00020?n000kooooo0P3oP009
0?l000<0oh000P3o00090?n00080o`000P3oP0000`3o0000oh000?n00004003o00D0o`000P3oP002
0?l00080oh0000<0o`000?n0003oP0000P3o00040000o`030?n0003o0000o`000080oh00103o0000
0`3oP000o`000?l000040?l000030?n0003o0000o`0000L0o`000P3oP0060?l000030?n0003o0000
o`0001@0o`000P3oP0030?l00080oh000P3o00020000o`<0oh001P000?l50?n001Sooooo000Foooo
o`800?l00P3oP00<003o01H0o`001`00o`020?l00003003o003o0000o`000080o`000P00o`020?l0
00030000o`3o0000o`000080oh001`3o0002003o00T0o`000P3oP0030?l00080oh000P00o`020?l0
0003003o003o0000o`0000800?l02`3o0002003o01T0o`0000<0oh000000o`000?l00P000?l>oooo
o`@0oh002@00o`000`3o00000?l0003o00090?l000L00?l0103o00030000o`@0oh005`00o`020?n0
00T00?l0103o000/003o00@0o`000P000?l70?n000kooooo1`00o`040?l000800?l000<0oh00003o
0000o`000P00o`0@0?l000@0003o00<0o`000?n0003oP000103o00020?n000`00?l02`3o0005003o
00L0o`000P3oP0020?l000@00?l00`3o00060000o`<0oh000P00o`050?l000@0003o0P3o00000`3o
P000o`000?l000040000o`80oh000`000?l20?l00080oh000`000?l20?l00080oh003_ooool20?n0
00T0o`000`3oP0020?l000T0oh000P3o00020?n000030?l0003oP000oh0000@00?l01@3o00020?n0
0080o`000P3oP0000`3o0000oh000?n000020?l000@0003o00<0oh000?l0003o00000P3oP0040?l0
00030?n0003o0000o`0000@0o`0000<0oh000?l0003o00001`3o00020?n000H0o`0000<0oh000?l0
003o0000503o00020?n000<0o`000P3oP0020?l00080003o0`3oP0060000o`D0oh006?ooool001Ko
oooo0P3o00020?n000<0o`001000o`030?l000800?l02@3o00020?n000h0o`001`00o`040?l00080
0?l00P3o00000`000?l0o`000?l000020?n00180o`000`000?l20?l00080oh001`3o0002003o00/0
o`001@00o`0;0?l00080oh002@3o00000`3oP000003o0000o`020000o`kooooo103oP009003o00X0
o`003@00o`030000o`@0oh005P00o`000`3o0000oh000?n00009003o00@0o`009`00o`090?l00080
003o1`3oP00>ooooo`L00?l0103o0002003o00030?n00000o`000?l000@00?l03P3o00040000o`<0
oh001`3o000=003o00T0o`001@00o`040?l000<0003o0P3oP0020?l000800?l00P3o00090000o`03
0?n0003o0000o`0000@00?l00`3o00040000o`80o`0000<0oh000?l0003o00000P3o00020000o`80
oh0000<0o`000?n0003oP0000P3o00020?n000<0003o103oP00>ooooo`@0oh0000<00?l00?l0003o
0000103o00030?n00080o`000P3oP0020?l000L0oh000`3o00040?n000800?l00P3o00000`3oP000
003o0000o`020?n00080o`000P3oP0000`3o0000oh000?n000060?l000<0oh000P3o0004003o0003
0?l0003oP000oh0000L0o`000P3oP0050000o`80oh000P3o0002003o0080o`0000<0oh000?l0003o
00000P3o00040?n000<0o`00103oP0030?l00080oh000P3o00020?n000030?l0003oP000oh0000@0
o`000P000?l30?n000@0003o1@3oP0020?l001Sooooo000Fooooo`80o`000P3oP0030?l000@00?l0
0`3o0002003o00T0o`000P3oP00>0?l000L00?l0103o0002003o0080o`0000<0003o0?l0003o0000
0P3oP00B0?l000<0003o0P3o00020?n000L0o`000P00o`0;0?l000D00?l02`3o00020?n000T0o`00
00<0oh000000o`000?l00P000?l>ooooo`@0oh002@00o`0:0?l000d00?l00`000?l40?n001H00?l0
00<0o`000?n0003oP0002@00o`040?l002L00?l02@3o00020000o`L0oh003_ooool7003o00@0o`00
0P00o`000`3oP0000?l0003o0004003o00h0o`0010000?l30?n000L0o`003@00o`090?l000D00?l0
103o00030000o`80oh000P3o0002003o0080o`002@000?l00`3oP000o`000?l00004003o00<0o`00
10000?l20?l000030?n0003o0000o`000080o`000P000?l20?n000030?l0003oP000oh000080o`00
0P3oP0030000o`@0oh003_ooool40?n00003003o003o0000o`0000@0o`000`3oP0020?l00080oh00
0P3o00070?n000<0o`00103oP002003o0080o`0000<0oh000000o`000?l00P3oP0020?l00080oh00
00<0o`000?n0003oP0001P3o00030?n00080o`001000o`000`3o0000oh000?n000070?l00080oh00
1@000?l20?n00080o`000P00o`020?l000030?n0003o0000o`000080o`00103oP0030?l000@0oh00
0`3o00020?n00080o`000P3oP0000`3o0000oh000?n000040?l00080003o0`3oP0040000o`D0oh00
0P3o000Hooooo`005_ooool40?l00003003o003o0000o`000180o`00103oP0050?l00080oh001@3o
0004003o00L0o`000P00o`030?l000@0oh00403o00040?n000<0o`000P3oP00D0?l000D00?l01@3o
00020000o`80o`00103oP0090?l000030?n0003o0000o`000080o`003_ooool40?n000T00?l01`3o
000@003o00<0003o0P3o00020?n001L00?l00P3oP009003o00@0o`009`00o`050?l00080oh000P3o
00020000o`80oh0000<0o`000?n0003oP0000P3oP00>ooooo`T00?l00P3o0002003o00030?n00000
o`000?l000L00?l02`3o00040000o`<0oh001P3o00000`3oP000o`000?l00002003o00d0o`0000<0
oh000?l0003o00000P3o0002003o00<0o`001P000?l50?n000@0o`001@000?l50?n000H0o`001@00
0?l20?n00080o`0000<0oh000?l0003o00003@3o00030000o`@0oh003_ooool20?n00080o`0000<0
oh000?l0003o00000P3o00020000o`<0oh000P3o00020?n000@0o`0000<0oh000?l0003o00000P3o
P0030?l000@0oh000P00o`020?l000030?n0003o0000o`000080oh001@3o00020?n000H0o`0000<0
oh000?l0003o00001`3o00020?n000D0o`000P00o`020?n000@0o`000`3oP0060?l000030?n0003o
0000o`000080o`001@3oP0020?l000@0oh000P3o00030?n000D0o`000P000?l20?n000/0003o0P3o
P0000`000?l0oh000?n000020?n001Sooooo000Fooooo`D00?l01P3o00020?n000`0o`00103oP00G
0?l000800?l00`3o00040?n000`0o`000P000?l20?l000@0oh000`3o00020?n001@0o`000P3oP003
003o00D0o`000P000?l20?l000@0oh001`3o00020?n000D0o`003_ooool40?l000T00?l000<0o`00
003o0000o`000P00o`020?l001000?l00`000?l20?l00080oh005`00o`020?n000T00?l0103o000W
003o00D0o`000P3oP0020?l00080003o0P3oP0000`3o0000oh000?n000020?n000kooooo2@00o`02
0?l000800?l01@3o00020?n000T0o`0000<0oh000?l0003o00000P3o00040000o`<0oh0010000?l2
0?l000030?n00000o`000?l000800?l0103o0003003o0080o`000P000?l20?l000<0oh000P3o0002
0?n000<0o`001P000?l70?n000L0003o103oP0070?l000D0003o0P3oP003003o0080o`000P00o`0;
0?l000<0003o103oP00>ooooo`80oh000P3o00000`3oP000o`000?l000040000o`L0oh00103o0000
0`3oP000o`000?l000020?n000<0o`000P00o`020?n000800?l01@3o00020?n000D0o`000P3oP002
003o0080o`000P00o`030?l00080003o0P3o00050?n000L0o`00103oP0020?l000030000o`3oP000
oh000080oh00103o00000`3oP000o`000?l000090?n00080003o1`3oP002003o0080o`000`000?l2
0?n000D0003o0P3oP0020?l000T0oh006?ooool001Kooooo1@00o`060?l00080oh00303o00040?n0
01L0o`000P00o`030?l000@0oh00303o00020000o`80o`00103oP0030?l00080oh00503o00020?n0
00<00?l01@3o00020000o`80o`00103oP0070?l00080oh001@3o000>ooooo`@0o`002@00o`000`3o
00000?l0003o0002003o0080o`004000o`030000o`80o`000P3oP00G003o0080oh002@00o`040?l0
02L00?l01@3o00020?n00080o`000P000?l20?n000030?l0003oP000oh000080oh003_ooool9003o
0080o`000P00o`050?l00080oh002@3o00000`3oP000o`000?l000020?l000@0003o0`3oP0040000
o`80o`0000<0oh00003o0000o`000P00o`040?l000<00?l00P3o00020000o`80o`000`3oP0020?l0
0080oh000`3o00060000o`L0oh001`000?l40?n000L0o`001@000?l20?n000<00?l00P3o0002003o
00/0o`000`000?l40?n000kooooo0P3oP0020?l000030?n0003o0000o`0000@0003o1`3oP0040?l0
00030?n0003o0000o`000080oh000`3o0002003o0080oh000P00o`050?l00080oh001@3o00020?n0
00800?l00P3o0002003o00<0o`000P000?l20?l000D0oh001`3o00040?n00080o`0000<0003o0?n0
003oP0000P3oP0040?l000030?n0003o0000o`0000T0oh000P000?l70?n000800?l00P3o00030000
o`80oh001@000?l20?n00080o`002@3oP00Hooooo`005_ooool7003o00/0o`000P00o`050?l00080
oh000P00o`0:0?l00080oh002`3o0002003o00<0o`00103oP002003o00X0o`000P000?l20?l000@0
oh00403o00020?n000030?l0003oP000oh0000@0o`000P3oP003003o00D0o`000P000?l20?l00080
oh002@3o00020?n000D0o`003_oooolB003o0080o`004000o`030000o`80o`000P3oP00F003o0003
0?l00000o`000?l000800?l00P3o0005003o00@0o`000`00o`040?l001@00?l000<0o`00003o0000
o`002@00o`020?l00080003o00<0o`000?n0003oP0000P3o00020000o`80oh0000<0o`000?n0003o
P0000P3oP00>ooooo`@0oh001@00o`020?l000800?l000<0o`000?n0003oP0000P3o00020?n000h0
o`000P000?l20?l000<0oh0010000?l20?l000030?n00000o`000?l000800?l01@3o0002003o00H0
o`000`000?l40?n000<0o`001P000?l70?n00080003o00<0oh000000o`000?l00P3o00040?n000L0
o`001@000?l20?n000<00?l01P3o00020?n000T0o`000`000?l20?n000kooooo0P3oP0020?l00003
0?n0003o0000o`000080o`000P000?l30?n00080o`000P3oP002003o0080o`0000<0003o0?n0003o
P0000P3oP005003o0080oh001`00o`070?l00080oh001P3o00000`3oP000003o0000o`020000o`@0
oh0000<0o`000000o`000?l01@3o0002003o00@0oh000`000?l60?n00080o`0000<0oh000?l0003o
00001`3oP0040000o`L0oh000P00o`020?l000030?n0003o0000o`000080o`000P3oP0020000o`<0
oh00103o00020?n000D0o`006?ooool001Kooooo1`00o`0;0?l000800?l01@3o00020?n000800?l0
2P3o00020?n000/0o`000P00o`030?l000@0oh000P00o`0:0?l00080003o0P3o00040?n00100o`00
0P3oP0000`3o0000oh000?n000040?l00080oh000`00o`050?l00080003o0P3o00020?n000T0o`00
0P3oP0050?l000kooooo4P00o`020?l001000?l00`000?l20?l00080oh005P00o`000`3o00000?l0
003o0002003o0080o`001@00o`040?l000<00?l0103o000D003o00030?l00000o`000?l000T00?l0
0P3o00020000o`030?l0003oP000oh000080o`000P000?l20?n000030?l0003oP000oh000080oh00
3_ooool40?n000D00?l00P3o0002003o00030?l0003oP000oh000080o`000P3oP00>0?l00080003o
0P3o00030?n000@0003o0P3o00000`3oP0000?l0003o0002003o00D0o`000P00o`060?l000<0003o
103oP0030?l000H0003o1`3oP0020000o`030?n000000?l0003o0080o`00103oP0070?l000D0003o
0P3oP003003o00H0o`000P3oP0090?l000<0003o0P3oP00>ooooo`80oh000P3o00000`3oP000o`00
0?l000020?l00080003o0`3oP0020?l00080oh000P00o`020?l000030000o`3oP000oh000080oh00
1@00o`020?n000L00?l01`3o00020?n000H0o`0000<0oh000000o`000?l00P000?l40?n000030?l0
00000?l0003o00D0o`000P00o`040?n000<0003o1P3oP0020?l000030?n0003o0000o`0000L0oh00
10000?l70?n000800?l00P3o00000`3oP000o`000?l000020?l00080oh000P000?l30?n000@0o`00
0P3oP0050?l001Sooooo000Fooooo`L00?l01P3o0003003o0080o`000P00o`050?l00080oh000P00
o`0<0?l000800?l01`3o0004003o00<0o`00103oP00<0?l00080003o103o00020?n00100o`000P3o
P0070?l00080oh001`3o00000`3oP000003o0000o`020?l00080oh002@3o00020?n000D0o`003_oo
oolB003o00D0o`003@00o`030000o`@0oh005000o`030?l000@00?l01@3o0002003o00D0o`000P00
o`060?l001800?l000<0o`00003o0000o`002@00o`050?l00080oh000P3o00020000o`80oh0000<0
o`000?n0003oP0000P3oP00>ooooo`@0oh001@00o`050?l00080oh00403o00020?n000@0003o0`3o
P0040000o`80o`0000<0oh00003o0000o`001000o`020?l000D00?l0103o00070000o`030?l0003o
P000oh0000/0003o0P3oP0020000o`<0oh00103o00030000o`80o`000P3oP0040?l000030?n00000
0?l0003o0080o`000P00o`000`3oP000o`000?l000040?l00080oh0000<0003o0?n0003oP0001P3o
00050000o`kooooo0P3oP0020?l000030?n0003o0000o`0000@0o`000P3oP0000`3o00000?l0003o
0002003o00D0o`00103oP0020?l000X00?l01P3o00020?n000L0o`000`3oP0040000o`80o`000P3o
P0030?l00080003o0P3o00000`3oP000o`000?l00002003o00@0oh0000<0003o0?n0003oP0000P3o
P002003o0080oh000`3o00020?n00080o`000`3oP0040000o`L0oh000P3o00030?n00080003o0P3o
P0070?l00080oh000P00o`020?n000D0o`006?ooool001Kooooo1`00o`060?l000<00?l00P3o0002
003o00D0o`000P3oP002003o00`0o`000P00o`070?l000@00?l00`3o00040?n000`0o`000P000?l4
0?l00080oh00403o00020?n000L0o`000P3oP0070?l000030?n000000?l0003o0080o`000P3oP009
0?l00080oh001@3o000>oooooa800?l01@3o000=003o00<0003o103oP00D003o00<0o`001000o`05
0?l000800?l01@3o0002003o00H0o`004P00o`000`3o00000?l0003o0009003o00D0o`000P3oP002
0?l00080003o0P3oP0000`3o0000oh000?n000020?n000kooooo103oP005003o00D0o`000P3oP00@
0?l00080oh0010000?l30?n000@0003o0P3o00000`3oP0000?l0003o0004003o0080o`001@00o`04
0?l000L0003o00<0o`000?n0003oP0002`000?l20?n00080003o0`3oP0040?l000<0003o0P3o0002
0?n000@0o`0000<0oh000000o`000?l00P3o0002003o00030?n0003o0000o`0000@0o`000P3oP000
0`000?l0oh000?n000060?l000D0003o3_ooool20?n00080o`0000<0oh000?l0003o0000103o0002
0?n000030?l00000o`000?l000800?l01@3o00040?n00080o`002P00o`060?l00080oh001`3o0003
0?n000@0003o0P3o00020?n000<0o`000P000?l20?l000030?n0003o0000o`0000800?l0103oP000
0`000?l0oh000?n000020?n000800?l00P3oP0030?l00080oh000P3o00030?n000@0003o1`3oP002
0?l000<0oh000P000?l20?n000L0o`000P3oP002003o0080oh001@3o000Hooooo`005_ooool7003o
00H0o`000`00o`090?l000@00?l0303o0002003o00L0o`001000o`050?l00080oh006@3o0002003o
00T0o`000P3oP00@0?l000030?n0003o0000o`0000d0o`000P3oP0050?l000kooooo4P00o`040?l0
00X00?l00P3o0002003o00<0003o0P3o00020?n001@00?l00`3o0004003o00`0o`000P00o`060?l0
00030?n00000o`000?l000l00?l000<0o`00003o0000o`002@00o`090?l00080003o0P3oP0000`3o
0000oh000?n000020?l000kooooo103oP005003o00D0o`000P3oP00@0?l00080oh0010000?l30?n0
00@0003o0P3o00000`3oP0000?l0003o000=003o0080o`000`000?l40?n000030?l0003oP000oh00
00/0003o1@3oP0040?l000D0003o103oP004003o00030?l000000?l0003o0080003o0P3o00000`3o
P000o`000?l000020000o`80o`000P3oP0000`000?l0oh000?n000020?n000@0o`001@000?l>oooo
o`80oh001`3o00040?n000L0o`000`000?l40?n000D0o`000P00o`020?l000800?l000<0o`000?n0
003oP000103o00020?n000L0o`000`3oP0060000o`80oh0000<0o`000000o`000?l00P3oP0020?l0
00030?n0003o0000o`000080o`000P3oP0030000o`P0oh000`3o00020?n00080o`000P3oP0000`3o
0000003o0000o`020000o`@0oh000`3o00070?n000@0o`000P3oP0000`00o`00o`000?l000020?n0
0080o`000P3oP0050?l001Sooooo000Fooooo`L00?l08P3o0004003o00D0o`001000o`050?l00080
oh001@3o0002003o00/0o`000P000?l00`3o0000oh000?n0000=0?l00080oh002@3o00000`00o`00
o`000?l0000D0?l00080oh000`3o00020000o`kooooo4P00o`020?l000T00?l000<0o`00003o0000
o`000P3o0002003o00<0003o0P3o00020?n001@00?l00`3o0004003o00`0o`000P00o`060?l00003
0?n00000o`000?l001/00?l00P3o0002003o00D0o`000P000?l20?n000030?l0003oP000oh000080
o`003_ooool40?n000D00?l0103o00000`00o`00oh000?n00002003o00@0o`0000<00?l00?l0003o
00001@3o00040?n00080o`000P000?l30?n000@0o`000P3oP0000`3o00000?l0003o000=003o0080
o`000`000?l40?n000030?l0003oP000oh0000/0003o1@3oP0040?l000@0003o1@3oP004003o0003
0?l000000?l0003o0080003o0`3oP0060?l00080oh0000<0003o0?n0003oP0000P3oP0020?l00080
0?l000<0o`000000o`000?l00P000?l>ooooo`T0o`00103oP0000`00o`00o`000?l000020?l000D0
003o103oP00;0?l000<0oh00103o0003003o00H0o`000P3oP0000`3o0000003o0000o`040000o`80
oh000`000?l50?n000@0o`000P3oP0030000o`P0oh000`3o00020?n00080o`000`000?l60?n000<0
003o2@3oP0020000o`@0oh0000<0o`000?n0003oP0000P3oP0020?l00080oh000`000?l20?n001So
oooo000Fooooo`L00?l08P3o0004003o00D0o`001000o`050?l00080oh001@3o0002003o00/0o`00
0P000?l00`3o0000oh000?n0000=0?l00080oh002@3o00000`00o`00o`000?l0000D0?l00080oh00
0`3o00020000o`kooooo4P00o`020?l000T00?l000<0o`00003o0000o`000P3o0002003o00<0003o
0P3o00020?n001@00?l00`3o0004003o00`0o`000P00o`060?l000030?n00000o`000?l001/00?l0
0P3o0002003o00D0o`000P000?l20?n000030?l0003oP000oh000080o`003_ooool40?n000D00?l0
103o00000`00o`00oh000?n00002003o00@0o`0000<00?l00?l0003o00001@3o00040?n00080o`00
0P000?l30?n000@0o`000P3oP0000`3o00000?l0003o000=003o0080o`000`000?l40?n000030?l0
003oP000oh0000/0003o1@3oP0040?l000@0003o1@3oP004003o00030?l000000?l0003o0080003o
0`3oP0060?l00080oh0000<0003o0?n0003oP0000P3oP0020?l000800?l000<0o`000000o`000?l0
0P000?l>ooooo`T0o`00103oP0000`00o`00o`000?l000020?l000D0003o103oP00;0?l000<0oh00
103o0003003o00H0o`000P3oP0000`3o0000003o0000o`040000o`80oh000`000?l50?n000@0o`00
0P3oP0030000o`P0oh000`3o00020?n00080o`000`000?l60?n000<0003o2@3oP0020000o`@0oh00
00<0o`000?n0003oP0000P3oP0020?l00080oh000`000?l20?n001Sooooo000Fooooo`800?l00P3o
00000`00o`00o`000?l0000=0?l00080oh0000<00?l00?l0003o00003P3o0004003o00L0o`000P00
o`070?l00080oh00103o00000`3oP0000?l0003o000>0?l00080oh00103o00020?n000L0o`000P3o
P0000`00o`00o`000?l0000B0?l00080oh002@3o00020?n000<0o`000P000?l>ooooob@00?l00P3o
00000`000?l0o`000?l000020?n001800?l01@3o0004003o00/0o`000`00o`060?l001h00?l00P3o
0002003o00L0o`000P3oP0000`3o0000oh000?n000020?l000kooooo3P00o`020?l000800?l00P3o
0005003o00D0o`000P3oP0070?l00080oh00103o00020?n000030?l00000o`000?l000800?l00P3o
0007003o00@0o`000`000?l40?n000<0o`001P000?l30?n00080o`00103oP0000`00o`00o`000?l0
00020?l000@0003o0`3oP0020?l000@00?l01@3o00030?n000800?l0103o00030000o`80o`000P3o
P004003o00030?l000000?l0003o0080003o3_ooool2003o00D0o`000P00o`020?n000<00?l00P3o
00020?n000@0003o1@3oP0050?l000T0oh000P3o00020?n000T0o`000P3oP0030?l000@0003o0`3o
P0020000o`80oh000P3o00030?n000L0003o0P3oP0040?l000D0oh00103o00020000o`L0oh000`00
0?l40?n00080o`000`3oP0020000o`80o`000P3oP0000`00o`00oh000?n000020?n000@0o`000`00
0?l20?n001Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l0000=0?l00080oh0000<00?l0
0?l0003o00003P3o0004003o00L0o`000P00o`070?l00080oh00103o00000`3oP0000?l0003o000>
0?l00080oh00103o00020?n000L0o`000P3oP0000`00o`00o`000?l0000B0?l00080oh002@3o0002
0?n000<0o`000P000?l>ooooob@00?l00P3o00000`000?l0o`000?l000020?n001800?l01@3o0004
003o00/0o`000`00o`060?l001h00?l00P3o0002003o00L0o`000P3oP0000`3o0000oh000?n00002
0?l000kooooo3P00o`020?l000800?l00P3o0005003o00D0o`000P3oP0070?l00080oh00103o0002
0?n000030?l00000o`000?l000800?l00P3o0007003o00@0o`000`000?l40?n000<0o`001P000?l3
0?n00080o`00103oP0000`00o`00o`000?l000020?l000@0003o0`3oP0020?l000@00?l01@3o0003
0?n000800?l0103o00030000o`80o`000P3oP004003o00030?l000000?l0003o0080003o3_ooool2
003o00D0o`000P00o`020?n000<00?l00P3o00020?n000@0003o1@3oP0050?l000T0oh000P3o0002
0?n000T0o`000P3oP0030?l000@0003o0`3oP0020000o`80oh000P3o00030?n000L0003o0P3oP004
0?l000D0oh00103o00020000o`L0oh000`000?l40?n00080o`000`3oP0020000o`80o`000P3oP000
0`00o`00oh000?n000020?n000@0o`000`000?l20?n001Sooooo000Fooooo`800?l00P3o00000`00
o`00o`000?l0000R0?l000800?l01`3o0002003o00L0o`000P000?l20?l00080oh0000<0o`00003o
0000o`003P3o00020?n000@0o`000P3oP0070?l00080oh0000<00?l00?l0003o00000P00o`040?l0
00<00?l02@3o00020?n000<0o`000P3oP0090?l00080003o3_oooolT003o0080o`0000<0003o0?l0
003o00000P3oP00B003o00@0o`001`00o`090?l000D00?l0103o000S003o00H0o`000P3oP0000`3o
0000oh000?n000020?l000kooooo3P00o`060?l000800?l000<0o`00003o0000o`001@3o00020?n0
00d0o`000P3oP0000`3o00000?l0003o0002003o0080o`001`00o`040?l000<0003o0P3o00020?n0
0003003o003o0000o`0000H0003o0`3oP0040?l00080oh0000<00?l00?l0003o00000P00o`050?l0
0080oh002`3o00020?n000<00?l02@3o00020?n000@00?l000<0o`000000o`000?l00P3o000>oooo
o`800?l01`3o00020?n000D00?l00P3o00020?n00080o`000`3oP0020?l00080oh001`3o00090?n0
00L0o`000P000?l30?n00080o`0010000?l30?n000@0003o1@3oP0060000o`<0oh00103o00070?n0
00D0003o103oP0040000o`D0oh000`3o00020?n000@0003o0`3oP0020?l000@0oh001@000?l20?n0
01Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l0000R0?l000800?l01`3o0002003o00L0
o`000P000?l20?l00080oh0000<0o`00003o0000o`003P3o00020?n000@0o`000P3oP0070?l00080
oh0000<00?l00?l0003o00000P00o`040?l000<00?l02@3o00020?n000<0o`000P3oP0090?l00080
003o3_oooolT003o0080o`0000<0003o0?l0003o00000P3oP00B003o00@0o`001`00o`090?l000D0
0?l0103o000S003o00H0o`000P3oP0000`3o0000oh000?n000020?l000kooooo3P00o`060?l00080
0?l000<0o`00003o0000o`001@3o00020?n000d0o`000P3oP0000`3o00000?l0003o0002003o0080
o`001`00o`040?l000<0003o0P3o00020?n00003003o003o0000o`0000H0003o0`3oP0040?l00080
oh0000<00?l00?l0003o00000P00o`050?l00080oh002`3o00020?n000<00?l02@3o00020?n000@0
0?l000<0o`000000o`000?l00P3o000>ooooo`800?l01`3o00020?n000D00?l00P3o00020?n00080
o`000`3oP0020?l00080oh001`3o00090?n000L0o`000P000?l30?n00080o`0010000?l30?n000@0
003o1@3oP0060000o`<0oh00103o00070?n000D0003o103oP0040000o`D0oh000`3o00020?n000@0
003o0`3oP0020?l000@0oh001@000?l20?n001Sooooo000Foooooa00o`000P3oP00G0?l000800?l0
1`3o0002003o00D0o`000P3oP0020000o`80o`000P3oP00>0?l00080003o00<0o`000?n0003oP000
103o00020?n000L0o`000P3oP0000`00o`00o`000?l00002003o00@0o`000`00o`050?l00080oh00
1`3o00020?n000@0o`000`3oP0040?l000kooooo9000o`020?l000030000o`3o0000o`000080oh00
5000o`020?l000D00?l02`3o0005003o0080o`009@00o`060?l00080oh001@3o000>ooooo`h00?l0
0P3o0002003o01@0o`0000<0oh000?l0003o00001P3o00000`3oP0000?l0003o0006003o00030?l0
0000o`000?l000800?l00P3o00020000o`030?l0003oP000oh0000@0o`0000<00?l00?l0003o0000
1P000?l30?n000800?l00P3o0007003o00D0o`000P3oP00;0?l000D00?l00P3o00020000o`80o`00
00<0oh000?l0003o00000P3oP002003o00L0o`003_ooool2003o0080oh001`3o00030?n000800?l0
1P3o00030?n000800?l02@3o00030?n00080o`00103oP0070?l00080oh001@3o00020000o`80o`00
0`3oP0040000o`D0oh000P000?l20?n00080o`0000<0oh000?l0003o00001P3o00000`3oP000o`00
0?l000020?n00080003o0P3oP0000`000?l0o`000?l000020?n00080003o0P3o000:0?n000@0003o
0`3oP0040?l000@0003o00<0oh000000o`000?l00P000?lHooooo`005_ooool@0?l00080oh005`3o
0002003o00L0o`000P00o`050?l00080oh000P000?l20?l00080oh003P3o00020000o`030?l0003o
P000oh0000@0o`000P3oP0070?l00080oh0000<00?l00?l0003o00000P00o`040?l000<00?l01@3o
00020?n000L0o`000P3oP0040?l000<0oh00103o000>ooooob@00?l00P3o00000`000?l0o`000?l0
00020?n001@00?l00P3o0005003o00/0o`001@00o`020?l002D00?l01P3o00020?n000D0o`003_oo
ool>003o0080o`000P00o`0D0?l000030?n0003o0000o`0000H0o`0000<0oh00003o0000o`001P00
o`000`3o00000?l0003o0002003o0080o`000P000?l00`3o0000oh000?n000040?l00003003o003o
0000o`0000H0003o0`3oP002003o0080o`001`00o`050?l00080oh002`3o0005003o0080o`000P00
0?l20?l000030?n0003o0000o`000080oh000P00o`070?l000kooooo0P00o`020?n000L0o`000`3o
P002003o00H0o`000`3oP002003o00T0o`000`3oP0020?l000@0oh001`3o00020?n000D0o`000P00
0?l20?l000<0oh0010000?l50?n00080003o0P3oP0020?l000030?n0003o0000o`0000H0o`0000<0
oh000?l0003o00000P3oP0020000o`80oh0000<0003o0?l0003o00000P3oP0020000o`80o`002P3o
P0040000o`<0oh00103o00040000o`030?n000000?l0003o0080003o6?ooool001Kooooo0P00o`02
0?l00003003o003o0000o`0000L0o`000P00o`020?l000800?l01`3o0002003o00`0o`000P00o`0>
0?l000@0oh000P3o00020?n000h0o`000P000?l00`3o0000oh000?n000060?l00003003o003o0000
o`0000@0o`000P3oP005003o00D0o`000P00o`050?l00080oh003@3o00030?n000@0o`003_oooolT
003o0080o`0000<0003o0?l0003o00000P3oP00D003o0080o`001@00o`0;0?l000030?n00000o`00
0?l000800?l00P3o000I003o0080o`0000<00?l00?l0003o00001`00o`020?n000@0o`000P3oP005
0?l000kooooo0P3o000@003o00L0o`001000o`090?l000030?n0003o0000o`0000H0o`0000<0oh00
0?l0003o00001P00o`000`3o00000?l0003o0002003o00/0o`0000<00?l00?l0003o00000P3o0004
0000o`030?n0003o0000o`0000@0o`000P00o`000`3oP0000?l0003o0002003o00D0o`000P3oP002
0?l00080003o0`3o00020?n000@0o`0000<00?l00?l0003o000010000?l30?n000@0o`000P00o`07
0?l000kooooo0P3o00020?n000030?l000000?l0003o0080oh000P3o00030?n000800?l00P3o0002
0?n000<00?l00P3oP002003o0080oh0000<0o`00003o0000o`000P3o0002003o0080o`0000<0oh00
0?l0003o0000103oP0050?l000@0oh000`3o00020?n000@0003o0`3oP0040000o`D0oh000P000?l2
0?n00080o`000`3oP0040?l000D0003o0P3oP0020000o`80oh000`3o00040?n00080o`0000<0oh00
0?l0003o00001@3oP0020?l000@0003o0`3oP0040?l00080oh000P000?l00`3oP000003o0000o`02
0000oaSooooo000Fooooo`800?l01@3o00020?n000800?l00`3o0002003o01T0o`000P00o`020?l0
00800?l02P3o00040?n00080o`000P3oP0070?l00003003o003o0000o`0000800?l03@3o00000`00
o`00o`000?l000040?l00080oh001@00o`050?l000800?l00P3o0002003o00L0o`000P3oP0070?l0
00<0oh00103o000>ooooob@00?l01@3o00020?n001@00?l00P3o0005003o00L0o`000P000?l20?l0
00030?n00000o`000?l000H00?l000<0o`00003o0000o`006`00o`020?l000<00?l00P3oP0090?l0
00800?l03_ooool40?l000D00?l0103o0007003o00D0o`001000o`0E0?l000H00?l000<0o`00003o
0000o`003@3o00000`00o`00o`000?l000060?l000030?n0003o0000o`0000@0o`000P00o`000`3o
P000o`000?l00002003o00@0o`0000<0003o0?n0003oP0000P3o00020000o`80o`000`3oP0050?l0
0080oh0010000?l50?n00080o`000P00o`050?l00080oh003_ooool20?l00080oh000`000?l20?n0
0080o`000P3oP0050?l00080oh000`3o00020?n000800?l02`3o00030?n000@00?l01@3o00060?n0
00030?l0003oP000oh000080003o1@3oP0040000o`<0oh000P000?l40?n00080o`0000<0oh000?l0
003o00000P3o00070000o`@0oh000`000?l40?n00080o`001@000?l50?n00080o`0010000?l90?n0
0080003o00<0oh000000o`000?l00P000?lHooooo`005_ooool2003o00D0o`000P3oP002003o00<0
o`000P00o`0I0?l000800?l00P3o0002003o00X0o`00103oP0020?l00080oh001`3o00000`00o`00
o`000?l00002003o00d0o`0000<00?l00?l0003o0000103o00020?n000D00?l01@3o0002003o0080
o`000P00o`070?l00080oh001`3o00030?n000@0o`003_oooolT003o00D0o`000P3oP00D003o0080
o`001@00o`070?l00080003o0P3o00000`3oP0000?l0003o0006003o00030?l00000o`000?l001/0
0?l00P3o0003003o0080oh002@3o0002003o00kooooo103o0005003o00@0o`001`00o`050?l000@0
0?l05@3o0006003o00030?l00000o`000?l000d0o`0000<00?l00?l0003o00001P3o00000`3oP000
o`000?l000040?l000800?l000<0oh000?l0003o00000P00o`040?l000030000o`3oP000oh000080
o`000P000?l20?l000<0oh001@3o00020?n000@0003o1@3oP0020?l000800?l01@3o00020?n000ko
oooo0P3o00020?n000<0003o0P3oP0020?l00080oh001@3o00020?n000<0o`000P3oP002003o00/0
o`000`3oP004003o00D0o`001P3oP0000`3o0000oh000?n000020000o`D0oh0010000?l30?n00080
003o103oP0020?l000030?n0003o0000o`000080o`001`000?l40?n000<0003o103oP0020?l000D0
003o1@3oP0020?l000@0003o2@3oP0020000o`030?n000000?l0003o0080003o6?ooool001Kooooo
2@3o0002003o00<0o`000P00o`090?l00080oh00303o00020?n000800?l00P3o0002003o00<0o`00
0P00o`050?l00080oh003@3o00000`00o`00o`000?l00002003o0080o`000P000?lB0?l000030?n0
0000o`000?l000800?l01@3o0002003o00L0o`000P000?l20?l00080oh000`00o`020?l00080003o
0`3oP0040?l000kooooo5000o`020?l001000?l00`3o00020?n001/00?l01`3o00020000o`80o`00
00<0oh00003o0000o`001P00o`000`3o00000?l0003o000K003o0080o`000`00o`020?n00080o`00
0P00o`050?l000800?l03_ooool40?l00003003o003o0000o`0000800?l0103o0007003o00L0o`00
0P00o`070?l00080oh000`3o00020?n000L0o`002`00o`0;0?l00003003o003o0000o`0000@0o`00
0`3oP0060?l000800?l000<0oh000?l0003o00000P3o00050000o`80oh001P3o00000`3oP000o`00
0?l000040000o`030?l0003oP000oh0000@0003o1@3oP0020?l000800?l00P3oP0030?l00080oh00
3_ooool20?l00080oh000`000?l60?n000D0o`0010000?l30?n000800?l01`3o00020?n000<0o`00
0P3oP002003o0080o`000P3oP0000`000?l0o`000?l000040?n000<0o`0010000?l50?n00080o`00
10000?l50?n00080o`000P00o`000`3oP000o`000?l000020?l000D0003o1P3oP0030000o`@0oh00
0P3o00030000o`L0oh000P3o00040000o`L0oh0010000?l30?n00080003o6?ooool001Kooooo2@3o
0002003o00<0o`000P00o`090?l00080oh00303o00020?n000800?l00P3o0002003o00<0o`000P00
o`050?l00080oh003@3o00000`00o`00o`000?l00002003o0080o`000P000?lB0?l000030?n00000
o`000?l000800?l01@3o0002003o00L0o`000P000?l20?l00080oh000`00o`020?l00080003o0`3o
P0040?l000kooooo5000o`020?l001000?l00`3o00020?n001/00?l01`3o00020000o`80o`0000<0
oh00003o0000o`001P00o`000`3o00000?l0003o000K003o0080o`000`00o`020?n00080o`000P00
o`050?l000800?l03_ooool40?l00003003o003o0000o`0000800?l0103o0007003o00L0o`000P00
o`070?l00080oh000`3o00020?n000L0o`002`00o`0;0?l00003003o003o0000o`0000@0o`000`3o
P0060?l000800?l000<0oh000?l0003o00000P3o00050000o`80oh001P3o00000`3oP000o`000?l0
00040000o`030?l0003oP000oh0000@0003o1@3oP0020?l000800?l00P3oP0030?l00080oh003_oo
ool20?l00080oh000`000?l60?n000D0o`0010000?l30?n000800?l01`3o00020?n000<0o`000P3o
P002003o0080o`000P3oP0000`000?l0o`000?l000040?n000<0o`0010000?l50?n00080o`001000
0?l50?n00080o`000P00o`000`3oP000o`000?l000020?l000D0003o1P3oP0030000o`@0oh000P3o
00030000o`L0oh000P3o00040000o`L0oh0010000?l30?n00080003o6?ooool001Kooooo0P00o`02
0?l00003003o003o0000o`0000L0o`000P00o`090?l00080oh000P00o`0:0?l00080oh001`00o`02
0?l000800?l01@3o00020?n000@0o`000P3oP0070?l000D00?l05P3o00000`3oP0000?l0003o0002
003o0100o`00103oP003003o0080o`000P000?l30?n000@0o`003_oooolD003o0080o`00<000o`07
0?l00080003o0P3o00000`3oP0000?l0003o0004003o0080o`007P00o`020?l000<00?l00P3oP002
0?l00080oh001`00o`0>ooooo`@0o`0000<00?l00?l0003o00000P00o`040?l00003003o003o0000
o`000080o`000P00o`0@0?l00080oh000`3o00020?n00080o`000P3oP0000`3o0000oh000?n00002
0?l000T00?l02`3o00000`00o`00o`000?l000090?l00080oh000P3o0002003o00D0o`0010000?l0
0`3o0000oh000?n000090?l000@0003o00<0o`000?n0003oP00010000?l50?n000@0o`000P3oP003
0?l00080003o3_ooool40?l000030?n0003o0000o`0000H0oh001@3o00040000o`<0oh000P00o`05
0?l000@0oh000P3o00030?n000@0o`000`000?l20?l000@0oh000P3o00050000o`D0oh00103o0003
0000o`@0oh000P00o`070?l000D0003o0P3oP0060000o`D0oh000P3o00030000o`@0oh000P3o0000
0`3oP000o`000?l000040000o`L0oh0010000?l30?n00080003o6?ooool001Kooooo0P00o`020?l0
0003003o003o0000o`0000L0o`000P00o`090?l00080oh000P00o`0:0?l00080oh001`00o`020?l0
00800?l01@3o00020?n000@0o`000P3oP0070?l000D00?l05P3o00000`3oP0000?l0003o0002003o
0100o`00103oP003003o0080o`000P000?l30?n000@0o`003_oooolD003o0080o`00<000o`070?l0
0080003o0P3o00000`3oP0000?l0003o0004003o0080o`007P00o`020?l000<00?l00P3oP0020?l0
0080oh001`00o`0>ooooo`@0o`0000<00?l00?l0003o00000P00o`040?l00003003o003o0000o`00
0080o`000P00o`0@0?l00080oh000`3o00020?n00080o`000P3oP0000`3o0000oh000?n000020?l0
00T00?l02`3o00000`00o`00o`000?l000090?l00080oh000P3o0002003o00D0o`0010000?l00`3o
0000oh000?n000090?l000@0003o00<0o`000?n0003oP00010000?l50?n000@0o`000P3oP0030?l0
0080003o3_ooool40?l000030?n0003o0000o`0000H0oh001@3o00040000o`<0oh000P00o`050?l0
00@0oh000P3o00030?n000@0o`000`000?l20?l000@0oh000P3o00050000o`D0oh00103o00030000
o`@0oh000P00o`070?l000D0003o0P3oP0060000o`D0oh000P3o00030000o`@0oh000P3o00000`3o
P000o`000?l000040000o`L0oh0010000?l30?n00080003o6?ooool001Kooooo0P00o`020?l00003
003o003o0000o`0001@0o`000P00o`050?l00080oh000`3o00020?n000800?l00P3o0002003o00<0
o`000P00o`050?l00080oh00103o00020?n001L0o`000P00o`0<0?l000@00?l03P3o00020?n00080
o`000`00o`020?l00080003o0`3oP0040?l000kooooo3P00o`020?l000800?l0103o000`003o00L0
o`000P000?l20?l000030?n00000o`000?l000@00?l00P3o000G003o0080oh002P00o`040?l00080
oh001`00o`0>ooooo`80o`000`00o`020?l000800?l00P3o00020?n000<0o`000P3oP002003o0080
oh000`3o00020?n000T0o`000P3oP0000`3o0000003o0000o`020?n000@0003o00<0o`000?n0003o
P0002`00o`050?l000@0oh000P3o00000`00o`00o`000?l000040?l000<0003o1P3oP002003o00L0
o`000P3oP0000`3o0000oh000?n000090?l000@0003o00<0o`000?n0003oP00010000?l50?n000@0
o`000P3oP0030?l00080003o3_ooool40?l000030?n0003o0000o`0000@00?l00`3o00080000o`<0
oh001000o`000`3oP000o`000?l000020?l00080oh001`00o`020?n00080o`0000<0003o0?n0003o
P000103oP0020?l000L0003o0`3oP0040?l000<0003o103oP002003o0080o`000`000?l20?n000@0
003o0`3oP0060000o`D0oh000P3o00030000o`@0oh000`00o`020?l00080003o2@3oP0040000o`<0
oh000P3o000Hooooo`005_ooool2003o0080o`0000<00?l00?l0003o0000503o0002003o00D0o`00
0P3oP0030?l00080oh000P00o`020?l000800?l00`3o0002003o00D0o`000P3oP0040?l00080oh00
5`3o0002003o00`0o`001000o`0>0?l00080oh000P3o0003003o0080o`000P000?l30?n000@0o`00
3_ooool>003o0080o`000P00o`040?l003000?l01`3o00020000o`80o`0000<0oh00003o0000o`00
1000o`020?l001L00?l00P3oP00:003o00@0o`000P3oP007003o00kooooo0P3o0003003o0080o`00
0P00o`020?l00080oh000`3o00020?n000800?l00P3oP0030?l00080oh002@3o00020?n000030?l0
00000?l0003o0080oh0010000?l00`3o0000oh000?n0000;003o00D0o`00103oP0020?l00003003o
003o0000o`0000@0o`000`000?l60?n000800?l01`3o00020?n000030?l0003oP000oh0000T0o`00
10000?l00`3o0000oh000?n000040000o`D0oh00103o00020?n000<0o`000P000?l>ooooo`@0o`00
00<0oh000?l0003o00001000o`030?l000P0003o0`3oP004003o00030?n0003o0000o`000080o`00
0P3oP007003o0080oh000P3o00000`000?l0oh000?n000040?n00080o`001`000?l30?n000@0o`00
0`000?l40?n000800?l00P3o00030000o`80oh0010000?l30?n000H0003o1@3oP0020?l000<0003o
103oP003003o0080o`000P000?l90?n000@0003o0`3oP0020?l001Sooooo000Fooooo`800?l00P3o
00000`00o`00o`000?l0000@0?l000800?l00P3o0002003o00D0o`000P3oP0050?l000H00?l00`3o
0002003o0080o`000P00o`070?l00080oh007P3o0002003o00<0o`000P00o`020?n000800?l03P3o
00020?n00080o`000`00o`040?l000<0oh00103o000>ooooo`h00?l00P3o0002003o00@0o`00<000
o`020?l000<00?l010000?l20?l000030?n00000o`000?l000T00?l00P3oP007003o0080o`001000
o`000`3o00000?l0003o0002003o0080oh002@00o`050?l00080oh001`00o`0>ooooo`T00?l00P3o
00020000o`<0o`000P3oP002003o0080o`0000<0003o0?l0003o0000103oP0030?l00080oh000P3o
00050?n000H0003o0`3oP0020?l000T00?l01`3o00020?n00080o`0000<00?l00?l0003o00000P3o
00050000o`@0oh000P00o`090?l00080oh0000<0o`000?n0003oP0001P3o00000`000?l0o`000?l0
00020?l00080oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh001P3o00020?n000<0o`000P00
0?l>ooooo`80o`001`3oP002003o00D0o`001`3oP006003o00030?n000000?l0003o0080o`000P3o
P005003o00@0oh000P3o00000`000?l0oh000?n000020?l00080oh000P3o00000`3oP000003o0000
o`040000o`<0oh000P00o`020?l000<0003o203oP0000`3o0000003o0000o`040000o`80o`0000<0
oh000?l0003o00001P000?l30?n00080o`000P3oP0030?l000@0oh002`3o00050?n00080o`001@3o
P0020?l001Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l0000?0?l000<00?l00P3o0002
003o00D0o`000P3oP0050?l000H00?l000<0o`00003o0000o`00103o0002003o02L0o`000P00o`05
0?l00080oh00303o00020000o`80o`000P3oP0090?l00080oh0000<0o`00003o0000o`000P00o`0>
ooooo`h00?l00P3o0002003o0080o`002@00o`050?l00080oh005`00o`020?l000800?l00P3o0003
003o0080oh000`00o`020?l000@0003o0P3o00000`3oP0000?l0003o0009003o0080oh004P00o`02
0?n000X00?l0103o00020?n000L00?l03_ooool;003o00D0o`000P3oP002003o0080o`000`000?l4
0?n000D0o`000P3oP0020?l000<0oh0010000?l50?n000/00?l01@3o00020000o`D0oh001000o`05
0000o`H0oh000`3o00020000o`l0o`000`000?l40?n000<00?l00P3oP002003o00<0o`000P000?l4
0?l00080oh0000<0o`000000o`000?l00P000?l>ooooo`T0oh00103o00050?n00080o`000`3oP006
003o00030?n000000?l0003o0080o`000P3oP002003o00030?n0003o0000o`0000@0oh000P3o0000
0`000?l0oh000?n000020?l00080oh000P3o00000`3oP000o`000?l000040000o`<0oh00103o0003
0000o`P0oh000`3o00040000o`80o`0000<0oh000?l0003o000010000?l50?n000L0o`00103oP002
0?l000030?n0003o0000o`0000800?l00P3oP0020?l00003003o003oP000oh0000800?l00P3oP003
0?l00080oh000P3o000Hooooo`005_ooool2003o0080o`0000<00?l00?l0003o00003`3o0003003o
0080o`000P00o`050?l00080oh001@3o0006003o00030?l00000o`000?l000@0o`000P00o`0W0?l0
00800?l01@3o00020?n000`0o`000P000?l20?l00080oh002@3o00020?n000030?l00000o`000?l0
00800?l03_ooool>003o0080o`000P00o`020?l000T00?l01@3o00020?n001L00?l00P3o0002003o
0080o`000`00o`020?n000<00?l00P3o00040000o`80o`0000<0oh00003o0000o`002@00o`020?n0
01800?l00P3oP00:003o00@0o`000P3oP007003o00kooooo2`00o`050?l00080oh000P00o`020?l0
00<0003o103oP0050?l00080oh000P3o00030?n000@0003o1@3oP00;003o00D0o`000P000?l50?n0
00@00?l01@000?l60?n000<0o`000P000?l?0?l000<0003o103oP003003o0080oh000P00o`030?l0
0080003o103o00020?n000030?l000000?l0003o0080003o3_ooool90?n000@0o`001@3oP0020?l0
00<0oh001P00o`000`3oP000003o0000o`020?l00080oh000P00o`000`3oP000o`000?l000040?n0
0080o`0000<0003o0?n0003oP0000P3o00020?n00080o`0000<0oh000?l0003o000010000?l30?n0
00@0o`000`000?l80?n000<0o`0010000?l20?l000030?n0003o0000o`0000@0003o1@3oP0070?l0
00@0oh000P3o00000`3oP000o`000?l00002003o0080oh000P3o00000`00o`00oh000?n00002003o
0080oh000`3o00020?n00080o`006?ooool001Kooooo0P00o`020?l00003003o003o0000o`000080
o`000P00o`0;0?l000<00?l00P3o0002003o00<0o`000P00o`020?n000<00?l00P3o0002003o0080
o`000P00o`070?l000800?l02@3o00000`00o`00o`000?l000090?l00080oh00403o0002003o00`0
o`001000o`030?l00080003o0P3o00020?n000T0o`000P3oP0000`3o00000?l0003o00020?l000ko
oooo3P00o`020?l000d00?l01@3o00020?n001D00?l01P3o00030?n000800?l00P3oP003003o0080
o`001P000?l00`3oP0000?l0003o0009003o0080oh007P00o`040?l00080oh001`00o`0>ooooo`80
0?l00P3o0007003o00D0o`000P3oP002003o0080o`0000<0003o0?l0003o0000103oP0050?l00080
oh000P3o00000`3oP000o`000?l000040000o`D0oh002@00o`070?l00080003o0P3o00030?n000@0
0?l01@000?l40?n000@0o`000`000?l20?n000T0o`001`000?l40?n000T00?l000<0o`000000o`00
0?l00P000?l20?l00080oh001@000?l>ooooo`80oh000P3o00030?n000@0o`000P000?l00`3oP000
o`000?l000020?n000D0o`000P3oP004003o00<0003o103oP002003o00D0o`000P3oP0020?l00003
0000o`3oP000oh0000H0oh000`3o00040000o`<0oh000P00o`020?l000<0003o203oP0000`00o`00
o`000?l000040000o`80o`0000<0oh000?l0003o00000P3o00020000o`D0oh00103o00020?n000<0
o`000P3oP0020000o`030?l0003oP000oh0000@0oh000P3o00000`00o`00oh000?n00002003o00@0
oh001@3o000Hooooo`005_ooool2003o0080o`0000<00?l00?l0003o00000P3o0002003o00/0o`00
0`00o`020?l000800?l00`3o0002003o0080oh000`00o`020?l000800?l00P3o0002003o00L0o`00
0P00o`090?l00003003o003o0000o`0000T0o`000P3oP00@0?l000800?l0303o0004003o00<0o`00
0P000?l20?l00080oh002@3o00020?n000030?l00000o`000?l00080o`003_ooool>003o0080o`00
3@00o`050?l00080oh005@00o`060?l000<0oh000P00o`020?n000<00?l00P3o00060000o`030?n0
0000o`000?l000T00?l00P3oP00N003o00@0o`000P3oP007003o00kooooo0P00o`020?l000L00?l0
1@3o00020?n000800?l00P3o00000`000?l0o`000?l000040?n000D0o`000P3oP0020?l000030?n0
003o0000o`0000@0003o1@3oP009003o00L0o`000P000?l20?l000<0oh001000o`050000o`@0oh00
103o00030000o`80oh002@3o00070000o`@0oh002@00o`000`3o0000003o0000o`020000o`80o`00
0P3oP0050000o`kooooo0P3oP0020?l000<0oh00103o00020000o`030?n0003o0000o`000080oh00
1@3o00020?n000@00?l00`000?l40?n000800?l01@3o00020?n00080o`0000<0003o0?n0003oP000
1P3oP0030?l000@0003o0`3oP002003o0080o`000`000?l80?n00003003o003o0000o`0000@0003o
0P3o00000`3oP000o`000?l000020?l00080003o1@3oP0040?l00080oh000`3o00020?n00080003o
00<0o`000?n0003oP000103oP0020?l00003003o003oP000oh0000800?l0103oP0050?l001Sooooo
000Fooooo`800?l00P3o00000`00o`00o`000?l00004003o00L0o`000P00o`020?l000L00?l00`3o
000;003o0080o`000P00o`070?l000800?l02@3o0007003o00D0o`000P3oP00Y0?l00080oh00303o
0002003o0080o`003_oooolN003o00@0o`000P3oP00@003o00@0o`0000<00?l00?l0003o00000P00
0?l20?l000<0oh000P3o00020?n000<00?l00P3o00060000o`030?n00000o`000?l000T00?l00P3o
P00[003o00kooooo0P00o`020?n000030?l00000o`000?l00080o`000P00o`020?l000<00?l00P3o
0002003o00h0o`000P00o`030?l000H0003o0`3oP0020?l000d00?l00`3o00020000o`@0o`0000<0
oh00003o0000o`000P00o`050000o`@0oh000P3o00020?n000<0003o0P3oP0040?l000`0003o103o
P0050?l000D00?l00P3o00020000o`80o`000P3oP0030000o`80oh003_ooool20?n00080o`000`3o
P0020?l000D0oh000P3o00040?n000<0o`00103oP002003o00<0003o0P3o00020?n000800?l01@3o
00020?n00080o`000`000?l40?n00080o`0000<0oh000?l0003o00000P3oP0020000o`D0oh000P3o
00030000o`P0oh0000<0o`000?n0003oP000103oP0020?l000030?n0003o0000o`0000@0o`000P3o
P0030?l00080oh000P3o00020?n000<0o`000P3oP0020000o`<0oh000P3o00040?n00003003o003o
P000oh0000800?l02@3oP00Hooooo`005_ooool2003o0080o`0000<00?l00?l0003o00001000o`07
0?l000800?l00P3o0007003o00<0o`002`00o`020?l000800?l01`3o0002003o00T0o`001`00o`05
0?l00080oh00:@3o00020?n000`0o`000P00o`020?l000kooooo7P00o`040?l00080oh004000o`04
0?l00003003o003o0000o`000080003o0P3o00030?n00080o`000P3oP003003o0080o`001P000?l0
0`3oP0000?l0003o0009003o0080oh00:`00o`0>ooooo`800?l00P3oP0000`3o00000?l0003o0002
0?l000800?l00P3o0003003o0080o`000P00o`0>0?l000800?l00`3o00060000o`<0oh000P3o000=
003o00<0o`000P000?l40?l000030?n00000o`000?l000800?l01@000?l40?n00080o`000P3oP003
0000o`80oh00103o000<0000o`@0oh001@3o0005003o0080o`000P000?l20?l00080oh000`000?l2
0?n000kooooo0P3oP0020?l000<0oh000P3o00050?n00080o`00103oP0030?l000@0oh000P00o`03
0000o`80o`000P3oP002003o00D0o`000P3oP0020?l000<0003o103oP0020?l000030?n0003o0000
o`000080oh000P000?l50?n00080o`000`000?l80?n000030?l0003oP000oh0000@0oh000P3o0000
0`3oP000o`000?l000040?l00080oh000`3o00020?n00080o`000P3oP0030?l00080oh000P000?l3
0?n00080o`00103oP0000`00o`00oh000?n00002003o00T0oh006?ooool001Kooooo1000o`0>0?l0
00800?l01@3o0004003o00<0o`001P00o`000`3o00000?l0003o00040?l000800?l04P3o00000`00
o`00o`000?l0000>0?l000@00?l0803o00040?n000`0o`000P00o`020?l000kooooo<000o`080?l0
0003003o003o0000o`000080003o0P3o00030?n000H00?l000<0o`00003o0000o`001P000?l00`3o
P0000?l0003o0009003o0080oh00:`00o`0>ooooo`800?l00P3oP0000`3o00000?l0003o000?0?l0
00030?n00000o`000?l000L0o`000P3oP002003o00<0o`001P000?l20?n000<0o`001000o`020?l0
00L00?l01@3o00020?n00080o`0000<0oh000?l0003o00000P00o`050000o`@0oh000P3o00020?n0
00<0003o0P3oP0040?l000<0003o0P3oP0050000o`H0oh001`3o0003003o0080o`002@000?l20?n0
00kooooo103oP0000`3o0000003o0000o`020?l000D0oh00103o00040?n000030?l0003oP000oh00
0080oh000P00o`000`3o0000003o0000o`020?l00080oh001`3o00020?n00080o`001@000?l20?n0
0080o`0000<0oh000?l0003o00000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3o00030000
o`80oh000P000?l40?n000030?l0003oP000oh000080oh000P000?l20?l000030?n0003o0000o`00
00@0o`000P3oP0000`00o`00o`000?l000020?n00080o`000P3oP0030?l00080oh000P3o000<0?n0
00@00?l01`3oP00Hooooo`005_ooool4003o00<0o`000P00o`090?l000800?l01@3o00020?n00080
0?l000<0o`00003o0000o`000P3o0004003o01T0o`000P00o`080?l000800?l0103o0002003o0003
0?l00000o`000?l000H0o`0000<0oh000?l0003o0000103o0002003o00030?l00000o`000?l00080
o`000P00o`0<0?l000@0oh000P3o00000`00o`00o`000?l00004003o00D0o`000P00o`0>oooooc00
0?l01P3o00020?n000<00?l0103o00030?n000T00?l010000?l20?l000030?n00000o`000?l00280
0?l0103o0002003o00030?l00000o`000?l000/00?l03_ooool2003o00<0o`000P00o`020?l00080
0?l01@3o00020?n000@0o`0000<0oh00003o0000o`001`3o00020?n000800?l00`3o00040000o`@0
oh000`3o0004003o0080o`001`00o`020?l000030000o`3o0000o`000080oh000P3o00000`00o`00
o`000?l000020?l000D0003o103oP0020?l00080oh0000<0o`000?n0003oP0002@3o00020?n000D0
003o103oP0030?l00080oh000P3o00020?n000L0o`002@000?l>ooooo`800?l00P3oP0000`00o`00
003o0000o`020000o`D0oh00103o00040?n000030?l0003oP000oh000080oh000P00o`000`3o0000
003o0000o`020000o`@0oh000`000?l20?l00080oh000P3o00000`3oP000003o0000o`020?l00080
oh000P3o00000`3oP000o`000?l000020?n000D0o`00103oP0020?l000030000o`3oP000oh0000H0
oh0000<0o`000?n0003oP0000P3oP0040?l000030?n0003o0000o`0000@0o`000P3oP003003o00@0
o`000P3oP0000`00o`00oh000?n000020?n000800?l00`3oP004003o00D0oh001000o`020?l000D0
oh006?ooool001Kooooo1000o`030?l000800?l02@3o0002003o00D0o`000P3oP002003o00030?l0
0000o`000?l00080o`001000o`0I0?l000800?l0203o0002003o00@0o`000P00o`000`3o00000?l0
003o00060?l000030?n0003o0000o`0000@0o`000P00o`000`3o00000?l0003o00020?l000800?l0
303o00040?n00080o`0000<00?l00?l0003o00001000o`050?l000800?l03_ooool`003o00H0o`00
0P3oP003003o00@0o`000`3oP009003o00@0003o0P3o00000`3oP0000?l0003o000R003o00@0o`00
0P00o`000`3o00000?l0003o000;003o00kooooo0P00o`030?l000800?l00P3o0002003o00D0o`00
0P3oP0040?l000030?n00000o`000?l000L0o`000P3oP002003o00<0o`0010000?l40?n000<0o`00
1000o`020?l000L00?l00P3o00000`000?l0o`000?l000020?n00080o`0000<00?l00?l0003o0000
0P3o00050000o`@0oh000P3o00020?n000030?l0003oP000oh0000T0o`000P3oP0050000o`@0oh00
0`3o00020?n00080o`000P3oP0070?l000T0003o3_ooool2003o0080oh0000<00?l00000o`000?l0
0P000?l50?n000@0o`00103oP0000`3o0000oh000?n000020?n000800?l000<0o`000000o`000?l0
0P000?l40?n000<0003o0P3o00020?n00080o`0000<0oh000000o`000?l00P3o00020?n00080o`00
00<0oh000?l0003o00000P3oP0050?l000@0oh000P3o00000`000?l0oh000?n000060?n000030?l0
003oP000oh000080oh00103o00000`3oP000o`000?l000040?l00080oh000`00o`040?l00080oh00
00<00?l00?n0003oP0000P3oP002003o00<0oh001000o`050?n000@00?l00P3o00050?n001Sooooo
000Fooooo`@00?l01`3o0003003o00@0o`000P00o`050?l000L00?l0103o0002003o02<0o`000P00
o`040?l000800?l000<0o`00003o0000o`002@3o0009003o0080o`000P00o`0<0?l000@0oh000P3o
00000`00o`00o`000?l00004003o00D0o`000P3oP00>oooooah00?l0103o000>003o00H0o`000P3o
P007003o0080o`0000<0oh00003o0000o`001`00o`040000o`80o`0000<0oh00003o0000o`001P00
o`000`3o00000?l0003o000I003o00@0o`000P00o`000`3oP0000?l0003o000;003o00kooooo1000
o`000`3o00000?l0003o00020?l000800?l01@3o00020?n000`0o`000P00o`020?n000800?l01@3o
00020000o`@0oh0000<0o`000?n0003oP0001000o`020?l000L00?l00`000?l20?l00080oh001`3o
00050000o`@0oh000P3o00020?n000030?l0003oP000oh0000T0o`000P3oP0020?l00080003o00<0
o`000?n0003oP0000P3oP0030?l00080oh002`3o00020000o`80o`001@000?l>ooooo`80o`000`00
o`020?l00080003o1@3oP002003o0080o`00103oP0000`3o0000oh000?n000020?n000800?l00`3o
00020000o`@0oh000`000?l20?l00080oh000P3o00050000o`80oh000P3o00030000o`@0oh000P00
0?l00`3o0000oh000?n000020?n00080o`0000<0003o0?n0003oP000103oP0050?l000@0oh000P3o
00000`3oP000o`000?l000020?n00080o`000P3oP0000`00o`00o`000?l000020?n00080003o0P3o
00050?n000<0o`000P3oP002003o0080o`001@3oP0020?l00080oh000P3o00050?n001Sooooo000F
ooooo`@00?l01`3o0003003o00@0o`000P00o`050?l000L00?l0103o0002003o02<0o`000P00o`04
0?l000800?l000<0o`00003o0000o`002@3o0009003o0080o`000P00o`0<0?l000@0oh000P3o0000
0`00o`00o`000?l00004003o00D0o`000P3oP00>oooooah00?l0103o000>003o00H0o`000P3oP007
003o0080o`0000<0oh00003o0000o`001`00o`040000o`80o`0000<0oh00003o0000o`001P00o`00
0`3o00000?l0003o000I003o00@0o`000P00o`000`3oP0000?l0003o000;003o00kooooo1000o`00
0`3o00000?l0003o00020?l000800?l01@3o00020?n000`0o`000P00o`020?n000800?l01@3o0002
0000o`@0oh0000<0o`000?n0003oP0001000o`020?l000L00?l00`000?l20?l00080oh001`3o0005
0000o`@0oh000P3o00020?n000030?l0003oP000oh0000T0o`000P3oP0020?l00080003o00<0o`00
0?n0003oP0000P3oP0030?l00080oh002`3o00020000o`80o`001@000?l>ooooo`80o`000`00o`02
0?l00080003o1@3oP002003o0080o`00103oP0000`3o0000oh000?n000020?n000800?l00`3o0002
0000o`@0oh000`000?l20?l00080oh000P3o00050000o`80oh000P3o00030000o`@0oh000P000?l0
0`3o0000oh000?n000020?n00080o`0000<0003o0?n0003oP000103oP0050?l000@0oh000P3o0000
0`3oP000o`000?l000020?n00080o`000P3oP0000`00o`00o`000?l000020?n00080003o0P3o0005
0?n000<0o`000P3oP002003o0080o`001@3oP0020?l00080oh000P3o00050?n001Sooooo000Foooo
o`80o`000P00o`070?l000<00?l0103o0002003o01`0o`000P00o`090?l000800?l00P3o0002003o
0140o`000P00o`0=0?l000D00?l0403o00020?n00080o`000P00o`000`3o00000?l0003o0002003o
00D0o`000P3oP002003o00kooooo7P00o`060?l00080oh002P00o`060?l00080oh002@00o`000`3o
00000?l0003o0007003o0080o`000P000?l20?l000030?n00000o`000?l000H00?l000<0o`00003o
0000o`006@00o`040?l000800?l000<0oh00003o0000o`002`00o`0>ooooo`/00?l01@3o00020?n0
0080o`000P3oP0080?l000@00?l02@3o00040?n000030?l0003oP000oh0000d00?l00`000?l20?l0
0080oh001`3o00050000o`80oh000P000?l20?l000D0oh00103o00020?n000<0o`000P00o`0<0?l0
0080oh001P3o00000`000?l0o`000?l000020?l00080003o0P3o00050000o`kooooo1@3o00020?n0
00@0003o0`3oP002003o00@0oh000P000?l50?n000<0o`00103oP0020?l00080oh000`000?l40?n0
0080o`000`000?l20?l00080oh000P3o00030000o`80oh000P3o00020?n000030000o`3oP000oh00
0080oh000P3o00000`000?l0oh000?n000020?l00080oh000P3o00000`3oP000o`000?l000020?l0
0080oh000`00o`020?n00080003o0P3o00030?n000@0o`0010000?l50?n000800?l000<0oh00003o
0000o`001000o`030?l00080oh000P3o00020?n00080o`0000<0oh000?l0003o00000P3o000Hoooo
o`005_ooool20?l000800?l01`3o0003003o00@0o`000P00o`0L0?l000800?l02@3o0002003o0080
o`000P00o`0A0?l000800?l03@3o0005003o0100o`000P3oP0020?l000800?l000<0o`00003o0000
o`000P00o`050?l00080oh000P00o`0>oooooah00?l01P3o00020?n000X00?l01P3o00020?n000T0
0?l000<0o`00003o0000o`001`00o`020?l00080003o0P3o00000`3oP0000?l0003o0006003o0003
0?l00000o`000?l001T00?l0103o0002003o00030?n00000o`000?l000/00?l03_ooool;003o00D0
o`000P3oP0020?l00080oh00203o0004003o00T0o`00103oP0000`3o0000oh000?n0000=003o00<0
003o0P3o00020?n000L0o`001@000?l20?n00080003o0P3o00050?n000@0o`000P3oP0030?l00080
0?l0303o00020?n000H0o`0000<0003o0?l0003o00000P3o00020000o`80o`001@000?l>ooooo`D0
o`000P3oP0040000o`<0oh000P00o`040?n00080003o1@3oP0030?l000@0oh000P3o00020?n000<0
003o103oP0020?l000<0003o0P3o00020?n00080o`000`000?l20?n00080o`000P3oP0000`000?l0
oh000?n000020?n00080o`0000<0003o0?n0003oP0000P3o00020?n00080o`0000<0oh000?l0003o
00000P3o00020?n000<00?l00P3oP0020000o`80o`000`3oP0040?l000@0003o1@3oP002003o0003
0?n00000o`000?l000@00?l00`3o00020?n00080o`000P3oP0020?l000030?n0003o0000o`000080
o`006?ooool001Kooooo1000o`070?l000<00?l00P3o0006003o00L0o`0000<00?l00?l0003o0000
1P3o00000`00o`00o`000?l000020?l000800?l00P3o0003003o0080o`000P00o`090?l000800?l0
1`3o00000`00o`00o`000?l0000F0?l000800?l05`3o0002003o00h0o`003_oooolM003o00L0o`00
0P3oP00:003o0080o`000P00o`020?l00080oh002@00o`000`3o00000?l0003o0007003o0080o`00
0P000?l20?l000030?n00000o`000?l000800?l00P3o0002003o00030?l0003oP000oh0001/00?l0
0P3o0002003o00030?l00000o`000?l000/00?l03_ooool>003o00H0o`000P3oP0080?l000@00?l0
2@3o00040?n000030?l0003oP000oh0000d00?l00`000?l20?l00080oh002@3o00020?n000030?l0
00000?l0003o00@0003o1@3oP0040?l00080oh001`00o`020?l00003003o003o0000o`0000@0o`00
00<00?l00?n0003oP0000P00o`040?l000030000o`3o0000o`0000@0oh000P3o00050000o`kooooo
103o00000`00o`00oh000?n000020?l00080003o0`3oP002003o0080o`0010000?l30?n000D0o`00
103oP0020?l000<0003o103oP0040?l000<0oh000P3o00020?n000<0o`000P000?l60?n000<0o`00
103oP0000`3o0000oh000?n000040?n00080o`0000<0oh000?l0003o00000P3o00020?n000<0o`00
0P3oP0060000o`D0oh0010000?l70?n000<0o`001P00o`000`3o0000oh000?n000020000o`@0oh00
1@3o000Hooooo`005_ooool4003o00L0o`000`00o`020?l000H00?l01`3o00000`00o`00o`000?l0
00060?l00003003o003o0000o`000080o`000P00o`020?l000<00?l00P3o0002003o00T0o`000P00
o`070?l00003003o003o0000o`0001H0o`000P00o`0G0?l000800?l03P3o000>oooooad00?l01`3o
00020?n000X00?l00P3o0002003o0080o`000P3oP009003o00030?l00000o`000?l000L00?l00P3o
00020000o`80o`0000<0oh00003o0000o`000P00o`020?l000800?l000<0o`000?n0003oP0006`00
o`020?l000800?l000<0o`00003o0000o`002`00o`0>ooooo`h00?l01P3o00020?n000P0o`001000
o`090?l000@0oh0000<0o`000?n0003oP0003@00o`030000o`80o`000P3oP0090?l00080oh0000<0
o`000000o`000?l010000?l50?n000@0o`000P3oP007003o0080o`0000<00?l00?l0003o0000103o
00000`00o`00oh000?n00002003o00@0o`0000<0003o0?l0003o0000103oP0020?l000D0003o3_oo
ool40?l00003003o003oP000oh000080o`000P000?l30?n000800?l00P3o00040000o`<0oh001@3o
00040?n00080o`000`000?l40?n000@0o`000`3oP0020?l00080oh000`3o00020000o`H0oh000`3o
00040?n000030?l0003oP000oh0000@0oh000P3o00000`3oP000o`000?l000020?l00080oh000`3o
00020?n000H0003o1@3oP0040000o`L0oh000`3o0006003o00030?l0003oP000oh000080003o103o
P0050?l001Sooooo000Fooooo`800?l02@3o0003003o0080o`001P00o`070?l00003003o003o0000
o`0000@00?l00P3o00000`00o`00o`000?l000020?l000/00?l0;P3o00020?n000@0o`000P00o`0E
0?l00080oh001`3o000>oooooad00?l01`3o00020?n000X00?l00P3o0002003o00@0o`004`00o`06
0?l000030?n00000o`000?l000H00?l000<0o`00003o0000o`006`00o`020?l000800?l000<0o`00
003o0000o`000P3o0009003o00kooooo0P3oP00<003o0080o`000P00o`020?l00080oh001`3o0007
003o00D0o`001P000?l00`3o0000oh000?n00007003o0080o`001000o`030000o`80o`000P3oP00<
0?l000H0003o1@3oP0040000o`80oh0000<0o`00003o0000o`001P3o00000`00o`00o`000?l00004
0?l000L00?l00P3o00030000o`80oh002@000?l>ooooo`@0o`0000<00?l00?n0003oP0002@3oP002
003o00@0003o0`3oP0050?l000@0oh000P3o00050000o`80oh001@3o00020?n00080o`000P3oP002
003o00030?l000000?l0003o00H0oh000`3o00040?n000030?l0003oP000oh0000@0oh000P3o0000
0`3oP000o`000?l000020?l00080oh001`3o00070000o`80oh000P000?l70?n000<0o`000P3oP002
0?l000800?l00`3o00040000o`D0o`000P000?l20?l001Sooooo000Fooooo`800?l00`3o0002003o
0080o`001000o`030?l000H00?l01`3o00000`00o`00o`000?l000090?l000L00?l0103o0002003o
00`0o`000P00o`0;0?l00080003o2@3o00000`3oP000o`000?l000070?l00080oh00103o0002003o
0100o`0000<0oh00003o0000o`001`3o0002003o0080o`003_oooolM003o00L0o`003000o`020?l0
00800?l0103o000C003o00@0o`00:@00o`020?l000800?l01`3o0007003o00kooooo0P3oP005003o
0080o`000P00o`030?l000T00?l01`3o0006003o00<0o`002@000?l20?n000H00?l00`3o0004003o
00D0o`000P3oP00;0?l000L0003o1@3oP0040000o`80oh001@00o`0;0?l000L00?l00P3o00030000
o`@0oh000P000?l00`3o0000003o0000o`020000o`kooooo103oP0000`00o`00o`000?l000020?n0
0080o`000P3oP0000`3o0000oh000?n000020?l00080003o0P3o00050?n000<0o`00103oP0020?l0
00<0003o103oP0020?l000<0oh001000o`020?n000<00?l0103o00040?n000030?l000000?l0003o
0080oh000P3o00050?n000@0o`0000<0oh000?l0003o00000P3o00020?n000<0o`000P3oP0040?l0
00D0003o2`3oP0020000o`030?l0003oP000oh000080o`000P00o`030?l00080003o0P3oP0040?l0
00D0003o6?ooool001Kooooo0P00o`030?l000800?l00P3o0004003o00<0o`001P00o`070?l00003
003o003o0000o`0000T0o`001`00o`040?l000800?l0303o0002003o00/0o`000P000?l90?l00003
0?n0003o0000o`0000L0o`000P3oP0040?l000800?l0403o00000`3oP0000?l0003o00070?l00080
0?l00P3o000>oooooad00?l01`3o000<003o0080o`000P00o`040?l001<00?l0103o000Y003o0080
o`000P00o`070?l000L00?l03_ooool20?n000D00?l00P3o0002003o00<0o`002@00o`070?l000H0
0?l00`3o00090000o`80oh001P00o`030?l000@00?l01@3o00020?n000/0o`001`000?l50?n000@0
003o0P3oP005003o00/0o`001`00o`020?l000<0003o103oP0020000o`030?l000000?l0003o0080
003o3_ooool40?n00003003o003o0000o`000080oh000P3o00020?n000030?l0003oP000oh000080
o`000P000?l20?l000D0oh000`3o00040?n00080o`000`000?l40?n00080o`000`3oP004003o0080
oh000`00o`040?l000@0oh0000<0o`000000o`000?l00P3oP0020?l000D0oh00103o00000`3oP000
o`000?l000020?l00080oh000`3o00020?n000@0o`001@000?l;0?n00080003o00<0o`000?n0003o
P0000P3o0002003o00<0o`000P000?l20?n000@0o`001@000?lHooooo`005_ooool=003o00030?l0
0000o`000?l000H00?l000<0o`00003o0000o`00103o00000`00o`00o`000?l000090?l000H00?l0
0`3o0002003o01T0o`000P3oP0090?l00080oh002P3o00020?n000@0o`000P00o`0J0?l000800?l0
0P3o000>oooooa/00?l00P3oP0000`3o00000?l0003o00020?l002L00?l01P3o0002003o00030?l0
0000o`000?l000800?l00P3oP00P003o0080o`000P00o`070?l000L00?l03_ooool20?n000<00?l0
2@3o0009003o00T0o`001000o`020?l000030?n000000?l0003o00H0003o00<0o`000?n0003oP000
1P00o`030?l000@00?l01@3o00020?n000800?l000<0o`00003o0000o`000P3o0002003o00T0003o
0`3oP0040?l000@0oh000`00o`040?l00080003o00<0o`000000o`000?l00P3oP0020?l000<00?l0
0P3o0002003o0080o`001@000?l20?n00080003o00<0o`000000o`000?l00P000?l>ooooo`@0oh00
00<00?l00?l0003o00000P3oP002003o0080oh0000<0o`000?n0003oP0000P3oP0020000o`80o`00
00<0oh000?l0003o00000P3oP002003o00<0o`000P3oP0020?l000<0003o103oP0020?l000D0oh00
1P00o`030?l000H0oh0000<0o`000000o`000?l0103oP0000`3o00000?l0003o00020?n00080o`00
0P3oP0050?l00080oh000`3o00020?n000800?l00P3o00050000o`@0oh000P3o00050?n000<0003o
0P3oP0060?l000030000o`3o0000o`000080oh000P00o`020?l000D0003o6?ooool001Kooooo3@00
o`000`3o00000?l0003o0006003o00030?l00000o`000?l000@0o`0000<00?l00?l0003o00002@3o
0006003o00<0o`000P00o`0I0?l00080oh002@3o00020?n000X0o`000P3oP0040?l000800?l06P3o
0002003o0080o`003_oooolK003o0080oh0000<0o`00003o0000o`000P3o000W003o00H0o`000P00
o`000`3o00000?l0003o0002003o0080oh008000o`020?l000800?l01`3o0007003o00kooooo0P3o
P003003o00T0o`002@00o`090?l000@00?l00P3o00000`3oP000003o0000o`060000o`030?l0003o
P000oh0000H00?l00`3o0004003o00D0o`000P3oP002003o00030?l00000o`000?l00080o`000P00
o`090000o`<0oh00103o00040?n000<00?l0103o00020000o`030?l000000?l0003o0080oh000P3o
0003003o0080o`000P00o`020?l000D0003o0P3oP0020000o`030?l000000?l0003o0080003o3_oo
ool40?n00003003o003o0000o`000080oh000P00o`020?n000030?l0003oP000oh000080oh000P00
0?l20?l000030?n0003o0000o`000080oh000P00o`030?l00080oh000P3o00030000o`@0oh000P3o
00050?n000H00?l00`3o00060?n000030?l000000?l0003o00@0oh0000<0o`00003o0000o`000P3o
P0020?l00080oh001@3o00020?n000<0o`000P3oP002003o0080o`001@000?l40?n00080o`001@3o
P0030000o`80oh001P3o00000`000?l0o`000?l000020?n000800?l00P3o00050000oaSooooo000F
ooooo`/00?l01@3o0009003o0080o`000`00o`090?l00080oh00103o0002003o00<0o`000P00o`04
0?l00003003o003o0000o`000080o`000P00o`090?l000030?n000000?l0003o0080o`000P3oP00>
0?l000800?l02`3o0002003o00030?l00000o`000?l001L0o`000P00o`020?l000kooooo6`00o`02
0?n000030?l00000o`000?l00080o`006`00o`020?l000T00?l01`3o0002003o00030?l00000o`00
0?l000800?l00P3oP009003o0080o`005@00o`020?l000800?l01`3o0002003o00030?n00000o`00
0?l000800?l03_ooool20?n000<00?l01P3o00020?n000030?l00000o`000?l000/00?l01@3o0002
0?n000800?l00P3o00000`3oP000o`000?l000020000o`80o`000P000?l30?n000H00?l0303o0002
0?n000D00?l00P3o0002003o00<0003o103oP0020?l000<0oh00103o00020?n00080o`000`00o`04
0?l000D0003o103oP0090?l000D0003o0P3oP0050?l00080003o3_ooool70?l00080oh000P3o0002
0?n000030?l0003oP000oh000080oh000P000?l20?l000030?n00000o`000?l000@00?l00`3o0002
0?n00080o`000P000?l50?n000T0o`000P00o`020?l00003003o003o0000o`0000H0oh0000<0o`00
0000o`000?l03@3oP0030000o`80o`00103oP0000`3o0000oh000?n00004003o0080oh0000<0003o
0?n0003oP0000P3o00020?n00080o`0000<0003o0?n0003oP0000P3o00020?n000030000o`3oP000
oh000080003o0P3oP0030000o`@0oh00103o00050000oaSooooo000Fooooo`/00?l01@3o0009003o
0080o`000`00o`090?l00080oh00103o0002003o00<0o`000P00o`040?l00003003o003o0000o`00
0080o`000P00o`090?l000030?n000000?l0003o0080o`000P3oP00>0?l000800?l02`3o0002003o
00030?l00000o`000?l001L0o`000P00o`020?l000kooooo6`00o`020?n000030?l00000o`000?l0
0080o`006`00o`020?l000T00?l01`3o0002003o00030?l00000o`000?l000800?l00P3oP009003o
0080o`005@00o`020?l000800?l01`3o0002003o00030?n00000o`000?l000800?l03_ooool20?n0
00<00?l01P3o00020?n000030?l00000o`000?l000/00?l01@3o00020?n000800?l00P3o00000`3o
P000o`000?l000020000o`80o`000P000?l30?n000H00?l0303o00020?n000D00?l00P3o0002003o
00<0003o103oP0020?l000<0oh00103o00020?n00080o`000`00o`040?l000D0003o103oP0090?l0
00D0003o0P3oP0050?l00080003o3_ooool70?l00080oh000P3o00020?n000030?l0003oP000oh00
0080oh000P000?l20?l000030?n00000o`000?l000@00?l00`3o00020?n00080o`000P000?l50?n0
00T0o`000P00o`020?l00003003o003o0000o`0000H0oh0000<0o`000000o`000?l03@3oP0030000
o`80o`00103oP0000`3o0000oh000?n00004003o0080oh0000<0003o0?n0003oP0000P3o00020?n0
0080o`0000<0003o0?n0003oP0000P3o00020?n000030000o`3oP000oh000080003o0P3oP0030000
o`@0oh00103o00050000oaSooooo000Fooooo`800?l00P3o0005003o00T0o`001`00o`020?l00080
0?l01@3o00020000o`<0o`000P3oP0090?l000800?l0103o00000`00o`00o`000?l000020?l00080
0?l02@3o00000`3oP000o`000?l000020?l00080oh00303o0004003o02H0o`0000<0oh000?l0003o
00000P3o000>oooooa/00?l00P3oP0000`3o00000?l0003o00020?l001/00?l01@3o0002003o0080
o`000P00o`070?l000800?l000<0o`00003o0000o`000P00o`020?n000T00?l00P3o000E003o0080
o`001@00o`020?l000@00?l01@3o000>ooooo`80oh000`00o`060?l00080oh0000<0o`00003o0000
o`002`00o`050?l00080oh001000o`000`3oP000o`000?l000020?l000@0003o0`3oP006003o00T0
o`0000<0003o0?l0003o0000103oP0000`3o00000?l0003o00040?l000<0003o103oP002003o0080
o`0000<0oh000?l0003o00000P3o00020?n000800?l000<0o`00003o0000o`00103o00050000o`@0
oh000`3o00020000o`80o`000P3oP0000`3o0000003o0000o`020000o`80oh000`3o00040000o`ko
oooo0P00o`090?l00080oh000`000?l20?n000@0003o00<0oh000?l0003o00000P3oP002003o00<0
o`000P3oP0040?l000<0oh00103o00020?n000`0o`00103oP0020?l000030?n000000?l0003o00@0
oh000`000?l60?n000<0003o1P3oP0000`3o0000oh000?n00004003o0080o`000`000?l20?l00080
oh000`000?l20?n00080o`000P3oP0000`3o0000oh000?n000040?n000<0003o103oP0040?l000<0
003o0P3oP00Hooooo`005_ooool2003o0080o`001@00o`090?l000L00?l00P3o0002003o00D0o`00
0P000?l30?l00080oh002@3o0002003o00@0o`0000<00?l00?l0003o00000P3o0002003o00T0o`00
00<0oh000?l0003o00000P3o00020?n000`0o`001000o`0V0?l000030?n0003o0000o`000080o`00
3_oooolK003o0080oh0000<0o`00003o0000o`000P3o000K003o00D0o`000P00o`020?l000800?l0
1`3o0002003o00030?l00000o`000?l000800?l00P3oP009003o0080o`005@00o`020?l000D00?l0
0P3o0004003o00D0o`003_ooool20?n000<00?l01P3o00020?n000030?l00000o`000?l000/00?l0
1@3o00020?n000@00?l000<0oh000?l0003o00000P3o00040000o`<0oh001P00o`090?l000030000
o`3o0000o`0000@0oh0000<0o`00003o0000o`00103o00030000o`@0oh000P00o`020?l000030?n0
003o0000o`000080o`000P3oP002003o00030?l00000o`000?l000@0o`001@000?l40?n000<0o`00
0P000?l20?l00080oh0000<0o`000000o`000?l00P000?l20?n000<0o`0010000?l>ooooo`800?l0
2@3o00020?n000<0003o0P3oP0040000o`030?n0003o0000o`000080oh000P00o`030?l00080oh00
103o00030?n000@0o`000P3oP00<0?l000@0oh000P3o00000`3oP000003o0000o`040?n000<0003o
1P3oP0030000o`H0oh0000<0o`000?n0003oP0001000o`020?l000<0003o0P3o00020?n000<0003o
0P3oP0020?l00080oh0000<0o`000?n0003oP000103oP0030000o`@0oh00103o00030000o`80oh00
6?ooool001Kooooo0P00o`030?l000@00?l06@3o00020?n000<0o`000P3oP0070?l000@00?l0503o
00000`3oP000o`000?l0000=0?l000T00?l0303o0002003o00T0o`000P00o`0;0?l000030?n0003o
0000o`000080o`003_ooool2003o0080o`007000o`020?l001/00?l01@3o00020?n000T0o`000P3o
P00B003o0080oh000`3o00020?n001000?l00P3o0005003o0080o`001000o`050?l000kooooo0P3o
P002003o00X0o`003@00o`020?l000030000o`3o0000o`000080oh000P3o0002003o00030?n0003o
0000o`000080o`0010000?l30?n00080o`000P00o`050?l000800?l0103o00000`000?l0o`000?l0
00040?n00003003o003o0000o`000080o`001@000?l40?n000@00?l000<0o`00003o0000o`001000
o`030?l000800?l00P3oP0070000o`@0oh000`3o00020000o`80o`000P3oP0030?l00080003o0P3o
P0030?l000@0003o3_ooool40?l000<0oh000P3o00040?n000T0003o1@3oP0050?l00080oh00103o
00030?n00080o`000P000?l20?n000<0o`000P000?l50?n00080o`00103oP0090?l000<0003o0P3o
P0020000o`<0oh0010000?l40?n000D0o`000P00o`020?l000030?n000000?l0003o0080o`000P00
0?l50?n00080o`000P3oP0030?l000@0003o0P3oP0000`3o0000oh000?n000020?n00080o`000P3o
P0030?l00080oh006?ooool001Kooooo0P00o`030?l000@00?l03@3o00000`3oP000o`000?l00009
0?l00080oh00303o0002003o02@0o`004000o`060?l000P00?l00P3o0004003o00D0o`000P3oP004
0?l00003003o003o0000o`000080o`003_ooool2003o0080o`007000o`020?l001/00?l01@3o0002
0?n000D0o`000P3oP0020?l001@00?l00P3oP0030?l00080oh004000o`020?l000/00?l01@3o000>
ooooo`80oh001@3o0002003o00L0o`001`00o`060?l000030000o`3o0000o`000080oh000P3o0002
003o00030?n0003o0000o`000080o`0010000?l50?n000800?l00`3o0004003o00@0o`0000<0003o
0?l0003o00000P3oP0050?l00080oh001@000?l40?n000@00?l000<0o`00003o0000o`001P00o`03
0?l00080oh001`000?l40?n000<0o`000P000?l20?l00080oh000`3o00020000o`D0o`0010000?l>
ooooo`80o`001@3oP0040?l00080oh002@000?l30?n000800?l00P3o00000`000?l0o`000?l00004
0?n000<0o`000P3oP0040?l00080oh000`3o00020000o`D0oh000P3o00040?n00080o`000`3oP004
0?l000<0003o0P3oP0020000o`<0oh0010000?l40?n000<0o`000P3oP002003o0080o`0000<0oh00
0000o`000?l00P3oP0020000o`D0oh001`3o00020?n00080o`000P3oP0000`3o0000003o0000o`02
0000o`80o`000P3oP0000`000?l0o`000?l000020?n001Sooooo000Fooooo`800?l00`3o0004003o
00d0o`0000<0oh000?l0003o00002@3o00020?n000`0o`000P00o`0T0?l001000?l01P3o0008003o
0080o`001000o`050?l00080oh00103o00000`00o`00o`000?l000020?l000kooooo0P00o`020?l0
01`00?l00P3o000K003o00D0o`000P3oP0050?l00080oh000P3o000D003o0080oh000`3o00020?n0
01000?l00P3o000;003o00D0o`003_ooool20?n000D0o`000P00o`070?l000L00?l01P3o00000`00
0?l0o`000?l000020?n00080o`000P00o`000`3oP000o`000?l000020?l000@0003o1@3oP002003o
00<0o`001000o`040?l000030000o`3o0000o`000080oh001@3o00020?n000D0003o103oP004003o
00030?l00000o`000?l000H00?l00`3o00020?n000L0003o103oP0030?l00080003o0P3o00020?n0
00<0o`000P000?l50?l000@0003o3_ooool20?l000D0oh00103o00020?n000T0003o0`3oP002003o
0080o`0000<0003o0?l0003o0000103oP0030?l00080oh00103o00020?n000<0o`000P000?l50?n0
0080o`00103oP0020?l000<0oh00103o00030000o`80oh000P000?l30?n000@0003o103oP0030?l0
0080oh000P00o`020?l000030?n000000?l0003o0080oh000P000?l50?n000L0o`000P3oP0020?l0
0080oh0000<0o`000000o`000?l00P000?l20?l00080oh0000<0003o0?l0003o00000P3oP00Hoooo
o`005_ooool2003o00<0o`001000o`0o0?l000030000o`3o0000o`000080o`000P3oP0090?l00080
0?l000<0o`00003o0000o`000P3o0002003o00<0o`000P00o`060?l000<00?l01`3o0004003o00D0
o`000P3oP0020?l00080oh001@3o000>ooooo`800?l00P3o000i003o00D0o`000P3oP0050?l00080
oh000P3o000F003o00<0o`004P00o`020?l000/00?l01@3o000>ooooo`80oh002@3o00020?n000<0
o`001P00o`070?l000030000o`3o0000o`000080oh00103o00000`3oP000o`000?l000040?l00080
003o00<0o`000?n0003oP0000P3o0002003o0080o`001@00o`0>0?l000H0003o0`3oP0020000o`80
o`000P3oP009003o00<0o`000P3oP0070000o`@0oh000`3o00020000o`80o`000P3oP003003o0080
003o103o00000`3oP000003o0000o`020000o`kooooo0P3o00050?n000@0003o0`3oP0080000o`03
0?n00000o`000?l000800?l00P3o00030000o`@0oh000P000?l00`3o0000oh000?n000020?n00080
003o0P3oP0030?l00080oh000P3o00030?n000@0003o2@3oP0050000o`80oh0010000?l30?n000@0
o`000`3oP0020?l000@0oh000P3o00030?n000@0003o1@3oP0050?l00080oh00103o00020?n00003
0?l0003oP000oh000080003o0P3o00020?n000030000o`3o0000o`000080oh006?ooool001Kooooo
0P00o`030?l000@00?l0?`3o00000`000?l0o`000?l000020?l00080oh002@3o0002003o00030?l0
0000o`000?l00080o`000P00o`030?l000800?l01P3o0003003o00L0o`001000o`050?l00080oh00
0P3o00020?n000D0o`003_ooool2003o0080o`00>@00o`050?l00080oh001@3o00020?n00080o`00
5P00o`030?l001800?l00P3o000;003o00D0o`003_ooool20?n000T0o`000P3oP0030?l000H00?l0
1`3o00000`000?l0o`000?l000020?n000@0o`0000<0oh000?l0003o0000103o00020000o`030?l0
003oP000oh000080o`000P00o`020?l000D00?l03P3o00060000o`<0oh000P000?l20?l00080oh00
2@00o`030?l00080oh001`000?l40?n000<0o`000P000?l20?l00080oh000`00o`020000o`@0o`00
00<0oh000000o`000?l00P000?l>ooooo`80o`001@3oP0040000o`<0oh0020000?l00`3oP0000?l0
003o0002003o0080o`000`000?l40?n00080003o00<0o`000?n0003oP0000P3oP0020000o`80oh00
0`3o00020?n00080o`000`3oP0040000o`T0oh001@000?l20?n000@0003o0`3oP0040?l000<0oh00
0P3o00040?n00080o`000`3oP0040000o`D0oh001@3o00020?n000@0o`000P3oP0000`3o0000oh00
0?n000020000o`80o`000P3oP0000`000?l0o`000?l000020?n001Sooooo000Fooooo`800?l00P3o
0005003o0280o`001000o`0G0?l00080oh000`3o00040?n000T0o`000P00o`000`3o00000?l0003o
0006003o00030?l00000o`000?l000H0o`000`00o`020?l000800?l00`3o0004003o00<0o`00103o
P0020?l00080oh001@3o000>ooooo`800?l00P3o00000`3oP0000?l0003o00020?n003@00?l01@3o
00020?n000D0o`000P3oP0020?l001H00?l00`3o000O003o00D0o`003_ooool;0?l00080oh001`3o
0002003o00L0o`0000<0003o0?l0003o00000P3oP0020000o`80o`0000<0oh000?l0003o00000P3o
00020?n000<0o`000P3oP0020?l000800?l00P3o0005003o00/0o`0000<0oh000?l0003o00001P00
0?l30?n00080003o0P3o00020?n000`00?l00P3o00070000o`@0oh000`3o00020000o`80o`000P3o
P003003o00@0003o0P3o00000`3oP000003o0000o`020000o`kooooo1@3oP0020?l00080oh000P00
0?l70?n000@0003o00<0oh00003o0000o`001000o`050000o`80oh000P000?l00`3o0000oh000?n0
00060?n000030?l0003oP000oh000080oh000P3o00020?n000L0o`000P000?l50?n000D0003o0P3o
P0020000o`D0oh00103o00050?n00080003o103o00000`3oP000o`000?l000040000o`D0oh000P00
o`020?n000030?l0003oP000oh0000@0o`000P3oP0030?l00080003o0P3o00030?n00080o`000P3o
P00Hooooo`005_ooool2003o0080o`001@00o`0R0?l000@00?l05`3o00020?n000<0o`00103oP009
0?l000800?l000<0o`00003o0000o`001P00o`000`3o00000?l0003o00060?l000<00?l00P3o0002
003o00<0o`001000o`030?l000@0oh000P3o00020?n000D0o`003_ooool2003o0080o`0000<0oh00
003o0000o`000P3oP00d003o00D0o`000P3oP0050?l00080oh000P3o000F003o00<0o`007`00o`05
0?l000kooooo2`3o00020?n000L0o`000P00o`070?l000030000o`3o0000o`000080oh000P000?l2
0?l000030?n0003o0000o`000080o`000P3oP0030?l00080oh000P3o0002003o0080o`001@00o`0;
0?l000030?n0003o0000o`0000H0003o0`3oP0020000o`80o`000P3oP00<003o0080o`001`000?l4
0?n000<0o`000P000?l20?l00080oh000`00o`040000o`80o`0000<0oh000000o`000?l00P000?l>
ooooo`D0oh000P3o00020?n00080003o1`3oP0040000o`030?n00000o`000?l000@00?l01@000?l2
0?n00080003o00<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000020?n00080o`000P3oP007
0?l00080003o1@3oP0050000o`80oh000P000?l50?n000@0o`001@3oP0020000o`@0o`0000<0oh00
0?l0003o000010000?l50?n000800?l00P3oP0000`3o0000oh000?n000040?l00080oh000`3o0002
0000o`80o`000`3oP0020?l00080oh006?ooool001Kooooo2@00o`050?l00080oh002@3o0002003o
0100o`001000o`000`3o00000?l0003o000=0?l000800?l01@3o00020?n000D0o`000P3oP00<0?l0
00P00?l000<0o`00003o0000o`005`3o00020?n000H0o`0000<00?l00?l0003o00000P00o`0>oooo
o`D0o`00>000o`070?l00080003o0`3o00020?n00080o`00>000o`050?l000kooooo0P3oP0090?l0
0080oh001`3o0002003o00L0o`0000<0003o0?l0003o00000P3oP0020000o`80o`0000<0oh000000
o`000?l00P3o00020?n000<0o`000P00o`020?l000800?l00P3o00000`00o`00o`000?l00002003o
00@0o`0000<00?l00?l0003o0000103o00000`3oP000003o0000o`020000o`L0oh0010000?l20?n0
00<00?l00P3oP004003o00030?l00000o`000?l000@0o`000`000?l40?n000T0o`000P3oP003003o
00H0003o00<0oh000000o`000?l00P000?l>ooooo`80o`000`3oP002003o00@0003o0`3oP0020?l0
00H0003o0`3oP004003o00<0003o0P3o00020?n000D0o`001P3oP0030?l00080oh000P00o`020?n0
0003003o003o0000o`0000@0o`000`000?l40?n000T0003o0P3oP0000`3o0000oh000?n00002003o
0080o`001@3oP0040?l000<0oh000P3o00040000o`D0oh000P3o0002003o00030?l0003oP000oh00
00@00?l00P3o00000`3oP000o`000?l000020?n00080o`000P3oP0000`000?l0o`000?l000020?n0
01Sooooo000Fooooo`T00?l01@3o00020?n000L00?l02`3o0002003o0280o`000P3oP00:0?l00080
0?l01`3o0002003o0080o`001000o`0C0?l000800?l02`3o0003003o0080o`000P00o`0>ooooo`80
oh000P3o000i003o0080o`000`00o`060?l000<0oh00103o0005003o00H0o`0000<0oh000?l0003o
0000:000o`050?l000kooooo0P3oP002003o00L0o`000P3oP0070?l000800?l000<0o`000000o`00
0?l00P3o00020?n000030000o`3o0000o`000080oh0010000?l00`3oP000003o0000o`020?l000D0
oh000P00o`020?l000800?l00P3o00000`00o`00o`000?l000040?l000<00?l01P3o00000`3oP000
003o0000o`020000o`@0oh0000<00?l00?n0003oP00010000?l20?n000<00?l00P3oP009003o0080
o`000`000?l40?n000/0o`000`00o`060?l000030?n000000?l0003o0080003o3_ooool20?l00080
oh000`00o`020?n000@0o`0000<0oh000000o`000?l00P000?l20?n00080o`000`3oP004003o00D0
o`000P3oP0050?l000H0oh000`3o00020?n000@00?l000<0oh000?l0003o00001P3o00000`000?l0
oh000?n000020?n000<0o`001P000?l20?n000030?l00000o`000?l000800?l00P3o00050?n000@0
o`001@3oP0020?l000L0oh001000o`000`3o0000oh000?n000060?l000030?n0003o0000o`0000H0
o`0000<0oh000?l0003o00000P3o000Hooooo`005_ooool9003o00D0o`000P3oP007003o00/0o`00
0P00o`0R0?l00080oh002P3o0002003o00L0o`000P00o`020?l000@00?l04`3o0002003o00/0o`00
0`00o`020?l000800?l03_ooool20?n00080o`00>@00o`020?l000<00?l01P3o00030?n000@0o`00
1@00o`060?l000030?n0003o0000o`0002P00?l01@3o000>ooooo`80oh000P00o`070?l00080oh00
1`3o0002003o00030?l000000?l0003o0080o`000P3oP0000`000?l0o`000?l000020?n000@0003o
00<0oh000000o`000?l00P3o00050?n000800?l00P3o0002003o0080o`0000<00?l00?l0003o0000
103o0003003o00H0o`0000<0oh000000o`000?l00P000?l40?n00003003o003oP000oh0000@0003o
0P3oP003003o0080oh002@00o`020?l000<0003o103oP00;0?l000<00?l01P3o00000`3oP000003o
0000o`020000o`kooooo0P3o00020?n000<00?l00P3oP0040?l000030?n000000?l0003o0080003o
0P3oP0020?l000<0oh001000o`050?l00080oh001@3o00060?n000<0o`000P3oP004003o00030?n0
003o0000o`0000H0o`0000<0003o0?n0003oP0000P3oP0030?l000H0003o0P3oP0000`3o00000?l0
003o0002003o0080o`001@3oP0040?l000D0oh000P3o00070?n000@00?l000<0o`000?n0003oP000
1P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`000080o`006?ooool001Kooooo3@00
o`050?l000D00?l02@3o0004003o0180o`000P00o`070?l000800?l01@3o00020?n000T0o`002@00
o`070?l000800?l01@3o00020?n000X0o`000P00o`0;0?l000@00?l00`3o0002003o00kooooo0P3o
000<003o0080o`00;@00o`020?l000<00?l01P3o00030?n000@0o`000P3oP003003o00H0o`0000<0
oh000?l0003o0000:`00o`020?l000kooooo0P3oP002003o00L0o`000P3oP0050?l000@00?l000<0
o`000000o`000?l00P000?l30?n00080o`000P3oP00;0000o`<0oh000P00o`0;0?l000L00?l00P3o
0002003o00D0o`000P3oP0020?l00003003o003o0000o`0000@0003o0P3oP003003o0080oh000P00
o`030?l000800?l0103o00030000o`@0oh000P000?l90?l000<00?l00P3o0002003o00<0o`001000
0?l>ooooo`L00?l00P3oP002003o0080oh001@000?l20?n00080o`0000<0003o0?n0003oP0000P3o
P0020?l000030?n0003o0000o`000080o`000P3oP0070?l000@0oh000`3o00020?n000@0o`0000<0
oh000?l0003o00001P3o00000`000?l0oh000?n000090?l000@0oh002@00o`030?l000800?l00P3o
00020?n000D0o`000P3oP0020?l000030?n00000o`000?l000L00?l01P3o00000`3oP000o`000?l0
00060?l000<0oh000P3o000Hooooo`005_ooool=003o00D0o`001@00o`090?l000@00?l04P3o0002
003o00L0o`000P00o`050?l00080oh002@3o0009003o00L0o`000P00o`050?l00080oh002P3o0002
003o00/0o`001000o`030?l000800?l03_ooool20?l000`00?l00P3o000]003o0080o`000`00o`06
0?l000<0oh00103o00020?n000<00?l01P3o00000`3oP000o`000?l0000[003o0080o`003_ooool2
0?n000800?l01`3o00020?n000D0o`001000o`000`3o0000003o0000o`020000o`<0oh000P3o0002
0?n000/0003o0`3oP002003o00/0o`001`00o`020?l000800?l01@3o00020?n00080o`0000<00?l0
0?l0003o000010000?l20?n000<00?l00P3oP002003o00<0o`000P00o`040?l000<0003o103oP002
0000o`T0o`000`00o`020?l000800?l00`3o00040000o`kooooo1`00o`020?n000800?l00P3oP005
0000o`80oh000P3o00000`000?l0oh000?n000020?n00080o`0000<0oh000?l0003o00000P3o0002
0?n000L0o`00103oP0030?l00080oh00103o00000`3oP000o`000?l000060?l000030000o`3oP000
oh0000T0o`00103oP009003o00<0o`000P00o`020?l00080oh001@3o00020?n00080o`0000<0oh00
003o0000o`001`00o`060?l000030?n0003o0000o`0000H0o`000`3oP0020?l001Sooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05
oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolGo`00o`Cooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooo
oaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`001?oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool000Cooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`001Ol0
07lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o
001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001E
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`1^o`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooog;o00009ooooomao`0002Oooooo
LOl0000Wooooog;o00008oooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool001Kooooo
2@00o`0N0?l000800?l01`3o0002003o00@0o`000`3oP0020?l000800?l03P3o0002003o01L0o`00
0P00o`060?l00003003o003o0000o`0000/0o`000P3oP00>0?l000kooooo1000o`030?l000800?l0
103o000E003o0080o`004P00o`070?l000@00?l000<0o`00003o0000o`00;`00o`070?l000L00?l0
103o0005003o00kooooo0P3o0014003o00L0o`00?@00o`0>ooooo`d0oh001`3o00050?n000@0o`00
1`3oP0070?l000L0oh003@3o00030?n00080o`000P3oP0050?l001d0oh001@3o00040?n000D0o`00
1P3oP0000`3o0000oh000?n0000;0?n001Sooooo000Fooooo`T00?l07P3o0002003o00L0o`000P00
o`040?l000<0oh000P3o0002003o00h0o`000P00o`0G0?l000800?l01P3o00000`00o`00o`000?l0
000;0?l00080oh003P3o000>ooooo`@00?l00`3o0002003o00@0o`005@00o`020?l001800?l01`3o
0004003o00030?l00000o`000?l002l00?l01`3o0007003o00@0o`001@00o`0>ooooo`80o`00A000
o`070?l003d00?l03_ooool=0?n000L0o`001@3oP0040?l000L0oh001`3o00070?n000d0o`000`3o
P0020?l00080oh001@3o000M0?n000D0o`00103oP0050?l000H0oh0000<0o`000?n0003oP0002`3o
P00Hooooo`005_ooool2003o0080o`0000<00?l00?l0003o00002`3o0002003o00D0o`000P00o`0<
0?l000800?l01`3o0002003o00@0o`000`3oP0020?l000800?l01`3o0002003o00D0o`000P00o`05
0?l00080oh009P3o00030?n000P0o`000`3oP0020?l000kooooo0P00o`070?l001L00?l01`3o000?
003o00<0o`000P00o`020?l000@00?l01@3o000K003o0080o`004@00o`020?l000/00?l0103o0005
003o00kooooo0P3o000k003o0080o`002@00o`030?l001H00?l00P3o000L003o0080o`002@00o`0>
ooooo`T0oh000P3o00030?n000P0o`0000<0oh000?l0003o0000103o00050?n00080o`000P3oP003
0?l001P0oh003P3o00050?n00080o`000P3oP0020?l00100oh000`3o000?0?n000030?l0003oP000
oh0000/0oh006?ooool001Kooooo0P00o`020?l00003003o003o0000o`0000/0o`000P00o`050?l0
00800?l0303o0002003o00L0o`000P00o`040?l000<0oh000P3o0002003o00L0o`000P00o`050?l0
00800?l01@3o00020?n002H0o`000`3oP0080?l000<0oh000P3o000>ooooo`800?l01`3o000G003o
00L0o`003`00o`030?l000800?l00P3o0004003o00D0o`006`00o`020?l001400?l00P3o000;003o
00@0o`001@00o`0>ooooo`80o`00>`00o`020?l000T00?l00`3o000F003o0080o`007000o`020?l0
00T00?l03_ooool90?n00080o`000`3oP0080?l000030?n0003o0000o`0000@0o`001@3oP0020?l0
0080oh000`3o000H0?n000h0o`001@3oP0020?l00080oh000P3o000@0?n000<0o`003`3oP0000`3o
0000oh000?n0000;0?n001Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l000040?l00080
0?l01@3o0004003o0140o`001000o`0;0?l000<0oh002`3o0002003o00/0o`000`3oP00M0?l00080
0?l000<0o`00003o0000o`000P00o`020?l00080oh002@3o00050?n000kooooo1000o`000`3o0000
0?l0003o000_003o00<0o`002@00o`040?l004@00?l03_ooool50?l003P00?l00P3o000:003o0080
o`005P00o`020?l001`00?l00P3o0009003o00kooooo2@3oP0020?l000<0oh00203o00050?n00080
o`005`3oP0070?l000H0oh005@3o000G0?n000T0o`003@3oP0020?l000D0oh006?ooool001Kooooo
103o00000`00o`00o`000?l000040?l000800?l01`3o0002003o00D0o`000P00o`0<0?l000800?l0
6@3o0002003o00`0o`000P3oP00P0?l000@00?l01`3o0004003o0080o`001@3oP00>ooooo`@00?l0
00<0o`00003o0000o`00>P00o`080?l002d00?l0103o000@003o00kooooo1@3o0025003o00kooooo
103oP0030?l00080oh000P3o00020?n000T0o`007P3oP0020?l00080oh003P3o00020?n000D0o`00
1`3oP0060?l00180oh0000<0o`000?n0003oP0000P3oP0050?l000L0oh001P3o00050?n00080o`00
6?ooool001Kooooo103o00000`00o`00o`000?l000040?l000800?l01`3o0002003o00D0o`000P00
o`0<0?l000800?l06@3o0002003o00`0o`000P3oP00P0?l000@00?l01`3o0004003o0080o`001@3o
P00>ooooo`@00?l000<0o`00003o0000o`00>P00o`080?l002d00?l0103o000@003o00kooooo1@3o
0025003o00kooooo103oP0030?l00080oh000P3o00020?n000T0o`007P3oP0020?l00080oh003P3o
00020?n000D0o`001`3oP0060?l00180oh0000<0o`000?n0003oP0000P3oP0050?l000L0oh001P3o
00050?n00080o`006?ooool001Kooooo2`3o0003003o00d0o`000`00o`080?l00003003o003o0000
o`0003/0o`000P00o`020?l000@00?l04`3o0004003o00L0o`003_oooom1003o00P0o`00@@00o`0>
ooooo`D0o`00;`00o`070?l000h00?l0203o000i003o00kooooo4P3oP0020?l000L0oh000`3o000F
0?n000D0o`003@3oP0050?l00240oh000`3o000@0?n000T0o`000P3oP00Hooooo`005_ooool;0?l0
00<00?l03@3o0003003o00P0o`0000<00?l00?l0003o0000>`3o0002003o0080o`001000o`0C0?l0
00@00?l01`3o000>oooood400?l0203o0011003o00kooooo1@3o000_003o00L0o`003P00o`080?l0
03T00?l03_oooolB0?n00080o`001`3oP0030?l001H0oh001@3o000=0?n000D0o`008@3oP0030?l0
0100oh002@3o00020?n001Sooooo000Fooooo`/0o`000P00o`0I0?l00003003o003o0000o`0000L0
o`000P00o`0?0?l00003003o003o0000o`0001/0o`000P00o`0I0?l000800?l01@3o0004003o00D0
o`003_oooom1003o00<0o`000P00o`020?l004800?l03_ooool50?l004@00?l0203o000i003o00ko
oooo4P3oP0020?l001h0oh00103o00020?n000030?l0003oP000oh0000d0oh000`3o000;0?n000D0
o`001P3oP0020?l002<0oh00103o000Hooooo`005_ooool;0?l000800?l06@3o00000`00o`00o`00
0?l000070?l000800?l03`3o00000`00o`00o`000?l0000K0?l000800?l06@3o0002003o00D0o`00
1000o`050?l000kooooo@@00o`030?l000800?l00P3o0012003o00kooooo1@3o0014003o00P0o`00
>@00o`0>oooooa80oh000P3o000N0?n000@0o`000P3oP0000`3o0000oh000?n0000=0?n000<0o`00
2`3oP0050?l000H0oh000P3o000S0?n000@0o`006?ooool001Kooooo0P3o0002003o00L0o`000P00
o`0<0?l000800?l0503o0003003o01T0o`000P00o`0B0?l000800?l02@3o0002003o0100o`0000<0
0?l00?l0003o00001`3o0004003o00koooooB`00o`060?l003T00?l03_ooool2003o0080o`003000
o`020?l000800?l00P3o000J003o0080o`001000o`020?l001<00?l02@3o000T003o0080o`002`00
o`000`3o00000?l0003o0002003o00kooooo6@3oP0020?l000h0oh000P3o000D0?n00080o`001`3o
P0000`3o0000oh000?n0000F0?n00080o`008`3oP0020?l00080oh006?ooool001Kooooo1000o`07
0?l000800?l01`3o0002003o00<0o`000P00o`070?l000D00?l0203o0003003o02d0o`000P00o`0U
0?l000800?l00P3o000>oooood/00?l01P3o000i003o00kooooo8P00o`020?l000/00?l000<0o`00
003o0000o`006@00o`090?l002000?l01P3o0009003o0080o`001@00o`0>oooooaT0oh000P3o000N
0?n00080o`003@3oP0000`3o0000oh000?n0000;0?n00080o`006@3oP0070?l00080oh000P3o0003
0?n00080o`000P3oP0020?l000D0oh006?ooool001Kooooo1000o`070?l000800?l01`3o0002003o
00<0o`000P00o`070?l000D00?l0203o0003003o02d0o`000P00o`0U0?l000800?l00P3o000>oooo
od/00?l01P3o000i003o00kooooo8P00o`020?l000/00?l000<0o`00003o0000o`006@00o`090?l0
02000?l01P3o0009003o0080o`001@00o`0>oooooaT0oh000P3o000N0?n00080o`003@3oP0000`3o
0000oh000?n0000;0?n00080o`006@3oP0070?l00080oh000P3o00030?n00080o`000P3oP0020?l0
00D0oh006?ooool001Kooooo1@00o`060?l000800?l05`3o0003003o01@0o`000P00o`070?l00080
0?l01`3o0002003o00h0o`000P00o`0;0?l000800?l00`3o0002003o00`0o`000P00o`0;0?l000ko
ooooB`00o`060?l002h00?l00P3o0009003o00kooooo8P00o`020?l000D00?l00P3o000D003o0080
o`002P00o`060?l00003003o003o0000o`0001000?l00P3o0004003o0080o`002000o`060?l00100
0?l03_ooool=0?n000X0o`000P3oP0020?l002H0oh0000<0o`000?n0003oP0000P3o000<0?n000P0
o`005@3oP0050?l000/0oh000P3o00070?n00080o`006?ooool001Kooooo1@00o`060?l000800?l0
5`3o0003003o01@0o`000P00o`070?l000800?l01`3o0002003o00h0o`000P00o`0;0?l000800?l0
0`3o0002003o00`0o`000P00o`0;0?l000koooooB`00o`060?l002h00?l00P3o0009003o00kooooo
8P00o`020?l000D00?l00P3o000D003o0080o`002P00o`060?l00003003o003o0000o`0001000?l0
0P3o0004003o0080o`002000o`060?l001000?l03_ooool=0?n000X0o`000P3oP0020?l002H0oh00
00<0o`000?n0003oP0000P3o000<0?n000P0o`005@3oP0050?l000/0oh000P3o00070?n00080o`00
6?ooool001Kooooo1000o`050?l000@00?l0403o00000`00o`00o`000?l000060?l00003003o003o
0000o`0000@0o`000`00o`0F0?l000800?l01@3o0002003o00h0o`000P00o`050?l000800?l0103o
0002003o00<0o`000P00o`0<0?l000@00?l02@3o000>oooooah00?l02@3o0002003o0080o`007@00
o`0:0?l002X00?l02@3o0005003o00kooooo?`00o`020?l000`00?l01`3o000=003o0080o`005@00
o`040?l000h00?l03_ooool=0?n000030?l0003oP000oh0000@0oh002P3o00080?n000030?l0003o
P000oh0001H0oh001`3o00070?n000/0o`006@3oP0070?l000L0oh00103o00070?n001Sooooo000F
ooooo`@00?l01@3o0004003o0100o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l00004
0?l000<00?l05P3o0002003o00D0o`000P00o`0>0?l000800?l01@3o0002003o00@0o`000P00o`03
0?l000800?l0303o0004003o00T0o`003_oooolN003o00T0o`000P00o`020?l001d00?l02P3o000Z
003o00T0o`001@00o`0>ooooocl00?l00P3o000<003o00L0o`003@00o`020?l001D00?l0103o000>
003o00kooooo3@3oP0000`3o0000oh000?n000040?n000X0o`00203oP0000`3o0000oh000?n0000F
0?n000L0o`001`3oP00;0?l001T0oh001`3o00070?n000@0o`001`3oP00Hooooo`005_ooool2003o
00L0o`001000o`0@0?l000<00?l08@3o00000`00o`00o`000?l0000[0?l000@00?l0303o0002003o
00T0o`003_oooolT003o0080o`008`00o`090?l002/00?l00P3o000;003o00kooooo:@00o`020?l0
05l00?l03_ooool20?l00100oh00303o000Q0?n000L0o`001`3oP0040?l000030?n0003o0000o`00
0080o`006@3oP0070?l000/0oh001@3o00040?n001Sooooo000Fooooo`800?l01`3o0004003o0100
o`000`00o`0Q0?l00003003o003o0000o`0002/0o`001000o`0<0?l000800?l02@3o000>ooooob@0
0?l00P3o000S003o00T0o`00:`00o`020?l000/00?l03_oooolY003o0080o`00G`00o`0>ooooo`80
o`00403oP00<0?l00240oh001`3o00070?n000@0o`0000<0oh000?l0003o00000P3o000I0?n000L0
o`002`3oP0050?l000@0oh006?ooool001Kooooo1@00o`060?l000800?l0303o0002003o0080o`00
0`00o`070?l000800?l0BP3o00000`00o`00o`000?l0000D0?l000kooooo9000o`070?l001h00?l0
2`3o000X003o00T0o`001@00o`0>ooooohX00?l03_ooool40?l00180oh001`3o000R0?n000<0o`00
8P3oP0020?l002@0oh006?ooool001Kooooo1@00o`060?l000800?l03P3o0003003o00T0o`001000
o`050?l000800?l07`3o0003003o01P0o`0000<00?l00?l0003o00006`3o000>ooooodT00?l0103o
0005003o0080o`00:000o`090?l000D00?l03_oooom;003o0080o`00?@00o`0>ooooo`/0oh001@3o
00020?n00080o`001`3oP0090?l000h0oh001`3o00020?n000L0o`00B03oP00Hooooo`005_ooool5
003o00H0o`000P00o`0>0?l000<00?l02@3o0004003o00D0o`000P00o`0O0?l000<00?l0603o0000
0`00o`00o`000?l0000K0?l000koooooB@00o`040?l000D00?l00P3o000X003o00T0o`001@00o`0>
oooood/00?l00P3o000m003o00kooooo2`3oP0050?l00080oh000P3o00070?n000T0o`003P3oP007
0?l00080oh001`3o00180?n001Sooooo000Fooooo`D00?l01P3o0002003o00L0o`000P00o`050?l0
00<00?l0203o00000`00o`00o`000?l00002003o00D0o`001000o`0V0?l00003003o003o0000o`00
00L0o`001000o`040?l00003003o003o0000o`000080o`000P3oP0070?l00080oh0000<0o`00003o
0000o`002`3o000>ooooob@00?l00P3o000U003o0080o`001@00o`020?l002T00?l0203o0005003o
00koooooB`00o`060?l001<00?l0103o000R003o00kooooo5`3oP0020?l00080oh000P3o00030?n0
0080o`00403oP0020?l00080oh000`3o00020?n000@0o`001`3oP0030?l002/0oh001P3o000@0?n0
01Sooooo000Fooooo`D00?l01P3o0002003o00L0o`000P00o`050?l000<00?l0203o00000`00o`00
o`000?l00002003o00D0o`001000o`0V0?l00003003o003o0000o`0000L0o`001000o`040?l00003
003o003o0000o`000080o`000P3oP0070?l00080oh0000<0o`00003o0000o`002`3o000>ooooob@0
0?l00P3o000U003o0080o`001@00o`020?l002T00?l0203o0005003o00koooooB`00o`060?l001<0
0?l0103o000R003o00kooooo5`3oP0020?l00080oh000P3o00030?n00080o`00403oP0020?l00080
oh000`3o00020?n000@0o`001`3oP0030?l002/0oh001P3o000@0?n001Sooooo000Fooooo`D00?l0
0P3o0002003o0080o`000P00o`070?l000800?l01`3o00000`00o`00o`000?l000060?l00003003o
003o0000o`0000@0o`002@00o`050?l000@00?l01@3o0002003o00L0o`000P00o`0U0?l000800?l0
1`3o0002003o00/0o`003_oooolN003o0080o`00:`00o`020?l003800?l00P3o0002003o0080o`00
1@00o`0>ooooobL00?l0103o000P003o00H0o`004P00o`070?l001T00?l00P3o0005003o00kooooo
3@3oP0000`3o0000oh000?n000070?n00080o`002@3oP0050?l00080oh00103o00020?n000<0o`00
1`3oP0060?l000D0oh001@3o000[0?n000H0o`00403oP00Hooooo`005_ooool5003o0080o`000P00
o`020?l000800?l01`3o0002003o00L0o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l0
00040?l000T00?l01@3o0004003o00D0o`000P00o`070?l000800?l09@3o0002003o00L0o`000P00
o`0;0?l000kooooo7P00o`020?l002/00?l00P3o000b003o0080o`000P00o`020?l000D00?l03_oo
oolW003o00@0o`008000o`060?l001800?l01`3o000I003o0080o`001@00o`0>ooooo`d0oh0000<0
o`000?n0003oP0001`3oP0020?l000T0oh001@3o00020?n000@0o`000P3oP0030?l000L0oh001P3o
00050?n000D0o`00:`3oP0060?l00100oh006?ooool001Kooooo1000o`050?l000@00?l000<0o`00
003o0000o`000P00o`020?l000800?l01`3o0003003o00H0o`0000<00?l00?l0003o00001P3o0000
0`00o`00o`000?l000040?l000800?l01`3o0002003o00`0o`000P00o`0U0?l000800?l01`3o0004
003o00@0o`000`3oP0020?l000kooooo7P00o`020?l002/00?l00P3o000m003o00kooooo9`00o`02
0?l002800?l01`3o000D003o0080o`006`00o`020?l000D00?l03_ooool>0?n000@0o`009P3oP007
0?l000D0oh00103o00070?n00080o`008P3oP0090?l000h0oh006?ooool001Kooooo1000o`050?l0
00@00?l000<0o`00003o0000o`000P00o`020?l000800?l01`3o0003003o00H0o`0000<00?l00?l0
003o00001P3o00000`00o`00o`000?l000040?l000800?l01`3o0002003o00`0o`000P00o`0U0?l0
00800?l01`3o0004003o00@0o`000`3oP0020?l000kooooo7P00o`020?l002/00?l00P3o000m003o
00kooooo9`00o`020?l002800?l01`3o000D003o0080o`006`00o`020?l000D00?l03_ooool>0?n0
00@0o`009P3oP0070?l000D0oh00103o00070?n00080o`008P3oP0090?l000h0oh006?ooool001Ko
oooo1@00o`060?l000800?l01`3o0002003o00030?l00000o`000?l000800?l00P3o00000`00o`00
o`000?l000060?l00003003o003o0000o`0000H0o`0000<00?l00?l0003o0000103o0003003o00H0
o`000P00o`070?l00003003o003o0000o`000080o`001000o`0B0?l00003003o003o0000o`000080
o`000P00o`090?l00003003o003o0000o`0000800?l01`3o0002003o00@0o`000`3oP0020?l000ko
ooooB`00o`020?l003H00?l00`3o0004003o00kooooo9`00o`020?l002800?l01`3o000a003o0080
o`001@00o`0>ooooo`/0oh001`3o000B0?n000<0o`00103oP0020?l000/0oh000`3o00090?n000D0
o`002`3oP0020?l00280oh00103o000>0?n001Sooooo000Fooooo`D00?l01P3o0002003o00L0o`00
0P00o`0:0?l000800?l0103o00000`00o`00o`000?l000060?l000<00?l01P3o00000`00o`00o`00
0?l0000@0?l000800?l00P3o0002003o01<0o`000P00o`0=0?l00003003o003o0000o`0000H00?l0
0`3o0002003o00L0o`000P00o`0>ooooohD00?l000<0o`00003o0000o`000P00o`0>oooooaT00?l0
0P3o000>003o0080o`008000o`070?l002400?l00`3o000;003o00D0o`001000o`0>ooooo`/0oh00
1`3o000@0?n000@0o`0000<0oh000?l0003o0000103oP0030?l000P0oh0000<0o`000?n0003oP000
2`3oP0020?l001/0oh001`3o000>0?n000800?l01@3o000;0?n001Sooooo000Fooooo`D00?l01P3o
0002003o00L0o`000P00o`0:0?l000800?l0103o00000`00o`00o`000?l000060?l000<00?l01P3o
00000`00o`00o`000?l0000@0?l000800?l00P3o0002003o01<0o`000P00o`0=0?l00003003o003o
0000o`0000H00?l00`3o0002003o00L0o`000P00o`0>ooooohD00?l000<0o`00003o0000o`000P00
o`0>oooooaT00?l00P3o000>003o0080o`008000o`070?l002400?l00`3o000;003o00D0o`001000
o`0>ooooo`/0oh001`3o000@0?n000@0o`0000<0oh000?l0003o0000103oP0030?l000P0oh0000<0
o`000?n0003oP0002`3oP0020?l001/0oh001`3o000>0?n000800?l01@3o000;0?n001Sooooo000F
ooooo`@00?l01`3o0003003o01H0o`000`00o`080?l000<00?l01P3o00000`00o`00o`000?l0000@
0?l000800?l05`3o0002003o00d0o`0000<00?l00?l0003o0000103o0003003o0080o`001P00o`05
0?l000koooooP@00o`020?l000L00?l03_oooolD003o0080o`0000<00?l00?l0003o00000P3o000>
003o00H0o`004P00o`000`3o00000?l0003o0009003o0080o`000P00o`000`3o00000?l0003o000O
003o00030?l00000o`000?l000l00?l000<0o`00003o0000o`000P3o000>ooooo`/0oh001`3o0004
0?n000030?l0003oP000oh0000T0oh00103o000L0?n000L0o`00103oP0040?l002L0oh003@3o0005
0?n001Sooooo000Fooooo`@00?l01`3o0003003o01H0o`000`00o`080?l000<00?l01P3o00000`00
o`00o`000?l0000@0?l000800?l05`3o0002003o00d0o`0000<00?l00?l0003o0000103o0003003o
0080o`001P00o`050?l000koooooP@00o`020?l000L00?l03_oooolD003o0080o`0000<00?l00?l0
003o00000P3o000>003o00H0o`004P00o`000`3o00000?l0003o0009003o0080o`000P00o`000`3o
00000?l0003o000O003o00030?l00000o`000?l000l00?l000<0o`00003o0000o`000P3o000>oooo
o`/0oh001`3o00040?n000030?l0003oP000oh0000T0oh00103o000L0?n000L0o`00103oP0040?l0
02L0oh003@3o00050?n001Sooooo000Fooooo`@00?l01`3o0002003o01L0o`000`00o`090?l000@0
0?l01@3o0002003o00L0o`000P00o`070?l000800?l0103o00000`3oP000o`000?l00002003o00@0
o`0000<00?l00?l0003o00003`3o00000`00o`00o`000?l000040?l00003003o003o0000o`0000H0
o`000`00o`040?l000D00?l00P3o000>ooooocT00?l00P3o0014003o00T0o`000P00o`0>oooooa@0
0?l00P3o00000`00o`00o`000?l000020?l000/00?l000<0o`00003o0000o`001`3o000A003o0003
0?l00000o`000?l004@00?l00P3o000>ooooo`T0oh001`3o000T0?n00080o`00:@3oP0070?l001L0
oh00103o00050?n000@0o`006?ooool001Kooooo1000o`070?l000800?l05`3o0003003o00T0o`00
1000o`050?l000800?l01`3o0002003o00L0o`000P00o`040?l000030?n0003o0000o`0000800?l0
103o00000`00o`00o`000?l0000?0?l00003003o003o0000o`0000@0o`0000<00?l00?l0003o0000
1P3o0003003o00@0o`001@00o`020?l000kooooo>@00o`020?l004@00?l02@3o0002003o00kooooo
5000o`020?l00003003o003o0000o`000080o`002`00o`000`3o00000?l0003o00070?l001400?l0
00<0o`00003o0000o`00A000o`020?l000kooooo2@3oP0070?l002@0oh000P3o000Y0?n000L0o`00
5`3oP0040?l000D0oh00103o000Hooooo`005_ooool4003o0200o`000`00o`080?l00003003o003o
0000o`0000800?l0503o00030?n001/0o`000P00o`0;0?l000<00?l01`3o0002003o00H0o`000`00
o`020?l000kooooo>`00o`020?l004800?l00P3o0009003o00kooooo5000o`070?l000/00?l000<0
o`00003o0000o`001`3o000A003o00030?l00000o`000?l003@00?l0103o000>003o00kooooo3P3o
000D0?n000T0o`008P3oP0050?l00240oh0000<0o`000?n0003oP0001`3oP00;0?l000800?l06?oo
ool001Kooooo1000o`0>0?l000800?l01@3o0004003o00T0o`0000<00?l00?l0003o00001P3o0000
0`00o`00o`000?l0000B0?l000800?l03P3o0002003o00d0o`0000<00?l00?l0003o00001P00o`00
0`3o00000?l0003o000>0?l000800?l0103o00020?n000D0o`003_oooomo003o0080o`002@00o`0>
oooooaH00?l000<0o`00003o0000o`000P3o000;003o00030?l00000o`000?l000H0o`004P00o`00
0`3o00000?l0003o000d003o0080o`004000o`0>ooooodP0oh0000<0o`000?n0003oP000:03oP000
0`3o0000oh000?n000070?n000P0o`001@3oP00Hooooo`005_ooool4003o00h0o`000P00o`050?l0
00@00?l02@3o00000`00o`00o`000?l000060?l00003003o003o0000o`000180o`000P00o`0>0?l0
00800?l03@3o00000`00o`00o`000?l00006003o00030?l00000o`000?l000h0o`000P00o`040?l0
0080oh001@3o000>ooooogl00?l00P3o0009003o00kooooo5P00o`000`3o00000?l0003o00020?l0
00/00?l000<0o`00003o0000o`001P3o000B003o00030?l00000o`000?l003@00?l00P3o000@003o
00koooooB03oP0000`3o0000oh000?n0000X0?n000030?l0003oP000oh0000L0oh00203o00050?n0
01Sooooo000Fooooo`@00?l03P3o0002003o00L0o`000P00o`090?l000<00?l01P3o00000`00o`00
o`000?l000040?l000<00?l06`3o0004003o00/0o`0000<00?l00?l0003o00000P3o0004003o0003
0?l00000o`000?l000800?l0303o0002003o00/0o`003_ooooli003o0080o`00A000o`020?l000T0
0?l03_oooolF003o00030?l00000o`000?l00080o`002`00o`090?l001L00?l00P3o00000`00o`00
o`000?l000020?l000800?l01@3o0007003o0080o`001000o`020?l00003003o003o0000o`000180
0?l00P3o0002003o00<0o`002`00o`0>ooooob80oh000P3o000T0?n000<0o`00403oP0020?l001l0
oh000`3o000;0?n001Sooooo000Fooooo`@00?l03P3o0002003o00L0o`000P00o`090?l000<00?l0
1P3o00000`00o`00o`000?l000040?l000<00?l06`3o0004003o00/0o`0000<00?l00?l0003o0000
0P3o0004003o00030?l00000o`000?l000800?l0303o0002003o00/0o`003_ooooli003o0080o`00
A000o`020?l000T00?l03_oooolF003o00030?l00000o`000?l00080o`002`00o`090?l001L00?l0
0P3o00000`00o`00o`000?l000020?l000800?l01@3o0007003o0080o`001000o`020?l00003003o
003o0000o`0001800?l00P3o0002003o00<0o`002`00o`0>ooooob80oh000P3o000T0?n000<0o`00
403oP0020?l001l0oh000`3o000;0?n001Sooooo000Fooooo`@00?l01`3o0002003o00D0o`000P00
o`070?l000800?l02P3o0002003o00d0o`000`00o`0K0?l000@00?l02`3o00000`00o`00o`000?l0
00020?l000@00?l00`3o0002003o01L0o`000P00o`0>ooooohX00?l03_oooolF003o00030?l00000
o`000?l001000?l01P3o00000`00o`00o`000?l0000M003o00<0o`003`00o`020?l001000?l000<0
o`00003o0000o`000P00o`020?l001000?l03_ooool20?l00280oh000P3o00000`3oP000o`000?l0
000?0?n000030?l0003oP000oh0000H0oh00203o00020?n000@0o`000P3oP0090?l000030?n0003o
0000o`000200oh000P3o000;0?n001Sooooo000Fooooo`@00?l01`3o0002003o00D0o`000P00o`07
0?l000800?l02P3o0002003o00d0o`000`00o`0K0?l000@00?l02`3o00000`00o`00o`000?l00002
0?l000@00?l00`3o0002003o01L0o`000P00o`0>ooooohX00?l03_oooolF003o00030?l00000o`00
0?l001000?l01P3o00000`00o`00o`000?l0000M003o00<0o`003`00o`020?l001000?l000<0o`00
003o0000o`000P00o`020?l001000?l03_ooool20?l00280oh000P3o00000`3oP000o`000?l0000?
0?n000030?l0003oP000oh0000H0oh00203o00020?n000@0o`000P3oP0090?l000030?n0003o0000
o`000200oh000P3o000;0?n001Sooooo000Fooooo`@00?l00`3o0002003o00T0o`000P00o`070?l0
00800?l03P3o0002003o00<0o`000P00o`060?l000<00?l03P3o0002003o00T0o`001000o`0I0?l0
00800?l01@3o0002003o00D0o`000P00o`070?l000800?l03_oooon:003o00kooooo:`00o`020?l0
00<00?l00P3o001H003o00kooooo0P3o000f0?n000D0o`00103oP00:0?l002/0oh000P3o00040?n0
00030?l0003oP000oh0000/0oh006?ooool001Kooooo1000o`030?l000800?l02@3o0002003o00L0
o`000P00o`0>0?l000800?l00`3o0002003o00H0o`000`00o`0>0?l000800?l02@3o0004003o01T0
o`000P00o`050?l000800?l01@3o0002003o00L0o`000P00o`0>ooooohX00?l03_ooool[003o0080
o`000`00o`020?l005P00?l03_ooool20?l003H0oh001@3o00040?n000X0o`00:`3oP0020?l000@0
oh0000<0o`000?n0003oP0002`3oP00Hooooo`005_ooool4003o00<0o`000P00o`070?l000@00?l0
1@3o0004003o00`0o`001000o`070?l000800?l02`3o00000`00o`00o`000?l000050?l000@00?l0
1`3o0002003o0080o`000P00o`050?l000800?l00P3o00000`00o`00o`000?l0000;0?l000800?l0
403o0003003o0080o`000P00o`0>ooooohX00?l03_oooon:003o00kooooo103o00000`3oP000o`00
0?l000020?n00080o`000P3oP0000`3o0000oh000?n000060?n000h0o`00503oP0070?l000L0oh00
1@3o000[0?n00080o`000P3oP0030?l000d0oh006?ooool001Kooooo1000o`000`3o00000?l0003o
0002003o00L0o`000P00o`070?l000L00?l0103o0002003o00030?l00000o`000?l00080o`001000
o`050?l000800?l02`3o00000`00o`00o`000?l000020?l000800?l000<0o`00003o0000o`000P00
o`050?l000@00?l03P3o0002003o00H0o`0000<00?l00?l0003o00000P3o0002003o0180o`0000<0
0?l00?l0003o00000P3o000>ooooohX00?l03_oooon:003o00kooooo103o000<0?n000h0o`006`3o
P0080?l001D0oh000P3o000R0?n000D0o`002`3oP00Hooooo`005_ooool4003o00030?l00000o`00
0?l000800?l01`3o0002003o00L0o`001`00o`040?l000800?l000<0o`00003o0000o`000P3o0004
003o00D0o`000P00o`0;0?l00003003o003o0000o`000080o`000P00o`000`3o00000?l0003o0002
003o00D0o`001000o`0>0?l000800?l01P3o00000`00o`00o`000?l000020?l000800?l04P3o0000
0`00o`00o`000?l000020?l000koooooRP00o`0>ooooohX00?l03_ooool40?l000`0oh003P3o000K
0?n000P0o`005@3oP0020?l00280oh001@3o000;0?n001Sooooo000Fooooo`@00?l0303o0004003o
00D0o`000P00o`030?l000800?l00P3o0002003o0080o`000`00o`020?l000@00?l01@3o0002003o
00T0o`000P00o`050?l000L00?l03P3o0002003o00l0o`002000o`060?l000800?l01@3o00020?n0
0080o`001@00o`0>oooooh400?l00P3o0007003o00koooooRP00o`0>ooooo`@0o`005@3oP0020?l0
0080oh0000<0o`000?n0003oP0000P3o000K0?n00080o`001`3oP0050?l003l0oh006?ooool001Ko
oooo1000o`0<0?l000@00?l01@3o0002003o00<0o`000P00o`020?l000800?l00P3o0003003o0080
o`001000o`050?l000800?l02@3o0002003o00D0o`001`00o`0>0?l000800?l03`3o0008003o00H0
o`000P00o`050?l00080oh000P3o0005003o00koooooP@00o`020?l000L00?l03_oooon:003o00ko
oooo103o000E0?n00080o`000P3oP0000`3o0000oh000?n000020?l001/0oh000P3o00070?n000D0
o`00?`3oP00Hooooo`005_ooool2003o0100o`000P00o`0>0?l000800?l00`3o0002003o0080o`00
0P00o`070?l000@00?l01`3o0002003o00D0o`000`00o`090?l000@00?l0103o0003003o00T0o`00
1000o`020?l000D00?l00P3o00000`00o`00o`000?l000060?l00003003o003o0000o`0000L0o`00
1000o`0>oooood@00?l01`3o000o003o00koooooRP00o`0>oooooaT0oh000P3o00020?n000030?l0
003oP000oh0002P0oh0000<0o`000?n0003oP000:03oP0030?l000H0oh001@3o00090?n001Sooooo
000Fooooo`800?l0403o0002003o00h0o`000P00o`030?l000800?l00P3o0002003o00L0o`001000
o`070?l000800?l01@3o0003003o00T0o`001000o`040?l000<00?l02@3o0004003o0080o`001@00
o`020?l00003003o003o0000o`0000H0o`0000<00?l00?l0003o00001`3o0004003o00koooooA000
o`070?l003l00?l03_oooon:003o00kooooo6@3oP0020?l00080oh0000<0o`000?n0003oP000:03o
P0000`3o0000oh000?n0000X0?n000<0o`001P3oP0050?l000T0oh006?ooool001Kooooo0P00o`03
0?l000800?l02`3o0002003o00h0o`000P00o`0<0?l000P00?l0403o00000`00o`00o`000?l00007
0?l000800?l00P3o0002003o0080o`000`00o`090?l000@00?l00`3o0004003o00/0o`0000<00?l0
0?l0003o00001`3o0004003o00kooooo?`00o`0<0?l003l00?l03_oooon:003o00kooooo3P3oP002
0?l000d0oh0000<0o`000?n0003oP0002@3o000O0?n000L0o`000`3oP0020?l001l0oh0000<0o`00
0?n0003oP0001P3oP0030?l000/0oh006?ooool001Kooooo0P00o`030?l000800?l02`3o0002003o
00h0o`000P00o`0<0?l000P00?l0403o00000`00o`00o`000?l000070?l000800?l00P3o0002003o
0080o`000`00o`090?l000@00?l00`3o0004003o00/0o`0000<00?l00?l0003o00001`3o0004003o
00kooooo?`00o`0<0?l003l00?l03_oooon:003o00kooooo3P3oP0020?l000d0oh0000<0o`000?n0
003oP0002@3o000O0?n000L0o`000`3oP0020?l001l0oh0000<0o`000?n0003oP0001P3oP0030?l0
00/0oh006?ooool001Kooooo0P00o`0<0?l000800?l0103o0002003o00<0o`000P00o`070?l00080
0?l0303o0004003o0080o`001`00o`0;0?l00003003o003o0000o`0000l0o`0000<00?l00?l0003o
00001`3o0008003o00<0o`000P00o`070?l000800?l00P3o00000`00o`00o`000?l0000;0?l000ko
oooo?`00o`090?l000030?n0003o0000o`0003l00?l03_oooon:003o00kooooo3P3oP0040?l001@0
oh0000<0o`000?n0003oP0002@3oP0020?l00080oh000`3o000h0?n000<0o`00203oP0000`3o0000
oh000?n000070?n00080o`000P3oP00Hooooo`005_ooool2003o00D0o`000P00o`050?l000800?l0
2`3o0002003o00D0o`000P00o`070?l000800?l01@3o0004003o00<0o`000P00o`070?l000800?l0
103o00000`00o`00o`000?l0000?0?l00003003o003o0000o`0000H0o`001@00o`020?l000800?l0
0`3o0002003o00L0o`000P00o`0;0?l00003003o003o0000o`000080o`003_oooom2003o00H0o`00
00<0oh000?l0003o00000P3o000=003o00030?l00000o`000?l002d00?l03_oooomA003o00<0o`00
=P00o`0>ooooo`h0oh000P3o000R0?n000L0o`00603oP0030?l000H0oh000`3o000D0?n00080o`00
1`3oP0050?l000T0oh000P3o000Hooooo`005_ooool2003o00D0o`000P00o`050?l000800?l02`3o
0002003o00D0o`000P00o`070?l000800?l01@3o0004003o00<0o`000P00o`070?l000800?l0103o
00000`00o`00o`000?l0000?0?l00003003o003o0000o`0000H0o`001@00o`020?l000800?l00`3o
0002003o00L0o`000P00o`0;0?l00003003o003o0000o`000080o`003_oooom2003o00H0o`0000<0
oh000?l0003o00000P3o000=003o00030?l00000o`000?l002d00?l03_oooomA003o00<0o`00=P00
o`0>ooooo`h0oh000P3o000R0?n000L0o`00603oP0030?l000H0oh000`3o000D0?n00080o`001`3o
P0050?l000T0oh000P3o000Hooooo`005_ooool4003o00<0o`000P00o`0=0?l000<00?l02@3o0002
003o00L0o`000P00o`050?l000@00?l00`3o0002003o00L0o`000P00o`050?l000800?l01P3o0003
003o00H0o`0000<00?l00?l0003o00001P3o0005003o0080o`000`00o`020?l000@00?l04P3o0000
0`00o`00o`000?l000020?l000kooooo@@00o`0:0?l003l00?l03_oooomB003o0080o`00=P00o`0>
ooooof`0oh001@3o00090?n000D0o`002`3oP00Hooooo`005_ooool4003o00<0o`000P00o`0=0?l0
00<00?l02@3o0002003o00L0o`000P00o`050?l000@00?l00`3o0002003o00L0o`000P00o`050?l0
00800?l01P3o0003003o00H0o`0000<00?l00?l0003o00001P3o0005003o0080o`000`00o`020?l0
00@00?l04P3o00000`00o`00o`000?l000020?l000kooooo@@00o`0:0?l003l00?l03_oooomB003o
0080o`00=P00o`0>ooooof`0oh001@3o00090?n000D0o`002`3oP00Hooooo`005_ooool2003o0080
o`000`00o`020?l000800?l01@3o0002003o00@0o`000`00o`050?l000800?l01P3o00000`00o`00
o`000?l000020?l000800?l01@3o0004003o00`0o`000P00o`050?l000@00?l0103o0003003o00H0
o`0000<00?l00?l0003o00001P3o0005003o0080o`002P00o`060?l000<00?l0203o0003003o0080
o`003_oooom4003o00T0o`00?@00o`0>ooooob/00?l00P3o000<003o0080o`005`00o`020?l002H0
0?l00`3o000=003o00kooooo5P3oP0000`3o0000oh000?n0000M0?n00080o`001`3oP0020?l00300
oh000P3o000G0?n001Sooooo000Fooooo`800?l00P3o0003003o0080o`000P00o`050?l000800?l0
103o0003003o00D0o`000P00o`060?l00003003o003o0000o`000080o`000P00o`050?l000@00?l0
303o0002003o00D0o`001000o`040?l000<00?l01P3o00000`00o`00o`000?l000060?l000D00?l0
0P3o000:003o00H0o`000`00o`080?l000<00?l00P3o000>oooood@00?l02@3o000m003o00kooooo
:`00o`020?l000`00?l00P3o000G003o0080o`009P00o`030?l000d00?l03_oooolF0?n000030?l0
003oP000oh0001d0oh000P3o00070?n00080o`00<03oP0020?l001L0oh006?ooool001Kooooo0P00
o`020?l000<00?l03`3o0005003o00/0o`0000<00?l00?l0003o00000P3o0005003o00@0o`000P00
o`0L0?l000@00?l00P3o0003003o00H0o`000P00o`030?l000800?l00P3o0005003o0080o`000`00
o`060?l000<00?l0203o0003003o0080o`003_ooool2003o0080o`00=@00o`020?l000H00?l000<0
o`00003o0000o`000P3o0003003o00@0o`00?@00o`0>ooooob/00?l00P3o0019003o00L0o`003@00
o`0>oooooaL0oh00103o000P0?n00080o`000P3oP0020?l00140oh00103o000d0?n001Sooooo000F
ooooo`@0o`000`00o`0=0?l000L00?l0503o00000`00o`00o`000?l000020?l000@00?l01@3o0004
003o00D0o`000P00o`070?l000800?l01@3o0007003o0080o`001000o`000`3o00000?l0003o0004
003o0080o`000`00o`040?l000<00?l01P3o0003003o00H0o`000`00o`020?l000kooooo@@00o`00
0`3o00000?l0003o000;0?l003/00?l03_oooomf003o00L0o`003@00o`0>ooooo`D0oh000P3o0006
0?n000L0o`000P3oP0050?l000D0oh002@3o00020?n00080o`005@3oP0020?l00100oh000P3o000N
0?n000@0o`004P3oP00Hooooo`005_ooool40?l000<00?l03@3o0007003o01@0o`0000<00?l00?l0
003o00000P3o0004003o00D0o`001000o`050?l000800?l01`3o0002003o00D0o`001`00o`020?l0
00@00?l000<0o`00003o0000o`001000o`020?l000<00?l0103o0003003o00H0o`000`00o`060?l0
00<00?l00P3o000>oooood400?l000<0o`00003o0000o`002`3o000k003o00koooooMP00o`070?l0
00d00?l03_ooool50?n00080o`001P3oP0070?l00080oh001@3o00050?n000T0o`000P3oP0020?l0
01D0oh000P3o000@0?n00080o`007P3oP0040?l00180oh006?ooool001Kooooo0P00o`030?l00080
0?l03@3o0003003o0080o`000P00o`0N0?l000800?l00P3o0004003o00D0o`000`00o`080?l00003
003o003o0000o`000080o`001@00o`020?l000H00?l00`3o0004003o0080o`000`00o`050?l000@0
0?l0103o0005003o00@0o`000`00o`020?l000kooooo>@00o`060?l000800?l000<0o`00003o0000
o`001@3o0002003o0080o`005`00o`020?l002@00?l03_oooomA003o00030?l00000o`000?l000L0
0?l0103o000D003o00X0o`003@00o`0>ooooo`/0o`00;@3oP0030?l003/0oh000P3o000B0?n001So
oooo000Fooooo`800?l00`3o0002003o00d0o`000`00o`020?l000800?l07P3o0002003o0080o`00
1000o`050?l000<00?l0203o00000`00o`00o`000?l000020?l000D00?l00P3o0006003o00<0o`00
1000o`020?l000<00?l01@3o0004003o00@0o`001@00o`040?l000<00?l00P3o000>ooooocT00?l0
1P3o0002003o00030?l00000o`000?l000D0o`000P00o`020?l001L00?l00P3o000T003o00kooooo
D@00o`000`3o00000?l0003o0007003o00@0o`005000o`0:0?l000d00?l03_ooool;0?l002d0oh00
0`3o000k0?n00080o`004P3oP00Hooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000Wooooog7o
00009ooooomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`0Nooooo`03o`3o
0?oooooooooo01;ooooo00?o0?l0ooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`3o
0?oooooooooo01;ooooo00?o0?l0ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`02ooooo`03o`3o
0?oooooooooo01?ooooo00?o0?l0ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo00?o0?l0ooooooooool04oooool00ol0o`3oooooooooo`0hooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oo
oolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5_oo000PoooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Go
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo
5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0ho`00OaKo003o1?l007lGoomo00Co001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o
001o5ooo000jo`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1?oo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0h
o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lO
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol0
07lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o
001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;oooooL_l0000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool_0?l000D0oh00>03o00030?n001/0
o`003_ooool40?n000D0003o103oP00:0000o`@0oh000P000?l50?n000@0o`0000<0oh000000o`00
0?l03@000?lB0?n000030?l0003oP000oh0000H0oh001@000?l40?n000030000o`3oP000oh0000@0
oh001@3o00040?n000<0003o5P3oP0020000o`D0oh003_oooom60000o`80oh002P000?l40?n000T0
003o103oP00E0000o`80oh000P000?l00`3oP000003o0000o`0;0000o`kooooo1@3oP0020000o`80
oh00103o00030?n00080003o103oP0030000o`80oh000P000?l50?n000@0003o4P3oP0000`3o0000
oh000?n000070?n00080o`00103oP0030000o`80oh0010000?l00`3oP000003o0000o`060?n000D0
o`001`3oP0040000o`<0oh00103o000;0?n000<0o`000P3oP0050?l000@0oh006?ooool001Kooooo
;`3o00050?n003P0o`000`3oP00K0?l000kooooo103oP0050000o`@0oh002P000?l40?n00080003o
1@3oP0040?l000030?n000000?l0003o00d0003o4P3oP0000`3o0000oh000?n000060?n000D0003o
103oP0000`000?l0oh000?n000040?n000D0o`00103oP0030000oaH0oh000P000?l50?n000kooooo
AP000?l20?n000X0003o103oP0090000o`@0oh005@000?l20?n00080003o00<0oh000000o`000?l0
2`000?l>ooooo`D0oh000P000?l20?n000@0o`000`3oP0020000o`@0oh000`000?l20?n00080003o
1@3oP0040000oa80oh0000<0o`000?n0003oP0001`3oP0020?l000@0oh000`000?l20?n000@0003o
00<0oh000000o`000?l01P3oP0050?l000L0oh0010000?l30?n000@0o`002`3oP0030?l00080oh00
1@3o00040?n001Sooooo000Foooooc00o`001P3oP00g0?l00080oh006`3o000>ooooo`@0oh0000<0
003o0?n0003oP0000P000?l20?n001D0003o1`3oP00?0000o`<0oh0010000?l;0?n000030?l0003o
P000oh0000L0oh002@000?l60?n00080o`0000<0oh000?l0003o00000P3o00020?n000D0003o503o
P0020000o`D0oh003_oooom60000o`80oh002P000?l40?n000L0003o103oP00L0000o`80oh002`00
0?l>ooooo`@0oh000`000?l20?n000@0o`000`3oP0020000o`h0oh0010000?lD0?n000<0o`000P3o
P0020?l000<0oh000P3o00050?n00080003o1P3oP0050000o`80oh001`3o000;0?n00100o`000`3o
P0090?l000@0oh006?ooool001Kooooo<03o00060?n003L0o`000P3oP00K0?l000kooooo103oP000
0`000?l0oh000?n000020000o`80oh005@000?l70?n000l0003o0`3oP0040000o`/0oh0000<0o`00
0?n0003oP0001`3oP0090000o`H0oh000P3o00000`3oP000o`000?l000020?l00080oh001@000?lD
0?n00080003o1@3oP00>ooooodH0003o0P3oP00:0000o`@0oh001`000?l40?n001`0003o0P3oP00;
0000o`kooooo103oP0030000o`80oh00103o00030?n00080003o3P3oP0040000oa@0oh000`3o0002
0?n00080o`000`3oP0020?l000D0oh000P000?l60?n000D0003o0P3oP0070?l000/0oh00403o0003
0?n000T0o`00103oP00Hooooo`005_oooold0?l00080oh00E03o000>ooooo`80oh005@000?l20?n0
00L0003o1`3oP00D0000o`H0oh0000<0o`000?n0003oP0002`3oP0070000o`@0oh0000<0003o0?n0
003oP000103oP0020?l000030?n0003o0000o`000080o`000P3oP0050000oa/0oh003_oooom10000
oa00oh0000<0003o0?n0003oP0000P3oP0020000o`80oh0000<0003o0?n0003oP000103oP0020000
o`L0oh000P000?l70?n001L0003o3_ooool20?n00080003o00<0oh000000o`000?l0103oP0050?l0
00L0oh00103o00050?n000@0003o303oP0040?l000@0oh001`3o000:0?n000H0003o0`3oP0020000
o`@0oh001`3o00090?n00100o`001@3oP00;0?l00080oh006?ooool001KoooooR03o00020?n000ko
oooo5P000?l50?n000L0003o103oP00G0000o`L0oh000P3o00090?n000L0003o503oP0070000o`L0
oh0010000?l>0?n000kooooo8P000?l20?n001d0003o1`3oP0000`000?l0oh000?n000060?n00003
0000o`3oP000oh000080oh000P000?l20?n000030000o`3oP000oh0000L0003o3`3oP00G0000o`ko
oooo1@3oP0020000o`@0oh001`3o00040?n000<0o`00103oP0070000o`D0oh000P000?l50?n00080
o`00503oP0050000o`/0oh000P000?l20?n000<0o`001`3oP0020?l00080oh00803o00020?n001So
oooo000FooooohP0o`000P3oP00>oooooaH0003o1@3oP0070000o`@0oh005`000?l70?n00080o`00
2@3oP0070000oa@0oh001`000?l70?n000@0003o3P3oP00>ooooob80003o0P3oP00M0000o`L0oh00
00<0003o0?n0003oP0001P3oP0000`000?l0oh000?n000020?n00080003o0P3oP0000`000?l0oh00
0?n000070000o`l0oh005`000?l>ooooo`D0oh000P000?l40?n000L0o`00103oP0030?l000@0oh00
1`000?l50?n00080003o1@3oP0020?l001@0oh001@000?l;0?n00080003o0P3oP0030?l000L0oh00
0P3o00020?n00200o`000P3oP00Hooooo`005_oooon:0?l000kooooo8P000?l40?n001/0003o1@3o
P0020000o`L0oh001`000?l90?n00080003o2@3oP0070000oaT0oh003_oooolV0000o`030?n00000
0?l0003o01H0003o8P3oP0050000o`d0oh001@000?l50?n000T0003o103oP00>ooooo`D0oh000P00
0?l20?n000L0o`001`3oP0020?l000@0oh001`000?l>0?n00080o`002@3oP0020?l000L0oh001@00
0?l;0?n00080003o403oP0070?l000L0oh00403o00020?n00080003o6?ooool001KoooooRP3o000>
ooooob80003o103oP00K0000o`D0oh000P000?l70?n000L0003o2@3oP0020000o`T0oh001`000?lI
0?n000kooooo9P000?l00`3oP000003o0000o`0F0000ob80oh001@000?l=0?n000D0003o1@3oP009
0000o`@0oh003_ooool50?n00080003o0P3oP0070?l000L0oh000P3o00040?n000L0003o3P3oP002
0?l000T0oh000P3o00070?n000D0003o2`3oP0020000oa00oh001`3o00070?n00100o`000P3oP002
0000oaSooooo000FooooohX0o`003_oooolP0000o`H0oh006`000?l00`3oP000003o0000o`090000
o`80oh001`000?l50?n000d0003o0P3oP00B0000o``0oh000P000?l>oooooa@0003o0P3oP00<0000
o`80oh000P000?l00`3oP000003o0000o`0D0000o`@0oh001`000?l00`3oP000003o0000o`070?n0
0080003o3@3oP0020000o`L0oh003P000?l20?n000L0003o103oP0000`000?l0oh000?n000020000
o`kooooo0P3o00070?n000L0o`003@3oP0050000oa@0oh000P3o00030?n000H0o`0000<0oh000?l0
003o0000103oP0030000o`80oh001@3o000F0?n000@0o`0000<0oh000?l0003o00001`3oP0070?l0
0080oh000P3o00090?n001Sooooo000FooooohX0o`003_oooolP0000o`H0oh006`000?l00`3oP000
003o0000o`090000o`80oh001`000?l50?n000d0003o0P3oP00B0000o``0oh000P000?l>oooooa@0
003o0P3oP00<0000o`80oh000P000?l00`3oP000003o0000o`0D0000o`@0oh001`000?l00`3oP000
003o0000o`070?n00080003o3@3oP0020000o`L0oh003P000?l20?n000L0003o103oP0000`000?l0
oh000?n000020000o`kooooo0P3o00070?n000L0o`003@3oP0050000oa@0oh000P3o00030?n000H0
o`0000<0oh000?l0003o0000103oP0030000o`80oh001@3o000F0?n000@0o`0000<0oh000?l0003o
00001`3oP0070?l00080oh000P3o00090?n001Sooooo000Fooooogl0o`000P3oP0090?l000kooooo
7P000?l80?n002L0003o0P3oP00]0000o`L0oh000P000?l00`3oP000003o0000o`020000o`kooooo
9P000?l30?n000@0003o0P3oP00G0000o``0oh000P000?lB0?n00180003o0P3oP00<0000o`80oh00
0P000?l>ooooo`80oh000`3o000H0?n000L0003o1@3oP0020?l000D0oh000P000?l90?n000h0o`00
1P3oP0050?l001T0oh00103o000I0?n001Sooooo000Foooooh40o`00103oP0050?l000kooooo2`00
0?l20?n00140003o203oP00U0000o`@0oh00;@000?l<0?n00080003o3_oooolo0000ob@0oh009`00
0?l>ooooo`80oh000`3o00060?n000L0003o1@3oP0020?l00080oh000P3o00030?n000@0003o1@3o
P0040?l000<0oh000P000?l90?n000H0o`0000<0oh000?l0003o00002`3oP0090?l00080oh0000<0
003o0?n0003oP0002@3oP0040?l000<0oh000P3o00050?n000/0003o2`3oP00Hooooo`005_oooon1
0?l000@0oh001@3o000>ooooo`/0003o0P3oP00A0000o`P0oh009@000?l40?n002d0003o303oP002
0000o`kooooo?`000?lT0?n002L0003o3_ooool20?n000<0o`001P3oP0070000o`D0oh000P3o0002
0?n00080o`000`3oP0040000o`D0oh00103o00030?n00080003o2@3oP0060?l000030?n0003o0000
o`0000/0oh002@3o00020?n000030000o`3oP000oh0000T0oh00103o00030?n00080o`001@3oP00;
0000o`/0oh006?ooool001KoooooC@3o00020?n00380o`00103oP0050?l000kooooo6@000?l20?n0
00<0003o203oP00I0000o`D0oh001`000?l60?n002/0003o1`3oP0020000o`030?n000000?l0003o
0080003o3_ooool]0000o`80oh003P000?l20?n000<0003o1P3oP0030000o`L0oh00>0000?l>oooo
o`80oh001`3o00020?n000L0003o103oP0030?l00100oh00103o00030?n000@0003o2`3oP0020?l0
00030?n0003o0000o`000080o`002@3oP0090?l00080oh0000<0003o0?n0003oP0006`3oP0070000
o`/0oh006?ooool001KoooooC@3o00020?n00380o`00103oP0050?l000kooooo6@000?l20?n000<0
003o203oP00I0000o`D0oh001`000?l60?n002/0003o1`3oP0020000o`030?n000000?l0003o0080
003o3_ooool]0000o`80oh003P000?l20?n000<0003o1P3oP0030000o`L0oh00>0000?l>ooooo`80
oh001`3o00020?n000L0003o103oP0030?l00100oh00103o00030?n000@0003o2`3oP0020?l00003
0?n0003o0000o`000080o`002@3oP0090?l00080oh0000<0003o0?n0003oP0006`3oP0070000o`/0
oh006?ooool001Kooooo=03o00020?n00580o`000P3oP00>ooooo`d0003o00<0oh000000o`000?l0
3@000?l90?n001`0003o0P3oP0070000o`L0oh0010000?l20?n001/0003o0`3oP0020000o`T0oh00
0P3o00050?n00080003o3_oooolP0000o`80oh002@000?l50?n000d0003o103oP0000`000?l0oh00
0?n0000=0?n003T0003o3_ooool40?n000<0o`00103oP0070000o`/0oh0000<0003o0?n0003oP000
2@3oP0040?l000D0oh000P000?l;0?n00080o`002P3oP0040000o`80oh001@3o00020?n000<0003o
7@3oP0070000o`/0oh006?ooool001Kooooo=03o00020?n00580o`000P3oP00>ooooo`d0003o00<0
oh000000o`000?l03@000?l90?n001`0003o0P3oP0070000o`L0oh0010000?l20?n001/0003o0`3o
P0020000o`T0oh000P3o00050?n00080003o3_oooolP0000o`80oh002@000?l50?n000d0003o103o
P0000`000?l0oh000?n0000=0?n003T0003o3_ooool40?n000<0o`00103oP0070000o`/0oh0000<0
003o0?n0003oP0002@3oP0040?l000D0oh000P000?l;0?n00080o`002P3oP0040000o`80oh001@3o
00020?n000<0003o7@3oP0070000o`/0oh006?ooool001Kooooo=03o00020?n005@0o`003_oooolM
0000o`<0oh000P000?l40?n001/0003o1@3oP0030?l000T0oh000P000?l20?n000@0003o1@3oP00@
0000o`L0oh000P000?l50?n000H0o`000P3oP0000`000?l0oh000?n000020?n000koooooB@000?l2
0?n003l0003o3_ooool20000o`D0oh000P3o00040?n000L0003o2@3oP0000`000?l0oh000?n0000F
0?n00080o`0000<0oh000?l0003o00002@3oP0040?l000<0oh000P000?l50?n00080o`001P3oP000
0`000?l0oh000?n000020?n00080003o6@3oP0050000o`T0oh000P3o000Hooooo`005_oooold0?l0
0080oh00E03o000>oooooad0003o0`3oP0020000o`@0oh006`000?l50?n000<0o`002@3oP0020000
o`80oh0010000?l50?n00100003o1`3oP0020000o`D0oh001P3o00020?n000030000o`3oP000oh00
0080oh003_oooom90000o`80oh00?`000?l>ooooo`80003o1@3oP0020?l000@0oh001`000?l90?n0
00030000o`3oP000oh0001H0oh000P3o00000`3oP000o`000?l000090?n000@0o`000`3oP0020000
o`D0oh000P3o00060?n000030000o`3oP000oh000080oh000P000?lI0?n000D0003o2@3oP0020?l0
01Sooooo000FooooohX0o`003_ooool20000o`80oh0080000?l20?n001T0003o0`3oP00;0?l000/0
oh000P000?l30?n00080003o0P3oP0020000o`030?n000000?l0003o00h0003o0P3oP0020000o`D0
oh001P3o00070?n000koooooEP000?l20?n00380003o3_ooool20000o`<0oh00103o00050?n000@0
003o7P3oP0020?l000@0oh001`3o00050?n000T0o`000P000?l20?n00080003o3P3oP0020000o`h0
oh00103o00050?n000@0003o303oP0020?l001Sooooo000Fooooocd0o`000P3oP0020?l000030?n0
003o0000o`0004H0o`003_oooolT0000o`D0oh0040000?l=0?n000<0o`002@3oP0020000o`@0oh00
0P000?l30?n000H0003o00<0oh000000o`000?l01`000?l90?n00080003o2@3oP0020?l00080oh00
00<0003o0?n0003oP0000P3oP00>ooooocl0003o0P3oP00E0000o`80oh00<P000?l>ooooo`80003o
0`3oP0060?l000D0oh000P000?l>0?n000@0003o503oP0050?l000T0oh001@3o00040?n00080003o
1@3oP0020?l00080oh0000<0003o0?n0003oP000403oP0020000o`80o`00303oP0020000o`@0oh00
0P000?l50?n001Sooooo000Fooooocd0o`000P3oP0020?l000030?n0003o0000o`0004H0o`003_oo
oolT0000o`D0oh0040000?l=0?n000<0o`002@3oP0020000o`@0oh000P000?l30?n000H0003o00<0
oh000000o`000?l01`000?l90?n00080003o2@3oP0020?l00080oh0000<0003o0?n0003oP0000P3o
P00>ooooocl0003o0P3oP00E0000o`80oh00<P000?l>ooooo`80003o0`3oP0060?l000D0oh000P00
0?l>0?n000@0003o503oP0050?l000T0oh001@3o00040?n00080003o1@3oP0020?l00080oh0000<0
003o0?n0003oP000403oP0020000o`80o`00303oP0020000o`@0oh000P000?l50?n001Sooooo000F
ooooohX0o`003_oooolT0000o`80oh005@000?l70?n00080o`000P3oP0030?l000H0oh000P3o000>
0?n000@0003o00<0oh000000o`000?l02@000?l40?n000T0003o2@3oP0000`000?l0oh000?n00002
0000o`kooooo?@000?l50?n000H0003o1@3oP00m0000o`kooooo0P000?l20?n000T0o`002@3oP003
0?l000D0oh000P000?lH0?n000030?l0003oP000oh0000h0oh00103o00070?n000@0o`005`3oP002
0?l000`0oh000P000?l20?n00080003o1`3oP00Hooooo`005_oooon:0?l000kooooo90000?l20?n0
01D0003o1`3oP0020?l00080oh000`3o00060?n00080o`003P3oP0040000o`030?n000000?l0003o
00T0003o103oP0090000o`T0oh0000<0003o0?n0003oP0000P000?l>ooooocd0003o1@3oP0060000
o`D0oh00?@000?l>ooooo`80003o0P3oP0090?l000T0oh000`3o00050?n00080003o603oP0000`3o
0000oh000?n0000>0?n000@0o`001`3oP0040?l001L0oh000P3o000<0?n00080003o0P3oP0020000
o`L0oh006?ooool001Kooooo;@3o00020?n005/0o`003_oooolk0000o`80oh000P000?l90?n00003
0?l0003oP000oh0000@0oh000P3o000<0?n000H0003o00<0oh000000o`000?l02`000?l20?n000T0
003o3P3oP00>oooood/0003o0P3oP00m0000o`kooooo0P3oP00;0?l000D0oh001`3o000;0?n000D0
003o3`3oP0000`3o0000oh000?n000090?n00080o`000P3oP0030?l000H0oh0000<0003o0?n0003o
P000103o000U0?n00080003o0P3oP0020000o`80oh0000<0o`000?n0003oP0000P3oP00Hooooo`00
5_ooool]0?l00080oh00F`3o000>oooooc/0003o0P3oP0020000o`T0oh0000<0o`000?n0003oP000
103oP0020?l000`0oh001P000?l00`3oP000003o0000o`0;0000o`80oh002@000?l>0?n000kooooo
B`000?l20?n003d0003o3_ooool20?n000/0o`001@3oP0070?l000/0oh001@000?l?0?n000030?l0
003oP000oh0000T0oh000P3o00020?n000<0o`001P3oP0000`000?l0oh000?n000040?l002D0oh00
0P000?l20?n00080003o0P3oP0000`3o0000oh000?n000020?n001Sooooo000FooooobL0o`000P3o
P0040?l00080oh00F`3o000>oooooad0003o00<0oh000000o`000?l00P3oP0020000o`80oh006`00
0?l<0?n000@0o`00303oP0060000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l0103o
P0090000o`T0oh0000<0003o0?n0003oP0000P000?l>oooood80003o0P3oP0070000o`80oh000P00
0?l20?n000h0003o103oP0050000o`80oh004`000?l80?n000D0003o3_ooool20?n000L0o`002@3o
P0050?l000l0oh000`000?l40?n000D0o`000P3oP0070?l000T0oh000P3o000>0?n000@0o`000`3o
P0020000oa00oh000P000?l20?n00080003o2@3oP0030000o`H0oh0000<0o`000?n0003oP0000P3o
P00Hooooo`005_oooolW0?l00080oh00103o00020?n005/0o`003_oooolM0000o`030?n000000?l0
003o0080oh000P000?l20?n001/0003o303oP0040?l000`0oh001P000?l00`3oP000003o0000o`06
0000o`030?n000000?l0003o00@0oh002@000?l90?n000030000o`3oP000oh000080003o3_oooom2
0000o`80oh001`000?l20?n00080003o0P3oP00>0000o`@0oh001@000?l20?n001<0003o203oP005
0000o`kooooo0P3oP0070?l000T0oh001@3o000?0?n000<0003o103oP0050?l00080oh001`3o0009
0?n00080o`003P3oP0040?l000<0oh000P000?l@0?n00080003o0P3oP0020000o`T0oh000`000?l6
0?n000030?l0003oP000oh000080oh006?ooool001Kooooo9`3o00040?n005l0o`003_oooolM0000
o`030?n000000?l0003o00@0oh004P000?l20?n000L0003o3P3oP0020?l000h0oh0010000?l50?n0
00/0003o1@3oP0070000o`d0oh003_ooool`0000o`80oh003@000?l90?n000L0003o1`3oP00B0000
o`80oh004`000?l=0?n000kooooo0P000?l20?n000030?l0003oP000oh0000/0oh00103o00050?n0
00<0003o3`3oP0030?l000@0oh001@3o00090?n00080003o2`3oP0020?l000<0oh000P3o00050?n0
0080003o1P3oP0000`3o0000oh000?n0000;0?n00080003o2P3oP0020000o`/0oh006?ooool001Ko
oooo?`3o00030?n004P0o`003_oooold0000o`80oh001`000?lD0?n000D0003o4P3oP00E0000o`/0
oh000P000?l>ooooob/0003o0P3oP00B0000oaL0oh001`000?l20?n000T0003o103oP00A0000o`P0
oh0000<0003o0?n0003oP0000P000?l>ooooo`80003o5@3oP0060000o`T0oh0000<0o`000?n0003o
P0002`3oP0040?l000L0oh001@000?l;0?n000L0o`001@3oP0040000o`@0oh000`3o00020?n00080
o`002@3oP0050000o`80oh001@000?l70?n00080003o0P3oP00Hooooo`005_oooolo0?l000<0oh00
B03o000>oooooc@0003o0P3oP0070000oa@0oh001@000?lB0?n001D0003o2`3oP0020000o`kooooo
:`000?l20?n00180003o5`3oP0070000o`80oh002@000?l40?n00140003o203oP0000`000?l0oh00
0?n000020000o`kooooo0P000?lE0?n000H0003o2@3oP0000`3o0000oh000?n0000;0?n000@0o`00
1`3oP0050000o`/0oh001`3o00050?n000@0003o103oP0030?l00080oh000P3o00090?n000D0003o
0P3oP0050000o`L0oh000P000?l20?n001Sooooo000FooooohX0o`003_oooolf0000o`<0oh001000
0?l;0?n000030?l0003oP000oh0000T0oh000P000?l50?n00080o`002@3oP00B0000o`@0oh000`00
0?l;0?n000kooooo:@000?l60?n001<0003o503oP0020000oa@0oh004@000?l80?n000D0003o3_oo
ool20000o`T0oh000P3o00000`3oP000o`000?l000020?l000@0oh002P000?l60?n000<0o`002@3o
P0070?l000T0oh000P000?lG0?n00080003o1`3oP0020?l000d0oh001`000?l20?n000<0003o0P3o
P0040000o`D0oh006?ooool001KoooooRP3o000>ooooocH0003o0`3oP0040000o`/0oh0000<0o`00
0?n0003oP0002@3oP0020000o`D0oh000P3o00090?n00180003o103oP0030000o`/0oh003_oooolY
0000o`H0oh004`000?lD0?n00080003o503oP00A0000o`P0oh001@000?l>ooooo`80003o2@3oP002
0?l000030?n0003o0000o`000080o`00103oP00:0000o`H0oh000`3o00090?n000L0o`002@3oP002
0000oaL0oh000P000?l70?n00080o`003@3oP0070000o`80oh000`000?l20?n000@0003o1@3oP00H
ooooo`005_ooool20?l00080oh00K`3o00000`3oP000o`000?l0000D0?l000kooooo8P000?l20?n0
0100003o103oP0030000oaH0oh0000<0003o0?n0003oP0000P000?l40?n000<0o`001`3oP0020000
o`80oh004P000?l20?n000030000o`3oP000oh0000L0oh000P000?l20?n000kooooo9`000?l80?n0
01L0003o1`3oP0020000o`L0oh000P000?l70?n00080003o0P3oP0030000o`80oh002@000?l50?n0
00L0003o103oP0020000o`80oh001@000?l>ooooo`@0003o2P3oP0020?l000T0oh001`000?l60?n0
00030?l0003oP000oh0000L0oh000P3o00020?n00080o`000P3oP0000`3o0000oh000?n000090?n0
00L0o`00403oP0040000oa@0oh001`000?l30?n00080003o0P3oP0040000o`<0oh000P3o000Hoooo
o`005_ooool20?l00080oh00K`3o00000`3oP000o`000?l0000D0?l000kooooo8P000?l20?n00100
003o103oP0030000oaH0oh0000<0003o0?n0003oP0000P000?l40?n000<0o`001`3oP0020000o`80
oh004P000?l20?n000030000o`3oP000oh0000L0oh000P000?l20?n000kooooo9`000?l80?n001L0
003o1`3oP0020000o`L0oh000P000?l70?n00080003o0P3oP0030000o`80oh002@000?l50?n000L0
003o103oP0020000o`80oh001@000?l>ooooo`@0003o2P3oP0020?l000T0oh001`000?l60?n00003
0?l0003oP000oh0000L0oh000P3o00020?n00080o`000P3oP0000`3o0000oh000?n000090?n000L0
o`00403oP0040000oa@0oh001`000?l30?n00080003o0P3oP0040000o`<0oh000P3o000Hooooo`00
5_ooool20?l00080oh00EP3o00030?n002d0o`003_ooooli0000o`/0oh001@000?l80?n000D0003o
2@3oP00R0000o`D0oh0010000?l>ooooobL0003o0P3oP00D0000o`80oh001`000?l>0?n000@0003o
1@3oP0020000o`@0oh0000<0003o0?n0003oP0001`3oP0020000o`T0oh000P000?l90?n000L0003o
3_ooool50000oa@0oh001@000?lB0?n000H0o`003P3oP0070?l000@0oh000P000?l00`3oP000003o
0000o`020?n000@0003o0`3oP0020000oa@0oh001`000?l30?n000P0003o00<0oh000?l0003o0000
0P3o000Hooooo`005_oooon:0?l000kooooo=0000?l20?n00080003o0`3oP0020000o`L0oh000P00
0?lI0?n00200003o103oP0070000o`kooooo0P000?l30?n001H0003o0P3oP00:0000o`@0oh000P00
0?l20?n000030000o`3oP000oh000080oh0040000?l20?n000<0003o2`3oP0040000o`<0oh006000
0?l50?n00080003o1`3oP0090000o`kooooo1@000?l=0?n000@0o`000`3oP0040000oa<0oh000P3o
000B0?n000L0o`000P3oP0040000o`h0oh000P000?l70?n000@0o`00303oP00;0000o`<0oh000P3o
00020?n001Sooooo000FooooohX0o`003_oooold0000o`80oh000P000?l30?n00080003o1`3oP002
0000oaT0oh0080000?l40?n000L0003o3_ooool20000o`<0oh005P000?l20?n000X0003o103oP002
0000o`80oh0000<0003o0?n0003oP0000P3oP00@0000o`80oh000`000?l;0?n000@0003o0`3oP00H
0000o`D0oh000P000?l70?n000T0003o3_ooool50000o`d0oh00103o00030?n000@0003o4`3oP002
0?l00180oh001`3o00020?n000@0003o3P3oP0020000o`L0oh00103o000<0?n000/0003o0`3oP002
0?l00080oh006?ooool001KoooooRP3o000>ooooocH0003o303oP0070000o`/0oh0010000?l70?n0
01h0003o203oP0050000o`kooooo10000?l00`3oP000003o0000o`0h0000o`80oh000`000?l70?n0
0080003o1@3oP00Q0000o`D0oh001`000?l20?n000T0003o3_ooool40?n000030000o`3oP000oh00
00H0oh000`000?l20?n000D0o`007@3oP0040000o`T0oh0000<0003o0?n0003oP0001@3oP0060?l0
0080oh0000<0o`000?n0003oP0000P3oP0050000o`80oh000P000?l90?n000T0o`001@3oP0070000
o`P0oh000`3o00020?n001Sooooo000FooooohX0o`003_oooolf0000o``0oh001`000?l;0?n000@0
003o1`3oP00N0000o`P0oh001@000?l>ooooo`@0003o00<0oh000000o`000?l0>0000?l20?n000<0
003o1`3oP0020000o`D0oh008@000?l50?n000L0003o0P3oP0090000o`kooooo103oP0000`000?l0
oh000?n000060?n000<0003o0P3oP0050?l001d0oh0010000?l90?n000030000o`3oP000oh0000D0
oh001P3o00020?n000030?l0003oP000oh000080oh001@000?l20?n00080003o2@3oP0090?l000D0
oh001`000?l80?n000<0o`000P3oP00Hooooo`005_oooon:0?l000kooooo>0000?l90?n000L0003o
1`3oP0020?l000h0oh0080000?l70?n000@0003o3_ooool20000o`80oh0030000?l40?n002/0003o
0P3oP0000`000?l0oh000?n000020?n00080003o2P3oP00h0000o`kooooo0P3oP0020?l000<0oh00
103o00020?n000<0003o103oP0030?l001d0oh0010000?l30?n00080o`001@3oP0020000oa80oh00
0P000?l20?n000030000o`3oP000oh0000@0003o0P3oP0000`000?l0oh000?n000040?n000L0o`00
1`3oP0070000o`80oh001`3o00020?n001Sooooo000FooooohX0o`003_oooolh0000o`T0oh001`00
0?l70?n00080o`003P3oP00P0000o`L0oh0010000?l>ooooo`80003o0P3oP00<0000o`@0oh00:`00
0?l20?n000030000o`3oP000oh000080oh000P000?l:0?n003P0003o3_ooool20?n00080o`000`3o
P0040?l00080oh000`000?l40?n000<0o`007@3oP0040000o`<0oh000P3o00050?n00080003o4P3o
P0020000o`80oh0000<0003o0?n0003oP00010000?l20?n000030000o`3oP000oh0000@0oh001`3o
00070?n000L0003o0P3oP0070?l00080oh006?ooool001KoooooL`3o00000`3oP000o`000?l0000D
0?l000kooooo7@000?l00`3oP000003o0000o`020000o`80oh0050000?l:0?n00080003o6@3oP00M
0000o`80oh003P000?l>ooooodP0003o00<0oh000000o`000?l010000?l20?n003T0003o3_ooool4
0?l000D0oh000P3o00020?n000<0003o103oP0030?l000T0oh000P000?lB0?n00080003o1@3oP002
0?l000L0oh000P3o00030?n000@0o`002@3oP0050000o`80oh00103o00020?n000030000o`3oP000
oh0000@0oh002P3o00040?n000@0003o0`3oP0070?l000@0oh006?ooool001KoooooL`3o00000`3o
P000o`000?l0000D0?l000kooooo7@000?l00`3oP000003o0000o`020000o`80oh0050000?l:0?n0
0080003o6@3oP00M0000o`80oh003P000?l>ooooodP0003o00<0oh000000o`000?l010000?l20?n0
03T0003o3_ooool40?l000D0oh000P3o00020?n000<0003o103oP0030?l000T0oh000P000?lB0?n0
0080003o1@3oP0020?l000L0oh000P3o00030?n000@0o`002@3oP0050000o`80oh00103o00020?n0
00030000o`3oP000oh0000@0oh002P3o00040?n000@0003o0`3oP0070?l000@0oh006?ooool001Ko
ooooRP3o000>ooooocH0003o803oP0020000o`L0oh006`000?l;0?n000D0003o3_oooon:0000o`ko
oooo103o00090?n000L0003o0`3oP0020000o`L0oh0010000?l30?n00080o`000P3oP0050000o`@0
oh000P000?l20?n000030000o`3oP000oh0000h0oh000P3o00020?n00080o`002@3oP0030?l00080
oh00103o00050?n000h0o`00103oP0040000o`<0oh001P3o00050?n001Sooooo000Foooooa00o`00
0P3oP01h0?l000kooooo1`000?l20?n001@0003o00<0oh000000o`000?l06@000?lI0?n00080003o
2`3oP00I0000o`L0oh000P000?l20?n000L0003o3_oooon50000o`030?n000000?l0003o0080003o
3_ooool20?l000L0oh00103o00000`3oP000003o0000o`060000o`030?n000000?l0003o00L0oh00
10000?l30?n00080o`00103oP0020?l000h0oh000P000?lC0?n000@0o`000P3oP0030?l00080oh00
0P3o00020?n000<0003o103oP0020?l00080oh002P3o00040?n00080003o3P3oP00Hooooo`005_oo
ool@0?l00080oh00N03o000>ooooo`L0003o0P3oP00D0000o`030?n000000?l0003o01T0003o6@3o
P0020000o`/0oh006@000?l70?n00080003o0P3oP0070000o`koooooQ@000?l00`3oP000003o0000
o`020000o`kooooo0P3o00070?n000@0o`0000<0oh000000o`000?l01P000?l00`3oP000003o0000
o`070?n000@0003o0`3oP0020?l000@0oh000P3o000>0?n00080003o4`3oP0040?l00080oh000`3o
00020?n00080o`000P3oP0030000o`@0oh000P3o00020?n000X0o`00103oP0020000o`h0oh006?oo
ool001KoooooP`3o00020?n000030?l0003oP000oh000080o`003_oooolM0000o`030?n000000?l0
003o01T0003o6@3oP0040000oa@0oh0040000?l50?n000/0003o3_oooon:0000o`kooooo1`3oP006
0?l000<0oh0010000?l30?n00080003o1`3oP0040000o``0oh001P000?l20?n000<0003o3@3oP000
0`000?l0oh000?n000090?n000L0o`000P3oP0040?l000D0oh00103o00070?n000L0o`00103oP000
0`3o0000oh000?n000040?l000L0oh006?ooool001KoooooP`3o00020?n000030?l0003oP000oh00
0080o`003_oooolM0000o`030?n000000?l0003o01T0003o6@3oP0040000oa@0oh0040000?l50?n0
00/0003o3_oooon:0000o`kooooo1`3oP0060?l000<0oh0010000?l30?n00080003o1`3oP0040000
o``0oh001P000?l20?n000<0003o3@3oP0000`000?l0oh000?n000090?n000L0o`000P3oP0040?l0
00D0oh00103o00070?n000L0o`00103oP0000`3o0000oh000?n000040?l000L0oh006?ooool001Ko
ooooK@3o00020?n000h0o`000P3oP0040?l000D0oh000P3o000>oooooc/0003o0P3oP0050000o`l0
oh001@000?l20?n00080003o3P3oP00D0000o`030?n000000?l0003o00/0003o3_oooomM0000o`80
oh00:`000?l>ooooo`L0oh000P3o00020?n00080o`001@3oP0020000o`80oh000`000?l70?n000H0
003o1@3oP0020?l000<0oh002`000?l40?n00080003o00<0oh000000o`000?l02`3oP0030000o`T0
oh001P3o000@0?n000L0o`00103oP0050?l000T0oh006?ooool001KoooooK@3o00020?n000h0o`00
0P3oP0040?l000D0oh000P3o000>oooooc/0003o0P3oP0050000o`l0oh001@000?l20?n00080003o
3P3oP00D0000o`030?n000000?l0003o00/0003o3_oooomM0000o`80oh00:`000?l>ooooo`L0oh00
0P3o00020?n00080o`001@3oP0020000o`80oh000`000?l70?n000H0003o1@3oP0020?l000<0oh00
2`000?l40?n00080003o00<0oh000000o`000?l02`3oP0030000o`T0oh001P3o000@0?n000L0o`00
103oP0050?l000T0oh006?ooool001KoooooB03o00000`3oP000o`000?l0000b0?l000@0oh002@3o
000>oooooa/0003o0`3oP00H0000o`80oh0000<0003o0?n0003oP0005`3oP0040000o`80oh000`00
0?l;0?n002@0003o3_oooomA0000o`030?n000000?l0003o00T0003o0P3oP00[0000o`kooooo0P00
0?l>0?n000@0003o0P3oP0030000o`D0oh002@000?l80?n000T0003o403oP0050?l000D0003o2@3o
P0040?l000D0oh001P3o00020?n000030?l0003oP000oh0000D0oh00103o00050?n000@0o`002@3o
P00Hooooo`005_oooom80?l000030?n0003o0000o`000380o`00103oP0090?l000kooooo6`000?l3
0?n001P0003o0P3oP0000`000?l0oh000?n0000G0?n000@0003o0P3oP0030000o`/0oh0090000?l>
oooooe40003o00<0oh000000o`000?l02@000?l20?n002/0003o3_ooool20000o`h0oh0010000?l2
0?n000<0003o1@3oP0090000o`P0oh002@000?l@0?n000D0o`001@000?l90?n000@0o`001@3oP006
0?l00080oh0000<0o`000?n0003oP0001@3oP0040?l000D0oh00103o00090?n001Sooooo000Foooo
odP0o`0000<0oh000?l0003o0000903o00020?n000D0o`000P3oP0040?l000L0oh001`3o000>oooo
oa/0003o1`3oP00F0000o`T0oh000`000?l=0?n000`0003o1`3oP00O0000o`80oh001@000?l>oooo
ohX0003o3_ooool20?n000<0o`001P3oP0050000o`H0oh001@000?l30?n000T0003o103oP0020?l0
0080oh003P000?l90?n000L0o`001`3oP00=0?l000<0oh002@3o00090?n00080o`001@3oP0020?l0
00/0oh006?ooool001KoooooD@3o00000`3oP000o`000?l000040?l000<0oh007@3o00020?n000D0
o`00103oP0070?l000kooooo6`000?l70?n001@0003o2`3oP0000`000?l0oh000?n000020?n00080
003o0`3oP0020000o`@0oh0030000?l60?n001`0003o1`3oP0040000o`koooooIP000?l20?n00280
003o3_ooool=0?n000030000o`3oP000oh0000H0oh002P000?l20?n000@0003o0`3oP0060?l00003
0000o`3oP000oh0000T0003o1P3oP0000`3o0000oh000?n000020?n000L0o`001`3oP00=0?l00080
oh002@3o00070?n000T0o`000`3oP0090000o`80oh006?ooool001KoooooD@3o00000`3oP000o`00
0?l000040?l000<0oh007@3o00020?n000D0o`00103oP0070?l000kooooo6`000?l70?n001@0003o
2`3oP0000`000?l0oh000?n000020?n00080003o0`3oP0020000o`@0oh0030000?l60?n001`0003o
1`3oP0040000o`koooooIP000?l20?n00280003o3_ooool=0?n000030000o`3oP000oh0000H0oh00
2P000?l20?n000@0003o0`3oP0060?l000030000o`3oP000oh0000T0003o1P3oP0000`3o0000oh00
0?n000020?n000L0o`001`3oP00=0?l00080oh002@3o00070?n000T0o`000`3oP0090000o`80oh00
6?ooool001Kooooo5`3o00020?n00080o`000P3oP00R0?l00080oh006@3o00000`3oP000o`000?l0
000R0?l000@0oh001`3o000>oooooa/0003o1@3oP00F0000o`/0oh0000<0003o0?n0003oP0000P3o
P0020000o`T0oh002@000?l30?n00080003o103oP00P0000o`<0oh0010000?l>ooooodd0003o103o
P00B0000o`h0oh006@000?l>ooooo`@0oh000`000?l?0?n00140003o0P3oP0060?l000030?n0003o
0000o`0000@0oh000P000?l50?n001@0o`000`3oP0090?l00080oh000P3o00020?n000L0o`00303o
P0070?l000d0oh006?ooool001Kooooo5`3o00020?n00080o`000P3oP00R0?l00080oh006@3o0000
0`3oP000o`000?l0000R0?l000@0oh001`3o000>oooooa/0003o1@3oP00F0000o`/0oh0000<0003o
0?n0003oP0000P3oP0020000o`T0oh002@000?l30?n00080003o103oP00P0000o`<0oh0010000?l>
ooooodd0003o103oP00B0000o`h0oh006@000?l>ooooo`@0oh000`000?l?0?n00140003o0P3oP006
0?l000030?n0003o0000o`0000@0oh000P000?l50?n001@0o`000`3oP0090?l00080oh000P3o0002
0?n000L0o`00303oP0070?l000d0oh006?ooool001Kooooo0P3oP0020?l000030?n0003o0000o`00
01@0o`000P3oP00U0?l00080oh005P3o00000`3oP000o`000?l0000T0?l000@0oh001@3o000>oooo
oc/0003o1P3oP0000`000?l0oh000?n000040?n000030?l0003oP000oh0000H0oh001@000?l20?n0
0080003o0`3oP0020000o`D0oh0060000?l50?n00080003o0P3oP0050000o`kooooo9`000?l20?n0
00@0003o0P3oP00L0000o`80oh005`000?l80?n001h0003o3_ooool50?n000H0003o2`3oP00A0000
o`@0oh001`3o00040?n000<0003o103oP0050?l00080oh003@3o00050?n000L0o`00103oP00;0?l0
00030?n000000?l0003o00L0oh001`3o00090?n000@0o`006?ooool001Kooooo0P3oP0020?l00003
0?n0003o0000o`0001@0o`000P3oP00U0?l00080oh005P3o00000`3oP000o`000?l0000T0?l000@0
oh001@3o000>oooooc/0003o1P3oP0000`000?l0oh000?n000040?n000030?l0003oP000oh0000H0
oh001@000?l20?n00080003o0`3oP0020000o`D0oh0060000?l50?n00080003o0P3oP0050000o`ko
oooo9`000?l20?n000@0003o0P3oP00L0000o`80oh005`000?l80?n001h0003o3_ooool50?n000H0
003o2`3oP00A0000o`@0oh001`3o00040?n000<0003o103oP0050?l00080oh003@3o00050?n000L0
o`00103oP00;0?l000030?n000000?l0003o00L0oh001`3o00090?n000@0o`006?ooool001Kooooo
0P3oP00T0?l000030?n0003o0000o`0001T0o`000P3oP00R0?l00080oh006@3o00040?n000D0o`00
3_ooool20000o`<0oh00=0000?l=0?n00080003o00<0oh000?l0003o0000103oP00;0000o`030?n0
00000?l0003o0080003o0P3oP0020000o`D0oh005`000?l70?n000@0003o3_ooool50000o`80oh00
80000?l40?n00080003o0P3oP00@0000o`80oh0020000?l60?n00100003o0P3oP0020000o`T0oh00
7P000?l>ooooo`@0oh001`000?l70?n001D0003o103oP0050?l000d0oh001@3o00040?n00080o`00
00<0oh000?l0003o00001P3o00070?n000<0o`00203oP0090?l000D0oh000P000?l70?n000L0o`00
1@3oP0040?l001Sooooo000Fooooo`h0o`000P3oP00G0?l00080oh007@3o00020?n001h0o`000P3o
P0040?l000<0oh00103o00000`3oP000o`000?l0000;0?l000@0oh001@3o000>ooooo`80003o0P3o
P00g0000oaT0oh000P000?l20?n000<0003o0P3oP0020000o`/0oh003P000?l20?n00080003o2@3o
P0050000o`kooooo1@000?l20?n002T0003o0P3oP00b0000o`80oh002@000?l20?n001T0003o3_oo
ool20000o`80oh001`000?l70?n00080003o0P3oP0070000o`030?n000000?l0003o00@0003o0P3o
P0000`000?l0oh000?n000040?n000D0o`003`3oP0030?l00100oh000P000?l70?n00080003o103o
P0090?l00100oh0000<0o`000?n0003oP0000P3o00020?n00080o`0000<0oh000?l0003o00000P3o
000Hooooo`005_ooool>0?l00080oh005`3o00020?n001d0o`000P3oP00N0?l00080oh00103o0003
0?n000@0o`0000<0oh000?l0003o00002`3o00040?n000D0o`003_ooool20000o`80oh00=`000?lI
0?n00080003o0P3oP0030000o`80oh000P000?l;0?n000h0003o0P3oP0020000o`T0oh001@000?l>
ooooo`D0003o0P3oP00Y0000o`80oh00<P000?l20?n000T0003o0P3oP00I0000o`kooooo0P000?l2
0?n000L0003o1`3oP0020000o`80oh001`000?l00`3oP000003o0000o`040000o`80oh0000<0003o
0?n0003oP000103oP0050?l000l0oh000`3o000@0?n00080003o1`3oP0020000o`@0oh002@3o000@
0?n000030?l0003oP000oh000080o`000P3oP0020?l000030?n0003o0000o`000080o`006?ooool0
01Kooooo2@3o00020?n001`0o`000P3oP00V0?l00080oh00703o00020?n000@0o`0000<0oh000?l0
003o00000P3o00020?n000<0o`000P3oP0040?l00080oh001@3o000>ooooo`80003o0P3oP00i0000
oa@0oh0040000?l20?n000<0003o1`3oP00?0000o`X0oh0010000?l>ooooocP0003o00<0oh000000
o`000?l010000?l20?n002h0003o0P3oP00E0000o`80oh000P000?l>ooooo`80003o0`3oP0060000
o`L0oh000P000?l50?n00080o`001@3oP0020000o`D0oh000P3o00090?n000@0o`002`3oP0030?l0
00@0oh001@000?l40?n000030?l0003oP000oh000100oh002@3o00090?n00080003o0P3oP0020000
o`030?n0003o0000o`000080o`000P3oP0020?l000D0oh006?ooool001Kooooo2@3o00020?n001`0
o`000P3oP00V0?l00080oh00703o00020?n000@0o`0000<0oh000?l0003o00000P3o00020?n000<0
o`000P3oP0040?l00080oh001@3o000>ooooo`80003o0P3oP00i0000oa@0oh0040000?l20?n000<0
003o1`3oP00?0000o`X0oh0010000?l>ooooocP0003o00<0oh000000o`000?l010000?l20?n002h0
003o0P3oP00E0000o`80oh000P000?l>ooooo`80003o0`3oP0060000o`L0oh000P000?l50?n00080
o`001@3oP0020000o`D0oh000P3o00090?n000@0o`002`3oP0030?l000@0oh001@000?l40?n00003
0?l0003oP000oh000100oh002@3o00090?n00080003o0P3oP0020000o`030?n0003o0000o`000080
o`000P3oP0020?l000D0oh006?ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Rooooog;o00009ooooomao`00
02OoooooLOl0000Wooooog7o00009?ooool002;ooooo00?o0000ooooooooool00ooooolFool000Go
oooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Go
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Co
oooo5ol0o`04oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool001oooooo5ol00?l4oooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000PoooooaKo003o1?oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo
5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`008?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00o`Cooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5
oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000j
oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaKoo`008?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
7ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00
8?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00>_oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool003[ooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l0
0?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000O
oooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000j
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000O
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo000Oo`00
OaOo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5_oo000jo`00
OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo000Oo`00
OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`04o`00
O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000joooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo
5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001D
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1BoooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol0
07lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Bo`00OaOoogl01?l0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo001Do`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Boooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Doooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1Bo`00OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01?l007l00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?l007oo001o06ko001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009oooooma
o`0002Cooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Fooooo`80o`000P000?l0
0`3o0000003o0000o`040?l00080003o00<0o`000000o`000?l0103o00020000o`030?l000000?l0
003o0080o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080003o0P3o0000
0`000?l0o`000?l000020?l00080003o0`3o00020000o`@0o`000P000?l00`3o0000003o0000o`04
0?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`<0o`0010000?l4
0?l000030000o`3o0000o`000080o`0010000?l30?l00080003o0P3o00000`000?l0o`000?l00002
0?l00080003o0`3o00020000o`@0o`000P000?l30?l00080003o3_ooool20?l001`0oh000P000?l6
0?l001L0oh000P000?l30?l000T0oh000P000?l20?n000L0o`001@3oP0020000o`80oh00103o0000
0`000?l0o`000?l000020?l000L0oh00103o000>0?n00080003o0`3o00040?n000kooooo0P000?l3
0?l000T0oh001P3o00030?n000H0o`0000<0003o0?l0003o00000P3o00020000o`80o`001@3oP004
0?l000030000o`3o0000o`0000T0o`0010000?l20?l000030000o`3o0000o`0000D0o`0010000?l2
0?l000<0003o103o00050000o`@0o`000P000?l;0?l000030000o`3o0000o`0000@0o`001`3oP002
0000o`<0o`000P000?l20?l00080003o00<0o`000000o`000?l00P000?l>oooooeX0oh000`3o0007
0?n000P0o`00303oP0020?l00080003o0`3o00020?n00080o`001`3oP00Hooooo`005_ooool20?l0
0080003o00<0o`000000o`000?l0103o00020000o`030?l000000?l0003o00@0o`000P000?l00`3o
0000003o0000o`020?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000
o`80o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l40?l00080003o00<0o`000000
o`000?l0103o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`000P000?l30?l0
00@0003o103o00000`000?l0o`000?l000020?l000@0003o0`3o00020000o`80o`0000<0003o0?l0
003o00000P3o00020000o`<0o`000P000?l40?l00080003o0`3o00020000o`kooooo0P3o000L0?n0
0080003o1P3o000G0?n00080003o0`3o00090?n00080003o0P3oP0070?l000D0oh000P000?l20?n0
00@0o`0000<0003o0?l0003o00000P3o00070?n000@0o`003P3oP0020000o`<0o`00103oP00>oooo
o`80003o0`3o00090?n000H0o`000`3oP0060?l000030000o`3o0000o`000080o`000P000?l20?l0
00D0oh00103o00000`000?l0o`000?l000090?l000@0003o0P3o00000`000?l0o`000?l000050?l0
00@0003o0P3o00030000o`@0o`001@000?l40?l00080003o2`3o00000`000?l0o`000?l000040?l0
00L0oh000P000?l30?l00080003o0P3o00020000o`030?l000000?l0003o0080003o3_oooomJ0?n0
00<0o`001`3oP0080?l000`0oh000P3o00020000o`<0o`000P3oP0020?l000L0oh006?ooool001Ko
oooo2`3o00020000o`030?l000000?l0003o00@0o`000P000?l50?l00080003o0`3o00020000o`@0
o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`<0
o`000P000?l40?l00080003o00<0o`000000o`000?l0103o00000`000?l0o`000?l000020?l00080
003o0`3o00020000o`80o`000P000?l30?l00080003o0P3o00020000o`80o`000`000?l20?l000@0
003o1`3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`@0o`000P000?l30?l00080
003o3_ooool20?l001h0oh00103o000I0?n00080003o0`3o00090?n00080o`000P3oP0050?l000/0
oh00103o00000`000?l0o`000?l000020?l000L0oh00103o000@0?n00080o`001@3oP00>ooooo`D0
o`00203oP0000`3o0000003o0000o`040?l000<0oh000P3o00020000o`80o`0000<0003o0?l0003o
00001P3o00030?n00080003o1@3o00040?n000L0o`000P000?l40?l000030000o`3o0000o`0000D0
o`000P000?l60?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`000080
o`000P000?l;0?l000030000o`3o0000o`0000@0o`001@3oP0020000o`D0o`000P000?l50?l00080
003o0P3o000>ooooodH0oh000P3o000B0?n000<0o`002@3oP0020?l00080003o0`3o000=0?n000<0
o`000P000?l70?n00080o`000P3oP00Hooooo`005_ooool;0?l00080003o00<0o`000000o`000?l0
103o00020000o`D0o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080003o
0P3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`@0o`000P000?l00`3o0000003o
0000o`040?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`<0o`00
0P000?l20?l00080003o0P3o00030000o`80o`0010000?l70?l000030000o`3o0000o`000080o`00
0P000?l30?l00080003o103o00020000o`<0o`000P000?l>ooooo`80o`007P3oP0040?l001T0oh00
0P000?l30?l000T0oh000P3o00020?n000D0o`002`3oP0040?l000030000o`3o0000o`000080o`00
1`3oP0040?l00100oh000P3o00050?n000kooooo1@3o00080?n000030?l000000?l0003o00@0o`00
0`3oP0020?l00080003o0P3o00000`000?l0o`000?l000060?l000<0oh000P000?l50?l000@0oh00
1`3o00020000o`@0o`0000<0003o0?l0003o00001@3o00020000o`H0o`0000<0003o0?l0003o0000
0P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`/0o`0000<0003o0?l0003o0000
103o00050?n00080003o1@3o00020000o`D0o`000P000?l20?l000koooooAP3oP0020?l00180oh00
0`3o00090?n00080o`000P000?l30?l000d0oh000`3o00020000o`L0oh000P3o00020?n001Sooooo
000Fooooo`/0o`000P000?l00`3o0000003o0000o`040?l00080003o00<0o`000000o`000?l00P3o
00020000o`<0o`000P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P3o
00020000o`<0o`000P000?l40?l00080003o00<0o`000000o`000?l0103o00000`000?l0o`000?l0
00020?l00080003o0`3o00020000o`80o`000P000?l70?l00080003o0P3o00030000o`80o`001000
0?l70?l000030000o`3o0000o`000080o`000P000?l30?l00080003o103o00020000o`D0o`003_oo
ool20?l001h0oh00103o000G0?n00080003o1@3o00070?n00080o`000P000?l70?l000L0oh000P00
0?l60?l000030000o`3o0000o`000080o`001`3oP0040?l000h0oh00103o00050?n000kooooo1@3o
00040?n00080003o0`3o00020000o`T0o`000P000?l20?l000030000o`3o0000o`0000@0003o0`3o
00040?n000D0o`001P3oP0050?l00080003o103o00000`000?l0o`000?l000050?l00080003o103o
00030000o`@0o`000P000?l20?l000030000o`3o0000o`0000@0003o0`3o00020?n000L0o`000P00
0?l50?l000@0oh000P000?l30?l00080003o1`3o00020?n00080o`003_oooomV0?n00080o`000P00
0?l30?l000/0oh001`3o000;0?n001Sooooo000Fooooo`D0o`000P000?l40?l00080003o00<0o`00
0000o`000?l00P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o
0?l0003o00001P3o00000`000?l0o`000?l000020?l00080003o0P3o00030000o`80o`000P000?l3
0?l00080003o103o00000`000?l0o`000?l000040000o`<0o`000P000?l20?l00080003o1`3o0002
0000o`80o`000`000?l20?l000D0003o0P3o00020000o`80o`000`3oP0020?l00080003o0`3o0002
0000o`@0o`000`000?l40?l000kooooo0P3o000P0?n00080o`005@3oP0020?l00080003o1`3o0004
0?n000<0o`000P000?l70?l000H0oh0000<0o`000000o`000?l0103o00030000o`@0o`001@3oP002
0000o`D0o`00203oP0030?l00080oh00103o00050?n000kooooo1@3o00040?n00080003o1`3o0002
0000o``0o`0010000?l30?l00080003o0P3oP0050?l000H0oh000P3o00000`000?l0o`000?l00002
0000o`@0o`0000<0003o0?l0003o00001@3o00020000o`@0o`000`000?l40?l000D0003o0P3o0004
0000o`<0o`000P000?l20?n000D0o`000P000?l50?l000@0oh000P000?l70?l00080003o1`3o000>
oooooeX0oh0000<0o`000?n0003oP0002`3oP0020000o`<0o`002`3oP0070?l000/0oh006?ooool0
01Kooooo1@3o00020000o`@0o`000P000?l00`3o0000003o0000o`020?l00080003o0`3o00020000
o`80o`000P000?l30?l00080003o103o00000`000?l0o`000?l000060?l000030000o`3o0000o`00
0080o`000P000?l20?l000<0003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`00
00@0003o0`3o00020000o`80o`000P000?l70?l00080003o0P3o00030000o`80o`001@000?l20?l0
0080003o0P3o00030?n00080o`000P000?l30?l00080003o103o00030000o`@0o`003_ooool20?l0
0200oh000P3o000E0?n00080o`000P000?l70?l000@0oh000`3o00020000o`L0o`001P3oP0000`3o
0000003o0000o`040?l000<0003o103o00050?n00080003o1@3o00080?n000<0o`000P3oP0040?l0
00D0oh003_ooool50?l000@0oh000P000?l70?l00080003o303o00040000o`<0o`000P000?l20?n0
00D0o`001P3oP0020?l000030000o`3o0000o`000080003o103o00000`000?l0o`000?l000050?l0
0080003o103o00030000o`@0o`001@000?l20?l000@0003o0`3o00020000o`80oh001@3o00020000
o`D0o`00103oP0020000o`L0o`000P000?l70?l000koooooFP3oP0000`3o0000oh000?n0000;0?n0
0080003o0`3o000;0?n000L0o`002`3oP00Hooooo`005_ooool50?l00080003o103o00020000o`03
0?l000000?l0003o0080o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l00003
0000o`3o0000o`000080003o103o00000`000?l0o`000?l000060?l000030000o`3o0000o`000080
o`000P000?l30?l00080003o103o00000`000?l0o`000?l000040000o`80o`000`000?l20?l00080
003o0P3o00000`000?l0o`000?l000020?l00080003o0P3o00030000o`80o`001@000?l20?l00080
003o0P3o00030?n000@0003o0`3o00020000o`/0o`003_ooool20?l001h0oh00103o000G0?n000@0
003o1@3o00040?n000<0o`000P000?l70?l00080oh000P000?l30?l00080003o103o00030000o`80
o`001`3oP0020000o`@0o`002@3oP0030?l00080oh00103o00050?n000kooooo0P3oP0030?l000P0
oh0000<0003o0?l0003o00000P3o00020000o`80o`0000<0oh000?l0003o000010000?l30?l000@0
003o0`3o00020000o`L0o`001P3oP0020?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o
00001@3o00020000o`@0o`000`000?l40?l000D0003o0P3o00040000o`<0o`000P000?l60?l00003
0000o`3o0000o`0000D0o`00103oP00B0?l000koooooFP3oP0000`3o0000oh000?n0000=0?n00080
o`002P3oP0020000o`D0o`003@3oP00Hooooo`005_ooool50?l00080003o103o00020000o`030?l0
00000?l0003o0080o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l000030000
o`3o0000o`000080003o103o00000`000?l0o`000?l000060?l000030000o`3o0000o`000080o`00
0P000?l30?l00080003o103o00000`000?l0o`000?l000040000o`80o`000`000?l20?l00080003o
0P3o00000`000?l0o`000?l000020?l00080003o0P3o00030000o`80o`001@000?l20?l00080003o
0P3o00030?n000@0003o0`3o00020000o`/0o`003_ooool20?l001h0oh00103o000G0?n000@0003o
1@3o00040?n000<0o`000P000?l70?l00080oh000P000?l30?l00080003o103o00030000o`80o`00
1`3oP0020000o`@0o`002@3oP0030?l00080oh00103o00050?n000kooooo0P3oP0030?l000P0oh00
00<0003o0?l0003o00000P3o00020000o`80o`0000<0oh000?l0003o000010000?l30?l000@0003o
0`3o00020000o`L0o`001P3oP0020?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o0000
1@3o00020000o`@0o`000`000?l40?l000D0003o0P3o00040000o`<0o`000P000?l60?l000030000
o`3o0000o`0000D0o`00103oP00B0?l000koooooFP3oP0000`3o0000oh000?n0000=0?n00080o`00
2P3oP0020000o`D0o`003@3oP00Hooooo`005_ooool50?l00080003o1`3o00020000o`80o`000P00
0?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o103o
00000`000?l0o`000?l000060?l000030000o`3o0000o`000080o`000P000?l30?l00080003o103o
00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0
003o0?l0003o00000P3o00020000o`80o`002P000?l60?l000030000o`3o0000o`0000@0003o0`3o
00020000o`T0o`000P000?l>ooooo`80o`00503oP0030?l000D0oh001P3o000G0?n000@0003o1@3o
00020000o`D0o`000P000?l70?l00080oh000P000?l30?l00080003o103o00020000o`<0o`001`3o
P0020000o`@0o`002@3oP0000`3o0000oh000?n000040?n00080o`001@3oP00>ooooo`80003o0`3o
00080?n000030000o`3o0000o`0000H0o`000`3oP0040000o`030?l000000?l0003o00@0003o0`3o
00020000o`80o`000P000?l30?l000@0oh00103o00000`000?l0o`000?l000060?l000030000o`3o
0000o`0000D0o`000P000?l40?l00080003o1@3o00020000o`<0o`000P000?l20?l00080003o0`3o
00020000o`H0o`0000<0003o0?l0003o00001@3o00080?n000T0o`0000<0003o0?l0003o00000P3o
000>ooooof`0oh0000<0o`000?n0003oP0001`3oP0020000o`@0o`003P3oP00Hooooo`005_ooool5
0?l00080003o1`3o00020000o`80o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l4
0?l000030000o`3o0000o`000080003o103o00000`000?l0o`000?l000060?l000030000o`3o0000
o`000080o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000o`@0o`0000<0003o
0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`80o`002P000?l6
0?l000030000o`3o0000o`0000@0003o0`3o00020000o`T0o`000P000?l>ooooo`80o`00503oP003
0?l000D0oh001P3o000G0?n000@0003o1@3o00020000o`D0o`000P000?l70?l00080oh000P000?l3
0?l00080003o103o00020000o`<0o`001`3oP0020000o`@0o`002@3oP0000`3o0000oh000?n00004
0?n00080o`001@3oP00>ooooo`80003o0`3o00080?n000030000o`3o0000o`0000H0o`000`3oP004
0000o`030?l000000?l0003o00@0003o0`3o00020000o`80o`000P000?l30?l000@0oh00103o0000
0`000?l0o`000?l000060?l000030000o`3o0000o`0000D0o`000P000?l40?l00080003o1@3o0002
0000o`<0o`000P000?l20?l00080003o0`3o00020000o`H0o`0000<0003o0?l0003o00001@3o0008
0?n000T0o`0000<0003o0?l0003o00000P3o000>ooooof`0oh0000<0o`000?n0003oP0001`3oP002
0000o`@0o`003P3oP00Hooooo`005_ooool50?l00080003o1`3o00020000o`80o`000P000?l30?l0
0080003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o103o00000`00
0?l0o`000?l000060?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00030000
o`80o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`00
00H0o`000`000?l20?l000@0003o2P3o00020000o`D0o`000P000?l40?l00080003o0`3o00020000
o`kooooo0P3o000D0?n000D0o`000`3oP0060?l001L0oh0010000?l50?l000@0003o0`3o00020000
o`T0o`000P000?l30?l00080003o103o00020000o`D0o`001@3oP0020000o`@0o`005`3oP00>oooo
o`D0o`002@3oP0080?l000<0oh000P000?l30?l000H0003o0`3o00040000o`D0o`00103oP0040?l0
00030000o`3o0000o`0000@0o`000`000?l20?l00080003o0`3o00020000o`@0o`000P000?l50?l0
0080003o0`3o00020000o`80o`000P000?l30?l00080003o1P3o00000`000?l0o`000?l000050?l0
00d0oh001`3o00020000o`koooooDP3oP0020?l00280oh000P3o000B0?n001Sooooo000Fooooo`D0
o`000P000?l60?l000<0003o0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`L0
o`000P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P3o00020000o`<0
o`000P000?l20?l000<0003o0P3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`80
o`0000<0003o0?l0003o0000103o00030000o`@0o`0010000?l:0?l00080003o103o00030000o`@0
o`000P000?l30?l00080003o3_ooool20?l001@0oh000`3o00040?n000L0o`000`3oP0020?l00180
oh0010000?l50?l000@0003o0`3o00020000o`80o`000P000?l50?l00080003o0`3o00020000o`@0
o`000P3oP0000`3o0000003o0000o`020?l000D0oh000P000?l40?l00100oh000`3o00040?n000ko
oooo0P3o000>0?n000H0o`000`3oP0040000o`<0o`0010000?l50?l00080oh001@3o00040?n000@0
o`000`000?l20?l000@0003o0`3o00020000o`<0o`000P000?l20?l00080oh000`000?l40?l00080
003o0`3o00020000o`80o`000P000?l30?l00080003o103o00020000o`L0o`002@3oP0030?l00080
003o1`3o00020000o`kooooo103oP0030?l006l0oh000P3o000B0?n001Sooooo000Fooooo`D0o`00
0P000?l60?l000<0003o0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`L0o`00
0P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P3o00020000o`<0o`00
0P000?l20?l000<0003o0P3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`80o`00
00<0003o0?l0003o0000103o00030000o`@0o`0010000?l:0?l00080003o103o00030000o`@0o`00
0P000?l30?l00080003o3_ooool20?l001@0oh000`3o00040?n000L0o`000`3oP0020?l00180oh00
10000?l50?l000@0003o0`3o00020000o`80o`000P000?l50?l00080003o0`3o00020000o`@0o`00
0P3oP0000`3o0000003o0000o`020?l000D0oh000P000?l40?l00100oh000`3o00040?n000kooooo
0P3o000>0?n000H0o`000`3oP0040000o`<0o`0010000?l50?l00080oh001@3o00040?n000@0o`00
0`000?l20?l000@0003o0`3o00020000o`<0o`000P000?l20?l00080oh000`000?l40?l00080003o
0`3o00020000o`80o`000P000?l30?l00080003o103o00020000o`L0o`002@3oP0030?l00080003o
1`3o00020000o`kooooo103oP0030?l006l0oh000P3o000B0?n001Sooooo000Fooooo`D0o`000P00
0?l20?l00080003o0`3o00020000o`80o`000P000?l70?l00080003o00<0o`000000o`000?l00P00
0?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00001P3o00000`000?l0o`000?l0
00020?l00080003o0`3o00020000o`80o`000`000?l20?l00080003o103o00000`000?l0o`000?l0
00020?l00080003o0P3o00000`000?l0o`000?l000020000o`80o`000`000?l40?l000@0003o2P3o
00020000o`D0o`000P000?l90?l00080003o3_oooolG0?n00080o`001@3oP0020?l001/0oh000P00
0?l70?l000@0oh000`3o00020000o`80o`000P000?l30?l000@0003o0`3o00020000o`L0o`000P00
0?l20?l000L0oh00103o00090?n000<0o`000P3oP0050?l000@0oh003_ooool20?l00080003o1@3o
00020?n000D0o`002`3oP0020000o`<0o`0010000?l50?l00080oh001@3o00040?n000D0o`000P00
0?l20?l000@0003o0`3o00040000o`D0o`00103oP0000`000?l0o`000?l000020?l000@0003o00<0
o`000000o`000?l00P3o00020000o`<0o`000P000?l40?l00080003o1`3o00050?n00080o`000P00
0?l30?l000@0003o0`3o00020000o`80o`003_ooool40?n000030?l0003oP000oh0008<0oh006?oo
ool001Kooooo1@3o00020000o`80o`000P000?l30?l00080003o0P3o00020000o`L0o`000P000?l0
0`3o0000003o0000o`020000o`80o`000P000?l30?l00080003o103o00000`000?l0o`000?l00006
0?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00030000o`80o`000P000?l4
0?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`000080003o0P3o0003
0000o`@0o`0010000?l:0?l00080003o1@3o00020000o`T0o`000P000?l>oooooaL0oh000P3o0005
0?n00080o`006`3oP0020000o`L0o`00103oP0030?l00080003o0P3o00020000o`<0o`0010000?l3
0?l00080003o1`3o00020000o`80o`001`3oP0040?l000T0oh000`3o00020?n000D0o`00103oP00>
ooooo`80o`000P000?l50?l00080oh001@3o000;0?n00080003o0`3o00040000o`D0o`000P3oP005
0?l000@0oh001@3o00020000o`80o`0010000?l30?l000@0003o1@3o00040?n000030000o`3o0000
o`000080o`0010000?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`@0o`000P000?l7
0?l000D0oh000P3o00020000o`<0o`0010000?l30?l00080003o0P3o000>ooooo`@0oh0000<0o`00
0?n0003oP000P`3oP00Hooooo`005_ooool40000o`030?l000000?l0003o0080o`000P000?l30?l0
0080003o0P3o00020000o`L0o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000
o`@0o`0000<0003o0?l0003o00000P000?l40?l000030000o`3o0000o`000080o`000P000?l30?l0
0080003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l20?l0
00030000o`3o0000o`0000H0003o1@3o00020000o``0o`000P000?l90?l00080003o1@3o00020000
o`kooooo>`3oP0020000o`D0o`001P3oP0030?l00080003o1`3o00020000o`80o`000P000?l30?l0
0080oh001@3o00020000o`80o`001`3oP0040?l000L0oh001@3o00020000o`L0o`000P3oP00>oooo
o`80o`000P000?l50?l00080oh001@3o000;0?n00080003o0`3o00020000o`80o`000P000?l30?l0
0080003o103o00050?n000D0o`000P000?l20?l000D0003o103o00020000o`<0o`000P000?l50?n0
0080003o103o00020000o`030?l000000?l0003o00@0003o0`3o00020000o`L0o`000P000?l50?l0
00@0oh000P3o00020000o`D0o`000P000?l30?l000@0003o3_ooool40?n000<0o`00P`3oP00Hoooo
o`005_ooool40000o`030?l000000?l0003o0080o`000P000?l30?l00080003o0P3o00020000o`L0
o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o
00000P000?l40?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`<0
o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`0000H0
003o1@3o00020000o``0o`000P000?l90?l00080003o1@3o00020000o`kooooo>`3oP0020000o`D0
o`001P3oP0030?l00080003o1`3o00020000o`80o`000P000?l30?l00080oh001@3o00020000o`80
o`001`3oP0040?l000L0oh001@3o00020000o`L0o`000P3oP00>ooooo`80o`000P000?l50?l00080
oh001@3o000;0?n00080003o0`3o00020000o`80o`000P000?l30?l00080003o103o00050?n000D0
o`000P000?l20?l000D0003o103o00020000o`<0o`000P000?l50?n00080003o103o00020000o`03
0?l000000?l0003o00@0003o0`3o00020000o`L0o`000P000?l50?l000@0oh000P3o00020000o`D0
o`000P000?l30?l000@0003o3_ooool40?n000<0o`00P`3oP00Hooooo`005_ooool40000o`030?l0
00000?l0003o0080o`000P000?l30?l00080003o2`3o00020000o`<0o`000P000?l40?l000030000
o`3o0000o`000080003o103o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o0000
0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o0000
0P3o00020000o`80o`0000<0003o0?l0003o0000103o00020000o`<0o`000P000?l20?l00080003o
1`3o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`D0o`00
0P000?l>oooooc/0oh000P000?l50?l000H0oh000`3o00020000o`@0o`0000<0003o0?l0003o0000
0P000?l20?l00080003o0`3o00020?n000@0o`005`3oP0030?l00080003o1`3o00040?n000kooooo
0P3o00020000o`D0o`000P3oP0050?l000T0oh000P000?l30?l00080003o103o00020000o`<0o`00
0P000?l40?l000D0oh001@3o00020000o`@0o`000`000?l40?l00080003o1`3o00030?n00080003o
103o00020000o`<0o`0010000?l50?l00080oh000P000?l30?l000@0003o0`3o00060?n00080003o
2P3o00040000o`kooooo103oP0030?l006D0oh0000<0o`000?n0003oP0005P3oP0030?l00080oh00
6?ooool001Kooooo10000?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`/0o`000P00
0?l30?l00080003o103o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o00000P00
0?l40?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`<0o`000P00
0?l40?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`0000@0o`000P00
0?l30?l00080003o0P3o00020000o`L0o`0000<0003o0?l0003o00000P000?l40?l000030000o`3o
0000o`000080o`000P000?l50?l00080003o3_oooolk0?n00080003o1@3o00060?n000<0o`000P00
0?l40?l000030000o`3o0000o`000080003o0P3o00020000o`<0o`000P3oP0040?l001L0oh000`3o
00020000o`L0o`00103oP00>ooooo`80o`000P000?l50?l00080oh001@3o00090?n00080003o0`3o
00020000o`@0o`000P000?l30?l00080003o103o00050?n000D0o`000P000?l40?l000<0003o103o
00020000o`L0o`000`3oP0020000o`@0o`000P000?l30?l000@0003o1@3o00020?n00080003o0`3o
00040000o`<0o`001P3oP0020000o`X0o`0010000?l>ooooo`@0oh000`3o001U0?n000030?l0003o
P000oh0001H0oh000`3o00020?n001Sooooo000Fooooo`80003o0`3o00020000o`80o`000P000?l3
0?l00080003o2`3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o1`3o0002
0000o`@0o`000`000?l20?l00080003o0`3o00020000o`80o`000P000?l30?l00080003o103o0000
0`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`000?l000040?l00080003o0`3o0002
0000o`/0o`0000<0003o0?l0003o00000P000?l40?l000030000o`3o0000o`000080o`000P000?l5
0?l00080003o3_oooolk0?n00080003o1@3o00060?n000<0o`000P000?l40?l000030000o`3o0000
o`000080003o103o00050?n000D0o`002`3oP0020?l000T0oh000`3o00020000o`L0o`00103oP00>
ooooo`T0o`00103oP0000`3o0000003o0000o`020?l000L0oh001@3o00020000o`@0o`000P000?l3
0?l00080003o1@3o00020000o`L0o`000P000?l40?l000<0003o103o00020000o`<0o`000P000?l2
0?l00080003o00<0o`000000o`000?l0103o00020000o`<0o`0010000?l30?l00080003o1`3o0004
0000o`<0o`002@3oP0090?l000@0003o3_oooomQ0?n00080o`001`3oP0020000o`<0o`006`3oP00H
ooooo`005_ooool20000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`000P000?l00`3o
0000003o0000o`020?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P000?l70?l0
0080003o103o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`000P000?l30?l0
0080003o103o00000`000?l0o`000?l000060?l000030000o`3o0000o`0000@0o`000P000?l30?l0
0080003o0P3o00020000o`L0o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0
003o00000P3o00040000o`<0o`000P000?l>oooooc/0oh000P000?l70?l000@0oh000`3o00020000
o`@0o`0000<0003o0?l0003o00000P000?lG0?n000@0o`002`3oP0000`3o0000003o0000o`090?l0
0080oh003_ooool20?l00080003o0`3o000;0?n00080o`001@3oP0020?l00080003o00<0o`000000
o`000?l00P3o00040000o`D0o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l0
0080003o1@3o00020000o`<0o`000P000?l20?l00080003o00<0o`000000o`000?l00P000?l20?l0
0080003o00<0o`000000o`000?l00P000?l50?l00080003o1`3o00040000o`<0o`002@3oP0020000
o`@0o`000P000?l00`3o0000003o0000o`020000o`kooooo1@3oP0020?l00080003oC@3oP0020?l0
00L0oh000P3o00020000o`030?l0003oP000oh0000@0oh000`3o000M0?n001Sooooo000Fooooo`80
003o0`3o00020000o`80o`000P000?l30?l00080003o103o00020000o`030?l000000?l0003o0080
o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000o`L0o`000P000?l40?l00003
0000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l00003
0000o`3o0000o`0000H0o`0000<0003o0?l0003o0000103o00020000o`<0o`000P000?l20?l00080
003o1`3o00000`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`000?l000020?l000@0
003o0`3o00020000o`kooooo>`3oP0020000o`L0o`00103oP0030?l00080003o103o00000`000?l0
o`000?l000020000oaL0oh00103o000;0?n000030?l000000?l0003o00T0o`000P3oP00>ooooo`80
o`000P000?l30?l000/0oh000P3o00050?n00080o`000P000?l00`3o0000003o0000o`020?l000@0
003o1@3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`000P000?l50?l00080
003o0`3o00020000o`80o`000P000?l00`3o0000003o0000o`020000o`80o`000P000?l00`3o0000
003o0000o`020000o`D0o`000P000?l70?l000@0003o0`3o00090?n00080003o103o00020000o`03
0?l000000?l0003o0080003o3_ooool50?n00080o`000P000?m=0?n00080o`001`3oP0020?l00080
003o00<0o`000?n0003oP000103oP0030?l001d0oh006?ooool001Kooooo0P000?l30?l00080003o
0P3o00020000o`<0o`000P000?l40?l00080003o00<0o`000000o`000?l00P3o00020000o`<0o`00
0P000?l40?l000030000o`3o0000o`000080003o1`3o00020000o`@0o`0000<0003o0?l0003o0000
0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o0000
1P3o00000`000?l0o`000?l000020000o`80o`000P000?l30?l00080003o2`3o00000`000?l0o`00
0?l000020?l00080003o1`3o00040000o`<0o`000P000?l>oooooc/0oh000P000?l70?l000@0oh00
0`3o00020000o`@0o`0000<0003o0?l0003o00000P000?l20?l00080003o00<0o`000?n0003oP000
403oP0040?l000/0oh0000<0o`000000o`000?l02@3o00020?n000kooooo0P3o000E0?n000@0o`00
0P000?l50?l00080003o1`3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`00
0P000?l50?l00080003o0`3o000;0000o`80o`000P000?l30?l00080003o1@3o00020000o`L0o`00
103oP0030?l000T0oh000P3o00020000o`80o`000P000?l00`3o0000003o0000o`020000o`kooooo
B@3oP0020?l001H0oh000P000?l00`3o0000oh000?n000040?n000D0o`006`3oP00Hooooo`005_oo
ool20000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`000P000?l00`3o0000003o0000
o`020?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P000?l70?l00080003o103o
00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`000P000?l30?l00080003o103o
00000`000?l0o`000?l000060?l000030000o`3o0000o`000080003o0P3o00020000o`<0o`000P00
0?l;0?l000030000o`3o0000o`000080o`000P000?l70?l000@0003o0`3o00020000o`kooooo>`3o
P0020000o`L0o`00103oP0030?l00080003o103o00000`000?l0o`000?l000020000o`80o`000P00
0?l00`3o0000oh000?n0000@0?n000@0o`002`3oP0000`3o0000003o0000o`090?l00080oh003_oo
ool20?l001D0oh00103o00020000o`D0o`000P000?l70?l00080003o0`3o00020000o`80o`000P00
0?l30?l00080003o103o00020000o`D0o`000P000?l30?l000/0003o0P3o00020000o`<0o`000P00
0?l50?l00080003o1`3o00040?n000<0o`002@3oP0020?l00080003o0P3o00020000o`030?l00000
0?l0003o0080003o3_oooom90?n00080o`005P3oP0020000o`030?l0003oP000oh0000@0oh001@3o
000K0?n001Sooooo000Fooooo`80003o0`3o00020000o`80o`000P000?l30?l00080003o103o0002
0000o`030?l000000?l0003o0080o`000P000?l30?l00080003o103o00000`000?l0o`000?l00002
0000o`L0o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o0002
0000o`<0o`000P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P000?l2
0?l00080003o0`3o00020000o`D0o`000P000?l40?l000030000o`3o0000o`0000@0003o0`3o0002
0000o`80o`0010000?l30?l00080003o3_oooolk0?n00080003o1`3o00040?n000<0o`000P000?l4
0?l000030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o0100oh00103o000<
0?n00080003o2@3o00020?n000kooooo0P3o00020000o`030?n0003o0000o`0000@0oh001@3o0007
0?n000@0o`000P000?l70?l00080003o1@3o00020000o`80o`0000<0003o0?l0003o00000P3o0002
0000o`<0o`000P000?l40?l00080003o1@3o00020000o`<0o`0010000?l30?l00080003o103o0002
0000o`<0o`000P000?l50?l00080003o1`3o000?0?n000<0o`000P000?l20?l00080003o1@3o000>
oooooeH0oh00103o00000`000?l0oh000?n000040?n00080003o2@3oP0000`3o0000oh000?n0000K
0?n001Sooooo000Fooooo`80003o0`3o00020000o`80o`000P000?l30?l00080003o103o00020000
o`030?l000000?l0003o0080o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000
o`L0o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000
o`<0o`000P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P000?l20?l0
0080003o0`3o00020000o`D0o`000P000?l40?l000030000o`3o0000o`0000@0003o0`3o00020000
o`80o`0010000?l30?l00080003o3_oooolk0?n00080003o1`3o00040?n000<0o`000P000?l40?l0
00030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o0100oh00103o000<0?n0
0080003o2@3o00020?n000kooooo0P3o00020000o`030?n0003o0000o`0000@0oh001@3o00070?n0
00@0o`000P000?l70?l00080003o1@3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000
o`<0o`000P000?l40?l00080003o1@3o00020000o`<0o`0010000?l30?l00080003o103o00020000
o`<0o`000P000?l50?l00080003o1`3o000?0?n000<0o`000P000?l20?l00080003o1@3o000>oooo
oeH0oh00103o00000`000?l0oh000?n000040?n00080003o2@3oP0000`3o0000oh000?n0000K0?n0
01Sooooo000Fooooo`80003o0`3o00020000o`80o`000P000?l20?l000<0003o103o00020000o`03
0?l000000?l0003o0080o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020000o`80
o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80
o`000P000?l30?l00080003o103o00000`000?l0o`000?l000040000o`80o`0000<0003o0?l0003o
00000P000?l20?l00080003o0`3o00020000o`80o`000P000?l00`3o0000003o0000o`040?l00003
0000o`3o0000o`0000@0003o0`3o00020000o`@0o`000P000?l30?l00080003o3_ooooli0?n000@0
003o1`3o00020000o`80oh000`3o00020000o`L0o`000P000?l50?l00080003o1`3oP0020?l000L0
oh001P3o000<0?n000L0o`00103oP00>ooooo`80o`000P000?l50?l00080oh000P000?l30?l000H0
oh001@3o00020000o`L0o`000P000?lB0?l000030?n000000?l0003o00@0o`000P000?l50?l00080
003o0`3o00040000o`80o`000`000?l40?l00080003o0`3o00040000o`<0o`000P000?l70?l000@0
oh000`3o00080?n000L0o`000`000?l40?l000koooooK03oP0000`3o0000oh000?n000020000oaT0
oh006?ooool001Kooooo0P000?l30?l00080003o0P3o00020000o`80o`000`000?l40?l00080003o
00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o
0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080o`000P000?l30?l00080003o
0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`0000@0003o0P3o00000`000?l0o`00
0?l000020000o`80o`000P000?l30?l00080003o0P3o00020000o`030?l000000?l0003o00@0o`00
00<0003o0?l0003o000010000?l30?l00080003o103o00020000o`<0o`000P000?l>ooooocT0oh00
10000?l70?l00080003o0P3oP0030?l00080003o1`3o00020000o`D0o`000P000?l70?n00080o`00
1`3oP0060?l000`0oh001`3o00040?n000kooooo0P3o00020000o`D0o`000P3oP0020000o`<0o`00
1P3oP0050?l00080003o1`3o00020000oa80o`0000<0oh000000o`000?l0103o00020000o`D0o`00
0P000?l30?l000@0003o0P3o00030000o`@0o`000P000?l30?l000@0003o0`3o00020000o`L0o`00
103oP0030?l000P0oh001`3o00030000o`@0o`003_oooom/0?n000030?l0003oP000oh000080003o
6@3oP00Hooooo`005_ooool20000o`<0o`00103oP0050?l00080003o103o00020000o`030?l00000
0?l0003o0080o`000P000?l30?l00080003o1`3o00020000o`80o`000P000?l30?l00080003o103o
00000`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o0`3o
00020000o`@0o`0000<0003o0?l0003o00001P3o00000`000?l0o`000?l000020000o`80o`000P00
0?l00`3o0000003o0000o`020000o`80o`000P000?l00`3o0000003o0000o`040?l000030000o`3o
0000o`0000@0003o0`3o00020000o`80o`000P000?l50?l00080003o3_ooooli0?n000@0003o0P3o
00020000o`<0o`000P3oP0020000o`<0o`000P000?l70?l000@0003o0`3o00020000o`L0oh00103o
00050?n000H0o`00403oP0020?l000D0oh003_ooool20?l00080003o00<0o`000?n0003oP0000P3o
00020?n00080003o1`3o00020?n000D0o`000P000?l70?l00080003o0`3o00020000o`80o`000P00
0?l30?l000T0oh00103o00020000o`D0o`000P000?l30?l00080003o103o00030000o`@0o`000P00
0?l00`3o0000003o0000o`060000o`030?l000000?l0003o0080003o1@3o00040?n000<0o`001P3o
P0090?l000<0003o103o000>ooooogP0oh000P000?l20?l000h0oh006?ooool001Kooooo0P000?l5
0?l00080oh000P000?l30?l00080003o103o00020000o`030?l000000?l0003o0080o`000P000?l3
0?l00080003o1`3o00020000o`80o`000P000?l30?l00080003o103o00000`000?l0o`000?l00002
0?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`000`000?l8
0?l000030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o0080003o0P3o0002
0000o`030?l000000?l0003o00@0o`0000<0003o0?l0003o000010000?l20?l000<0003o0P3o0002
0000o`<0o`000P000?l20?l000kooooo>`3oP0020000o`L0o`000P3oP0020000o`<0o`000P000?l2
0?l00080003o0`3o00040000o`<0o`000P000?l20?n00080o`000`3oP0040?l000D0oh000P000?l4
0?l001L0oh003_ooool20?l00080oh001@3o00020?n00080003o0`3o00020000o`@0oh0000<0003o
0?l0003o00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`80o`000P000?l3
0?l000L0oh000P000?l40?l00080003o0`3o00040000o`<0o`000P000?l40?l000030?n0003o0000
o`0000@0o`000P000?l00`3o0000003o0000o`060000o`030?l000000?l0003o0080003o0P3o0002
0000o`<0o`000P000?l50?l00080003o2@3o00050000o`@0o`003_oooomh0?n00080003o0P3o000>
0?n001Sooooo000Fooooo`80003o1@3o00020?n00080003o0`3o00020000o`@0o`000P000?l00`3o
0000003o0000o`020?l00080003o0`3o00020000o`L0o`000P000?l20?l00080003o0`3o00020000
o`@0o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000
o`<0o`000P000?l20?l000<0003o203o00000`000?l0o`000?l000020000o`80o`000P000?l00`3o
0000003o0000o`020000o`80o`000P000?l00`3o0000003o0000o`040?l000030000o`3o0000o`00
00@0003o0P3o00030000o`80o`000P000?l30?l00080003o0P3o000>oooooc/0oh000P000?l70?l0
0080oh000P000?l30?l00080003o0P3o00020000o`<0o`0010000?l30?l00080003o0P3oP0020?l0
00<0oh00103o00050?n00080003o103o000G0?n000kooooo0P3o00020?n000D0o`000P3oP0020000
o`<0o`000P000?l40?n000030000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000
o`<0o`000P000?l20?l00080003o0`3o00070?n00080003o103o00020000o`<0o`0010000?l30?l0
0080003o103o00000`3oP000o`000?l000040?l00080003o00<0o`000000o`000?l01P000?l00`3o
0000003o0000o`020000o`80o`000P000?l30?l00080003o1@3o00020000o`T0o`001@000?l40?l0
00koooooN03oP0020000o`80o`003P3oP00Hooooo`005_ooool20000o`L0o`000P000?l30?l00080
003o103o00020000o`030?l000000?l0003o0080o`000P000?l30?l00080003o0P3o00020000o`<0
o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?n0003oP0000P3o00020000o`80
o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0
o`0000<0003o0?l0003o00000P000?l20?l00080003o00<0o`000000o`000?l00P000?l20?l00080
003o00<0o`000000o`000?l01`3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`<0
o`000P000?l20?l000kooooo803oP0020?l00180oh000P3o00050?n00080003o1@3o00040?n00080
003o1`3o00020000o`D0o`000P000?l30?l00080003o0P3oP0020?l000`0oh000P000?l40?l000`0
oh001P3o00050?n000kooooo0P3o00050?n00080o`000P3oP0050?l000H0oh0000<0003o0?l0003o
00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00040000o`D0o`000P000?l40?l00003
0?n000000?l0003o00@0o`000P000?l30?l000D0003o0P3o00020000o`@0o`0000<0003o0?l0003o
0000103o00020000o`030?l000000?l0003o00H0003o00<0o`000000o`000?l00P000?l20?l00080
003o0`3o00020000o`D0o`0010000?l70?l00080003o1`3o000>ooooofX0oh000P3o000<0?n00080
003o0P3o000>0?n001Sooooo000Fooooo`80003o1`3o00020000o`<0o`000P000?l40?l00080003o
00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`80o`00
0P000?l30?l00080003o103o00000`000?l0oh000?n000020?l00080003o0P3o00000`000?l0o`00
0?l000020?l00080003o0`3o00020000o`80o`000P000?l30?l00080003o103o00000`000?l0o`00
0?l000020000o`80o`000P000?l00`3o0000003o0000o`020000o`80o`000P000?l00`3o0000003o
0000o`070?l00080003o103o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`00
3_oooolP0?n00080o`004P3oP0020?l000D0oh000P000?l50?l000@0oh000P000?l70?l00080003o
1@3o00020000o`<0o`000P000?l20?n00080o`00303oP0020000o`@0o`00303oP0060?l000D0oh00
3_ooool20?l000D0oh000P3o00020?n000D0o`001P3oP0000`000?l0o`000?l000020?l00080003o
0`3o00020000o`80o`000P000?l30?l000@0003o1@3o00020000o`@0o`0000<0oh000000o`000?l0
103o00020000o`<0o`001@000?l20?l00080003o103o00000`000?l0o`000?l000040?l00080003o
00<0o`000000o`000?l01P000?l00`3o0000003o0000o`020000o`80o`000P000?l30?l00080003o
1@3o00040000o`L0o`000P000?l70?l000koooooJP3oP0020?l000`0oh000P000?l20?l000h0oh00
6?ooool001Kooooo0P000?l70?l00080003o0P3o00030000o`@0o`000P000?l00`3o0000003o0000
o`020?l00080003o0`3o00020000o`80o`000P000?l30?l00080003o0P3o00020000o`L0o`000P00
0?l00`3o0000oh000?n000020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`030?l00000
0?l0003o0080003o0P3o00020000o`<0o`000P000?l20?l00080003o2P3o00040000o`80o`000P00
0?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P3o
00020000o`<0o`000P000?l20?l000kooooo7P3oP0040?l00080003o5`3oP0020000o`D0o`00103o
P0020000o`L0o`000P000?l30?l000H0003o00<0o`000000o`000?l00P3o000>0?n00080003o103o
000<0?n00080o`000P000?l20?l000D0oh003_ooool20?l000T0oh000P000?l50?l000L0oh000P3o
00020000o`<0o`000P000?l20?l00080003o0`3o00060000o`<0o`000P000?l50?l00080003o103o
00030000o`80o`001@000?l20?l00080003o103o00000`000?l0o`000?l000020?l00080oh000P00
0?l00`3o0000003o0000o`040000o`<0o`000P000?l40?n00080003o0`3o00020000o`L0o`000P00
0?l70?l00080003o0`3o00040000o`koooooQP3oP0020?l00080oh006?ooool001Kooooo0P000?l7
0?l00080003o0P3o00030000o`@0o`000P000?l00`3o0000003o0000o`020?l00080003o0`3o0002
0000o`80o`000P000?l30?l00080003o0P3o00020000o`L0o`000P000?l00`3o0000oh000?n00002
0000o`@0o`0000<0003o0?l0003o00000P3o00020000o`030?l000000?l0003o0080003o0P3o0002
0000o`<0o`000P000?l20?l00080003o2P3o00040000o`80o`000P000?l00`3o0000003o0000o`02
0?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l2
0?l000kooooo7P3oP0040?l00080003o5`3oP0020000o`D0o`00103oP0020000o`L0o`000P000?l3
0?l000H0003o00<0o`000000o`000?l00P3o000>0?n00080003o103o000<0?n00080o`000P000?l2
0?l000D0oh003_ooool20?l000T0oh000P000?l50?l000L0oh000P3o00020000o`<0o`000P000?l2
0?l00080003o0`3o00060000o`<0o`000P000?l50?l00080003o103o00030000o`80o`001@000?l2
0?l00080003o103o00000`000?l0o`000?l000020?l00080oh000P000?l00`3o0000003o0000o`04
0000o`<0o`000P000?l40?n00080003o0`3o00020000o`L0o`000P000?l70?l00080003o0`3o0004
0000o`koooooQP3oP0020?l00080oh006?ooool001Kooooo0P000?l;0?l000030000o`3o0000o`00
0080o`000P000?l70?l00080003o1`3o00020000o`L0o`000P000?l00`3o0000003o0000o`040?l0
0080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`030?l000000?l0003o
00@0o`000P000?l30?l00080003o0P3o00020000o`030?l000000?l0003o00L0o`0010000?l20?l0
0080003o00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`00
0080o`000P000?l30?l00080003o0P3o000>oooooah0oh00103o00020000oa00oh000P3o00050?n0
0080003o103o00000`000?l0oh000?n000020?n00080003o00<0o`000000o`000?l0103o00020000
o`<0o`0010000?l30?l00080003o0P3o000>0?n00080003o103o000<0?n00080o`000P000?l30?l0
00@0oh003_ooool20?l000/0oh001@3o00090?n00080003o00<0o`000000o`000?l0103o00020000
o`<0o`001P000?l50?l000D0oh000P000?l40?l000<0003o103o00030000o`80o`000P000?l40?l0
00030000o`3o0000o`0000T0o`0010000?l30?l00080003o0P3o00020?n00080o`000`3oP0020000
o`D0o`00103oP0020?l000<0003o0P3o00020000o`D0o`000P000?l>ooooocT0oh000P3o001:0?n0
00030000o`3o0000o`000080oh006?ooool001Kooooo0P000?l30?l00080oh000P000?l40?l00003
0000o`3o0000o`000080o`000P000?l70?l00080003o00<0o`000000o`000?l0103o00020000o`03
0?l000000?l0003o00L0o`000P000?l40?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o
00001@3o00020000o`@0o`000P000?l30?l00080003o0P3o00020000o`030?l000000?l0003o0080
o`000P000?l30?l00080003o103o00020000o`D0o`000P000?l30?l00080003o103o00000`000?l0
o`000?l000020?l00080003o0P3o00030000o`80o`003_oooolN0?n000H0o`00403oP0020?l000D0
oh000P000?l40?l000030000o`3oP000oh000080003o0`3o00020000o`@0o`000P000?l30?l000@0
003o0`3o00020000o`80o`003P3oP0020000o`@0o`002P3oP0020000o`H0o`001@3oP00>ooooo`80
o`002`3oP0050?l000@0oh0000<0o`000?n0003oP0000P3oP0020000o`030?l000000?l0003o00T0
o`00103oP0020000o`D0o`000P000?l30?n00080003o1P3o00000`000?l0o`000?l000020?l00080
003o0`3o00040000o`<0o`000P000?l20?l000@0003o1@3o00020000o`<0o`0010000?l40?l000<0
oh000P000?l50?l000H0oh000`000?l40?l000<0003o0P3o00020000o`kooooo;`3oP0000`3o0000
oh000?n000070?n00080o`00>03oP0000`3o0000oh000?n0000?0?n000030000o`3o0000o`000080
oh006?ooool001Kooooo0P000?l30?l00080oh000P000?l40?l000030000o`3o0000o`000080o`00
0P000?l70?l00080003o00<0o`000000o`000?l0103o00020000o`030?l000000?l0003o00L0o`00
0P000?l40?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00001@3o00020000o`@0o`00
0P000?l30?l00080003o0P3o00020000o`030?l000000?l0003o0080o`000P000?l30?l00080003o
103o00020000o`D0o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080003o
0P3o00030000o`80o`003_oooolN0?n000H0o`00403oP0020?l000D0oh000P000?l40?l000030000
o`3oP000oh000080003o0`3o00020000o`@0o`000P000?l30?l000@0003o0`3o00020000o`80o`00
3P3oP0020000o`@0o`002P3oP0020000o`H0o`001@3oP00>ooooo`80o`002`3oP0050?l000@0oh00
00<0o`000?n0003oP0000P3oP0020000o`030?l000000?l0003o00T0o`00103oP0020000o`D0o`00
0P000?l30?n00080003o1P3o00000`000?l0o`000?l000020?l00080003o0`3o00040000o`<0o`00
0P000?l20?l000@0003o1@3o00020000o`<0o`0010000?l40?l000<0oh000P000?l50?l000H0oh00
0`000?l40?l000<0003o0P3o00020000o`kooooo;`3oP0000`3o0000oh000?n000070?n00080o`00
>03oP0000`3o0000oh000?n0000?0?n000030000o`3o0000o`000080oh006?ooool001Kooooo103o
00030?n00080003o103o00000`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`000?l0
00050?l00080003o1`3o00020000o`L0o`000P000?l40?l00080003o0`3o00020000o`80o`000`00
0?l20?l00080003o0`3o00020000o`80o`0010000?l00`3o0000003o0000o`020000o`80o`000P00
0?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`@0o`000`000?l90?l00080003o103o
00000`000?l0o`000?l000060?l000030000o`3o0000o`000080o`003_oooolN0?n000H0o`005`3o
P0020000o`@0o`0000<0003o0?l0003o00000P000?l30?l00080003o103o00020000o`D0o`000P00
0?l30?l00080003o403oP0060?l000X0oh000P000?l70?l000@0oh003_ooool20?l000`0oh00103o
00020?n000<0o`001P3oP0000`3o0000003o0000o`090?l000H0oh001@3o00020000o`D0oh001P3o
00000`000?l0o`000?l000020?l00080003o0`3o00040000o`<0o`000P000?l20?l000D0003o0P3o
00040000o`<0o`0010000?l40?l000<0oh000P000?l70?l000@0oh000`000?l40?l00080003o0`3o
00020000o`kooooo;`3oP0030?l000H0oh000`3o000]0?n000@0o`0000<0003o0?l0003o0000103o
P0030?l000l0oh000`3o00020?n001Sooooo000Fooooo`@0o`000`3oP0020000o`@0o`0000<0003o
0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00001@3o00020000o`L0o`000P000?l7
0?l00080003o103o00020000o`<0o`000P000?l20?l000<0003o0P3o00020000o`<0o`000P000?l2
0?l000@0003o00<0o`000000o`000?l00P000?l20?l00080003o00<0o`000000o`000?l00P3o0002
0000o`<0o`000P000?l40?l000<0003o2@3o00020000o`@0o`0000<0003o0?l0003o00001P3o0000
0`000?l0o`000?l000020?l000kooooo7P3oP0060?l001L0oh000P000?l40?l000030000o`3o0000
o`000080003o0`3o00020000o`@0o`000P000?l50?l00080003o0`3o00020000oa00oh001P3o000:
0?n00080003o1`3o00040?n000kooooo0P3o000<0?n000@0o`000P3oP0030?l000H0oh0000<0o`00
0000o`000?l02@3o00060?n000D0o`000P000?l50?n000H0o`0000<0003o0?l0003o00000P3o0002
0000o`<0o`0010000?l30?l00080003o0P3o00050000o`80o`0010000?l30?l000@0003o103o0003
0?n00080003o1`3o00040?n000<0003o103o00020000o`<0o`000P000?l>ooooobl0oh000`3o0006
0?n000<0o`00;@3oP0040?l000030000o`3o0000o`0000@0oh000`3o000?0?n000<0o`000P3oP00H
ooooo`005_ooool40?l000<0oh000P000?l40?l000030000o`3o0000o`0000H0o`0000<0003o0?l0
003o00000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000
o`T0o`000P000?l20?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000
o`<0o`000P000?l40?l00080003o00<0o`000000o`000?l00P3o00020000o`80o`000`000?l60?l0
00030000o`3o0000o`000080003o0`3o00040000o`@0o`0000<0003o0?l0003o00000P000?l40?l0
00030000o`3o0000o`000080o`003_oooolP0?n00080o`006@3oP0020000o`L0o`000P000?l30?l0
00H0003o0`3o00020000o`L0o`000P000?l@0?n000@0o`002`3oP0000`3o0000003o0000o`070?l0
00@0oh003_ooool40?l000<0oh000P3o00050?n000@0o`000P3oP0020000o`030?l0003oP000oh00
00@0oh00303o00060?n000<0o`0010000?l50?n000H0o`0000<0003o0?l0003o000010000?l00`3o
0000003o0000o`020?l00080003o0`3o00020000o`@0o`000`000?l20?l000@0003o0`3o00040000
o`@0o`0000<0oh000?l0003o00001`3o00020000o`@0oh000`000?l40?l00080003o1@3o000>oooo
oc00oh000P3o000M0?n000D0o`002`3oP0040?l000D0oh000P3o00020000o`030?l0003oP000oh00
00@0oh000`3o000?0?n000<0o`000P3oP00Hooooo`005_ooool40?l000<0oh000P000?l40?l00003
0000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P000?l30?l00080003o0P3o00020000o`<0
o`000P000?l20?l00080003o0`3o00020000o`T0o`000P000?l20?l00080003o0`3o00020000o`80
o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l40?l00080003o00<0o`000000o`00
0?l00P3o00020000o`80o`000`000?l60?l000030000o`3o0000o`000080003o0`3o00040000o`@0
o`0000<0003o0?l0003o00000P000?l40?l000030000o`3o0000o`000080o`003_oooolP0?n00080
o`006@3oP0020000o`L0o`000P000?l30?l000H0003o0`3o00020000o`L0o`000P000?l@0?n000@0
o`002`3oP0000`3o0000003o0000o`070?l000@0oh003_ooool40?l000<0oh000P3o00050?n000@0
o`000P3oP0020000o`030?l0003oP000oh0000@0oh00303o00060?n000<0o`0010000?l50?n000H0
o`0000<0003o0?l0003o000010000?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`@0
o`000`000?l20?l000@0003o0`3o00040000o`@0o`0000<0oh000?l0003o00001`3o00020000o`@0
oh000`000?l40?l00080003o1@3o000>oooooc00oh000P3o000M0?n000D0o`002`3oP0040?l000D0
oh000P3o00020000o`030?l0003oP000oh0000@0oh000`3o000?0?n000<0o`000P3oP00Hooooo`00
5_ooool50?n00080o`000P000?l70?l00080003o103o00000`000?l0o`000?l000020000o`L0o`00
0P000?l30?l00080003o0P3o00020000o`<0o`00103oP0020000o`<0o`000P000?l40?l00080003o
0`3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l70?l00080003o
0P3o00020000o`80o`000`000?l60?l000030000o`3o0000o`000080003o0`3o00020000o`@0o`00
0P000?l30?l00080003o103o00000`000?l0o`000?l000020?l000kooooo>`3oP0020000o`D0o`00
1P3oP0030?l00080003o1@3o00020000o`L0o`000P000?l40?l000h0oh000P3o000;0?n000030?l0
00000?l0003o00H0o`001@3oP00>ooooo`80003o2@3o00020?n000030000o`3o0000o`000080o`00
0P3oP0030?l000H0oh000`3o00020000o`@0o`0000<0003o0?l0003o00000P3o00050?n000T0o`00
0P3oP0040?l000<0003o0P3o00020000o`<0o`000P000?l20?l000@0003o00<0o`000000o`000?l0
103o00020000o`<0o`000P000?l40?l000<0003o103o00020000o`D0o`000P000?l30?l00080003o
1@3o00020000o`@0o`000P000?l50?l000koooooC`3oP0030?l00080003o0P3o00070?n00080003o
103o00030?n000@0o`000P000?l00`3o0000oh000?n000040?n000<0o`00403oP0020?l00080oh00
6?ooool001Kooooo1@3oP0020?l00080003o1`3o00020000o`@0o`0000<0003o0?l0003o00000P00
0?l70?l00080003o0`3o00020000o`80o`000P000?l30?l000@0oh000P000?l30?l00080003o103o
00020000o`<0o`000P000?l20?l000030000o`3o0000o`000080o`000P000?l30?l00080003o1`3o
00020000o`80o`000P000?l20?l000<0003o1P3o00000`000?l0o`000?l000020000o`<0o`000P00
0?l40?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P3o000>oooooc/0oh000P00
0?l50?l000H0oh000`3o00020000o`D0o`000P000?l70?l00080003o103o000>0?n00080o`002`3o
P0000`3o0000003o0000o`060?l000D0oh003_ooool20000o`T0o`000P3oP0000`000?l0o`000?l0
00020?l00080oh000`3o00060?n000<0o`000P000?l40?l000030000o`3o0000o`000080o`001@3o
P0090?l00080oh00103o00030000o`80o`000P000?l30?l00080003o0P3o00040000o`030?l00000
0?l0003o00@0o`000P000?l30?l00080003o103o00030000o`@0o`000P000?l50?l00080003o0`3o
00020000o`D0o`000P000?l40?l00080003o1@3o000>ooooodl0oh000`3o00020000o`80o`001`3o
P0020000o`@0o`000`3oP0040?l00080003o00<0o`000?n0003oP000103oP0030?l00100oh000P3o
00020?n001Sooooo000Fooooo`@0oh001`3o00020000o`<0o`000P000?l70?l00080003o0P3o0000
0`000?l0o`000?l000020?l00080003o1`3o00020000o`80o`0000<0003o0?l0003o00000P3oP002
0000o`<0o`000P000?l40?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o000010000?l3
0?l00080003o0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`H0o`0000<0003o
0?l0003o00000P000?l30?l00080003o103o00020000o`<0o`000P000?l40?l000030000o`3o0000
o`000080o`003_ooooli0?n000@0003o1@3o00060?n000<0o`000P000?l40?l000<0003o1`3o0002
0000o`@0o`000P3oP0030?l001H0oh0000<0o`000000o`000?l01P3o00050?n000kooooo0P000?l3
0?l00080003o103o00030?n000@0o`000P3oP0020?l000L0oh000`3o00020000o`@0o`0000<0003o
0?l0003o00000P3o00070?n00080o`000P000?l30?l000H0oh000P000?l30?l00080003o0`3o0002
0000o`80o`0010000?l00`3o0000003o0000o`040?l00080003o0`3o00020000o`/0o`000P000?l0
0`3oP000o`000?l000020?l00080003o0`3o00020000o`L0o`000P000?l40?l000030000o`3o0000
o`000080o`003_oooom?0?n000<0o`000P000?l40?l000h0oh001P3o00080?n00080o`003`3oP005
0?l001Sooooo000Fooooo`80o`000P000?l70?l00080003o0`3o00020000o`L0o`000P000?l20?l0
00030000o`3o0000o`0000H0o`0000<0003o0?l0003o00001P3o00050?n00080003o0`3o00020000
o`@0o`000P000?l00`3o0000003o0000o`070?l000@0003o1`3o00020000o`80o`0000<0003o0?l0
003o00000P3o00020000o`<0o`000P000?l20?l00080003o1@3o00020000o`<0o`000P000?l20?l0
0080003o0`3o00020000o`H0o`0000<0003o0?l0003o00000P3o000>ooooocP0oh0000<0o`000000
o`000?l00P000?l50?l000@0oh001@3o00020000o`@0o`0000<0003o0?n0003oP0001`3oP0060?l0
0080003o0`3o000D0?n000<0o`000P000?l60?l000D0oh003_ooool20000o`80o`0000<0oh000000
o`000?l0103o00030?n000@0o`002`3oP0030?l00080003o1@3o00040000o`T0o`000P000?l30?l0
00H0oh000P000?l70?l000030?n000000?l0003o00@0o`000P000?l00`3o0000003o0000o`040?l0
0080003o0`3o00020000o`T0o`001`3oP0040000o`<0o`000P000?l70?l00080003o103o00000`00
0?l0o`000?l000020?l000kooooo@@3oP0030?l000d0oh0000<0o`000000o`000?l0103o000^0?n0
0080003o0P3oP00Hooooo`005_ooool20?l00080003o1`3o00020000o`<0o`000P000?l70?l00080
003o0P3o00000`000?l0o`000?l000060?l000030000o`3o0000o`0000H0o`001@3oP0020000o`<0
o`000P000?l40?l00080003o00<0o`000000o`000?l01`3o00040000o`L0o`000P000?l20?l00003
0000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00020000o`D0o`000P000?l30?l00080
003o0P3o00020000o`<0o`000P000?l60?l000030000o`3o0000o`000080o`003_oooolh0?n00003
0?l000000?l0003o0080003o1@3o00040?n000D0o`000P000?l40?l000030000o`3oP000oh0000L0
oh001P3o00020000o`<0o`00503oP0030?l00080003o1P3o00050?n000kooooo0P000?l20?l00003
0?n000000?l0003o00@0o`000`3oP0040?l000/0oh000`3o00020000o`D0o`0010000?l90?l00080
003o0`3o00060?n00080003o1`3o00000`3oP000003o0000o`040?l00080003o00<0o`000000o`00
0?l0103o00020000o`<0o`000P000?l90?l000L0oh0010000?l30?l00080003o1`3o00020000o`@0
o`0000<0003o0?l0003o00000P3o000>oooood40oh000`3o000=0?n000030?l000000?l0003o00@0
o`00;P3oP0020000o`80oh006?ooool001Kooooo1@3o00020000o`L0o`000P000?l40?l00080003o
0`3o00020000o`80o`0000<0003o0?l0003o00000P000?l40?l000030000o`3o0000o`000080003o
1`3o00020000o`@0o`000`000?l20?l000@0003o00<0o`000000o`000?l00P3o00020000o`<0o`00
0P000?l40?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000o`0000L0o`00
0P000?l20?l00080003o1@3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`<0o`00
0P000?l40?l000<0003o103o000>ooooocT0oh0010000?l50?l00080oh001@3o00040000o`D0o`00
2@3oP0060?l00080003o1@3o00070?n000@0o`001@3oP0050?l00080003o0P3o00020000o`80o`00
1@3oP00>ooooo`@0o`0000<0oh000000o`000?l0103o000B0?n000<0o`000P000?l50?l000@0003o
103o00000`000?l0o`000?l000040000o`<0o`000P000?l20?n00080o`000P000?l30?l00080003o
0P3o00030000o`@0o`000P000?l00`3o0000003o0000o`040?l00080003o0`3o00020000o`D0o`00
0P000?l20?l000T0oh000P000?l30?l000@0003o0P3o00000`000?l0o`000?l000020000o`@0o`00
00<0003o0?l0003o00000P3o000>oooood40oh000`3o000>0?n000@0o`006@3oP0020?l001T0oh00
6?ooool001Kooooo1@3o00020000o`L0o`000P000?l40?l00080003o0`3o00020000o`80o`0000<0
003o0?l0003o00000P000?l40?l000030000o`3o0000o`000080003o1`3o00020000o`@0o`000`00
0?l20?l000@0003o00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l40?l000030000o`3o
0000o`000080o`000P000?l20?l000030000o`3o0000o`0000L0o`000P000?l20?l00080003o1@3o
00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l40?l000<0003o103o
000>ooooocT0oh0010000?l50?l00080oh001@3o00040000o`D0o`002@3oP0060?l00080003o1@3o
00070?n000@0o`001@3oP0050?l00080003o0P3o00020000o`80o`001@3oP00>ooooo`@0o`0000<0
oh000000o`000?l0103o000B0?n000<0o`000P000?l50?l000@0003o103o00000`000?l0o`000?l0
00040000o`<0o`000P000?l20?n00080o`000P000?l30?l00080003o0P3o00030000o`@0o`000P00
0?l00`3o0000003o0000o`040?l00080003o0`3o00020000o`D0o`000P000?l20?l000T0oh000P00
0?l30?l000@0003o0P3o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o00000P3o
000>oooood40oh000`3o000>0?n000@0o`006@3oP0020?l001T0oh006?ooool001Kooooo1@3o0002
0000o`80o`000P000?l30?l00080003o103o00020000o`L0o`0000<0003o0?l0003o00000P000?l4
0?l000030000o`3o0000o`000080003o1`3o00020000o`@0o`0000<0003o0?l0003o00000P3o0002
0000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00001P3o0000
0`000?l0o`000?l000020000o`80o`000P000?l00`3o0000003o0000o`0=0?l000030000o`3o0000
o`000080o`000P000?l30?l00080003o103o00030000o`@0o`003_oooold0?n00080o`000`3oP004
0000o`D0o`000P3oP0020000o`<0o`0010000?l20?l00080003o00<0o`000?n0003oP0001`3oP006
0?l00080003o0`3o00090?n000@0o`001@3oP0040?l000030000o`3o0000o`000080o`000P3oP002
0?l000D0oh003_ooool40?l000030?n000000?l0003o00@0o`001`3oP0070?l000D0oh000P3o0002
0000o`D0o`0010000?l70?l000@0003o0`3o00020000o`80oh000P3o00020000o`<0o`000P000?l2
0?l000030000o`3o0000o`000080o`0010000?l00`3o0000003o0000o`040?l00080003o0`3o0004
0000o`<0o`000P000?l40?l000L0oh000P000?l30?l000L0003o0P3o00020000o`@0o`0000<0003o
0?l0003o00000P3o000>oooood40oh000`3o000>0?n000@0o`003P3oP0020?l002@0oh006?ooool0
01Kooooo1@3o00020000o`80o`000P000?l30?l00080003o103o00020000o`L0o`0000<0003o0?l0
003o00000P000?l40?l000030000o`3o0000o`000080003o1`3o00020000o`@0o`0000<0003o0?l0
003o00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0
003o00001P3o00000`000?l0o`000?l000020000o`80o`000P000?l00`3o0000003o0000o`0=0?l0
00030000o`3o0000o`000080o`000P000?l30?l00080003o103o00030000o`@0o`003_oooold0?n0
0080o`000`3oP0040000o`D0o`000P3oP0020000o`<0o`0010000?l20?l00080003o00<0o`000?n0
003oP0001`3oP0060?l00080003o0`3o00090?n000@0o`001@3oP0040?l000030000o`3o0000o`00
0080o`000P3oP0020?l000D0oh003_ooool40?l000030?n000000?l0003o00@0o`001`3oP0070?l0
00D0oh000P3o00020000o`D0o`0010000?l70?l000@0003o0`3o00020000o`80oh000P3o00020000
o`<0o`000P000?l20?l000030000o`3o0000o`000080o`0010000?l00`3o0000003o0000o`040?l0
0080003o0`3o00040000o`<0o`000P000?l40?l000L0oh000P000?l30?l000L0003o0P3o00020000
o`@0o`0000<0003o0?l0003o00000P3o000>oooood40oh000`3o000>0?n000@0o`003P3oP0020?l0
02@0oh006?ooool001Kooooo1@3o00020000o`80o`000P000?l30?l00080003o103o00020000o`D0
o`000P000?l30?l00080003o1`3o00020000o`L0o`000P000?l40?l000030000o`3o0000o`000080
o`000P000?l70?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00000P000?l40?l00003
0000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o0080003o2`3o00000`000?l0
o`000?l000020?l00080003o0`3o00020000o`@0o`000`000?l40?l000kooooo=03oP0020?l000D0
oh000P3o00020000o`<0o`00103oP0030?l000@0003o0P3o00020000o`030?l0003oP000oh0000H0
oh001`3o00020000o`030?l0003oP000oh0000T0oh00103o00090?n000D0o`002@3oP00>ooooo`80
o`000`3oP0060?l000D0oh002@3o00020000o`T0o`000P000?l30?l00080003o1`3o00040000o`<0
o`000P000?l40?n00080003o0`3o00020000o`80o`000`000?l20?l000@0003o00<0o`000000o`00
0?l0103o00020000o`<0o`0010000?l20?l000<0003o103o00070?n00080003o0`3o00070000o`80
o`000P000?l20?l000<0003o103o000>oooood40oh000`3o00070?n00080o`001@3oP0020?l000H0
oh000`3o000]0?n001Sooooo000Fooooo`D0o`000P000?l20?l00080003o0`3o00020000o`@0o`00
0P000?l50?l00080003o0`3o00020000o`L0o`000P000?l70?l00080003o103o00000`000?l0o`00
0?l000020?l00080003o1`3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o
103o00000`000?l0o`000?l000020000o`80o`000P000?l00`3o0000003o0000o`020000o`/0o`00
00<0003o0?l0003o00000P3o00020000o`<0o`000P000?l40?l000<0003o103o000>oooooc@0oh00
0P3o00050?n00080o`000P000?l30?l000@0oh000`3o00040000o`80o`000P000?l00`3o0000oh00
0?n000060?n000L0o`000P000?l00`3o0000oh000?n000090?n000@0o`002@3oP0050?l000T0oh00
3_ooool20?l000<0oh001P3o00050?n000T0o`000P000?l90?l00080003o0`3o00020000o`L0o`00
10000?l30?l00080003o103oP0020000o`<0o`000P000?l20?l000<0003o0P3o00040000o`030?l0
00000?l0003o00@0o`000P000?l30?l000@0003o0P3o00030000o`@0o`001`3oP0020000o`<0o`00
1`000?l20?l00080003o0P3o00030000o`@0o`003_oooom10?n000<0o`001`3oP0020?l000D0oh00
0P3o00060?n000<0o`00;@3oP00Hooooo`005_ooool50?l00080003o0P3o00020000o`<0o`000P00
0?l20?l000@0003o00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l20?l00080003o0`3o
00020000o`80o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080003o1`3o
00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o103o00000`000?l0o`000?l0
00020000o`80o`000P000?l00`3o0000003o0000o`020000o`80o`000P000?l00`3o0000003o0000
o`040?l000030000o`3o0000o`000080003o1@3o00020000o`H0o`0000<0003o0?l0003o00000P3o
000>ooooocd0oh000P000?l30?l000H0oh0000<0o`000000o`000?l01`3o00060?n000D0o`004P3o
P0020?l00100oh000P3o00070?n000kooooo0P3o00020000o`D0o`001`3oP0040?l00080003o0`3o
00020000o`80o`0000<0003o0?l0003o00000P3o00040000o`<0o`000P000?l20?l00080003o0`3o
00040000o`<0o`001P3oP0020000o`<0o`000P000?l20?l000<0003o0P3o00020000o`<0o`001000
0?l20?l00080003o0`3o00020000o`@0o`000`000?l40?l000L0oh000P000?l00`3o0000003o0000
o`040?l000<0003o0P3o00020000o`80o`000`000?l40?l000kooooo3P3oP0040?l001D0oh000P3o
000D0?n00080o`00303oP0040?l000<0oh000P3o00060?n000<0o`00;@3oP00Hooooo`005_ooool2
0?n000L0o`000P000?l20?l000030000o`3o0000o`000080o`000P000?l70?l00080003o1`3o0002
0000o`<0o`000P000?l20?l00080003o0`3o00020000o`80o`000P000?l50?l00080003o1`3o0002
0000o`<0o`000P000?l40?l000030000o`3o0000o`000080003o103o00000`000?l0o`000?l00004
0?l00080003o00<0o`000000o`000?l00P000?l20?l00080003o1`3o00000`000?l0o`000?l00002
0000o`D0o`000P000?l40?l000<0003o103o000>ooooocd0oh000P000?l30?l000d0oh001@3o0002
0?n00080003o0`3o000V0?n00080o`001`3oP00>ooooo`80o`000P000?l50?l000L0oh00103o0002
0000o`L0o`0000<0003o0?l0003o00000P3o00040000o`<0o`000P000?l20?l00080003o0`3o0004
0000o`<0o`001P3oP0020?l000030000o`3o0000o`000080003o0`3o00020000o`80o`000P000?l2
0?l000030000o`3o0000o`000080003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000
o`0000@0o`001`3oP0020000o`030?l000000?l0003o0080003o0P3o00030000o`80o`001`000?l4
0?l000kooooo3@3oP0000`000?l0o`000?l000020?l001L0oh000P3o000@0?n000H0o`00303oP002
0?l000/0oh001@3o00090?n000@0o`007P3oP00Hooooo`005_ooool20?n000L0o`000P000?l20?l0
00030000o`3o0000o`000080o`000P000?l70?l00080003o1`3o00020000o`<0o`000P000?l20?l0
0080003o0`3o00020000o`80o`000P000?l50?l00080003o1`3o00020000o`<0o`000P000?l40?l0
00030000o`3o0000o`000080003o103o00000`000?l0o`000?l000040?l00080003o00<0o`000000
o`000?l00P000?l20?l00080003o1`3o00000`000?l0o`000?l000020000o`D0o`000P000?l40?l0
00<0003o103o000>ooooocd0oh000P000?l30?l000d0oh001@3o00020?n00080003o0`3o000V0?n0
0080o`001`3oP00>ooooo`80o`000P000?l50?l000L0oh00103o00020000o`L0o`0000<0003o0?l0
003o00000P3o00040000o`<0o`000P000?l20?l00080003o0`3o00040000o`<0o`001P3oP0020?l0
00030000o`3o0000o`000080003o0`3o00020000o`80o`000P000?l20?l000030000o`3o0000o`00
0080003o0P3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`0000@0o`001`3oP0020000
o`030?l000000?l0003o0080003o0P3o00030000o`80o`001`000?l40?l000kooooo3@3oP0000`00
0?l0o`000?l000020?l001L0oh000P3o000@0?n000H0o`00303oP0020?l000/0oh001@3o00090?n0
00@0o`007P3oP00Hooooo`005_ooool20?n000L0o`000P000?l20?l000030000o`3o0000o`000080
o`000P000?l50?l00080003o0`3o00020000o`@0o`000P000?l70?l00080003o1`3o00020000o`D0
o`000P000?l20?l000030000o`3o0000o`000080o`000P000?l00`3o0000003o0000o`020000o`L0
o`000P000?l40?l000030000o`3o0000o`0000L0o`0010000?l20?l00080003o00<0o`000000o`00
0?l01`3o00020000o`/0o`000P000?l30?l00080003o3_oooolk0?n00080o`000P000?l30?l000H0
oh0000<0o`000?n0003oP0000P3oP0070?l00080oh000P000?l30?l002l0oh003_ooool40?l000X0
oh000P000?l40?l00080003o1`3o00000`000?l0o`000?l000020?l000@0003o0`3o00060000o`<0
o`0010000?l20?l000L0oh000`000?l20?l00080003o0`3o00020000o`H0o`0000<0003o0?l0003o
00000P3o00040000o`<0o`000P000?l;0?l000L0oh000P000?l00`3o0000003o0000o`040?l000<0
003o0P3o00070000o`@0o`003_ooool=0?n000030000o`3o0000o`0002/0oh001P3o000>0?n000<0
o`001P3oP0050?l000T0oh000P000?l40?l001h0oh006?ooool001Kooooo0P3oP0070?l00080003o
0P3o00000`000?l0o`000?l000020?l00080003o1@3o00020000o`<0o`000P000?l40?l00080003o
1`3o00020000o`L0o`000P000?l50?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o
00<0o`000000o`000?l00P000?l70?l00080003o103o00000`000?l0o`000?l000070?l000@0003o
0P3o00020000o`030?l000000?l0003o00L0o`000P000?l;0?l00080003o0`3o00020000o`kooooo
>`3oP0020?l00080003o0`3o00060?n000030?l0003oP000oh000080oh001`3o00020?n00080003o
0`3o000_0?n000kooooo103o000:0?n00080003o103o00020000o`L0o`0000<0003o0?l0003o0000
0P3o00040000o`<0o`001P000?l30?l000@0003o0P3o00070?n000<0003o0P3o00020000o`<0o`00
0P000?l60?l000030000o`3o0000o`000080o`0010000?l30?l00080003o2`3o00070?n00080003o
00<0o`000000o`000?l0103o00030000o`80o`001`000?l40?l000kooooo3@3oP0000`000?l0o`00
0?l0000[0?n000H0o`003P3oP0030?l000H0oh001@3o00090?n00080003o103o000N0?n001Sooooo
000Fooooo`80oh002`3o00000`000?l0o`000?l000020?l00080003o0`3o00020?n00080003o0`3o
00020000o`@0o`000P000?l00`3o0000003o0000o`040?l00080003o1`3o00020000o`D0o`000P00
0?l20?l000030000o`3o0000o`0000@0003o00<0o`000000o`000?l00P000?l20?l00080003o0`3o
00020000o`h0o`0010000?l20?l00080003o00<0o`000000o`000?l00P3o00020000o`<0o`000P00
0?l40?l000030000o`3o0000o`0000@0o`000P000?l30?l00080003o3_ooooli0?n00080003o1`3o
00020?n00080003o0`3o00080?n000<0o`000P3oP0020000o`<0o`000P000?l]0?n000kooooo103o
000:0?n00080003o103o00020?n000L0o`0000<0003o0?l0003o00000P3o00040000o`<0o`001P00
0?l30?l00080003o103o00070?n000<0003o0P3o00020000o`<0o`000P000?l20?l00080003o0P3o
00000`000?l0o`000?l000020?l00080003o1@3o00020000o`/0o`001`3oP0020000o`030?l00000
0?l0003o00@0o`0030000?l40?l000kooooo403oP0020?l002/0oh00103o000<0?n00080003o0`3o
00080?n000030?l0003oP000oh0000T0oh000P000?l40?l001h0oh006?ooool001Kooooo0P3oP00;
0?l000030000o`3o0000o`000080o`000P000?l30?l00080oh000P000?l30?l00080003o103o0002
0000o`030?l000000?l0003o00@0o`000P000?l70?l00080003o1@3o00020000o`80o`0000<0003o
0?l0003o000010000?l00`3o0000003o0000o`020000o`80o`000P000?l30?l00080003o3P3o0004
0000o`80o`000P000?l00`3o0000003o0000o`020?l00080003o0`3o00020000o`@0o`0000<0003o
0?l0003o0000103o00020000o`<0o`000P000?l>ooooocT0oh000P000?l70?l00080oh000P000?l3
0?l000P0oh000`3o00020?n00080003o0`3o00020000obd0oh003_ooool40?l000X0oh000P000?l4
0?l00080oh001`3o00000`000?l0o`000?l000020?l000@0003o0`3o00060000o`<0o`000P000?l4
0?l000L0oh000`000?l20?l00080003o0`3o00020000o`80o`000P000?l20?l000030000o`3o0000
o`000080o`000P000?l50?l00080003o2`3o00070?n00080003o00<0o`000000o`000?l0103o000<
0000o`@0o`003_ooool@0?n00080o`00:`3oP0040?l000`0oh000P000?l30?l000P0oh0000<0o`00
0?n0003oP0002@3oP0020000o`@0o`007P3oP00Hooooo`005_ooool20?n000/0o`0000<0003o0?l0
003o00000P3o00020000o`80o`0000<0003o0?n0003oP0000P000?l30?l00080003o1`3o00020000
o`@0o`000P000?l00`3o0000003o0000o`040?l00080003o0`3o00020000o`@0o`0000<0003o0?l0
003o00000P000?l30?l00080003o103o00020000o`<0o`000P000?l20?l00080003o2P3o00020000
o`/0o`000P000?l30?l00080003o103o00000`000?l0o`000?l000040?l00080003o0`3o00020000
o`kooooo>@3oP0020000o`@0o`000P000?l00`3o0000oh000?n000020000o`D0o`000P3oP0020?l0
0080oh001@3o00020000o`<0o`000P000?l20?l000@0oh0000<0o`000?n0003oP0002@3oP0020?l0
01T0oh003_ooool40?l000<0oh000P3o00050?n000T0o`00103oP0020?l000030000o`3o0000o`00
0080o`001@000?l20?l000H0003o0`3o00020000o`D0o`00103oP0050000o`80o`000P000?l30?l0
0080003o0P3o00050000o`@0o`000P000?l50?l00080003o1@3o00020000o`@0o`002@3oP0070?l0
00L0003o0P3o00030000o`@0o`003_oooomX0?n00080o`00803oP00Hooooo`005_ooool40?l00003
0000o`3o0000o`0000T0o`000P000?l40?l000030000o`3o0000o`000080003o0`3o00020000o`80
o`000P000?l30?l00080003o0P3o00020000o`<0o`000P000?l40?l00080003o0`3o00020000o`@0
o`0000<0003o0?l0003o00000P000?l30?l00080003o103o00020000o`L0o`000P000?l:0?l00080
003o2`3o00020000o`<0o`000P000?l40?l000030000o`3o0000o`000080o`000P3oP0020?l000<0
oh000P000?l>ooooocT0oh000P000?l40?l00080003o0`3o00020000o`<0o`000P000?l40?l00080
oh001@3o00020000o`<0o`000P000?l20?l000@0oh0000<0o`000?n0003oP0001`3oP0040?l001T0
oh003_ooool40?l000X0oh002@3o00040?n00080o`0000<0003o0?l0003o00000P3o00020000o`80
o`0000<0003o0?l0003o00001P000?l<0?l00080oh000P000?l20?l000030000o`3o0000o`000080
003o0`3o00020000o`80o`001@000?l40?l00080003o1@3o00020000o`@0o`000`000?l40?l000T0
oh000`3o00020000o`80o`000`000?l20?l000L0003o103o000>ooooohX0oh006?ooool001Kooooo
103o00000`000?l0o`000?l000090?l00080003o103o00000`000?l0o`000?l000020000o`<0o`00
0P000?l20?l00080003o0`3o00020000o`80o`000P000?l30?l00080003o103o00020000o`<0o`00
0P000?l40?l000030000o`3o0000o`000080003o0`3o00020000o`@0o`000P000?l70?l00080003o
2P3o00020000o`/0o`000P000?l30?l00080003o103o00000`000?l0o`000?l000020?l00080oh00
0P3o00030?n00080003o3_ooooli0?n00080003o103o00020000o`<0o`000P000?l30?l00080003o
103o00020?n000D0o`000P000?l30?l00080003o0P3o00040?n000030?l0003oP000oh0000L0oh00
103o000I0?n000kooooo103o000:0?n000T0o`00103oP0020?l000030000o`3o0000o`000080o`00
0P000?l20?l000030000o`3o0000o`0000H0003o303o00020?n00080003o0P3o00000`000?l0o`00
0?l000020000o`<0o`000P000?l20?l000D0003o103o00020000o`D0o`000P000?l40?l000<0003o
103o00090?n000<0o`000P000?l20?l000<0003o0P3o00070000o`@0o`003_oooon:0?n001Sooooo
000Fooooo`@0o`0000<0003o0?l0003o00000P000?l70?l00080003o1`3o00020000o`80o`0000<0
003o0?l0003o00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`000P00
0?l30?l00080003o1`3o00020000o`<0o`000P000?l40?l00080003o1`3o00020000o`X0o`000P00
0?l>0?l00080003o2`3o00020000o`D0o`000P000?l>ooooocT0oh000P000?l40?l00080003o0`3o
00020000o`/0o`0000<0003o0?l0003o00000P3o00020000o`h0o`001`3oP0040?l001T0oh003_oo
ool40?l000030?n000000?l0003o00L0oh00103o00020000o`<0o`00103oP00;0?l000030000o`3o
0000o`000080o`000P000?l@0?l000D0003o0P3o00020000o`<0o`000P000?l20?l000D0003o103o
00020000o`80o`0000<0003o0?l0003o00000P000?l40?l000<0003o1P3o00050?n00080003o0`3o
00020000o`80o`0030000?l40?l000koooooF`3oP0020?l000L0oh000P3o000T0?n001Sooooo000F
ooooo`@0o`0000<0003o0?l0003o00000P000?l70?l00080003o1`3o00020000o`80o`0000<0003o
0?l0003o00000P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`000P000?l3
0?l00080003o1`3o00020000o`<0o`000P000?l40?l00080003o1`3o00020000o`X0o`000P000?l>
0?l00080003o2`3o00020000o`D0o`000P000?l>ooooocT0oh000P000?l40?l00080003o0`3o0002
0000o`/0o`0000<0003o0?l0003o00000P3o00020000o`h0o`001`3oP0040?l001T0oh003_ooool4
0?l000030?n000000?l0003o00L0oh00103o00020000o`<0o`00103oP00;0?l000030000o`3o0000
o`000080o`000P000?l@0?l000D0003o0P3o00020000o`<0o`000P000?l20?l000D0003o103o0002
0000o`80o`0000<0003o0?l0003o00000P000?l40?l000<0003o1P3o00050?n00080003o0`3o0002
0000o`80o`0030000?l40?l000koooooF`3oP0020?l000L0oh000P3o000T0?n001Sooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaOo0?l01?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0023ooooo5_l00?l4oooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo
003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool0023ooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
7ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool0023ooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolF
ool0023ooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolF
o`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0
023ooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l0
07lGool003[o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o
5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0>?l007lFo`00oaoo001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003ooooo
ooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00
Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00
OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`1^o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`005_ooooma0?l00080oh000`3o00020?n00180o`003_ooool20?l001h0003o0P3o
P0050?l000/0003o1P3oP0070000o`D0o`002`000?l20?l000h0003o1@3o00020000o`80o`001`00
0?l50?l000H0003o0P3o00030000o`80oh001`000?l20?l000koooooRP000?l>ooooo`h0o`00103o
P0040?l000030000o`3o0000o`000080o`000`3oP0060000o`h0o`003@000?l@0?l000/0oh001@3o
00050?n000@0o`001`3oP0050?l00080003o103oP00@0?l001Sooooo000Fooooog40o`000P3oP003
0?l00080oh004P3o000>ooooo`80o`007P000?l20?n000D0o`002`000?l60?n000L0003o1@3o000;
0000o`80o`003P000?l50?l00080003o0P3o00070000o`D0o`001P000?l20?l000<0003o0P3oP007
0000o`80o`003_oooon:0000o`kooooo3P3o00040?n000@0o`0000<0003o0?l0003o00000P3o0003
0?n000H0003o3P3o000=0000oa00o`002`3oP0050?l000D0oh00103o00070?n000D0o`000P000?l4
0?n00100o`006?ooool001KoooooRP3o000>ooooo`@0o`007P000?l50?l001@0003o0P3o00020000
o`L0o`002@000?l30?l000d0003o2@3o000;0000o`030?l000000?l0003o0080003o1`3o00020000
o`80o`001`000?l>ooooohX0003o3_ooool40?n000<0o`001P3oP0050?l000D0oh000P000?l20?l0
00h0oh001`3o00020?n000@0003o1@3oP0060?l000D0oh001`3o00040?n000X0003o0P3o00090?n0
0080o`000P3oP0030000o`H0oh0000<0o`000?n0003oP0003`3oP0050?l001Sooooo000FooooohX0
o`003_ooool40?l001h0003o1@3o000D0000o`80o`000P000?l70?l000T0003o0`3o000=0000o`T0
o`002`000?l00`3o0000003o0000o`020000o`L0o`000P000?l20?l000L0003o3_oooon:0000o`ko
oooo103oP0030?l000H0oh001@3o00050?n00080003o0P3o000>0?n000L0o`000P3oP0040000o`D0
oh001P3o00050?n000L0o`00103oP00:0000o`80o`002@3oP0020?l00080oh000`000?l60?n00003
0?l0003oP000oh0000l0oh001@3o000Hooooo`005_oooolm0?l00080oh002P3o00040?n00080o`00
0P3oP00d0?l000<0oh000P3o000>ooooo`@0o`007P000?l40?n001D0003o0P3o00020000o`L0o`00
1`000?l50?l000T0003o0P3o00020000o`80o`000P3oP0050?l00100003o103o00000`000?l0o`00
0?l000060?l000D0003o3_oooon:0000o`kooooo0P000?l70?n000/0o`002P3oP00A0?l000<0oh00
1P000?l70?n000D0o`0010000?l70?l000D0oh000P3o00050000o`T0o`002@3oP0090?l00080003o
3P3o00040?n001Sooooo000FooooohX0o`003_ooool20000o`80o`00?@000?l50?l000L0003o103o
00090000o`<0o`000P000?l20?n001T0003o0P3o00000`000?l0o`000?l000020?n00080o`000P3o
P0050000o`koooooRP000?l>ooooo`d0oh0000<0o`000?n0003oP0003P3oP0020000o`L0o`002`3o
P0040000o`D0o`002`3oP0050000o`80o`001`3oP0060000o`030?n0003o0000o`0000L0o`003`3o
P0070?l00080003o3P3o000Hooooo`005_oooon:0?l000kooooo0P000?l20?l003d0003o1@3o0007
0000o`@0o`002@000?l30?l00080003o0P3oP00I0000o`80o`0000<0003o0?l0003o00000P3oP002
0?l00080oh001@000?l>ooooohX0003o3_ooool=0?n000030?l0003oP000oh0000h0oh000P000?l7
0?l000/0oh0010000?l50?l000/0oh001@000?l20?l000L0oh001P000?l00`3oP000o`000?l00007
0?l000l0oh001`3o00020000o`h0o`006?ooool001Kooooo7P3o00020?n006X0o`003_oooom?0000
o`80o`000`000?l70?l001d0003o1`3o00020000o`80o`001`000?l>ooooodd0003o1@3o000h0000
o`kooooo1@3o000;0?n000h0003o103oP0050?l000l0oh001@3o00070?n000@0003o7P3oP0020?l0
00H0003o4@3oP0080?l000D0oh006?ooool001Kooooo7P3o00020?n006X0o`003_oooom?0000o`80
o`000`000?l70?l001d0003o1`3o00020000o`80o`001`000?l>ooooodd0003o1@3o000h0000o`ko
oooo1@3o000;0?n000h0003o103oP0050?l000l0oh001@3o00070?n000@0003o7P3oP0020?l000H0
003o4@3oP0080?l000D0oh006?ooool001Kooooo903o00020?n006@0o`003_oooomF0000o`80o`00
0`3oP00_0000o`koooooB`000?l;0?n003@0003o3_ooool40?l000D0oh002@3o00050000o`80oh00
0P3o00030?n00080003o0P3oP0050?l000P0oh000`3o00020000o`L0o`00103oP0020000o`<0oh00
3@000?l70?l00080003o1`3o00070000o`@0o`0000<0003o0?n0003oP0005P3oP0000`000?l0oh00
0?n000020?n001Sooooo000Fooooob@0o`000P3oP01T0?l000koooooEP000?l20?l000<0oh00;`00
0?l>oooood/0003o2`3oP00d0000o`kooooo103o00050?n000T0o`001@000?l20?n00080o`000`3o
P0020000o`80oh001@3o00080?n000<0o`000P000?l70?l000@0oh000P000?l30?n000d0003o1`3o
00020000o`L0o`001`000?l40?l000030000o`3oP000oh0001H0oh0000<0003o0?n0003oP0000P3o
P00Hooooo`005_ooool40?n006/0o`002@3oP00B0?l000kooooo90000?l20?l005L0003o1P3o0007
0000o`koooooC@000?l70?l001P0003o00<0o`000000o`000?l06`000?l>ooooo`/0oh002`3o0003
0?n000D0o`0010000?l70?n000T0o`001`3oP0060?l000<0003o1`3o00040000o`L0oh00103o0009
0?n000D0003o2@3oP0040?l001L0oh006?ooool001KoooooM03o00020?n001@0o`003_oooomo0000
o`@0o`001`000?l>oooood/0003o2@3oP00f0000o`kooooo0P3oP0090?l00080003o00<0o`000000
o`000?l0403o00040000oa@0oh002P3o00070?n00080o`002@3oP0040?l000T0oh000P3o000C0?n0
00@0o`002@3oP0070?l001Sooooo000Fooooog@0o`000P3oP00D0?l000koooooO`000?l40?l000L0
003o3_oooom;0000o`T0oh00=P000?l>ooooo`80oh002@3o00020000o`030?l000000?l0003o0100
o`0010000?lD0?n000X0o`001`3oP0020?l000T0oh00103o00090?n00080o`004`3oP0040?l000T0
oh001`3o000Hooooo`005_oooon:0?l000kooooo?`000?l20?l003h0003o1P3o00050000o`kooooo
C`000?l20?n003T0003o3_ooool90?l000D0oh000P000?l40?n001`0o`0010000?l50?l000@0oh00
103o000G0?n00080003o00<0oh000?l0003o00002@3o000;0?n000<0o`002@3oP0090?l000@0oh00
6?ooool001KoooooRP3o000>ooooocl0003o0P3o000n0000o`H0o`001@000?l>ooooodl0003o0P3o
P00i0000o`kooooo2@3o00050?n00080003o103oP00L0?l000@0003o1@3o00040?n000@0o`005`3o
P0020000o`030?n0003o0000o`0000T0o`002`3oP0030?l000T0oh002@3o00040?n001Sooooo000F
oooooa/0o`000`3oP01/0?l000kooooo>@000?l20?l00080003o2@3o00070000o`D0oh009P000?l2
0?l000L0oh00103o00050000o`koooooRP000?l>ooooo`@0o`0000<0oh000?l0003o00000P3oP009
0000o`L0oh001@3o000F0?n00080o`002@3oP00:0?l00080oh001P000?l:0?n000@0o`00403oP002
0?l000L0003o103oP0070?l000L0oh006?ooool001Kooooo6`3o00030?n006`0o`003_ooooli0000
o`80o`000P000?l90?l000L0003o1@3oP00V0000o`80o`001`3oP0040?l000D0003o3_oooon:0000
o`kooooo103o00000`3oP000o`000?l000020?n000T0003o1`3oP0050?l001H0oh000P3o00090?n0
00X0o`000P3oP0060000o`X0oh00103o000@0?n00080o`001`000?l40?n000L0o`001`3oP00Hoooo
o`005_oooon:0?l000kooooo>@000?l=0?l000L0003o1`3o00020000o`80o`0080000?l40?l000D0
003o1@3o00040000o`koooooA0000?l20?n004@0003o3_ooool40?l000D0oh00103o00030000o`@0
o`002P3oP0060?l000/0oh000`3o00090?n00100o`00603oP00>0?l00080003o1@3oP0040?l000h0
oh006?ooool001KoooooRP3o000>ooooocT0003o3@3o00070000o`L0o`000P000?l20?l00200003o
103o00050000o`D0o`0010000?l>oooood@0003o0P3oP0140000o`kooooo103o00050?n000@0o`00
0`000?l40?l000X0oh001P3o000;0?n000<0o`002@3oP00@0?l001P0oh003P3o00020000o`D0oh00
103o000>0?n001Sooooo000Fooooo`80o`000P3oP0260?l000kooooo=P000?l50?n000@0o`000`3o
P0040?l000D0003o2@3o00020000o`80o`000P000?l00`3o0000003o0000o`0K0000o`80oh001`00
0?l50?n000@0003o3_oooon:0000o`kooooo3@3oP0000`3o0000oh000?n000020?l00080oh000`3o
00040000o`<0o`004@3oP0030?l00080oh000P3o00070?n00180o`000P000?l90?l000030?n0003o
0000o`0000H0o`001`3oP0070?l00080oh000`3o000B0?n00080o`006?ooool001KoooooRP3o000>
oooooc/0003o1`3o00020?n000@0o`000`000?l?0?l000D0oh0090000?l20?l000D0003o3_oooon:
0000o`kooooo1`3o00020?n000L0o`003@3oP0050?l000@0003o2P3o00040?n00080o`000P000?l0
0`3o0000oh000?n0000B0?n00080o`000P000?l<0?l000d0oh000P3o00000`3oP000o`000?l0000@
0?l000L0oh00103o000Hooooo`005_oooon:0?l000kooooo>`000?l70?l00080oh00103o00030000
o`l0o`001@3oP00T0000o`80o`001@000?l>ooooohX0003o3_ooool70?l00080oh001`3o000=0?n0
00D0o`0010000?l:0?l000@0oh000P3o00020000o`030?l0003oP000oh000180oh000P3o00020000
o``0o`003@3oP0020?l000030?n0003o0000o`000100o`001`3oP0040?l001Sooooo000FooooohX0
o`003_oooolk0000o`H0o`002P000?l60?l000L0oh000`000?l20?l000H0003o0`3o000T0000o`ko
ooooRP000?l>ooooo`L0o`00403oP0060?l000D0oh000P000?l70?l000@0oh0000<0o`000000o`00
0?l00P000?l40?n000<0o`002`3oP0020000o`D0o`0010000?l70?n000D0o`003`3oP0000`3o0000
oh000?n000050?n000H0o`002`3oP0000`000?l0oh000?n000020?n001Sooooo000FooooohX0o`00
3_oooolk0000o`H0o`002P000?l60?l000L0oh000`000?l20?l000H0003o0`3o000T0000o`kooooo
RP000?l>ooooo`L0o`00403oP0060?l000D0oh000P000?l70?l000@0oh0000<0o`000000o`000?l0
0P000?l40?n000<0o`002`3oP0020000o`D0o`0010000?l70?n000D0o`003`3oP0000`3o0000oh00
0?n000050?n000H0o`002`3oP0000`000?l0oh000?n000020?n001Sooooo000Foooooel0o`000P3o
P00Y0?l000kooooo>`000?l70?n000L0003o1P3o000B0000o`80o`009`000?l>ooooohX0003o3_oo
ool20?n000`0o`00203oP0070?l000X0oh000P3o00020?n000T0o`000P3oP0070?l000@0003o1@3o
00030?n00080o`002@3oP0070?l00240oh0000<0o`000?n0003oP0002`3oP00Hooooo`005_oooomO
0?l00080oh00:@3o000>oooooc/0003o1`3oP0070000o`H0o`004P000?l20?l002L0003o3_oooon:
0000o`kooooo0P3oP00<0?l000P0oh001`3o000:0?n00080o`000P3oP0090?l00080oh001`3o0004
0000o`D0o`000`3oP0020?l000T0oh001`3o000Q0?n000030?l0003oP000oh0000/0oh006?ooool0
01Kooooo0P3oP0020?l000030?n0003o0000o`0007P0o`000P3oP0090?l000kooooo>`000?l60?l0
0200003o0P3o000W0000o`koooooRP000?l>ooooo`d0oh001`3o00070?n000<0o`003@3oP00D0?l0
0080003o1`3o000G0?n000D0o`000P000?lB0?n000L0o`002@000?l20?n001Sooooo000Fooooo`80
oh000P3o00000`3oP000o`000?l0001h0?l00080oh002@3o000>oooooc/0003o1P3o000P0000o`80
o`009`000?l>ooooohX0003o3_ooool=0?n000L0o`001`3oP0030?l000d0oh00503o00020000o`L0
o`005`3oP0050?l00080003o4P3oP0070?l000T0003o0P3oP00Hooooo`005_oooomK0?l00080oh00
;@3o000>ooooocl0003o0P3o000P0000o`80o`009`000?l>ooooobL0003o0P3o00040?n005d0003o
3_ooool;0?n000D0o`003@3oP0070?l000L0003o0P3o00030?n000/0o`00103oP0070000o`80o`00
1`3oP0090?l00080003o303oP00>0?l000@0oh001`3o000;0?n001Sooooo000Fooooo`d0o`0000<0
oh000?l0003o0000NP3o000>ooooocl0003o0P3o00100000o`80o`000P000?l00`3o0000003o0000
o`020000o`koooooRP000?l>ooooo`@0o`0000<0oh000?l0003o0000103o00090?n000h0o`001`00
0?lV0?n000T0o`000P000?l30?n00080o`000P3oP00C0?l001H0oh006?ooool001Kooooo3@3o0000
0`3oP000o`000?l0001j0?l000kooooo?`000?l20?l00400003o0P3o00020000o`030?l000000?l0
003o0080003o3_oooon:0000o`kooooo103o00000`3oP000o`000?l000040?l000T0oh003P3o0007
0000obH0oh002@3o00020000o`<0oh000P3o00020?n001<0o`005P3oP00Hooooo`005_oooom40?l0
0080oh00A03o000>oooooed0003o0P3o000P0000o`L0o`0010000?l>ooooobL0003o103oP00P0000
o`L0o`00:P000?l30?n000/0003o3_ooool40?l000030?n0003o0000o`0000L0o`002`3oP0040?l0
00030?n0003o0000o`0000@0oh000`000?l20?l001T0oh0010000?l20?n000L0003o3P3oP0090?l0
00T0oh001@3o00060?n00080o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l000020?l0
01Sooooo000Foooood@0o`000P3oP0140?l000koooooG@000?l20?l00200003o1`3o00040000o`ko
oooo9`000?l40?n00200003o1`3o000Z0000o`<0oh002`000?l>ooooo`@0o`0000<0oh000?l0003o
00001`3o000;0?n000@0o`0000<0oh000?l0003o0000103oP0030000o`80o`006@3oP0040000o`80
oh001`000?l>0?n000T0o`002@3oP0050?l000H0oh000P3o00000`000?l0o`000?l000060?l00003
0?n0003o0000o`000080o`006?ooool001Kooooo7P3o00020?n006X0o`003_oooomM0000o`80o`00
8P000?l20?l000<0oh0010000?l>oooooe40003o0`3o000X0000o`D0o`002@000?l>ooooo`L0oh00
3@3o00070?n00080o`00303oP00F0?l00080003o00<0oh000?l0003o0000103o00070000o`L0oh00
1`000?l70?l001H0oh001`3o00090?n001Sooooo000Foooooah0o`000P3oP01Z0?l000koooooG@00
0?l20?l00280003o0P3o00030?n000@0003o3_oooomA0000o`<0o`00:0000?l50?l000T0003o3_oo
ool70?n000d0o`001`3oP0020?l000`0oh005P3o00020000o`030?n0003o0000o`0000@0o`001`00
0?l70?n000L0003o1`3o000F0?n000L0o`002@3oP00Hooooo`005_ooool40?n00580o`00103oP00`
0?l000koooooRP000?l>ooooobT0003o0P3o00020?n00280003o0P3oP0050?l002H0003o1@3o0009
0000o`kooooo10000?l70?n000T0o`00303oP0020000o`D0oh00203o00050?n00080o`00303oP006
0?l000L0oh001`000?l20?n00080003o2@3oP0030?l000L0oh000P000?l;0?n00080o`000`3oP004
0000o`L0oh006?ooool001Kooooo103oP0030?l00080oh00P@3o000>ooooodd0003o0P3o000k0000
o`kooooo:@000?l20?n00080o`0090000?l50?l002@0003o0`3oP00=0000o`kooooo1`3oP0020?l0
00D0oh00403o00090?n000T0o`003@3oP0040000o`D0oh000P3o00000`000?l0oh000?n000040?n0
0080o`000`000?l=0?n000<0o`000P3oP0020?l000h0oh000P000?l70?n00080003o2@3oP00Hoooo
o`005_ooool40?n000<0o`000P3oP0210?l000koooooC@000?l20?l003/0003o3_oooolY0000o`80
oh000P3o000T0000o`D0o`0090000?l30?n000d0003o3_ooool70?n00080o`001@3oP00@0?l000T0
oh002@3o000=0?n000@0003o1@3oP0020?l000030000o`3oP000oh0000@0oh000P3o00030000o`d0
oh000`3o00020?n00080o`003P3oP0020000o`L0oh000P000?l90?n001Sooooo000Fooooo`h0o`00
0P3oP01j0?l000koooooRP000?l>ooooob/0003o0P3o001M0000o`kooooo0P3oP0090?l000/0oh00
00<0o`000000o`000?l00P3o00070?n000D0o`00603oP0020000o`P0oh003@3o00020?n00180o`00
0P000?l70?l000L0oh001`000?l90?n001Sooooo000Fooooo`h0o`000P3oP01j0?l000koooooRP00
0?l>ooooob/0003o0P3o001M0000o`kooooo0P3oP0090?l000/0oh0000<0o`000000o`000?l00P3o
00070?n000D0o`00603oP0020000o`P0oh003@3o00020?n00180o`000P000?l70?l000L0oh001`00
0?l90?n001Sooooo000FooooocT0o`000P3oP00]0?l000L0oh006`3o000>ooooohX0003o3_oooon:
0000o`kooooo0P000?l20?l000<0oh001P3o00090?n000030?l000000?l0003o0080o`000P000?l9
0?n000030?l0003oP000oh0000T0oh003`3o00070000o``0o`001P000?l00`3o0000oh000?n00002
0?n001T0o`00103oP0030000o`/0o`006?ooool001Kooooo>@3o00020?n002d0o`001`3oP00K0?l0
00koooooRP000?l>ooooohX0003o3_ooool20000o`80o`000`3oP0060?l000T0oh0000<0o`000000
o`000?l00P3o00020000o`T0oh0000<0o`000?n0003oP0002@3oP00?0?l000L0003o303o00060000
o`030?l0003oP000oh000080oh006@3o00040?n000<0003o2`3o000Hooooo`005_oooom20?l00080
oh001`3o00020?n003d0o`003_oooolo0000o`80o`002P000?l60?n003T0003o3_oooon:0000o`ko
oooo3@3oP0000`000?l0o`000?l000020?l000L0oh00103o000<0?n00100o`00103oP0040?l00003
0?n000000?l0003o00@0o`002P3oP0040?l000L0oh001P3o00050?n00080o`000P3oP0030?l000L0
oh000P3o00020?n00080003o1`3oP0070?l001Sooooo000Foooood80o`000P3oP0070?l00080oh00
?@3o000>ooooocl0003o0P3o000:0000o`H0oh00>@000?l>ooooohX0003o3_ooool=0?n000030000
o`3o0000o`000080o`001`3oP0040?l000`0oh00403o00040?n000@0o`0000<0oh000000o`000?l0
103o000:0?n000@0o`001`3oP0060?l000D0oh000P3o00020?n000<0o`001`3oP0020?l00080oh00
0P000?l70?n000L0o`006?ooool001Kooooo0P3o00020?n00200o`001@3oP00T0?l00080oh001`3o
00020?n001h0o`000P3oP00B0?l000kooooo?`000?l20?l004T0003o3_oooon:0000o`kooooo0P3o
P0050000o`L0oh0020000?l00`3o0000003o0000o`040?l000D0003o1`3oP00;0?l000h0oh00103o
00030000o`d0oh000P3o00020?n000030?l0003oP000oh000080oh003P3o00070?n000H0o`001@00
0?l60?l000D0oh006?ooool001Kooooo3@3o00000`3oP000o`000?l0000P0?l00080oh00F03o000>
ooooocl0003o0P3o00190000o`koooooRP000?l>ooooo`D0003o0P3oP0040?l00080oh002@000?l0
0`3oP000003o0000o`040?l000030000o`3o0000o`0000H0oh001@3o000=0?n000030000o`3oP000
oh0001@0oh000P000?lP0?l00080oh0000<0o`000?n0003oP0001P3oP0050000o`80o`001@3oP002
0?l001Sooooo000Fooooo`d0o`0000<0oh000?l0003o0000803o00020?n005P0o`003_oooolo0000
o`80o`00B@000?l>ooooohX0003o3_ooool50000o`80oh00103o00020?n000T0003o00<0oh000000
o`000?l0103o00000`000?l0o`000?l000060?n000D0o`003@3oP0000`000?l0oh000?n0000D0?n0
0080003o803o00020?n000030?l0003oP000oh0000H0oh001@000?l20?l000D0oh000P3o000Hoooo
o`005_ooooli0?l00080oh00;`3o00020?n001h0o`003_oooolm0000o`@0o`0070000?l20?l00080
003o0P3o000W0000o`koooooRP000?l>ooooo`80003o1@3oP0040?l00180oh001`3o00030?n00080
o`000P3oP0050?l000H0oh002@000?lE0?n000L0o`000P3oP0060?l000L0oh001@3o000F0?n000<0
o`000P3oP00Hooooo`005_ooooli0?l00080oh00;`3o00020?n001h0o`003_oooolm0000o`@0o`00
70000?l20?l00080003o0P3o000W0000o`koooooRP000?l>ooooo`80003o1@3oP0040?l00180oh00
1`3o00030?n00080o`000P3oP0050?l000H0oh002@000?lE0?n000L0o`000P3oP0060?l000L0oh00
1@3o000F0?n000<0o`000P3oP00Hooooo`005_oooolG0?l00080oh00103o00000`3oP000o`000?l0
001X0?l00080oh003_oooolm0000o`@0o`00B@000?l>ooooohX0003o3_ooool40?n000D0o`001@3o
P00;0?l00080oh005`3o00020000o`80o`002@000?l50?n00080o`000P000?l@0?n000`0o`00203o
P0000`3o0000oh000?n000070?n00080o`000P3oP00;0?l000<0oh000P3o000Hooooo`005_oooolG
0?l00080oh00103o00000`3oP000o`000?l0001X0?l00080oh003_oooolm0000o`@0o`00B@000?l>
ooooohX0003o3_ooool40?n000D0o`001@3oP00;0?l00080oh005`3o00020000o`80o`002@000?l5
0?n00080o`000P000?l@0?n000`0o`00203oP0000`3o0000oh000?n000070?n00080o`000P3oP00;
0?l000<0oh000P3o000Hooooo`005_ooool20?n008P0o`003_oooolm0000o`@0o`00B@000?l>oooo
ohX0003o3_ooool>0?n000H0o`000`3oP0070?l00080oh000P3o00020?n000<0o`00103oP0040?l0
00D0003o103o00000`000?l0oh000?n000040?n00080o`001`3oP0000`3o0000003o0000o`060?l0
00L0oh000`3o00080?n000D0o`000P3oP0050?l000T0oh002`3o00030?n00080o`000P3oP00Hoooo
o`005_ooool20?n008P0o`003_oooolm0000o`@0o`00B@000?l>ooooohX0003o3_ooool>0?n000H0
o`000`3oP0070?l00080oh000P3o00020?n000<0o`00103oP0040?l000D0003o103o00000`000?l0
oh000?n000040?n00080o`001`3oP0000`3o0000003o0000o`060?l000L0oh000`3o00080?n000D0
o`000P3oP0050?l000T0oh002`3o00030?n00080o`000P3oP00Hooooo`005_oooomc0?l000030?n0
003o0000o`000080oh00103o00000`3oP000o`000?l0000;0?l000kooooo80000?l20?l001d0003o
0P3o00190000o`koooooRP000?l>ooooo`L0o`00503oP0030?l001H0oh000P000?l20?n000030000
o`3oP000oh0000H0oh00203o00040?n000T0o`002`3oP0050?l000H0oh00303o000B0?n001Sooooo
000Fooooobd0o`000`3oP00M0?l000@0oh00>@3o000>ooooocl0003o0P3o00190000o`koooooRP00
0?l>ooooo`T0oh001`3o000=0?n000<0o`001P000?l70?n00080o`005@3oP0050?l000@0oh00403o
00070?n000@0o`000P3oP0020?l000030?n0003o0000o`0000/0o`003P3oP0020000oaSooooo000F
ooooobd0o`000`3oP00M0?l000@0oh00>@3o000>ooooocl0003o0P3o00190000o`koooooRP000?l>
ooooo`T0oh001`3o000=0?n000<0o`001P000?l70?n00080o`005@3oP0050?l000@0oh00403o0007
0?n000@0o`000P3oP0020?l000030?n0003o0000o`0000/0o`003P3oP0020000oaSooooo000Foooo
o`d0o`0000<0oh000?l0003o00001P3oP01d0?l000kooooo0P000?l20?l003/0003o0P3o000:0000
o`80o`00<P000?l20?l000T0003o3_oooon:0000o`kooooo0P000?lL0?l000T0003o103o00040?n0
00030?l0003oP000oh0000T0oh000P3o00020?n00080o`0000<0oh000?l0003o00002@3o00070?n0
0100o`00103oP0020?l000L0oh00303o000=0?n001Sooooo000Fooooo`d0o`0000<0oh000?l0003o
00001P3oP01d0?l000kooooo0P000?l20?l003/0003o0P3o000:0000o`80o`00<P000?l20?l000T0
003o3_oooon:0000o`kooooo0P000?lL0?l000T0003o103o00040?n000030?l0003oP000oh0000T0
oh000P3o00020?n00080o`0000<0oh000?l0003o00002@3o00070?n00100o`00103oP0020?l000L0
oh00303o000=0?n001Sooooo000Fooooogl0o`000P000?l90?l000koooooB0000?l70?l002h0003o
0P3oP0040?l000L0003o3_oooon:0000o`kooooo2`3oP0070?l00100oh000P3o00070000o`L0oh00
103o000G0?n00080o`000P3oP0000`3o0000003o0000o`020?n000d0o`000`3oP0090?l00080oh00
0P000?l00`3oP000o`000?l0000;0?l000@0003o1@3o000Hooooo`005_oooomo0?l00080003o2@3o
000>ooooodP0003o1`3o000^0000o`80oh00103o00070000o`koooooRP000?l>ooooo`/0oh001`3o
000@0?n00080o`001`000?l70?n000@0o`005`3oP0020?l00080oh0000<0o`000000o`000?l00P3o
P00=0?l000<0oh002@3o00020?n00080003o00<0oh000?l0003o00002`3o00040000o`D0o`006?oo
ool001Kooooo7@3o00000`3oP000o`000?l000140?l00080oh006@3o00020000o`T0o`003_ooool2
0000o`80oh00A0000?l70?l002h0003o0P3oP0040?l000L0003o3_oooomT0000o`@0oh008P000?l>
ooooo`80o`00;@3oP0030?l000H0oh001@3o00020?n00080o`00203oP0080?l001`0oh00103o0002
0000oa80oh001@3o000Hooooo`005_oooom40?l000T0oh00?@3o000>ooooo`80003o0P3oP0140000
o`L0o`002`000?l50?l00200003o103o00070000o`koooooRP000?l>ooooo`@0oh000`000?l@0?n0
00/0o`001`000?l@0?n000H0o`002P3oP0080?l000030?n0003o0000o`000080003o4P3oP0020?l0
00<0oh002@3o00060?n000<0o`001P3oP0050?l001Sooooo000Foooood@0o`002@3oP00m0?l000ko
oooo0P000?l20?n004@0003o1`3o000;0000o`D0o`0080000?l40?l000L0003o3_oooon:0000o`ko
oooo103oP0030000oa00oh002`3o00070000oa00oh001P3o000:0?n000P0o`0000<0oh000?l0003o
00000P000?lB0?n00080o`000`3oP0090?l000H0oh000`3o00060?n000D0o`006?ooool001Kooooo
9`3o00020?n004@0o`000P3oP00K0?l000koooooB@000?l20?l003@0003o103oP0070000o`kooooo
O`000?l20?l00080003o0P3o00050000o`kooooo103oP0050000o`80o`001@3oP0020?l000T0oh00
0P3o00070?n000L0o`002`3oP0090?l000X0oh00203o000C0?n000/0o`000P3oP0020?l000h0oh00
0P3o00070?n001Sooooo000FooooobL0o`000P3oP0140?l00080oh006`3o000>ooooodT0003o0P3o
000d0000o`@0oh001`000?l>ooooogl0003o0P3o00020000o`80o`001@000?l>ooooo`@0oh001@00
0?l20?l000D0oh000P3o00090?n00080o`001`3oP0070?l000/0oh002@3o000:0?n000P0o`004`3o
P00;0?l00080oh000P3o000>0?n00080o`001`3oP00Hooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59468 L
.2381 .59468 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59468 L
.2381 .59468 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02336 L
.95238 .02336 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02336 L
.95238 .02336 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01877 L
.2381 .01877 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01877 L
.2381 .01877 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .5004 L
.47619 .5004 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .5004 L
.47619 .5004 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .1045 L
.71429 .1045 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .1045 L
.71429 .1045 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF80000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF800000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF00FF8000FF000000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000
00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FFFF8000FF800000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF0000FF80000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF0000FF000000FF000000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF800000FF00
FF0000FF80000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF00000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF00FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF00000000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF00FF000000FF00FF000000FF
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF000000FF
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF0000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FF0000FF00FF0000FF00FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF0000FF00FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF00FF000000FF0000FFFF0000FF8000FF800000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF000000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01251 L
.2381 .01251 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01251 L
.2381 .01251 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .16999 L
.47619 .16999 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .16999 L
.47619 .16999 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .44116 L
.71429 .44116 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .44116 L
.71429 .44116 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01689 L
.2381 .01689 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01689 L
.2381 .01689 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01731 L
.47619 .01731 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01731 L
.47619 .01731 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01585 L
.71429 .01585 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01585 L
.71429 .01585 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .59176 L
.95238 .59176 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .59176 L
.95238 .59176 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF000000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF000000FF00FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooooaKoo`001?oooolG
o`3o00Cooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooo
oooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooo
ooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo
5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo
001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03
o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
1?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07OoooolGo`3o03Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0
003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go
001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`04o`00OaOo003o7ol007l00ol0003o
ooooooooo`0Tooooo`03o`000?l007oo001o05;o001o5oooO`04o`00O`03o`000?oooooooooo02?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07OoooolGo`3o03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0
o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Toooo
o`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07OoooolGo`3o03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Boooo
oaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKo
o`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000o`00
Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`0Mo`00
OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo001o5ol00?lOo`00
O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co001o00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l0
07lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo001o5ol00?lOo`00O`03o`000?oo
oooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co001o00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07OoooolGo`3o03Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
001oo`00O`02o`00OaKoo`00EOl007l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o01go
001o5ol0o`0io`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Tooooo`03o`000?l007oo001o05;o001o5oooO`04o`00O`03o`000?oooooooooo02?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07OoooolGo`3o03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02
oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03
o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`00
9?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oo
oooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;o
oooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo
5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02?ooooo000Tooooog7o00009_oooomao`0002OoooooLOl0000Vooooog7o
00009Oooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo000GooooocH0o`000`3oP0110?l00080oh003P3o000>oooo
oah00?l00P000?l2003o00<0o`004000o`020?n000D00?l00P000?l=003o0080003o3P00o`020000
o`<00?l0103o000L003o00D0003o1000o`0>ooooo`80003o4000o`020000o`<00?l03P000?l6003o
00D0003o2`00o`0Z0000o`800?l02`000?l3003o01@0003o3_oooom20?n00080o`00>03oP0000`3o
0000oh000?n0000;0?n001Wooooo000GooooocH0o`000`3oP0110?l00080oh003P3o000>oooooah0
0?l00P000?l2003o00<0o`004000o`020?n000D00?l00P000?l=003o0080003o3P00o`020000o`<0
0?l0103o000L003o00D0003o1000o`0>ooooo`80003o4000o`020000o`<00?l03P000?l6003o00D0
003o2`00o`0Z0000o`800?l02`000?l3003o01@0003o3_oooom20?n00080o`00>03oP0000`3o0000
oh000?n0000;0?n001Wooooo000GooooocH0o`000`3oP00I0?l00080oh009P3o00030?n000P0o`00
0`3oP0020?l000kooooo0P00o`020?n001`00?l00P000?l2003o00<0oh005@00o`020000o`800?l0
0P3o00020?n001`00?l00P3o0002003o00<0o`006@00o`020?n00080003o1@00o`0>ooooo`80003o
2P00o`040000o`L00?l03P000?l4003o00L0003o2`00o`0:0000o`800?l07P000?l2003o00/0003o
1@00o`0B0000o`koooooAP3oP0020?l00280oh000`3o000M0?n001Wooooo000GooooocH0o`000`3o
P00I0?l00080oh009P3o00030?n000P0o`000`3oP0020?l000kooooo0P00o`020?n001`00?l00P00
0?l2003o00<0oh005@00o`020000o`800?l00P3o00020?n001`00?l00P3o0002003o00<0o`006@00
o`020?n00080003o1@00o`0>ooooo`80003o2P00o`040000o`L00?l03P000?l4003o00L0003o2`00
o`0:0000o`800?l07P000?l2003o00/0003o1@00o`0B0000o`koooooAP3oP0020?l00280oh000`3o
000M0?n001Wooooo000GooooocH0o`000`3oP00F0?l000D0oh009P3o00020?n000T0o`001@3oP00>
ooooob@00?l00`000?lI003o0080o`000P3oP007003o0080003o5`00o`030?l001T00?l00P000?l7
003o00kooooo1@000?l4003o0080003o00<00?l00000o`000?l00P000?l7003o0100003o1000o`07
0000o`800?l04@000?l2003o01d0003o00<00?l00000o`000?l03@000?l3003o00h0003o0P00o`02
0000o`kooooo3P3oP0020?l006<0oh0000<0o`000?n0003oP000503oP00Iooooo`005ooooomB0?l0
0080oh007`3o00000`3oP000o`000?l0000?0?l000D0oh003_ooool20000ob800?l00`000?lD003o
00030000o`00o`000?l000@00?l00P3oP0000`3o00000?l0003o00020000o`800?l00P000?lC003o
00@0003o2@00o`000`000?l00?l0003o000;003o0080003o0`00o`040000o`D00?l03_ooool50000
o`@00?l00P000?l00`00o`00003o0000o`0R0000o`D00?l010000?l2003o02X0003o0P00o`090000
o`L00?l04P000?l>ooooodT0oh000P00o`0b0?n000@0o`002@3oP00Iooooo`005ooooomB0?l00080
oh007`3o00000`3oP000o`000?l0000?0?l000D0oh003_ooool20000ob800?l00`000?lD003o0003
0000o`00o`000?l000@00?l00P3oP0000`3o00000?l0003o00020000o`800?l00P000?lC003o00@0
003o2@00o`000`000?l00?l0003o000;003o0080003o0`00o`040000o`D00?l03_ooool50000o`@0
0?l00P000?l00`00o`00003o0000o`0R0000o`D00?l010000?l2003o02X0003o0P00o`090000o`L0
0?l04P000?l>ooooodT0oh000P00o`0b0?n000@0o`002@3oP00Iooooo`005ooooomd0?l00080oh00
503o000>ooooob@00?l00`000?lD003o00<0003o0P00o`040000o`<00?l00P000?l2003o00<0003o
3@00o`020000o`<00?l010000?l9003o00030000o`00o`000?l001000?l010000?l5003o00kooooo
1@000?l7003o02@0003o1@00o`0H0000o`<0oh000P00o`0N0000o`L00?l04P000?l>oooooa/0oh00
0P00o`000`000?l0oh000?n0001O0?n000@0o`001`3oP00Iooooo`005ooooomd0?l00080oh00503o
000>ooooob@00?l00`000?lD003o00<0003o0P00o`040000o`<00?l00P000?l2003o00<0003o3@00
o`020000o`<00?l010000?l9003o00030000o`00o`000?l001000?l010000?l5003o00kooooo1@00
0?l7003o02@0003o1@00o`0H0000o`<0oh000P00o`0N0000o`L00?l04P000?l>oooooa/0oh000P00
o`000`000?l0oh000?n0001O0?n000@0o`001`3oP00Iooooo`005ooooon:0?l000kooooo5@00o`02
0000o`d00?l00`000?lD003o01L0003o2@00o`020000o`<00?l00P000?l;003o00030000o`00o`00
0?l000/00?l00P000?l3003o00@0003o1@00o`0>ooooo`D0003o1`00o`090000o`@00?l05`000?l5
003o00@0003o0`00o`0?0000o`D0oh000P3o000N0000o`800?l00P000?l7003o00h0003o3_oooon:
0?n001Wooooo000GooooohX0o`003_oooolE003o0080003o3@00o`030000oa@00?l05`000?l9003o
0080003o0`00o`020000o`/00?l000<0003o003o0000o`002`00o`020000o`<00?l010000?l5003o
00kooooo1@000?l7003o00T0003o1000o`0G0000o`D00?l010000?l3003o00l0003o1@3oP0020?l0
01h0003o0P00o`020000o`L00?l03P000?l>ooooohX0oh006Oooool001OoooooL`3o00000`3oP000
o`000?l0000D0?l000kooooo8000o`020000o`<00?l00P000?lD003o00L0003o0P00o`0>0000o`80
0?l02@000?l3003o0080003o2`00o`000`000?l00?l0003o000I003o00kooooo10000?l:003o00L0
003o1000o`0G0000o`D00?l010000?l5003o00d0003o0`3oP0020?l000@0oh004`000?l4003o00T0
003o00<00?l00000o`000?l01000o`020000o`<00?l02@000?l>ooooohX0oh006Oooool001Oooooo
P`3o00020?n000D0o`003_oooolL003o0080003o0P00o`020000o`800?l01@000?lB003o00L0003o
0P00o`0>0000o`800?l02@000?l7003o00030000o`00o`000?l000H00?l000<0003o003o0000o`00
4P00o`030000o`@00?l03_ooool20000oa000?l00`000?l4003o0100003o0P00o`050000o`L00?l0
10000?l00`00o`00003o0000o`0=0000o`T0oh004`000?l2003o00T0003o2@00o`0>0000o`kooooo
RP3oP00Iooooo`005ooooon30?l00080oh001@3o000>oooooa`00?l00P000?l2003o0080003o0P00
o`050000oa800?l01`000?l2003o00h0003o0P00o`090000o`L00?l000<0003o003o0000o`001P00
o`000`000?l00?l0003o000B003o00<0003o1000o`0>ooooo`80003o4000o`030000o`@00?l04000
0?l2003o00D0003o1`00o`040000o`03003o00000?l0003o00d0003o2@3oP00C0000o`800?l02@00
0?l9003o00h0003o3_oooon:0?n001Wooooo000Goooooh<0o`000P3oP0050?l000kooooo9@00o`02
0000oa@00?l00`000?l2003o0080003o1@00o`090000o`@00?l01@000?l2003o0080003o1`00o`00
0`000?l00?l0003o000D003o00<0003o0P3oP004003o00030000o`00o`000?l000800?l03_ooool2
003o0080003o2P00o`020000o`/00?l03P000?l2003o00D0003o1000o`000`000?l00?l0003o0002
003o01@0003o0`3oP0090000o`800?l030000?l2003o00T0003o1@00o`0;0000o`800?l01@000?l>
ooooo`h0oh000P00o`1j0?n001Wooooo000Goooooh<0o`000P3oP0050?l000kooooo9@00o`020000
oa@00?l00`000?l2003o0080003o1@00o`090000o`@00?l01@000?l2003o0080003o1`00o`000`00
0?l00?l0003o000D003o00<0003o0P3oP004003o00030000o`00o`000?l000800?l03_ooool2003o
0080003o2P00o`020000o`/00?l03P000?l2003o00D0003o1000o`000`000?l00?l0003o0002003o
01@0003o0`3oP0090000o`800?l030000?l2003o00T0003o1@00o`0;0000o`800?l01@000?l>oooo
o`h0oh000P00o`1j0?n001Wooooo000Goooooe80o`000P3oP00f0?l000kooooo9@00o`020000o`80
0?l00P000?l@003o00030000o`00o`000?l000T00?l01P000?l30?n000@00?l01@000?l;003o0003
0000o`00o`000?l001@00?l01@3oP0020?l00080oh000`000?l2003o00kooooo0P00o`020000o`X0
0?l00P000?l;003o01<0003o1P00o`000`000?l00?l0003o0002003o0080003o00<00?l00000o`00
0?l02@000?l2003o00@0003o1@3oP0070000o`800?l05`000?l5003o00/0003o0P00o`050000o`ko
oooo3@3oP0000`00o`00oh000?n0001Q0?n000800?l05`3oP00Iooooo`005ooooomB0?l00080oh00
=P3o000>ooooobD00?l00P000?l2003o0080003o4000o`000`000?l00?l0003o0009003o00H0003o
0`3oP004003o00D0003o2`00o`000`000?l00?l0003o000D003o00D0oh000P3o00020?n000<0003o
0P00o`0>ooooo`800?l00P000?l:003o0080003o2`00o`0C0000o`H00?l000<0003o003o0000o`00
0P00o`020000o`03003o00000?l0003o00T0003o0P00o`040000o`D0oh001`000?l2003o01L0003o
1@00o`0;0000o`800?l01@000?l>ooooo`d0oh0000<00?l00?n0003oP000H@3oP002003o01L0oh00
6Oooool001OoooooQ@3o00000`3oP000o`000?l000020?l000kooooo9@00o`020000ob800?l01000
0?l50?l000800?l000<0003o003o0000o`000P000?lT003o00030?l00000o`000?l00080o`001`00
o`0>ooooo`800?l00P000?l:003o0080003o2@00o`0E0000o`T00?l010000?l00`00o`00003o0000
o`090000o`800?l01`000?l2003o0080003o00<00?l00000o`000?l00P000?l4003o00P0003o0P00
o`090000o`L00?l02@000?l2003o00L0003o3_ooooma0?n00080003o5`3oP00Iooooo`005ooooon5
0?l000030?n0003o0000o`000080o`003_oooolU003o0080003o8P00o`040000o`D0o`000P00o`00
0`000?l00?l0003o00020000ob@00?l000<0o`00003o0000o`000P3o0007003o00kooooo0P00o`02
0000o`X00?l00P000?l9003o01D0003o2@00o`040000o`03003o00000?l0003o00T0003o0P00o`07
0000o`800?l00P000?l00`00o`00003o0000o`020000o`@00?l020000?l2003o00T0003o1`00o`09
0000o`800?l01`000?l>ooooog40oh000P000?lG0?n001Wooooo000GooooohX0o`003_oooolU003o
0080003o0P00o`020000oa<00?l00P000?l;003o00D0o`000P3oP002003o00030000o`00o`000?l0
02@00?l00P000?l00`3oP0000?l0003o00020?l00080oh0000<0003o003o0000o`000P00o`0>oooo
o`80003o3000o`020000o``00?l05P000?l5003o00@0003o00<00?l00000o`000?l02@000?l2003o
0180003o0P00o`0E0000o`<00?l010000?l4003o00<0003o0P00o`070000o`kooooo5`3oP0020000
o`800?l0K`3oP00Iooooo`005ooooon:0?l000koooooB@00o`020000o`80o`0000<0003o003o0000
o`000P000?lY003o00D0003o0P00o`020?l000<0003o0P00o`0>ooooo`@0003o5`00o`0G0000o`80
0?l000<0003o003o0000o`0040000?l2003o02/0003o00<00?l00000o`000?l00P000?l4003o00<0
003o0P00o`070000o`kooooo>03oP0000`3o0000oh000?n0001?0?n001Wooooo000GooooohX0o`00
3_oooom9003o0080003o0P3o00000`000?l00?l0003o00020000obT00?l01@000?l2003o0080o`00
0`000?l2003o00kooooo10000?lG003o01L0003o0P00o`000`000?l00?l0003o000@0000o`800?l0
:`000?l00`00o`00003o0000o`020000o`@00?l00`000?l2003o00L0003o3_oooolh0?n000030?l0
003oP000oh0004l0oh006Oooool001OoooooL@3o00020?n000L0o`000P3oP00>0?l000koooooB@00
o`020000o`80o`0000<0003o0?l0003o00000P000?l5003o00@0003o8P00o`0:0000o`800?l03_oo
ool20000oaD00?l06`000?l2003o00030000o`00o`000?l000800?l00P000?l00`00o`00003o0000
o`090000o`800?l090000?l00`00o`00003o0000o`040000o`03003o00000?l0003o0080003o1000
o`030000o`800?l01`000?l>ooooocP0oh0000<0o`000?n0003oP000C`3oP00Iooooo`005oooooma
0?l00080oh001`3o00020?n000h0o`003_oooom9003o0080003o0P3o00000`000?l0o`000?l00002
0000o`D00?l010000?lR003o00X0003o0P00o`0>ooooo`80003o5@00o`0K0000o`800?l000<0003o
003o0000o`000P00o`020000o`03003o00000?l0003o00T0003o0P00o`0T0000o`03003o00000?l0
003o00@0003o00<00?l00000o`000?l00P000?l4003o00<0003o0P00o`070000o`kooooo>03oP000
0`3o0000oh000?n0001?0?n001Wooooo000GooooohX0o`003_oooom;003o0080o`0000<0003o003o
0000o`000P000?l2003o00030000o`00o`000?l00080003o0P00o`020000ob000?l01`000?l5003o
00kooooo10000?l00`00o`00003o0000o`04003o00030000o`00o`000?l00080003o1`00o`0N0000
o`@00?l00P000?l00`00o`00003o0000o`090000o`800?l090000?l00`00o`00003o0000o`020000
o`<00?l010000?l2003o00h0003o3_oooom40?n00080o`00A03oP00Iooooo`005ooooon:0?l000ko
ooooB`00o`020?l000030000o`00o`000?l00080003o0P00o`000`000?l00?l0003o00020000o`80
0?l00P000?lP003o00L0003o1@00o`0>ooooo`@0003o00<00?l00000o`000?l01000o`000`000?l0
0?l0003o00020000o`L00?l07P000?l4003o0080003o00<00?l00000o`000?l02@000?l2003o02@0
003o00<00?l00000o`000?l00P000?l3003o00@0003o0P00o`0>0000o`koooooA03oP0020?l004@0
oh006Oooool001OoooooQ@3o00030?n00080o`003_ooooli003o0080003o2@00o`000`000?l00?l0
003o00060000o`<00?l00P000?l2003o00030000o`00o`000?l00080003o0P00o`020000oa<00?l0
0P000?l<003o00@0003o1`00o`0>ooooo`@0003o00<00?l00000o`000?l01000o`050000o`D00?l0
7@000?l7003o0080003o00<00?l00000o`000?l02@000?l2003o02@0003o00<00?l00000o`000?l0
10000?l00`00o`00003o0000o`020000o`800?l03P000?l>oooood@0oh000P3o00140?n001Wooooo
000GooooohD0o`000`3oP0020?l000kooooo>@00o`020000o`T00?l000<0003o003o0000o`001P00
0?l3003o0080003o0P00o`000`000?l00?l0003o00020000o`800?l00P000?lC003o0080003o3000
o`040000o`L00?l03_ooool40000o`03003o00000?l0003o00@00?l01@000?l5003o01d0003o1`00
o`020000o`03003o00000?l0003o00T0003o0P00o`0T0000o`03003o00000?l0003o00@0003o00<0
0?l00000o`000?l00P000?l2003o00h0003o3_oooom40?n00080o`00A03oP00Iooooo`005oooool5
0?l000@0oh00O03o00030?n00080o`003_ooooli003o00<0003o2@00o`020000o`@00?l00P000?l0
0`00o`00003o0000o`020000o`800?l00`000?l4003o0080003o2000o`020000o`T00?l00P000?l@
003o0080003o1@00o`0>ooooo`800?l00P000?l7003o00L0003o0`00o`0M0000o`X00?l02`000?l2
003o00`0003o0P00o`0F0000o`<00?l010000?l5003o0100003o3_oooolV0?n00003003o003oP000
oh0001/0oh000P00o`0b0?n000@0o`003P3oP00Iooooo`005oooool70?l00080oh006@3o00020?n0
06H0o`003_oooolk003o00030000o`00o`000?l000L00?l00P000?l2003o00T0003o0P00o`030000
o`@00?l00P000?l@003o00030000o`00o`000?l00080003o5`00o`0>ooooo`/00?l01`000?l3003o
01d0003o1`00o`020000o`03003o00000?l0003o00/0003o0P00o`0/0000o`800?l040000?l>oooo
ogP0oh000P3o000@0?n001Wooooo000Gooooo`L0o`000P3oP00I0?l00080oh00IP3o000>oooooc/0
0?l000<0003o003o0000o`001`00o`020000o`800?l02@000?l2003o00<0003o1000o`020000oa00
0?l000<0003o003o0000o`000P000?lG003o00kooooo2`00o`070000o`<00?l07@000?l7003o0080
003o00<00?l00000o`000?l02`000?l2003o02`0003o0P00o`0@0000o`koooooN03oP0020?l00100
oh006Oooool001OoooooRP3o000>ooooob000?l00P000?lI003o00L0003o0`00o`020000o`800?l0
2@000?l3003o0080003o5P00o`000`000?l00?l0003o000@003o0080oh001`00o`0>ooooo`/00?l0
1@000?l5003o01@0003o0P3oP0000`000?l0oh000?n000060000o`D00?l040000?l2003o0080o`00
00<0oh000000o`000?l00P3oP00R0000o`03003o00000?l0003o0080003o0P00o`0>0000o`kooooo
@P3oP0020000oc@0oh000P000?l20?l00003003o003oP000oh0000800?l02@3oP00Iooooo`005ooo
oon:0?l000kooooo8000o`020000oaT00?l01`000?l3003o0080003o0P00o`090000o`<00?l00P00
0?lF003o00030000o`00o`000?l001000?l00P3oP007003o00kooooo2`00o`050000o`D00?l05000
0?l20?n000030000o`3oP000oh0000H0003o1@00o`0@0000o`800?l00P3o00000`3oP000003o0000
o`020?n00280003o00<00?l00000o`000?l00P000?l2003o00h0003o3_oooom20?n00080003o=03o
P0020000o`80o`0000<00?l00?n0003oP0000P00o`090?n001Wooooo000Goooooe40o`0000<0oh00
0?l0003o0000=P3o000>oooooah00?l01P000?lG003o00L0003o0`00o`020000o`800?l02@000?l2
003o00D0003o5000o`000`000?l00?l0003o000>003o0080003o0P3o00030?n000@00?l03_ooool;
003o00030000o`00o`000?l000800?l00P000?l7003o00T0003o0P00o`0@0000o`D00?l00P000?l3
003o00/0003o0P00o`070000o`800?l000<0003o003o0000o`008P000?l5003o00/0003o3_ooool>
0?n00080o`00K`3oP002003o00T0oh006Oooool001OoooooD@3o00000`3oP000o`000?l0000f0?l0
00kooooo7P00o`060000oaL00?l01`000?l3003o0080003o0P00o`090000o`800?l01@000?lD003o
00030000o`00o`000?l000h00?l00P000?l20?l000<0oh001000o`0>ooooo`/00?l000<0003o003o
0000o`000P00o`020000o`L00?l02@000?l2003o0100003o1@00o`020000o`<00?l02`000?l2003o
00L0003o0P00o`000`000?l00?l0003o000R0000o`D00?l02`000?l>ooooo`h0oh000P3o001_0?n0
00800?l02@3oP00Iooooo`005ooooom80?l000<0oh00?`3o000>ooooob800?l00P000?l@003o0003
0000o`00o`000?l000@00?l01`000?l3003o00d0003o0P00o`030000o`@00?l00`000?l?003o0003
0000o`00o`000?l000h00?l010000?l7003o00kooooo3000o`060000o`<00?l00P000?l4003o00L0
003o0P00o`050000o`<0oh001P000?l7003o0080003o0`00o`0D0000o`<00?l060000?l00`00o`00
003o0000o`050000o`@00?l00P000?l3003o00/0003o3_ooool20000odd0oh000P000?l00`00o`00
oh000?n0000[0?n000800?l00P000?l70?n001Wooooo000Gooooo`D0o`000P3oP01l0?l00080oh00
1@3o000>oooooc@00?l000<0003o003o0000o`001000o`070000o`800?l000<0003o003o0000o`00
0P00o`090000o`800?l00`000?l4003o0080003o4000o`000`000?l00?l0003o000=003o00<0003o
2@00o`0>ooooo``00?l01P000?l3003o0080003o1000o`070000o`800?l01@000?l30?n000H0003o
0P00o`000`000?l00?l0003o0002003o0080003o0`00o`090000o`800?l02`000?l00`00o`00003o
0000o`0F0000o`03003o00000?l0003o00D0003o0P00o`020000o`800?l03P000?l>ooooogl0oh00
0P00o`090?n001Wooooo000Gooooo`D0o`000P3oP01l0?l00080oh001@3o000>oooooc@00?l000<0
003o003o0000o`001000o`070000o`800?l000<0003o003o0000o`000P00o`090000o`800?l00`00
0?l4003o0080003o4000o`000`000?l00?l0003o000=003o00<0003o2@00o`0>ooooo``00?l01P00
0?l3003o0080003o1000o`070000o`800?l01@000?l30?n000H0003o0P00o`000`000?l00?l0003o
0002003o0080003o0`00o`090000o`800?l02`000?l00`00o`00003o0000o`0F0000o`03003o0000
0?l0003o00D0003o0P00o`020000o`800?l03P000?l>ooooogl0oh000P00o`090?n001Wooooo000G
ooooo`D0o`000P3oP0230?l000kooooo7P00o`040000oaT00?l000<0003o003o0000o`0010000?l2
003o00030000o`00o`000?l000800?l02@000?l3003o0080003o0P00o`040000ob000?l00`000?l9
003o00kooooo3P00o`040000o`800?l00`000?l5003o00H0003o0P00o`070000o`030?n000000?l0
003o00@0003o0P00o`000`000?l00?l0003o0007003o0100003o0P3oP00K0000o`<00?l02@000?l4
003o00h0003o3_oooomm0?n00080003o2`3oP00Iooooo`005oooool50?l00080oh00P`3o000>oooo
oah00?l010000?lI003o00030000o`00o`000?l000@0003o0P00o`000`000?l00?l0003o0002003o
00T0003o0`00o`020000o`800?l010000?lP003o00<0003o2@00o`0>ooooo`h00?l010000?l2003o
00<0003o1@00o`060000o`800?l01`000?l00`3oP000003o0000o`040000o`800?l000<0003o003o
0000o`001`00o`0@0000o`80oh006`000?l3003o00T0003o1000o`0>0000o`koooooO@3oP0020000
o`/0oh006Oooool001Oooooo103o00030?n008<0o`003_oooolP003o0080003o6@00o`000`000?l0
0?l0003o0002003o0080003o0P00o`000`000?l00?l0003o0002003o00D0003o0P00o`040000o`D0
0?l010000?lN003o00<0003o2`00o`0>ooooo`h00?l010000?l2003o00<0003o1@00o`020000o`@0
0?l01`000?l2003o00X0003o2@00o`0@0000o`80oh006`000?l2003o00X0003o1000o`0>0000o`ko
oooo@@3oP0050000o``0oh000P3o0002003o0080003o<P3oP00Iooooo`005oooool40?l000<0oh00
P`3o000>ooooob000?l00P000?lI003o00030000o`00o`000?l000800?l00P000?l2003o00030000
o`00o`000?l000800?l01@000?l2003o00@0003o1@00o`040000oah00?l00`000?l;003o00kooooo
3P00o`040000o`800?l00`000?l5003o0080003o1000o`070000o`800?l02P000?l9003o0100003o
0P3oP00K0000o`800?l02P000?l4003o00h0003o3_oooom10?n000D0003o303oP0020?l000800?l0
0P000?lb0?n001Wooooo000GooooohX0o`003_oooolk003o00030000o`00o`000?l000800?l00P00
0?l9003o00T0003o00<00?l00000o`000?l00P00o`040000oah00?l00`000?l;003o00kooooo0P00
0?l:003o00H0003o0P00o`030000o`D00?l00P000?l2003o00`0003o1000o`020000o``00?l09`00
0?l4003o0080003o0P00o`050000o`800?l05@000?l>ooooohX0oh006Oooool001OoooooRP3o000>
oooooc/00?l000<0003o003o0000o`000P00o`020000o`T00?l02@000?l00`00o`00003o0000o`02
003o00@0003o7P00o`030000o`/00?l03_ooool20000o`X00?l01P000?l2003o00<0003o1@00o`02
0000o`800?l030000?l4003o0080003o3000o`0W0000o`@00?l00P000?l2003o00D0003o0P00o`0E
0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo>@00o`030000o`l00?l02@000?l5003o
00@0003o7P00o`050000o`T00?l03_ooool20000o`<00?l00P000?l7003o0080003o1000o`000`00
0?l00?l0003o0009003o0080003o0P00o`0:0000o`H00?l000<0003o003o0000o`001`00o`0V0000
o`03003o00000?l0003o00@0003o0P00o`050000o`<00?l00P000?l2003o0100003o3_ooool@0?n0
00800?l03P3oP0020000ofP0oh006Oooool001Oooooo<03o00020?n005P0o`003_ooooli003o00<0
003o3`00o`030000o`800?l00P000?l>003o0080003o6@00o`070000o`L00?l03_ooool20000o`<0
0?l010000?lC003o0080003o0P00o`020000o`800?l03P000?l2003o00030000o`00o`000?l00080
003o1@00o`090000o`800?l06@000?l<003o00@0003o0`00o`020000o`800?l040000?l>oooooa00
oh000P00o`020000ogH0oh006Oooool001Oooooo<03o00020?n005P0o`003_ooooli003o00<0003o
3`00o`030000o`800?l00P000?l>003o0080003o6@00o`070000o`L00?l03_ooool20000o`<00?l0
10000?lC003o0080003o0P00o`020000o`800?l03P000?l2003o00030000o`00o`000?l00080003o
1@00o`090000o`800?l06@000?l<003o00@0003o0`00o`020000o`800?l040000?l>oooooa00oh00
0P00o`020000ogH0oh006Oooool001OoooooP@3o00020?n000L0o`003_ooooli003o00<0003o3@00
o`050000o`800?l00P000?lU003o0080003o0P00o`070000o`L00?l03_ooool20000o`<00?l01P00
0?lA003o00H0003o0P00o`0A0000o`800?l010000?l3003o00L0003o0P00o`060000o`03003o0000
0?l0003o0180003o0P00o`030000o`800?l00P000?l2003o00030000o`00o`000?l00080003o0`00
o`0D0000o`kooooo0P000?n80?n001Wooooo000Goooooh40o`000P3oP0070?l000kooooo>@00o`03
0000o`d00?l01@000?l2003o0080003o9@00o`020000o`800?l01`000?l7003o00kooooo0P000?l3
003o00H0003o4@00o`060000o`800?l04@000?l2003o00@0003o0`00o`070000o`800?l01P000?l0
0`00o`00003o0000o`0B0000o`800?l00`000?l2003o0080003o0P00o`000`000?l00?l0003o0002
0000o`<00?l050000?l>ooooo`80003oR03oP00Iooooo`005ooooon:0?l000kooooo>@00o`030000
o`P00?l03P000?l>003o0080003o5@00o`020000o`800?l01@000?l9003o00kooooo0P000?l3003o
00H0003o4`00o`040000o`800?l04@000?l2003o00@0003o00<00?l00000o`000?l01`000?l2003o
0080003o0P00o`0G0000o`800?l02P000?l2003o01T0003o3_oooon:0?n001Wooooo000GooooohX0
o`003_ooooli003o00<0003o2000o`0>0000o`h00?l00P000?lE003o0080003o0P00o`050000o`T0
0?l03_ooool20000o`<00?l01P000?lC003o00@0003o0P00o`0A0000o`800?l010000?l00`00o`00
003o0000o`070000o`800?l00P000?l2003o01L0003o0P00o`0:0000o`800?l06@000?l>ooooohX0
oh006Oooool001OoooooRP3o000>oooooch00?l00P3o00020000o`<00?l03@000?l>003o0080003o
7000o`020000o`T00?l03_ooool20000o`<00?l01P000?l>003o00T0003o0P00o`0A0000o`800?l0
10000?l3003o01L0003o0P00o`090000o`800?l030000?l2003o01T0003o3_oooolT0?n000800?l0
9@3oP0020?l003d0oh006Oooool001OoooooRP3o000>oooooch00?l00P3o00020000o`<00?l03@00
0?l>003o0080003o7000o`020000o`T00?l03_ooool20000o`<00?l01P000?l>003o00T0003o0P00
o`0A0000o`800?l010000?l3003o01L0003o0P00o`090000o`800?l030000?l2003o01T0003o3_oo
oolT0?n000800?l09@3oP0020?l003d0oh006Oooool001OoooooRP3o000>oooooc`00?l00P000?l2
0?l000@0003o0`00o`020?n000D0003o>`00o`0>ooooo`T0003o2`00o`000`000?l00?l0003o0002
003o0200003o1@00o`0G0000o`800?l010000?l2003o00030000o`00o`000?l000h0003o0P00o`0I
0000o`koooooRP3oP00Iooooo`005ooooomo0?l00080oh002@3o000>oooooc`00?l00P000?l2003o
00@0003o0`00o`020?n00080003o2P00o`020000o`800?l00P000?l^003o00kooooo1`000?l=003o
00030000o`00o`000?l00280003o1@00o`0G0000o`800?l010000?l2003o00030000o`00o`000?l0
00800?l030000?l2003o01T0003o3_oooomJ0?n000<0o`00;@3oP00Iooooo`005ooooomo0?l00080
oh002@3o000>oooooc`00?l00P000?l2003o00@0003o0`00o`020?n00080003o2P00o`020000o`80
0?l00P000?l^003o00kooooo1`000?l=003o00030000o`00o`000?l00280003o1@00o`0G0000o`80
0?l010000?l2003o00030000o`00o`000?l000800?l030000?l2003o01T0003o3_oooomJ0?n000<0
o`00;@3oP00Iooooo`005ooooomo0?l00080oh002@3o000>oooooc`00?l00P000?l2003o00@0003o
0`00o`040000o`X00?l00P000?lb003o00kooooo10000?l:003o0080003o1000o`0S0000o`L00?l0
6`000?l4003o00030000o`00o`000?l000800?l030000?l2003o00d0003o00<00?l00000o`000?l0
2@000?l>ooooohX0oh006Oooool001OoooooO`3o00020?n000T0o`003_ooooll003o0080003o0P00
o`040000o`<00?l010000?l:003o0080003o<P00o`0>ooooo`@0003o2P00o`020000o`@00?l08`00
0?l7003o01/0003o1000o`000`000?l00?l0003o0002003o00`0003o0P00o`0=0000o`03003o0000
0?l0003o00T0003o3_oooon:0?n001Wooooo000GooooohX0o`003_ooooli003o0080003o00<00?l0
0000o`000?l010000?l2003o00<0003o0P3o00040?n000P00?l00P000?l4003o0080003o;000o`0>
ooooo`@0003o2P00o`060000o`03003o00000?l0003o01d0003o00<00?l00000o`000?l01`00o`0K
0000o`@00?l000<0003o003o0000o`001@00o`090000o`800?l06@000?l>ooooohX0oh006Oooool0
01OoooooRP3o000>ooooocT00?l00P000?l00`00o`00003o0000o`040000o`800?l00`000?l20?l0
00@0oh002000o`020000o`@00?l00P000?l/003o00kooooo10000?l:003o00H0003o00<00?l00000
o`000?l07@000?l00`00o`00003o0000o`07003o01/0003o1000o`000`000?l00?l0003o0005003o
00T0003o0P00o`0I0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo0P00o`020?n003D0
0?l00P000?l00`00o`00003o0000o`040000o`800?l00`000?l2003o00@0oh002000o`020000o`@0
0?l00P000?l/003o00kooooo10000?l3003o0080003o1@00o`060000o`03003o00000?l0003o00@0
0?l05@000?l2003o0080003o00<00?l00000o`000?l01@00o`0M0000o`@00?l000<0003o003o0000
o`000P00o`020000o`<00?l01P000?l5003o01L0003o3_oooolI0?n000800?l0K`3oP00Iooooo`00
5oooool>0?l00080oh00L@3o00020?n000L0o`003_ooooli003o0080003o00<00?l00000o`000?l0
2@000?l40?n000<0o`001P00o`050000oc000?l03_ooool20000o``00?l01P000?l00`00o`00003o
0000o`020000o`800?l05@000?l2003o0080003o00<00?l00000o`000?l00P00o`020000o`03003o
00000?l0003o00800?l06@000?l4003o00030000o`00o`000?l000800?l00`000?l2003o00H0003o
1@00o`0;0000o`03003o00000?l0003o00T0003o3_ooool50?n000800?l04P3oP002003o00D0oh00
0P00o`020000oc00oh000P000?ld0?n001Wooooo000Gooooo`h0o`000P3oP01a0?l00080oh001`3o
000>ooooocT00?l00P000?l00`00o`00003o0000o`090000o`@0oh000`3o0006003o00D0003o<000
o`0>ooooo`80003o3000o`060000o`03003o00000?l0003o0080003o0P00o`0E0000o`800?l00P00
0?l00`00o`00003o0000o`02003o0080003o00<00?l00000o`000?l00P00o`0I0000o`@00?l000<0
003o003o0000o`000P00o`030000o`800?l01P000?l5003o00/0003o00<00?l00000o`000?l02@00
0?l>ooooo`D0oh000P00o`0B0?n000800?l01@3oP002003o0080003o<03oP0020000oc@0oh006Ooo
ool001Oooooo9`3o00020?n00640o`003_ooooli003o0100003o0P00o`070000o`800?l02@000?l7
003o00030000o`00o`000?l002800?l03_ooool70000o`L00?l01P000?l00`00o`00003o0000o`0I
0000o`800?l040000?l2003o00030000o`00o`000?l001L0003o0P00o`0=0000o`<00?l03P000?l2
003o0080003o0P00o`050000o`kooooo0P00o`020?n000<00?l00P000?l2003o07l0oh006Oooool0
01Oooooo9`3o00020?n00640o`003_ooooli003o0100003o0P00o`070000o`800?l02@000?l7003o
00030000o`00o`000?l002800?l03_ooool70000o`L00?l01P000?l00`00o`00003o0000o`0I0000
o`800?l040000?l2003o00030000o`00o`000?l001L0003o0P00o`0=0000o`<00?l03P000?l2003o
0080003o0P00o`050000o`kooooo0P00o`020?n000<00?l00P000?l2003o07l0oh006Oooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.00589017 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13252 -12 -4.5 ]
[-0.0125 .13252 0 4.5 ]
[-0.0125 .25032 -12 -4.5 ]
[-0.0125 .25032 0 4.5 ]
[-0.0125 .36813 -12 -4.5 ]
[-0.0125 .36813 0 4.5 ]
[-0.0125 .48593 -12 -4.5 ]
[-0.0125 .48593 0 4.5 ]
[-0.0125 .60373 -18 -4.5 ]
[-0.0125 .60373 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13252 m
1 .13252 L
s
0 .25032 m
1 .25032 L
s
0 .36813 m
1 .36813 L
s
0 .48593 m
1 .48593 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13252 m
.00625 .13252 L
s
[(20)] -0.0125 .13252 1 0 Mshowa
0 .25032 m
.00625 .25032 L
s
[(40)] -0.0125 .25032 1 0 Mshowa
0 .36813 m
.00625 .36813 L
s
[(60)] -0.0125 .36813 1 0 Mshowa
0 .48593 m
.00625 .48593 L
s
[(80)] -0.0125 .48593 1 0 Mshowa
0 .60373 m
.00625 .60373 L
s
[(100)] -0.0125 .60373 1 0 Mshowa
.125 Mabswid
0 .04417 m
.00375 .04417 L
s
0 .07362 m
.00375 .07362 L
s
0 .10307 m
.00375 .10307 L
s
0 .16197 m
.00375 .16197 L
s
0 .19142 m
.00375 .19142 L
s
0 .22087 m
.00375 .22087 L
s
0 .27977 m
.00375 .27977 L
s
0 .30922 m
.00375 .30922 L
s
0 .33867 m
.00375 .33867 L
s
0 .39758 m
.00375 .39758 L
s
0 .42703 m
.00375 .42703 L
s
0 .45648 m
.00375 .45648 L
s
0 .51538 m
.00375 .51538 L
s
0 .54483 m
.00375 .54483 L
s
0 .57428 m
.00375 .57428 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13252 m
1 .13252 L
s
.99375 .25032 m
1 .25032 L
s
.99375 .36813 m
1 .36813 L
s
.99375 .48593 m
1 .48593 L
s
.99375 .60373 m
1 .60373 L
s
.125 Mabswid
.99625 .04417 m
1 .04417 L
s
.99625 .07362 m
1 .07362 L
s
.99625 .10307 m
1 .10307 L
s
.99625 .16197 m
1 .16197 L
s
.99625 .19142 m
1 .19142 L
s
.99625 .22087 m
1 .22087 L
s
.99625 .27977 m
1 .27977 L
s
.99625 .30922 m
1 .30922 L
s
.99625 .33867 m
1 .33867 L
s
.99625 .39758 m
1 .39758 L
s
.99625 .42703 m
1 .42703 L
s
.99625 .45648 m
1 .45648 L
s
.99625 .51538 m
1 .51538 L
s
.99625 .54483 m
1 .54483 L
s
.99625 .57428 m
1 .57428 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .58699 L
.06452 .58699 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .58699 L
.06452 .58699 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .39533 L
.22581 .39533 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .39533 L
.22581 .39533 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .58409 L
.3871 .58409 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .58409 L
.3871 .58409 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .46542 L
.54839 .46542 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .46542 L
.54839 .46542 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .44681 L
.70968 .44681 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .44681 L
.70968 .44681 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .22725 L
.87097 .22725 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .22725 L
.87097 .22725 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .01472 L
.09677 .01472 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .01472 L
.09677 .01472 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .01472 L
.25806 .01472 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .01472 L
.25806 .01472 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .56238 L
.58065 .56238 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .56238 L
.58065 .56238 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .45632 L
.74194 .45632 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .45632 L
.74194 .45632 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .60332 L
.90323 .60332 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .60332 L
.90323 .60332 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .59174 L
.12903 .59174 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .59174 L
.12903 .59174 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .1797 L
.29032 .1797 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .1797 L
.29032 .1797 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .51731 L
.45161 .51731 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .51731 L
.45161 .51731 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .01472 L
.6129 .01472 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .01472 L
.6129 .01472 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .11519 L
.77419 .11519 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .11519 L
.77419 .11519 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .01472 L
.93548 .01472 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .01472 L
.93548 .01472 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .3209 L
.16129 .3209 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .3209 L
.16129 .3209 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .55742 L
.32258 .55742 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .55742 L
.32258 .55742 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .38065 L
.48387 .38065 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .38065 L
.48387 .38065 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .48692 L
.64516 .48692 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .48692 L
.64516 .48692 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .25661 L
.80645 .25661 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .25661 L
.80645 .25661 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .42779 L
.96774 .42779 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .42779 L
.96774 .42779 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`0002kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Qoooooooo0000IOl0000;ooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`coogl02ol0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000;ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_o
oooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool001Oooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`co
ogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_o
oooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<
oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;
ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo
3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_oo
ool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=
ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:
ooooo`coo`003?l0o`0;ooooo`coogl02Oooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool0
00_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00
o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co
003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool0
00[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co
003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000co
0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l0
0?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:
ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000co0?l02oooool<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`002_ooool<o`00
o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o
00_ooooo3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<
oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;
ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo
3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_oo
ool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo
00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co
003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool0
00[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co
003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co
0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`004?oo
ool5o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?oo
O`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo
000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02ooo
ool<oomo00_ooooo00?o0000ooooooooool02Oooool0017ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l0
2oooool<oomo00_ooooo00?o0000ooooooooool02Oooool001;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l0
2oooool<oomo00_ooooo00?o0000ooooooooool02Oooool001?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Cooooo0ol00008o`00O`goo`002_l007l<o`00o`coogl0
2_l007l=ool000[o001o3?l00?l<oomo00_o001o3?oo000;o`00O`_o003o3?ooO`0;o`00O`_oo`00
3Ol0o`0:o`00O`googl02_l007l<ool000co0?l02_l007l=oomo00[o001o3?oo000<o`3o00_o001o
3?ooO`08o`00O`Co00002oooool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[o
oooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go
0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`co
ogl02oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00
o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o
00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oo
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co
003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool0
00[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co
003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co
0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool2o`0000Wooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02ooo
ool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000co0?l02oooool<oomo00Wooooo0ol0000;ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<
oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<
ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:oooo
o`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02oooool<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<
oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;
ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_o
oooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co
0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00
5_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl0
2_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?oo
O`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?oo
O`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3?l00?l<
oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02oooool<
oomo00Wooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00
o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;oooo
o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00
o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;oooo
o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool00ol0003ooooooooo
o`09ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<
oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<
ool000co0?l02_ooool=oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`09ooooo`?o00002oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02oooool<oomo00_ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[o
oooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000co0?l02oooool<oomo00_o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl05_ooool<o`3o00_ooooo
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo01Kooooo3?l0
o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0F
ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool0
00_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl05_ooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_o
oooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co
0?l02_ooool=oomo01Kooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`00
4_ooool3o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo01Kooooo3?l0o`0;ooooo`coogl0
2oooool00ol0003oooooooooo`09ooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0Fooooo`co0?l02oooool<oomo00_ooooo
00?o0000ooooooooool02Oooool0013ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0:ooooo`googl05_ooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000@ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001_ooool3o`0000So
001o3Ooo000:o`00O`co003o3?ooO`0:o`00O`goo`005_l007l<oomo00_o001o3?oo000;o`00O`_o
003o3?ooO`0;o`00O`_oo`003Ol0o`0:o`00O`googl02_l007l<ool000co0?l02_l007l=oomo01Ko
001o3?l0o`0;o`00O`coogl02?l007l4o`0000_ooooo000Aooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`co
ogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go
0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0Fooooo`co0?l02oooool<oomo00_o
oooo00?o0000ooooooooool02Oooool001;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl05_ooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wo
oooo000Cooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo
3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o
3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?oo
O`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:
ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;
ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:oooo
o`co003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co
003o3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?oo
O`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000F
ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00Wooooo0ol0000;ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o
02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`co
o`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02go
oooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo
3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0
o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;
ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00
o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;oooo
o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`co
ogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl0
2oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_oo
ool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02ooo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02ooo
ool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`co003o3?ooO`0:
ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:
ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`09ooooo`?o00002oooool0
027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]
ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o
00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`co
ogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol0
0?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o
02gooooo3?l0o`0;ooooo`coogl02Oooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`co
ogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol0
0?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Foooo
o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_o
oooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co
0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo
3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?oo
O`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`004?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo
2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l0
2oooool<oomo00_ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`goo`002_l007l=o`00oaGo
001o3Ooo000Fo`00O`coogl02ol007l<ool000_o001o2ol00?l<oomo00_o001o2ooo000=o`3o00[o
001o3OooO`0:o`00O`coo`003?l0o`0]o`00O`co0?l02ol007l<oomo00So001o1?l0000;ooooo`00
4?ooool4o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_o
oooo00?o0000ooooooooool02Oooool0013ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Ko
oooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`00
4Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`_o
003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_o
oooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o00001?ooool2o`0000Oooooo
00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`goo`005_ooool<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0
o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lF
ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:oooo
o`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lEooooo`go
o`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00oaGooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o5Oooool=ool001Kooooo3?ooO`0;ooooo`coo`002ooo
ool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02ooo
ool<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`002_ooool=
o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00Wooooo0ol0000;ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00
oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3Ol00?lhooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`go
ogl02_ooool<ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo
3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo
3?l0o`0;ooooo`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo
000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lh
ooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<
ool000co0?l0;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;oooo
o`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;oooo
o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l02oooool<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl0
2oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
;Oooool<o`3o00_ooooo3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o5_oo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02ooo
ool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`go003o>?ooool<
oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o02gooooo3?l0o`0;ooooo`coogl02Oooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o02gooooo3?l0o`0;ooooo`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSo
oooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0]ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?oo
O`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0]ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;oooo
o`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0]oooo
o`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0]ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`00
2oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0Fooooo`co0?l0;Oooool<o`3o02;ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol0
0?lhooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl05_oo
ool<o`3o02gooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;
ool000go0?l02_ooool=oomo01Kooooo3?l0o`0]ooooo`co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;oooo
o`co003o5_ooool;ool000go0?l02_ooool=oomo01Kooooo3?l0o`0]ooooo`co0?l08?ooool3o`00
00_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_o
oooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo04oooooo3?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o
>?ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo04oooooo
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_oo
ool=oomo04oooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o8Oooool=
o`3o00[ooooo3OooO`1?ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00
ob7ooooo3Ol0o`0:ooooo`googl0Coooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool000_o
oooo3?l00?lQooooo`go0?l02_ooool=oomo04oooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo
3?oo000;ooooo`co003o8Oooool=o`3o00[ooooo3OooO`1?ooooo`co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000;ooooo`co003o8Oooool=o`3o00[ooooo3Ooo
O`1?ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo3Ol0o`0:ooooo`googl0
Coooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`goo`002_l007l=o`00ocSo
001o3?ooO`0;o`00O`coo`002ol007l<o`00ob7o001o3Ol0o`0:o`00O`googl0Col007l<o`3o01oo
001o1?l0000;ooooo`004Oooool3o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7o
oooo3Ol0o`0:ooooo`googl0Coooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool000_ooooo3?l00?lQoooo
o`go0?l0I_ooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=
ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool000_ooooo3?l00?lQooooo`go0?l0I_ooool<
o`3o02;ooooo00?o0000ooooooooool02Oooool0017ooooo0ol00004ooooo`;o00001oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00
ob7ooooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7o
oooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo
3Ol0o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo3Ol0
o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo3Ol0o`1V
ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo3Ol0o`1Voooo
o`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`002oooool<o`00ob7ooooo3Ol0o`1Vooooo`co
0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000:ooooo`go003o
>?ooool<oomo00_ooooo3?oo000;ooooo`co003o8Oooool=o`3o06Kooooo3?l0o`0Pooooo`?o0000
2oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl02ooo
ool<ool003Sooooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`00>?ooool=
o`3o06Kooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo000hooooo`go0?l0I_ooool<o`3o
02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3Ol00?lhooooo`coogl02oooool<ool003Sooooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00ocSooooo
3?ooO`0;ooooo`coo`00>?ooool=o`3o06Kooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo00_ooooo3?oo
000hooooo`go0?l0I_ooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool003Sooooo3Ol0o`1V
ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`00>?ooool=o`3o06Kooooo3?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go
003o>?ooool<oomo00_ooooo3?oo000hooooo`go0?l0I_ooool<o`3o02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo0_l00009ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`00
>?ooool=o`3o06Kooooo3?l0o`0Pooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool003Sooooo3Ol0o`1Vooooo`co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=
o`00ocSooooo3?ooO`0;ooooo`coo`00>?ooool=o`3o06Kooooo3?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`go003o>?ooool<oomo
00_ooooo3?oo000hooooo`go0?l0I_ooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?lhooooo`coogl02oooool<ool003So
oooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool=o`00ocSooooo3?ooO`0;ooooo`coo`00>?ooool=o`3o06Kooooo
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`go003oCoooool<ool003Sooooo3Ol0o`1Vooooo`co0?l08_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00odoooooo3?oo002[
ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool=o`00odoooooo3?oo002[ooooo`co0?l08_ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool=o`00odoooooo3?oo002[ooooo`co
0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool=o`00odoooooo3?oo002[ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool2o`0000Wooooo3Ooo000:ooooo`go003oCoooool<ool00:_ooooo3?l0o`0Pooooo`?o00002ooo
ool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?m?ooooo`coo`00Zoooool<
o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
00[ooooo3Ol00?m?ooooo`coo`00Zoooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3Ol00?m?ooooo`coo`00Zoooool<o`3o02;o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3Ol00?ooooooo`Oooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo01oooooo3Ol00?ooooooo`Oooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo01oooooo3Ol00?ooooooo`Oooooo3?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000;ooooo`?o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
0?oooooo<oooool<o`3o02;ooooo00?o0000ooooooooool02Oooool000cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooolcooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`003?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooooc?ooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00006ooooo`?o0000oooooolcooooo`co0?l07oooool4o`0000_ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo0?ooooooHOooool00ol0003oooooooooo`09ooooo`002oooool2o`0000Cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
0?ooooooHOooool00ol0003oooooooooo`09ooooo`003?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool2o`0000Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Qoooooooo0000IOl0
000;ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`00
03Gooooo0ol0000fooooo`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003o
ooooooooool0000eooooo`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0c
ooooo`05o`000?ooooooooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo
0012ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0booooo`Go0000>?ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000
;Oooool004;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Ooo
ool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_oo
ool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo
0011ooooo`;o0000=_ooool01Ol0003ooooooooooooooooo000003Gooooo00Go0000oooooooooooo
ooooo`00000fooooo`;o0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02ko
oooo0012ooooo`03o`000?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003ooooo
ooooo`0cooooo`Go0000=_ooool2o`0002kooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.119489, -8.92682, \
0.0174717, 0.478427}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.0060019 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13475 -12 -4.5 ]
[-0.0125 .13475 0 4.5 ]
[-0.0125 .25479 -12 -4.5 ]
[-0.0125 .25479 0 4.5 ]
[-0.0125 .37483 -12 -4.5 ]
[-0.0125 .37483 0 4.5 ]
[-0.0125 .49487 -12 -4.5 ]
[-0.0125 .49487 0 4.5 ]
[-0.0125 .61491 -18 -4.5 ]
[-0.0125 .61491 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13475 m
.00625 .13475 L
s
[(20)] -0.0125 .13475 1 0 Mshowa
0 .25479 m
.00625 .25479 L
s
[(40)] -0.0125 .25479 1 0 Mshowa
0 .37483 m
.00625 .37483 L
s
[(60)] -0.0125 .37483 1 0 Mshowa
0 .49487 m
.00625 .49487 L
s
[(80)] -0.0125 .49487 1 0 Mshowa
0 .61491 m
.00625 .61491 L
s
[(100)] -0.0125 .61491 1 0 Mshowa
.125 Mabswid
0 .04472 m
.00375 .04472 L
s
0 .07473 m
.00375 .07473 L
s
0 .10474 m
.00375 .10474 L
s
0 .16476 m
.00375 .16476 L
s
0 .19477 m
.00375 .19477 L
s
0 .22478 m
.00375 .22478 L
s
0 .2848 m
.00375 .2848 L
s
0 .31481 m
.00375 .31481 L
s
0 .34482 m
.00375 .34482 L
s
0 .40484 m
.00375 .40484 L
s
0 .43485 m
.00375 .43485 L
s
0 .46486 m
.00375 .46486 L
s
0 .52488 m
.00375 .52488 L
s
0 .55489 m
.00375 .55489 L
s
0 .5849 m
.00375 .5849 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13475 m
1 .13475 L
s
.99375 .25479 m
1 .25479 L
s
.99375 .37483 m
1 .37483 L
s
.99375 .49487 m
1 .49487 L
s
.99375 .61491 m
1 .61491 L
s
.125 Mabswid
.99625 .04472 m
1 .04472 L
s
.99625 .07473 m
1 .07473 L
s
.99625 .10474 m
1 .10474 L
s
.99625 .16476 m
1 .16476 L
s
.99625 .19477 m
1 .19477 L
s
.99625 .22478 m
1 .22478 L
s
.99625 .2848 m
1 .2848 L
s
.99625 .31481 m
1 .31481 L
s
.99625 .34482 m
1 .34482 L
s
.99625 .40484 m
1 .40484 L
s
.99625 .43485 m
1 .43485 L
s
.99625 .46486 m
1 .46486 L
s
.99625 .52488 m
1 .52488 L
s
.99625 .55489 m
1 .55489 L
s
.99625 .5849 m
1 .5849 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .60332 L
.2381 .60332 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .60332 L
.2381 .60332 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .5081 L
.47619 .5081 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .5081 L
.47619 .5081 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .44827 L
.71429 .44827 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .44827 L
.71429 .44827 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60037 L
.95238 .60037 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60037 L
.95238 .60037 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00DOooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`0003gooooo001Booooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0??ooool005;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol0000mooooo`00D_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
03kooooo001Booooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000?_ooool0057ooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l0000n
ooooo`00D_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0??ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool0027oooooool0001Uo`0000_ooooo000Qooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`006?ooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00002oooool0
01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`005oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000?ooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool001?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00Cooooo0ol0000>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl03Oooool4o`0000_ooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool2
o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool001;ooooo0ol00003ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`004?ooool5o`0000;ooooo00Co0000oooooooooooo00001_ooool3o`0000kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0=ooooo`Co00002oooool0013ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`004_ooool2o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`004oooool00ol0003oooooooooo`02ooooo`;o00001oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool2
o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004Ooo
ool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000@ooooo`Co00000oooool01?l0003oooooooooool00006ooooo`?o
00003_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00gooooo1?l0000;ooooo`00
4?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0017ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Booooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o06CoooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0I?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`1TooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o06CoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0I?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o06CoooooAOooO`0>ooooo`?o
00002oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`1TooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o06CoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l0I?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`1TooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o06Co
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l0I?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`1TooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l0I?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`1TooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool3o`0000kooooo
A?oo000@ooooodGo0?l0I?oooom5oomo00gooooo1?l0000;ooooo`004Oooool3o`0000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o06Cooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l0I?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`1TooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Co
oooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0I?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`1TooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o00002ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o00002oooool0
027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002i
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo0_l0000?ooooodCoo`00^Ooooom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002ioooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`00ooooool?ooooo`03o`000?oooooooooo00Wooooo000;ooooo`?o00001?ooool2o`0000Cooooo
0_l00007ooooo`03o`000?oooooooooo0?ooooooHOooool00ol0003oooooooooo`09ooooo`003?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`3oooooof7ooooo00?o0000ooooooooool02Oooool000cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00006ooooo`?o0000;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0]ooooo`Co00002oooool0
00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Koooooool0001Uo`0000_ooooo000;ooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`000?ooooooM_ooool000cooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l0003oooooogOooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo001Aooooo`?o0000DOooool5o`00053ooooo0ol0001Cooooo`?o0000?Ooo
ool005;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0001?ooooo`05o`000?oo
ooooooooooooool00000Doooool00ol0003oooooooooo`0looooo`00D_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0C_ooool5o`0003gooooo001B
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0D?ooool2o`00057ooooo00Co0000
oooooooooooo0000?_ooool005;ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooo
oooo000005?ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00000nooooo`00DOooool2
o`0005;ooooo00Go0000ooooooooooooooooo`00001?ooooo`05o`000?ooooooooooooooool00000
D_ooool2o`0003kooooo001Booooo`03o`000?oooooooooo057ooooo0ol0001Aooooo`?o0000E?oo
ool00ol0003oooooooooo`0looooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.00675159, -8.76064, \
0.0118357, 0.469521}}],

Cell[BoxData[
    \(87.52193752193753`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #3 (8 clusters per band)", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 3;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8D7A45402B4C6E2D
685819402C465900
9D844B5635759140
6D7B312D36587728
98A162443B61763B
846F3E44123F5707
8A9D64455052963E
B8FF8DCF9ECADCA7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B29BC3C4B1EAAAA1
9990CAA3BFE7ABA8
554C56586274586E
24202402211F2C35
252E0C090A000819
4E5E362F341A301C
6E7E508661566C46
FFB4C0CCD0FDF1E4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C0A0623103C5124
1E00131000142309
311E2D16092A0803
6972753E4249210E
94CCB47F92853D45
BEFEFFC8F6C6AA81
99F1ECB6F0B4A883
977C6C8F928FB07E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5FCD19B3991EB71D
8DC00FE1713CDE17
B4921EFF4F60EC16
D05B34F529A2C50E
BA2E5BC305BB9B2D
A7107D9100BE602D
86239C5D18C53242
1A6B3C266F2A1E2E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4C547A839775671F
3F3A795E6A57471D
5F5FA587B2685A05
7138917B82534D03
5C266F86A183740F
592E745EA2656F18
6C2C7C7C86754400
F7CBFFF1FFEDCDC8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
24252A24241B1A13
12090C060B00120C
162516231823201D
1F202E353B3B3E30
22282E38343A3A2D
201519181C1C1F18
19151117121E1419
B8E5FFDDE0C5C786
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2589980D9A4A2050
19C88A1CCC3F4655
1AEB7B46EB237E4D
27FF437AF006B249
3ACB2BA2C51ADD1C
549606A58D1BD117
686302A54F2BBB00
2D1D502508482213
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C01D7D7C0B9A3732
D11FBD8E37D1385A
B430EA715AFF298C
8E28F44F75EA22B1
543CB82785AD18AE
132E80007A751596
105246016A39156B
5724214B2914420A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool7ohf=S@OoNWYj1om5ADD7od10@0Ko:b/[1om<C4`7ofi^KPKo
;Bd]1Oooool7ok:b/POoVi^K1oo3`l<7olC4a0Oo/K6a1_oZj^X7ojZZZPKoXJ6Q1Oooool7o``<30Oo
2PX:1ol61PH7ob<S8`Oo410@1oll?3`6oe5AD@Ko92@T1_ooool6oemOG`OocLg=1olI6AT7ok>c/`Oo
VIVI1olN7Qh6okNg]`Ko7AdM1_ooool7oda<C0KoE5AD1omjNWX7oh>3P`OoUiNG1omeMGD7ofMWI`Go
7alO1_ooool7ob@T90Oo9BDU1_lZ:RX>ob@T90Oo6a/K1olJ6QX6oa<C4`Gooooo1olU9BD7ohV9R@Ko
V9RH1ol=3@d7oiZJVPOoBTY:1olP8206oe1@D0Gooooo1oo0`<07oadM7@OoOGem1_mlO7`7o`/;2`Oo
VYZJ1olg=cL6oc8b<Q7ooooo000?ooooo`OoSHf=1omjNWX7odE5A@Oo@4101_l[:b/7oda<C0OoKVi^
1_l];Bd5ooooo`Oo/[:b1onKVi/7ol?3``Ooa<C41ona/K46on[ZjPOoZZZZ1_nQXJ45ooooo`Oo30`<
1ol:2PX7o`H61POo8b<S1ol@4107oc`l?0KoDE5A1_lT92@6ooooo`KoGemO1oo=cLd7oaTI6@Oo/k>c
1onIVIT7oahN7PKo]kNg1_lM7Ad6ooooo`OoC4a<1_mDE5@7ogYjNPOoPh>31onGUiL7ogEeM@OoIfMW
1OlO7al6ooooo`Oo92@T1olU9BD6obXZ:Pko92@T1olK6a/7oaXJ6PKo4a<C1Oooool7obDU9@OoRHV9
1_nHV9P7o`d=3@OoVYZJ1om:BTX7ob0P80KoD51@1Oooool7ol30`0Oo7AdM1ommOGd6ogalO0Oo2`/;
1onJVYX7ocLg=`Ko<S8b4Oooool000oooooo1on=SHd7ogYjNPOoADE51om0@406ob/[:`OoC4a<1om^
KVh6obd];@Gooooo1onb/[87oi^KV`Oo`l?31oo4a<@7ok6a/@Koj^[Z1onZZZX6oj6QX@Gooooo1ol<
30`7o`X:2POo1PH61olS8b<7oa0@40Oo?3`l1_mADE46ob@T90Kooooo1_mOGel7olg=c@Oo6ATI1onc
/k<7oiVIV@Oo7QhN1_ng]kL6oadM7@Kooooo1om<C4`6oeADE0OoNWYj1on3Ph<7oiNGU`OoMGEe1omW
IfL5oalO7`Kooooo1olT92@7obDU9@Ko:RXZ3_lT92@7oa/K6`Oo6QXJ1_lC4a<5ooooo`Oo9BDU1on9
RHT6oiRHV0Oo3@d=1onJVYX7odY:BPOo820P1_m@D505ooooo`Oo`<301olM7Ad7ogemO@KoO7al1ol;
2`/7oiZJVPOo=cLg1_lb<S8Aooooo`003oooool7ohf=S@OoNWYj1om5ADD7od10@0Ko:b/[1om<C4`7
ofi^KPKo;Bd]1Oooool7ok:b/POoVi^K1oo3`l<7olC4a0Oo/K6a1_oZj^X7ojZZZPKoXJ6Q1Oooool7
o``<30Oo2PX:1ol61PH7ob<S8`Oo410@1oll?3`6oe5AD@Ko92@T1_ooool6oemOG`OocLg=1olI6AT7
ok>c/`OoVIVI1olN7Qh6okNg]`Ko7AdM1_ooool7oda<C0KoE5AD1omjNWX7oh>3P`OoUiNG1omeMGD7
ofMWI`Go7alO1_ooool7ob@T90Oo9BDU1_lZ:RX>ob@T90Oo6a/K1olJ6QX6oa<C4`Gooooo1olU9BD7
ohV9R@KoV9RH1ol=3@d7oiZJVPOoBTY:1olP8206oe1@D0Gooooo1oo0`<07oadM7@OoOGem1_mlO7`7
o`/;2`OoVYZJ1olg=cL6oc8b<Q7ooooo000?ooooo`OoSHf=1omjNWX7odE5A@Oo@4101_l[:b/7oda<
C0OoKVi^1_l];Bd5ooooo`Oo/[:b1onKVi/7ol?3``Ooa<C41ona/K46on[ZjPOoZZZZ1_nQXJ45oooo
o`Oo30`<1ol:2PX7o`H61POo8b<S1ol@4107oc`l?0KoDE5A1_lT92@6ooooo`KoGemO1oo=cLd7oaTI
6@Oo/k>c1onIVIT7oahN7PKo]kNg1_lM7Ad6ooooo`OoC4a<1_mDE5@7ogYjNPOoPh>31onGUiL7ogEe
M@OoIfMW1OlO7al6ooooo`Oo92@T1olU9BD6obXZ:Pko92@T1olK6a/7oaXJ6PKo4a<C1Oooool7obDU
9@OoRHV91_nHV9P7o`d=3@OoVYZJ1om:BTX7ob0P80KoD51@1Oooool7ol30`0Oo7AdM1ommOGd6ogal
O0Oo2`/;1onJVYX7ocLg=`Ko<S8b4Oooool000oooooo1on=SHd7ogYjNPOoADE51om0@406ob/[:`Oo
C4a<1om^KVh6obd];@Gooooo1onb/[87oi^KV`Oo`l?31oo4a<@7ok6a/@Koj^[Z1onZZZX6oj6QX@Go
oooo1ol<30`7o`X:2POo1PH61olS8b<7oa0@40Oo?3`l1_mADE46ob@T90Kooooo1_mOGel7olg=c@Oo
6ATI1onc/k<7oiVIV@Oo7QhN1_ng]kL6oadM7@Kooooo1om<C4`6oeADE0OoNWYj1on3Ph<7oiNGU`Oo
MGEe1omWIfL5oalO7`Kooooo1olT92@7obDU9@Ko:RXZ3_lT92@7oa/K6`Oo6QXJ1_lC4a<5ooooo`Oo
9BDU1on9RHT6oiRHV0Oo3@d=1onJVYX7odY:BPOo820P1_m@D505ooooo`Oo`<301olM7Ad7ogemO@Ko
O7al1ol;2`/7oiZJVPOo=cLg1_lb<S8Aooooo`003oooool7ohf=S@OoNWYj1om5ADD7od10@0Ko:b/[
1om<C4`7ofi^KPKo;Bd]1Oooool7ok:b/POoVi^K1oo3`l<7olC4a0Oo/K6a1_oZj^X7ojZZZPKoXJ6Q
1Oooool7o``<30Oo2PX:1ol61PH7ob<S8`Oo410@1oll?3`6oe5AD@Ko92@T1_ooool6oemOG`OocLg=
1olI6AT7ok>c/`OoVIVI1olN7Qh6okNg]`Ko7AdM1_ooool7oda<C0KoE5AD1omjNWX7oh>3P`OoUiNG
1omeMGD7ofMWI`Go7alO1_ooool7ob@T90Oo9BDU1_lZ:RX>ob@T90Oo6a/K1olJ6QX6oa<C4`Gooooo
1olU9BD7ohV9R@KoV9RH1ol=3@d7oiZJVPOoBTY:1olP8206oe1@D0Gooooo1oo0`<07oadM7@OoOGem
1_mlO7`7o`/;2`OoVYZJ1olg=cL6oc8b<Q7ooooo000?ooooo`OoJ6QX1omHF5P7oaTI6@Oo@4101_l/
;2`7odI6APOoFEUI1_l00005ooooo`OoVIVI1on@T907ol[:bPOoXj>S1ono_kl6onOWi`OoZj^[1_nX
Z:P5ooooo`Oo7QhN1ol00007oa<C4`Oo410@1ol00007oa@D50Ko8b<S1_l92@T6ooooo`KoSHf=1oo0
`<07o`l?3`OohN7Q1omaLG47oc`l?0Kog]kN1_lG5aL6ooooo`Oo?clo1_lj>SX7ogUiN@OoGUiN1omZ
JVX7oeMGE`OoAdM71OlM7Ad6ooooo`Oo4Q8B1ol92@T6o``<30Oo1PH61ol;2`/7o`0000Oo4Q8B1_l<
30`5ooooo`Oo6ATI1oo8b<P6ohZ:RPOo71`L1oo<c<`7oclo?`OoATI61_mEEED5ooooo`OodM7A1olO
7al7okfm_@KoSXj>1olg=cL7om7Ad@Oo>3Ph1_mJFUXAooooo`003oooool7ofQXJ0OoF5QH1olI6AT7
od10@0Ko;2`/1om6ATH7oeUIF@Ko00001Oooool7oiVIV@OoT92@1oo:b/X7oj>SX`Oo_kno1_oWinL7
oj^[Z`KoZ:RX1Oooool7oahN7POo00001olC4a<7oa0@40Oo00001olD51@6ob<S8`Ko2@T91_ooool6
ohf=S@Oo`<301ol?3`l7on7Qh@OoLG5a1oll?3`6omkNgPKo5aLG1_ooool7oclo?`Ko>SXj1omiNGT7
oeiNGPOoJVYZ1omGEeL7odM7A`Go7AdM1_ooool7oa8B4POo2@T91_l<30`7o`H61POo2`/;1ol00007
oa8B4PKo30`<1Oooool7oaTI6@Oob<S81_n:RXX7oa`L70Ooc<c<1olo?cl7odI6APKoEEEE1Oooool7
om7Ad@Oo7alO1onm_Kd6ohj>SPOo=cLg1ooAdM47ocPh>0KoFUYJ4Oooool000oooooo1omXJ6P7oeQH
F0Oo6ATI1om0@406ob`/;0OoATI61omIFET6o`0000Gooooo1onIVIT7oi2@T0Oob/[:1onSXj<7okno
_`KoinOW1on[Zj/6ojRXZ0Gooooo1olN7Qh7o`0000Oo4a<C1ol@4107o`0000Oo51@D1_lS8b<6o`T9
2@Kooooo1_n=SHd7ol30`0Oo3`l?1ooQhN47og5aL@Oo?3`l1_oNg]h6oaLG5`Kooooo1olo?cl6ocXj
>POoNGUi1omNGUh7ofYZJPOoEeMG1om7AdL5oadM7@Kooooo1olB4Q87o`T92@Ko30`<1ol61PH7o`/;
2`Oo00001olB4Q86o``<30Gooooo1olI6AT7olS8b0KoRXZ:1olL71`7olc<c0Oo?clo1om6ATH6oeEE
E@Gooooo1ooAdM47oalO7`Oo_Kfm1_n>SXh7ocLg=`OodM7A1olh>3P6oeYJFQ7ooooo000?ooooo`Oo
J6QX1omHF5P7oaTI6@Oo@4101_l/;2`7odI6APOoFEUI1_l00005ooooo`OoVIVI1on@T907ol[:bPOo
Xj>S1ono_kl6onOWi`OoZj^[1_nXZ:P5ooooo`Oo7QhN1ol00007oa<C4`Oo410@1ol00007oa@D50Ko
8b<S1_l92@T6ooooo`KoSHf=1oo0`<07o`l?3`OohN7Q1omaLG47oc`l?0Kog]kN1_lG5aL6ooooo`Oo
?clo1_lj>SX7ogUiN@OoGUiN1omZJVX7oeMGE`OoAdM71OlM7Ad6ooooo`Oo4Q8B1ol92@T6o``<30Oo
1PH61ol;2`/7o`0000Oo4Q8B1_l<30`5ooooo`Oo6ATI1oo8b<P6ohZ:RPOo71`L1oo<c<`7oclo?`Oo
ATI61_mEEED5ooooo`OodM7A1olO7al7okfm_@KoSXj>1olg=cL7om7Ad@Oo>3Ph1_mJFUXAooooo`00
3oooool7ofQXJ0OoF5QH1olI6AT7od10@0Ko;2`/1om6ATH7oeUIF@Ko00001Oooool7oiVIV@OoT92@
1oo:b/X7oj>SX`Oo_kno1_oWinL7oj^[Z`KoZ:RX1Oooool7oahN7POo00001olC4a<7oa0@40Oo0000
1olD51@6ob<S8`Ko2@T91_ooool6ohf=S@Oo`<301ol?3`l7on7Qh@OoLG5a1oll?3`6omkNgPKo5aLG
1_ooool7oclo?`Ko>SXj1omiNGT7oeiNGPOoJVYZ1omGEeL7odM7A`Go7AdM1_ooool7oa8B4POo2@T9
1_l<30`7o`H61POo2`/;1ol00007oa8B4PKo30`<1Oooool7oaTI6@Oob<S81_n:RXX7oa`L70Ooc<c<
1olo?cl7odI6APKoEEEE1Oooool7om7Ad@Oo7alO1onm_Kd6ohj>SPOo=cLg1ooAdM47ocPh>0KoFUYJ
4Oooool000oooooo1omXJ6P7oeQHF0Oo6ATI1om0@406ob`/;0OoATI61omIFET6o`0000Gooooo1onI
VIT7oi2@T0Oob/[:1onSXj<7okno_`KoinOW1on[Zj/6ojRXZ0Gooooo1olN7Qh7o`0000Oo4a<C1ol@
4107o`0000Oo51@D1_lS8b<6o`T92@Kooooo1_n=SHd7ol30`0Oo3`l?1ooQhN47og5aL@Oo?3`l1_oN
g]h6oaLG5`Kooooo1olo?cl6ocXj>POoNGUi1omNGUh7ofYZJPOoEeMG1om7AdL5oadM7@Kooooo1olB
4Q87o`T92@Ko30`<1ol61PH7o`/;2`Oo00001olB4Q86o``<30Gooooo1olI6AT7olS8b0KoRXZ:1olL
71`7olc<c0Oo?clo1om6ATH6oeEEE@Gooooo1ooAdM47oalO7`Oo_Kfm1_n>SXh7ocLg=`OodM7A1olh
>3P6oeYJFQ7ooooo000?ooooo`OoJ6QX1omHF5P7oaTI6@Oo@4101_l/;2`7odI6APOoFEUI1_l00005
ooooo`OoVIVI1on@T907ol[:bPOoXj>S1ono_kl6onOWi`OoZj^[1_nXZ:P5ooooo`Oo7QhN1ol00007
oa<C4`Oo410@1ol00007oa@D50Ko8b<S1_l92@T6ooooo`KoSHf=1oo0`<07o`l?3`OohN7Q1omaLG47
oc`l?0Kog]kN1_lG5aL6ooooo`Oo?clo1_lj>SX7ogUiN@OoGUiN1omZJVX7oeMGE`OoAdM71OlM7Ad6
ooooo`Oo4Q8B1ol92@T6o``<30Oo1PH61ol;2`/7o`0000Oo4Q8B1_l<30`5ooooo`Oo6ATI1oo8b<P6
ohZ:RPOo71`L1oo<c<`7oclo?`OoATI61_mEEED5ooooo`OodM7A1olO7al7okfm_@KoSXj>1olg=cL7
om7Ad@Oo>3Ph1_mJFUXAooooo`003oooool7oifMW@OoQ8B41om;Bd/7oeIFEPKo=CDe1omeMGD7oi6A
T@Ko@4101Oooool7oeEEE@OoC4a<1omFEUH7oeQHF0OoHV9R1_mdM7@7oeQHF0KoKVi^1Oooool7oc4a
<@Oo7QhN1ol];Bd7oaHF5POo2@T91olZ:RX6o`P820Ko0`<31_ooool6okBd]0OoTY:B1olN7Qh7oooo
o`OoCdm?1omPH606onc/k0Ko5QHF1_ooool=oemOG`OoYJFU1on7QhL7ok:b/POoJ6QX1omJFUX5o`D5
1@Kooooo1olF5QH7obDU9@Ko5QHF1olS8b<7oaPH60Oo8b<S1olP8206oadM7@Gooooo1olJ6QX7on_[
j`KoNg]k1om6ATH7on_[j`Oo8b<S1omnOWh6ode=C@Gooooo1ond];@7oc0`<0Ooj^[Z1_maLG47oeYJ
FPOooooo1olY:BT6ohb<S17ooooo000?ooooo`OoWIfM1on4Q8@7od];B`OoEUIF1_le=CD7ogEeM@Oo
TI6A1_m0@405ooooo`OoEEEE1om<C4`7oeIFEPOoF5QH1omRHV86ogAdM0OoF5QH1_m^KVh5ooooo`Oo
<C4a1olN7Qh7obd];@Oo5QHF1ol92@T7obXZ:PKo20P81_l30`<6ooooo`Ko];Bd1onBTY87oahN7POo
oooo1om?Cdl7of1PH0Kok>c/1_lF5QH6ooooo`goGemO1onUYJD7ohN7Q`Oo/[:b1omXJ6P7oeYJFPGo
1@D51_ooool7oaHF5POo9BDU1_lF5QH7ob<S8`Oo61PH1olS8b<7ob0P80Ko7AdM1Oooool7oaXJ6POo
jn_[1_mkNg/7odI6APOojn_[1olS8b<7oginOPKoCDe=1Oooool7okBd]0Oo<30`1ooZj^X6og5aL@Oo
FUYJ1oooool7obTY:@KoS8b<4Oooool000oooooo1onMWId7ohB4Q0OoBd];1omFEUH6ocDe=@OoMGEe
1onATI46od10@0Gooooo1omEEED7oda<C0OoEUIF1omHF5P7of9RHPKoM7Ad1omHF5P6ofi^KPGooooo
1ola<C47oahN7POo;Bd]1olF5QH7o`T92@Oo:RXZ1_l820P6o`<30`Kooooo1_nd];@7oi:BTPOo7QhN
1oooool7odm?C`OoH61P1_o/k>`6oaHF5PKooooo3OmOGel7ojFUY@OoQhN71onb/[87ofQXJ0OoFUYJ
1Ol51@D6ooooo`Oo5QHF1olU9BD6oaHF5POo8b<S1olH61P7ob<S8`Oo820P1_lM7Ad5ooooo`Oo6QXJ
1oo[jn/6og]kN`OoATI61oo[jn/7ob<S8`OoOWin1_m=CDd5ooooo`Oo];Bd1ol`<307on[ZjPKoLG5a
1omJFUX7ooooo`Oo:BTY1_n<S8`Aooooo`003oooool7oifMW@OoQ8B41om;Bd/7oeIFEPKo=CDe1ome
MGD7oi6AT@Ko@4101Oooool7oeEEE@OoC4a<1omFEUH7oeQHF0OoHV9R1_mdM7@7oeQHF0KoKVi^1Ooo
ool7oc4a<@Oo7QhN1ol];Bd7oaHF5POo2@T91olZ:RX6o`P820Ko0`<31_ooool6okBd]0OoTY:B1olN
7Qh7ooooo`OoCdm?1omPH606onc/k0Ko5QHF1_ooool=oemOG`OoYJFU1on7QhL7ok:b/POoJ6QX1omJ
FUX5o`D51@Kooooo1olF5QH7obDU9@Ko5QHF1olS8b<7oaPH60Oo8b<S1olP8206oadM7@Gooooo1olJ
6QX7on_[j`KoNg]k1om6ATH7on_[j`Oo8b<S1omnOWh6ode=C@Gooooo1ond];@7oc0`<0Ooj^[Z1_ma
LG47oeYJFPOooooo1olY:BT6ohb<S17ooooo000?ooooo`OoWIfM1on4Q8@7od];B`OoEUIF1_le=CD7
ogEeM@OoTI6A1_m0@405ooooo`OoEEEE1om<C4`7oeIFEPOoF5QH1omRHV86ogAdM0OoF5QH1_m^KVh5
ooooo`Oo<C4a1olN7Qh7obd];@Oo5QHF1ol92@T7obXZ:PKo20P81_l30`<6ooooo`Ko];Bd1onBTY87
oahN7POooooo1om?Cdl7of1PH0Kok>c/1_lF5QH6ooooo`goGemO1onUYJD7ohN7Q`Oo/[:b1omXJ6P7
oeYJFPGo1@D51_ooool7oaHF5POo9BDU1_lF5QH7ob<S8`Oo61PH1olS8b<7ob0P80Ko7AdM1Oooool7
oaXJ6POojn_[1_mkNg/7odI6APOojn_[1olS8b<7oginOPKoCDe=1Oooool7okBd]0Oo<30`1ooZj^X6
og5aL@OoFUYJ1oooool7obTY:@KoS8b<4Oooool000oooooo1onMWId7ohB4Q0OoBd];1omFEUH6ocDe
=@OoMGEe1onATI46od10@0Gooooo1omEEED7oda<C0OoEUIF1omHF5P7of9RHPKoM7Ad1omHF5P6ofi^
KPGooooo1ola<C47oahN7POo;Bd]1olF5QH7o`T92@Oo:RXZ1_l820P6o`<30`Kooooo1_nd];@7oi:B
TPOo7QhN1oooool7odm?C`OoH61P1_o/k>`6oaHF5PKooooo3OmOGel7ojFUY@OoQhN71onb/[87ofQX
J0OoFUYJ1Ol51@D6ooooo`Oo5QHF1olU9BD6oaHF5POo8b<S1olH61P7ob<S8`Oo820P1_lM7Ad5oooo
o`Oo6QXJ1oo[jn/6og]kN`OoATI61oo[jn/7ob<S8`OoOWin1_m=CDd5ooooo`Oo];Bd1ol`<307on[Z
jPKoLG5a1omJFUX7ooooo`Oo:BTY1_n<S8`Aooooo`003oooool7ofe]K@OoNg]k1ola<C47obd];@Ko
=SHf1omHF5P7ogMgM`Ko:2PX1Oooool7ob@T90Oo820P1olT92@7o`820POo8B4Q1_lO7al7ob`/;0Ko
=CDe1Oooool7ofUYJ@OoLW9b1omeMGD7ochn?POo@T921om9BDT6ob4Q8@Ko3Ph>1_ooool6om3@d0Oo
Fe]K1old=3@7ooGem@Oo:BTY1onRXZ86olG5a@Ko3Ph>1_ooool7og5aL@Ko>3Ph1onATI47og]kN`Oo
PX:21omCDe<7ode=C@Go0`<31_ooool7oalO7`Oo820P1_l^;Rh7ocDe=@ko>c/k1oln?Sh6oc0`<0Go
oooo1olW9bL7ooooo`Ko@d=31omjNWX7oo3`l0Oo1PH61onb/[86odU9B@Gooooo1on>SXh7obPX:0Oo
m?Cd1_m?Cdl7ogEeM@Ooj^[Z1olR8R86ok6a/A7ooooo000?ooooo`OoKFe]1omkNg/7oc4a<@Oo;Bd]
1_lf=SH7oeQHF0OoMgMg1_lX:2P5ooooo`Oo92@T1olP8207ob@T90Oo0P821olQ8B46oalO7`Oo;2`/
1_le=CD5ooooo`OoJFUY1ombLW87ogEeM@Oo?Shn1om2@T87odU9B@Ko8B4Q1_l>3Ph6ooooo`Kod=3@
1omKFe/7oc@d=0OomOGe1olY:BT7oj:RXPKoaLG51_l>3Ph6ooooo`OoLG5a1_lh>3P7oi6AT@OoNg]k
1on2PX87oe=CD`OoCDe=1Ol30`<6ooooo`Oo7alO1olP8206obh^;POo=CDe3_lk>c/7ochn?PKo<30`
1Oooool7obLW9`Oooooo1_m3@d<7ogYjNPOol?3`1ol61PH7ok:b/PKoBDU91Oooool7ohj>SPOo:2PX
1oodm?@6odm?C`OoMGEe1ooZj^X7ob8R8PKo/K6a4Oooool000oooooo1om]KFd7og]kN`Oo<C4a1ol]
;Bd6ocHf=POoF5QH1omgMgL6obPX:0Gooooo1olT92@7ob0P80Oo92@T1ol20P87ob4Q8@Ko7alO1ol/
;2`6ocDe=@Gooooo1omYJFT7og9bLPOoMGEe1oln?Sh7od92@POoBDU91_lQ8B46o`h>3PKooooo1_o@
d=07oe]KF`Oo=3@d1ooemOD7obTY:@OoXZ:R1_o5aLD6o`h>3PKooooo1omaLG46ocPh>0OoTI6A1omk
Ng/7oh:2PPOoDe=C1om=CDd5o`<30`Kooooo1olO7al7ob0P80Ko;Rh^1ole=CD>oc/k>`Oo?Shn1_l`
<305ooooo`Oo9bLW1oooool6od=3@`OoNWYj1oo`l?07o`H61POo/[:b1_m9BDT5ooooo`OoSXj>1olX
:2P7ooCdm0KoCdm?1omeMGD7on[ZjPOo8R8R1_na/K4Aooooo`003oooool7ofe]K@OoNg]k1ola<C47
obd];@Ko=SHf1omHF5P7ogMgM`Ko:2PX1Oooool7ob@T90Oo820P1olT92@7o`820POo8B4Q1_lO7al7
ob`/;0Ko=CDe1Oooool7ofUYJ@OoLW9b1omeMGD7ochn?POo@T921om9BDT6ob4Q8@Ko3Ph>1_ooool6
om3@d0OoFe]K1old=3@7ooGem@Oo:BTY1onRXZ86olG5a@Ko3Ph>1_ooool7og5aL@Ko>3Ph1onATI47
og]kN`OoPX:21omCDe<7ode=C@Go0`<31_ooool7oalO7`Oo820P1_l^;Rh7ocDe=@ko>c/k1oln?Sh6
oc0`<0Gooooo1olW9bL7ooooo`Ko@d=31omjNWX7oo3`l0Oo1PH61onb/[86odU9B@Gooooo1on>SXh7
obPX:0Oom?Cd1_m?Cdl7ogEeM@Ooj^[Z1olR8R86ok6a/A7ooooo000?ooooo`OoKFe]1omkNg/7oc4a
<@Oo;Bd]1_lf=SH7oeQHF0OoMgMg1_lX:2P5ooooo`Oo92@T1olP8207ob@T90Oo0P821olQ8B46oalO
7`Oo;2`/1_le=CD5ooooo`OoJFUY1ombLW87ogEeM@Oo?Shn1om2@T87odU9B@Ko8B4Q1_l>3Ph6oooo
o`Kod=3@1omKFe/7oc@d=0OomOGe1olY:BT7oj:RXPKoaLG51_l>3Ph6ooooo`OoLG5a1_lh>3P7oi6A
T@OoNg]k1on2PX87oe=CD`OoCDe=1Ol30`<6ooooo`Oo7alO1olP8206obh^;POo=CDe3_lk>c/7ochn
?PKo<30`1Oooool7obLW9`Oooooo1_m3@d<7ogYjNPOol?3`1ol61PH7ok:b/PKoBDU91Oooool7ohj>
SPOo:2PX1oodm?@6odm?C`OoMGEe1ooZj^X7ob8R8PKo/K6a4Oooool000oooooo1om]KFd7og]kN`Oo
<C4a1ol];Bd6ocHf=POoF5QH1omgMgL6obPX:0Gooooo1olT92@7ob0P80Oo92@T1ol20P87ob4Q8@Ko
7alO1ol/;2`6ocDe=@Gooooo1omYJFT7og9bLPOoMGEe1oln?Sh7od92@POoBDU91_lQ8B46o`h>3PKo
oooo1_o@d=07oe]KF`Oo=3@d1ooemOD7obTY:@OoXZ:R1_o5aLD6o`h>3PKooooo1omaLG46ocPh>0Oo
TI6A1omkNg/7oh:2PPOoDe=C1om=CDd5o`<30`Kooooo1olO7al7ob0P80Ko;Rh^1ole=CD>oc/k>`Oo
?Shn1_l`<305ooooo`Oo9bLW1oooool6od=3@`OoNWYj1oo`l?07o`H61POo/[:b1_m9BDT5ooooo`Oo
SXj>1olX:2P7ooCdm0KoCdm?1omeMGD7on[ZjPOo8R8R1_na/K4Aooooo`003oooool7ofe]K@OoNg]k
1ola<C47obd];@Ko=SHf1omHF5P7ogMgM`Ko:2PX1Oooool7ob@T90Oo820P1olT92@7o`820POo8B4Q
1_lO7al7ob`/;0Ko=CDe1Oooool7ofUYJ@OoLW9b1omeMGD7ochn?POo@T921om9BDT6ob4Q8@Ko3Ph>
1_ooool6om3@d0OoFe]K1old=3@7ooGem@Oo:BTY1onRXZ86olG5a@Ko3Ph>1_ooool7og5aL@Ko>3Ph
1onATI47og]kN`OoPX:21omCDe<7ode=C@Go0`<31_ooool7oalO7`Oo820P1_l^;Rh7ocDe=@ko>c/k
1oln?Sh6oc0`<0Gooooo1olW9bL7ooooo`Ko@d=31omjNWX7oo3`l0Oo1PH61onb/[86odU9B@Gooooo
1on>SXh7obPX:0Oom?Cd1_m?Cdl7ogEeM@Ooj^[Z1olR8R86ok6a/A7ooooo000?ooooo`OoV9RH1onQ
XJ47of9RHPOoA4A41_lk>c/7of5QH@OoMWIf1_lk>c/5ooooo`Oo9BDU1ol^;Rh7o``<30Oo2@T91ol:
2PX6o`0000Oo20P81_lI6AT5ooooo`OoU9BD1oo<c<`7okBd]0OoOgmo1onBTY87ohF5Q@Ko?Cdm1_m5
ADD6ooooo`Ko^[Zj1ol^;Rh7oe]KF`Oo`l?31ol51@D7ok^k^`KoVi^K1_l];Bd6ooooo`OoG5aL1_lV
9RH7ofm_K`OoQXJ61onQXJ47oh>3P`OoM7Ad1Ol?3`l6ooooo`Oo8R8R1olX:2P6obh^;POo>3Ph1old
=3@>ocXj>PKo;Bd]1Oooool7ocXj>POobl_;1_l[:b/7oj:RXPOoaLG51olJ6QX7omgMg@Ko71`L1Ooo
ool7oeADE0Oo?3`l1onh^;P6obLW9`OoQHF51on][Jd7oaPH60Ko[Zj^4Oooool000oooooo1onHV9P7
oj6QX@OoHV9R1om4A4@6oc/k>`OoHF5Q1omfMWH6oc/k>`Gooooo1olU9BD7obh^;POo30`<1ol92@T7
o`X:2PKo00001ol820P6oaTI6@Gooooo1onDU9@7olc<c0Oo];Bd1omoOgl7oi:BTPOoQHF51_lm?Cd6
odE5A@Kooooo1_nj^[X7obh^;POoFe]K1oo3`l<7o`D51@Oo^k^k1_nKVi/6obd];@Kooooo1omLG5`6
obHV9POoKfm_1on6QXH7oj6QX@OoPh>31omdM7@5o`l?3`Kooooo1olR8R87obPX:0Ko;Rh^1olh>3P7
oc@d=0ko>SXj1_l];Bd5ooooo`Oo>SXj1oo;bl/6ob/[:`OoXZ:R1oo5aLD7oaXJ6POogMgM1_lL71`5
ooooo`OoE5AD1oll?3`7okRh^0Ko9bLW1on5QHD7ojf][@Oo61PH1_n^[ZhAooooo`003oooool7oiRH
V0OoXJ6Q1omRHV87odA4A0Ko>c/k1omQHF47ogIfMPKo>c/k1Oooool7obDU9@Oo;Rh^1ol<30`7o`T9
2@Oo2PX:1_l00007o`P820Ko6ATI1Oooool7oiBDU0Ooc<c<1ond];@7ogmoO`OoTY:B1on5QHD6ocdm
?@KoADE51_ooool6okZj^POo;Rh^1omKFe/7ol?3``Oo1@D51onk^k/6oi^KV`Ko;Bd]1_ooool7oeaL
G0Ko9RHV1om_Kfl7ohJ6QPOoXJ6Q1on3Ph<7ogAdM0Go3`l?1_ooool7ob8R8POo:2PX1_l^;Rh7ocPh
>0Oo=3@d3_lj>SX6obd];@Gooooo1olj>SX7ol_;b`Ko:b/[1onRXZ87olG5a@Oo6QXJ1ooMgMd6oa`L
70Gooooo1omDE5@7oc`l?0Oo^;Rh1_lW9bL7ohF5Q@Oo[Jf]1olH61P6ojj^[Q7ooooo000?ooooo`Oo
V9RH1onQXJ47of9RHPOoA4A41_lk>c/7of5QH@OoMWIf1_lk>c/5ooooo`Oo9BDU1ol^;Rh7o``<30Oo
2@T91ol:2PX6o`0000Oo20P81_lI6AT5ooooo`OoU9BD1oo<c<`7okBd]0OoOgmo1onBTY87ohF5Q@Ko
?Cdm1_m5ADD6ooooo`Ko^[Zj1ol^;Rh7oe]KF`Oo`l?31ol51@D7ok^k^`KoVi^K1_l];Bd6ooooo`Oo
G5aL1_lV9RH7ofm_K`OoQXJ61onQXJ47oh>3P`OoM7Ad1Ol?3`l6ooooo`Oo8R8R1olX:2P6obh^;POo
>3Ph1old=3@>ocXj>PKo;Bd]1Oooool7ocXj>POobl_;1_l[:b/7oj:RXPOoaLG51olJ6QX7omgMg@Ko
71`L1Oooool7oeADE0Oo?3`l1onh^;P6obLW9`OoQHF51on][Jd7oaPH60Ko[Zj^4Oooool000oooooo
1onHV9P7oj6QX@OoHV9R1om4A4@6oc/k>`OoHF5Q1omfMWH6oc/k>`Gooooo1olU9BD7obh^;POo30`<
1ol92@T7o`X:2PKo00001ol820P6oaTI6@Gooooo1onDU9@7olc<c0Oo];Bd1omoOgl7oi:BTPOoQHF5
1_lm?Cd6odE5A@Kooooo1_nj^[X7obh^;POoFe]K1oo3`l<7o`D51@Oo^k^k1_nKVi/6obd];@Kooooo
1omLG5`6obHV9POoKfm_1on6QXH7oj6QX@OoPh>31omdM7@5o`l?3`Kooooo1olR8R87obPX:0Ko;Rh^
1olh>3P7oc@d=0ko>SXj1_l];Bd5ooooo`Oo>SXj1oo;bl/6ob/[:`OoXZ:R1oo5aLD7oaXJ6POogMgM
1_lL71`5ooooo`OoE5AD1oll?3`7okRh^0Ko9bLW1on5QHD7ojf][@Oo61PH1_n^[ZhAooooo`003ooo
ool7oiRHV0OoXJ6Q1omRHV87odA4A0Ko>c/k1omQHF47ogIfMPKo>c/k1Oooool7obDU9@Oo;Rh^1ol<
30`7o`T92@Oo2PX:1_l00007o`P820Ko6ATI1Oooool7oiBDU0Ooc<c<1ond];@7ogmoO`OoTY:B1on5
QHD6ocdm?@KoADE51_ooool6okZj^POo;Rh^1omKFe/7ol?3``Oo1@D51onk^k/6oi^KV`Ko;Bd]1_oo
ool7oeaLG0Ko9RHV1om_Kfl7ohJ6QPOoXJ6Q1on3Ph<7ogAdM0Go3`l?1_ooool7ob8R8POo:2PX1_l^
;Rh7ocPh>0Oo=3@d3_lj>SX6obd];@Gooooo1olj>SX7ol_;b`Ko:b/[1onRXZ87olG5a@Oo6QXJ1ooM
gMd6oa`L70Gooooo1omDE5@7oc`l?0Oo^;Rh1_lW9bL7ohF5Q@Oo[Jf]1olH61P6ojj^[Q7ooooo000?
ooooo`OoQ8B41om_Kfl7ochn?POoA4A41_lB4Q87oclo?`OoEeMG1_l71`L5ooooo`OoCTi>1omNGUh7
ocHf=POo;bl_1old=3@6oaXJ6POo<30`1_lL71`5ooooo`Oo_[jn1oono_h7ooooo`Oob<S81oofm_H7
olK6aPKoZZZZ1_n1PH46ooooo`KoYjNW1ol@4107ogemO@OoTI6A1ol00007okjn_PKoH61P1_l];Bd6
ooooo`OoFEUI1_l^;Rh7ogAdM0OoGUiN1onRXZ87ofEUI@OoKfm_1OlH61P6ooooo`Oo820P1olE5AD6
oaTI6@Oo61PH3_lL71`7oalO7`Ko61PH1Oooool7oeADE0OoUYJF1_l61PH7ojFUY@OoSHf=1olK6a/7
om7Ad@Ko5aLG1Oooool7oa<C4`Oo;Rh^1on0P806o`0000OoNWYj1omeMGD7oaDE5@KoUYJF4Oooool0
00oooooo1on4Q8@7ofm_K`Oo?Shn1om4A4@6oa8B4POo?clo1omGEeL6o`L71`Gooooo1om>CTh7oeiN
GPOo=SHf1ol_;bl7oc@d=0Ko6QXJ1ol`<306oa`L70Gooooo1onn_[h7ooknoPOooooo1oo8b<P7ooKf
mPOoa/K61_nZZZX6oh61P@Kooooo1_nWYjL7oa0@40OoOGem1onATI47o`0000Oo_[jn1_mPH606obd]
;@Kooooo1omIFET6obh^;POoM7Ad1omNGUh7oj:RXPOoIFEU1om_Kfl5oaPH60Kooooo1olP8207oaDE
5@Ko6ATI1olH61P>oa`L70Oo7alO1_lH61P5ooooo`OoE5AD1onFUYH6o`H61POoYJFU1on=SHd7oa/K
6`OodM7A1_lG5aL5ooooo`Oo4a<C1ol^;Rh7oh20P0Ko00001omjNWX7ogEeM@Oo5ADE1_nFUYHAoooo
o`003oooool7ohB4Q0OoKfm_1oln?Sh7odA4A0Ko4Q8B1olo?cl7oeMGE`Ko1`L71Oooool7odi>CPOo
GUiN1olf=SH7obl_;`Oo=3@d1_lJ6QX7oc0`<0Ko71`L1Oooool7okjn_POoo_kn1oooool7olS8b0Oo
m_Kf1oo6a/H6ojZZZPKoPH611_ooool6ojNWY`Oo410@1ommOGd7oi6AT@Oo00001onn_[h6of1PH0Ko
;Bd]1_ooool7oeUIF@Ko;Rh^1omdM7@7oeiNGPOoXZ:R1omUIFD7ofm_K`Go61PH1_ooool7ob0P80Oo
5ADE1_lI6AT7oaPH60ko71`L1olO7al6oaPH60Gooooo1omDE5@7oiJFUPKo1PH61onUYJD7ohf=S@Oo
6a/K1ooAdM46oaLG5`Gooooo1olC4a<7obh^;POoP8201_l00007ogYjNPOoMGEe1olE5AD6oiJFUQ7o
oooo000?ooooo`OoQ8B41om_Kfl7ochn?POoA4A41_lB4Q87oclo?`OoEeMG1_l71`L5ooooo`OoCTi>
1omNGUh7ocHf=POo;bl_1old=3@6oaXJ6POo<30`1_lL71`5ooooo`Oo_[jn1oono_h7ooooo`Oob<S8
1oofm_H7olK6aPKoZZZZ1_n1PH46ooooo`KoYjNW1ol@4107ogemO@OoTI6A1ol00007okjn_PKoH61P
1_l];Bd6ooooo`OoFEUI1_l^;Rh7ogAdM0OoGUiN1onRXZ87ofEUI@OoKfm_1OlH61P6ooooo`Oo820P
1olE5AD6oaTI6@Oo61PH3_lL71`7oalO7`Ko61PH1Oooool7oeADE0OoUYJF1_l61PH7ojFUY@OoSHf=
1olK6a/7om7Ad@Ko5aLG1Oooool7oa<C4`Oo;Rh^1on0P806o`0000OoNWYj1omeMGD7oaDE5@KoUYJF
4Oooool000oooooo1on4Q8@7ofm_K`Oo?Shn1om4A4@6oa8B4POo?clo1omGEeL6o`L71`Gooooo1om>
CTh7oeiNGPOo=SHf1ol_;bl7oc@d=0Ko6QXJ1ol`<306oa`L70Gooooo1onn_[h7ooknoPOooooo1oo8
b<P7ooKfmPOoa/K61_nZZZX6oh61P@Kooooo1_nWYjL7oa0@40OoOGem1onATI47o`0000Oo_[jn1_mP
H606obd];@Kooooo1omIFET6obh^;POoM7Ad1omNGUh7oj:RXPOoIFEU1om_Kfl5oaPH60Kooooo1olP
8207oaDE5@Ko6ATI1olH61P>oa`L70Oo7alO1_lH61P5ooooo`OoE5AD1onFUYH6o`H61POoYJFU1on=
SHd7oa/K6`OodM7A1_lG5aL5ooooo`Oo4a<C1ol^;Rh7oh20P0Ko00001omjNWX7ogEeM@Oo5ADE1_nF
UYHAooooo`003oooool7ohB4Q0OoKfm_1oln?Sh7odA4A0Ko4Q8B1olo?cl7oeMGE`Ko1`L71Oooool7
odi>CPOoGUiN1olf=SH7obl_;`Oo=3@d1_lJ6QX7oc0`<0Ko71`L1Oooool7okjn_POoo_kn1oooool7
olS8b0Oom_Kf1oo6a/H6ojZZZPKoPH611_ooool6ojNWY`Oo410@1ommOGd7oi6AT@Oo00001onn_[h6
of1PH0Ko;Bd]1_ooool7oeUIF@Ko;Rh^1omdM7@7oeiNGPOoXZ:R1omUIFD7ofm_K`Go61PH1_ooool7
ob0P80Oo5ADE1_lI6AT7oaPH60ko71`L1olO7al6oaPH60Gooooo1omDE5@7oiJFUPKo1PH61onUYJD7
ohf=S@Oo6a/K1ooAdM46oaLG5`Gooooo1olC4a<7obh^;POoP8201_l00007ogYjNPOoMGEe1olE5AD6
oiJFUQ7ooooo000?ooooo`OoQ8B41om_Kfl7ochn?POoA4A41_lB4Q87oclo?`OoEeMG1_l71`L5oooo
o`OoCTi>1omNGUh7ocHf=POo;bl_1old=3@6oaXJ6POo<30`1_lL71`5ooooo`Oo_[jn1oono_h7oooo
o`Oob<S81oofm_H7olK6aPKoZZZZ1_n1PH46ooooo`KoYjNW1ol@4107ogemO@OoTI6A1ol00007okjn
_PKoH61P1_l];Bd6ooooo`OoFEUI1_l^;Rh7ogAdM0OoGUiN1onRXZ87ofEUI@OoKfm_1OlH61P6oooo
o`Oo820P1olE5AD6oaTI6@Oo61PH3_lL71`7oalO7`Ko61PH1Oooool7oeADE0OoUYJF1_l61PH7ojFU
Y@OoSHf=1olK6a/7om7Ad@Ko5aLG1Oooool7oa<C4`Oo;Rh^1on0P806o`0000OoNWYj1omeMGD7oaDE
5@KoUYJF4Oooool000oooooo1on:RXX7oifMW@OoI6AT1om5ADD6oe1@D0OoDU9B1onFUYH6ochn?PGo
oooo1om^KVh7oginOPOoD51@1on6QXH7of5QH@KoEUIF1om/K6`6odI6APGooooo1onIVIT7oo7al@Oo
k>c/1onf][H7oo3`l0Oo];Bd1_nXZ:P6oh>3P`Kooooo1_n6QXH7ob<S8`OoW9bL1omMGEd7oaPH60Oo
aLG51_lb<S86od92@PKooooo1om/K6`6ob`/;0koO7al1on6QXH7ogEeM@OoA4A41Ol00006ooooo`Oo
6ATI1olE5AD6oa4A4@Oo5aLG1olB4Q87oahN7POo51@D1_lI6AT5ooooo`OoJ6QX1omSHf<6o`820POo
YJFU1om?Cdl7ob/[:`Oo^k^k1_l00005ooooo`Oo410@1omBDU87odI6APKo0@411omZJVX7ocTi>@Oo
5ADE1_m[Jf/Aooooo`003oooool7ohZ:RPOoWIfM1omTI6@7odE5A@KoD51@1omBDU87oiJFUPKo?Shn
1Oooool7ofi^KPOoOWin1om@D507ohJ6QPOoHF5Q1_mFEUH7ofa/K0KoATI61Oooool7oiVIV@OolO7a
1oo/k>`7okJf]POol?3`1ond];@6ojRXZ0KoPh>31_ooool6ohJ6QPOo8b<S1onLW9`7oeeMG@Oo61PH
1oo5aLD6oc8b<PKo@T921_ooool7ofa/K0Ko;2`/3_mlO7`7ohJ6QPOoMGEe1om4A4@5o`0000Kooooo
1olI6AT7oaDE5@Ko4A4A1olG5aL7oa8B4POo7QhN1olD51@6oaTI6@Gooooo1omXJ6P7of=SH`Ko0P82
1onUYJD7odm?C`Oo:b/[1onk^k/6o`0000Gooooo1ol@4107oe9BDPOoATI61_l10@47ofYZJPOo>CTi
1olE5AD6of][Ja7ooooo000?ooooo`OoRXZ:1onMWId7ofATI0OoADE51_m@D507oe9BDPOoUYJF1_ln
?Sh5ooooo`OoKVi^1omnOWh7oe1@D0OoQXJ61omQHF46oeIFEPOoK6a/1_m6ATH5ooooo`OoVIVI1ooa
lO47onc/k0Oo][Jf1oo`l?07okBd]0KoZ:RX1_n3Ph<6ooooo`KoQXJ61olS8b<7oibLW0OoGEeM1olH
61P7olG5a@Ko<S8b1_m2@T86ooooo`OoK6a/1_l/;2`>ogalO0OoQXJ61omeMGD7odA4A0Go00001_oo
ool7oaTI6@Oo5ADE1_lA4A47oaLG5`Oo4Q8B1olN7Qh7oa@D50Ko6ATI1Oooool7ofQXJ0OoHf=S1_l2
0P87ojFUY@OoCdm?1ol[:b/7ok^k^`Ko00001Oooool7oa0@40OoDU9B1om6ATH6o`410@OoJVYZ1oli
>CT7oaDE5@KoJf][4Oooool000oooooo1on:RXX7oifMW@OoI6AT1om5ADD6oe1@D0OoDU9B1onFUYH6
ochn?PGooooo1om^KVh7oginOPOoD51@1on6QXH7of5QH@KoEUIF1om/K6`6odI6APGooooo1onIVIT7
oo7al@Ook>c/1onf][H7oo3`l0Oo];Bd1_nXZ:P6oh>3P`Kooooo1_n6QXH7ob<S8`OoW9bL1omMGEd7
oaPH60OoaLG51_lb<S86od92@PKooooo1om/K6`6ob`/;0koO7al1on6QXH7ogEeM@OoA4A41Ol00006
ooooo`Oo6ATI1olE5AD6oa4A4@Oo5aLG1olB4Q87oahN7POo51@D1_lI6AT5ooooo`OoJ6QX1omSHf<6
o`820POoYJFU1om?Cdl7ob/[:`Oo^k^k1_l00005ooooo`Oo410@1omBDU87odI6APKo0@411omZJVX7
ocTi>@Oo5ADE1_m[Jf/Aooooo`003oooool7ohZ:RPOoWIfM1omTI6@7odE5A@KoD51@1omBDU87oiJF
UPKo?Shn1Oooool7ofi^KPOoOWin1om@D507ohJ6QPOoHF5Q1_mFEUH7ofa/K0KoATI61Oooool7oiVI
V@OolO7a1oo/k>`7okJf]POol?3`1ond];@6ojRXZ0KoPh>31_ooool6ohJ6QPOo8b<S1onLW9`7oeeM
G@Oo61PH1oo5aLD6oc8b<PKo@T921_ooool7ofa/K0Ko;2`/3_mlO7`7ohJ6QPOoMGEe1om4A4@5o`00
00Kooooo1olI6AT7oaDE5@Ko4A4A1olG5aL7oa8B4POo7QhN1olD51@6oaTI6@Gooooo1omXJ6P7of=S
H`Ko0P821onUYJD7odm?C`Oo:b/[1onk^k/6o`0000Gooooo1ol@4107oe9BDPOoATI61_l10@47ofYZ
JPOo>CTi1olE5AD6of][Ja7ooooo000?ooooo`OoRXZ:1onMWId7ofATI0OoADE51_m@D507oe9BDPOo
UYJF1_ln?Sh5ooooo`OoKVi^1omnOWh7oe1@D0OoQXJ61omQHF46oeIFEPOoK6a/1_m6ATH5ooooo`Oo
VIVI1ooalO47onc/k0Oo][Jf1oo`l?07okBd]0KoZ:RX1_n3Ph<6ooooo`KoQXJ61olS8b<7oibLW0Oo
GEeM1olH61P7olG5a@Ko<S8b1_m2@T86ooooo`OoK6a/1_l/;2`>ogalO0OoQXJ61omeMGD7odA4A0Go
00001_ooool7oaTI6@Oo5ADE1_lA4A47oaLG5`Oo4Q8B1olN7Qh7oa@D50Ko6ATI1Oooool7ofQXJ0Oo
Hf=S1_l20P87ojFUY@OoCdm?1ol[:b/7ok^k^`Ko00001Oooool7oa0@40OoDU9B1om6ATH6o`410@Oo
JVYZ1oli>CT7oaDE5@KoJf][4Oooool000oooooo1on:RXX7oifMW@OoI6AT1om5ADD6oe1@D0OoDU9B
1onFUYH6ochn?PGooooo1om^KVh7oginOPOoD51@1on6QXH7of5QH@KoEUIF1om/K6`6odI6APGooooo
1onIVIT7oo7al@Ook>c/1onf][H7oo3`l0Oo];Bd1_nXZ:P6oh>3P`Kooooo1_n6QXH7ob<S8`OoW9bL
1omMGEd7oaPH60OoaLG51_lb<S86od92@PKooooo1om/K6`6ob`/;0koO7al1on6QXH7ogEeM@OoA4A4
1Ol00006ooooo`Oo6ATI1olE5AD6oa4A4@Oo5aLG1olB4Q87oahN7POo51@D1_lI6AT5ooooo`OoJ6QX
1omSHf<6o`820POoYJFU1om?Cdl7ob/[:`Oo^k^k1_l00005ooooo`Oo410@1omBDU87odI6APKo0@41
1omZJVX7ocTi>@Oo5ADE1_m[Jf/Aooooo`003oooool7okRh^0Oooooo1on=SHd7olo?c`KoWYjN1oo:
b/X7omcLg0KoYjNW3?ooool7okBd]0Oo`<301oo<c<`7om3@d0KooOgm1ooalO46onCTi0Gooooo1onG
UiL7ogalO0OoK6a/1on?Shl7oi:BTPOoShn?1_n`/;06oginOPKooooo1_lJ6QX7of][J`Oo?3`l1olV
9RH7ofm_K`Oo:RXZ1_lN7Qh6obh^;PKooooo1oogmoL6ol_;b`Oooooo1ooalO47ooooo`OokNg]1oo=
cLd5olS8b0Kooooo1onh^;P7onGUi@Kooooo1ooMgMd7on3Ph0OoaLG51oo7alL6ohJ6QPGooooo1ol]
;Bd7oadM7@KoD51@1olU9BD7o`P820OoB4Q81olR8R86oa<C4`Gooooo1omGEeL7ob@T90Oo8B4Q1_m;
Bd/7obTY:@Oo51@D1om2@T86o`X:2Q7ooooo000?ooooo`Oo^;Rh1oooool7ohf=S@Ooclo?1_nNWYh7
ol[:bPOog=cL1_nWYjL<ooooo`Oo];Bd1oo0`<07olc<c0Ood=3@1_omoOd7oo7al@Koi>CT1Oooool7
oiNGU`OoO7al1om/K6`7ohn?S`OoTY:B1on?Shl6ok2`/0KoOWin1_ooool6oaXJ6POoJf][1oll?3`7
obHV9POoKfm_1olZ:RX6oahN7PKo;Rh^1_ooool7ooOgm`Kobl_;1oooool7oo7al@Oooooo1oo]kNd7
olg=c@Gob<S81_ooool7okRh^0OoiNGU1_ooool7omgMg@Ooh>3P1oo5aLD7olO7a`KoQXJ61Oooool7
obd];@Oo7AdM1_m@D507obDU9@Oo20P81om8B4P7ob8R8PKo4a<C1Oooool7oeMGE`Oo92@T1olQ8B46
od];B`Oo:BTY1olD51@7od92@PKo2PX:4Oooool000oooooo1onh^;P7ooooo`OoSHf=1oo?cll6oijN
WPOob/[:1ooLg=`6ojNWY`cooooo1ond];@7ol30`0Ooc<c<1oo@d=06oogmo@OolO7a1_oTi>@5oooo
o`OoUiNG1omlO7`7ofa/K0OoShn?1onBTY87ohn?S`Ko/;2`1_mnOWh6ooooo`Ko6QXJ1om[Jf/7oc`l
?0Oo9RHV1om_Kfl7obXZ:PKo7QhN1_l^;Rh6ooooo`OomoOg1_o;bl/7ooooo`OolO7a1oooool7ong]
k@OocLg=1Oo8b<P6ooooo`Oo^;Rh1ooUiND6ooooo`OogMgM1ooPh>07olG5a@OoalO71_n6QXH5oooo
o`Oo;Bd]1olM7Ad6oe1@D0Oo9BDU1ol820P7odQ8B0Oo8R8R1_lC4a<5ooooo`OoEeMG1olT92@7ob4Q
8@KoBd];1olY:BT7oa@D50Oo@T921_l:2PXAooooo`003oooool7okRh^0Oooooo1on=SHd7olo?c`Ko
WYjN1oo:b/X7omcLg0KoYjNW3?ooool7okBd]0Oo`<301oo<c<`7om3@d0KooOgm1ooalO46onCTi0Go
oooo1onGUiL7ogalO0OoK6a/1on?Shl7oi:BTPOoShn?1_n`/;06oginOPKooooo1_lJ6QX7of][J`Oo
?3`l1olV9RH7ofm_K`Oo:RXZ1_lN7Qh6obh^;PKooooo1oogmoL6ol_;b`Oooooo1ooalO47ooooo`Oo
kNg]1oo=cLd5olS8b0Kooooo1onh^;P7onGUi@Kooooo1ooMgMd7on3Ph0OoaLG51oo7alL6ohJ6QPGo
oooo1ol];Bd7oadM7@KoD51@1olU9BD7o`P820OoB4Q81olR8R86oa<C4`Gooooo1omGEeL7ob@T90Oo
8B4Q1_m;Bd/7obTY:@Oo51@D1om2@T86o`X:2Q7ooooo000?ooooo`Oo^;Rh1oooool7ohf=S@Ooclo?
1_nNWYh7ol[:bPOog=cL1_nWYjL<ooooo`Oo];Bd1oo0`<07olc<c0Ood=3@1_omoOd7oo7al@Koi>CT
1Oooool7oiNGU`OoO7al1om/K6`7ohn?S`OoTY:B1on?Shl6ok2`/0KoOWin1_ooool6oaXJ6POoJf][
1oll?3`7obHV9POoKfm_1olZ:RX6oahN7PKo;Rh^1_ooool7ooOgm`Kobl_;1oooool7oo7al@Oooooo
1oo]kNd7olg=c@Gob<S81_ooool7okRh^0OoiNGU1_ooool7omgMg@Ooh>3P1oo5aLD7olO7a`KoQXJ6
1Oooool7obd];@Oo7AdM1_m@D507obDU9@Oo20P81om8B4P7ob8R8PKo4a<C1Oooool7oeMGE`Oo92@T
1olQ8B46od];B`Oo:BTY1olD51@7od92@PKo2PX:4Oooool000oooooo1onh^;P7ooooo`OoSHf=1oo?
cll6oijNWPOob/[:1ooLg=`6ojNWY`cooooo1ond];@7ol30`0Ooc<c<1oo@d=06oogmo@OolO7a1_oT
i>@5ooooo`OoUiNG1omlO7`7ofa/K0OoShn?1onBTY87ohn?S`Ko/;2`1_mnOWh6ooooo`Ko6QXJ1om[
Jf/7oc`l?0Oo9RHV1om_Kfl7obXZ:PKo7QhN1_l^;Rh6ooooo`OomoOg1_o;bl/7ooooo`OolO7a1ooo
ool7ong]k@OocLg=1Oo8b<P6ooooo`Oo^;Rh1ooUiND6ooooo`OogMgM1ooPh>07olG5a@OoalO71_n6
QXH5ooooo`Oo;Bd]1olM7Ad6oe1@D0Oo9BDU1ol820P7odQ8B0Oo8R8R1_lC4a<5ooooo`OoEeMG1olT
92@7ob4Q8@KoBd];1olY:BT7oa@D50Oo@T921_l:2PXAooooo`00oooooooeooooo`00oooooooeoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-2.32564, \
-0.204693, 0.148839, 0.148839}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-11.135, -0.204693, 0.148839, 0.148839}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-19.9351, -0.204693, 0.148839, 0.148839}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-28.7352, -0.204693, 0.148839, 0.148839}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-37.5353, -0.204693, 0.148839, 0.148839}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-46.3354, -0.204693, 0.148839, \
0.148839}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-55.1355, -0.204693, \
0.148839, 0.148839}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-63.9356, \
-0.204693, 0.148839, 0.148839}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
504D7A5CC4C9F5FF
2434674AC1C3BDBE
1C2B543AD2C5DD9F
04305234C5D3DB9E
181A5B33D9C3D7AE
00405146DBC3EADC
2E406B54CED7F8E2
23495F4DB0B6DEFB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
94F4702814264716
ACF2611408275A0F
C0FF52100B324616
D5F041000B326419
DDE533081046572F
F0D1270020416630
E3BD220F24585C54
D99A1B082E4D6256
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B298FEE8F3B0D61
183D97FF872A0041
1735ACFC73211041
185AB4FE661C0725
225ABEEF5218232A
1F72C8DC4B161D0D
367BC1CD3E1E3E25
2C79B4A938183019
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
77581E1131B9BD6D
804B1B0A3BD5C073
7A3E061049E6C17B
7F3008135BF9BB87
6E2400206DFAB28C
6D1A04267CFFA399
5412093386EF9792
520E0C3A8CD87C8F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4E3125160F1328E7
422B1D10040E2CEF
4F312311050A25FF
472B1A12010A24FD
4C332012050C25FE
47281913001123F2
492C1F130E1421EF
3725151708111ECA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
285DE47820298765
1365F45A15248A4E
237BF557102F9D55
157DFF3B023CA248
2B9DEA2E0B409D44
289DE5210056B143
43ABC9171F53A03A
389AB41A075FA545
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7A321166DB9D3DE3
7C171077EF8E39EE
59171D89F2862DF4
5504239DFF651FEB
3A063AAEF35D20EC
370043BBF24214DC
290D5DC1D23521D2
2A1759B3BC3118B9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
603B4E84E3815100
6C3C488FEF624802
6A4F5DACFF784510
764255ACF8503A08
6F5663B9F35F391D
734959B4D4382D10
655360ADC7401E1C
523D458697200308
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool7oe1@D0OoCDe=1omjNWX7oeaLG0Koa<C41oo9bLT7ooGem@_o
oooo1onDU9@7ooCdm0OoL71`1olX:2P7oa@D50Ko9RHV1om7AdL6oaHF5PGooooo1olK6a/7obTY:@Oo
Shn?1oo^k^h7ohn?S`Oo>c/k1_l=3@d6of5QH@Kooooo1_mgMgL7oeQHF0Oo7QhN1olA4A47oc4a<@Oo
^KVi1_nm_Kd6ofe]K@Kooooo1om>CTh6oc4a<@Oo9BDU1olF5QH7o`l?3`Oo4a<C1olX:2P5onOWi`Ko
oooo1olX:2P7oeeMG@Koi>CT1omhN7P7ob0P80Oo:BTY1on7QhL6ofEUI@Gooooo1omjNWX7oc8b<PKo
4A4A1omVIVH7om_Kf`OoWIfM1olm?Cd6on?Sh`Gooooo1omPH607oc/k>`OoCTi>1_n4Q8@7on?Sh`Oo
PH611omADE46o`00017ooooo000?ooooo`OoD51@1om=CDd7ogYjNPOoG5aL1_o4a<@7olW9b@OomOGe
2oooool7oiBDU0Oom?Cd1om`L707obPX:0Oo51@D1_lV9RH7odM7A`Ko5QHF1Oooool7oa/K6`Oo:BTY
1on?Shl7onk^kPOoShn?1olk>c/6o`d=3@KoHF5Q1_ooool6ogMgM`OoF5QH1olN7Qh7oa4A4@Oo<C4a
1oni^KT6okfm_@KoKFe]1_ooool7odi>CPKo<C4a1olU9BD7oaHF5POo3`l?1olC4a<7obPX:0GoinOW
1_ooool7obPX:0OoGEeM1_oTi>@7ogQhN0Oo820P1olY:BT7ohN7Q`KoIFEU1Oooool7ogYjNPOo<S8b
1_lA4A47ofIVIPOofm_K1onMWId7ocdm?@Kohn?S1Oooool7of1PH0Oo>c/k1om>CTh6ohB4Q0Oohn?S
1on1PH47oe5AD@Ko00004Oooool000oooooo1om@D507ode=C@OoNWYj1omLG5`6olC4a0OobLW91ooe
mOD;ooooo`OoU9BD1oodm?@7og1`L0Oo:2PX1olD51@6obHV9POoAdM71_lF5QH5ooooo`Oo6a/K1olY
:BT7ohn?S`Ook^k^1on?Shl7oc/k>`Ko3@d=1_mQHF46ooooo`KoMgMg1omHF5P7oahN7POo4A4A1ola
<C47okVi^@Ko_Kfm1_m]KFd6ooooo`OoCTi>1_la<C47obDU9@Oo5QHF1ol?3`l7oa<C4`Oo:2PX1OoW
inL6ooooo`Oo:2PX1omMGEd6onCTi0OoN7Qh1olP8207obTY:@OoQhN71_mUIFD5ooooo`OoNWYj1olb
<S86oa4A4@OoIVIV1ooKfm/7oifMW@Oo?Cdm1_oShn<5ooooo`OoH61P1olk>c/7odi>CPKoQ8B41ooS
hn<7oh61P@OoDE5A1_l0000Aooooo`003oooool7oe1@D0OoCDe=1omjNWX7oeaLG0Koa<C41oo9bLT7
ooGem@_ooooo1onDU9@7ooCdm0OoL71`1olX:2P7oa@D50Ko9RHV1om7AdL6oaHF5PGooooo1olK6a/7
obTY:@OoShn?1oo^k^h7ohn?S`Oo>c/k1_l=3@d6of5QH@Kooooo1_mgMgL7oeQHF0Oo7QhN1olA4A47
oc4a<@Oo^KVi1_nm_Kd6ofe]K@Kooooo1om>CTh6oc4a<@Oo9BDU1olF5QH7o`l?3`Oo4a<C1olX:2P5
onOWi`Kooooo1olX:2P7oeeMG@Koi>CT1omhN7P7ob0P80Oo:BTY1on7QhL6ofEUI@Gooooo1omjNWX7
oc8b<PKo4A4A1omVIVH7om_Kf`OoWIfM1olm?Cd6on?Sh`Gooooo1omPH607oc/k>`OoCTi>1_n4Q8@7
on?Sh`OoPH611omADE46o`00017ooooo000?ooooo`OoD51@1om=CDd7ogYjNPOoG5aL1_o4a<@7olW9
b@OomOGe2oooool7oiBDU0Oom?Cd1om`L707obPX:0Oo51@D1_lV9RH7odM7A`Ko5QHF1Oooool7oa/K
6`Oo:BTY1on?Shl7onk^kPOoShn?1olk>c/6o`d=3@KoHF5Q1_ooool6ogMgM`OoF5QH1olN7Qh7oa4A
4@Oo<C4a1oni^KT6okfm_@KoKFe]1_ooool7odi>CPKo<C4a1olU9BD7oaHF5POo3`l?1olC4a<7obPX
:0GoinOW1_ooool7obPX:0OoGEeM1_oTi>@7ogQhN0Oo820P1olY:BT7ohN7Q`KoIFEU1Oooool7ogYj
NPOo<S8b1_lA4A47ofIVIPOofm_K1onMWId7ocdm?@Kohn?S1Oooool7of1PH0Oo>c/k1om>CTh6ohB4
Q0Oohn?S1on1PH47oe5AD@Ko00004Oooool000oooooo1om@D507ode=C@OoNWYj1omLG5`6olC4a0Oo
bLW91ooemOD;ooooo`OoU9BD1oodm?@7og1`L0Oo:2PX1olD51@6obHV9POoAdM71_lF5QH5ooooo`Oo
6a/K1olY:BT7ohn?S`Ook^k^1on?Shl7oc/k>`Ko3@d=1_mQHF46ooooo`KoMgMg1omHF5P7oahN7POo
4A4A1ola<C47okVi^@Ko_Kfm1_m]KFd6ooooo`OoCTi>1_la<C47obDU9@Oo5QHF1ol?3`l7oa<C4`Oo
:2PX1OoWinL6ooooo`Oo:2PX1omMGEd6onCTi0OoN7Qh1olP8207obTY:@OoQhN71_mUIFD5ooooo`Oo
NWYj1olb<S86oa4A4@OoIVIV1ooKfm/7oifMW@Oo?Cdm1_oShn<5ooooo`OoH61P1olk>c/7odi>CPKo
Q8B41ooShn<7oh61P@OoDE5A1_l0000Aooooo`003oooool7oe1@D0OoCDe=1omjNWX7oeaLG0Koa<C4
1oo9bLT7ooGem@_ooooo1onDU9@7ooCdm0OoL71`1olX:2P7oa@D50Ko9RHV1om7AdL6oaHF5PGooooo
1olK6a/7obTY:@OoShn?1oo^k^h7ohn?S`Oo>c/k1_l=3@d6of5QH@Kooooo1_mgMgL7oeQHF0Oo7QhN
1olA4A47oc4a<@Oo^KVi1_nm_Kd6ofe]K@Kooooo1om>CTh6oc4a<@Oo9BDU1olF5QH7o`l?3`Oo4a<C
1olX:2P5onOWi`Kooooo1olX:2P7oeeMG@Koi>CT1omhN7P7ob0P80Oo:BTY1on7QhL6ofEUI@Gooooo
1omjNWX7oc8b<PKo4A4A1omVIVH7om_Kf`OoWIfM1olm?Cd6on?Sh`Gooooo1omPH607oc/k>`OoCTi>
1_n4Q8@7on?Sh`OoPH611omADE46o`00017ooooo000?ooooo`Oo92@T1old=3@7ofMWI`OoBTY:1_o1
`L47ol?3``Oo_Kfm1_nn_[h5ooooo`Oo[:b/1oobl_87of5QH@Oo51@D1ol820P6obLW9`OoFUYJ1_l?
3`l5ooooo`Oo61PH1olm?Cd7oiNGU`Oooooo1on7QhL7obXZ:PKo00001_m1@D46ooooo`KoP8201om;
Bd/7oa/K6`Oo2PX:1olk>c/7omGEe@Ko`<301_mcLg<6ooooo`Oo@T921_l[:b/7oadM7@Oo410@1ol4
10@7o`h>3POo;2`/1Oo_knl6ooooo`Oo4a<C1omUIFD6ooCdm0OoFUYJ1olE5AD7ob@T90OoRXZ:1_m>
CTh5ooooo`OoO7al1olG5aL6oa0@40OoMgMg1oo_knl7ohj>SPOo>CTi1_o^k^h5ooooo`OoK6a/1oll
?3`7odQ8B0KoShn?1oo_knl7of9RHPOoB4Q81_l20P8Aooooo`003oooool7ob@T90Oo=3@d1omWIfL7
odY:BPKo`L711oo3`l<7okfm_@Ko_[jn1Oooool7ojb/[0Ool_;b1omQHF47oa@D50Oo20P81_lW9bL7
oeYJFPKo3`l?1Oooool7oaPH60Oo?Cdm1onGUiL7ooooo`OoQhN71olZ:RX6o`0000Ko@D511_ooool6
oh20P0OoBd];1olK6a/7o`X:2POo>c/k1ooEeMD6ol30`0KoLg=c1_ooool7od92@PKo:b/[1olM7Ad7
oa0@40Oo10@41ol>3Ph7ob`/;0Gokno_1_ooool7oa<C4`OoIFEU1_odm?@7oeYJFPOo5ADE1olT92@7
ohZ:RPKoCTi>1Oooool7ogalO0Oo5aLG1_l@4107ogMgM`Ookno_1on>SXh7ocTi>@Kok^k^1Oooool7
ofa/K0Oo?3`l1om8B4P6ohn?S`Ookno_1omRHV87odQ8B0Ko0P824Oooool000oooooo1olT92@7oc@d
=0OoIfMW1om:BTX6ol71`@Oo`l?31onm_Kd6okjn_PGooooo1on/[:`7oo;blPOoHF5Q1olD51@7o`P8
20Ko9bLW1omJFUX6o`l?3`Gooooo1olH61P7ocdm?@OoUiNG1oooool7ohN7Q`Oo:RXZ1_l00006od51
@@Kooooo1_n0P807od];B`Oo6a/K1ol:2PX7oc/k>`OoeMGE1_o0`<06og=cL`Kooooo1om2@T86ob/[
:`Oo7AdM1ol@4107o`@410Oo3Ph>1ol/;2`5ono_k`Kooooo1olC4a<7ofEUI@Kom?Cd1omJFUX7oaDE
5@Oo92@T1on:RXX6odi>CPGooooo1omlO7`7oaLG5`Ko410@1omgMgL7ono_k`OoSXj>1oli>CT6onk^
kPGooooo1om/K6`7oc`l?0OoB4Q81_n?Shl7ono_k`OoHV9R1om8B4P6o`820Q7ooooo000?ooooo`Oo
92@T1old=3@7ofMWI`OoBTY:1_o1`L47ol?3``Oo_Kfm1_nn_[h5ooooo`Oo[:b/1oobl_87of5QH@Oo
51@D1ol820P6obLW9`OoFUYJ1_l?3`l5ooooo`Oo61PH1olm?Cd7oiNGU`Oooooo1on7QhL7obXZ:PKo
00001_m1@D46ooooo`KoP8201om;Bd/7oa/K6`Oo2PX:1olk>c/7omGEe@Ko`<301_mcLg<6ooooo`Oo
@T921_l[:b/7oadM7@Oo410@1ol410@7o`h>3POo;2`/1Oo_knl6ooooo`Oo4a<C1omUIFD6ooCdm0Oo
FUYJ1olE5AD7ob@T90OoRXZ:1_m>CTh5ooooo`OoO7al1olG5aL6oa0@40OoMgMg1oo_knl7ohj>SPOo
>CTi1_o^k^h5ooooo`OoK6a/1oll?3`7odQ8B0KoShn?1oo_knl7of9RHPOoB4Q81_l20P8Aooooo`00
3oooool7ob@T90Oo=3@d1omWIfL7odY:BPKo`L711oo3`l<7okfm_@Ko_[jn1Oooool7ojb/[0Ool_;b
1omQHF47oa@D50Oo20P81_lW9bL7oeYJFPKo3`l?1Oooool7oaPH60Oo?Cdm1onGUiL7ooooo`OoQhN7
1olZ:RX6o`0000Ko@D511_ooool6oh20P0OoBd];1olK6a/7o`X:2POo>c/k1ooEeMD6ol30`0KoLg=c
1_ooool7od92@PKo:b/[1olM7Ad7oa0@40Oo10@41ol>3Ph7ob`/;0Gokno_1_ooool7oa<C4`OoIFEU
1_odm?@7oeYJFPOo5ADE1olT92@7ohZ:RPKoCTi>1Oooool7ogalO0Oo5aLG1_l@4107ogMgM`Ookno_
1on>SXh7ocTi>@Kok^k^1Oooool7ofa/K0Oo?3`l1om8B4P6ohn?S`Ookno_1omRHV87odQ8B0Ko0P82
4Oooool000oooooo1olT92@7oc@d=0OoIfMW1om:BTX6ol71`@Oo`l?31onm_Kd6okjn_PGooooo1on/
[:`7oo;blPOoHF5Q1olD51@7o`P820Ko9bLW1omJFUX6o`l?3`Gooooo1olH61P7ocdm?@OoUiNG1ooo
ool7ohN7Q`Oo:RXZ1_l00006od51@@Kooooo1_n0P807od];B`Oo6a/K1ol:2PX7oc/k>`OoeMGE1_o0
`<06og=cL`Kooooo1om2@T86ob/[:`Oo7AdM1ol@4107o`@410Oo3Ph>1ol/;2`5ono_k`Kooooo1olC
4a<7ofEUI@Kom?Cd1omJFUX7oaDE5@Oo92@T1on:RXX6odi>CPGooooo1omlO7`7oaLG5`Ko410@1omg
MgL7ono_k`OoSXj>1oli>CT6onk^kPGooooo1om/K6`7oc`l?0OoB4Q81_n?Shl7ono_k`OoHV9R1om8
B4P6o`820Q7ooooo000?ooooo`Oo92@T1old=3@7ofMWI`OoBTY:1_o1`L47ol?3``Oo_Kfm1_nn_[h5
ooooo`Oo[:b/1oobl_87of5QH@Oo51@D1ol820P6obLW9`OoFUYJ1_l?3`l5ooooo`Oo61PH1olm?Cd7
oiNGU`Oooooo1on7QhL7obXZ:PKo00001_m1@D46ooooo`KoP8201om;Bd/7oa/K6`Oo2PX:1olk>c/7
omGEe@Ko`<301_mcLg<6ooooo`Oo@T921_l[:b/7oadM7@Oo410@1ol410@7o`h>3POo;2`/1Oo_knl6
ooooo`Oo4a<C1omUIFD6ooCdm0OoFUYJ1olE5AD7ob@T90OoRXZ:1_m>CTh5ooooo`OoO7al1olG5aL6
oa0@40OoMgMg1oo_knl7ohj>SPOo>CTi1_o^k^h5ooooo`OoK6a/1oll?3`7odQ8B0KoShn?1oo_knl7
of9RHPOoB4Q81_l20P8Aooooo`003oooool7oa`L70Oo:b/[1omDE5@7ocXj>PKod];B1oo5aLD7omgM
g@KoWinO1Oooool7ol30`0Oooooo1omBDU87oa0@40Oo2`/;1_lb<S87odI6APKo5QHF1Oooool7oaLG
5`Oo=CDe1on/[:`7ooclo0OoLg=c1olQ8B46oa0@40Ko@D511_ooool6ogYjNPOo?Shn1ol61PH7oa0@
40OoBDU91ooVi^H6ol71`@KoNg]k1_ooool7odm?C`Ko<C4a1olS8b<7oa4A4@Oo1@D51ol:2PX7obDU
9@_ooooo1olS8b<7og]kN`KomOGe1omGEeL7oa0@40Oo;bl_1onMWId6oeEEE@Gooooo1omIFET7oaLG
5`Ko7AdM1on9RHT7oo;blPOoQXJ61ol];Bd6ooCdm0Gooooo1omZJVX7odm?C`OoGEeM1_n/[:`7oooo
o`OoN7Qh1om5ADD6oa0@417ooooo000?ooooo`Oo71`L1ol[:b/7oeADE0Oo>SXj1_oBd]87olG5a@Oo
gMgM1_nOWil5ooooo`Oo`<301oooool7oe9BDPOo410@1ol;2`/6oc8b<POoATI61_lF5QH5ooooo`Oo
5aLG1ole=CD7ojb/[0Ooo?cl1omcLg<7ob4Q8@Ko410@1_m1@D46ooooo`KoNWYj1oln?Sh7o`H61POo
410@1om9BDT7onKViPKo`L711_mkNg/6ooooo`OoCdm?1_la<C47ob<S8`Oo4A4A1ol51@D7o`X:2POo
9BDU2oooool7ob<S8`OoNg]k1_oemOD7oeMGE`Oo410@1ol_;bl7oifMW@KoEEEE1Oooool7oeUIF@Oo
5aLG1_lM7Ad7ohV9R@Ool_;b1on6QXH7obd];@Kom?Cd1Oooool7ofYZJPOoCdm?1omMGEd6ojb/[0Oo
oooo1omhN7P7odE5A@Ko410@4Oooool000oooooo1olL71`7ob/[:`OoE5AD1olj>SX6om;BdPOoaLG5
1ooMgMd6oinOW`Gooooo1oo0`<07ooooo`OoDU9B1ol@4107o`/;2`Ko<S8b1om6ATH6oaHF5PGooooo
1olG5aL7ocDe=@Oo[:b/1oolo?`7og=cL`Oo8B4Q1_l@4106od51@@Kooooo1_mjNWX7ochn?POo1PH6
1ol@4107odU9B@Ooi^KV1_o1`L46og]kN`Kooooo1om?Cdl6oc4a<@Oo8b<S1olA4A47o`D51@Oo2PX:
1olU9BD;ooooo`Oo8b<S1omkNg/6ooGem@OoEeMG1ol@4107obl_;`OoWIfM1_mEEED5ooooo`OoFEUI
1olG5aL6oadM7@OoRHV91oobl_87ohJ6QPOo;Bd]1_odm?@5ooooo`OoJVYZ1om?Cdl7oeeMG@Ko[:b/
1oooool7ogQhN0OoADE51_l@410Aooooo`003oooool7oa`L70Oo:b/[1omDE5@7ocXj>PKod];B1oo5
aLD7omgMg@KoWinO1Oooool7ol30`0Oooooo1omBDU87oa0@40Oo2`/;1_lb<S87odI6APKo5QHF1Ooo
ool7oaLG5`Oo=CDe1on/[:`7ooclo0OoLg=c1olQ8B46oa0@40Ko@D511_ooool6ogYjNPOo?Shn1ol6
1PH7oa0@40OoBDU91ooVi^H6ol71`@KoNg]k1_ooool7odm?C`Ko<C4a1olS8b<7oa4A4@Oo1@D51ol:
2PX7obDU9@_ooooo1olS8b<7og]kN`KomOGe1omGEeL7oa0@40Oo;bl_1onMWId6oeEEE@Gooooo1omI
FET7oaLG5`Ko7AdM1on9RHT7oo;blPOoQXJ61ol];Bd6ooCdm0Gooooo1omZJVX7odm?C`OoGEeM1_n/
[:`7ooooo`OoN7Qh1om5ADD6oa0@417ooooo000?ooooo`Oo71`L1ol[:b/7oeADE0Oo>SXj1_oBd]87
olG5a@OogMgM1_nOWil5ooooo`Oo`<301oooool7oe9BDPOo410@1ol;2`/6oc8b<POoATI61_lF5QH5
ooooo`Oo5aLG1ole=CD7ojb/[0Ooo?cl1omcLg<7ob4Q8@Ko410@1_m1@D46ooooo`KoNWYj1oln?Sh7
o`H61POo410@1om9BDT7onKViPKo`L711_mkNg/6ooooo`OoCdm?1_la<C47ob<S8`Oo4A4A1ol51@D7
o`X:2POo9BDU2oooool7ob<S8`OoNg]k1_oemOD7oeMGE`Oo410@1ol_;bl7oifMW@KoEEEE1Oooool7
oeUIF@Oo5aLG1_lM7Ad7ohV9R@Ool_;b1on6QXH7obd];@Kom?Cd1Oooool7ofYZJPOoCdm?1omMGEd6
ojb/[0Oooooo1omhN7P7odE5A@Ko410@4Oooool000oooooo1olL71`7ob/[:`OoE5AD1olj>SX6om;B
dPOoaLG51ooMgMd6oinOW`Gooooo1oo0`<07ooooo`OoDU9B1ol@4107o`/;2`Ko<S8b1om6ATH6oaHF
5PGooooo1olG5aL7ocDe=@Oo[:b/1oolo?`7og=cL`Oo8B4Q1_l@4106od51@@Kooooo1_mjNWX7ochn
?POo1PH61ol@4107odU9B@Ooi^KV1_o1`L46og]kN`Kooooo1om?Cdl6oc4a<@Oo8b<S1olA4A47o`D5
1@Oo2PX:1olU9BD;ooooo`Oo8b<S1omkNg/6ooGem@OoEeMG1ol@4107obl_;`OoWIfM1_mEEED5oooo
o`OoFEUI1olG5aL6oadM7@OoRHV91oobl_87ohJ6QPOo;Bd]1_odm?@5ooooo`OoJVYZ1om?Cdl7oeeM
G@Ko[:b/1oooool7ogQhN0OoADE51_l@410Aooooo`003oooool7o`@410Oo<30`1omBDU87oc@d=0Ko
aLG51ooCdm<7om_Kf`KoWYjN1Oooool7omGEe@Ool?3`1om1@D47o`0000Oo2`/;1_lb<S87ofATI0Ko
6ATI1Oooool7oaPH60OoFUYJ1ond];@7ooknoPOoIVIV1olL71`6o`L71`Ko9BDU1_ooool6ogmoO`Oo
<30`1ol820P7oa<C4`OoFe]K1ooinOT6ok^k^`KoQhN71_ooool7odM7A`Ko:b/[1olJ6QX7oa8B4POo
0@411ol:2PX7ob@T90GooOgm1_ooool7oaDE5@OoOGem1_ooool7oc/k>`Oo0P821oll?3`7oj:RXPKo
B4Q81Oooool7oeEEE@Oo10@41_lS8b<7oifMW@Oooooo1omUIFD7oalO7`Kojn_[1Oooool7ogIfMPOo
@T921omEEED6ojb/[0Oon?Sh1om@D507ocXj>PKo20P84Oooool000oooooo1ol410@7oc0`<0OoDU9B
1old=3@6olG5a@Oodm?C1ooKfm/6oijNWPGooooo1ooEeMD7oo3`l0Oo@D511ol00007o`/;2`Ko<S8b
1omTI6@6oaTI6@Gooooo1olH61P7oeYJFPOo];Bd1oono_h7ofIVIPOo71`L1_l71`L6obDU9@Kooooo
1_moOgl7oc0`<0Oo20P81olC4a<7oe]KF`OonOWi1_nk^k/6ohN7Q`Kooooo1om7AdL6ob/[:`Oo6QXJ
1olB4Q87o`410@Oo2PX:1olT92@5oogmo@Kooooo1olE5AD7ogemO@Kooooo1olk>c/7o`820POo?3`l
1onRXZ86odQ8B0Gooooo1omEEED7o`@410Ko8b<S1onMWId7ooooo`OoIFEU1olO7al6on_[j`Gooooo
1omfMWH7od92@POoEEEE1_n/[:`7ooShn0OoD51@1olj>SX6o`P8217ooooo000?ooooo`Oo10@41ol`
<307oe9BDPOo=3@d1_o5aLD7om?Cd`Oofm_K1_nNWYh5ooooo`OoeMGE1oo`l?07od51@@Oo00001ol;
2`/6oc8b<POoI6AT1_lI6AT5ooooo`Oo61PH1omJFUX7okBd]0Ooo_kn1omVIVH7oa`L70Ko1`L71_lU
9BD6ooooo`KoOgmo1ol`<307o`P820Oo4a<C1omKFe/7ooWin@Ko^k^k1_n7QhL6ooooo`OoAdM71_l[
:b/7oaXJ6POo4Q8B1ol10@47o`X:2POo92@T1OomoOd6ooooo`Oo5ADE1ommOGd6ooooo`Oo>c/k1ol2
0P87oc`l?0OoXZ:R1_m8B4P5ooooo`OoEEEE1ol410@6ob<S8`OoWIfM1oooool7ofEUI@Oo7alO1_o[
jn/5ooooo`OoMWIf1om2@T87oeEEE@Ko[:b/1oohn?P7oe1@D0Oo>SXj1_l820PAooooo`003oooool7
o`@410Oo<30`1omBDU87oc@d=0KoaLG51ooCdm<7om_Kf`KoWYjN1Oooool7omGEe@Ool?3`1om1@D47
o`0000Oo2`/;1_lb<S87ofATI0Ko6ATI1Oooool7oaPH60OoFUYJ1ond];@7ooknoPOoIVIV1olL71`6
o`L71`Ko9BDU1_ooool6ogmoO`Oo<30`1ol820P7oa<C4`OoFe]K1ooinOT6ok^k^`KoQhN71_ooool7
odM7A`Ko:b/[1olJ6QX7oa8B4POo0@411ol:2PX7ob@T90GooOgm1_ooool7oaDE5@OoOGem1_ooool7
oc/k>`Oo0P821oll?3`7oj:RXPKoB4Q81Oooool7oeEEE@Oo10@41_lS8b<7oifMW@Oooooo1omUIFD7
oalO7`Kojn_[1Oooool7ogIfMPOo@T921omEEED6ojb/[0Oon?Sh1om@D507ocXj>PKo20P84Oooool0
00oooooo1ol410@7oc0`<0OoDU9B1old=3@6olG5a@Oodm?C1ooKfm/6oijNWPGooooo1ooEeMD7oo3`
l0Oo@D511ol00007o`/;2`Ko<S8b1omTI6@6oaTI6@Gooooo1olH61P7oeYJFPOo];Bd1oono_h7ofIV
IPOo71`L1_l71`L6obDU9@Kooooo1_moOgl7oc0`<0Oo20P81olC4a<7oe]KF`OonOWi1_nk^k/6ohN7
Q`Kooooo1om7AdL6ob/[:`Oo6QXJ1olB4Q87o`410@Oo2PX:1olT92@5oogmo@Kooooo1olE5AD7ogem
O@Kooooo1olk>c/7o`820POo?3`l1onRXZ86odQ8B0Gooooo1omEEED7o`@410Ko8b<S1onMWId7oooo
o`OoIFEU1olO7al6on_[j`Gooooo1omfMWH7od92@POoEEEE1_n/[:`7ooShn0OoD51@1olj>SX6o`P8
217ooooo000?ooooo`Oo10@41ol`<307oe9BDPOo=3@d1_o5aLD7om?Cd`Oofm_K1_nNWYh5ooooo`Oo
eMGE1oo`l?07od51@@Oo00001ol;2`/6oc8b<POoI6AT1_lI6AT5ooooo`Oo61PH1omJFUX7okBd]0Oo
o_kn1omVIVH7oa`L70Ko1`L71_lU9BD6ooooo`KoOgmo1ol`<307o`P820Oo4a<C1omKFe/7ooWin@Ko
^k^k1_n7QhL6ooooo`OoAdM71_l[:b/7oaXJ6POo4Q8B1ol10@47o`X:2POo92@T1OomoOd6ooooo`Oo
5ADE1ommOGd6ooooo`Oo>c/k1ol20P87oc`l?0OoXZ:R1_m8B4P5ooooo`OoEEEE1ol410@6ob<S8`Oo
WIfM1oooool7ofEUI@Oo7alO1_o[jn/5ooooo`OoMWIf1om2@T87oeEEE@Ko[:b/1oohn?P7oe1@D0Oo
>SXj1_l820PAooooo`003oooool7o`@410Oo<30`1omBDU87oc@d=0KoaLG51ooCdm<7om_Kf`KoWYjN
1Oooool7omGEe@Ool?3`1om1@D47o`0000Oo2`/;1_lb<S87ofATI0Ko6ATI1Oooool7oaPH60OoFUYJ
1ond];@7ooknoPOoIVIV1olL71`6o`L71`Ko9BDU1_ooool6ogmoO`Oo<30`1ol820P7oa<C4`OoFe]K
1ooinOT6ok^k^`KoQhN71_ooool7odM7A`Ko:b/[1olJ6QX7oa8B4POo0@411ol:2PX7ob@T90GooOgm
1_ooool7oaDE5@OoOGem1_ooool7oc/k>`Oo0P821oll?3`7oj:RXPKoB4Q81Oooool7oeEEE@Oo10@4
1_lS8b<7oifMW@Oooooo1omUIFD7oalO7`Kojn_[1Oooool7ogIfMPOo@T921omEEED6ojb/[0Oon?Sh
1om@D507ocXj>PKo20P84Oooool000oooooo1olH61P7oaXJ6POoFe]K1olc<c<6omWIf@Oo`l?31ooG
emL6ojj^[PGooooo1ooMgMd7onGUi@Oo<c<c1ol820P7oa0@40KoATI61omGEeL6obl_;`Gooooo1olR
8R87oeYJFPOo_[jn1oo_knl7oe9BDPOo61PH1_lS8b<6obXZ:PKooooo1_m^KVh7ob@T90Oo00001olP
8207ofe]K@Oon_[j1_nb/[86ohb<S0Kooooo1om<C4`6oc<c<`Oo820P1olB4Q87o`D51@Oo30`<1olU
9BD5ooknoPKooooo1ol[:b/7oifMW@Koj^[Z1ol^;Rh7o`/;2`Oo@4101onMWId6odA4A0Gooooo1olj
>SX7o`H61PKo>SXj1on^[Zh7oo?cl`OoGEeM1olP8206onc/k0Gooooo1om_Kfl7oeIFEPOoHf=S1_ni
^KT7oo?cl`OoGemO1oli>CT6oadM7A7ooooo000?ooooo`Oo61PH1olJ6QX7oe]KF`Oo<c<c1_oIfMT7
ol?3``OoemOG1_n^[Zh5ooooo`OogMgM1ooUiND7oc<c<`Oo20P81ol@4106odI6APOoEeMG1_l_;bl5
ooooo`Oo8R8R1omJFUX7okjn_POokno_1omBDU87oaPH60Ko8b<S1_lZ:RX6ooooo`KoKVi^1olT92@7
o`0000Oo820P1om]KFd7oo[jnPKo/[:b1_n<S8`6ooooo`OoC4a<1_lc<c<7ob0P80Oo4Q8B1ol51@D7
o``<30Oo9BDU1Oono_h6ooooo`Oo:b/[1onMWId6on[ZjPOo;Rh^1ol;2`/7od10@0OoWIfM1_m4A4@5
ooooo`Oo>SXj1ol61PH6ocXj>POo[Zj^1ooclo<7oeeMG@Oo820P1_o/k>`5ooooo`OoKfm_1omFEUH7
of=SH`Ko^KVi1ooclo<7oemOG`Oo>CTi1_lM7AdAooooo`003oooool7oaPH60Oo6QXJ1omKFe/7oc<c
<`KofMWI1oo3`l<7omOGe`Ko[Zj^1Oooool7omgMg@OoiNGU1olc<c<7o`P820Oo410@1_m6ATH7oeMG
E`Ko;bl_1Oooool7ob8R8POoFUYJ1onn_[h7ono_k`OoDU9B1olH61P6ob<S8`Ko:RXZ1_ooool6ofi^
KPOo92@T1ol00007ob0P80OoKFe]1oojn_X6ok:b/PKoS8b<1_ooool7oda<C0Ko<c<c1olP8207oa8B
4POo1@D51ol<30`7obDU9@Goo_kn1_ooool7ob/[:`OoWIfM1_oZj^X7obh^;POo2`/;1om0@407oifM
W@KoA4A41Oooool7ocXj>POo1PH61_lj>SX7ojj^[POolo?c1omMGEd7ob0P80Kok>c/1Oooool7ofm_
K`OoEUIF1omSHf<6okVi^@Oolo?c1omOGel7ocTi>@Ko7AdM4Oooool000oooooo1olH61P7oaXJ6POo
Fe]K1olc<c<6omWIf@Oo`l?31ooGemL6ojj^[PGooooo1ooMgMd7onGUi@Oo<c<c1ol820P7oa0@40Ko
ATI61omGEeL6obl_;`Gooooo1olR8R87oeYJFPOo_[jn1oo_knl7oe9BDPOo61PH1_lS8b<6obXZ:PKo
oooo1_m^KVh7ob@T90Oo00001olP8207ofe]K@Oon_[j1_nb/[86ohb<S0Kooooo1om<C4`6oc<c<`Oo
820P1olB4Q87o`D51@Oo30`<1olU9BD5ooknoPKooooo1ol[:b/7oifMW@Koj^[Z1ol^;Rh7o`/;2`Oo
@4101onMWId6odA4A0Gooooo1olj>SX7o`H61PKo>SXj1on^[Zh7oo?cl`OoGEeM1olP8206onc/k0Go
oooo1om_Kfl7oeIFEPOoHf=S1_ni^KT7oo?cl`OoGemO1oli>CT6oadM7A7ooooo000?ooooo`Oo61PH
1olJ6QX7oe]KF`Oo<c<c1_oIfMT7ol?3``OoemOG1_n^[Zh5ooooo`OogMgM1ooUiND7oc<c<`Oo20P8
1ol@4106odI6APOoEeMG1_l_;bl5ooooo`Oo8R8R1omJFUX7okjn_POokno_1omBDU87oaPH60Ko8b<S
1_lZ:RX6ooooo`KoKVi^1olT92@7o`0000Oo820P1om]KFd7oo[jnPKo/[:b1_n<S8`6ooooo`OoC4a<
1_lc<c<7ob0P80Oo4Q8B1ol51@D7o``<30Oo9BDU1Oono_h6ooooo`Oo:b/[1onMWId6on[ZjPOo;Rh^
1ol;2`/7od10@0OoWIfM1_m4A4@5ooooo`Oo>SXj1ol61PH6ocXj>POo[Zj^1ooclo<7oeeMG@Oo820P
1_o/k>`5ooooo`OoKfm_1omFEUH7of=SH`Ko^KVi1ooclo<7oemOG`Oo>CTi1_lM7AdAooooo`003ooo
ool7oaPH60Oo6QXJ1omKFe/7oc<c<`KofMWI1oo3`l<7omOGe`Ko[Zj^1Oooool7omgMg@OoiNGU1olc
<c<7o`P820Oo410@1_m6ATH7oeMGE`Ko;bl_1Oooool7ob8R8POoFUYJ1onn_[h7ono_k`OoDU9B1olH
61P6ob<S8`Ko:RXZ1_ooool6ofi^KPOo92@T1ol00007ob0P80OoKFe]1oojn_X6ok:b/PKoS8b<1_oo
ool7oda<C0Ko<c<c1olP8207oa8B4POo1@D51ol<30`7obDU9@Goo_kn1_ooool7ob/[:`OoWIfM1_oZ
j^X7obh^;POo2`/;1om0@407oifMW@KoA4A41Oooool7ocXj>POo1PH61_lj>SX7ojj^[POolo?c1omM
GEd7ob0P80Kok>c/1Oooool7ofm_K`OoEUIF1omSHf<6okVi^@Oolo?c1omOGel7ocTi>@Ko7AdM4Ooo
ool000oooooo1ol00007od10@0OoDE5A1om6ATH6om_Kf`Oo`l?31ooZj^X6omcLg0Gooooo1oo`l?07
om7Ad@Oo9bLW1ol00007ob0P80Ko@D511omVIVH6oc0`<0Gooooo1olO7al7og9bLPOob<S81ooLg=`7
od];B`Oo5QHF1_lM7Ad6o`d=3@Kooooo1_m]KFd7oaXJ6POo10@41olV9RH7ogalO0Oooooo1_nSXj<6
oiVIV@Kooooo1om7AdL6obPX:0Oo6ATI1olC4a<7o`0000Oo4A4A1olS8b<5oo;blPKooooo1olX:2P7
oifMW@KoiNGU1olQ8B47o`0000OoEUIF1ona/K46od=3@`Gooooo1olg=cL7o`0000Ko@d=31onk^k/7
oo;blPOo@T921olD51@6omcLg0Gooooo1omcLg<7odU9B@OoFEUI1_nd];@7omCDe0Oo>3Ph1ol];Bd6
oa0@417ooooo000?ooooo`Oo00001om0@407oe5AD@OoATI61_oKfm/7ol?3``Ooj^[Z1_oLg=`5oooo
o`Ool?3`1ooAdM47obLW9`Oo00001olP8206od51@@OoIVIV1_l`<305ooooo`Oo7alO1ombLW87olS8
b0Oog=cL1om;Bd/7oaHF5PKo7AdM1_l=3@d6ooooo`KoKFe]1olJ6QX7o`@410Oo9RHV1omlO7`7oooo
o`KoXj>S1_nIVIT6ooooo`OoAdM71_lX:2P7oaTI6@Oo4a<C1ol00007oa4A4@Oo8b<S1Oobl_86oooo
o`Oo:2PX1onMWId6onGUi@Oo8B4Q1ol00007oeIFEPOo/K6a1_m3@d<5ooooo`Oo=cLg1ol00006od=3
@`Oo^k^k1oobl_87od92@POo51@D1_oLg=`5ooooo`OoLg=c1om9BDT7oeUIF@Ko];Bd1ooDe=@7ocPh
>0Oo;Bd]1_l@410Aooooo`003oooool7o`0000Oo@4101omADE47odI6APKofm_K1oo3`l<7on[ZjPKo
g=cL1Oooool7oo3`l0OodM7A1olW9bL7o`0000Oo820P1_m1@D47ofIVIPKo<30`1Oooool7oalO7`Oo
LW9b1oo8b<P7omcLg0OoBd];1olF5QH6oadM7@Ko3@d=1_ooool6ofe]K@Oo6QXJ1ol410@7obHV9POo
O7al1oooool6oj>SX`KoVIVI1_ooool7odM7A`Ko:2PX1olI6AT7oa<C4`Oo00001olA4A47ob<S8`Go
l_;b1_ooool7obPX:0OoWIfM1_oUiND7ob4Q8@Oo00001omFEUH7ok6a/@Ko@d=31Oooool7ocLg=`Oo
00001_m3@d<7ok^k^`Ool_;b1om2@T87oa@D50Kog=cL1Oooool7og=cL`OoBDU91omIFET6okBd]0Oo
e=CD1olh>3P7obd];@Ko410@4Oooool000oooooo1ol00007od10@0OoDE5A1om6ATH6om_Kf`Oo`l?3
1ooZj^X6omcLg0Gooooo1oo`l?07om7Ad@Oo9bLW1ol00007ob0P80Ko@D511omVIVH6oc0`<0Gooooo
1olO7al7og9bLPOob<S81ooLg=`7od];B`Oo5QHF1_lM7Ad6o`d=3@Kooooo1_m]KFd7oaXJ6POo10@4
1olV9RH7ogalO0Oooooo1_nSXj<6oiVIV@Kooooo1om7AdL6obPX:0Oo6ATI1olC4a<7o`0000Oo4A4A
1olS8b<5oo;blPKooooo1olX:2P7oifMW@KoiNGU1olQ8B47o`0000OoEUIF1ona/K46od=3@`Gooooo
1olg=cL7o`0000Ko@d=31onk^k/7oo;blPOo@T921olD51@6omcLg0Gooooo1omcLg<7odU9B@OoFEUI
1_nd];@7omCDe0Oo>3Ph1ol];Bd6oa0@417ooooo000?ooooo`Oo00001om0@407oe5AD@OoATI61_oK
fm/7ol?3``Ooj^[Z1_oLg=`5ooooo`Ool?3`1ooAdM47obLW9`Oo00001olP8206od51@@OoIVIV1_l`
<305ooooo`Oo7alO1ombLW87olS8b0Oog=cL1om;Bd/7oaHF5PKo7AdM1_l=3@d6ooooo`KoKFe]1olJ
6QX7o`@410Oo9RHV1omlO7`7ooooo`KoXj>S1_nIVIT6ooooo`OoAdM71_lX:2P7oaTI6@Oo4a<C1ol0
0007oa4A4@Oo8b<S1Oobl_86ooooo`Oo:2PX1onMWId6onGUi@Oo8B4Q1ol00007oeIFEPOo/K6a1_m3
@d<5ooooo`Oo=cLg1ol00006od=3@`Oo^k^k1oobl_87od92@POo51@D1_oLg=`5ooooo`OoLg=c1om9
BDT7oeUIF@Ko];Bd1ooDe=@7ocPh>0Oo;Bd]1_l@410Aooooo`003oooool7o`0000Oo@4101omADE47
odI6APKofm_K1oo3`l<7on[ZjPKog=cL1Oooool7oo3`l0OodM7A1olW9bL7o`0000Oo820P1_m1@D47
ofIVIPKo<30`1Oooool7oalO7`OoLW9b1oo8b<P7omcLg0OoBd];1olF5QH6oadM7@Ko3@d=1_ooool6
ofe]K@Oo6QXJ1ol410@7obHV9POoO7al1oooool6oj>SX`KoVIVI1_ooool7odM7A`Ko:2PX1olI6AT7
oa<C4`Oo00001olA4A47ob<S8`Gol_;b1_ooool7obPX:0OoWIfM1_oUiND7ob4Q8@Oo00001omFEUH7
ok6a/@Ko@d=31Oooool7ocLg=`Oo00001_m3@d<7ok^k^`Ool_;b1om2@T87oa@D50Kog=cL1Oooool7
og=cL`OoBDU91omIFET6okBd]0Ooe=CD1olh>3P7obd];@Ko410@4Oooool000oooooo1ol00007od10
@0OoDE5A1om6ATH6om_Kf`Oo`l?31ooZj^X6omcLg0Gooooo1oo`l?07om7Ad@Oo9bLW1ol00007ob0P
80Ko@D511omVIVH6oc0`<0Gooooo1olO7al7og9bLPOob<S81ooLg=`7od];B`Oo5QHF1_lM7Ad6o`d=
3@Kooooo1_m]KFd7oaXJ6POo10@41olV9RH7ogalO0Oooooo1_nSXj<6oiVIV@Kooooo1om7AdL6obPX
:0Oo6ATI1olC4a<7o`0000Oo4A4A1olS8b<5oo;blPKooooo1olX:2P7oifMW@KoiNGU1olQ8B47o`00
00OoEUIF1ona/K46od=3@`Gooooo1olg=cL7o`0000Ko@d=31onk^k/7oo;blPOo@T921olD51@6omcL
g0Gooooo1omcLg<7odU9B@OoFEUI1_nd];@7omCDe0Oo>3Ph1ol];Bd6oa0@417ooooo000?ooooo`Oo
;Rh^1om0@407of][J`OoE5AD1_o>c/h7omOGe`Oon?Sh1_oRh^85ooooo`Oohn?S1onm_Kd7ob8R8POo
3`l?1olT92@6oeQHF0OoG5aL1_mDE5@5ooooo`Oo=SHf1omkNg/7ol71`@OocLg=1oln?Sh7oahN7PKo
?Shn1_lU9BD6ooooo`KoE5AD1olB4Q87o`T92@Oo<c<c1on6QXH7ono_k`KoUiNG1_nBTY86ooooo`Oo
BDU91_l/;2`7oalO7`Oo4a<C1ol>3Ph7oa@D50Oo8B4Q1Oo_knl6ooooo`Oo@d=31on[Zj/6olW9b@Oo
5aLG1olO7al7oe=CD`OoX:2P1_lj>SX5ooooo`Oo:BTY1ol=3@d6oeeMG@Oo`L711ooBd]87ocDe=@Oo
8B4Q1_oBd]85ooooo`OoIFEU1omCDe<7of1PH0Ko[Jf]1oo7alL7od10@0Oo7QhN1_lL71`Aooooo`00
3oooool7obh^;POo@4101om[Jf/7oeADE0Koc/k>1ooGemL7ooShn0Koh^;R1Oooool7on?Sh`Oo_Kfm
1olR8R87o`l?3`Oo92@T1_mHF5P7oeaLG0KoE5AD1Oooool7ocHf=POoNg]k1oo1`L47olg=c@Oo?Shn
1olN7Qh6ochn?PKo9BDU1_ooool6oeADE0Oo4Q8B1ol92@T7oc<c<`OoQXJ61oo_knl6oiNGU`KoTY:B
1_ooool7odU9B@Ko;2`/1olO7al7oa<C4`Oo3Ph>1olD51@7ob4Q8@Gokno_1_ooool7od=3@`OoZj^[
1_o9bLT7oaLG5`Oo7alO1omCDe<7oj2PX0Ko>SXj1Oooool7obTY:@Oo3@d=1_mMGEd7ol71`@Ood];B
1ole=CD7ob4Q8@Kod];B1Oooool7ofEUI@OoDe=C1omPH606ojf][@OoalO71om0@407oahN7PKo71`L
4Oooool000oooooo1ol^;Rh7od10@0OoJf][1omDE5@6olk>cPOoemOG1oohn?P6on;RhPGooooo1ooS
hn<7okfm_@Oo8R8R1ol?3`l7ob@T90KoF5QH1omLG5`6oeADE0Gooooo1olf=SH7og]kN`Oo`L711oo=
cLd7ochn?POo7QhN1_ln?Sh6obDU9@Kooooo1_mDE5@7oa8B4POo2@T91olc<c<7ohJ6QPOokno_1_nG
UiL6oi:BTPKooooo1om9BDT6ob`/;0Oo7alO1olC4a<7o`h>3POo51@D1olQ8B45ono_k`Kooooo1om3
@d<7oj^[Z`KobLW91olG5aL7oalO7`OoDe=C1onPX:06ocXj>PGooooo1olY:BT7o`d=3@KoGEeM1oo1
`L47om;BdPOo=CDe1olQ8B46om;BdPGooooo1omUIFD7oe=CD`OoH61P1_n][Jd7olO7a`Oo@4101olN
7Qh6oa`L717ooooo000?ooooo`Oo;Rh^1om0@407of][J`OoE5AD1_o>c/h7omOGe`Oon?Sh1_oRh^85
ooooo`Oohn?S1onm_Kd7ob8R8POo3`l?1olT92@6oeQHF0OoG5aL1_mDE5@5ooooo`Oo=SHf1omkNg/7
ol71`@OocLg=1oln?Sh7oahN7PKo?Shn1_lU9BD6ooooo`KoE5AD1olB4Q87o`T92@Oo<c<c1on6QXH7
ono_k`KoUiNG1_nBTY86ooooo`OoBDU91_l/;2`7oalO7`Oo4a<C1ol>3Ph7oa@D50Oo8B4Q1Oo_knl6
ooooo`Oo@d=31on[Zj/6olW9b@Oo5aLG1olO7al7oe=CD`OoX:2P1_lj>SX5ooooo`Oo:BTY1ol=3@d6
oeeMG@Oo`L711ooBd]87ocDe=@Oo8B4Q1_oBd]85ooooo`OoIFEU1omCDe<7of1PH0Ko[Jf]1oo7alL7
od10@0Oo7QhN1_lL71`Aooooo`003oooool7obh^;POo@4101om[Jf/7oeADE0Koc/k>1ooGemL7ooSh
n0Koh^;R1Oooool7on?Sh`Oo_Kfm1olR8R87o`l?3`Oo92@T1_mHF5P7oeaLG0KoE5AD1Oooool7ocHf
=POoNg]k1oo1`L47olg=c@Oo?Shn1olN7Qh6ochn?PKo9BDU1_ooool6oeADE0Oo4Q8B1ol92@T7oc<c
<`OoQXJ61oo_knl6oiNGU`KoTY:B1_ooool7odU9B@Ko;2`/1olO7al7oa<C4`Oo3Ph>1olD51@7ob4Q
8@Gokno_1_ooool7od=3@`OoZj^[1_o9bLT7oaLG5`Oo7alO1omCDe<7oj2PX0Ko>SXj1Oooool7obTY
:@Oo3@d=1_mMGEd7ol71`@Ood];B1ole=CD7ob4Q8@Kod];B1Oooool7ofEUI@OoDe=C1omPH606ojf]
[@OoalO71om0@407oahN7PKo71`L4Oooool000oooooo1ol^;Rh7od10@0OoJf][1omDE5@6olk>cPOo
emOG1oohn?P6on;RhPGooooo1ooShn<7okfm_@Oo8R8R1ol?3`l7ob@T90KoF5QH1omLG5`6oeADE0Go
oooo1olf=SH7og]kN`Oo`L711oo=cLd7ochn?POo7QhN1_ln?Sh6obDU9@Kooooo1_mDE5@7oa8B4POo
2@T91olc<c<7ohJ6QPOokno_1_nGUiL6oi:BTPKooooo1om9BDT6ob`/;0Oo7alO1olC4a<7o`h>3POo
51@D1olQ8B45ono_k`Kooooo1om3@d<7oj^[Z`KobLW91olG5aL7oalO7`OoDe=C1onPX:06ocXj>PGo
oooo1olY:BT7o`d=3@KoGEeM1oo1`L47om;BdPOo=CDe1olQ8B46om;BdPGooooo1omUIFD7oe=CD`Oo
H61P1_n][Jd7olO7a`Oo@4101olN7Qh6oa`L717ooooo000?ooooo`Oo;Rh^1om0@407of][J`OoE5AD
1_o>c/h7omOGe`Oon?Sh1_oRh^85ooooo`Oohn?S1onm_Kd7ob8R8POo3`l?1olT92@6oeQHF0OoG5aL
1_mDE5@5ooooo`Oo=SHf1omkNg/7ol71`@OocLg=1oln?Sh7oahN7PKo?Shn1_lU9BD6ooooo`KoE5AD
1olB4Q87o`T92@Oo<c<c1on6QXH7ono_k`KoUiNG1_nBTY86ooooo`OoBDU91_l/;2`7oalO7`Oo4a<C
1ol>3Ph7oa@D50Oo8B4Q1Oo_knl6ooooo`Oo@d=31on[Zj/6olW9b@Oo5aLG1olO7al7oe=CD`OoX:2P
1_lj>SX5ooooo`Oo:BTY1ol=3@d6oeeMG@Oo`L711ooBd]87ocDe=@Oo8B4Q1_oBd]85ooooo`OoIFEU
1omCDe<7of1PH0Ko[Jf]1oo7alL7od10@0Oo7QhN1_lL71`Aooooo`003oooool7ob<S8`OoBDU91omO
Gel7ode=C@Ko/;2`1onf][H7omkNgPKono_k1Oooool7omWIf@OoVYZJ1olK6a/7o`P820Oo;Rh^1_m=
CDd7of9RHPKoEUIF1Oooool7ob`/;0OoNGUi1ond];@7ojVYZ@Oo>3Ph1olH61P6oc0`<0Ko6ATI1_oo
ool6oe9BDPOo3Ph>1ol<30`7ocXj>POoS8b<1ooHf=P6ogalO0KoShn?1_ooool7ocLg=`Ko9BDU1olE
5AD7oaLG5`Oo20P81olA4A47oahN7PGob/[:1_ooool7ocPh>0OoVYZJ1_nd];@7oaXJ6POo1`L71omO
Gel7ojFUY@KoADE51Oooool7obXZ:POo5aLG1_mIFET7ok>c/`Oo_;bl1ola<C47oaPH60Ko^KVi1Ooo
ool7oe9BDPOo?Cdm1om5ADD6ohJ6QPOoUiNG1olP8207o`<30`Ko20P84Oooool000oooooo1olS8b<7
odU9B@OoGemO1om=CDd6ok2`/0Oo][Jf1ooNg]h6oo_kn`Gooooo1ooIfMT7oiZJVPOo6a/K1ol820P7
obh^;PKoCDe=1omRHV86oeIFEPGooooo1ol/;2`7ogUiN@Oo];Bd1onYZJT7ocPh>0Oo61PH1_l`<306
oaTI6@Kooooo1_mBDU87o`h>3POo30`<1olj>SX7ohb<S0Oof=SH1_mlO7`6ohn?S`Kooooo1olg=cL6
obDU9@Oo5ADE1olG5aL7o`P820Oo4A4A1olN7Qh5ol[:bPKooooo1olh>3P7oiZJVPKo];Bd1olJ6QX7
o`L71`OoGemO1onUYJD6odE5A@Gooooo1olZ:RX7oaLG5`KoFEUI1onc/k<7okbl_0Oo<C4a1olH61P6
okVi^@Gooooo1omBDU87ocdm?@OoADE51_n6QXH7oiNGU`Oo820P1ol30`<6o`P8217ooooo000?oooo
o`Oo8b<S1om9BDT7oemOG`OoCDe=1_n`/;07okJf]POog]kN1_okno/5ooooo`OofMWI1onJVYX7oa/K
6`Oo20P81ol^;Rh6ode=C@OoHV9R1_mFEUH5ooooo`Oo;2`/1omiNGT7okBd]0OoZJVY1olh>3P7oaPH
60Ko<30`1_lI6AT6ooooo`KoDU9B1ol>3Ph7o``<30Oo>SXj1on<S8`7omSHf0KoO7al1_n?Shl6oooo
o`Oo=cLg1_lU9BD7oaDE5@Oo5aLG1ol820P7oa4A4@Oo7QhN1Oo:b/X6ooooo`Oo>3Ph1onJVYX6okBd
]0Oo6QXJ1ol71`L7oemOG`OoYJFU1_m5ADD5ooooo`Oo:RXZ1olG5aL6oeUIF@Oo/k>c1onl_;`7oc4a
<@Oo61PH1_ni^KT5ooooo`OoDU9B1olm?Cd7odE5A@KoQXJ61onGUiL7ob0P80Oo0`<31_l820PAoooo
o`003oooool7ob<S8`OoBDU91omOGel7ode=C@Ko/;2`1onf][H7omkNgPKono_k1Oooool7omWIf@Oo
VYZJ1olK6a/7o`P820Oo;Rh^1_m=CDd7of9RHPKoEUIF1Oooool7ob`/;0OoNGUi1ond];@7ojVYZ@Oo
>3Ph1olH61P6oc0`<0Ko6ATI1_ooool6oe9BDPOo3Ph>1ol<30`7ocXj>POoS8b<1ooHf=P6ogalO0Ko
Shn?1_ooool7ocLg=`Ko9BDU1olE5AD7oaLG5`Oo20P81olA4A47oahN7PGob/[:1_ooool7ocPh>0Oo
VYZJ1_nd];@7oaXJ6POo1`L71omOGel7ojFUY@KoADE51Oooool7obXZ:POo5aLG1_mIFET7ok>c/`Oo
_;bl1ola<C47oaPH60Ko^KVi1Oooool7oe9BDPOo?Cdm1om5ADD6ohJ6QPOoUiNG1olP8207o`<30`Ko
20P84Oooool000oooooo1olS8b<7odU9B@OoGemO1om=CDd6ok2`/0Oo][Jf1ooNg]h6oo_kn`Gooooo
1ooIfMT7oiZJVPOo6a/K1ol820P7obh^;PKoCDe=1omRHV86oeIFEPGooooo1ol/;2`7ogUiN@Oo];Bd
1onYZJT7ocPh>0Oo61PH1_l`<306oaTI6@Kooooo1_mBDU87o`h>3POo30`<1olj>SX7ohb<S0Oof=SH
1_mlO7`6ohn?S`Kooooo1olg=cL6obDU9@Oo5ADE1olG5aL7o`P820Oo4A4A1olN7Qh5ol[:bPKooooo
1olh>3P7oiZJVPKo];Bd1olJ6QX7o`L71`OoGemO1onUYJD6odE5A@Gooooo1olZ:RX7oaLG5`KoFEUI
1onc/k<7okbl_0Oo<C4a1olH61P6okVi^@Gooooo1omBDU87ocdm?@OoADE51_n6QXH7oiNGU`Oo820P
1ol30`<6o`P8217ooooo000?ooooo`Oo8b<S1om9BDT7oemOG`OoCDe=1_n`/;07okJf]POog]kN1_ok
no/5ooooo`OofMWI1onJVYX7oa/K6`Oo20P81ol^;Rh6ode=C@OoHV9R1_mFEUH5ooooo`Oo;2`/1omi
NGT7okBd]0OoZJVY1olh>3P7oaPH60Ko<30`1_lI6AT6ooooo`KoDU9B1ol>3Ph7o``<30Oo>SXj1on<
S8`7omSHf0KoO7al1_n?Shl6ooooo`Oo=cLg1_lU9BD7oaDE5@Oo5aLG1ol820P7oa4A4@Oo7QhN1Oo:
b/X6ooooo`Oo>3Ph1onJVYX6okBd]0Oo6QXJ1ol71`L7oemOG`OoYJFU1_m5ADD5ooooo`Oo:RXZ1olG
5aL6oeUIF@Oo/k>c1onl_;`7oc4a<@Oo61PH1_ni^KT5ooooo`OoDU9B1olm?Cd7odE5A@KoQXJ61onG
UiL7ob0P80Oo0`<31_l820PAooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-2.32564, \
-0.204693, 0.148839, 0.148839}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-11.135, -0.204693, 0.148839, 0.148839}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-19.9351, -0.204693, 0.148839, 0.148839}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-28.7352, -0.204693, 0.148839, 0.148839}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-37.5353, -0.204693, 0.148839, 0.148839}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-46.3354, -0.204693, 0.148839, \
0.148839}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-55.1355, -0.204693, \
0.148839, 0.148839}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-63.9356, \
-0.204693, 0.148839, 0.148839}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F1C32201A1B2180
1605260313051361
1E222D1A151A197E
181223131E001561
242E362323221E80
15051D111613245F
2F192A1C1A202579
F1D8F6C5D8C7D9FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3D00AE6905590A57
321CE09C123F043E
4912DCCA004C2049
452EFFDD2938163D
642DC5FC11582C51
583BBCE73054283D
7A2F62E616543A48
4C3A8F69224D2160
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
49472E180B0E1C78
4B451E1A090A1A7A
524E371D11001E8C
5B5B2C200905178A
5D593C27170B1D99
625F3A231B0B1893
5566492E292035AD
8A755D37382844FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
75B60966205D973D
83F0024F1C55AC57
5CF8095D3441B242
4FFF00403148BE3E
44E10056492FBF4D
38C20E52392CB678
31AE054A5217A4B1
71862B4D29617856
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
22423A82A19A7F72
0E202E688F8D8354
12201B618CA57A63
00011F4C6B93805B
0D08104568807461
0F19284668766B5E
1C19385470715859
4B7282E3F4FFEE93
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AF0B401F74910166
D4003E2279A40181
DD04411A77CC005E
F2003D217DEC0E87
D31A5E1C64FF0675
CF1F533350E61581
982B743A31EE097A
981C5E3D68741C94
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17344D355A173EFF
0E2844245D243CD8
081E3717561935B3
0B1B2908460D257E
011827034107234C
0B211C002F0C1B3B
1B272A053311273D
27373F3B492539A6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
024502251B0B3654
023C0D321B0B2E78
0243122F240D2CAE
01301C3C331030CE
053C2834421532FF
06232D2C53193AED
002A2F20551630C8
02350F1B2C122F3E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool7oalO7`Oo71`L1olb<S87ob0P80Ko6QXJ1olK6a/7ob4Q8@Ko
P8201Oooool7ocdm?@Oo00001on^[Zh7ofUYJ@Oo1@D51_mIFET7o`X:2PKoEeMG1Oooool7odU9B@Oo
AdM71ol^;Rh7oaPH60Oo2`/;1ol>3Ph6oa`L70KoN7Qh1_ooool6ogEeM@Oo][Jf1ol92@T7ofIVIPOo
820P1omMGEd6oiNGU`Ko?Cdm1_ooool7ob8R8PKo@T921olj>SX7oh:2PPOoXJ6Q1onJVYX7ogmoO`Go
LW9b1_ooool7ojn_[`Oo2`/;1_m0@407oalO7`OoM7Ad1onATI47o`410@KoIVIV1Oooool7oaLG5`Oo
=3@d1_m=CDd7ocDe=@OoFUYJ1olG5aL7ochn?P_ooooo1ol20P87odE5A@Oo0P821_lU9BD7oa/K6`Oo
2`/;1olf=SH6oeADE17ooooo000?ooooo`Oo7alO1olL71`7oc8b<POo820P1_lJ6QX7oa/K6`Oo8B4Q
1_n0P805ooooo`Oo?Cdm1ol00007ojj^[POoJFUY1ol51@D6oeUIF@Oo2PX:1_mGEeL5ooooo`OoBDU9
1om7AdL7obh^;POo61PH1ol;2`/7o`h>3PKo71`L1_mhN7P6ooooo`KoMGEe1onf][H7o`T92@OoIVIV
1olP8207oeeMG@KoUiNG1_lm?Cd6ooooo`Oo8R8R1_m2@T87ocXj>POoPX:21onQXJ47oiZJVPOoOgmo
1OmbLW86ooooo`Oo[jn_1ol;2`/6od10@0Oo7alO1omdM7@7oi6AT@Oo0@411_mVIVH5ooooo`Oo5aLG
1old=3@6ode=C@Oo=CDe1omJFUX7oaLG5`Oo?Shn2oooool7o`820POoADE51ol20P86obDU9@Oo6a/K
1ol;2`/7ocHf=PKoE5AD4Oooool000oooooo1olO7al7oa`L70Oo<S8b1olP8206oaXJ6POo6a/K1olQ
8B46oh20P0Gooooo1olm?Cd7o`0000Oo[Zj^1omYJFT7o`D51@KoFEUI1ol:2PX6oeMGE`Gooooo1om9
BDT7odM7A`Oo;Rh^1olH61P7o`/;2`Oo3Ph>1_lL71`6ogQhN0Kooooo1_meMGD7okJf]POo2@T91omV
IVH7ob0P80OoGEeM1_nGUiL6ocdm?@Kooooo1olR8R86od92@POo>SXj1on2PX87oj6QX@OoVYZJ1omo
Ogl5og9bLPKooooo1on_[jl7o`/;2`Ko@4101olO7al7ogAdM0OoTI6A1ol10@46ofIVIPGooooo1olG
5aL7oc@d=0KoCDe=1ole=CD7oeYJFPOo5aLG1oln?Sh;ooooo`Oo0P821om5ADD7o`820PKo9BDU1olK
6a/7o`/;2`Oo=SHf1_mDE5@Aooooo`003oooool7oalO7`Oo71`L1olb<S87ob0P80Ko6QXJ1olK6a/7
ob4Q8@KoP8201Oooool7ocdm?@Oo00001on^[Zh7ofUYJ@Oo1@D51_mIFET7o`X:2PKoEeMG1Oooool7
odU9B@OoAdM71ol^;Rh7oaPH60Oo2`/;1ol>3Ph6oa`L70KoN7Qh1_ooool6ogEeM@Oo][Jf1ol92@T7
ofIVIPOo820P1omMGEd6oiNGU`Ko?Cdm1_ooool7ob8R8PKo@T921olj>SX7oh:2PPOoXJ6Q1onJVYX7
ogmoO`GoLW9b1_ooool7ojn_[`Oo2`/;1_m0@407oalO7`OoM7Ad1onATI47o`410@KoIVIV1Oooool7
oaLG5`Oo=3@d1_m=CDd7ocDe=@OoFUYJ1olG5aL7ochn?P_ooooo1ol20P87odE5A@Oo0P821_lU9BD7
oa/K6`Oo2`/;1olf=SH6oeADE17ooooo000?ooooo`Oo7alO1olL71`7oc8b<POo820P1_lJ6QX7oa/K
6`Oo8B4Q1_n0P805ooooo`Oo?Cdm1ol00007ojj^[POoJFUY1ol51@D6oeUIF@Oo2PX:1_mGEeL5oooo
o`OoBDU91om7AdL7obh^;POo61PH1ol;2`/7o`h>3PKo71`L1_mhN7P6ooooo`KoMGEe1onf][H7o`T9
2@OoIVIV1olP8207oeeMG@KoUiNG1_lm?Cd6ooooo`Oo8R8R1_m2@T87ocXj>POoPX:21onQXJ47oiZJ
VPOoOgmo1OmbLW86ooooo`Oo[jn_1ol;2`/6od10@0Oo7alO1omdM7@7oi6AT@Oo0@411_mVIVH5oooo
o`Oo5aLG1old=3@6ode=C@Oo=CDe1omJFUX7oaLG5`Oo?Shn2oooool7o`820POoADE51ol20P86obDU
9@Oo6a/K1ol;2`/7ocHf=PKoE5AD4Oooool000oooooo1olO7al7oa`L70Oo<S8b1olP8206oaXJ6POo
6a/K1olQ8B46oh20P0Gooooo1olm?Cd7o`0000Oo[Zj^1omYJFT7o`D51@KoFEUI1ol:2PX6oeMGE`Go
oooo1om9BDT7odM7A`Oo;Rh^1olH61P7o`/;2`Oo3Ph>1_lL71`6ogQhN0Kooooo1_meMGD7okJf]POo
2@T91omVIVH7ob0P80OoGEeM1_nGUiL6ocdm?@Kooooo1olR8R86od92@POo>SXj1on2PX87oj6QX@Oo
VYZJ1omoOgl5og9bLPKooooo1on_[jl7o`/;2`Ko@4101olO7al7ogAdM0OoTI6A1ol10@46ofIVIPGo
oooo1olG5aL7oc@d=0KoCDe=1ole=CD7oeYJFPOo5aLG1oln?Sh;ooooo`Oo0P821om5ADD7o`820PKo
9BDU1olK6a/7o`/;2`Oo=SHf1_mDE5@Aooooo`003oooool7oalO7`Oo71`L1olb<S87ob0P80Ko6QXJ
1olK6a/7ob4Q8@KoP8201Oooool7ocdm?@Oo00001on^[Zh7ofUYJ@Oo1@D51_mIFET7o`X:2PKoEeMG
1Oooool7odU9B@OoAdM71ol^;Rh7oaPH60Oo2`/;1ol>3Ph6oa`L70KoN7Qh1_ooool6ogEeM@Oo][Jf
1ol92@T7ofIVIPOo820P1omMGEd6oiNGU`Ko?Cdm1_ooool7ob8R8PKo@T921olj>SX7oh:2PPOoXJ6Q
1onJVYX7ogmoO`GoLW9b1_ooool7ojn_[`Oo2`/;1_m0@407oalO7`OoM7Ad1onATI47o`410@KoIVIV
1Oooool7oaLG5`Oo=3@d1_m=CDd7ocDe=@OoFUYJ1olG5aL7ochn?P_ooooo1ol20P87odE5A@Oo0P82
1_lU9BD7oa/K6`Oo2`/;1olf=SH6oeADE17ooooo000?ooooo`Oo5QHF1ol51@D7obHV9POo0`<31_lC
4a<7o`D51@Oo4a<C1_mQHF45ooooo`Oo<S8b1olL71`7on3Ph0OoW9bL1olB4Q86oclo?`Oo10@41_ln
?Sh5ooooo`OoBd];1om5ADD7oahN7POo6QXJ1ol92@T7o`X:2PKo6QXJ1_mjNWX6ooooo`KoPh>31oo`
l?07o`820POoCdm?1olL71`7oeEEE@Ko[:b/1_mGEeL6ooooo`Oo3Ph>1_lP8207obh^;POoJ6QX1on?
Shl7ohf=S@OoPh>31OmDE5@6ooooo`Ooe=CD1ol00006ochn?POo8R8R1omiNGT7ojBTY0Oo0@411_n1
PH45ooooo`Oo3Ph>1olX:2P6odA4A0Oo92@T1omMGEd7ob@T90Oo?3`l1_oHf=P5ooooo`Oo0P821oll
?3`7o`d=3@Ko<S8b1olK6a/7o`/;2`Oo;Rh^1_mhN7PAooooo`003oooool7oaHF5POo1@D51olV9RH7
o`<30`Ko4a<C1ol51@D7oa<C4`KoHF5Q1Oooool7oc8b<POo71`L1ooPh>07oibLW0Oo4Q8B1_lo?cl7
o`@410Ko?Shn1Oooool7od];B`OoADE51olN7Qh7oaXJ6POo2@T91ol:2PX6oaXJ6PKoNWYj1_ooool6
oh>3P`Ool?3`1ol20P87odm?C`Oo71`L1omEEED6ojb/[0KoEeMG1_ooool7o`h>3PKo820P1ol^;Rh7
ofQXJ0OoShn?1on=SHd7oh>3P`GoE5AD1_ooool7omCDe0Oo00001_ln?Sh7ob8R8POoNGUi1onTY:@7
o`410@KoPH611Oooool7o`h>3POo:2PX1_m4A4@7ob@T90OoGEeM1olT92@7oc`l?0Kof=SH1Oooool7
o`820POo?3`l1ol=3@d6oc8b<POo6a/K1ol;2`/7obh^;PKoN7Qh4Oooool000oooooo1olF5QH7o`D5
1@Oo9RHV1ol30`<6oa<C4`Oo1@D51olC4a<6of5QH@Gooooo1olb<S87oa`L70Ooh>3P1onLW9`7oa8B
4PKo?clo1ol410@6ochn?PGooooo1om;Bd/7odE5A@Oo7QhN1olJ6QX7o`T92@Oo2PX:1_lJ6QX6ogYj
NPKooooo1_n3Ph<7oo3`l0Oo0P821om?Cdl7oa`L70OoEEEE1_n/[:`6oeMGE`Kooooo1ol>3Ph6ob0P
80Oo;Rh^1omXJ6P7ohn?S`OoSHf=1on3Ph<5oeADE0Kooooo1ooDe=@7o`0000Ko?Shn1olR8R87ogUi
N@OoY:BT1ol10@46oh61P@Gooooo1ol>3Ph7obPX:0KoA4A41olT92@7oeeMG@Oo92@T1oll?3`6omSH
f0Gooooo1ol20P87oc`l?0Oo3@d=1_lb<S87oa/K6`Oo2`/;1ol^;Rh6ogQhN17ooooo000?ooooo`Oo
5QHF1ol51@D7obHV9POo0`<31_lC4a<7o`D51@Oo4a<C1_mQHF45ooooo`Oo<S8b1olL71`7on3Ph0Oo
W9bL1olB4Q86oclo?`Oo10@41_ln?Sh5ooooo`OoBd];1om5ADD7oahN7POo6QXJ1ol92@T7o`X:2PKo
6QXJ1_mjNWX6ooooo`KoPh>31oo`l?07o`820POoCdm?1olL71`7oeEEE@Ko[:b/1_mGEeL6ooooo`Oo
3Ph>1_lP8207obh^;POoJ6QX1on?Shl7ohf=S@OoPh>31OmDE5@6ooooo`Ooe=CD1ol00006ochn?POo
8R8R1omiNGT7ojBTY0Oo0@411_n1PH45ooooo`Oo3Ph>1olX:2P6odA4A0Oo92@T1omMGEd7ob@T90Oo
?3`l1_oHf=P5ooooo`Oo0P821oll?3`7o`d=3@Ko<S8b1olK6a/7o`/;2`Oo;Rh^1_mhN7PAooooo`00
3oooool7oaHF5POo1@D51olV9RH7o`<30`Ko4a<C1ol51@D7oa<C4`KoHF5Q1Oooool7oc8b<POo71`L
1ooPh>07oibLW0Oo4Q8B1_lo?cl7o`@410Ko?Shn1Oooool7od];B`OoADE51olN7Qh7oaXJ6POo2@T9
1ol:2PX6oaXJ6PKoNWYj1_ooool6oh>3P`Ool?3`1ol20P87odm?C`Oo71`L1omEEED6ojb/[0KoEeMG
1_ooool7o`h>3PKo820P1ol^;Rh7ofQXJ0OoShn?1on=SHd7oh>3P`GoE5AD1_ooool7omCDe0Oo0000
1_ln?Sh7ob8R8POoNGUi1onTY:@7o`410@KoPH611Oooool7o`h>3POo:2PX1_m4A4@7ob@T90OoGEeM
1olT92@7oc`l?0Kof=SH1Oooool7o`820POo?3`l1ol=3@d6oc8b<POo6a/K1ol;2`/7obh^;PKoN7Qh
4Oooool000oooooo1olF5QH7o`D51@Oo9RHV1ol30`<6oa<C4`Oo1@D51olC4a<6of5QH@Gooooo1olb
<S87oa`L70Ooh>3P1onLW9`7oa8B4PKo?clo1ol410@6ochn?PGooooo1om;Bd/7odE5A@Oo7QhN1olJ
6QX7o`T92@Oo2PX:1_lJ6QX6ogYjNPKooooo1_n3Ph<7oo3`l0Oo0P821om?Cdl7oa`L70OoEEEE1_n/
[:`6oeMGE`Kooooo1ol>3Ph6ob0P80Oo;Rh^1omXJ6P7ohn?S`OoSHf=1on3Ph<5oeADE0Kooooo1ooD
e=@7o`0000Ko?Shn1olR8R87ogUiN@OoY:BT1ol10@46oh61P@Gooooo1ol>3Ph7obPX:0KoA4A41olT
92@7oeeMG@Oo92@T1oll?3`6omSHf0Gooooo1ol20P87oc`l?0Oo3@d=1_lb<S87oa/K6`Oo2`/;1ol^
;Rh6ogQhN17ooooo000?ooooo`Oo5QHF1ol51@D7obHV9POo0`<31_lC4a<7o`D51@Oo4a<C1_mQHF45
ooooo`Oo<S8b1olL71`7on3Ph0OoW9bL1olB4Q86oclo?`Oo10@41_ln?Sh5ooooo`OoBd];1om5ADD7
oahN7POo6QXJ1ol92@T7o`X:2PKo6QXJ1_mjNWX6ooooo`KoPh>31oo`l?07o`820POoCdm?1olL71`7
oeEEE@Ko[:b/1_mGEeL6ooooo`Oo3Ph>1_lP8207obh^;POoJ6QX1on?Shl7ohf=S@OoPh>31OmDE5@6
ooooo`Ooe=CD1ol00006ochn?POo8R8R1omiNGT7ojBTY0Oo0@411_n1PH45ooooo`Oo3Ph>1olX:2P6
odA4A0Oo92@T1omMGEd7ob@T90Oo?3`l1_oHf=P5ooooo`Oo0P821oll?3`7o`d=3@Ko<S8b1olK6a/7
o`/;2`Oo;Rh^1_mhN7PAooooo`003oooool7oahN7POo8R8R1ol];Bd7oaXJ6PKo5ADE1olJ6QX7oaTI
6@KoOWin1Oooool7odU9B@Oo4Q8B1ooLg=`7ol[:bPOo00001_m<C4`7ob0P80KoBDU91Oooool7oe9B
DPOoCTi>1olg=cL7oadM7@Oo4A4A1ol00006oahN7PKoS8b<1_ooool6oeaLG0Oon?Sh1ol92@T7oeeM
G@Oo=3@d1om1@D46ok:b/PKo@T921_ooool7oa8B4PKo820P1olK6a/7of5QH@OoS8b<1onUYJD7ogYj
NPGoHf=S1_ooool7omgMg@Oo10@41_m1@D47oaXJ6POoMgMg1oo<c<`7o`0000KoGUiN1Oooool7o`P8
20Oo7QhN1_lg=cL7oaLG5`OoEUIF1olI6AT7ocDe=@Ko/k>c1Oooool7o`820POo@d=31olB4Q86obl_
;`Oo92@T1ol=3@d7ob`/;0Ko[Zj^4Oooool000oooooo1olN7Qh7ob8R8POo;Bd]1olJ6QX6oaDE5@Oo
6QXJ1olI6AT6oginOPGooooo1om9BDT7oa8B4POog=cL1oo:b/X7o`0000KoC4a<1olP8206odU9B@Go
oooo1omBDU87odi>CPOo=cLg1olM7Ad7oa4A4@Oo00001_lN7Qh6ohb<S0Kooooo1_mLG5`7ooShn0Oo
2@T91omMGEd7oc@d=0Oo@D511_nb/[86od92@PKooooo1olB4Q86ob0P80Oo6a/K1omQHF47ohb<S0Oo
YJFU1omjNWX5of=SH`Kooooo1ooMgMd7o`@410Ko@D511olJ6QX7ogMgM`Ooc<c<1ol00006oeiNGPGo
oooo1ol820P7oahN7PKo=cLg1olG5aL7oeIFEPOo6ATI1ole=CD6ok>c/`Gooooo1ol20P87od=3@`Oo
4Q8B1_l_;bl7ob@T90Oo3@d=1ol/;2`6ojj^[Q7ooooo000?ooooo`Oo7QhN1olR8R87obd];@Oo6QXJ
1_lE5AD7oaXJ6POo6ATI1_mnOWh5ooooo`OoBDU91olB4Q87omcLg0Oob/[:1ol00006oda<C0Oo820P
1_m9BDT5ooooo`OoDU9B1om>CTh7ocLg=`Oo7AdM1olA4A47o`0000Ko7QhN1_n<S8`6ooooo`KoG5aL
1oohn?P7o`T92@OoGEeM1old=3@7od51@@Ko/[:b1_m2@T86ooooo`Oo4Q8B1_lP8207oa/K6`OoHF5Q
1on<S8`7ojFUY@OoNWYj1OmSHf<6ooooo`OogMgM1ol410@6od51@@Oo6QXJ1omgMgL7olc<c0Oo0000
1_mNGUh5ooooo`Oo20P81olN7Qh6ocLg=`Oo5aLG1omFEUH7oaTI6@Oo=CDe1_nc/k<5ooooo`Oo0P82
1om3@d<7oa8B4PKo;bl_1olT92@7o`d=3@Oo;2`/1_n^[ZhAooooo`003oooool7oahN7POo8R8R1ol]
;Bd7oaXJ6PKo5ADE1olJ6QX7oaTI6@KoOWin1Oooool7odU9B@Oo4Q8B1ooLg=`7ol[:bPOo00001_m<
C4`7ob0P80KoBDU91Oooool7oe9BDPOoCTi>1olg=cL7oadM7@Oo4A4A1ol00006oahN7PKoS8b<1_oo
ool6oeaLG0Oon?Sh1ol92@T7oeeMG@Oo=3@d1om1@D46ok:b/PKo@T921_ooool7oa8B4PKo820P1olK
6a/7of5QH@OoS8b<1onUYJD7ogYjNPGoHf=S1_ooool7omgMg@Oo10@41_m1@D47oaXJ6POoMgMg1oo<
c<`7o`0000KoGUiN1Oooool7o`P820Oo7QhN1_lg=cL7oaLG5`OoEUIF1olI6AT7ocDe=@Ko/k>c1Ooo
ool7o`820POo@d=31olB4Q86obl_;`Oo92@T1ol=3@d7ob`/;0Ko[Zj^4Oooool000oooooo1olN7Qh7
ob8R8POo;Bd]1olJ6QX6oaDE5@Oo6QXJ1olI6AT6oginOPGooooo1om9BDT7oa8B4POog=cL1oo:b/X7
o`0000KoC4a<1olP8206odU9B@Gooooo1omBDU87odi>CPOo=cLg1olM7Ad7oa4A4@Oo00001_lN7Qh6
ohb<S0Kooooo1_mLG5`7ooShn0Oo2@T91omMGEd7oc@d=0Oo@D511_nb/[86od92@PKooooo1olB4Q86
ob0P80Oo6a/K1omQHF47ohb<S0OoYJFU1omjNWX5of=SH`Kooooo1ooMgMd7o`@410Ko@D511olJ6QX7
ogMgM`Ooc<c<1ol00006oeiNGPGooooo1ol820P7oahN7PKo=cLg1olG5aL7oeIFEPOo6ATI1ole=CD6
ok>c/`Gooooo1ol20P87od=3@`Oo4Q8B1_l_;bl7ob@T90Oo3@d=1ol/;2`6ojj^[Q7ooooo000?oooo
o`Oo7QhN1olR8R87obd];@Oo6QXJ1_lE5AD7oaXJ6POo6ATI1_mnOWh5ooooo`OoBDU91olB4Q87omcL
g0Oob/[:1ol00006oda<C0Oo820P1_m9BDT5ooooo`OoDU9B1om>CTh7ocLg=`Oo7AdM1olA4A47o`00
00Ko7QhN1_n<S8`6ooooo`KoG5aL1oohn?P7o`T92@OoGEeM1old=3@7od51@@Ko/[:b1_m2@T86oooo
o`Oo4Q8B1_lP8207oa/K6`OoHF5Q1on<S8`7ojFUY@OoNWYj1OmSHf<6ooooo`OogMgM1ol410@6od51
@@Oo6QXJ1omgMgL7olc<c0Oo00001_mNGUh5ooooo`Oo20P81olN7Qh6ocLg=`Oo5aLG1omFEUH7oaTI
6@Oo=CDe1_nc/k<5ooooo`Oo0P821om3@d<7oa8B4PKo;bl_1olT92@7o`d=3@Oo;2`/1_n^[ZhAoooo
o`003oooool7oaPH60Oo4Q8B1olS8b<7oa<C4`Ko7QhN1ol00007oaDE5@KoHF5Q1Oooool7odE5A@Oo
;Rh^1oooool7omgMg@Oo:BTY1_lh>3P7oaHF5PKo?Cdm1Oooool>oe]KF`Oo;2`/1olP8207o`T92@Oo
1@D51_lG5aL6ohZ:RPKooooo1_m?Cdl7ooooo`Oo00001om0@407oc4a<@OoB4Q81_nn_[h6ochn?PKo
oooo1ol00006o`410@Oo7alO1om<C4`7of][J`OoTi>C1on0P805oe]KF`Kooooo1oobl_87o`0000Ko
?Cdm1olQ8B47ogemO@Ook>c/1ol>3Ph6ohN7Q`Gooooo1ol;2`/7oa/K6`Ko:BTY1ol820P7odI6APOo
3@d=1olU9BD6oginOPGooooo1ol10@47oc0`<0Oo71`L1_ll?3`7oc<c<`Oo410@1ol`<306olk>cQ7o
oooo000?ooooo`Oo61PH1olB4Q87ob<S8`Oo4a<C1_lN7Qh7o`0000Oo5ADE1_mQHF45ooooo`OoADE5
1ol^;Rh7ooooo`OogMgM1olY:BT6ocPh>0Oo5QHF1_lm?Cd5ooooo`koFe]K1ol/;2`7ob0P80Oo2@T9
1ol51@D6oaLG5`KoRXZ:1_ooool6odm?C`Oooooo1ol00007od10@0Oo<C4a1om8B4P6okjn_PKo?Shn
1_ooool7o`0000Ko0@411olO7al7oda<C0OoJf][1onCTi<7oh20P0GoFe]K1_ooool7oo;blPOo0000
1_lm?Cd7ob4Q8@OoOGem1oo/k>`7o`h>3PKoQhN71Oooool7o`/;2`Oo6a/K1_lY:BT7o`P820OoATI6
1ol=3@d7obDU9@KoOWin1Oooool7o`410@Oo<30`1olL71`6oc`l?0Oo<c<c1ol@4107oc0`<0Koc/k>
4Oooool000oooooo1olH61P7oa8B4POo8b<S1olC4a<6oahN7POo00001olE5AD6of5QH@Gooooo1om5
ADD7obh^;POooooo1ooMgMd7obTY:@Ko>3Ph1olF5QH6ocdm?@Gooooo3_mKFe/7ob`/;0Oo820P1ol9
2@T7o`D51@Ko5aLG1_n:RXX6ooooo`KoCdm?1oooool7o`0000Oo@4101ola<C47odQ8B0Ko_[jn1_ln
?Sh6ooooo`Oo00001_l10@47oalO7`OoC4a<1om[Jf/7oi>CT`OoP8201OmKFe/6ooooo`Ool_;b1ol0
0006ocdm?@Oo8B4Q1ommOGd7onc/k0Oo3Ph>1_n7QhL5ooooo`Oo2`/;1olK6a/6obTY:@Oo20P81om6
ATH7o`d=3@Oo9BDU1_mnOWh5ooooo`Oo0@411ol`<307oa`L70Ko?3`l1olc<c<7oa0@40Oo<30`1_o>
c/hAooooo`003oooool7oaPH60Oo4Q8B1olS8b<7oa<C4`Ko7QhN1ol00007oaDE5@KoHF5Q1Oooool7
odE5A@Oo;Rh^1oooool7omgMg@Oo:BTY1_lh>3P7oaHF5PKo?Cdm1Oooool>oe]KF`Oo;2`/1olP8207
o`T92@Oo1@D51_lG5aL6ohZ:RPKooooo1_m?Cdl7ooooo`Oo00001om0@407oc4a<@OoB4Q81_nn_[h6
ochn?PKooooo1ol00006o`410@Oo7alO1om<C4`7of][J`OoTi>C1on0P805oe]KF`Kooooo1oobl_87
o`0000Ko?Cdm1olQ8B47ogemO@Ook>c/1ol>3Ph6ohN7Q`Gooooo1ol;2`/7oa/K6`Ko:BTY1ol820P7
odI6APOo3@d=1olU9BD6oginOPGooooo1ol10@47oc0`<0Oo71`L1_ll?3`7oc<c<`Oo410@1ol`<306
olk>cQ7ooooo000?ooooo`Oo61PH1olB4Q87ob<S8`Oo4a<C1_lN7Qh7o`0000Oo5ADE1_mQHF45oooo
o`OoADE51ol^;Rh7ooooo`OogMgM1olY:BT6ocPh>0Oo5QHF1_lm?Cd5ooooo`koFe]K1ol/;2`7ob0P
80Oo2@T91ol51@D6oaLG5`KoRXZ:1_ooool6odm?C`Oooooo1ol00007od10@0Oo<C4a1om8B4P6okjn
_PKo?Shn1_ooool7o`0000Ko0@411olO7al7oda<C0OoJf][1onCTi<7oh20P0GoFe]K1_ooool7oo;b
lPOo00001_lm?Cd7ob4Q8@OoOGem1oo/k>`7o`h>3PKoQhN71Oooool7o`/;2`Oo6a/K1_lY:BT7o`P8
20OoATI61ol=3@d7obDU9@KoOWin1Oooool7o`410@Oo<30`1olL71`6oc`l?0Oo<c<c1ol@4107oc0`
<0Koc/k>4Oooool000oooooo1olH61P7oa8B4POo8b<S1olC4a<6oahN7POo00001olE5AD6of5QH@Go
oooo1om5ADD7obh^;POooooo1ooMgMd7obTY:@Ko>3Ph1olF5QH6ocdm?@Gooooo3_mKFe/7ob`/;0Oo
820P1ol92@T7o`D51@Ko5aLG1_n:RXX6ooooo`KoCdm?1oooool7o`0000Oo@4101ola<C47odQ8B0Ko
_[jn1_ln?Sh6ooooo`Oo00001_l10@47oalO7`OoC4a<1om[Jf/7oi>CT`OoP8201OmKFe/6ooooo`Oo
l_;b1ol00006ocdm?@Oo8B4Q1ommOGd7onc/k0Oo3Ph>1_n7QhL5ooooo`Oo2`/;1olK6a/6obTY:@Oo
20P81om6ATH7o`d=3@Oo9BDU1_mnOWh5ooooo`Oo0@411ol`<307oa`L70Ko?3`l1olc<c<7oa0@40Oo
<30`1_o>c/hAooooo`003oooool7oaPH60Oo4Q8B1olS8b<7oa<C4`Ko7QhN1ol00007oaDE5@KoHF5Q
1Oooool7odE5A@Oo;Rh^1oooool7omgMg@Oo:BTY1_lh>3P7oaHF5PKo?Cdm1Oooool>oe]KF`Oo;2`/
1olP8207o`T92@Oo1@D51_lG5aL6ohZ:RPKooooo1_m?Cdl7ooooo`Oo00001om0@407oc4a<@OoB4Q8
1_nn_[h6ochn?PKooooo1ol00006o`410@Oo7alO1om<C4`7of][J`OoTi>C1on0P805oe]KF`Kooooo
1oobl_87o`0000Ko?Cdm1olQ8B47ogemO@Ook>c/1ol>3Ph6ohN7Q`Gooooo1ol;2`/7oa/K6`Ko:BTY
1ol820P7odI6APOo3@d=1olU9BD6oginOPGooooo1ol10@47oc0`<0Oo71`L1_ll?3`7oc<c<`Oo410@
1ol`<306olk>cQ7ooooo000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Ooo
ool7ofATI0Oo;Bd]1oo5aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll
?3`7obLW9`Oo5aLG1ol;2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_
;bl6okno_`KoCDe=1_ooool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_oo
ool7om?Cd`Oo6QXJ1_mNGUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW
9bL7o`<30`Oo@D511ol71`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE
5AD7oc8b<QOooooo000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Oooool7
ofATI0Oo;Bd]1oo5aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll?3`7
obLW9`Oo5aLG1ol;2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_;bl6
okno_`KoCDe=1_ooool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_ooool7
om?Cd`Oo6QXJ1_mNGUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW9bL7
o`<30`Oo@D511ol71`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE5AD7
oc8b<QOooooo000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Oooool7ofAT
I0Oo;Bd]1oo5aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll?3`7obLW
9`Oo5aLG1ol;2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_;bl6okno
_`KoCDe=1_ooool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_ooool7om?C
d`Oo6QXJ1_mNGUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW9bL7o`<3
0`Oo@D511ol71`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE5AD7oc8b
<QOooooo000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Oooool7ofATI0Oo
;Bd]1oo5aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll?3`7obLW9`Oo
5aLG1ol;2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_;bl6okno_`Ko
CDe=1_ooool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_ooool7om?Cd`Oo
6QXJ1_mNGUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW9bL7o`<30`Oo
@D511ol71`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE5AD7oc8b<QOo
oooo000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Oooool7ofATI0Oo;Bd]
1oo5aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll?3`7obLW9`Oo5aLG
1ol;2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_;bl6okno_`KoCDe=
1_ooool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_ooool7om?Cd`Oo6QXJ
1_mNGUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW9bL7o`<30`Oo@D51
1ol71`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE5AD7oc8b<QOooooo
000?ooooo`Oo92@T1ol^;Rh7ocHf=Pgo8b<S1olR8R87oahN7PKoP8201Oooool7ofATI0Oo;Bd]1oo5
aLD7ooclo0Oo4A4A1_mHF5P7ob`/;0KoDE5A1Oooool7oeeMG@OoFEUI1oll?3`7obLW9`Oo5aLG1ol;
2`/6oadM7@KoVIVI1_ooool6odA4A0OohN7Q1ol00007oeIFEPOoBDU91ol_;bl6okno_`KoCDe=1_oo
ool7o`d=3@Ko20P81ol@4107odE5A@OoJ6QX1on0P807ogAdM0GoHF5Q1_ooool7om?Cd`Oo6QXJ1_mN
GUh7oa`L70OoI6AT1oooool7o`H61PKoMGEe1Oooool7o`410@Oo61PH1_lW9bL7o`<30`Oo@D511ol7
1`L7ob<S8`KoC4a<1Oooool7o`D51@Oo?3`l1olX:2P6oc@d=0Oo@T921olE5AD7oc8b<QOooooo000?
ooooo`Oo5ADE1ol51@D7oadM7@Oo4A4A1_lF5QH7oa<C4`Oo92@T1_mOGel5ooooo`OoF5QH1olk>c/7
okbl_0OoinOW1ol`<306oeADE0Oo:2PX1_lm?Cd5ooooo`OoHV9R1omOGel7ocXj>POo8b<S1olK6a/7
o`/;2`Ko61PH1_nCTi<6ooooo`Ko>3Ph1oo2`/87o`h>3POoDU9B1oli>CT7ob`/;0Ko][Jf1_mhN7P6
ooooo`Oo3`l?1_lI6AT7obPX:0OoATI61omXJ6P7ogIfMPOoJf][1OmNGUh6ooooo`Ooclo?1olO7al6
oe=CD`Oo<c<c1om@D507onKViPOo5ADE1_n1PH45ooooo`Oo2`/;1olQ8B46oa`L70Oo00001ol_;bl7
o``<30Oo6a/K1_lk>c/5ooooo`Oo1PH61olS8b<7obd];@Ko;2`/1omCDe<7oaTI6@Oo>SXj1_o]kNdA
ooooo`003oooool7oaDE5@Oo1@D51olM7Ad7oa4A4@Ko5QHF1olC4a<7ob@T90KoGemO1Oooool7oeQH
F0Oo>c/k1onl_;`7onOWi`Oo<30`1_mDE5@7obPX:0Ko?Cdm1Oooool7of9RHPOoGemO1olj>SX7ob<S
8`Oo6a/K1ol;2`/6oaPH60KoTi>C1_ooool6ocPh>0Oo`/;21ol>3Ph7oe9BDPOo>CTi1ol/;2`6okJf
]PKoN7Qh1_ooool7o`l?3`Ko6ATI1olX:2P7odI6APOoJ6QX1omfMWH7of][J`GoGUiN1_ooool7olo?
c`Oo7alO1_mCDe<7oc<c<`OoD51@1ooVi^H7oaDE5@KoPH611Oooool7o`/;2`Oo8B4Q1_lL71`7o`00
00Oo;bl_1ol<30`7oa/K6`Ko>c/k1Oooool7o`H61POo8b<S1ol];Bd6ob`/;0OoDe=C1olI6AT7ocXj
>PKokNg]4Oooool000oooooo1olE5AD7o`D51@Oo7AdM1olA4A46oaHF5POo4a<C1olT92@6oemOG`Go
oooo1omHF5P7oc/k>`Oo_;bl1ooWinL7oc0`<0KoE5AD1olX:2P6ocdm?@Gooooo1omRHV87oemOG`Oo
>SXj1olS8b<7oa/K6`Oo2`/;1_lH61P6oi>CT`Kooooo1_lh>3P7ol;2`POo3Ph>1omBDU87ocTi>@Oo
;2`/1_nf][H6ogQhN0Kooooo1ol?3`l6oaTI6@Oo:2PX1om6ATH7ofQXJ0OoMWIf1om[Jf/5oeiNGPKo
oooo1oo?cll7oalO7`KoDe=C1olc<c<7oe1@D0Ooi^KV1olE5AD6oh61P@Gooooo1ol;2`/7ob4Q8@Ko
71`L1ol00007obl_;`Oo30`<1olK6a/6oc/k>`Gooooo1ol61PH7ob<S8`Oo;Bd]1_l/;2`7oe=CD`Oo
6ATI1olj>SX6ong]kA7ooooo000?ooooo`Oo5ADE1ol51@D7oadM7@Oo4A4A1_lF5QH7oa<C4`Oo92@T
1_mOGel5ooooo`OoF5QH1olk>c/7okbl_0OoinOW1ol`<306oeADE0Oo:2PX1_lm?Cd5ooooo`OoHV9R
1omOGel7ocXj>POo8b<S1olK6a/7o`/;2`Ko61PH1_nCTi<6ooooo`Ko>3Ph1oo2`/87o`h>3POoDU9B
1oli>CT7ob`/;0Ko][Jf1_mhN7P6ooooo`Oo3`l?1_lI6AT7obPX:0OoATI61omXJ6P7ogIfMPOoJf][
1OmNGUh6ooooo`Ooclo?1olO7al6oe=CD`Oo<c<c1om@D507onKViPOo5ADE1_n1PH45ooooo`Oo2`/;
1olQ8B46oa`L70Oo00001ol_;bl7o``<30Oo6a/K1_lk>c/5ooooo`Oo1PH61olS8b<7obd];@Ko;2`/
1omCDe<7oaTI6@Oo>SXj1_o]kNdAooooo`003oooool7oaDE5@Oo1@D51olM7Ad7oa4A4@Ko5QHF1olC
4a<7ob@T90KoGemO1Oooool7oeQHF0Oo>c/k1onl_;`7onOWi`Oo<30`1_mDE5@7obPX:0Ko?Cdm1Ooo
ool7of9RHPOoGemO1olj>SX7ob<S8`Oo6a/K1ol;2`/6oaPH60KoTi>C1_ooool6ocPh>0Oo`/;21ol>
3Ph7oe9BDPOo>CTi1ol/;2`6okJf]PKoN7Qh1_ooool7o`l?3`Ko6ATI1olX:2P7odI6APOoJ6QX1omf
MWH7of][J`GoGUiN1_ooool7olo?c`Oo7alO1_mCDe<7oc<c<`OoD51@1ooVi^H7oaDE5@KoPH611Ooo
ool7o`/;2`Oo8B4Q1_lL71`7o`0000Oo;bl_1ol<30`7oa/K6`Ko>c/k1Oooool7o`H61POo8b<S1ol]
;Bd6ob`/;0OoDe=C1olI6AT7ocXj>PKokNg]4Oooool000oooooo1olE5AD7o`D51@Oo7AdM1olA4A46
oaHF5POo4a<C1olT92@6oemOG`Gooooo1omHF5P7oc/k>`Oo_;bl1ooWinL7oc0`<0KoE5AD1olX:2P6
ocdm?@Gooooo1omRHV87oemOG`Oo>SXj1olS8b<7oa/K6`Oo2`/;1_lH61P6oi>CT`Kooooo1_lh>3P7
ol;2`POo3Ph>1omBDU87ocTi>@Oo;2`/1_nf][H6ogQhN0Kooooo1ol?3`l6oaTI6@Oo:2PX1om6ATH7
ofQXJ0OoMWIf1om[Jf/5oeiNGPKooooo1oo?cll7oalO7`KoDe=C1olc<c<7oe1@D0Ooi^KV1olE5AD6
oh61P@Gooooo1ol;2`/7ob4Q8@Ko71`L1ol00007obl_;`Oo30`<1olK6a/6oc/k>`Gooooo1ol61PH7
ob<S8`Oo;Bd]1_l/;2`7oe=CD`Oo6ATI1olj>SX6ong]kA7ooooo000?ooooo`Oo5ADE1ol51@D7oadM
7@Oo4A4A1_lF5QH7oa<C4`Oo92@T1_mOGel5ooooo`OoF5QH1olk>c/7okbl_0OoinOW1ol`<306oeAD
E0Oo:2PX1_lm?Cd5ooooo`OoHV9R1omOGel7ocXj>POo8b<S1olK6a/7o`/;2`Ko61PH1_nCTi<6oooo
o`Ko>3Ph1oo2`/87o`h>3POoDU9B1oli>CT7ob`/;0Ko][Jf1_mhN7P6ooooo`Oo3`l?1_lI6AT7obPX
:0OoATI61omXJ6P7ogIfMPOoJf][1OmNGUh6ooooo`Ooclo?1olO7al6oe=CD`Oo<c<c1om@D507onKV
iPOo5ADE1_n1PH45ooooo`Oo2`/;1olQ8B46oa`L70Oo00001ol_;bl7o``<30Oo6a/K1_lk>c/5oooo
o`Oo1PH61olS8b<7obd];@Ko;2`/1omCDe<7oaTI6@Oo>SXj1_o]kNdAooooo`003oooool7obl_;`Oo
6ATI1olZ:RX7oa`L70Ko6QXJ1olP8207obDU9@KoNGUi1Oooool7ogYjNPOo;bl_1omRHV87onKViPOo
5QHF1_mDE5@7ocXj>PKoB4Q81Oooool7oeEEE@OoIVIV1om9BDT7obh^;POo:BTY1olP8206ocDe=@Ko
[Jf]1_ooool6oc4a<@Oo[Zj^1ol51@D7odY:BPOoDU9B1olG5aL6ojBTY0Ko/K6a1_ooool7oa`L70Ko
6ATI1olh>3P7oeADE0OoL71`1omaLG47oeQHF0GoFEUI1_ooool7oiRHV0Oo:b/[1_mdM7@7ocXj>POo
<C4a1oo^k^h7o`T92@KoNWYj1Oooool7oa/K6`Oo9bLW1_lZ:RX7o`D51@Oo<c<c1olA4A47obLW9`Ko
?Cdm1Oooool7o`0000Oo:RXZ1ol_;bl6ob0P80OoEEEE1olF5QH7oc0`<0Kob<S84Oooool000oooooo
1ol_;bl7oaTI6@Oo:RXZ1olL71`6oaXJ6POo820P1olU9BD6ogUiN@Gooooo1omjNWX7obl_;`OoHV9R
1ooVi^H7oaHF5PKoE5AD1olj>SX6odQ8B0Gooooo1omEEED7ofIVIPOoBDU91ol^;Rh7obTY:@Oo820P
1_le=CD6ojf][@Kooooo1_la<C47ojj^[POo1@D51om:BTX7oe9BDPOo5aLG1_nTY:@6ok6a/@Kooooo
1olL71`6oaTI6@Oo>3Ph1omDE5@7og1`L0OoLG5a1omHF5P5oeUIF@Kooooo1onHV9P7ob/[:`KoM7Ad
1olj>SX7oc4a<@Ook^k^1ol92@T6ogYjNPGooooo1olK6a/7obLW9`Ko:RXZ1ol51@D7oc<c<`Oo4A4A
1olW9bL6ocdm?@Gooooo1ol00007obXZ:POo;bl_1_lP8207oeEEE@Oo5QHF1ol`<306olS8b17ooooo
000?ooooo`Oo;bl_1olI6AT7obXZ:POo71`L1_lJ6QX7ob0P80Oo9BDU1_miNGT5ooooo`OoNWYj1ol_
;bl7of9RHPOoi^KV1olF5QH6oeADE0Oo>SXj1_m8B4P5ooooo`OoEEEE1omVIVH7odU9B@Oo;Rh^1olY
:BT7ob0P80Ko=CDe1_n][Jd6ooooo`Ko<C4a1on^[Zh7o`D51@OoBTY:1omBDU87oaLG5`KoY:BT1_na
/K46ooooo`Oo71`L1_lI6AT7ocPh>0OoE5AD1om`L707og5aL@OoF5QH1OmIFET6ooooo`OoV9RH1ol[
:b/6ogAdM0Oo>SXj1ola<C47onk^kPOo2@T91_mjNWX5ooooo`Oo6a/K1olW9bL6obXZ:POo1@D51olc
<c<7oa4A4@Oo9bLW1_lm?Cd5ooooo`Oo00001olZ:RX7obl_;`Ko820P1omEEED7oaHF5POo<30`1_o8
b<PAooooo`003oooool7obl_;`Oo6ATI1olZ:RX7oa`L70Ko6QXJ1olP8207obDU9@KoNGUi1Oooool7
ogYjNPOo;bl_1omRHV87onKViPOo5QHF1_mDE5@7ocXj>PKoB4Q81Oooool7oeEEE@OoIVIV1om9BDT7
obh^;POo:BTY1olP8206ocDe=@Ko[Jf]1_ooool6oc4a<@Oo[Zj^1ol51@D7odY:BPOoDU9B1olG5aL6
ojBTY0Ko/K6a1_ooool7oa`L70Ko6ATI1olh>3P7oeADE0OoL71`1omaLG47oeQHF0GoFEUI1_ooool7
oiRHV0Oo:b/[1_mdM7@7ocXj>POo<C4a1oo^k^h7o`T92@KoNWYj1Oooool7oa/K6`Oo9bLW1_lZ:RX7
o`D51@Oo<c<c1olA4A47obLW9`Ko?Cdm1Oooool7o`0000Oo:RXZ1ol_;bl6ob0P80OoEEEE1olF5QH7
oc0`<0Kob<S84Oooool000oooooo1ol_;bl7oaTI6@Oo:RXZ1olL71`6oaXJ6POo820P1olU9BD6ogUi
N@Gooooo1omjNWX7obl_;`OoHV9R1ooVi^H7oaHF5PKoE5AD1olj>SX6odQ8B0Gooooo1omEEED7ofIV
IPOoBDU91ol^;Rh7obTY:@Oo820P1_le=CD6ojf][@Kooooo1_la<C47ojj^[POo1@D51om:BTX7oe9B
DPOo5aLG1_nTY:@6ok6a/@Kooooo1olL71`6oaTI6@Oo>3Ph1omDE5@7og1`L0OoLG5a1omHF5P5oeUI
F@Kooooo1onHV9P7ob/[:`KoM7Ad1olj>SX7oc4a<@Ook^k^1ol92@T6ogYjNPGooooo1olK6a/7obLW
9`Ko:RXZ1ol51@D7oc<c<`Oo4A4A1olW9bL6ocdm?@Gooooo1ol00007obXZ:POo;bl_1_lP8207oeEE
E@Oo5QHF1ol`<306olS8b17ooooo000?ooooo`Oo;bl_1olI6AT7obXZ:POo71`L1_lJ6QX7ob0P80Oo
9BDU1_miNGT5ooooo`OoNWYj1ol_;bl7of9RHPOoi^KV1olF5QH6oeADE0Oo>SXj1_m8B4P5ooooo`Oo
EEEE1omVIVH7odU9B@Oo;Rh^1olY:BT7ob0P80Ko=CDe1_n][Jd6ooooo`Ko<C4a1on^[Zh7o`D51@Oo
BTY:1omBDU87oaLG5`KoY:BT1_na/K46ooooo`Oo71`L1_lI6AT7ocPh>0OoE5AD1om`L707og5aL@Oo
F5QH1OmIFET6ooooo`OoV9RH1ol[:b/6ogAdM0Oo>SXj1ola<C47onk^kPOo2@T91_mjNWX5ooooo`Oo
6a/K1olW9bL6obXZ:POo1@D51olc<c<7oa4A4@Oo9bLW1_lm?Cd5ooooo`Oo00001olZ:RX7obl_;`Ko
820P1omEEED7oaHF5POo<30`1_o8b<PAooooo`003oooool7obl_;`Oo6ATI1olZ:RX7oa`L70Ko6QXJ
1olP8207obDU9@KoNGUi1Oooool7ogYjNPOo;bl_1omRHV87onKViPOo5QHF1_mDE5@7ocXj>PKoB4Q8
1Oooool7oeEEE@OoIVIV1om9BDT7obh^;POo:BTY1olP8206ocDe=@Ko[Jf]1_ooool6oc4a<@Oo[Zj^
1ol51@D7odY:BPOoDU9B1olG5aL6ojBTY0Ko/K6a1_ooool7oa`L70Ko6ATI1olh>3P7oeADE0OoL71`
1omaLG47oeQHF0GoFEUI1_ooool7oiRHV0Oo:b/[1_mdM7@7ocXj>POo<C4a1oo^k^h7o`T92@KoNWYj
1Oooool7oa/K6`Oo9bLW1_lZ:RX7o`D51@Oo<c<c1olA4A47obLW9`Ko?Cdm1Oooool7o`0000Oo:RXZ
1ol_;bl6ob0P80OoEEEE1olF5QH7oc0`<0Kob<S84Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5
aLD6omSHf0OoalO71ooIfMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mP
H605ooooo`OoRXZ:1omeMGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[
:b/7ode=C@Oo:BTY1omQHF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1ooo
ool7onk^kPGoTi>C1_ooool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Ooo
ool7obLW9`Oo=cLg1_lo?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?
3`l6oa/K6`Oo;2`/1olB4Q87obl_;`Ko?Shn4Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5aLD6
omSHf0OoalO71ooIfMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mPH605
ooooo`OoRXZ:1omeMGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[:b/7
ode=C@Oo:BTY1omQHF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1oooool7
onk^kPGoTi>C1_ooool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Oooool7
obLW9`Oo=cLg1_lo?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?3`l6
oa/K6`Oo;2`/1olB4Q87obl_;`Ko?Shn4Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5aLD6omSH
f0OoalO71ooIfMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mPH605oooo
o`OoRXZ:1omeMGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[:b/7ode=
C@Oo:BTY1omQHF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1oooool7onk^
kPGoTi>C1_ooool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Oooool7obLW
9`Oo=cLg1_lo?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?3`l6oa/K
6`Oo;2`/1olB4Q87obl_;`Ko?Shn4Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5aLD6omSHf0Oo
alO71ooIfMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mPH605ooooo`Oo
RXZ:1omeMGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[:b/7ode=C@Oo
:BTY1omQHF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1oooool7onk^kPGo
Ti>C1_ooool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Oooool7obLW9`Oo
=cLg1_lo?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?3`l6oa/K6`Oo
;2`/1olB4Q87obl_;`Ko?Shn4Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5aLD6omSHf0OoalO7
1ooIfMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mPH605ooooo`OoRXZ:
1omeMGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[:b/7ode=C@Oo:BTY
1omQHF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1oooool7onk^kPGoTi>C
1_ooool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Oooool7obLW9`Oo=cLg
1_lo?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?3`l6oa/K6`Oo;2`/
1olB4Q87obl_;`Ko?Shn4Oooool000oooooo1ooalO47omSHf0Oom_Kf1oo5aLD6omSHf0OoalO71ooI
fMT;ooooo`OoC4a<1olj>SX7ohn?S`OoJFUY1olR8R86ode=C@Oo8B4Q1_mPH605ooooo`OoRXZ:1ome
MGD7oeeMG@Oo=cLg1olh>3P7obPX:0KoA4A43?ooool6og5aL@OoQXJ61ol[:b/7ode=C@Oo:BTY1omQ
HF46ogQhN0KoEUIF1_ooool7od];B`KoLW9b1on2PX87on?Sh`Oom?Cd1oooool7onk^kPGoTi>C1_oo
ool7oiRHV0Oo71`L1_mNGUh7ocdm?@OoJ6QX1omdM7@7oa`L70KoU9BD1Oooool7obLW9`Oo=cLg1_lo
?cl7oc/k>`OoBDU91olU9BD7ocTi>@KoYZJV1Oooool7o`820POo=CDe1ol?3`l6oa/K6`Oo;2`/1olB
4Q87obl_;`Ko?Shn4Oooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-2.32564, \
-0.204693, 0.148839, 0.148839}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-11.135, -0.204693, 0.148839, 0.148839}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-19.9351, -0.204693, 0.148839, 0.148839}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-28.7352, -0.204693, 0.148839, 0.148839}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-37.5353, -0.204693, 0.148839, 0.148839}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-46.3354, -0.204693, 0.148839, \
0.148839}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-55.1355, -0.204693, \
0.148839, 0.148839}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-63.9356, \
-0.204693, 0.148839, 0.148839}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F52682A
61434B00
8A415107
D4D4FFC4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
32000E23
A059372F
FFD57D45
5D41414C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
002E69D4
0F053C70
33092440
1D658BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
100B2B19
1200040D
14060C02
2156FF51
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8648061B
76823C91
6BB588FF
802D000A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
51FFD029
53DCE32C
0029560F
11A3314B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C3CED7CB
59A8FBFF
00479DC1
7DA663D0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
44250709
170F0706
00071512
FF8F2131
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go
3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Ko
oooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``go
c/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B
3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD
1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A
3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L7
3Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS
8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6
QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oG
emL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=
obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=
oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>
om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TA
ooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5oooo
o`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8
B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;
b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGo
oooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko
2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go
:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`00
3oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko0000
3_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH6
3?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo
3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb
<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[
:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Ooo
ool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>
odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>
ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6
ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=
obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`00
00go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI
6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3
``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`ko
DU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@co
e=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`ko
DE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko
1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>
3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo
3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>
3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>odm?C`koDU9B3OmX
J6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_oo
ool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Ooo
ool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol9
2@TAooooo`003oooool>odm?C`koDU9B3OmXJ6P=obXZ:PGooooo3_lb<S8>o`0000go3Ph>3OlS8b<5
ooooo`ko00003_l^;Rh>ofUYJ@coe=CD1_ooool=oa0@40ko2`/;3_l[:b/<oaTI6@Kooooo3On6QXH>
odQ8B0ko1PH63?lK6a/6ooooo`koDE5A3Oooool>om3@d0go:BTY1Oooool>ol?3``goc/k>3_oGemL=
ol_;b`Gooooo3_m4A4@=obDU9@ko1`L73Ol92@TAooooo`003oooool>of5QH@ko@d=33Om;Bd/=o`00
00Gooooo3_nPX:0>oeUIF@go=cLg3Ol_;bl5ooooo`ko3`l?3_l51@D>oc`l?0coL71`1_ooool=oa8B
4Pko00003_l410@<o`d=3@Kooooo3OmfMWH>oh:2PPko?3`l3?nATI46ooooo`koDe=C3OoLg=`>on?S
h`go;2`/1Oooool>oeUIF@goZ:RX3_okno/Booooo`ko5aLG3Ol?3`l>o`L71`go1PH64Oooool000oo
oooo3_mQHF4>od=3@`goBd];3Ol00005ooooo`koX:2P3_mIFET=ocLg=`go;bl_1Oooool>o`l?3`ko
1@D53_ll?3`<og1`L0Kooooo3OlB4Q8>o`0000ko10@43?l=3@d6ooooo`goMWIf3_n2PX8>oc`l?0co
TI6A1_ooool>oe=CD`gog=cL3_oShn<=ob`/;0Gooooo3_mIFET=ojRXZ0kono_k4_ooool>oaLG5`go
3`l?3_l71`L=o`H61Q7ooooo000?ooooo`koHF5Q3_m3@d<=od];B`go00001Oooool>oj2PX0koFEUI
3Olg=cL=obl_;`Gooooo3_l?3`l>o`D51@ko?3`l3?m`L706ooooo`go4Q8B3_l0000>o`@410co3@d=
1_ooool=ogIfMPkoPX:23_ll?3`<oi6AT@Kooooo3_mCDe<=omcLg0kohn?S3Ol/;2`5ooooo`koFEUI
3OnXZ:P>oo_kna;ooooo3_lG5aL=o`l?3`ko1`L73Ol61PHAooooo`003oooool>of5QH@ko@d=33Om;
Bd/=o`0000Gooooo3_nPX:0>oeUIF@go=cLg3Ol_;bl5ooooo`ko3`l?3_l51@D>oc`l?0coL71`1_oo
ool=oa8B4Pko00003_l410@<o`d=3@Kooooo3OmfMWH>oh:2PPko?3`l3?nATI46ooooo`koDe=C3OoL
g=`>on?Sh`go;2`/1Oooool>oeUIF@goZ:RX3_okno/Booooo`ko5aLG3Ol?3`l>o`L71`go1PH64Ooo
ool000oooooo3_mQHF4>od=3@`goBd];3Ol00005ooooo`koX:2P3_mIFET=ocLg=`go;bl_1Oooool>
o`l?3`ko1@D53_ll?3`<og1`L0Kooooo3OlB4Q8>o`0000ko10@43?l=3@d6ooooo`goMWIf3_n2PX8>
oc`l?0coTI6A1_ooool>oe=CD`gog=cL3_oShn<=ob`/;0Gooooo3_mIFET=ojRXZ0kono_k4_ooool>
oaLG5`go3`l?3_l71`L=o`H61Q7ooooo000?ooooo`koHF5Q3_m3@d<=od];B`go00001Oooool>oj2P
X0koFEUI3Olg=cL=obl_;`Gooooo3_l?3`l>o`D51@ko?3`l3?m`L706ooooo`go4Q8B3_l0000>o`@4
10co3@d=1_ooool=ogIfMPkoPX:23_ll?3`<oi6AT@Kooooo3_mCDe<=omcLg0kohn?S3Ol/;2`5oooo
o`koFEUI3OnXZ:P>oo_kna;ooooo3_lG5aL=o`l?3`ko1`L73Ol61PHAooooo`003oooool>of5QH@ko
@d=33Om;Bd/=o`0000Gooooo3_nPX:0>oeUIF@go=cLg3Ol_;bl5ooooo`ko3`l?3_l51@D>oc`l?0co
L71`1_ooool=oa8B4Pko00003_l410@<o`d=3@Kooooo3OmfMWH>oh:2PPko?3`l3?nATI46ooooo`ko
De=C3OoLg=`>on?Sh`go;2`/1Oooool>oeUIF@goZ:RX3_okno/Booooo`ko5aLG3Ol?3`l>o`L71`go
1PH64Oooool000oooooo3_mQHF4>od=3@`goBd];3Ol00005ooooo`koX:2P3_mIFET=ocLg=`go;bl_
1Oooool>o`l?3`ko1@D53_ll?3`<og1`L0Kooooo3OlB4Q8>o`0000ko10@43?l=3@d6ooooo`goMWIf
3_n2PX8>oc`l?0coTI6A1_ooool>oe=CD`gog=cL3_oShn<=ob`/;0Gooooo3_mIFET=ojRXZ0kono_k
4_ooool>oaLG5`go3`l?3_l71`L=o`H61Q7ooooo000?ooooo`koHF5Q3_m3@d<=od];B`go00001Ooo
ool>oj2PX0koFEUI3Olg=cL=obl_;`Gooooo3_l?3`l>o`D51@ko?3`l3?m`L706ooooo`go4Q8B3_l0
000>o`@410co3@d=1_ooool=ogIfMPkoPX:23_ll?3`<oi6AT@Kooooo3_mCDe<=omcLg0kohn?S3Ol/
;2`5ooooo`koFEUI3OnXZ:P>oo_kna;ooooo3_lG5aL=o`l?3`ko1`L73Ol61PHAooooo`003oooool>
of5QH@ko@d=33Om;Bd/=o`0000Gooooo3_nPX:0>oeUIF@go=cLg3Ol_;bl5ooooo`ko3`l?3_l51@D>
oc`l?0coL71`1_ooool=oa8B4Pko00003_l410@<o`d=3@Kooooo3OmfMWH>oh:2PPko?3`l3?nATI46
ooooo`koDe=C3OoLg=`>on?Sh`go;2`/1Oooool>oeUIF@goZ:RX3_okno/Booooo`ko5aLG3Ol?3`l>
o`L71`go1PH64Oooool000oooooo3_mQHF4>od=3@`goBd];3Ol00005ooooo`koX:2P3_mIFET=ocLg
=`go;bl_1Oooool>o`l?3`ko1@D53_ll?3`<og1`L0Kooooo3OlB4Q8>o`0000ko10@43?l=3@d6oooo
o`goMWIf3_n2PX8>oc`l?0coTI6A1_ooool>oe=CD`gog=cL3_oShn<=ob`/;0Gooooo3_mIFET=ojRX
Z0kono_k4_ooool>oaLG5`go3`l?3_l71`L=o`H61Q7ooooo000?ooooo`koHF5Q3_m3@d<=od];B`go
00001Oooool>oj2PX0koFEUI3Olg=cL=obl_;`Gooooo3_l?3`l>o`D51@ko?3`l3?m`L706ooooo`go
4Q8B3_l0000>o`@410co3@d=1_ooool=ogIfMPkoPX:23_ll?3`<oi6AT@Kooooo3_mCDe<=omcLg0ko
hn?S3Ol/;2`5ooooo`koFEUI3OnXZ:P>oo_kna;ooooo3_lG5aL=o`l?3`ko1`L73Ol61PHAooooo`00
3oooool>of5QH@ko@d=33Om;Bd/=o`0000Gooooo3_nPX:0>oeUIF@go=cLg3Ol_;bl5ooooo`ko3`l?
3_l51@D>oc`l?0coL71`1_ooool=oa8B4Pko00003_l410@<o`d=3@Kooooo3OmfMWH>oh:2PPko?3`l
3?nATI46ooooo`koDe=C3OoLg=`>on?Sh`go;2`/1Oooool>oeUIF@goZ:RX3_okno/Booooo`ko5aLG
3Ol?3`l>o`L71`go1PH64Oooool000oooooo3_n:RXX>od51@@goDE5A3Ol71`LCooooo`koeMGE3Omm
OGd=odE5A@Gooooo3_lc<c<>o`T92@ko92@T3?m0@406ooooo`go51@D3_l61PH>o``<30co0P821_oo
ool=of][J`ko]KFe3_n8R8PBooooo`ko00003OlY:BT>oeIFEPgo3`l?1Oooool>o`0000goAdM73_nM
WId=ol71`@Gooooo3_l0000=o`L71`ko5ADE3OlB4Q8Aooooo`003oooool>ohZ:RPko@D513OmADE4=
o`L71a?ooooo3_oEeMD=ogemO@goADE51Oooool>oc<c<`ko2@T93_lT92@<od10@0Kooooo3OlD51@>
o`H61Pko30`<3?l20P86ooooo`goJf][3_ne]KD>ohR8R1;ooooo3_l0000=obTY:@koEUIF3Ol?3`l5
ooooo`ko00003Om7AdL>oifMW@go`L711Oooool>o`0000go1`L73_lE5AD=oa8B4Q7ooooo000?oooo
o`koRXZ:3_m1@D4=oe5AD@go1`L74oooool>omGEe@goOGem3Om5ADD5ooooo`ko<c<c3_l92@T>ob@T
90co@4101_ooool=oa@D50ko1PH63_l<30`<o`820PKooooo3Om[Jf/>okFe]@koR8R84_ooool>o`00
00go:BTY3_mFEUH=o`l?3`Gooooo3_l0000=odM7A`koWIfM3Oo1`L45ooooo`ko00003Ol71`L>oaDE
5@go4Q8B4Oooool000oooooo3_n:RXX>od51@@goDE5A3Ol71`LCooooo`koeMGE3OmmOGd=odE5A@Go
oooo3_lc<c<>o`T92@ko92@T3?m0@406ooooo`go51@D3_l61PH>o``<30co0P821_ooool=of][J`ko
]KFe3_n8R8PBooooo`ko00003OlY:BT>oeIFEPgo3`l?1Oooool>o`0000goAdM73_nMWId=ol71`@Go
oooo3_l0000=o`L71`ko5ADE3OlB4Q8Aooooo`003oooool>ohZ:RPko@D513OmADE4=o`L71a?ooooo
3_oEeMD=ogemO@goADE51Oooool>oc<c<`ko2@T93_lT92@<od10@0Kooooo3OlD51@>o`H61Pko30`<
3?l20P86ooooo`goJf][3_ne]KD>ohR8R1;ooooo3_l0000=obTY:@koEUIF3Ol?3`l5ooooo`ko0000
3Om7AdL>oifMW@go`L711Oooool>o`0000go1`L73_lE5AD=oa8B4Q7ooooo000?ooooo`koRXZ:3_m1
@D4=oe5AD@go1`L74oooool>omGEe@goOGem3Om5ADD5ooooo`ko<c<c3_l92@T>ob@T90co@4101_oo
ool=oa@D50ko1PH63_l<30`<o`820PKooooo3Om[Jf/>okFe]@koR8R84_ooool>o`0000go:BTY3_mF
EUH=o`l?3`Gooooo3_l0000=odM7A`koWIfM3Oo1`L45ooooo`ko00003Ol71`L>oaDE5@go4Q8B4Ooo
ool000oooooo3_n:RXX>od51@@goDE5A3Ol71`LCooooo`koeMGE3OmmOGd=odE5A@Gooooo3_lc<c<>
o`T92@ko92@T3?m0@406ooooo`go51@D3_l61PH>o``<30co0P821_ooool=of][J`ko]KFe3_n8R8PB
ooooo`ko00003OlY:BT>oeIFEPgo3`l?1Oooool>o`0000goAdM73_nMWId=ol71`@Gooooo3_l0000=
o`L71`ko5ADE3OlB4Q8Aooooo`003oooool>ohZ:RPko@D513OmADE4=o`L71a?ooooo3_oEeMD=ogem
O@goADE51Oooool>oc<c<`ko2@T93_lT92@<od10@0Kooooo3OlD51@>o`H61Pko30`<3?l20P86oooo
o`goJf][3_ne]KD>ohR8R1;ooooo3_l0000=obTY:@koEUIF3Ol?3`l5ooooo`ko00003Om7AdL>oifM
W@go`L711Oooool>o`0000go1`L73_lE5AD=oa8B4Q7ooooo000?ooooo`koRXZ:3_m1@D4=oe5AD@go
1`L74oooool>omGEe@goOGem3Om5ADD5ooooo`ko<c<c3_l92@T>ob@T90co@4101_ooool=oa@D50ko
1PH63_l<30`<o`820PKooooo3Om[Jf/>okFe]@koR8R84_ooool>o`0000go:BTY3_mFEUH=o`l?3`Go
oooo3_l0000=odM7A`koWIfM3Oo1`L45ooooo`ko00003Ol71`L>oaDE5@go4Q8B4Oooool000oooooo
3_n:RXX>od51@@goDE5A3Ol71`LCooooo`koeMGE3OmmOGd=odE5A@Gooooo3_lc<c<>o`T92@ko92@T
3?m0@406ooooo`go51@D3_l61PH>o``<30co0P821_ooool=of][J`ko]KFe3_n8R8PBooooo`ko0000
3OlY:BT>oeIFEPgo3`l?1Oooool>o`0000goAdM73_nMWId=ol71`@Gooooo3_l0000=o`L71`ko5ADE
3OlB4Q8Aooooo`003oooool>ohZ:RPko@D513OmADE4=o`L71a?ooooo3_oEeMD=ogemO@goADE51Ooo
ool>oc<c<`ko2@T93_lT92@<od10@0Kooooo3OlD51@>o`H61Pko30`<3?l20P86ooooo`goJf][3_ne
]KD>ohR8R1;ooooo3_l0000=obTY:@koEUIF3Ol?3`l5ooooo`ko00003Om7AdL>oifMW@go`L711Ooo
ool>o`0000go1`L73_lE5AD=oa8B4Q7ooooo000?ooooo`koRXZ:3_m1@D4=oe5AD@go1`L74oooool>
omGEe@goOGem3Om5ADD5ooooo`ko<c<c3_l92@T>ob@T90co@4101_ooool=oa@D50ko1PH63_l<30`<
o`820PKooooo3Om[Jf/>okFe]@koR8R84_ooool>o`0000go:BTY3_mFEUH=o`l?3`Gooooo3_l0000=
odM7A`koWIfM3Oo1`L45ooooo`ko00003Ol71`L>oaDE5@go4Q8B4Oooool000oooooo3_n:RXX>od51
@@goDE5A3Ol71`LCooooo`koeMGE3OmmOGd=odE5A@Gooooo3_lc<c<>o`T92@ko92@T3?m0@406oooo
o`go51@D3_l61PH>o``<30co0P821_ooool=of][J`ko]KFe3_n8R8PBooooo`ko00003OlY:BT>oeIF
EPgo3`l?1Oooool>o`0000goAdM73_nMWId=ol71`@Gooooo3_l0000=o`L71`ko5ADE3OlB4Q8Aoooo
o`003ooooolLomCDe0gooooo3Oo4a<@5ooooo`koGEeM6om1@D4=oda<C0Gooooo3_lM7Ad>ofEUI@ko
Rh^;4_ooool=ob4Q8@koEUIF3_ooool<oe5AD@Kooooo3On0P80>obd];@ko00003?l:2PX6ooooo`ko
4A4A3OnSXj<>oc4a<@goBd];1Oooool>ogemO@goYZJV3_mSHf<=om3@d1?ooooo3On?Shl>ob4Q8@go
<C4a4Oooool000oooooo7?oDe=@=ooooo`goa<C41Oooool>oeeMGA_o@D513Om<C4`5ooooo`ko7AdM
3_mUIFD>oh^;Ra;ooooo3OlQ8B4>oeIFEPkooooo3?mADE46ooooo`goP8203_l];Bd>o`0000co2PX:
1_ooool>oa4A4@goXj>S3_la<C4=od];B`Gooooo3_mmOGd=ojJVYPkoHf=S3Oo@d=0Cooooo`goShn?
3_lQ8B4=oc4a<A7ooooo000?oooooacoe=CD3Oooool=olC4a0Gooooo3_mMGEdKod51@@goC4a<1Ooo
ool>oadM7@koIFEU3_n;Rh/Booooo`go8B4Q3_mFEUH>ooooo`coDE5A1_ooool=oh20P0ko;Bd]3_l0
000<o`X:2PKooooo3_lA4A4=oj>SX`ko<C4a3Om;Bd/5ooooo`koOGem3OnVYZH>of=SH`god=3@4ooo
ool=ohn?S`ko8B4Q3Ola<C4Aooooo`003ooooolLomCDe0gooooo3Oo4a<@5ooooo`koGEeM6om1@D4=
oda<C0Gooooo3_lM7Ad>ofEUI@koRh^;4_ooool=ob4Q8@koEUIF3_ooool<oe5AD@Kooooo3On0P80>
obd];@ko00003?l:2PX6ooooo`ko4A4A3OnSXj<>oc4a<@goBd];1Oooool>ogemO@goYZJV3_mSHf<=
om3@d1?ooooo3On?Shl>ob4Q8@go<C4a4Oooool000oooooo7?oDe=@=ooooo`goa<C41Oooool>oeeM
GA_o@D513Om<C4`5ooooo`ko7AdM3_mUIFD>oh^;Ra;ooooo3OlQ8B4>oeIFEPkooooo3?mADE46oooo
o`goP8203_l];Bd>o`0000co2PX:1_ooool>oa4A4@goXj>S3_la<C4=od];B`Gooooo3_mmOGd=ojJV
YPkoHf=S3Oo@d=0Cooooo`goShn?3_lQ8B4=oc4a<A7ooooo000?oooooacoe=CD3Oooool=olC4a0Go
oooo3_mMGEdKod51@@goC4a<1Oooool>oadM7@koIFEU3_n;Rh/Booooo`go8B4Q3_mFEUH>ooooo`co
DE5A1_ooool=oh20P0ko;Bd]3_l0000<o`X:2PKooooo3_lA4A4=oj>SX`ko<C4a3Om;Bd/5ooooo`ko
OGem3OnVYZH>of=SH`god=3@4oooool=ohn?S`ko8B4Q3Ola<C4Aooooo`003ooooolLomCDe0gooooo
3Oo4a<@5ooooo`koGEeM6om1@D4=oda<C0Gooooo3_lM7Ad>ofEUI@koRh^;4_ooool=ob4Q8@koEUIF
3_ooool<oe5AD@Kooooo3On0P80>obd];@ko00003?l:2PX6ooooo`ko4A4A3OnSXj<>oc4a<@goBd];
1Oooool>ogemO@goYZJV3_mSHf<=om3@d1?ooooo3On?Shl>ob4Q8@go<C4a4Oooool000oooooo7?oD
e=@=ooooo`goa<C41Oooool>oeeMGA_o@D513Om<C4`5ooooo`ko7AdM3_mUIFD>oh^;Ra;ooooo3OlQ
8B4>oeIFEPkooooo3?mADE46ooooo`goP8203_l];Bd>o`0000co2PX:1_ooool>oa4A4@goXj>S3_la
<C4=od];B`Gooooo3_mmOGd=ojJVYPkoHf=S3Oo@d=0Cooooo`goShn?3_lQ8B4=oc4a<A7ooooo000?
oooooacoe=CD3Oooool=olC4a0Gooooo3_mMGEdKod51@@goC4a<1Oooool>oadM7@koIFEU3_n;Rh/B
ooooo`go8B4Q3_mFEUH>ooooo`coDE5A1_ooool=oh20P0ko;Bd]3_l0000<o`X:2PKooooo3_lA4A4=
oj>SX`ko<C4a3Om;Bd/5ooooo`koOGem3OnVYZH>of=SH`god=3@4oooool=ohn?S`ko8B4Q3Ola<C4A
ooooo`003ooooolLomCDe0gooooo3Oo4a<@5ooooo`koGEeM6om1@D4=oda<C0Gooooo3_lM7Ad>ofEU
I@koRh^;4_ooool=ob4Q8@koEUIF3_ooool<oe5AD@Kooooo3On0P80>obd];@ko00003?l:2PX6oooo
o`ko4A4A3OnSXj<>oc4a<@goBd];1Oooool>ogemO@goYZJV3_mSHf<=om3@d1?ooooo3On?Shl>ob4Q
8@go<C4a4Oooool000oooooo7?oDe=@=ooooo`goa<C41Oooool>oeeMGA_o@D513Om<C4`5ooooo`ko
7AdM3_mUIFD>oh^;Ra;ooooo3OlQ8B4>oeIFEPkooooo3?mADE46ooooo`goP8203_l];Bd>o`0000co
2PX:1_ooool>oa4A4@goXj>S3_la<C4=od];B`Gooooo3_mmOGd=ojJVYPkoHf=S3Oo@d=0Cooooo`go
Shn?3_lQ8B4=oc4a<A7ooooo000?oooooacoe=CD3Oooool=olC4a0Gooooo3_mMGEdKod51@@goC4a<
1Oooool>oadM7@koIFEU3_n;Rh/Booooo`go8B4Q3_mFEUH>ooooo`coDE5A1_ooool=oh20P0ko;Bd]
3_l0000<o`X:2PKooooo3_lA4A4=oj>SX`ko<C4a3Om;Bd/5ooooo`koOGem3OnVYZH>of=SH`god=3@
4oooool=ohn?S`ko8B4Q3Ola<C4Aooooo`003ooooolLomCDe0gooooo3Oo4a<@5ooooo`koGEeM6om1
@D4=oda<C0Gooooo3_lM7Ad>ofEUI@koRh^;4_ooool=ob4Q8@koEUIF3_ooool<oe5AD@Kooooo3On0
P80>obd];@ko00003?l:2PX6ooooo`ko4A4A3OnSXj<>oc4a<@goBd];1Oooool>ogemO@goYZJV3_mS
Hf<=om3@d1?ooooo3On?Shl>ob4Q8@go<C4a4Oooool00?oooooomOooool00?oooooomOooool00001
\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-1.16282, \
-0.102347, 0.0744193, 0.0744193}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-5.56752, -0.102347, 0.0744193, 0.0744193}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-9.96756, -0.102347, 0.0744193, 0.0744193}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-14.3676, -0.102347, 0.0744193, 0.0744193}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-18.7676, -0.102347, 0.0744193, 0.0744193}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-23.1677, -0.102347, 0.0744193, \
0.0744193}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-27.5677, -0.102347, \
0.0744193, 0.0744193}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-31.9678, \
-0.102347, 0.0744193, 0.0744193}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
78585FFF
621233F3
6B0038FD
4F0322F6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E051AFF
0C0014E7
0C0E1695
12090683
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
340CDB4D
1812F44E
0026FF6C
0C38F964
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5FE16017
6AFF5314
6FFE4400
53C4230A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00E6303A
03FF162A
18FD011C
20DE011A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B1F0764
701A0098
640F02FF
37030DAE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E12E060D
FD17000E
FF04111A
D8051923
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0321C83A
0026FF3F
0B2BFC3D
0C17B82A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool>ogQhN0koF5QH3OmOGelBooooo`ko7QhN3_l51@D=oaXJ6Q;o
oooo3_ld=3@>o``<30kofm_K3?m=CDd6ooooo`goGemO3_oQhN4>of1PH0co5aLG1_ooool=o`0000ko
i^KV3_l`<30<ocXj>PKooooo3_mKFe/=oalO7`ko1`L73OmTI6@5ooooo`kohN7Q3Ol^;Rh>o`H61Pgo
3@d=1Oooool>o`<30`go8B4Q3_o8b<P=ocXj>Q7ooooo000?ooooo`koN7Qh3_mHF5P=oemOGa;ooooo
3_lN7Qh>o`D51@go6QXJ4_ooool>oc@d=0ko30`<3_oKfm/<ode=C@Kooooo3OmOGel>on7Qh@koH61P
3?lG5aL6ooooo`go00003_oVi^H>oc0`<0co>SXj1_ooool>oe]KF`go7alO3_l71`L=ofATI0Gooooo
3_oQhN4=obh^;Pko1PH63Ol=3@d5ooooo`ko0`<33OlQ8B4>olS8b0go>SXj4Oooool000oooooo3_mh
N7P>oeQHF0goGemO4_ooool>oahN7Pko1@D53OlJ6QXBooooo`ko=3@d3_l<30`>om_Kf`coCDe=1_oo
ool=oemOG`kohN7Q3_mPH60<oaLG5`Kooooo3Ol0000>onKViPko<30`3?lj>SX6ooooo`koFe]K3OlO
7al>o`L71`goI6AT1Oooool>on7Qh@go;Rh^3_l61PH=o`d=3@Gooooo3_l30`<=ob4Q8@kob<S83Olj
>SXAooooo`003oooool>ogQhN0koF5QH3OmOGelBooooo`ko7QhN3_l51@D=oaXJ6Q;ooooo3_ld=3@>
o``<30kofm_K3?m=CDd6ooooo`goGemO3_oQhN4>of1PH0co5aLG1_ooool=o`0000koi^KV3_l`<30<
ocXj>PKooooo3_mKFe/=oalO7`ko1`L73OmTI6@5ooooo`kohN7Q3Ol^;Rh>o`H61Pgo3@d=1Oooool>
o`<30`go8B4Q3_o8b<P=ocXj>Q7ooooo000?ooooo`koN7Qh3_mHF5P=oemOGa;ooooo3_lN7Qh>o`D5
1@go6QXJ4_ooool>oc@d=0ko30`<3_oKfm/<ode=C@Kooooo3OmOGel>on7Qh@koH61P3?lG5aL6oooo
o`go00003_oVi^H>oc0`<0co>SXj1_ooool>oe]KF`go7alO3_l71`L=ofATI0Gooooo3_oQhN4=obh^
;Pko1PH63Ol=3@d5ooooo`ko0`<33OlQ8B4>olS8b0go>SXj4Oooool000oooooo3_mhN7P>oeQHF0go
GemO4_ooool>oahN7Pko1@D53OlJ6QXBooooo`ko=3@d3_l<30`>om_Kf`coCDe=1_ooool=oemOG`ko
hN7Q3_mPH60<oaLG5`Kooooo3Ol0000>onKViPko<30`3?lj>SX6ooooo`koFe]K3OlO7al>o`L71`go
I6AT1Oooool>on7Qh@go;Rh^3_l61PH=o`d=3@Gooooo3_l30`<=ob4Q8@kob<S83Olj>SXAooooo`00
3oooool>ogQhN0koF5QH3OmOGelBooooo`ko7QhN3_l51@D=oaXJ6Q;ooooo3_ld=3@>o``<30kofm_K
3?m=CDd6ooooo`goGemO3_oQhN4>of1PH0co5aLG1_ooool=o`0000koi^KV3_l`<30<ocXj>PKooooo
3_mKFe/=oalO7`ko1`L73OmTI6@5ooooo`kohN7Q3Ol^;Rh>o`H61Pgo3@d=1Oooool>o`<30`go8B4Q
3_o8b<P=ocXj>Q7ooooo000?ooooo`koN7Qh3_mHF5P=oemOGa;ooooo3_lN7Qh>o`D51@go6QXJ4_oo
ool>oc@d=0ko30`<3_oKfm/<ode=C@Kooooo3OmOGel>on7Qh@koH61P3?lG5aL6ooooo`go00003_oV
i^H>oc0`<0co>SXj1_ooool>oe]KF`go7alO3_l71`L=ofATI0Gooooo3_oQhN4=obh^;Pko1PH63Ol=
3@d5ooooo`ko0`<33OlQ8B4>olS8b0go>SXj4Oooool000oooooo3_mhN7P>oeQHF0goGemO4_ooool>
oahN7Pko1@D53OlJ6QXBooooo`ko=3@d3_l<30`>om_Kf`coCDe=1_ooool=oemOG`kohN7Q3_mPH60<
oaLG5`Kooooo3Ol0000>onKViPko<30`3?lj>SX6ooooo`koFe]K3OlO7al>o`L71`goI6AT1Oooool>
on7Qh@go;Rh^3_l61PH=o`d=3@Gooooo3_l30`<=ob4Q8@kob<S83Olj>SXAooooo`003oooool>ogQh
N0koF5QH3OmOGelBooooo`ko7QhN3_l51@D=oaXJ6Q;ooooo3_ld=3@>o``<30kofm_K3?m=CDd6oooo
o`goGemO3_oQhN4>of1PH0co5aLG1_ooool=o`0000koi^KV3_l`<30<ocXj>PKooooo3_mKFe/=oalO
7`ko1`L73OmTI6@5ooooo`kohN7Q3Ol^;Rh>o`H61Pgo3@d=1Oooool>o`<30`go8B4Q3_o8b<P=ocXj
>Q7ooooo000?ooooo`koN7Qh3_mHF5P=oemOGa;ooooo3_lN7Qh>o`D51@go6QXJ4_ooool>oc@d=0ko
30`<3_oKfm/<ode=C@Kooooo3OmOGel>on7Qh@koH61P3?lG5aL6ooooo`go00003_oVi^H>oc0`<0co
>SXj1_ooool>oe]KF`go7alO3_l71`L=ofATI0Gooooo3_oQhN4=obh^;Pko1PH63Ol=3@d5ooooo`ko
0`<33OlQ8B4>olS8b0go>SXj4Oooool000oooooo3_mhN7P>oeQHF0goGemO4_ooool>oahN7Pko1@D5
3OlJ6QXBooooo`ko=3@d3_l<30`>om_Kf`coCDe=1_ooool=oemOG`kohN7Q3_mPH60<oaLG5`Kooooo
3Ol0000>onKViPko<30`3?lj>SX6ooooo`koFe]K3OlO7al>o`L71`goI6AT1Oooool>on7Qh@go;Rh^
3_l61PH=o`d=3@Gooooo3_l30`<=ob4Q8@kob<S83Olj>SXAooooo`003oooool>ogQhN0koF5QH3OmO
GelBooooo`ko7QhN3_l51@D=oaXJ6Q;ooooo3_ld=3@>o``<30kofm_K3?m=CDd6ooooo`goGemO3_oQ
hN4>of1PH0co5aLG1_ooool=o`0000koi^KV3_l`<30<ocXj>PKooooo3_mKFe/=oalO7`ko1`L73OmT
I6@5ooooo`kohN7Q3Ol^;Rh>o`H61Pgo3@d=1Oooool>o`<30`go8B4Q3_o8b<P=ocXj>Q7ooooo000?
ooooo`koN7Qh3_mHF5P=oemOGa;ooooo3_lN7Qh>o`D51@go6QXJ4_ooool>oc@d=0ko30`<3_oKfm/<
ode=C@Kooooo3OmOGel>on7Qh@koH61P3?lG5aL6ooooo`go00003_oVi^H>oc0`<0co>SXj1_ooool>
oe]KF`go7alO3_l71`L=ofATI0Gooooo3_oQhN4=obh^;Pko1PH63Ol=3@d5ooooo`ko0`<33OlQ8B4>
olS8b0go>SXj4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D
50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6oooo
o`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG
5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo
<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKo
oooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go
6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go
?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW
1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<3
3_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko0000
3Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooc
lo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZ
JVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0
000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Ooo
ool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>
oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>
oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5
ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5oooo
o`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>oooo
o`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRH
V0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oo
oooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko
4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco
:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko
00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<
3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C
3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo
3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mR
HV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_od
m?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_oo
ool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV
9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=
oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6
ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=
oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B
4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>
CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`
L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>oooo
o`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c3Ooclo<5ooooo`ko30`<3_l0000=oa@D50go
inOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go
0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko
00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo4Oooool000oooooo3_mRHV8>oa8B4Pgo<c<c
3Ooclo<5ooooo`ko30`<3_l0000=oa@D50goinOW1Oooool>oaPH60ko4Q8B3_odm?@<odi>CPKooooo
3OmZJVX>ooooo`koDe=C3?lD51@6ooooo`go0`<33_ooool>oaHF5Pco:RXZ1_ooool>og1`L0go6QXJ
3_l0000=oiRHV0Gooooo3_omoOd=oaLG5`ko00003Ol>3Ph5ooooo`ko00003OlV9RH>ooooo`go?clo
4Oooool000oooooo3_m[Jf/>o`0000go>3Ph3OomoOd5ooooo`ko30`<3_l>3Ph=oaHF5PgoUIFE1Ooo
ool>o`0000ko9RHV3_ooool<ofa/K0Kooooo3Om_Kfl>ooknoPkoA4A43?l00006ooooo`go61PH3_om
oOd>o`410@co71`L1_ooool>ofATI0go3`l?3_l20P8Pooooo`go10@43_lA4A4=oaXJ6PGooooo3_l;
2`/=ob/[:`koo?cl3Olm?CdAooooo`003oooool>of][J`ko00003Olh>3P=oogmo@Gooooo3_l<30`>
o`h>3Pgo5QHF3OnEUID5ooooo`ko00003_lV9RH>ooooo`coK6a/1_ooool=ofm_K`koo_kn3_m4A4@<
o`0000Kooooo3OlH61P>oogmo@ko0@413?lL71`6ooooo`koI6AT3Ol?3`l>o`820R3ooooo3Ol410@>
oa4A4@go6QXJ1Oooool>o`/;2`go:b/[3_olo?`=ocdm?A7ooooo000?ooooo`koJf][3_l0000=ocPh
>0gooOgm1Oooool>o``<30ko3Ph>3OlF5QH=oiFEU@Gooooo3_l0000>obHV9Pkooooo3?m/K6`6oooo
o`goKfm_3_ono_h>odA4A0co00001_ooool=oaPH60kooOgm3_l10@4<oa`L70Kooooo3_mTI6@=o`l?
3`ko0P828?ooool=o`@410ko4A4A3OlJ6QX5ooooo`ko2`/;3Ol[:b/>ooclo0go?Cdm4Oooool000oo
oooo3_m[Jf/>o`0000go>3Ph3OomoOd5ooooo`ko30`<3_l>3Ph=oaHF5PgoUIFE1Oooool>o`0000ko
9RHV3_ooool<ofa/K0Kooooo3Om_Kfl>ooknoPkoA4A43?l00006ooooo`go61PH3_omoOd>o`410@co
71`L1_ooool>ofATI0go3`l?3_l20P8Pooooo`go10@43_lA4A4=oaXJ6PGooooo3_l;2`/=ob/[:`ko
o?cl3Olm?CdAooooo`003oooool>of][J`ko00003Olh>3P=oogmo@Gooooo3_l<30`>o`h>3Pgo5QHF
3OnEUID5ooooo`ko00003_lV9RH>ooooo`coK6a/1_ooool=ofm_K`koo_kn3_m4A4@<o`0000Kooooo
3OlH61P>oogmo@ko0@413?lL71`6ooooo`koI6AT3Ol?3`l>o`820R3ooooo3Ol410@>oa4A4@go6QXJ
1Oooool>o`/;2`go:b/[3_olo?`=ocdm?A7ooooo000?ooooo`koJf][3_l0000=ocPh>0gooOgm1Ooo
ool>o``<30ko3Ph>3OlF5QH=oiFEU@Gooooo3_l0000>obHV9Pkooooo3?m/K6`6ooooo`goKfm_3_on
o_h>odA4A0co00001_ooool=oaPH60kooOgm3_l10@4<oa`L70Kooooo3_mTI6@=o`l?3`ko0P828?oo
ool=o`@410ko4A4A3OlJ6QX5ooooo`ko2`/;3Ol[:b/>ooclo0go?Cdm4Oooool000oooooo3_m[Jf/>
o`0000go>3Ph3OomoOd5ooooo`ko30`<3_l>3Ph=oaHF5PgoUIFE1Oooool>o`0000ko9RHV3_ooool<
ofa/K0Kooooo3Om_Kfl>ooknoPkoA4A43?l00006ooooo`go61PH3_omoOd>o`410@co71`L1_ooool>
ofATI0go3`l?3_l20P8Pooooo`go10@43_lA4A4=oaXJ6PGooooo3_l;2`/=ob/[:`koo?cl3Olm?CdA
ooooo`003oooool>of][J`ko00003Olh>3P=oogmo@Gooooo3_l<30`>o`h>3Pgo5QHF3OnEUID5oooo
o`ko00003_lV9RH>ooooo`coK6a/1_ooool=ofm_K`koo_kn3_m4A4@<o`0000Kooooo3OlH61P>oogm
o@ko0@413?lL71`6ooooo`koI6AT3Ol?3`l>o`820R3ooooo3Ol410@>oa4A4@go6QXJ1Oooool>o`/;
2`go:b/[3_olo?`=ocdm?A7ooooo000?ooooo`koJf][3_l0000=ocPh>0gooOgm1Oooool>o``<30ko
3Ph>3OlF5QH=oiFEU@Gooooo3_l0000>obHV9Pkooooo3?m/K6`6ooooo`goKfm_3_ono_h>odA4A0co
00001_ooool=oaPH60kooOgm3_l10@4<oa`L70Kooooo3_mTI6@=o`l?3`ko0P828?ooool=o`@410ko
4A4A3OlJ6QX5ooooo`ko2`/;3Ol[:b/>ooclo0go?Cdm4Oooool000oooooo3_m[Jf/>o`0000go>3Ph
3OomoOd5ooooo`ko30`<3_l>3Ph=oaHF5PgoUIFE1Oooool>o`0000ko9RHV3_ooool<ofa/K0Kooooo
3Om_Kfl>ooknoPkoA4A43?l00006ooooo`go61PH3_omoOd>o`410@co71`L1_ooool>ofATI0go3`l?
3_l20P8Pooooo`go10@43_lA4A4=oaXJ6PGooooo3_l;2`/=ob/[:`koo?cl3Olm?CdAooooo`003ooo
ool>of][J`ko00003Olh>3P=oogmo@Gooooo3_l<30`>o`h>3Pgo5QHF3OnEUID5ooooo`ko00003_lV
9RH>ooooo`coK6a/1_ooool=ofm_K`koo_kn3_m4A4@<o`0000Kooooo3OlH61P>oogmo@ko0@413?lL
71`6ooooo`koI6AT3Ol?3`l>o`820R3ooooo3Ol410@>oa4A4@go6QXJ1Oooool>o`/;2`go:b/[3_ol
o?`=ocdm?A7ooooo000?ooooo`koJf][3_l0000=ocPh>0gooOgm1Oooool>o``<30ko3Ph>3OlF5QH=
oiFEU@Gooooo3_l0000>obHV9Pkooooo3?m/K6`6ooooo`goKfm_3_ono_h>odA4A0co00001_ooool=
oaPH60kooOgm3_l10@4<oa`L70Kooooo3_mTI6@=o`l?3`ko0P828?ooool=o`@410ko4A4A3OlJ6QX5
ooooo`ko2`/;3Ol[:b/>ooclo0go?Cdm4Oooool000oooooo3_m[Jf/>o`0000go>3Ph3OomoOd5oooo
o`ko30`<3_l>3Ph=oaHF5PgoUIFE1Oooool>o`0000ko9RHV3_ooool<ofa/K0Kooooo3Om_Kfl>ookn
oPkoA4A43?l00006ooooo`go61PH3_omoOd>o`410@co71`L1_ooool>ofATI0go3`l?3_l20P8Poooo
o`go10@43_lA4A4=oaXJ6PGooooo3_l;2`/=ob/[:`koo?cl3Olm?CdAooooo`003oooool>odm?C`ko
0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@co
I6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko
=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko
^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH6
3On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo
3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D5
3_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR
8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_oo
ool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol3
0`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ
:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5
ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>
omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=
ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKf
mPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=C
D`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=
3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAoooo
o`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko
30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko
0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Go
oooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo
3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C4
3_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^
1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003ooo
ool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh
>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ
6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<
30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>
o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<
o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>
omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?
C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWi
n@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6oooo
o`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG
5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go
1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKo
oooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go
1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`003oooool>odm?C`ko0`<3
3OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT
1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg
3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh
3OlZ:RXAooooo`003oooool>odm?C`ko0`<33OlR8R8=ooKfmPGooooo3_lB4Q8>o`T92@go1PH63On3
Ph<5ooooo`ko30`<3_lh>3P>ooWin@coI6AT1_ooool=oe=CD`koa<C43_lS8b<<o`X:2PKooooo3OlP
820>omkNgPko0@413?lJ6QX6ooooo`ko=cLg3Ol30`<>o`d=3@go[Zj^1Oooool>omSHf0go1@D53_lI
6AT=ob<S8`Gooooo3_l<30`=oaLG5`ko^;Rh3OlZ:RXAooooo`00oooooooeooooo`00oooooooeoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-1.16282, \
-0.102347, 0.0744193, 0.0744193}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-5.56752, -0.102347, 0.0744193, 0.0744193}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-9.96756, -0.102347, 0.0744193, 0.0744193}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-14.3676, -0.102347, 0.0744193, 0.0744193}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-18.7676, -0.102347, 0.0744193, 0.0744193}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-23.1677, -0.102347, 0.0744193, \
0.0744193}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-27.5677, -0.102347, \
0.0744193, 0.0744193}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-31.9678, \
-0.102347, 0.0744193, 0.0744193}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11494 
%%ImageSize: 500 57.4713 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00273673 0.119048 [
[ 0 0 0 0 ]
[ 1 .11494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11494 L
0 .11494 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00273673 0.133279 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2520002C
1D1D0A33
6E675373
EBF7DDFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00273673 0.253695 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6D00345C
CD4B0327
FFB61113
2F157051
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00273673 0.374111 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
271D38A5
49074BFF
6A0041D5
2F29242D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00273673 0.494527 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A881518
08D88D63
00DFFFAE
58731314
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00273673 0.614943 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F2F1E39
4740171B
1D1E0009
FFBBEBD4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00273673 0.735359 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
130A2A44
1A07101A
03000812
221A2DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00273673 0.855774 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
07A1CA44
0A22963C
52005855
3DFFC925
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00273673 0.97619 0.112206 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F2B1130F
7BB53900
2D9B561B
FF580436
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 57.4375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000>B000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go
=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Ko
oooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`go
XJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P
3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU
1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C
3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C
3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmL
G5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?
Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:
b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=
ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=
ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>
obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lA
ooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5oooo
o`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_
;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4
A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Go
oooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>Pko
R8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:Pgo
A4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`00
3oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW
3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN
3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo
3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]
KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE
5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Ooo
ool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>
obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>
ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6
ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=
ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`00
00go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH
60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L7
1`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko
820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0co
YJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko
4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko
4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d
3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo
3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q
3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003oooool>obDU9@ko820P3Ol0
000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_oo
ool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:
2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?
3`lAooooo`003oooool>obDU9@ko820P3Ol0000=ob`/;0Gooooo3_m]KFd>o`0000go=3@d3OmLG5`5
ooooo`ko9bLW3_lM7Ad>ocPh>0coYJFU1_ooool=ocXj>PkoR8R83_lE5AD<oaPH60Kooooo3Om?Cdl>
obl_;`ko7QhN3?li>CT6ooooo`ko4a<C3Ol:2PX>obXZ:PgoA4A41Oooool>o`L71`goXJ6Q3_o:b/X=
odA4A0Gooooo3_obl_8=ok6a/@ko4a<C3Ol?3`lAooooo`003ooooolLoadM7@go2PX:3Olc<c<5oooo
o`kocLg=3_m;Bd/=o`<30`go9bLW1Oooool>odU9B@ko1`L73_m;Bd/Booooo`go20P83_oHf=P>ohf=
S@coHf=S1_ooool=odM7A`ko@4103_lG5aL<oa/K6`Kooooo3_lJ6QX=o`L71`ko410@3OlJ6QX5oooo
o`ko2PX:3OlR8R8>oiJFUPgo?3`l1Oooool>og]kN`go]KFe3_li>CT=o`00017ooooo000?oooooaco
7AdM3Ol:2PX=oc<c<`Gooooo3_o=cLd>od];B`go0`<33OlW9bL5ooooo`koBDU93_l71`L>od];Ba;o
oooo3Ol820P>omSHf0koSHf=3?mSHf<6ooooo`goAdM73_m0@40>oaLG5`co6a/K1_ooool>oaXJ6Pgo
1`L73_l@410=oaXJ6PGooooo3_l:2PX=ob8R8PkoUYJF3Oll?3`5ooooo`koNg]k3One]KD>ocTi>@go
00004Oooool000oooooo7?lM7Ad=o`X:2Pgo<c<c1Oooool>olg=c@koBd];3Ol30`<=obLW9`Gooooo
3_m9BDT>o`L71`koBd];4_ooool=o`P820kof=SH3_n=SHd<of=SH`Kooooo3Om7AdL>od10@0ko5aLG
3?lK6a/6ooooo`ko6QXJ3Ol71`L>oa0@40go6QXJ1Oooool>o`X:2Pgo8R8R3_nFUYH=oc`l?0Gooooo
3_mkNg/=okFe]@ko>CTi3Ol0000Aooooo`003ooooolLoadM7@go2PX:3Olc<c<5ooooo`kocLg=3_m;
Bd/=o`<30`go9bLW1Oooool>odU9B@ko1`L73_m;Bd/Booooo`go20P83_oHf=P>ohf=S@coHf=S1_oo
ool=odM7A`ko@4103_lG5aL<oa/K6`Kooooo3_lJ6QX=o`L71`ko410@3OlJ6QX5ooooo`ko2PX:3OlR
8R8>oiJFUPgo?3`l1Oooool>og]kN`go]KFe3_li>CT=o`00017ooooo000?oooooaco7AdM3Ol:2PX=
oc<c<`Gooooo3_o=cLd>od];B`go0`<33OlW9bL5ooooo`koBDU93_l71`L>od];Ba;ooooo3Ol820P>
omSHf0koSHf=3?mSHf<6ooooo`goAdM73_m0@40>oaLG5`co6a/K1_ooool>oaXJ6Pgo1`L73_l@410=
oaXJ6PGooooo3_l:2PX=ob8R8PkoUYJF3Oll?3`5ooooo`koNg]k3One]KD>ocTi>@go00004Oooool0
00oooooo7?lM7Ad=o`X:2Pgo<c<c1Oooool>olg=c@koBd];3Ol30`<=obLW9`Gooooo3_m9BDT>o`L7
1`koBd];4_ooool=o`P820kof=SH3_n=SHd<of=SH`Kooooo3Om7AdL>od10@0ko5aLG3?lK6a/6oooo
o`ko6QXJ3Ol71`L>oa0@40go6QXJ1Oooool>o`X:2Pgo8R8R3_nFUYH=oc`l?0Gooooo3_mkNg/=okFe
]@ko>CTi3Ol0000Aooooo`003ooooolLoadM7@go2PX:3Olc<c<5ooooo`kocLg=3_m;Bd/=o`<30`go
9bLW1Oooool>odU9B@ko1`L73_m;Bd/Booooo`go20P83_oHf=P>ohf=S@coHf=S1_ooool=odM7A`ko
@4103_lG5aL<oa/K6`Kooooo3_lJ6QX=o`L71`ko410@3OlJ6QX5ooooo`ko2PX:3OlR8R8>oiJFUPgo
?3`l1Oooool>og]kN`go]KFe3_li>CT=o`00017ooooo000?oooooaco7AdM3Ol:2PX=oc<c<`Gooooo
3_o=cLd>od];B`go0`<33OlW9bL5ooooo`koBDU93_l71`L>od];Ba;ooooo3Ol820P>omSHf0koSHf=
3?mSHf<6ooooo`goAdM73_m0@40>oaLG5`co6a/K1_ooool>oaXJ6Pgo1`L73_l@410=oaXJ6PGooooo
3_l:2PX=ob8R8PkoUYJF3Oll?3`5ooooo`koNg]k3One]KD>ocTi>@go00004Oooool000oooooo7?lM
7Ad=o`X:2Pgo<c<c1Oooool>olg=c@koBd];3Ol30`<=obLW9`Gooooo3_m9BDT>o`L71`koBd];4_oo
ool=o`P820kof=SH3_n=SHd<of=SH`Kooooo3Om7AdL>od10@0ko5aLG3?lK6a/6ooooo`ko6QXJ3Ol7
1`L>oa0@40go6QXJ1Oooool>o`X:2Pgo8R8R3_nFUYH=oc`l?0Gooooo3_mkNg/=okFe]@ko>CTi3Ol0
000Aooooo`003ooooolLoadM7@go2PX:3Olc<c<5ooooo`kocLg=3_m;Bd/=o`<30`go9bLW1Oooool>
odU9B@ko1`L73_m;Bd/Booooo`go20P83_oHf=P>ohf=S@coHf=S1_ooool=odM7A`ko@4103_lG5aL<
oa/K6`Kooooo3_lJ6QX=o`L71`ko410@3OlJ6QX5ooooo`ko2PX:3OlR8R8>oiJFUPgo?3`l1Oooool>
og]kN`go]KFe3_li>CT=o`00017ooooo000?oooooaco7AdM3Ol:2PX=oc<c<`Gooooo3_o=cLd>od];
B`go0`<33OlW9bL5ooooo`koBDU93_l71`L>od];Ba;ooooo3Ol820P>omSHf0koSHf=3?mSHf<6oooo
o`goAdM73_m0@40>oaLG5`co6a/K1_ooool>oaXJ6Pgo1`L73_l@410=oaXJ6PGooooo3_l:2PX=ob8R
8PkoUYJF3Oll?3`5ooooo`koNg]k3One]KD>ocTi>@go00004Oooool000oooooo7?lM7Ad=o`X:2Pgo
<c<c1Oooool>olg=c@koBd];3Ol30`<=obLW9`Gooooo3_m9BDT>o`L71`koBd];4_ooool=o`P820ko
f=SH3_n=SHd<of=SH`Kooooo3Om7AdL>od10@0ko5aLG3?lK6a/6ooooo`ko6QXJ3Ol71`L>oa0@40go
6QXJ1Oooool>o`X:2Pgo8R8R3_nFUYH=oc`l?0Gooooo3_mkNg/=okFe]@ko>CTi3Ol0000Aooooo`00
3ooooolLoadM7@go2PX:3Olc<c<5ooooo`kocLg=3_m;Bd/=o`<30`go9bLW1Oooool>odU9B@ko1`L7
3_m;Bd/Booooo`go20P83_oHf=P>ohf=S@coHf=S1_ooool=odM7A`ko@4103_lG5aL<oa/K6`Kooooo
3_lJ6QX=o`L71`ko410@3OlJ6QX5ooooo`ko2PX:3OlR8R8>oiJFUPgo?3`l1Oooool>og]kN`go]KFe
3_li>CT=o`00017ooooo000?ooooo`koKVi^3_mWIfL=oe=CD`goLg=c4oooool>okJf]Pgo4A4A3OlC
4a<5ooooo`koJVYZ3_l0000>od51@@coeMGE1_ooool=o`0000kogmoO3_ooool<ojj^[PKooooo3OlM
7Ad>oahN7Pko00003?l92@T6ooooo`ko0`<33Ol0000>o`P820go4Q8B1Oooool>oe9BDPgo00003_mH
F5P=oeEEE@Gooooo3_l];Bd=oi^KV`koEUIF3OlK6a/Aooooo`003oooool>ofi^KPkoIfMW3OmCDe<=
og=cLa?ooooo3_nf][H=oa4A4@go4a<C1Oooool>ofYZJPko00003_m1@D4<omGEe@Kooooo3Ol0000>
omoOg`kooooo3?n^[Zh6ooooo`go7AdM3_lN7Qh>o`0000co2@T91_ooool>o`<30`go00003_l820P=
oa8B4PGooooo3_mBDU8=o`0000koF5QH3OmEEED5ooooo`ko;Bd]3OnKVi/>oeIFEPgo6a/K4Oooool0
00oooooo3_m^KVh>ofMWI`goDe=C3OmcLg<Cooooo`ko][Jf3OlA4A4=oa<C4`Gooooo3_mZJVX>o`00
00ko@D513?oEeMD6ooooo`go00003_oOgml>ooooo`co[Zj^1_ooool=oadM7@ko7QhN3_l0000<o`T9
2@Kooooo3_l30`<=o`0000ko20P83OlB4Q85ooooo`koDU9B3Ol0000>oeQHF0goEEEE1Oooool>obd]
;@goVi^K3_mFEUH=oa/K6a7ooooo000?ooooo`koKVi^3_mWIfL=oe=CD`goLg=c4oooool>okJf]Pgo
4A4A3OlC4a<5ooooo`koJVYZ3_l0000>od51@@coeMGE1_ooool=o`0000kogmoO3_ooool<ojj^[PKo
oooo3OlM7Ad>oahN7Pko00003?l92@T6ooooo`ko0`<33Ol0000>o`P820go4Q8B1Oooool>oe9BDPgo
00003_mHF5P=oeEEE@Gooooo3_l];Bd=oi^KV`koEUIF3OlK6a/Aooooo`003oooool>ofi^KPkoIfMW
3OmCDe<=og=cLa?ooooo3_nf][H=oa4A4@go4a<C1Oooool>ofYZJPko00003_m1@D4<omGEe@Kooooo
3Ol0000>omoOg`kooooo3?n^[Zh6ooooo`go7AdM3_lN7Qh>o`0000co2@T91_ooool>o`<30`go0000
3_l820P=oa8B4PGooooo3_mBDU8=o`0000koF5QH3OmEEED5ooooo`ko;Bd]3OnKVi/>oeIFEPgo6a/K
4Oooool000oooooo3_m^KVh>ofMWI`goDe=C3OmcLg<Cooooo`ko][Jf3OlA4A4=oa<C4`Gooooo3_mZ
JVX>o`0000ko@D513?oEeMD6ooooo`go00003_oOgml>ooooo`co[Zj^1_ooool=oadM7@ko7QhN3_l0
000<o`T92@Kooooo3_l30`<=o`0000ko20P83OlB4Q85ooooo`koDU9B3Ol0000>oeQHF0goEEEE1Ooo
ool>obd];@goVi^K3_mFEUH=oa/K6a7ooooo000?ooooo`koKVi^3_mWIfL=oe=CD`goLg=c4oooool>
okJf]Pgo4A4A3OlC4a<5ooooo`koJVYZ3_l0000>od51@@coeMGE1_ooool=o`0000kogmoO3_ooool<
ojj^[PKooooo3OlM7Ad>oahN7Pko00003?l92@T6ooooo`ko0`<33Ol0000>o`P820go4Q8B1Oooool>
oe9BDPgo00003_mHF5P=oeEEE@Gooooo3_l];Bd=oi^KV`koEUIF3OlK6a/Aooooo`003oooool>ofi^
KPkoIfMW3OmCDe<=og=cLa?ooooo3_nf][H=oa4A4@go4a<C1Oooool>ofYZJPko00003_m1@D4<omGE
e@Kooooo3Ol0000>omoOg`kooooo3?n^[Zh6ooooo`go7AdM3_lN7Qh>o`0000co2@T91_ooool>o`<3
0`go00003_l820P=oa8B4PGooooo3_mBDU8=o`0000koF5QH3OmEEED5ooooo`ko;Bd]3OnKVi/>oeIF
EPgo6a/K4Oooool000oooooo3_m^KVh>ofMWI`goDe=C3OmcLg<Cooooo`ko][Jf3OlA4A4=oa<C4`Go
oooo3_mZJVX>o`0000ko@D513?oEeMD6ooooo`go00003_oOgml>ooooo`co[Zj^1_ooool=oadM7@ko
7QhN3_l0000<o`T92@Kooooo3_l30`<=o`0000ko20P83OlB4Q85ooooo`koDU9B3Ol0000>oeQHF0go
EEEE1Oooool>obd];@goVi^K3_mFEUH=oa/K6a7ooooo000?ooooo`koKVi^3_mWIfL=oe=CD`goLg=c
4oooool>okJf]Pgo4A4A3OlC4a<5ooooo`koJVYZ3_l0000>od51@@coeMGE1_ooool=o`0000kogmoO
3_ooool<ojj^[PKooooo3OlM7Ad>oahN7Pko00003?l92@T6ooooo`ko0`<33Ol0000>o`P820go4Q8B
1Oooool>oe9BDPgo00003_mHF5P=oeEEE@Gooooo3_l];Bd=oi^KV`koEUIF3OlK6a/Aooooo`003ooo
ool>ofi^KPkoIfMW3OmCDe<=og=cLa?ooooo3_nf][H=oa4A4@go4a<C1Oooool>ofYZJPko00003_m1
@D4<omGEe@Kooooo3Ol0000>omoOg`kooooo3?n^[Zh6ooooo`go7AdM3_lN7Qh>o`0000co2@T91_oo
ool>o`<30`go00003_l820P=oa8B4PGooooo3_mBDU8=o`0000koF5QH3OmEEED5ooooo`ko;Bd]3OnK
Vi/>oeIFEPgo6a/K4Oooool000oooooo3_m^KVh>ofMWI`goDe=C3OmcLg<Cooooo`ko][Jf3OlA4A4=
oa<C4`Gooooo3_mZJVX>o`0000ko@D513?oEeMD6ooooo`go00003_oOgml>ooooo`co[Zj^1_ooool=
oadM7@ko7QhN3_l0000<o`T92@Kooooo3_l30`<=o`0000ko20P83OlB4Q85ooooo`koDU9B3Ol0000>
oeQHF0goEEEE1Oooool>obd];@goVi^K3_mFEUH=oa/K6a7ooooo000?ooooo`koKVi^3_mWIfL=oe=C
D`goLg=c4oooool>okJf]Pgo4A4A3OlC4a<5ooooo`koJVYZ3_l0000>od51@@coeMGE1_ooool=o`00
00kogmoO3_ooool<ojj^[PKooooo3OlM7Ad>oahN7Pko00003?l92@T6ooooo`ko0`<33Ol0000>o`P8
20go4Q8B1Oooool>oe9BDPgo00003_mHF5P=oeEEE@Gooooo3_l];Bd=oi^KV`koEUIF3OlK6a/Aoooo
o`003oooool>on_[j`komoOg3OoMgMdBooooo`ko;bl_3_lE5AD=og1`L0goDE5A1Oooool>obl_;`ko
:BTY3_lT92@<obd];@Kooooo3OmHF5P>og=cL`ko4a<C3?lD51@Cooooo`ko^k^k3_o[jn/<omCDe0Ko
oooo3_lR8R8=oaXJ6Pko;Bd]4_ooool>ocdm?@gooooo3_o9bLT=obDU9A?ooooo3OmHF5P>o`@410go
=SHf4Oooool000oooooo3_o[jn/>ooOgm`gogMgM4_ooool>obl_;`ko5ADE3Om`L70=oe5AD@Gooooo
3_l_;bl>obTY:@ko92@T3?l];Bd6ooooo`goF5QH3_mcLg<>oa<C4`co51@D4oooool>ok^k^`kojn_[
3?oDe=@6ooooo`ko8R8R3OlJ6QX>obd];A;ooooo3_lm?Cd=ooooo`kobLW93OlU9BDCooooo`goF5QH
3_l410@=ocHf=Q7ooooo000?ooooo`kojn_[3_ogmoL=omgMgA;ooooo3_l_;bl>oaDE5@goL71`3OmA
DE45ooooo`ko;bl_3_lY:BT>ob@T90co;Bd]1_ooool=oeQHF0koLg=c3_lC4a<<oa@D51?ooooo3_nk
^k/>on_[j`coe=CD1_ooool>ob8R8Pgo6QXJ3_l];BdBooooo`ko?Cdm3Oooool>olW9b@go9BDU4ooo
ool=oeQHF0ko10@43Olf=SHAooooo`003oooool>on_[j`komoOg3OoMgMdBooooo`ko;bl_3_lE5AD=
og1`L0goDE5A1Oooool>obl_;`ko:BTY3_lT92@<obd];@Kooooo3OmHF5P>og=cL`ko4a<C3?lD51@C
ooooo`ko^k^k3_o[jn/<omCDe0Kooooo3_lR8R8=oaXJ6Pko;Bd]4_ooool>ocdm?@gooooo3_o9bLT=
obDU9A?ooooo3OmHF5P>o`@410go=SHf4Oooool000oooooo3_o[jn/>ooOgm`gogMgM4_ooool>obl_
;`ko5ADE3Om`L70=oe5AD@Gooooo3_l_;bl>obTY:@ko92@T3?l];Bd6ooooo`goF5QH3_mcLg<>oa<C
4`co51@D4oooool>ok^k^`kojn_[3?oDe=@6ooooo`ko8R8R3OlJ6QX>obd];A;ooooo3_lm?Cd=oooo
o`kobLW93OlU9BDCooooo`goF5QH3_l410@=ocHf=Q7ooooo000?ooooo`kojn_[3_ogmoL=omgMgA;o
oooo3_l_;bl>oaDE5@goL71`3OmADE45ooooo`ko;bl_3_lY:BT>ob@T90co;Bd]1_ooool=oeQHF0ko
Lg=c3_lC4a<<oa@D51?ooooo3_nk^k/>on_[j`coe=CD1_ooool>ob8R8Pgo6QXJ3_l];BdBooooo`ko
?Cdm3Oooool>olW9b@go9BDU4oooool=oeQHF0ko10@43Olf=SHAooooo`003oooool>on_[j`komoOg
3OoMgMdBooooo`ko;bl_3_lE5AD=og1`L0goDE5A1Oooool>obl_;`ko:BTY3_lT92@<obd];@Kooooo
3OmHF5P>og=cL`ko4a<C3?lD51@Cooooo`ko^k^k3_o[jn/<omCDe0Kooooo3_lR8R8=oaXJ6Pko;Bd]
4_ooool>ocdm?@gooooo3_o9bLT=obDU9A?ooooo3OmHF5P>o`@410go=SHf4Oooool000oooooo3_o[
jn/>ooOgm`gogMgM4_ooool>obl_;`ko5ADE3Om`L70=oe5AD@Gooooo3_l_;bl>obTY:@ko92@T3?l]
;Bd6ooooo`goF5QH3_mcLg<>oa<C4`co51@D4oooool>ok^k^`kojn_[3?oDe=@6ooooo`ko8R8R3OlJ
6QX>obd];A;ooooo3_lm?Cd=ooooo`kobLW93OlU9BDCooooo`goF5QH3_l410@=ocHf=Q7ooooo000?
ooooo`kojn_[3_ogmoL=omgMgA;ooooo3_l_;bl>oaDE5@goL71`3OmADE45ooooo`ko;bl_3_lY:BT>
ob@T90co;Bd]1_ooool=oeQHF0koLg=c3_lC4a<<oa@D51?ooooo3_nk^k/>on_[j`coe=CD1_ooool>
ob8R8Pgo6QXJ3_l];BdBooooo`ko?Cdm3Oooool>olW9b@go9BDU4oooool=oeQHF0ko10@43Olf=SHA
ooooo`003oooool>on_[j`komoOg3OoMgMdBooooo`ko;bl_3_lE5AD=og1`L0goDE5A1Oooool>obl_
;`ko:BTY3_lT92@<obd];@Kooooo3OmHF5P>og=cL`ko4a<C3?lD51@Cooooo`ko^k^k3_o[jn/<omCD
e0Kooooo3_lR8R8=oaXJ6Pko;Bd]4_ooool>ocdm?@gooooo3_o9bLT=obDU9A?ooooo3OmHF5P>o`@4
10go=SHf4Oooool000oooooo3_o[jn/>ooOgm`gogMgM4_ooool>obl_;`ko5ADE3Om`L70=oe5AD@Go
oooo3_l_;bl>obTY:@ko92@T3?l];Bd6ooooo`goF5QH3_mcLg<>oa<C4`co51@D4oooool>ok^k^`ko
jn_[3?oDe=@6ooooo`ko8R8R3OlJ6QX>obd];A;ooooo3_lm?Cd=ooooo`kobLW93OlU9BDCooooo`go
F5QH3_l410@=ocHf=Q7ooooo000?ooooo`kojn_[3_ogmoL=omgMgA;ooooo3_l_;bl>oaDE5@goL71`
3OmADE45ooooo`ko;bl_3_lY:BT>ob@T90co;Bd]1_ooool=oeQHF0koLg=c3_lC4a<<oa@D51?ooooo
3_nk^k/>on_[j`coe=CD1_ooool>ob8R8Pgo6QXJ3_l];BdBooooo`ko?Cdm3Oooool>olW9b@go9BDU
4oooool=oeQHF0ko10@43Olf=SHAooooo`003oooool>on_[j`komoOg3OoMgMdBooooo`ko;bl_3_lE
5AD=og1`L0goDE5A1Oooool>obl_;`ko:BTY3_lT92@<obd];@Kooooo3OmHF5P>og=cL`ko4a<C3?lD
51@Cooooo`ko^k^k3_o[jn/<omCDe0Kooooo3_lR8R8=oaXJ6Pko;Bd]4_ooool>ocdm?@gooooo3_o9
bLT=obDU9A?ooooo3OmHF5P>o`@410go=SHf4Oooool00?oooooomOooool00?oooooomOooool00001
\
\>"],
  ImageRangeCache->{{{0, 499}, {56.4375, 0}} -> {-0.268325, -0.0229933, \
0.0171075, 0.0171075}, {{15.625, 69.375}, {55.0625, 1.3125}} -> {-1.16282, \
-0.102347, 0.0744193, 0.0744193}, {{74.8125, 128.562}, {55.0625, 1.3125}} -> \
{-5.56752, -0.102347, 0.0744193, 0.0744193}, {{133.938, 187.688}, {55.0625, \
1.3125}} -> {-9.96756, -0.102347, 0.0744193, 0.0744193}, {{193.062, 246.812}, \
{55.0625, 1.3125}} -> {-14.3676, -0.102347, 0.0744193, 0.0744193}, {{252.188, \
305.938}, {55.0625, 1.3125}} -> {-18.7676, -0.102347, 0.0744193, 0.0744193}, \
{{311.312, 365.062}, {55.0625, 1.3125}} -> {-23.1677, -0.102347, 0.0744193, \
0.0744193}, {{370.438, 424.188}, {55.0625, 1.3125}} -> {-27.5677, -0.102347, \
0.0744193, 0.0744193}, {{429.562, 483.312}, {55.0625, 1.3125}} -> {-31.9678, \
-0.102347, 0.0744193, 0.0744193}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 0.942097 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10892 -18 -4.5 ]
[-0.0125 .10892 0 4.5 ]
[-0.0125 .20313 -18 -4.5 ]
[-0.0125 .20313 0 4.5 ]
[-0.0125 .29734 -18 -4.5 ]
[-0.0125 .29734 0 4.5 ]
[-0.0125 .39155 -18 -4.5 ]
[-0.0125 .39155 0 4.5 ]
[-0.0125 .48576 -18 -4.5 ]
[-0.0125 .48576 0 4.5 ]
[-0.0125 .57997 -18 -4.5 ]
[-0.0125 .57997 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10892 m
.00625 .10892 L
s
[(0.1)] -0.0125 .10892 1 0 Mshowa
0 .20313 m
.00625 .20313 L
s
[(0.2)] -0.0125 .20313 1 0 Mshowa
0 .29734 m
.00625 .29734 L
s
[(0.3)] -0.0125 .29734 1 0 Mshowa
0 .39155 m
.00625 .39155 L
s
[(0.4)] -0.0125 .39155 1 0 Mshowa
0 .48576 m
.00625 .48576 L
s
[(0.5)] -0.0125 .48576 1 0 Mshowa
0 .57997 m
.00625 .57997 L
s
[(0.6)] -0.0125 .57997 1 0 Mshowa
.125 Mabswid
0 .03356 m
.00375 .03356 L
s
0 .0524 m
.00375 .0524 L
s
0 .07124 m
.00375 .07124 L
s
0 .09008 m
.00375 .09008 L
s
0 .12777 m
.00375 .12777 L
s
0 .14661 m
.00375 .14661 L
s
0 .16545 m
.00375 .16545 L
s
0 .18429 m
.00375 .18429 L
s
0 .22198 m
.00375 .22198 L
s
0 .24082 m
.00375 .24082 L
s
0 .25966 m
.00375 .25966 L
s
0 .2785 m
.00375 .2785 L
s
0 .31619 m
.00375 .31619 L
s
0 .33503 m
.00375 .33503 L
s
0 .35387 m
.00375 .35387 L
s
0 .37271 m
.00375 .37271 L
s
0 .4104 m
.00375 .4104 L
s
0 .42924 m
.00375 .42924 L
s
0 .44808 m
.00375 .44808 L
s
0 .46692 m
.00375 .46692 L
s
0 .50461 m
.00375 .50461 L
s
0 .52345 m
.00375 .52345 L
s
0 .54229 m
.00375 .54229 L
s
0 .56113 m
.00375 .56113 L
s
0 .59882 m
.00375 .59882 L
s
0 .61766 m
.00375 .61766 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10892 m
1 .10892 L
s
.99375 .20313 m
1 .20313 L
s
.99375 .29734 m
1 .29734 L
s
.99375 .39155 m
1 .39155 L
s
.99375 .48576 m
1 .48576 L
s
.99375 .57997 m
1 .57997 L
s
.125 Mabswid
.99625 .03356 m
1 .03356 L
s
.99625 .0524 m
1 .0524 L
s
.99625 .07124 m
1 .07124 L
s
.99625 .09008 m
1 .09008 L
s
.99625 .12777 m
1 .12777 L
s
.99625 .14661 m
1 .14661 L
s
.99625 .16545 m
1 .16545 L
s
.99625 .18429 m
1 .18429 L
s
.99625 .22198 m
1 .22198 L
s
.99625 .24082 m
1 .24082 L
s
.99625 .25966 m
1 .25966 L
s
.99625 .2785 m
1 .2785 L
s
.99625 .31619 m
1 .31619 L
s
.99625 .33503 m
1 .33503 L
s
.99625 .35387 m
1 .35387 L
s
.99625 .37271 m
1 .37271 L
s
.99625 .4104 m
1 .4104 L
s
.99625 .42924 m
1 .42924 L
s
.99625 .44808 m
1 .44808 L
s
.99625 .46692 m
1 .46692 L
s
.99625 .50461 m
1 .50461 L
s
.99625 .52345 m
1 .52345 L
s
.99625 .54229 m
1 .54229 L
s
.99625 .56113 m
1 .56113 L
s
.99625 .59882 m
1 .59882 L
s
.99625 .61766 m
1 .61766 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .1083 L
.17073 .1083 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .1083 L
.17073 .1083 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .16418 L
.29268 .16418 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .16418 L
.29268 .16418 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .26239 L
.41463 .26239 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .26239 L
.41463 .26239 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .02926 L
.53659 .02926 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .02926 L
.53659 .02926 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .01538 L
.65854 .01538 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .01538 L
.65854 .01538 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .25479 L
.78049 .25479 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .25479 L
.78049 .25479 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .21081 L
.90244 .21081 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .21081 L
.90244 .21081 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .51966 L
.07317 .51966 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .51966 L
.07317 .51966 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .02662 L
.19512 .02662 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .02662 L
.19512 .02662 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .03158 L
.31707 .03158 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .03158 L
.31707 .03158 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .01968 L
.43902 .01968 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .01968 L
.43902 .01968 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .40524 L
.56098 .40524 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .40524 L
.56098 .40524 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .01703 L
.68293 .01703 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .01703 L
.68293 .01703 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .02232 L
.80488 .02232 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .02232 L
.80488 .02232 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .01769 L
.92683 .01769 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .01769 L
.92683 .01769 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .60332 L
.09756 .60332 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .60332 L
.09756 .60332 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .01505 L
.21951 .01505 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .01505 L
.21951 .01505 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .01538 L
.34146 .01538 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .01538 L
.34146 .01538 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .01505 L
.46341 .01505 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .01505 L
.46341 .01505 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .36689 L
.58537 .36689 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .36689 L
.58537 .36689 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .01472 L
.70732 .01472 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .01472 L
.70732 .01472 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .01472 L
.82927 .01472 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .01472 L
.82927 .01472 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .0167 L
.12195 .0167 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .0167 L
.12195 .0167 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .25016 L
.2439 .25016 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .25016 L
.2439 .25016 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .20882 L
.36585 .20882 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .20882 L
.36585 .20882 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .06465 L
.4878 .06465 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .06465 L
.4878 .06465 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .104 L
.60976 .104 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .104 L
.60976 .104 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .2733 L
.73171 .2733 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .2733 L
.73171 .2733 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .06332 L
.85366 .06332 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .06332 L
.85366 .06332 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .07887 L
.97561 .07887 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .07887 L
.97561 .07887 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`coogl02ol0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;ool000co0?l02_ooool<
oomo00[ooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`_oo`003?l0o`0:ooooo`coogl02_ooool;
ool000_o0?l02ol00?l<oomo01Gooooo3?l0o`0:ooooo`coogl02_ooool;ool000co0?l02_ooool<
oomo00[ooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool;
ool000co0?l02_ooool<oomo00[ooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`_oo`003?l0o`0:
ooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`_oo`003?l0o`0:
ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Joooo
o`;o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`_oo`003?l0o`0:oooo
o`coogl02_ooool;ool000co0?l02_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool0
00_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`_oo`003?l0o`0:ooooo`coogl02_ooool<ool0
01Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00oaGooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`_oo`003?l0o`0:ooooo`co
ogl02_ooool<ool001Gooooo3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl0:oooool<oomo00[o
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo2ooo000<o`3o00[ooooo
3?ooO`0:ooooo`_oo`003?l0o`0:ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`_oo`00
2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo
3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00oaGooooo3?oo000Eooooo`coogl02_ooool;ool000co0?l02_ooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Ooo
ool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo2ooo000<
o`3o00[ooooo3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl0:oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0[oooo
o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00Wooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[o
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo02_o
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l0
2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?oo
O`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eoooo
o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[o
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo02_o
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l0
2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?oo
O`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<
o`00oaGooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo01Gooooo2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool001Gooooo3?ooO`09ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eoooo
o`coogl05Oooool;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[o
oooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0[ooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?oo
O`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?oo
O`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;
o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000foooo
o`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00:oooool<ool001Gooooo3?ooO`0:oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGo
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00_o
003o3?ooO`0[ooooo`coogl02_ooool<ool002_ooooo3?oo000Eooooo`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00_o003o3?ooO`0[ooooo`coogl0
2_ooool<ool002_ooooo3?oo000Eooooo`coogl02Oooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?oo
O`0:ooooo`coo`00=_ooool;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool002_ooooo3?oo
000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool003Kooooo2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000[ooooo`coo`005Oooool<
oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000foooo
o`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00:oooool<ool001Gooooo3?ooO`0:oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGo
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00_o
003o3?ooO`0[ooooo`coogl02_ooool<ool002_ooooo3?oo000Eooooo`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0;o`00o`coogl0
:oooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo
000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool003Kooooo2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEoooo
o`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0;o`00
o`coogl0:oooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0001?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl02_ooool<ool001Go
oooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool002_o
oooo3?oo000Zooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l0
2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?oo
O`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo02_ooooo3?oo
O`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00:oooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000foooo
o`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo02_o
oooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool000kooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00
=_ooool;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo
3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
:oooool<ool002_ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`06ooooo`Co00004_ooool;o`3o00co003o5Oooool<ool001Gooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0
2_ooool<ool002_ooooo3?oo000Xooooo`Co00003Oooool000gooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0
2_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o
=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o
=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003_oo
ool2o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_oo
ool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:
ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfoooo
o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo
00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`co
o`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo
3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0
o`0<o`00ocKooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l0
0?lfooooo`coogl02_ooool<ool002_ooooo3?oo000Zooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo
00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Ko
oooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo00[ooooo
3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0
o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o=_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00
ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?o
oooo0ol0000Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`co
o`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:_ooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo
3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ocKooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l0
0?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
ocKooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfoooo
o`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[o
oooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0
2_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:
ooooo`coo`005Oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<
ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o
00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo
00[ooooo3?oo000[ooooo`coo`00:_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00ocKooooo3?ooO`0[ooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKo
oooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00
=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl0:ooo
ool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo
000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00ocKooooo3?ooO`0[ooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:
ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o
00co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl0:oooool<oomo00[o
oooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo
3?ooO`0[ooooo`coogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l0
0?lfooooo`coogl0:oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_oo
ool<ool002_ooooo3?oo000Zooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<
oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl0:oooool<oomo00[ooooo3?oo000foooo
o`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0[ooooo`co
ogl02_ooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo
3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?lfooooo`coogl0:oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l0
0?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000>
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool04ooo
ool;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_oo
ool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
4oooool;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o
=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4oooool;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o
=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Ooo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo1?l0000Booooo`_o0?l0
3?l00?lfooooo`coogl0:oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0
2_ooool<ool002_ooooo3?oo000Xooooo`Co00003Oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool;o`3o00co
003o=_ooool<oomo02_ooooo3?ooO`0:ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[o
oooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?lfooooo`coogl0:oooool<oomo00[ooooo3?oo000fooooo`_o0?l03?l00?lfoooo
o`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o
00002Oooool3o`0000Oooooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo047o
oooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo
3?ooO`11ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Rooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?oo
O`11ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Rooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`11
ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Rooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`11oooo
o`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Rooooo`03o`000?oooooooooo
00_ooooo000Sooooo`?o00004oooool;o`3o00co003o=_ooool<oomo047ooooo3?oo000fooooo`_o
0?l03?l00?lfooooo`coogl02_ooool<ool0067ooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo
3?ooO`0:ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?oo
O`0:ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:
ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`co
o`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?lfooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00H_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lf
ooooo`coogl0@Oooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00H_ooool0
0ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00ocKooooo3?ooO`11oooo
o`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Qooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo047ooooo3?oo000fooooo`_o
0?l03?l00?lfooooo`coogl02_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo047ooooo3?oo000fooooo`_o0?l0
3?l00?lfooooo`coogl02_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo047ooooo3?oo000fooooo`_o0?l03?l0
0?lfooooo`coogl02_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o=_ooool<oomo047ooooo3?oo000fooooo`_o0?l03?l00?lf
ooooo`coogl02_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003oPoooool<ool003Kooooo2ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?n3ooooo`coo`00=_ooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001Rooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oh?ooooo
3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0N?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0001?ooooo2ol0o`0<o`00oh?ooooo3?oo000fooooo`_o0?l03?l00?lfooooo`coogl0Mooo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oh?ooooo3?oo000f
ooooo`_o0?l03?l00?lfooooo`coogl0N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?lfooooo`coogl0N?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o
0?l03?l00?lfooooo`coogl0N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?lfooooo`coogl0N?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l0
0?lfooooo`coogl0N?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?lfooooo`coogl0N?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGo
oooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l0
3?l00?o5ooooo`_o0?l03?l00?niooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003oaOooool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00
ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003oaOooool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo
000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`Co0000
4_ooool;o`3o00co003oaOooool;o`3o00co003o]oooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo
2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo
2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool;o`3o00co
003oaOooool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo
0ol00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOoo
ool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool;o`3o00co
003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00olGooooo
2ol0o`0<o`00okWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool;o`3o00co003o^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o
0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003oaOooool;o`3o00co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?nj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003oaOooool;o`3o
00co003o^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGo
oooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003oaOooool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<
o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003oaOooool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOoo
ool;o`3o00co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<
o`00olGooooo2ol0o`0<o`00okWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool;o`3o00co003o
^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?o5ooooo`_o0?l03?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo2ol0o`0<o`00olGooooo2ol0o`0<o`00ok[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool;o`3o00co003o^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co
0?l0aOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00olGooooo
3?l0o`34ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOoo
ool<o`3o0<Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003oaOooool<o`3o0<Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003oaOooool<o`3o0<Gooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool<o`3o0<Gooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oaOooool<o`3o0<Gooooo
00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0
0006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00olGooooo3?l0o`35ooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Go00001_ooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Booooo`_o0?l0
3?l00?o5ooooo`co0?l0`_ooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0
aOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o0000
1oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co0?l0aOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o5ooooo`co
0?l0aOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l0
0?oooooooiKooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03
o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003ooooooonFooooo`;o0000
3Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00004oooool;o`3o00co003ooooooonFooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<
o`00ooooooooU_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool0
00kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`04ooooo`Co00004_ooool;o`3o00co003ooooooonD
ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Sooooo1Ol00006oooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?oooooo
oiKooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00007_ooool<o`00ooooooooU_ooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001kooooo3?l00?oooooooiKooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00007_ooool<o`00ooooooooU_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01ko
oooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
7_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool07_ooool<o`00oooo
ooooUoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Nooooo`co003ooooooonGoooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Oooooo1?l0000M
ooooo`co003ooooooonDooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool0
00kooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_ooool<o`00oooooooo
Uoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Nooooo`co003ooooo
oonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01kooooo3?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Nooooo`co003ooooooonFoooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00_ooooo000Soooooooo0000aOl0000=ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00
@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000dooooo`?o0000
=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000ooooooooool0<ooo
ool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool00ol0003o
ooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooooooo
000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002gooooo0013
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0`
ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool00000=Ooo
ool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003ooooooooo
ool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo03;ooooo
0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000
=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000cooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002go
oooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000oooooooo
ooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool00000;Ooo
ool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`000?oooooo
oooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0500741, 0.0181824, \
0.00235365}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 1.02942 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11766 -18 -4.5 ]
[-0.0125 .11766 0 4.5 ]
[-0.0125 .2206 -18 -4.5 ]
[-0.0125 .2206 0 4.5 ]
[-0.0125 .32354 -18 -4.5 ]
[-0.0125 .32354 0 4.5 ]
[-0.0125 .42648 -18 -4.5 ]
[-0.0125 .42648 0 4.5 ]
[-0.0125 .52943 -18 -4.5 ]
[-0.0125 .52943 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11766 m
.00625 .11766 L
s
[(0.1)] -0.0125 .11766 1 0 Mshowa
0 .2206 m
.00625 .2206 L
s
[(0.2)] -0.0125 .2206 1 0 Mshowa
0 .32354 m
.00625 .32354 L
s
[(0.3)] -0.0125 .32354 1 0 Mshowa
0 .42648 m
.00625 .42648 L
s
[(0.4)] -0.0125 .42648 1 0 Mshowa
0 .52943 m
.00625 .52943 L
s
[(0.5)] -0.0125 .52943 1 0 Mshowa
.125 Mabswid
0 .0353 m
.00375 .0353 L
s
0 .05589 m
.00375 .05589 L
s
0 .07648 m
.00375 .07648 L
s
0 .09707 m
.00375 .09707 L
s
0 .13825 m
.00375 .13825 L
s
0 .15883 m
.00375 .15883 L
s
0 .17942 m
.00375 .17942 L
s
0 .20001 m
.00375 .20001 L
s
0 .24119 m
.00375 .24119 L
s
0 .26178 m
.00375 .26178 L
s
0 .28237 m
.00375 .28237 L
s
0 .30295 m
.00375 .30295 L
s
0 .34413 m
.00375 .34413 L
s
0 .36472 m
.00375 .36472 L
s
0 .38531 m
.00375 .38531 L
s
0 .4059 m
.00375 .4059 L
s
0 .44707 m
.00375 .44707 L
s
0 .46766 m
.00375 .46766 L
s
0 .48825 m
.00375 .48825 L
s
0 .50884 m
.00375 .50884 L
s
0 .55002 m
.00375 .55002 L
s
0 .5706 m
.00375 .5706 L
s
0 .59119 m
.00375 .59119 L
s
0 .61178 m
.00375 .61178 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11766 m
1 .11766 L
s
.99375 .2206 m
1 .2206 L
s
.99375 .32354 m
1 .32354 L
s
.99375 .42648 m
1 .42648 L
s
.99375 .52943 m
1 .52943 L
s
.125 Mabswid
.99625 .0353 m
1 .0353 L
s
.99625 .05589 m
1 .05589 L
s
.99625 .07648 m
1 .07648 L
s
.99625 .09707 m
1 .09707 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .15883 m
1 .15883 L
s
.99625 .17942 m
1 .17942 L
s
.99625 .20001 m
1 .20001 L
s
.99625 .24119 m
1 .24119 L
s
.99625 .26178 m
1 .26178 L
s
.99625 .28237 m
1 .28237 L
s
.99625 .30295 m
1 .30295 L
s
.99625 .34413 m
1 .34413 L
s
.99625 .36472 m
1 .36472 L
s
.99625 .38531 m
1 .38531 L
s
.99625 .4059 m
1 .4059 L
s
.99625 .44707 m
1 .44707 L
s
.99625 .46766 m
1 .46766 L
s
.99625 .48825 m
1 .48825 L
s
.99625 .50884 m
1 .50884 L
s
.99625 .55002 m
1 .55002 L
s
.99625 .5706 m
1 .5706 L
s
.99625 .59119 m
1 .59119 L
s
.99625 .61178 m
1 .61178 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .01688 L
.04878 .01688 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .01688 L
.04878 .01688 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .22176 L
.17073 .22176 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .22176 L
.17073 .22176 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .22826 L
.29268 .22826 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .22826 L
.29268 .22826 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .19935 L
.41463 .19935 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .19935 L
.41463 .19935 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .02411 L
.53659 .02411 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .02411 L
.53659 .02411 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .16467 L
.65854 .16467 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .16467 L
.65854 .16467 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .27704 L
.78049 .27704 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .27704 L
.78049 .27704 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .01508 L
.90244 .01508 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .01508 L
.90244 .01508 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .08301 L
.19512 .08301 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .08301 L
.19512 .08301 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .15599 L
.31707 .15599 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .15599 L
.31707 .15599 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .0588 L
.43902 .0588 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .0588 L
.43902 .0588 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .12347 L
.56098 .12347 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .12347 L
.56098 .12347 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .04579 L
.68293 .04579 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .04579 L
.68293 .04579 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .06097 L
.80488 .06097 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .06097 L
.80488 .06097 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .0158 L
.92683 .0158 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .0158 L
.92683 .0158 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .04904 L
.09756 .04904 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .04904 L
.09756 .04904 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .19104 L
.21951 .19104 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .19104 L
.21951 .19104 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .14443 L
.34146 .14443 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .14443 L
.34146 .14443 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .19827 L
.46341 .19827 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .19827 L
.46341 .19827 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .0588 L
.58537 .0588 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .0588 L
.58537 .0588 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .18165 L
.70732 .18165 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .18165 L
.70732 .18165 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .14226 L
.82927 .14226 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .14226 L
.82927 .14226 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .18165 L
.95122 .18165 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .18165 L
.95122 .18165 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .35256 L
.12195 .35256 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .35256 L
.12195 .35256 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .04218 L
.2439 .04218 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .04218 L
.2439 .04218 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .11661 L
.36585 .11661 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .11661 L
.36585 .11661 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .04543 L
.4878 .04543 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .04543 L
.4878 .04543 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .48155 L
.60976 .48155 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .48155 L
.60976 .48155 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .0205 L
.73171 .0205 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .0205 L
.73171 .0205 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .07361 L
.85366 .07361 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .07361 L
.85366 .07361 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .01472 L
.97561 .01472 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .01472 L
.97561 .01472 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`googl02_l0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;
o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;
ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02oooool0
01[ooooo0_l00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;ool0
00_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00
o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00co003o5Oooool;ool0
00_o0?l02ol00?l<oomo023ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[o
oooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o
0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo023o
oooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o
3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`_oo`00
2ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo2ooo
000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol0
0?l<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0
o`0;o`00o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;
ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Eooooo`_o0?l02ol00?l<
oomo00[ooooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo023ooooo3?l00?lE
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00
o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:oooo
o`_oo`002ol0o`0;o`00o`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00
oaGooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0001?ooooo2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[o
oooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl05Oooool;o`3o00_o
003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`co
003o5?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl0
2_ooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`00
2ol0o`0;o`00o`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo
2ooo000;o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?oo
O`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo01Gooooo2ol0
o`0;o`00o`coogl02_ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl08?oo
ool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo2ooo000;
o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo023ooooo3?l00?lEooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;ool0
00_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo
01Gooooo2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00
o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o
003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`_o
o`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo
2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00co003o
8?ooool;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00_o003o
3?ooO`0Pooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l02_ooool<oomo00[ooooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol0
0?l<oomo00[ooooo2ooo000;o`3o00co003o8?ooool;o`3o00_o003o3?ooO`0:ooooo`coo`002_oo
ool<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`co003o5Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo2ooo000;
o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00co003o8?ooool;
o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0P
ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`0:oooo
o`coogl02_ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool0
00_o0?l03?l00?lPooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool0
00_o0?l02ol00?l<oomo023ooooo3?l00?lDooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o
003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00ob3ooooo2ol0o`0;o`00o`coogl02_ooool<ool000[o
oooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl08?ooool<o`00oaGooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`00
2ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0<o`00ob3ooooo
2ol0o`0;o`00o`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl0
8?ooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?oo
O`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l0
0?lEooooo`_oo`002ol0o`0;o`00o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<
o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:
ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool;o`00o`coogl08?ooool<
o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:oooo
o`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEoooo
o`coo`002_ooool;o`00o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGo
oooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`co
ogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool;o`00o`coogl08?ooool<o`00oaGo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo
3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`00
2_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00
2_ooool;o`00o`coogl08?ooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo
000;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_oo
ool<ool000[ooooo3?l00?lEooooo`coo`002_ooool;o`00o`coogl08?ooool<o`00oaGooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:
ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<
o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool<
o`00ob_ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool<o`3o
00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:oooo
o`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEoooo
o`coo`002_ooool<o`00ob_ooooo3?l00?lDooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o
003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[o
oooo3?l00?lEooooo`coo`002_ooool<o`00ob_ooooo3?l00?lEooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool;ool000_o0?l0
3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<ool000[ooooo3?l00?lPooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[ooooo3?l00?l[ooooo`co003o
5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_oo
ool<oomo00[ooooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo
000:ooooo`co003o8?ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo
000:ooooo`co003o:oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;
o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<
ool000[ooooo3?l00?lEooooo`coo`002_ooool<o`00ob_ooooo3?l00?lEooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool0
00[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<ool000[ooooo3?l00?lPoooo
o`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[ooooo3?l00?l[oooo
o`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l02ol00?l<oomo00[o
oooo3?oo000:ooooo`co003o8?ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGo
oooo3?oo000:ooooo`co003o:oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo
2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl0
2_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool<o`00ob_ooooo3?l00?lEooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_oo
ool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<ool000[ooooo3?l0
0?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[ooooo3?l0
0?l[ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`0:
ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<
ool000[ooooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<
ool000[ooooo3?l00?l[ooooo`co003o5?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00
o`coogl02_ooool<ool000[ooooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:oooo
o`co003o5Oooool<ool000[ooooo3?l00?l[ooooo`co003o5Oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co
003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000:ooooo`co003o8?ooool<o`3o00[o
oooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co003o:oooool<o`00oaGo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo
3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`00
2_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00
2_ooool<o`00ob_ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0
o`0;o`00o`coogl02_ooool<ool000[ooooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo
000:ooooo`co003o5Oooool<ool000[ooooo3?l00?l[ooooo`co003o5Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:
ooooo`co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000:ooooo`co003o8?ooool<
o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co003o:oooool<
o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:oooo
o`coo`002_ooool<o`00ob3ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEoooo
o`coo`002_ooool<o`00ob_ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`0Cooooo`co
0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l02ol00?l<oomo00[o
oooo3?oo000:ooooo`co003o8?ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGo
oooo3?oo000:ooooo`co003o:oooool<o`00oaGooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?o
oooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0;o`00o`co
ogl02_ooool<ool000[ooooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co
003o5Oooool<ool000[ooooo3?l00?l[ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l0000Booooo`co
0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l02ol00?l<oomo00[o
oooo3?oo000:ooooo`co003o8?ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGo
oooo3?oo000:ooooo`co003o:oooool<o`00oa;ooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool<o`3o00[o
oooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00co003o5Oooool<ool000[o
oooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[o
oooo3?l00?l[ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool<o`3o00[o
oooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00co003o5Oooool<ool000[o
oooo3?l00?lPooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[o
oooo3?l00?l[ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[o
oooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l03?l00?lEooooo`coo`002_ooool<o`00ob3o
oooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool<o`00ob_o
oooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo
3?l00?lEooooo`_oo`002ol0o`0<o`00oaGooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo
3?oo000:ooooo`co003o5Oooool<ool000[ooooo3?l00?l[ooooo`co003o5Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo
000:ooooo`co003o5Oooool;ool000_o0?l03?l00?lEooooo`coo`002_ooool<o`00ocKooooo3?oo
O`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co003o:oooool<o`00oaGooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:
ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00co003o5Oooool<ool000[ooooo3?l00?lf
ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool<o`00ob_ooooo3?l00?lE
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:oooo
o`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0<o`00oaGooooo3?oo000:oooo
o`co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool000[ooooo3?l00?l[oooo
o`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l03?l00?lEooooo`co
o`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co
003o:oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l03?l00?lEooooo`coo`00
2_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co003o
:oooool<o`00oaCooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_oo
ool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000_o0?l03?l00?lEooooo`coo`002_oo
ool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000:ooooo`co003o:ooo
ool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000;o`3o00co003o5Oooool<
ool000[ooooo3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`002_ooool<
o`00ob_ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`002ol0o`0<o`00
oaGooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool0
047ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`_oo`003?l0o`0Pooooo`co
o`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo0011ooooo`co
003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool;ool000co0?l08?ooool<ool000[ooooo
3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00@Oooool<o`00oaGooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?oo
O`0:ooooo`coo`002_ooool<o`00oaGooooo2ooo000<o`3o023ooooo3?oo000:ooooo`co003o=_oo
ool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool0047ooooo3?l00?lEooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<
ool000[ooooo3?l00?lEooooo`_oo`003?l0o`0Pooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:
ooooo`coo`002_ooool<o`00oaGooooo3?oo0011ooooo`co003o5Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:oooo
o`co003o5Oooool;ool000co0?l08?ooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool<ool0
00[ooooo3?l00?lEooooo`coo`00@Oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGo
oooo3?oo000[ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGo
oooo3?oo0011ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo
3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00:oooool<ool000[ooooo
3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00@Oooool<o`00oaCooooo
0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo
000:ooooo`co003o5Oooool<ool002_ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo3?oo
000:ooooo`co003o5Oooool<ool0047ooooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lE
ooooo`coo`00:oooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lE
ooooo`coo`00@Oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000[oooo
o`coo`002_ooool<o`00ocKooooo3?ooO`0Pooooo`co003o5Oooool<ool0047ooooo3?l00?lEoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`co
ogl02_ooool<ool000[ooooo3?l00?lEooooo`coo`00:oooool<ool000[ooooo3?l00?lfooooo`co
ogl08?ooool<o`00oaGooooo3?oo0011ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o
5Oooool<ool002_ooooo3?oo000:ooooo`co003o=_ooool<oomo023ooooo3?l00?lEooooo`coo`00
@Oooool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o00[ooooo3?ooO`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000[ooooo`coo`002_oo
ool<o`00ocKooooo3?ooO`0Pooooo`co003o5Oooool<ool0047ooooo3?l00?lEooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<
ool000[ooooo3?l00?lEooooo`coo`00:oooool<ool000[ooooo3?l00?lfooooo`coogl08?ooool<
o`00oaGooooo3?oo0011ooooo`co003o5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool0
02_ooooo3?oo000:ooooo`co003o=_ooool<oomo023ooooo3?l00?lEooooo`coo`00@Oooool<o`00
oaGooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l02_ooool<oomo00[o
oooo3?oo000:ooooo`co003o5Oooool<ool002_ooooo3?oo000:ooooo`co003o=_ooool<oomo023o
oooo3?l00?lEooooo`coo`00@Oooool<o`00oaCooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool002_ooooo
3?oo000:ooooo`co003o=_ooool<oomo023ooooo3?l00?lEooooo`coo`00@Oooool<o`00oaGooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?oo
O`0:ooooo`coo`002_ooool<o`00oaGooooo3?oo000[ooooo`coo`002_ooool<o`00ocKooooo3?oo
O`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l02_ooool<oomo00[ooooo3?oo000:ooooo`co003o5Oooool<ool002_ooooo3?oo000:
ooooo`co003o=_ooool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool000[ooooo3?l00?lEoooo
o`coo`00:oooool<ool000[ooooo3?l00?lfooooo`coogl0@Oooool<ool006;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`co
o`002_ooool<o`00oaGooooo3?oo000[ooooo`coo`002_ooool<o`00ocKooooo3?ooO`11ooooo`co
o`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool000[ooooo3?l00?lfooooo`coogl0
@Oooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo3?oo000:ooooo`co003o=_oo
ool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`coo`002_ooool<
o`00ocKooooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`coo`002_ooool<o`00
ocKooooo3?ooO`11ooooo`coo`00HOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`0:ooooo`coogl02_ooool<ool002_ooooo3?oo0023ooooo`coogl0@Oooool<ool006;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo
3?ooO`0:ooooo`coo`00:oooool<ool008?ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo00[ooooo3?oo
000[ooooo`coo`00Poooool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl02_ooool<ool002_ooooo3?oo0023
ooooo`coogl0@Oooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool008?ooooo3?ooO`11oooo
o`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l02_ooool<oomo00[ooooo3?oo000[ooooo`coo`00Poooool<oomo047ooooo3?oo001Rooooo`03
o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Ko
oooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool008?o
oooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04oooool<o`3o
00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool008?ooooo3?ooO`11ooooo`coo`00H_ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool0
08?ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo1?l0000Booooo`co0?l02_ooool<oomo
00[ooooo3?oo000[ooooo`coo`00Poooool<oomo047ooooo3?oo001Oooooo`Co00003Oooool000go
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04oooool<o`3o00[ooooo3?ooO`11ooooo`coo`00Poooool<oomo047ooooo3?oo001R
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0@Ooo
ool<ool008?ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`003_ooool2
o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0@Oooool<
ool008?ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`11ooooo`coo`00H_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3o
oooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?oo
O`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`11ooooo`coo`00H_ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0001?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo047ooooo3?oo001Qoooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`co
ogl0@Oooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0@Oooool<ool006;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0@Ooo
ool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o00[ooooo3?ooO`3@ooooo`coogl0@Oooool<ool006;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0@Oooool<ool0
06;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[o
oooo3?ooO`3@ooooo`coogl0@Oooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0@Oooool<ool006;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?oo
O`3@ooooo`coogl0@Oooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`11ooooo`coo`00HOooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo047ooooo3?oo001Roooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`co
ogl0d?ooool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo047ooooo3?oo001Rooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?oo
ool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo047ooooo3?oo001Rooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo
047ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`0:ooooo`coogl0d?ooool<oomo047ooooo3?oo001Rooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo
00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l02_ooool<oomo0=3ooooo3?oo
O`2^ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@
ooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l02_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0
[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_oo
ool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3o
oooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo0ol0
000Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2^ooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2_oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`co
ogl0d?ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<
oomo0:oooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo
0:oooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@
ooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00Cooooo1?l0000Booooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2/
ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Oooooo00?o0000
ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool04oooool<
o`3o00[ooooo3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo
3?ooO`3@ooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l02_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o00004oooool<o`3o00[ooooo3?ooO`3@ooooo`coogl0[_ooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o00[ooooo3?ooO`3@ooooo`co
ogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
2_ooool<oomo0=3ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`0:ooooo`coogl0d?ooool<oomo0:oooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo
3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`3V
ooooo`coogl0[_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Voooo
o`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo
00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0i_ooool<oomo0:kooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`co
ogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00004oooool<o`3o0>Kooooo3?ooO`2^ooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0
[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_oo
ool<oomo0:oooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0ol00006ooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooo
oooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00006ooooo`Co00004_ooool<
o`3o0>Kooooo3?ooO`2/ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[ooo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`003_ooool2
o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<
oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0001?ooooo3?l0o`3Vooooo`coogl0[_ooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo
0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Ko
oooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`co0?l0i_ooool<oomo0:kooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0i_ooool<oomo0:oooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o0>Kooooo3?ooO`2_ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Vooooo`coogl0[oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
0ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`04ooooo`Co00004_ooool<o`3o0?ooooooWoooool4o`0000gooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o
0000ooooooooool02oooool000kooooo0_l00008ooooo`Go00001_ooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
01?ooooo3?l0o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00007_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo01gooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool004;ooooo0ol0000cooooo`Go0000<oooool3o`0003Gooooo0ol0000cooooo`?o0000=?ooool3
o`0003Gooooo00?o0000ooooooooool0<oooool3o`0002kooooo0013ooooo`03o`000?oooooooooo
03?ooooo00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o
0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000oooooooooooo
ooooo`00000dooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000]oooo
o`00@oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0<?ooool5o`0003Kooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo0000
03Gooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000002gooooo0013oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool2o`0003?ooooo00Co0000oooo
oooooooo0000=oooool00ol0003oooooooooo`0`ooooo`Co0000=_ooool00ol0003oooooooooo`0b
ooooo`?o0000;_ooool004?ooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo
000003Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000cooooo`Co0000<oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00
000]ooooo`00@_ooool2o`0003Cooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?oo
ooooooooooooool00000=?ooool2o`0003?ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0cooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooooooo0000
02gooooo0013ooooo`03o`000?oooooooooo03?ooooo0ol0000dooooo`?o0000=_ooool00ol0003o
ooooooooo`0aooooo`Go0000=?ooool2o`0003?ooooo1Ol0000cooooo`?o0000;_ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0458264, 0.0181824, \
0.002154}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 0.766072 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16793 -18 -4.5 ]
[-0.0125 .16793 0 4.5 ]
[-0.0125 .32114 -18 -4.5 ]
[-0.0125 .32114 0 4.5 ]
[-0.0125 .47436 -18 -4.5 ]
[-0.0125 .47436 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16793 m
.00625 .16793 L
s
[(0.2)] -0.0125 .16793 1 0 Mshowa
0 .32114 m
.00625 .32114 L
s
[(0.4)] -0.0125 .32114 1 0 Mshowa
0 .47436 m
.00625 .47436 L
s
[(0.6)] -0.0125 .47436 1 0 Mshowa
.125 Mabswid
0 .05302 m
.00375 .05302 L
s
0 .09132 m
.00375 .09132 L
s
0 .12963 m
.00375 .12963 L
s
0 .20623 m
.00375 .20623 L
s
0 .24454 m
.00375 .24454 L
s
0 .28284 m
.00375 .28284 L
s
0 .35945 m
.00375 .35945 L
s
0 .39775 m
.00375 .39775 L
s
0 .43605 m
.00375 .43605 L
s
0 .51266 m
.00375 .51266 L
s
0 .55097 m
.00375 .55097 L
s
0 .58927 m
.00375 .58927 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16793 m
1 .16793 L
s
.99375 .32114 m
1 .32114 L
s
.99375 .47436 m
1 .47436 L
s
.125 Mabswid
.99625 .05302 m
1 .05302 L
s
.99625 .09132 m
1 .09132 L
s
.99625 .12963 m
1 .12963 L
s
.99625 .20623 m
1 .20623 L
s
.99625 .24454 m
1 .24454 L
s
.99625 .28284 m
1 .28284 L
s
.99625 .35945 m
1 .35945 L
s
.99625 .39775 m
1 .39775 L
s
.99625 .43605 m
1 .43605 L
s
.99625 .51266 m
1 .51266 L
s
.99625 .55097 m
1 .55097 L
s
.99625 .58927 m
1 .58927 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .15561 L
.17073 .15561 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .15561 L
.17073 .15561 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .03058 L
.29268 .03058 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .03058 L
.29268 .03058 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .17632 L
.41463 .17632 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .17632 L
.41463 .17632 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .02924 L
.53659 .02924 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .02924 L
.53659 .02924 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .17578 L
.65854 .17578 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .17578 L
.65854 .17578 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .15293 L
.78049 .15293 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .15293 L
.78049 .15293 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .14862 L
.90244 .14862 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .14862 L
.90244 .14862 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .52561 L
.07317 .52561 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .52561 L
.07317 .52561 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .02413 L
.19512 .02413 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .02413 L
.19512 .02413 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .13115 L
.31707 .13115 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .13115 L
.31707 .13115 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .0174 L
.43902 .0174 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .0174 L
.43902 .0174 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .1376 L
.56098 .1376 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .1376 L
.56098 .1376 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .01687 L
.68293 .01687 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .01687 L
.68293 .01687 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .01606 L
.80488 .01606 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .01606 L
.80488 .01606 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .01498 L
.92683 .01498 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .01498 L
.92683 .01498 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .60332 L
.09756 .60332 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .60332 L
.09756 .60332 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .01472 L
.21951 .01472 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .01472 L
.21951 .01472 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .09458 L
.34146 .09458 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .09458 L
.34146 .09458 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .01472 L
.46341 .01472 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .01472 L
.46341 .01472 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .11205 L
.58537 .11205 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .11205 L
.58537 .11205 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .01498 L
.70732 .01498 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .01498 L
.70732 .01498 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .01472 L
.82927 .01472 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .01472 L
.82927 .01472 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .05155 L
.12195 .05155 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .05155 L
.12195 .05155 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .122 L
.2439 .122 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .122 L
.2439 .122 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .23521 L
.36585 .23521 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .23521 L
.36585 .23521 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .08248 L
.4878 .08248 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .08248 L
.4878 .08248 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .2145 L
.60976 .2145 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .2145 L
.60976 .2145 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .07145 L
.73171 .07145 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .07145 L
.73171 .07145 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .07575 L
.85366 .07575 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .07575 L
.85366 .07575 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .03085 L
.97561 .03085 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .03085 L
.97561 .03085 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`coogl02ol0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;ool000co0?l02_ooool<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`003?l0o`0:ooooo`coogl02_ooool;
ool000_o0?l02ol00?l<oomo00[ooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool;
ool000co0?l02_ooool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Joooo
o`;o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo2ooo000<o`3o
00[ooooo3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`_oo`002ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo
00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo2ooo000<o`3o00[ooooo3?ooO`0:ooooo`_o
o`002ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`co
ogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`co
ogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
2ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo
3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Ooo
ool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo2ooo
000;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_oo
ool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00_o003o3?ooO`0:oooo
o`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eoooo
o`_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`co
o`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`co
o`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l0
2ol00?l<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Ooo
ool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol0
0?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00:ooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<
oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<
oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo
00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo
00[ooooo3?oo000Eooooo`coogl02_ooool<ool002_ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Go
oooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[o
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00:oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l02ol00?l<oomo00[ooooo
3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo
2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo
3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo
000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<
ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool001Gooooo3?ooO`0:ooooo`coo`00:_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:oooo
o`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o
003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
5Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo
000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0
o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<
oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:oooo
o`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o
003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
5Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo
000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0
o`0;o`00o`coogl02_ooool<ool002_ooooo3?oo000Eooooo`coogl02_ooool<ool002_ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;
o`3o00_o003o3?ooO`0:ooooo`coo`00:oooool<ool001Gooooo3?ooO`0:ooooo`coo`00:oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEoooo
o`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool001Gooooo3?ooO`0Eoooo
o`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Go
oooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o
003o3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
5Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl0
2_ooool<ool002_ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo01Gooooo2ol0
o`0;o`00o`coogl02_ooool<ool003Kooooo2ol0o`0;o`00o`coogl02_ooool<ool002_ooooo3?oo
000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<
ool003Kooooo2ol0o`0;o`00o`coogl02_ooool<ool002_ooooo3?oo000[ooooo`coo`00:oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEoooo
o`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00o`coogl02_ooool<ool003Kooooo2ol0o`0;o`00
o`coogl02_ooool<ool002_ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0001?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o
003o3?ooO`0:ooooo`coo`00=_ooool;o`3o00_o003o3?ooO`0:ooooo`coo`00:oooool<ool002_o
oooo3?oo000Zooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
5Oooool<ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000fooooo`_o0?l0
2ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?oo
O`0Eooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo
000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<
oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000foooo
o`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Go
oooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo00[o
oooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00
:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo
000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<
oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eoooo
o`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000[oooo
o`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[o
oooo3?oo000fooooo`_o0?l02ol00?l<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?oo
O`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`co0?l02_ooool<oomo00[ooooo3?oo
000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<
oomo00[ooooo3?oo000fooooo`co0?l02_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool001Gooooo3?ooO`0Eooooo`co0?l02_ooool<oomo00[ooooo3?oo000foooo
o`co0?l02_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool003Ko
oooo3?l0o`0:ooooo`coogl02_ooool<ool003Kooooo3?l0o`0:ooooo`coogl02_ooool<ool002_o
oooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00=_ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00
=_ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo3?oo000[ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo
000fooooo`co0?l02_ooool<oomo00[ooooo3?oo000fooooo`co0?l02_ooool<oomo00[ooooo3?oo
000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`_o0?l03?l00?lEooooo`coo`00=_ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00=_ooool<
o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo3?oo000Zooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?ooO`0:oooo
o`coo`00=_ooool<o`3o00[ooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo3?oo000[oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGo
oooo3?oo001<ooooo`coogl02_ooool<ool003Kooooo3?l0o`0:ooooo`coogl02_ooool<ool002_o
oooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00C?ooool<oomo00[ooooo3?oo000fooooo`co0?l0
2_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?oo
O`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool004cooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool004cooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000[oooo
o`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003o5Oooool<ool004cooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[o
oooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?ooO`0:ooooo`coo`00
C?ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?oo
O`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000[ooooo`coo`00H_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00C?ooool<
oomo00[ooooo3?oo001<ooooo`coogl02_ooool<ool002_ooooo3?oo001Rooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<oooo
o`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`00VOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl02_ooool<ool004co
oooo3?ooO`0:ooooo`coo`00VOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`00
VOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`0:ooooo`coo`00
C?ooool<oomo00[ooooo3?oo002Iooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?m]ooooo`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`00VOooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04oooool;o`3o00co003oKOooool<oomo00[ooooo3?oo001<ooooo`co
ogl02_ooool<ool009Wooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`05ooooo`Co00004_ooool;o`3o00co003oKOooool<oomo00[o
oooo3?oo001<ooooo`coogl02_ooool<ool009Kooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?m]ooooo`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`00VOooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl02_ooool<
ool004cooooo3?ooO`0:ooooo`coo`00VOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00Wooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`0:oooo
o`coo`00C?ooool<oomo00[ooooo3?oo002Iooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`0:ooooo`coo`00C?ooool<oomo0:oo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
KOooool<oomo06;ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`1Rooooo`coogl0[oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl0H_ooool<
oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003oKOooool<oomo06;ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`1Rooooo`coogl0[oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl0
H_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003oKOooool<oomo06;ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`1Rooooo`coogl0[oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]oooo
o`coogl0H_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003oKOooool<oomo06;ooooo3?ooO`2_ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`1Rooooo`coogl0
[oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?m]ooooo`coogl0H_ooool<oomo0:oooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`_o0?l03?l00?m]ooooo`coogl0H_ooool<oomo0:kooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl0H_ooool<oomo0:oooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oKOooool<oomo06;o
oooo3?ooO`2_ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ofgooooo3?ooO`1Rooooo`coogl0[oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`coogl0H_ooool<oomo0:oooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oKOooool<
oomo0?oooooo7_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?m]ooooo`coogl0oooooolNooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`3ooooooakooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oKOooool<oomo0?oooooo
7_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?m]ooooo`coogl0oooooolNooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo2ol0o`0<o`00ofgooooo3?ooO`3ooooooakooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003oKOooool<oomo0?oooooo7_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m]ooooo`co
ogl0oooooolNooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ofgooooo3?ooO`3ooooooakooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooo
ooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?oooooooiKooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o00004oooool;o`3o00co003ooooooonFooooo`;o00003Oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001_oo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`Go00001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?oooooooiOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00007ooooo`Co00004_ooool;o`3o00co003ooooooonDooooo`Co0000
3Oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003Ooo
ool01?l0003oooooooooool00009ooooo`;o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?oooooooiOooooo00?o0000ooooooooool02oooool000kooooo0_l0000;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo
2ol0o`0<o`00ooooooooU_ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?oooooo
oiKooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?oooooooiKooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03
o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`Co00004_ooool;o`3o00co003ooooooonDooooo`Co00003Oooool000go
oooo00Co0000oooooooooooo00001oooool4o`0000Oooooo00?o0000ooooooooool04oooool;o`3o
00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo01?o
oooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oooooooo
Uoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00ooooooooU_ooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oo
oooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01ko
oooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
7_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001kooooo3?l00?oooooooiKooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`?o00007_ooool<o`00ooooooooU_ooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01kooooo3?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool07_ooool<o`00ooooooooUoooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Nooooo`co003ooooooonGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_o
oooo000Soooooooo0000aOl0000=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00@_ooool3o`00
03?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000dooooo`?o0000=Oooool00ol0
003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000ooooooooool0<oooool01?l0003o
ooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooooooo`0a
ooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooooooo000003Cooooo
00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002gooooo0013ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0`ooooo`Go0000
=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003o
ooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003oooooooooool0000goooo
o`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo03;ooooo0ol0000^oooo
o`00@oooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000=_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000cooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002gooooo0012oooo
o`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000ooooooooooooooooo`00
000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03?ooooo00Go
0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool00000;Oooool004?ooooo
00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`000?oooooooooo037ooooo
1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0615799, 0.0181824, \
0.00289446}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 0.690096 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15273 -18 -4.5 ]
[-0.0125 .15273 0 4.5 ]
[-0.0125 .29075 -18 -4.5 ]
[-0.0125 .29075 0 4.5 ]
[-0.0125 .42877 -18 -4.5 ]
[-0.0125 .42877 0 4.5 ]
[-0.0125 .56679 -18 -4.5 ]
[-0.0125 .56679 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15273 m
.00625 .15273 L
s
[(0.2)] -0.0125 .15273 1 0 Mshowa
0 .29075 m
.00625 .29075 L
s
[(0.4)] -0.0125 .29075 1 0 Mshowa
0 .42877 m
.00625 .42877 L
s
[(0.6)] -0.0125 .42877 1 0 Mshowa
0 .56679 m
.00625 .56679 L
s
[(0.8)] -0.0125 .56679 1 0 Mshowa
.125 Mabswid
0 .04922 m
.00375 .04922 L
s
0 .08372 m
.00375 .08372 L
s
0 .11823 m
.00375 .11823 L
s
0 .18724 m
.00375 .18724 L
s
0 .22174 m
.00375 .22174 L
s
0 .25625 m
.00375 .25625 L
s
0 .32526 m
.00375 .32526 L
s
0 .35976 m
.00375 .35976 L
s
0 .39427 m
.00375 .39427 L
s
0 .46328 m
.00375 .46328 L
s
0 .49778 m
.00375 .49778 L
s
0 .53229 m
.00375 .53229 L
s
0 .6013 m
.00375 .6013 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15273 m
1 .15273 L
s
.99375 .29075 m
1 .29075 L
s
.99375 .42877 m
1 .42877 L
s
.99375 .56679 m
1 .56679 L
s
.125 Mabswid
.99625 .04922 m
1 .04922 L
s
.99625 .08372 m
1 .08372 L
s
.99625 .11823 m
1 .11823 L
s
.99625 .18724 m
1 .18724 L
s
.99625 .22174 m
1 .22174 L
s
.99625 .25625 m
1 .25625 L
s
.99625 .32526 m
1 .32526 L
s
.99625 .35976 m
1 .35976 L
s
.99625 .39427 m
1 .39427 L
s
.99625 .46328 m
1 .46328 L
s
.99625 .49778 m
1 .49778 L
s
.99625 .53229 m
1 .53229 L
s
.99625 .6013 m
1 .6013 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .13704 L
.04878 .13704 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .13704 L
.04878 .13704 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .01472 L
.17073 .01472 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .01472 L
.17073 .01472 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .23441 L
.29268 .23441 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .23441 L
.29268 .23441 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .01472 L
.41463 .01472 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .01472 L
.41463 .01472 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .33905 L
.53659 .33905 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .33905 L
.53659 .33905 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .01472 L
.65854 .01472 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .01472 L
.65854 .01472 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .03845 L
.78049 .03845 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .03845 L
.78049 .03845 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .01472 L
.90244 .01472 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .01472 L
.90244 .01472 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .01472 L
.19512 .01472 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .01472 L
.19512 .01472 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .04548 L
.31707 .04548 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .04548 L
.31707 .04548 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .01472 L
.43902 .01472 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .01472 L
.43902 .01472 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .08472 L
.56098 .08472 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .08472 L
.56098 .08472 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .01472 L
.68293 .01472 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .01472 L
.68293 .01472 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .0152 L
.80488 .0152 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .0152 L
.80488 .0152 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .01496 L
.92683 .01496 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .01496 L
.92683 .01496 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .4701 L
.09756 .4701 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .4701 L
.09756 .4701 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .01472 L
.21951 .01472 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .01472 L
.21951 .01472 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .09295 L
.34146 .09295 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .09295 L
.34146 .09295 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .01472 L
.46341 .01472 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .01472 L
.46341 .01472 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .17095 L
.58537 .17095 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .17095 L
.58537 .17095 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .01472 L
.70732 .01472 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .01472 L
.70732 .01472 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .01496 L
.82927 .01496 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .01496 L
.82927 .01496 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .01472 L
.95122 .01472 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .01472 L
.12195 .01472 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .01472 L
.12195 .01472 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .14503 L
.2439 .14503 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .14503 L
.2439 .14503 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .02998 L
.36585 .02998 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .02998 L
.36585 .02998 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .13655 L
.4878 .13655 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .13655 L
.4878 .13655 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .02925 L
.60976 .02925 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .02925 L
.60976 .02925 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .12735 L
.73171 .12735 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .12735 L
.73171 .12735 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .18718 L
.85366 .18718 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .18718 L
.85366 .18718 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .13776 L
.97561 .13776 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .13776 L
.97561 .13776 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3OooO`09o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`coogl02ol0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo2ooo000;
o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:
ooooo`coo`005Oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lf
ooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl0:oooool<oomo00[ooooo00?o0000
ooooooooool02oooool001[ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o
00co003o=_ooool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool0
00_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo02_ooooo3?ooO`0:oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co
003o=_ooool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool000_o
0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo02_ooooo3?ooO`0:ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o
=_ooool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool000_o0?l0
2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo02_ooooo3?ooO`0:ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_oo
ool<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool000_o0?l02ol0
0?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool;ool000_o0?l03?l00?lf
ooooo`coogl02_ooool<ool001Gooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`coo`005Oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co
003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo000Eooooo`co
ogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool;ool000_o0?l03?l00?lfooooo`coogl0
2_ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool001Gooooo3?ooO`0[ooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0
o`0<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0
o`0<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool;
ool000_o0?l03?l00?lfooooo`coogl02_ooool;ool000_o0?l03?l00?lfooooo`coogl0:oooool<
oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_ooool<oomo
00[ooooo2ooo000;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKo
oooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKo
oooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo
0ol00008ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo
3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00Wooooo
0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?oo
O`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?oo
O`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lf
ooooo`coogl02_ooool;ool000_o0?l03?l00?lfooooo`coogl0:oooool<oomo02_ooooo3?ooO`0:
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o
00co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo2ooo000;o`3o
00co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`co
o`002_ooool<o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0[ooooo`co
ogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lfooooo`coogl0
2_ooool;ool000_o0?l03?l00?lfooooo`coogl0:oooool<oomo02_ooooo3?ooO`0:ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_oo
ool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_oo
ool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<
o`00ocKooooo3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<
oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool0
00_o0?l03?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool;ool0
00_o0?l03?l00?lfooooo`coogl0:oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[o
oooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_ooool<oomo02_o
oooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo
3?ooO`0:ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l0
0?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool;ool000_o0?l03?l0
0?lfooooo`coogl0:oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo000:
ooooo`co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0[
ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:oooo
o`_oo`002ol0o`0<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`co
ogl02_ooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool;ool000_o0?l03?l00?lfooooo`co
ogl0:oooool<oomo02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o
=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo2ooo000;o`3o00co003o=_oo
ool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo2ooo000;o`3o00co003o=_oo
ool<oomo02_ooooo3?ooO`0[ooooo`coogl02Oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo00Sooooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<
oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00
ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00
ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool000[o
oooo3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?lfooooo`coogl0:oooool<oomo02_o
oooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo
3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?oo
O`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?oo
O`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:
ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:oooo
o`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[oooo
o`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_o
o`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co
003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00
C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0
o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_oo
ool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00C?ooool<
oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00
ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo
02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[o
oooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo3?ooO`0[ooooo`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ocKooooo
3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo02_ooooo
3?ooO`0[ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo2ooo
000;o`3o00co003o=_ooool<oomo00[ooooo3?oo001<ooooo`coogl02_ooool<ool000[ooooo3?l0
0?lfooooo`coogl0:oooool<oomo02_ooooo3?ooO`09ooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool004cooooo3?ooO`0:
ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfoooo
o`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0[oooo
o`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`co
o`002_ooool<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl0
2_ooool<ool004cooooo3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0[ooooo`coogl0
:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool004cooooo3?ooO`0:ooooo`coo`002_oo
ool<o`00ocKooooo3?ooO`0[ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<
ool004cooooo3?ooO`0:ooooo`coo`002_ooool<o`00ofgooooo3?ooO`0[ooooo`coogl02_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00
ocKooooo3?ooO`0:ooooo`coo`00C?ooool<oomo00[ooooo3?oo000:ooooo`co003oKOooool<oomo
02_ooooo3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo2ooo000;o`3o00co003o=_ooool<oomo00[ooooo3?oo001<ooooo`coogl02_ooool<ool000[o
oooo3?l00?m]ooooo`coogl0:oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lfooooo`coogl02_ooool<ool004cooooo
3?ooO`0:ooooo`coo`002_ooool<o`00ofgooooo3?ooO`0[ooooo`coogl02_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_oo
ool<ool006;ooooo3?oo000:ooooo`co003oKOooool<oomo047ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o=_ooool<oomo00[ooooo3?oo001R
ooooo`coo`002_ooool<o`00ofgooooo3?ooO`11ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`00H_ooool<ool0
00[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool006;ooooo3?oo000:ooooo`co
003oKOooool<oomo047ooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`co
o`00H_ooool<ool000[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool04oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo000:ooooo`co003oKOooool<oomo
047ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`06ooooo`Co00004_ooool;o`3o00co003oC?ooool<ool006;ooooo3?oo000:oooo
o`co003oKOooool<oomo03kooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool;o`3o00co003oC?ooool<ool0
06;ooooo3?oo000:ooooo`co003oKOooool<oomo047ooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo000:ooooo`co003oKOooool<
oomo047ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool;o`3o00co003oC?oo
ool<ool006;ooooo3?oo000:ooooo`co003oKOooool<oomo047ooooo00?o0000ooooooooool02ooo
ool000kooooo0_l00009ooooo`?o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<
ooooo`coo`00H_ooool<ool000[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool0
00[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool000[ooooo3?l00?m]ooooo`co
ogl0@Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?m<ooooo`coo`00H_ooool<ool000[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_oo
ool<ool000[ooooo3?l00?m]ooooo`coogl0@Oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool008?ooooo3?ooO`11
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
odcooooo3?oo001Rooooo`coo`00Poooool<oomo047ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo0023ooooo`co
ogl0@Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?m<ooooo`coo`00H_ooool<ool008?ooooo3?ooO`11ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00Pooo
ool<oomo047ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003oC?ooool<ool006;ooooo3?oo0023ooooo`coogl0@Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool0
08?ooooo3?ooO`11ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co
003oC?ooool<ool006;ooooo3?oo0023ooooo`coogl0@?ooool2o`0000gooooo000Sooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00d?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_oo
ool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003oC?ooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00d?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`co
o`00H_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00d?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<
ooooo`coo`00H_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`co
o`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?m<ooooo`coo`00H_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003oC?ooool<ool006;ooooo3?oo003@ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001R
ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?o
oooo0ol0000Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool00<oooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool00=3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003oC?oo
ool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00d?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?m<ooooo`coo`00H_ooool<ool0
0=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003oC?ooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00odcooooo3?oo001Rooooo`coo`00d?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?nj
ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?nj
ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001?ooooo2ol0o`0<o`00ok[ooooo3?oo003?ooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool0
0=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool0
0=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000
ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006oooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ok[ooooo3?oo003@ooooo`03o`000?oooooooooo
00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool00007ooooo`Go00001_ooool4o`0001;ooooo2ol0o`0<o`00
ok[ooooo3?oo003=ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ok[ooooo3?oo003@
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o00001oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;
ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?nj
ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?nj
ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`_o0?l03?l00?njooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001?ooooo2ol0o`0<o`00ok[ooooo3?oo003?ooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o^_ooool<ool0
0=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool;o`3o00co003o^_ooool<ool00=3ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0
o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001?ooooo2ol0o`0<o`00ooooooooU_ooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooo
oonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
oooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003ooooo
oonFooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonG
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooo
oonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oooo
ooooUoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonG
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007
ooooo`Co00004_ooool;o`3o00co003ooooooonDooooo`Co00003Oooool000gooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonG
ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool2o`0000Oooooo00?o0000oooo
ooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooo
oiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?oooooooiKooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?oooooooiOooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003ooooooonGooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ooooooooUoooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0
o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0
000Cooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000ko
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0ol00007
ooooo`Co00004_ooool<o`3o0?ooooooWoooool4o`0000gooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool<o`3o0?oooooo
X_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3o
oooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool002?oooooool0
0035o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo0012ooooo`?o0000<oooool5o`0003?o
oooo0ol0000eooooo`?o0000<oooool3o`0003Cooooo0ol0000eooooo`03o`000?oooooooooo03?o
oooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0003;o
oooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo037ooooo00Go0000oooo
ooooooooooooo`00000booooo`05o`000?ooooooooooooooool00000=?ooool00ol0003ooooooooo
o`0booooo`05o`000?ooooooooooooooool00000;Oooool004?ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo033ooooo1Ol0000fooooo`03o`000?oo
oooooooo033ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo037ooooo
00Go0000ooooooooooooooooo`00000]ooooo`00@oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03?ooooo0_l0000cooooo`04o`000?ooooooooooo`0003Oooooo00?o0000oooooooo
ool0<?ooool4o`0003Kooooo00?o0000ooooooooool0<_ooool3o`0002kooooo0013ooooo`03o`00
0?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo037o
oooo00?o0000ooooool00000<oooool4o`0003?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0`ooooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo0_l0000dooooo`05
o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooooooo000003Cooooo0_l0000c
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooo
oooo000003;ooooo00Go0000ooooooooooooooooo`00000]ooooo`00@oooool00ol0003ooooooooo
o`0cooooo`?o0000=?ooool3o`0003Kooooo00?o0000ooooooooool0<Oooool5o`0003Cooooo0_l0
000cooooo`Go0000<oooool3o`0002kooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0683595, 0.0181824, \
0.00321313}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 0.890564 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10377 -18 -4.5 ]
[-0.0125 .10377 0 4.5 ]
[-0.0125 .19283 -18 -4.5 ]
[-0.0125 .19283 0 4.5 ]
[-0.0125 .28188 -18 -4.5 ]
[-0.0125 .28188 0 4.5 ]
[-0.0125 .37094 -18 -4.5 ]
[-0.0125 .37094 0 4.5 ]
[-0.0125 .46 -18 -4.5 ]
[-0.0125 .46 0 4.5 ]
[-0.0125 .54905 -18 -4.5 ]
[-0.0125 .54905 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10377 m
.00625 .10377 L
s
[(0.1)] -0.0125 .10377 1 0 Mshowa
0 .19283 m
.00625 .19283 L
s
[(0.2)] -0.0125 .19283 1 0 Mshowa
0 .28188 m
.00625 .28188 L
s
[(0.3)] -0.0125 .28188 1 0 Mshowa
0 .37094 m
.00625 .37094 L
s
[(0.4)] -0.0125 .37094 1 0 Mshowa
0 .46 m
.00625 .46 L
s
[(0.5)] -0.0125 .46 1 0 Mshowa
0 .54905 m
.00625 .54905 L
s
[(0.6)] -0.0125 .54905 1 0 Mshowa
.125 Mabswid
0 .03253 m
.00375 .03253 L
s
0 .05034 m
.00375 .05034 L
s
0 .06815 m
.00375 .06815 L
s
0 .08596 m
.00375 .08596 L
s
0 .12158 m
.00375 .12158 L
s
0 .13939 m
.00375 .13939 L
s
0 .15721 m
.00375 .15721 L
s
0 .17502 m
.00375 .17502 L
s
0 .21064 m
.00375 .21064 L
s
0 .22845 m
.00375 .22845 L
s
0 .24626 m
.00375 .24626 L
s
0 .26407 m
.00375 .26407 L
s
0 .2997 m
.00375 .2997 L
s
0 .31751 m
.00375 .31751 L
s
0 .33532 m
.00375 .33532 L
s
0 .35313 m
.00375 .35313 L
s
0 .38875 m
.00375 .38875 L
s
0 .40656 m
.00375 .40656 L
s
0 .42437 m
.00375 .42437 L
s
0 .44219 m
.00375 .44219 L
s
0 .47781 m
.00375 .47781 L
s
0 .49562 m
.00375 .49562 L
s
0 .51343 m
.00375 .51343 L
s
0 .53124 m
.00375 .53124 L
s
0 .56686 m
.00375 .56686 L
s
0 .58468 m
.00375 .58468 L
s
0 .60249 m
.00375 .60249 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10377 m
1 .10377 L
s
.99375 .19283 m
1 .19283 L
s
.99375 .28188 m
1 .28188 L
s
.99375 .37094 m
1 .37094 L
s
.99375 .46 m
1 .46 L
s
.99375 .54905 m
1 .54905 L
s
.125 Mabswid
.99625 .03253 m
1 .03253 L
s
.99625 .05034 m
1 .05034 L
s
.99625 .06815 m
1 .06815 L
s
.99625 .08596 m
1 .08596 L
s
.99625 .12158 m
1 .12158 L
s
.99625 .13939 m
1 .13939 L
s
.99625 .15721 m
1 .15721 L
s
.99625 .17502 m
1 .17502 L
s
.99625 .21064 m
1 .21064 L
s
.99625 .22845 m
1 .22845 L
s
.99625 .24626 m
1 .24626 L
s
.99625 .26407 m
1 .26407 L
s
.99625 .2997 m
1 .2997 L
s
.99625 .31751 m
1 .31751 L
s
.99625 .33532 m
1 .33532 L
s
.99625 .35313 m
1 .35313 L
s
.99625 .38875 m
1 .38875 L
s
.99625 .40656 m
1 .40656 L
s
.99625 .42437 m
1 .42437 L
s
.99625 .44219 m
1 .44219 L
s
.99625 .47781 m
1 .47781 L
s
.99625 .49562 m
1 .49562 L
s
.99625 .51343 m
1 .51343 L
s
.99625 .53124 m
1 .53124 L
s
.99625 .56686 m
1 .56686 L
s
.99625 .58468 m
1 .58468 L
s
.99625 .60249 m
1 .60249 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .10818 L
.04878 .10818 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .10818 L
.04878 .10818 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .0591 L
.17073 .0591 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .0591 L
.17073 .0591 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .26291 L
.29268 .26291 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .26291 L
.29268 .26291 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .01784 L
.41463 .01784 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .01784 L
.41463 .01784 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .27416 L
.53659 .27416 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .27416 L
.53659 .27416 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .01534 L
.65854 .01534 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .01534 L
.65854 .01534 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .24447 L
.78049 .24447 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .24447 L
.78049 .24447 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .02628 L
.90244 .02628 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .02628 L
.90244 .02628 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .06192 L
.19512 .06192 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .06192 L
.19512 .06192 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .10912 L
.31707 .10912 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .10912 L
.31707 .10912 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .01597 L
.43902 .01597 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .01597 L
.43902 .01597 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .10662 L
.56098 .10662 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .10662 L
.56098 .10662 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .01472 L
.68293 .01472 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .01472 L
.68293 .01472 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .07692 L
.80488 .07692 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .07692 L
.80488 .07692 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .01972 L
.92683 .01972 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .01972 L
.92683 .01972 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .12693 L
.09756 .12693 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .12693 L
.09756 .12693 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .11537 L
.21951 .11537 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .11537 L
.21951 .11537 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .13944 L
.34146 .13944 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .13944 L
.34146 .13944 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .121 L
.46341 .121 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .121 L
.46341 .121 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .14913 L
.58537 .14913 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .14913 L
.58537 .14913 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .0813 L
.70732 .0813 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .0813 L
.70732 .0813 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .14757 L
.82927 .14757 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .14757 L
.82927 .14757 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .12756 L
.95122 .12756 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .12756 L
.95122 .12756 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .02941 L
.12195 .02941 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .02941 L
.12195 .02941 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .22978 L
.2439 .22978 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .22978 L
.2439 .22978 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .1113 L
.36585 .1113 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .1113 L
.36585 .1113 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .11474 L
.4878 .11474 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .11474 L
.4878 .11474 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .11068 L
.60976 .11068 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .11068 L
.60976 .11068 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .17632 L
.73171 .17632 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .17632 L
.73171 .17632 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .11724 L
.85366 .11724 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .11724 L
.85366 .11724 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .11881 L
.97561 .11881 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .11881 L
.97561 .11881 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`coogl02ol0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool;ool000_o0?l02ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;
o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;
o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool00ol0003oooooooooo`0;
ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool;ool000_o0?l02ol00?l<oomo
00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00
o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o
00_o003o3?ooO`0:ooooo`coo`002_ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o
0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_o
o`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[o
oooo3?oo000:ooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl0
2_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o
3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl02_ooool<ool000[ooooo
2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0
o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol0
0?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o5Oooool;
ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo0ol00008oooo
o`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00
o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo
00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`09ooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`co
ogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o
003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`co
ogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`00
2ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl0
8?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo
2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol0
0?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0
o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol0
0?l<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool;
ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o
00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool0
00_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Poooo
o`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo2ooo000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o
003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`co
ogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lEooooo`_oo`00
2ol0o`0;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo
2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl0
8?ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo2ooo
000;o`3o00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?oo
O`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_oo
ool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00Wooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:
ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o
00co003o5Oooool;ool000_o0?l02ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Poooo
o`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool0
00_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?lEooooo`_oo`002ol0o`0;o`00o`co
ogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o
003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`co
ogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`00
2ol0o`0<o`00oaGooooo2ooo000;o`3o00_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl0
8?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo
2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o8?ooool;o`3o00_o003o3?oo
O`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol0
0?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?oo
O`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;
o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl08?ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ob_ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o
00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00
o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol00008ooooo`_oo`002ol0o`0<o`00ob_ooooo2ol00?l<oomo00[o
oooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`co
ogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00Wo
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ob_ooooo
2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`00
2ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo
2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool;ool000_o0?l03?l00?l[ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?oo
ool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo
000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o:oooool;o`00o`coogl02_ooool;
ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0P
ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00
ob_ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:oooo
o`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo
023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool;ool000_o0?l03?l00?l[ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`co
ogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[o
oooo3?oo000:ooooo`_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o:oooool;o`00o`coogl0
2_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o
3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`coo`002_ooool;o`00o`coogl08?ooool;o`00o`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0
o`0<o`00ob_ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?oo
O`0:ooooo`_oo`002ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000:ooooo`_o003o3?oo
O`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool;
ool000_o0?l03?l00?l[ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;
o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`002_ooool;
o`00o`coogl08?ooool;o`00o`coogl02Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo2ooo000;o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo
023ooooo2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool0
00[ooooo2ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool;ool000_o0?l03?l00?l[ooooo`_o003o3?ooO`0:ooooo`_o
o`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo02_o
oooo3?ooO`0:ooooo`coo`002_ooool;o`00o`coogl08?ooool;o`00o`coogl02_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ob_ooooo
2ol00?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`00
2ol0o`0;o`00o`coogl0:oooool<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0Pooooo`_o003o
3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo2ooo
000;o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol0
0?l<oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool000[ooooo2ol0
0?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool000kooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo2ooo000;
o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool000[ooooo2ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo2ooo000;
o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool000[ooooo2ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo2ooo000;
o`3o00co003o:oooool;o`00o`coogl02_ooool;ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0[ooooo`coogl02_ooool<ool000[ooooo2ol00?l<
oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00001oooool;ool000_o0?l03?l00?l[
ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;o`00o`coogl08?ooool;o`00o`coogl02_ooool;
ool000_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`002_ooool;o`00o`coogl08?ooool;
o`00o`coogl01oooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`_oo`002ol0o`0<o`00ob_ooooo2ol00?l<
oomo00[ooooo2ooo000;o`3o00_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl0:oooool<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0Pooooo`_o003o3?ooO`0:
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0_l00008
ooooo`03o`000?oooooooooo00Sooooo2ooo000;o`3o00co003o:oooool;o`00o`coogl02_ooool;
ool000_o0?l02ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0[
ooooo`coogl02_ooool<ool000[ooooo2ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000
ooooooooool02oooool000kooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04oooool;o`3o00co003o:oooool;o`00o`coogl02_ooool<ool000[ooooo2ol00?l<oomo
023ooooo2ol00?l<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0[ooooo`coogl02_ooool<ool0
00[ooooo2ol00?l<oomo023ooooo2ol00?l<oomo00[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00co003o:oooool;o`00o`coogl02_ooool<ool000[o
oooo3?l00?l[ooooo`_o003o3?ooO`0:ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`co
o`002_ooool;o`00o`coogl08?ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?l[ooooo`_o003o3?ooO`0:ooooo`coo`00
2_ooool<o`00ob_ooooo2ol00?l<oomo00[ooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo
3?oo000:ooooo`_o003o3?ooO`0Pooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_oo
ool<o`00ob_ooooo3?l00?lEooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_oo
ool;o`00o`coogl08?ooool;o`00o`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?l[
ooooo`co003o5Oooool<ool000[ooooo3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?l[
ooooo`_o003o3?ooO`0:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o
00co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o:oooool<o`00oaGooooo3?oo000:oooo
o`co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o:oooool<o`00oaCooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lfooooo`coogl02_ooool<ool000[o
oooo3?l00?m<ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00ob_o
oooo3?l00?lEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00odcooooo3?oo000:ooooo`co003o
=_ooool<oomo00[ooooo3?oo000:ooooo`co003o:oooool<o`00oaGooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`002_oo
ool<o`00odcooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003o:ooo
ool<o`00oaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o047ooooo3?ooO`0:ooooo`coo`002_ooool<o`00odcooooo3?oo000:ooooo`co003o=_ooool<
oomo00[ooooo3?oo000:ooooo`co003oC?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo000:ooooo`co003oC?ooool<ool0
00[ooooo3?l00?lfooooo`coogl02_ooool<ool000[ooooo3?l00?m<ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool000[o
oooo3?l00?m<ooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00odco
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo
3?ooO`0:ooooo`coo`002_ooool<o`00odcooooo3?oo000:ooooo`co003o=_ooool<oomo00[ooooo
3?oo000:ooooo`co003oC?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0
o`11ooooo`coogl02_ooool<ool000[ooooo3?l00?m<ooooo`coo`002_ooool<o`00ocKooooo3?oo
O`0:ooooo`coo`002_ooool<o`00od_ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`002_ooool<o`00ocKooooo3?ooO`0:
ooooo`coo`002_ooool<o`00odcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool000[ooooo3?l00?lfoooo
o`coogl02_ooool<ool000[ooooo3?l00?m<ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo000:ooooo`co
003o=_ooool<oomo00[ooooo3?oo000:ooooo`co003oC?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00
2_ooool<o`00ocKooooo3?ooO`0:ooooo`coo`002_ooool<o`00odcooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_oo
ool<ool004cooooo3?ooO`0:ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00C?ooool<
oomo00[ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001<ooooo`coogl02_ooool<ool0
06;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0@Oooool<oomo00[o
oooo3?oo001Rooooo`coo`00C?ooool<oomo00[ooooo3?oo001Qooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool004cooooo
3?ooO`0:ooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00C?ooool<oomo00[ooooo3?oo
001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`11
ooooo`coogl02_ooool<ool006;ooooo3?oo001<ooooo`coogl02_ooool<ool006;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:oooo
o`coo`00H_ooool<ool004cooooo3?ooO`0:ooooo`coo`00H_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`co
o`00C?ooool<oomo00[ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001<ooooo`coogl0
2_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool004cooooo3?ooO`0:ooooo`coo`00H_oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`11ooooo`coogl02_ooool<
ool006;ooooo3?oo001<ooooo`coogl02_ooool<ool0067ooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00C?ooool<oomo
00[ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo
3?oo001Rooooo`coo`00H_ooool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool006;ooooo3?oo
001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`11
ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;
ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooo
oooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_oo
ool<ool006;ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01_ooool4o`0001;ooooo3?l0o`11ooooo`coogl02_oo
ool<ool006;ooooo3?oo001Rooooo`coo`00Goooool4o`0000gooooo000=ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`co0?l0@Ooo
ool<oomo00[ooooo3?oo001Rooooo`coo`00H_ooool<ool006;ooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool006;ooooo
3?oo001Rooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`co
ogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl0
2_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00H_oo
ool<ool006;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o047ooooo3?ooO`0:ooooo`coo`00H_ooool<ool006;ooooo3?oo001Rooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool0
06;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?o
oooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00HOooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo
3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00H_ooool<ool006;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:
ooooo`coo`00H_ooool<ool006;ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Roooo
o`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0@Oooool<oomo00[ooooo3?oo001Rooooo`coo`00H_ooool<ool006;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o047ooooo3?ooO`0:ooooo`coo`00
H_ooool<ool006;ooooo3?oo001Rooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`11ooooo`coogl02_ooool<
ool006;ooooo3?oo001Rooooo`coo`00HOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`11ooooo`coogl02_ooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0Eoooool<ool006;o
oooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0Eoooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0Eoooool<ool006;ooooo3?oo
001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0Eoooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0Eoooool<ool006;ooooo3?oo001Roooo
o`coo`00H_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0Eoooool<ool006;ooooo3?oo001Rooooo`coo`00H_ooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0001?ooooo3?l0o`1Gooooo`coo`00H_ooool<ool00<oooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0Eoooool<ool006;ooooo3?oo003@ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`1Gooooo`coo`00H_ooool<
ool00=3ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
05Oooooo3?oo001Rooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`co0?l0Eoooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`1Gooooo`coo`00H_ooool<ool00=3ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o05Oooooo3?oo
001Rooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0Eoooool<ool006;ooooo3?oo003@ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00004oooool<o`3o05Oooooo3?oo001Rooooo`coo`00coooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`35ooooo`coo`00d?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0Cooooo`co0?l0aOooool<ool00=3ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0<Gooooo3?oo003@ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`35ooooo`coo`00d?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0aOooool<ool0
0=3ooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo1?l0000Boooo
o`co0?l0oooooonOooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002Oooool2o`00
00Oooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`00
00Oooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0001?ooooo3?l0o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0001?ooooo3?l0o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000kooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo01?ooooo3?l0o`3o
oooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool5o`0000Kooooo1?l0000B
ooooo`co0?l0oooooonOooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o
0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Oooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003_oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
1?ooool4o`0001;ooooo3?l0o`3ooooooioooooo1?l0000=ooooo`003Oooool01?l0003ooooooooo
ool00007ooooo`Co00001oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo
000>ooooo`;o00002?ooool5o`0000Kooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOoo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0o`3ooooooj7ooooo0_l0000=
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooooooo
ool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00007ooooo`Co00004_ooool<o`3o0?ooooooWoooool4o`0000gooooo000=ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRoooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool2o`0000Oooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000C
ooooo`co0?l0oooooonQooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo
3?l0o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooomOooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool004;ooooo0ol0000cooooo`Go0000<oooool3o`0003Gooooo0ol0000cooooo`?o0000
=?ooool3o`0003Gooooo00?o0000ooooooooool0<oooool3o`0002kooooo0013ooooo`03o`000?oo
oooooooo03?ooooo00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooooooo000003Go
oooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000oooo
ooooooooooooo`00000dooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00
000]ooooo`00@oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0<?ooool5o`0003Kooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000003Gooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000002gooooo
0013ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool2o`0003?ooooo00Co
0000oooooooooooo0000=oooool00ol0003oooooooooo`0`ooooo`Co0000=_ooool00ol0003ooooo
ooooo`0booooo`?o0000;_ooool004?ooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooo
oooooooo000003Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000cooooo`Co0000
<oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooo
ooooo`00000]ooooo`00@_ooool2o`0003Cooooo00Go0000ooooooooooooooooo`00000booooo`05
o`000?ooooooooooooooool00000=?ooool2o`0003?ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0cooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooo
oooo000002gooooo0013ooooo`03o`000?oooooooooo03?ooooo0ol0000dooooo`?o0000=_ooool0
0ol0003oooooooooo`0aooooo`Go0000=?ooool2o`0003?ooooo1Ol0000cooooo`?o0000;_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0529716, 0.0181824, \
0.00248985}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0853659 0.121951 0.0147151 0.626891 [
[.07317 -0.0125 -3 -9 ]
[.07317 -0.0125 3 0 ]
[.19512 -0.0125 -3 -9 ]
[.19512 -0.0125 3 0 ]
[.31707 -0.0125 -3 -9 ]
[.31707 -0.0125 3 0 ]
[.43902 -0.0125 -3 -9 ]
[.43902 -0.0125 3 0 ]
[.56098 -0.0125 -3 -9 ]
[.56098 -0.0125 3 0 ]
[.68293 -0.0125 -3 -9 ]
[.68293 -0.0125 3 0 ]
[.80488 -0.0125 -3 -9 ]
[.80488 -0.0125 3 0 ]
[.92683 -0.0125 -3 -9 ]
[.92683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14009 -18 -4.5 ]
[-0.0125 .14009 0 4.5 ]
[-0.0125 .26547 -18 -4.5 ]
[-0.0125 .26547 0 4.5 ]
[-0.0125 .39085 -18 -4.5 ]
[-0.0125 .39085 0 4.5 ]
[-0.0125 .51623 -18 -4.5 ]
[-0.0125 .51623 0 4.5 ]
[ 0 0 -0.125 0 ]
[.07317 .63053 -3 0 ]
[.07317 .63053 3 9 ]
[.19512 .63053 -3 0 ]
[.19512 .63053 3 9 ]
[.31707 .63053 -3 0 ]
[.31707 .63053 3 9 ]
[.43902 .63053 -3 0 ]
[.43902 .63053 3 9 ]
[.56098 .63053 -3 0 ]
[.56098 .63053 3 9 ]
[.68293 .63053 -3 0 ]
[.68293 .63053 3 9 ]
[.80488 .63053 -3 0 ]
[.80488 .63053 3 9 ]
[.92683 .63053 -3 0 ]
[.92683 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07317 0 m
.07317 .00625 L
s
[(1)] .07317 -0.0125 0 1 Mshowa
.19512 0 m
.19512 .00625 L
s
[(2)] .19512 -0.0125 0 1 Mshowa
.31707 0 m
.31707 .00625 L
s
[(3)] .31707 -0.0125 0 1 Mshowa
.43902 0 m
.43902 .00625 L
s
[(4)] .43902 -0.0125 0 1 Mshowa
.56098 0 m
.56098 .00625 L
s
[(5)] .56098 -0.0125 0 1 Mshowa
.68293 0 m
.68293 .00625 L
s
[(6)] .68293 -0.0125 0 1 Mshowa
.80488 0 m
.80488 .00625 L
s
[(7)] .80488 -0.0125 0 1 Mshowa
.92683 0 m
.92683 .00625 L
s
[(8)] .92683 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14009 m
.00625 .14009 L
s
[(0.2)] -0.0125 .14009 1 0 Mshowa
0 .26547 m
.00625 .26547 L
s
[(0.4)] -0.0125 .26547 1 0 Mshowa
0 .39085 m
.00625 .39085 L
s
[(0.6)] -0.0125 .39085 1 0 Mshowa
0 .51623 m
.00625 .51623 L
s
[(0.8)] -0.0125 .51623 1 0 Mshowa
.125 Mabswid
0 .04606 m
.00375 .04606 L
s
0 .0774 m
.00375 .0774 L
s
0 .10875 m
.00375 .10875 L
s
0 .17144 m
.00375 .17144 L
s
0 .20278 m
.00375 .20278 L
s
0 .23413 m
.00375 .23413 L
s
0 .29682 m
.00375 .29682 L
s
0 .32816 m
.00375 .32816 L
s
0 .3595 m
.00375 .3595 L
s
0 .42219 m
.00375 .42219 L
s
0 .45354 m
.00375 .45354 L
s
0 .48488 m
.00375 .48488 L
s
0 .54757 m
.00375 .54757 L
s
0 .57892 m
.00375 .57892 L
s
0 .61026 m
.00375 .61026 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07317 .61178 m
.07317 .61803 L
s
[(1)] .07317 .63053 0 -1 Mshowa
.19512 .61178 m
.19512 .61803 L
s
[(2)] .19512 .63053 0 -1 Mshowa
.31707 .61178 m
.31707 .61803 L
s
[(3)] .31707 .63053 0 -1 Mshowa
.43902 .61178 m
.43902 .61803 L
s
[(4)] .43902 .63053 0 -1 Mshowa
.56098 .61178 m
.56098 .61803 L
s
[(5)] .56098 .63053 0 -1 Mshowa
.68293 .61178 m
.68293 .61803 L
s
[(6)] .68293 .63053 0 -1 Mshowa
.80488 .61178 m
.80488 .61803 L
s
[(7)] .80488 .63053 0 -1 Mshowa
.92683 .61178 m
.92683 .61803 L
s
[(8)] .92683 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14009 m
1 .14009 L
s
.99375 .26547 m
1 .26547 L
s
.99375 .39085 m
1 .39085 L
s
.99375 .51623 m
1 .51623 L
s
.125 Mabswid
.99625 .04606 m
1 .04606 L
s
.99625 .0774 m
1 .0774 L
s
.99625 .10875 m
1 .10875 L
s
.99625 .17144 m
1 .17144 L
s
.99625 .20278 m
1 .20278 L
s
.99625 .23413 m
1 .23413 L
s
.99625 .29682 m
1 .29682 L
s
.99625 .32816 m
1 .32816 L
s
.99625 .3595 m
1 .3595 L
s
.99625 .42219 m
1 .42219 L
s
.99625 .45354 m
1 .45354 L
s
.99625 .48488 m
1 .48488 L
s
.99625 .54757 m
1 .54757 L
s
.99625 .57892 m
1 .57892 L
s
.99625 .61026 m
1 .61026 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
F
.5 Mabswid
.02439 .01472 m
.02439 .01472 L
.04878 .01472 L
.04878 .01472 L
.02439 .01472 L
s
.14634 .01472 m
.14634 .1683 L
.17073 .1683 L
.17073 .01472 L
F
.14634 .01472 m
.14634 .1683 L
.17073 .1683 L
.17073 .01472 L
.14634 .01472 L
s
.26829 .01472 m
.26829 .08425 L
.29268 .08425 L
.29268 .01472 L
F
.26829 .01472 m
.26829 .08425 L
.29268 .08425 L
.29268 .01472 L
.26829 .01472 L
s
.39024 .01472 m
.39024 .11681 L
.41463 .11681 L
.41463 .01472 L
F
.39024 .01472 m
.39024 .11681 L
.41463 .11681 L
.41463 .01472 L
.39024 .01472 L
s
.5122 .01472 m
.5122 .03892 L
.53659 .03892 L
.53659 .01472 L
F
.5122 .01472 m
.5122 .03892 L
.53659 .03892 L
.53659 .01472 L
.5122 .01472 L
s
.63415 .01472 m
.63415 .04266 L
.65854 .04266 L
.65854 .01472 L
F
.63415 .01472 m
.63415 .04266 L
.65854 .04266 L
.65854 .01472 L
.63415 .01472 L
s
.7561 .01472 m
.7561 .13948 L
.78049 .13948 L
.78049 .01472 L
F
.7561 .01472 m
.7561 .13948 L
.78049 .13948 L
.78049 .01472 L
.7561 .01472 L
s
.87805 .01472 m
.87805 .13948 L
.90244 .13948 L
.90244 .01472 L
F
.87805 .01472 m
.87805 .13948 L
.90244 .13948 L
.90244 .01472 L
.87805 .01472 L
s
0 1 0 r
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
F
.04878 .01472 m
.04878 .60332 L
.07317 .60332 L
.07317 .01472 L
.04878 .01472 L
s
.17073 .01472 m
.17073 .01494 L
.19512 .01494 L
.19512 .01472 L
F
.17073 .01472 m
.17073 .01494 L
.19512 .01494 L
.19512 .01472 L
.17073 .01472 L
s
.29268 .01472 m
.29268 .01494 L
.31707 .01494 L
.31707 .01472 L
F
.29268 .01472 m
.29268 .01494 L
.31707 .01494 L
.31707 .01472 L
.29268 .01472 L
s
.41463 .01472 m
.41463 .01472 L
.43902 .01472 L
.43902 .01472 L
F
.41463 .01472 m
.41463 .01472 L
.43902 .01472 L
.43902 .01472 L
.41463 .01472 L
s
.53659 .01472 m
.53659 .05212 L
.56098 .05212 L
.56098 .01472 L
F
.53659 .01472 m
.53659 .05212 L
.56098 .05212 L
.56098 .01472 L
.53659 .01472 L
s
.65854 .01472 m
.65854 .01494 L
.68293 .01494 L
.68293 .01472 L
F
.65854 .01472 m
.65854 .01494 L
.68293 .01494 L
.68293 .01472 L
.65854 .01472 L
s
.78049 .01472 m
.78049 .01494 L
.80488 .01494 L
.80488 .01472 L
F
.78049 .01472 m
.78049 .01494 L
.80488 .01494 L
.80488 .01472 L
.78049 .01472 L
s
.90244 .01472 m
.90244 .01472 L
.92683 .01472 L
.92683 .01472 L
F
.90244 .01472 m
.90244 .01472 L
.92683 .01472 L
.92683 .01472 L
.90244 .01472 L
s
0 0 1 r
.07317 .01472 m
.07317 .30737 L
.09756 .30737 L
.09756 .01472 L
F
.07317 .01472 m
.07317 .30737 L
.09756 .30737 L
.09756 .01472 L
.07317 .01472 L
s
.19512 .01472 m
.19512 .01714 L
.21951 .01714 L
.21951 .01472 L
F
.19512 .01472 m
.19512 .01714 L
.21951 .01714 L
.21951 .01472 L
.19512 .01472 L
s
.31707 .01472 m
.31707 .01582 L
.34146 .01582 L
.34146 .01472 L
F
.31707 .01472 m
.31707 .01582 L
.34146 .01582 L
.34146 .01472 L
.31707 .01472 L
s
.43902 .01472 m
.43902 .01692 L
.46341 .01692 L
.46341 .01472 L
F
.43902 .01472 m
.43902 .01692 L
.46341 .01692 L
.46341 .01472 L
.43902 .01472 L
s
.56098 .01472 m
.56098 .33861 L
.58537 .33861 L
.58537 .01472 L
F
.56098 .01472 m
.56098 .33861 L
.58537 .33861 L
.58537 .01472 L
.56098 .01472 L
s
.68293 .01472 m
.68293 .01692 L
.70732 .01692 L
.70732 .01472 L
F
.68293 .01472 m
.68293 .01692 L
.70732 .01692 L
.70732 .01472 L
.68293 .01472 L
s
.80488 .01472 m
.80488 .01648 L
.82927 .01648 L
.82927 .01472 L
F
.80488 .01472 m
.80488 .01648 L
.82927 .01648 L
.82927 .01472 L
.80488 .01472 L
s
.92683 .01472 m
.92683 .01538 L
.95122 .01538 L
.95122 .01472 L
F
.92683 .01472 m
.92683 .01538 L
.95122 .01538 L
.95122 .01472 L
.92683 .01472 L
s
1 .5 0 r
.09756 .01472 m
.09756 .0156 L
.12195 .0156 L
.12195 .01472 L
F
.09756 .01472 m
.09756 .0156 L
.12195 .0156 L
.12195 .01472 L
.09756 .01472 L
s
.21951 .01472 m
.21951 .08403 L
.2439 .08403 L
.2439 .01472 L
F
.21951 .01472 m
.21951 .08403 L
.2439 .08403 L
.2439 .01472 L
.21951 .01472 L
s
.34146 .01472 m
.34146 .13068 L
.36585 .13068 L
.36585 .01472 L
F
.34146 .01472 m
.34146 .13068 L
.36585 .13068 L
.36585 .01472 L
.34146 .01472 L
s
.46341 .01472 m
.46341 .08403 L
.4878 .08403 L
.4878 .01472 L
F
.46341 .01472 m
.46341 .08403 L
.4878 .08403 L
.4878 .01472 L
.46341 .01472 L
s
.58537 .01472 m
.58537 .11043 L
.60976 .11043 L
.60976 .01472 L
F
.58537 .01472 m
.58537 .11043 L
.60976 .11043 L
.60976 .01472 L
.58537 .01472 L
s
.70732 .01472 m
.70732 .13552 L
.73171 .13552 L
.73171 .01472 L
F
.70732 .01472 m
.70732 .13552 L
.73171 .13552 L
.73171 .01472 L
.70732 .01472 L
s
.82927 .01472 m
.82927 .11527 L
.85366 .11527 L
.85366 .01472 L
F
.82927 .01472 m
.82927 .11527 L
.85366 .11527 L
.85366 .01472 L
.82927 .01472 L
s
.95122 .01472 m
.95122 .06906 L
.97561 .06906 L
.97561 .01472 L
F
.95122 .01472 m
.95122 .06906 L
.97561 .06906 L
.97561 .01472 L
.95122 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00@_ooool3o`0003?ooooo1Ol0000cooooo`?o0000=Oooool3o`0003?ooooo0ol0000doooo
o`?o0000=Oooool00ol0003oooooooooo`0cooooo`?o0000;_ooool004?ooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooo
oooooooo000003Cooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002go
oooo0013ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0`ooooo`Go0000=_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000=Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000;Oooool004?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`;o0000<oooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03o`000?oooooooooo
03;ooooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0booooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003?ooooo1?l0000coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000002gooooo0012ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000dooooo`;o0000<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03?ooooo00Go0000ooooooooooooooooo`00000booooo`05o`000?ooooooooooooooool0
0000;Oooool004?ooooo00?o0000ooooooooool0<oooool3o`0003Cooooo0ol0000fooooo`03o`00
0?oooooooooo037ooooo1Ol0000dooooo`;o0000<oooool5o`0003?ooooo0ol0000^ooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`008oooooooo`000<Go00003Oooool002?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;
ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo`Oooool0
0ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00006
ooooo`_o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;o`00o`coogl02_l0000;
ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:o`0000_oo`002ol0o`0;
o`00o`coogl02_l0000;ool000_o0?l02ol00?l<oomo00[o00002ooo000;o`3o00_o003o3?ooO`0:
o`0000_oo`002ol0o`0;o`00o`coogl02ol0000=ooooo`006Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000:ooooo`_o003o3?ooO`0:
ooooo`coo`005Oooool<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool<ool000[ooooo2ol00?l<oomo00[ooooo3?oo000:ooooo`_o003o3?ooO`0:
ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`_oo`002ol0o`0;
o`00o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000oooo
ooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo
00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eoooo
o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o
0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`co
o`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo
3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?oo
O`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol0
0?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Ooo
ool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo
00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo
00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co
003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`co
ogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool;ool000_o0?l02ol00?l<oomo00[ooooo
3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Ooo
ool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_oo
ool;ool000_o0?l02ol00?l<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?oo
O`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o003o3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eoooo
o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo01Gooooo2ol0o`0;o`00
o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003o5Oooool<ool001Go
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl05Oooool;o`3o00_o
003o3?ooO`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00Wo
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
5Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Eooooo`_o0?l0
2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l0
0?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?oo
O`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0C
ooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool001Gooooo3?ooO`0Eooooo`_o0?l02ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eoooo
o`coogl02_ooool<ool001Gooooo3?ooO`0Pooooo`_o003o3?ooO`0[ooooo`coogl02_ooool<ool0
01Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`co
o`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl08?ooool;o`00o`coogl0:oooool<oomo00[o
oooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo023ooooo2ol00?l<oomo02_ooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`005Ooo
ool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Pooooo`_o003o3?oo
O`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl08?ooool;
o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
oaGooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo
023ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000Eoooo
o`coogl02_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?lEooooo`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Go
oooo3?ooO`0Pooooo`_o003o3?ooO`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`co
o`005Oooool<oomo00[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo
3?oo000Eooooo`coogl08?ooool;o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl0
2_ooool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000Eooooo`coogl08?ooool;o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_oo
ool<ool002_ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;
o`3o00co003o5Oooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000E
ooooo`coogl08?ooool;o`00o`coogl0:oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<
ool002_ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l00?lEoooo
o`coo`005Oooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool001Gooooo3?ooO`0Poooo
o`_o003o3?ooO`0[ooooo`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00:_ooool2o`00
00gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`co
ogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo023ooooo2ol00?l<oomo02_o
oooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl0
2_ooool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo023ooooo2ol00?l<oomo02_ooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo000Eooooo`coogl02_oo
ool<ool001Gooooo3?ooO`0:ooooo`coo`005Oooool<oomo023ooooo2ol00?l<oomo02_ooooo3?oo
O`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<
ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00
oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:oooo
o`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047o
oooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo
3?oo001<ooooo`coogl02_ooool<ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047ooooo2ol0
0?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<
ooooo`coogl02_ooool<ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<
oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047ooooo2ol00?l<oomo
02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`co
ogl02_ooool<ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[o
oooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047ooooo2ol00?l<oomo02_ooooo
3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_oo
ool<ool0047ooooo2ol00?l<oomo02_ooooo3?ooO`0:ooooo`coo`005Oooool<oomo00[ooooo3?oo
000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003o5Oooool<
ool004cooooo3?ooO`0:ooooo`coo`00@Oooool;o`00o`coogl0:oooool<oomo00[ooooo3?oo000E
ooooo`coogl02_ooool<ool002[ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Coooo
o`_o0?l03?l00?lEooooo`coo`00C?ooool<oomo00[ooooo3?oo0011ooooo`_o003o3?ooO`0[oooo
o`coogl02_ooool<ool001Gooooo3?ooO`0:ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00C?ooool<oomo00[o
oooo3?oo0011ooooo`co003o=_ooool<oomo00[ooooo3?oo000Eooooo`coogl02_ooool<ool002_o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
5Oooool<ool004cooooo3?ooO`0:ooooo`coo`00@Oooool<o`00ocKooooo3?ooO`0:ooooo`coo`00
5Oooool<oomo00[ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl02_ooool<ool0047ooooo3?l0
0?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl0Eoooool<
o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?ooO`1Goooo
o`co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00C?ooool<oomo05Oo
oooo3?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo001<ooooo`coogl0
Eoooool<o`00ocKooooo3?ooO`0:ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<ool004cooooo3?oo
O`1Gooooo`co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00C?ooool<
oomo05Oooooo3?l00?lfooooo`coogl02_ooool<ool002_ooooo3?oo000[ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo002_oooo
o`co003o=_ooool<oomo00[ooooo3?oo000[ooooo`coo`00:oooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00oaGooooo3?oo002_ooooo`co003o=_ooool<oomo00[ooooo3?oo000[oooo
o`coo`00:oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool00:oooooo3?l00?m<ooooo`coo`00:oooool<ool002_ooooo00?o0000ooooooooool02oooool0
00gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00004_ooool;
o`3o00co003o5Oooool<ool00:oooooo3?l00?m<ooooo`coo`00:oooool<ool002Sooooo1?l0000=
ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04oooool;o`3o00co003o5Oooool<ool00:oooooo3?l00?njooooo`03o`000?oooooo
oooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo002_ooooo`co003o^_oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
[oooool<o`00ok[ooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00[oooool<o`00ok[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o5Oooool<
ool00:oooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00oaGooooo3?oo002_ooooo`co003o^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00[oooool<o`00ok[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
5Oooool<ool00:oooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo002_ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00[oooool<
o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o
00co003o5Oooool<ool00:oooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00oaGooooo3?oo002_ooooo`co003o^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?lEooooo`coo`00
[oooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`_o0?l03?l0
0?o@ooooo`co003o^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l0
0?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l0
0?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<
o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l00?njooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00004oooool;o`3o00co003od?ooool<o`00okWooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@oooo
o`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@oooo
o`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@oooo
o`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo
2ol0o`0<o`00om3ooooo3?l00?niooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
d?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
d?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo01?ooooo2ol0o`0<o`00om3ooooo3?l0
0?njooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Go00001_oo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo
1?l0000Booooo`_o0?l03?l00?o@ooooo`co003o]oooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Cooooo`_o0?l0
3?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00009ooooo`;o00001oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o
^_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@oooo
o`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@oooo
o`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`_o
0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`_o0?l03?l00?o@ooooo`co003o^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool3o`0001?ooooo2ol0o`0<o`00om3ooooo3?l00?niooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool;o`3o00co003o
d?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool;o`3o00co003od?ooool<o`00ok[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0=_ooooo3?l00?njooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Kooooo`co003o^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0foooool<o`00ok[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0=_ooooo3?l0
0?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3K
ooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0foooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0=_ooooo3?l00?njooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3Kooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0001?ooooo3?l0o`3Kooooo`co003o^Oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3Kooooo`co003o^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0foooool<o`00ok[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool04oooool<o`3o0=_ooooo3?l00?njooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3Kooooo`co003o^_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0foooool<o`00ok[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oooooo
X_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooo
oonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3o
oooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00004oooool<o`3o0?oooooo
XOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oooooo
X_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooo
oonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3o
oooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o
0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co
0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo
3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04ooo
ool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`Co00004_ooool<o`3o0?ooooooWoooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000kooooo0_l0
000:ooooo`;o00001oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo0ol0000Cooooo`co0?l0oooooonQ
ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0001?ooooo3?l0
o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonR
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?oo
ooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0
oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
4oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool04oooool<
o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Coooo
o`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo01?o
oooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
4oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo01?ooooo3?l0
o`3ooooooj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool<o`3o0?oooooo
X_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03
o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0ol00007ooooo`Co
00004_ooool<o`3o0?ooooooWoooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooo
oj;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo
01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0001?ooooo3?l0o`3ooooooj7ooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00004oooool<o`3o0?ooooooXOooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`0Cooooo`co0?l0oooooonRooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo01?ooooo3?l0o`3ooooooj;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool04oooool<o`3o0?ooooooX_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o0000ooooooo0ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool002?oooooool0
0035o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo0012ooooo`?o0000<oooool5o`0003?o
oooo0ol0000eooooo`?o0000<oooool3o`0003Cooooo0ol0000eooooo`03o`000?oooooooooo03?o
oooo0ol0000^ooooo`00@oooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0003;o
oooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo037ooooo00Go0000oooo
ooooooooooooo`00000booooo`05o`000?ooooooooooooooool00000=?ooool00ol0003ooooooooo
o`0booooo`05o`000?ooooooooooooooool00000;Oooool004?ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo033ooooo1Ol0000fooooo`03o`000?oo
oooooooo033ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo037ooooo
00Go0000ooooooooooooooooo`00000]ooooo`00@oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03?ooooo0_l0000cooooo`04o`000?ooooooooooo`0003Oooooo00?o0000oooooooo
ool0<?ooool4o`0003Kooooo00?o0000ooooooooool0<_ooool3o`0002kooooo0013ooooo`03o`00
0?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo037o
oooo00?o0000ooooool00000<oooool4o`0003?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0`ooooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo0_l0000dooooo`05
o`000?ooooooooooooooool00000<_ooool01Ol0003ooooooooooooooooo000003Cooooo0_l0000c
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooo
oooo000003;ooooo00Go0000ooooooooooooooooo`00000]ooooo`00@oooool00ol0003ooooooooo
o`0cooooo`?o0000=?ooool3o`0003Kooooo00?o0000ooooooooool0<Oooool5o`0003Cooooo0_l0
000cooooo`Go0000<oooool3o`0002kooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {0.049734, -0.0752517, 0.0181824, \
0.00353709}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(251.1184430000000000001`8.851423603456976\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .50686 L
.2381 .50686 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .50686 L
.2381 .50686 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .03233 L
.71429 .03233 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .03233 L
.71429 .03233 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09073 L
.95238 .09073 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09073 L
.95238 .09073 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF00000000FFFF8000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF80000000FFFF0000FF0000FF8000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF80000000FF0000FFFF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF00000000FF0000FF0000FFFF0000FF0000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FF
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF80000000FFFF00000000FFFF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .53627 L
.47619 .53627 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .53627 L
.47619 .53627 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .08155 L
.71429 .08155 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .08155 L
.71429 .08155 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01814 L
.2381 .01814 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01814 L
.2381 .01814 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .27992 L
.47619 .27992 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .27992 L
.47619 .27992 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .32789 L
.71429 .32789 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .32789 L
.71429 .32789 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000
0000FF00FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FFFF0000
FF80000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF0000FF0000FF8000FF0000FF0000
0000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF00000000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FFFF0000FF0000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF00
0000FF0000FFFF00000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .29431 L
.2381 .29431 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .29431 L
.2381 .29431 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0146 L
.47619 .0146 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0146 L
.47619 .0146 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11597 L
.71429 .11597 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11597 L
.71429 .11597 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .21693 L
.95238 .21693 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .21693 L
.95238 .21693 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF00000000FFFF80000000FFFF0000FF8000FF00000000FF
FF8000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF80000000FF0000FFFF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF80000000FF0000FFFF0000
FF0000FF0000FF0000FF80000000FFFF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF00000000FFFF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF80000000FF0000FFFF0000FF0000FF80000000FF0000FFFF8000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF00000000FF
FF8000FF0000FF0000FF0000FF80000000FFFF8000FF0000FF80000000FFFF80000000FF
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
FF0000FF00000000FF00FF000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF80000000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000
FF0000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF80000000FFFF0000FF8000FF80000000FFFF0000FF0000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF00000000FFFF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF8000FF80000000FFFF0000FF8000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF80000000FF0000FFFF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
FF00000000FFFF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF80000000FFFF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF00000000FFFF8000FF0000FF0000FF0000FF0000FF00000000FFFF80000000FFFF8000
FF00000000FFFF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF0000FF0000
FF80000000FFFF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF0000FF80000000FFFF80000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FF00FF000000FF
0000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF80000000FFFF8000FF80000000FF0000FFFF0000FF0000FF0000
FF80000000FFFF80000000FFFF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF80000000FFFF8000FF80000000FFFF0000
FF0000FF8000FF80000000FFFF8000FF8000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF80000000FF0000FFFF80000000FF0000FFFF0000FF0000FF0000
FF80000000FF0000FFFF0000FF8000FF80000000FFFF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
0000FFFF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FFFF0000
FF0000FF8000FF80000000FFFF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF80000000FF0000FFFF80000000FF0000FFFF0000FF0000FF0000
FF80000000FF0000FFFF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF8000FF00000000FFFF8000FF0000FF0000
FF0000FF0000FF80000000FF0000FFFF8000FF0000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FFFF8000FF80000000FFFF80000000FFFF0000FF0000FF0000FF0000
FF80000000FFFF80000000FF0000FFFF80000000FFFF0000FF00000000FFFF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF80000000FFFF8000FF0000FF8000FF800000FF000000FFFF0000
FF0000FF0000FF0000FF8000FF8000
0000FFFF0000FF0000FF0000FF8000FF0000FF80000000FFFF0000FF0000FF8000FF0000
FF80000000FFFF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF8000
0000FFFF0000FF0000FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF80000000FF0000FF0000FFFF8000FF0000FF8000FF0000FF80000000FF0000FF
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF8000
0000FFFF0000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF
0000FFFF0000FF0000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF0000
FF80000000FFFF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF00000000FF
00FF000000FFFF00000000FFFF80000000FFFF8000FF80000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF80000000FF0000FFFF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FF
00FF000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF8000
FF0000FF00000000FFFF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000
FF0000FF0000FF8000FF0000FF8000
0000FF0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF80000000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00
0000FF0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FFFF8000
FF80000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF80000000FF
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF00000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF0000
0000FF00FF000000FFFF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF80000000FF0000FFFF00000000FF0000FFFF0000FF0000
FF8000FF80000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FFFF0000FF0000FF8000FF8000
0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF00000000FFFF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF00000000FF0000FF0000FFFF0000FF8000
FF8000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF00FF00
0000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF80000000FF0000FFFF8000FF80000000FFFF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FFFF80000000FF
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF80000000FFFF0000FF0000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FF
FF8000FF80000000FFFF80000000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF00000000FFFF80000000FF0000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF00000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF0000FF80000000FF0000FF0000FF
0000FFFF0000FF0000FF8000FF0000FF0000FF80000000FFFF80000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF80000000FFFF8000FF0000FF8000FF0000FF8000FF0000FF0000FF80000000FF0000FF
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
0000FFFF00000000FFFF8000FF0000FF0000FF0000FF8000FF800000FF0000FF00FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000FF80000000FF
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF00000000FF
FF0000FF0000FF0000FF0000FF8000
FF80000000FF0000FFFF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF80000000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FFFF0000
0000FFFF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF80000000FF0000FF
FF80000000FF0000FFFF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF00000000FFFF8000FF0000FF0000FF80000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF00000000FF
FF8000FF0000FF0000FF8000FF80000000FFFF00000000FF0000FFFF8000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000
FF0000FF80000000FF0000FF0000FFFF0000FF0000FF0000FF8000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF00000000FF
FF8000FF00000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000
FF0000FF80000000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF80000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FFFF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF80000000FF0000FF0000FFFF8000
FF00000000FFFF0000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FF0000FF0000FF0000FFFF80000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF80000000FFFF80000000FFFF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF80000000FFFF80000000FFFF8000
FF00000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF80000000FF0000FFFF0000FF8000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000
0000FFFF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF80000000FF0000FFFF8000
FF80000000FF00FF000000FF0000FFFF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF80000000FF0000FFFF0000FF8000FF0000FF0000FF80000000FFFF80000000FF
FF0000FF00000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF00FF00FF80000000FF0000FFFF8000FF0000FF0000FF8000FF0000
FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF80000000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FFFF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF80000000FFFF80000000FFFF0000FF00000000FFFF8000FF80000000FF0000FFFF8000
FF0000FF8000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .50603 L
.2381 .50603 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .50603 L
.2381 .50603 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0559 L
.47619 .0559 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0559 L
.47619 .0559 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02503 L
.71429 .02503 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02503 L
.71429 .02503 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05485 L
.95238 .05485 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05485 L
.95238 .05485 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF8000FF00000000FF
FF0000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF80000000FF0000FF
FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF8000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF00000000FF0000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FF
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF000000FF000000FF
0000FFFF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF800000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF800000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF0000
FF0000FF0000FF800000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF800000FF00FF000000FF00
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF8000FF0000
FF000000FF00FF0000FF000000FF00
FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .18293 L
.2381 .18293 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .18293 L
.2381 .18293 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .38359 L
.47619 .38359 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .38359 L
.47619 .38359 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02669 L
.71429 .02669 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02669 L
.71429 .02669 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0486 L
.95238 .0486 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0486 L
.95238 .0486 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF800000FF0000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FFFF8000FF0000FF8000FF0000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF8000FF8000
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF00000000FFFF8000
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF800000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000
0000FFFF8000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF800000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000
0000FFFF8000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000
0000FFFF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF0000FF0000FF0000FF00FF000000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF00000000FFFF0000
0000FFFF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000
0000FFFF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF8000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000FF800000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000FF800000FF0000FF00
00FF00FF000000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF00FF0000FF0000FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF00FF000000FF0000FF00FF800000FF0000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF00FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF
FF8000FF0000FF800000FF0000FF00FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00000000FFFF00000000FF
FF8000FF0000FF800000FF00FF0000FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00000000FFFF0000FF8000
FF8000FF0000FF800000FF00FF0000FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF8000
FF8000FF0000FF800000FF0000FF00FF00000000FF0000FFFF0000FF800000FF0000FF00
00FF0000FF00FF000000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF00FF000000FF00
FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF800000FF00FF0000
FF800000FF00FF000000FF0000FF0000FF000000FF0000FFFF0000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF800000FF00FF0000
FF000000FF00FF000000FF0000FF0000FF000000FF0000FFFF0000FF800000FF0000FF00
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF800000FF00FF0000
FF000000FF00FF000000FF0000FF0000FF000000FFFF0000FF0000FF800000FF0000FF00
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00
00FF0000FF00FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF800000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF00
FF000000FF00FF8000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF8000FF0000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF00000000FFFF0000FF0000FF8000FF0000FF0000FF800000FF0000FF00FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
FF8000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF00000000FFFF0000FF0000FF8000FF0000FF0000FF8000FF000000FF00FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .31371 L
.2381 .31371 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .31371 L
.2381 .31371 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .09323 L
.47619 .09323 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .09323 L
.47619 .09323 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .12139 L
.71429 .12139 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .12139 L
.71429 .12139 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11347 L
.95238 .11347 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11347 L
.95238 .11347 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FFFF0000FF8000FF8000FF8000FF0000FF0000
FF00000000FF0000FFFF0000FF8000FF0000FF00000000FFFF80000000FFFF0000FF0000
FF80000000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FF0000FFFF0000FF8000FF800000FF0000FF00FF0000
FF00000000FF0000FFFF0000FF8000FF0000FF00000000FFFF80000000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF8000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
0000FF0000FF0000FFFF8000FF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF00000000FFFF0000
FF8000FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF00000000FF0000FF0000FF0000FFFF8000FF80000000FFFF0000FF0000FF00000000FF
0000FFFF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF8000FF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF80000000FFFF0000FF8000FF0000FF00000000FF0000FFFF8000FF80000000FFFF8000
FF80000000FFFF80000000FFFF0000FF8000FF80000000FFFF00000000FFFF00000000FF
0000FFFF0000FF8000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF80000000FF0000FF0000FF0000FF0000FFFF0000
FF80000000FFFF8000FF8000FF00000000FF0000FF0000FFFF8000FF8000FF0000FF0000
FF80000000FFFF0000FF0000FF80000000FFFF0000FF0000FF80000000FFFF80000000FF
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF0000FF800000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FFFF8000FF0000FF80000000FF0000FF0000FF0000FF0000FFFF0000
FF8000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF8000FF800000FF0000FF00
FF00000000FF0000FFFF0000FF80000000FFFF0000FF00000000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FFFF80000000FFFF0000
FF8000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF8000FF800000FF0000FF00
FF00000000FF0000FFFF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF8000
FF0000FF00000000FF0000FF0000FF
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF000000FFFF0000FF0000FF8000FF8000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
0000FF0000FFFF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF8000FF800000FF00FF0000FF00000000FF0000FFFF0000FF8000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF8000
00FF0000FF000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF8000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF00000000FFFF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF0000FF00FF0000FF00000000FFFF0000FF0000FF8000
00FF0000FF000000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF800000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF800000FF00FF00000000FF0000FF0000FFFF8000FF8000FF0000
FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00FF00000000FF0000FFFF0000FF8000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FFFF8000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF000000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000
FF8000FF80000000FFFF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF0000
00FF00FF0000FF0000FF0000FF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF000000FF00FF8000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF0000
FF8000FF80000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
00FF00FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF8000
0000FFFF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF000000FF00FF00000000FFFF00000000FF0000FFFF0000FF8000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF00000000FFFF00000000FFFF8000
0000FF0000FFFF0000FF8000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000
FF800000FF00FF00000000FFFF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF00000000FF
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000FF8000FF0000FF0000
0000FF0000FFFF0000FF8000FF0000FF0000FF8000FF0000FF8000FF00000000FF0000FF
0000FF0000FFFF0000FF8000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF0000
FF0000FF8000FF0000FF00000000FF
FF0000FF000000FF0000FF0000FF0000FF000000FFFF0000FF0000FF800000FF00FF0000
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF8000FF800000FF00FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FFFF0000FF800000FF0000FF00FF800000FF00FF8000FF00000000FFFF0000
FF0000FF8000FF00000000FF0000FF
FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF8000FF000000FF000000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
0000FF0000FFFF0000FF800000FF00FF0000FF800000FF0000FF00FF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF800000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
FF00000000FFFF0000FF0000FF800000FF0000FF000000FF0000FF0000FFFF8000FF8000
FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FF
FF00000000FF0000FF0000FFFF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF00000000FF0000FF
FF0000FF8000FF8000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF00000000FF0000FFFF8000FF8000FF0000FF00000000FF0000FFFF00000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF8000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FF
FF0000FF8000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
FF0000FF0000FF8000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF80000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF8000
00FF0000FF00FF800000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF8000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FF0000FF
00FF0000FF00FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF
FF0000FF8000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF
FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF
0000FFFF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FF
FF0000FF8000FF80000000FFFF0000FF0000FF8000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF
FF800000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000
FF00000000FFFF0000FF0000FF800000FF0000FF00FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF800000FF0000FF0000FF00FF0000FF000000FF0000FF000000FF
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FF0000FF
0000FFFF8000FF80000000FF0000FFFF0000FF8000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF8000
0000FFFF0000FF00000000FF0000FF
FF800000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF
FF0000FF8000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF000000FF000000FF
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000
0000FF0000FFFF00000000FF0000FF
FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF8000
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FF
FF00000000FFFF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF000000FF0000FFFF00000000FF
0000FFFF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FF
FF00000000FFFF8000FF000000FF0000FF00FF0000FF0000FF00000000FF0000FF0000FF
FF80000000FFFF00000000FF0000FF
FF8000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF0000FF8000FF0000FF0000
FF00000000FFFF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF0000FF00FF000000FF000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF000000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF8000FF0000FF00000000FF0000FF
FF800000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF000000FFFF0000FF0000FF800000FF0000FF00FF8000FF00000000FF
0000FF0000FFFF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF8000FF0000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF00000000FF0000FFFF0000FF8000FF000000FF00FF8000FF0000FF0000
FF00000000FFFF8000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF
FF8000FF0000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF8000FF00000000FF
0000FF0000FFFF8000FF8000FF800000FF00FF0000FF000000FF0000FF00FF0000FF0000
0000FFFF0000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF00000000FFFF0000FF8000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF80000000FFFF0000
FF0000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF0000FF800000FF0000FF000000FF
FF0000FF00000000FF0000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF80000000FFFF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF00000000FFFF80000000FFFF80000000FFFF0000
FF0000FF8000FF000000FF00FF800000FF0000FF00FF000000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF
0000FFFF0000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF80000000FFFF0000FF80000000FFFF0000
FF8000FF0000FF0000FF8000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF00000000FFFF80000000FFFF00000000FF0000FF
0000FFFF8000FF0000FF0000FF800000FF0000FF00FF000000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF
FF0000FF0000FF80000000FF0000FF
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF80000000FF0000FFFF80000000FFFF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
00FF00FF0000FF0000FF0000FF8000FF00000000FFFF8000FF0000FF00000000FF0000FF
0000FFFF8000FF000000FF00FF800000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF80000000FF0000FF
FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF00000000FF0000FFFF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF00000000FF0000FF
0000FFFF8000FF000000FF00FF800000FF00FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF8000FF80000000FFFF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF00000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .22339 L
.2381 .22339 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .22339 L
.2381 .22339 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .03316 L
.47619 .03316 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .03316 L
.47619 .03316 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .1239 L
.71429 .1239 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .1239 L
.71429 .1239 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .26135 L
.95238 .26135 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .26135 L
.95238 .26135 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF000000FF00FF0000FF00000000FF0000FF
FF0000FF8000FF0000FF80000000FF0000FF0000FFFF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF00000000FF0000FFFF00000000FF
0000FFFF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF0000FF80000000FF0000FF
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF80000000FF0000FF0000FF0000FFFF0000
FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF80000000FFFF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF00000000FFFF8000FF80000000FF
0000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FFFF8000FF80000000FF
FF8000FF80000000FFFF8000FF0000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF800000FF00FF0000FF0000FF00000000FF0000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF0000FF800000FF00FF00000000FF0000FFFF80000000FF0000FF0000FFFF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF000000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF8000
FF00000000FFFF0000FF0000FF000000FF00FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF00000000FFFF0000FF00000000FF0000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF8000FF0000FF000000FF00FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF8000
FF80000000FFFF8000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF0000FF8000FF8000FF0000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF00000000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FFFF0000FF8000FF80000000FF0000FF0000FFFF8000
FF00000000FFFF8000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000
FF80000000FFFF0000FF0000FF8000FF0000FF8000FF00000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF800000FF00FF0000FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF00000000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF80000000FFFF8000FF80000000FFFF0000FF8000FF00000000FFFF8000
FF00000000FF0000FFFF0000FF8000
00FF00FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000
FF80000000FF0000FFFF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF0000FF8000FF8000
FF00000000FF0000FFFF8000FF8000
00FF00FF8000FF8000FF0000FF0000FF800000FF00FF800000FF00FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF80000000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF0000FF8000FF8000
FF80000000FF0000FFFF80000000FF
00FF00FF8000FF0000FF0000FF0000FF8000FF8000FF800000FF00FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF00000000FFFF0000FF0000
0000FF0000FFFF8000FF80000000FFFF8000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF80000000FFFF8000FF8000FF80000000FFFF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF0000FF0000
FF80000000FFFF8000FF80000000FF
FF0000FF0000FF00000000FFFF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF800000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF0000FF0000
FF8000FF0000FF80000000FF0000FF
FF00000000FF0000FF0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF800000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF0000FF0000
FF00000000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF00000000FF
0000FF0000FFFF80000000FFFF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF
FF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF800000FF00
FF00000000FFFF0000FF0000FF8000FF8000FF0000FF00000000FF0000FFFF8000FF8000
FF8000FF00000000FF0000FFFF8000FF8000FF8000FF000000FF00FF8000FF00000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF00000000FF
0000FFFF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF
FF0000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF
FF8000FF800000FF00FF00000000FFFF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF00000000FF0000FFFF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF00000000FF0000FFFF8000FF800000FF00FF0000FF8000FF0000FF0000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF
FF0000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FFFF00000000FF0000FF
FF8000FF800000FF0000FF000000FFFF0000FF0000FF8000FF0000FF800000FF00FF0000
FF0000FF00000000FFFF0000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF0000
FF8000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF800000FF00FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF800000FF0000FF0000FF000000FF0000FFFF0000FF800000FF00FF000000FF00FF8000
FF8000FF00000000FFFF8000FF0000FF8000FF0000FF80000000FF0000FF0000FFFF8000
FF800000FF00FF00000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
0000FFFF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF0000FF8000FF0000
0000FFFF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF800000FF0000FF0000FF000000FF0000FFFF0000FF800000FF00FF8000FF0000FF8000
FF8000FF00000000FFFF8000FF0000FF8000FF0000FF80000000FF0000FF0000FFFF8000
FF8000FF0000FF00000000FF0000FFFF8000FF8000FF0000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF8000FF0000FF0000
FF0000FF8000FF800000FF000000FF0000FFFF0000FF800000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF00000000FF0000FFFF8000
FF800000FF00FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF00000000FF0000FFFF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF800000FF000000FF0000FFFF0000FF8000FF00000000FFFF0000FF0000
FF8000FF00000000FF0000FFFF8000FF8000FF0000FF8000FF0000FF80000000FFFF8000
FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF00000000FF
FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF800000FF00
FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF00000000FF0000FFFF0000FF8000FF80000000FFFF0000FF0000
FF8000FF00000000FF0000FFFF0000FF8000FF0000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF80000000FF
FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF80000000FF
FF0000FF0000FF8000FF00000000FFFF0000FF0000FF8000FF80000000FF0000FFFF0000
FF8000FF00000000FFFF0000FF0000FF8000FF00000000FFFF0000FF8000FF00000000FF
FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF0000FF000000FFFF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00
00FF000000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF80000000FF
FF0000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF80000000FF0000FFFF0000
FF8000FF00000000FF0000FFFF0000FF8000FF00000000FF0000FFFF8000FF80000000FF
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF80000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF00000000FF0000FFFF0000FF8000FF00000000FF0000FFFF8000FF00000000FF
FF0000FF0000FF8000FF00000000FFFF8000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF80000000FFFF0000FF8000FF8000FF00000000FF0000FFFF0000
FF8000FF8000FF800000FF00FF8000FF000000FF0000FF00FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF00000000FFFF0000FF8000FF8000FF00000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF00000000FFFF8000FF0000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00FF0000FF0000FF80000000FF
FF0000FF0000FF8000FF0000FF0000
FF0000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF00000000FF0000FFFF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF800000FF00FF00000000FFFF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF0000FF00000000FF0000FF
FF0000FF8000FF80000000FFFF0000
FF8000FF800000FF00FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF0000FF8000FF8000FF800000FF00FF800000FF00FF0000FF0000FF0000FF8000FF0000
FF00000000FFFF8000FF0000FF8000FF80000000FFFF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF80000000FF0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF00FF0000FF8000FF0000FF8000FF0000FF80000000FFFF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF800000FF00FF800000FF00FF0000FF0000FF8000FF8000FF8000
FF00000000FFFF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF00000000FF0000FFFF8000FF00000000FFFF0000
0000FFFF80000000FF0000FF0000FFFF8000FF0000FF00000000FF0000FFFF0000FF8000
00FF00FF00000000FF0000FF0000FF
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF80000000FF0000FFFF0000
FF800000FF00FF8000FF0000FF8000FF0000FF8000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF8000FF8000
FF00000000FFFF8000FF0000FF8000FF80000000FFFF8000FF80000000FF0000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF00000000FFFF0000
0000FFFF8000FF00000000FF0000FFFF80000000FFFF00000000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FFFF00000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF0000FF8000FF800000FF00FF00000000FF0000FFFF00000000FF0000FF
0000FFFF8000FF0000FF8000FF00000000FFFF8000FF80000000FF0000FFFF8000FF8000
FF0000FF00000000FF0000FFFF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF80000000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF80000000FFFF80000000FF0000FFFF0000
FF8000FF8000FF0000FF0000FF000000FF00FF0000FF8000FF8000FF00000000FFFF8000
FF8000FF8000FF0000FF8000FF80000000FFFF8000FF0000FF8000FF00000000FFFF8000
FF0000FF00000000FFFF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF8000FF0000
0000FFFF8000FF00000000FF0000FFFF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF00000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF800000FF00FF0000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF80000000FFFF8000FF00000000FF0000FF
FF0000FF80000000FF0000FFFF8000
FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF00000000FF0000FF0000FF
FF800000FF0000FF00FF00000000FF0000FFFF0000FF80000000FFFF0000FF8000FF8000
0000FFFF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF0000FF8000
FF8000FF8000FF00000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF00000000FF0000FF
FF0000FF80000000FFFF0000FF8000
FF0000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF80000000FF0000FFFF0000
FF8000FF800000FF00FF80000000FF0000FFFF0000FF80000000FFFF0000FF0000FF8000
0000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF00000000FF
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF0000FF8000FF0000
FF0000FF8000FF8000FF80000000FFFF0000FF0000FF80000000FF0000FF0000FFFF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF0000
FF0000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF00000000FF0000FFFF0000
FF8000FF800000FF00FF00000000FF0000FFFF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF800000FF00FF800000FF00FF0000FF0000FF00000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF800000FF00
FF0000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF00000000FF0000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF800000FF0000FF00FF0000FF8000FF0000FF8000
FF0000FF80000000FFFF0000FF8000
FF0000FF800000FF0000FF00FF8000FF0000FF00000000FF0000FF0000FFFF8000FF0000
FF8000FF800000FF0000FF000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF800000FF00FF8000FF8000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF0000FF800000FF00
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF8000FF80000000FF
FF000000FF0000FF0000FF00FF800000FF00FF80000000FF0000FFFF0000FF80000000FF
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF80000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .51354 L
.2381 .51354 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .51354 L
.2381 .51354 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .04588 L
.47619 .04588 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .04588 L
.47619 .04588 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0705 L
.95238 .0705 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0705 L
.95238 .0705 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF8000FF000000FF00FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF8000FF8000FF8000FF0000
00FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
00FF0000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF0000
00FF00FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00
FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .12682 L
.2381 .12682 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .12682 L
.2381 .12682 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .48871 L
.47619 .48871 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .48871 L
.47619 .48871 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01439 L
.95238 .01439 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01439 L
.95238 .01439 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00
FF0000FF000000FF0000FF00FF0000
00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00
FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .15977 L
.2381 .15977 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .15977 L
.2381 .15977 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .45805 L
.47619 .45805 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .45805 L
.47619 .45805 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000
FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
00FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00
FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .04776 L
.2381 .04776 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .04776 L
.2381 .04776 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .57027 L
.95238 .57027 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .57027 L
.95238 .57027 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59927 L
.2381 .59927 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59927 L
.2381 .59927 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .03254 L
.2381 .03254 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .03254 L
.2381 .03254 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .34646 L
.71429 .34646 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .34646 L
.71429 .34646 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .25093 L
.95238 .25093 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .25093 L
.95238 .25093 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF0000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FFFF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF80000000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF80000000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FF
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000
FF8000FF8000FF80000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .4689 L
.71429 .4689 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .4689 L
.71429 .4689 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .14914 L
.95238 .14914 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .14914 L
.95238 .14914 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000
FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000
0000FF0000FFFF80000000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .18147 L
.2381 .18147 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .18147 L
.2381 .18147 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0682 L
.71429 .0682 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0682 L
.71429 .0682 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .38025 L
.95238 .38025 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .38025 L
.95238 .38025 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF80000000FFFF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000
0000FF0000FFFF8000FF8000FF0000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000
0000FFFF8000FF8000FF0000FF0000
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
0000FFFF80000000FFFF80000000FFFF8000FF80000000FFFF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF0000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF0000FF0000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .46723 L
.2381 .46723 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .46723 L
.2381 .46723 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .14559 L
.71429 .14559 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .14559 L
.71429 .14559 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01647 L
.95238 .01647 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01647 L
.95238 .01647 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF00000000FF
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FF
FF00000000FFFF00000000FF0000FF0000FFFF00000000FFFF00000000FFFF00000000FF
0000FF0000FFFF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF00000000FFFF00000000FF
0000FF0000FFFF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF80000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FF
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .2042 L
.2381 .2042 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .2042 L
.2381 .2042 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .30453 L
.47619 .30453 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .30453 L
.47619 .30453 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .04255 L
.71429 .04255 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .04255 L
.71429 .04255 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09052 L
.95238 .09052 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09052 L
.95238 .09052 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF800000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF800000FF00
FF0000FF0000FF0000FF800000FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF8000
FF800000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF800000FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF0000FF00FF0000FF0000FF8000FF800000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF800000FF00
FF0000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
0000FFFF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF800000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF00FF000000FF00FF0000FF000000FF00
0000FFFF0000FF8000FF800000FF00
FF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
0000FFFF0000FF800000FF00FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF000000FF00
0000FFFF0000FF8000FF800000FF00
FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF8000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00FF0000FF000000FF00
00FF00FF0000FF8000FF800000FF00
FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF8000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00FF0000FF800000FF00
00FF0000FF00FF800000FF0000FF00
FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF0000FF00000000FF
0000FFFF0000FF8000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF8000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00FF0000FF800000FF00
00FF00FF00000000FFFF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF8000FF0000FF00000000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF000000FF00
0000FFFF00000000FFFF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000
00FF0000FF00FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF8000
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FFFF0000FF800000FF00FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF00000000FF0000FF
0000FF0000FFFF800000FF00FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF0000FF00000000FF0000FF
0000FFFF0000FF800000FF00FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF8000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF00000000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00000000FF0000FF
FF0000FF800000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF0000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF8000FF0000FF00000000FF
FF0000FF800000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00FF0000
FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF8000FF0000FF0000FF0000
FF0000FF800000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF8000FF000000FF00FF0000FF800000FF0000FF0000FF00
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00FF0000
FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00
0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF00000000FF0000FF
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF0000FF00000000FFFF0000FF8000FF800000FF00FF000000FF00FF800000FF0000FF00
0000FFFF0000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF00FF8000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF800000FF00FF800000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF0000FF00000000FF
FF00000000FFFF000000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00
FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF000000FF0000FF00
00FF0000FF00FF0000FF8000FF8000FF800000FF0000FF00FF00000000FFFF00000000FF
FF0000FF0000FF000000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF000000FF00FF800000FF00FF800000FF0000FF0000FF00FF0000FF0000FF00000000FF
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF00000000FFFF00000000FF
FF0000FF0000FF000000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF000000FF00FF800000FF00FF800000FF0000FF0000FF00FF0000FF00000000FFFF0000
0000FFFF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF00FF000000FF00FF800000FF0000FF00FF00000000FFFF0000FF0000
FF0000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF
0000FFFF8000FF0000FF00000000FFFF00000000FFFF0000FF0000FF800000FF00FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00
00FF0000FF00FF0000FF000000FF00FF8000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF8000FF0000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF0000FF00000000FF0000FF
FF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF800000FF00FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00
FF800000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF800000FF00FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000
00FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF800000FF00
FF800000FF00FF0000FF0000FF8000FF800000FF0000FF00FF0000FF8000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF00FF800000FF00FF800000FF00FF0000FF0000
FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF0000FF00
00FF0000FF00FF0000FF000000FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00FF0000FF0000
FF0000FF800000FF0000FF00FF0000FF8000FF800000FF00FF00000000FFFF0000FF8000
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF0000FF0000FF0000
FF0000FF800000FF00FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF8000
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF800000FF00FF000000FF000000FFFF0000FF8000
FF0000FF00000000FFFF000000FF0000FF0000FF00FF000000FF00FF800000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF0000FF000000FF00FF800000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF0000FF000000FF00FF800000FF0000FF00
FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF800000FF0000FF00
FF0000FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .39652 L
.2381 .39652 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .39652 L
.2381 .39652 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .05423 L
.47619 .05423 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .05423 L
.47619 .05423 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .13933 L
.71429 .13933 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .13933 L
.71429 .13933 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05173 L
.95238 .05173 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05173 L
.95238 .05173 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF000000FF00FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF800000FF00FF0000
FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FF0000FF
FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF800000FF0000FF00FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF000000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF800000FF00FF0000FF0000FF00000000FFFF00000000FF
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FFFF00000000FF
FF800000FF00FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00000000FF
FF00000000FFFF00000000FFFF0000
FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00000000FFFF00000000FF
FF800000FF00FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000
FF8000FF0000FF0000FF000000FF00FF800000FF00FF0000FF00000000FFFF00000000FF
FF000000FF00FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF800000FF00FF8000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF800000FF00FF8000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF0000FF0000FF000000FF00FF0000FF800000FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF8000
00FF0000FF00FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF800000FF00FF800000FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF800000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF800000FF00FF0000FF0000FF8000FF800000FF0000FF0000FF000000FFFF0000
0000FFFF00000000FFFF0000FF0000
0000FFFF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF800000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF800000FF00FF000000FF00FF800000FF0000FF0000FF00FF00000000FFFF0000
0000FFFF00000000FFFF00000000FF
0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FFFF000000FF00FF0000FF0000FF800000FF0000FF00FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF8000FF0000FF0000FF8000FF0000FF00000000FFFF0000
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000
FF000000FF0000FF0000FF00FF000000FF00FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF00000000FFFF0000FF000000FF00FF0000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF
FF000000FF0000FF0000FF00FF000000FF00FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF8000FF00000000FFFF00000000FFFF000000FF00FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF00000000FFFF0000FF000000FF0000FF00FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF
FF0000FF800000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF00000000FFFF0000FF800000FF00FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF800000FF0000FF00FF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF000000FF00FF0000
FF0000FF800000FF0000FF00FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000
FF0000FF800000FF0000FF00FF00000000FFFF00000000FFFF00000000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000
FF00000000FFFF0000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF00000000FFFF00000000FFFF0000
FF8000FF000000FF00FF0000FF0000FF0000FF800000FF0000FF00FF8000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF00000000FFFF0000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF00000000FFFF00000000FFFF0000
FF8000FF0000FF80000000FFFF0000FF0000FF800000FF0000FF00FF8000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF00000000FFFF00000000FFFF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF00000000FFFF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000
FF800000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF8000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF8000FF000000FF0000FF0000FF00FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF8000
FF800000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF8000FF8000FF8000FF000000FF00FF800000FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FFFF0000FF0000FF8000FF000000FF0000FF0000FF00FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF8000
FF8000FF800000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF00000000FFFF00000000FF
FF000000FF00FF8000FF0000FF00000000FF0000FFFF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF8000
FF8000FF800000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF000000FF00FF8000FF0000FF00000000FFFF00000000FF
FF0000FF800000FF00FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
FF0000FF8000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF8000
FF8000FF800000FF00FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF00000000FFFF00000000FF
FF0000FF800000FF00FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF8000FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF8000
FF8000FF800000FF00FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .07947 L
.2381 .07947 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .07947 L
.2381 .07947 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .26845 L
.47619 .26845 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .26845 L
.47619 .26845 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .28054 L
.95238 .28054 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .28054 L
.95238 .28054 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF00FF0000
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
FF800000FF00FF8000FF0000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF000000FF00FF800000FF00FF0000FF0000FF0000FF8000
00FF00FF800000FF00FF800000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF800000FF00FF0000
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF0000
FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF0000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF00FF800000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF0000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000
FF8000FF800000FF0000FF00FF8000FF8000FF0000FF00000000FFFF0000FF0000FF8000
00FF00FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF00FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF0000FF8000FF8000
FF800000FF00FF8000FF0000FF800000FF00FF8000FF800000FF0000FF00FF0000FF0000
FF8000FF800000FF0000FF00FF800000FF00FF0000FF0000FF0000FF0000FF8000FF8000
00FF00FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF000000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000
FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
00FF00FF800000FF0000FF00FF0000FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF0000FF8000FF8000FF8000
FF800000FF00FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
00FF00FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF800000FF00
FF000000FF00FF800000FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF00FF0000FF0000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000
FF800000FF00FF8000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000
FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00
FF800000FF00FF0000FF8000FF8000
00FF0000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF0000
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF00FF0000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF0000
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF0000FF0000FF0000FF00FF000000FF00FF800000FF00FF800000FF0000FF00
FF0000FF8000FF8000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF0000FF0000FF00FF8000FF000000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF00FF0000
FF0000FF0000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF800000FF00
00FF0000FF0000FF00FF0000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF00FF0000
FF0000FF0000FF000000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF0000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00
FF0000FF0000FF800000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF0000FF0000FF000000FF00FF800000FF00FF0000FF0000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF800000FF00FF8000
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
FF0000FF0000FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF0000FF8000
FF0000FF0000FF000000FF00FF800000FF00FF0000FF0000FF0000FF8000FF8000FF8000
00FF00FF0000FF8000FF800000FF00
00FF00FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF0000FF8000
00FF00FF8000FF800000FF00FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
00FF0000FF0000FF00FF800000FF00
00FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF0000FF800000FF00FF0000FF0000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF8000
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF0000FF8000
FF800000FF00FF0000FF0000FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF0000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF0000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000
FF800000FF00FF0000FF0000FF8000FF800000FF00FF0000FF0000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00FF800000FF00
00FF0000FF00FF8000FF0000FF8000
00FF0000FF0000FF0000FF0000FF00FF0000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF8000FF800000FF00FF0000FF0000FF800000FF00FF8000
00FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00
FF800000FF0000FF00FF800000FF0000FF00FF0000FF800000FF0000FF00FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF800000FF00FF800000FF00
00FF0000FF00FF0000FF0000FF8000
00FF0000FF00FF8000FF800000FF00FF0000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF8000FF800000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF800000FF00FF800000FF00FF0000FF0000FF800000FF00FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF0000
FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF800000FF00FF8000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF00FF8000FF800000FF00FF0000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF0000FF00000000FFFF0000
FF8000FF800000FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF800000FF00FF0000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF800000FF00FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF800000FF00FF800000FF00FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF800000FF0000FF00FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF000000FF00FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF0000FF8000FF800000FF00
FF800000FF00FF800000FF0000FF00FF0000FF800000FF0000FF00FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF0000FF0000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF800000FF00FF0000FF0000FF8000FF800000FF00FF8000FF000000FF00FF8000FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF0000FF0000FF0000FF800000FF00
FF800000FF00FF800000FF0000FF00FF0000FF8000FF800000FF00FF8000FF0000FF0000
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF0000FF0000FF0000
FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000FF000000FF00
FF800000FF00FF0000FF0000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF0000FF0000FF0000FF8000FF8000
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF0000
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF000000FF00
FF8000FF00000000FFFF0000FF8000FF800000FF00FF800000FF00FF0000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF800000FF00FF800000FF00
00FF00FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000FF0000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF800000FF00
FF8000FF00000000FFFF0000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF0000FF0000FF0000
FF8000FF800000FF00FF8000FF800000FF0000FF00FF0000FF0000FF8000FF800000FF00
00FF00FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF00FF8000FF0000FF8000FF8000FF800000FF00
00FF00FF8000FF0000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00FF800000FF00FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF000000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00
FF800000FF00FF0000FF8000FF800000FF00FF0000FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF0000FF800000FF0000FF0000FF00FF800000FF00FF8000
00FF00FF800000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .49935 L
.2381 .49935 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .49935 L
.2381 .49935 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01293 L
.47619 .01293 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01293 L
.47619 .01293 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11764 L
.95238 .11764 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11764 L
.95238 .11764 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF800000FF00
FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02169 L
.2381 .02169 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02169 L
.2381 .02169 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .30599 L
.47619 .30599 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .30599 L
.47619 .30599 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .28722 L
.71429 .28722 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .28722 L
.71429 .28722 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0269 L
.95238 .0269 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0269 L
.95238 .0269 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF00FF0000FF0000FF000000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF0000FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF00FF8000FF0000FF000000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00
FF800000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF00FF8000FF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF0000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF000000FF00FF00FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF00FF800000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .24383 L
.47619 .24383 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .24383 L
.47619 .24383 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .3694 L
.71429 .3694 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .3694 L
.71429 .3694 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF8000FF000000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF800000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .09887 L
.2381 .09887 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .09887 L
.2381 .09887 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .08906 L
.47619 .08906 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .08906 L
.47619 .08906 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .44053 L
.95238 .44053 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .44053 L
.95238 .44053 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF800000FF0000FF0000FF00
0000FF00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF000000FF00FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF8000
FF0000FF0000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF000000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
00FF0000FF00FF0000FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF000000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF000000FF0000FF00FF00FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
00FF0000FF0000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF000000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF00FF0000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF000000FF00
00FF0000FF000000FF00FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF0000FF000000FF0000FF00
00FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF0000FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF000000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF00
00FF0000FF00FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF000000FF00FF00
FF800000FF00FF0000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF000000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF000000FF00FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF00FF0000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF000000FF00FF8000FF8000FF8000FF800000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1Ooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool001oooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Go
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000Ooooo
oaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
7ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolF
o`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo000jo`00OaKoogl01Ol007l00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000j
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo001Eooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00EOooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l00_l007lGool005Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Eoooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00EOooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o
001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo000FoooooaT0o`000P3oP00B0?l00080oh001`3o00020?n0
0100o`0000<0oh000?l0003o0000103o00020?n001T0o`000P3oP0050?l00080oh001`3o00020?n0
00`0o`000P3oP00>ooooob800?l01@000?l?003o00<0003o6000o`000`000?l00?l0003o0006003o
00`0003o2`00o`0@0000o`T00?l03_ooool20000o`T00?l03P000?l4003o00030000o`00o`000?l0
00H00?l06@000?l2003o00030000o`00o`000?l000T00?l00P000?l2003o0280003o00<00?l00000
o`000?l01`00o`0=0000o`kooooo1@3o00020?n000@0o`000P3oP0000`000?l0o`000?l000040?l0
0080oh0000<0o`000?n0003oP000103oP0000`3o0000003o0000o`020?n00080003o0P3o00000`3o
P000o`000?l000020000o`80oh001@3o00020?n00080003o0`3o00020?n000@0003o0`3o00020?n0
00@0o`001@3oP0020000o`80oh000`000?l70?l00080oh000P000?l40?n000030?l0003oP000oh00
00T0o`000P3oP0030?l00080oh001P3o00000`3oP000o`000?l000020?n00080o`000P3oP0050?l0
01Sooooo000FoooooaT0o`000P3oP00B0?l00080oh001`3o00020?n00100o`0000<0oh000?l0003o
0000103o00020?n001T0o`000P3oP0050?l00080oh001`3o00020?n000`0o`000P3oP00>ooooob80
0?l01@000?l?003o00<0003o6000o`000`000?l00?l0003o0006003o00`0003o2`00o`0@0000o`T0
0?l03_ooool20000o`T00?l03P000?l4003o00030000o`00o`000?l000H00?l06@000?l2003o0003
0000o`00o`000?l000T00?l00P000?l2003o0280003o00<00?l00000o`000?l01`00o`0=0000o`ko
oooo1@3o00020?n000@0o`000P3oP0000`000?l0o`000?l000040?l00080oh0000<0o`000?n0003o
P000103oP0000`3o0000003o0000o`020?n00080003o0P3o00000`3oP000o`000?l000020000o`80
oh001@3o00020?n00080003o0`3o00020?n000@0003o0`3o00020?n000@0o`001@3oP0020000o`80
oh000`000?l70?l00080oh000P000?l40?n000030?l0003oP000oh0000T0o`000P3oP0030?l00080
oh001P3o00000`3oP000o`000?l000020?n00080o`000P3oP0050?l001Sooooo000Fooooo`80o`00
0P3oP00P0?l00080003o1`3o00020?n000L0o`000P3oP0090?l000030?n0003o0000o`0000@0o`00
00<0oh000?l0003o00003`3o00000`3oP000o`000?l0000=0?l00080oh001@3o00020?n000D0o`00
0P3oP0090?l00080oh001@3o000>ooooob000?l02@000?l?003o00<0003o7`00o`0:0000o`l00?l0
1@000?l4003o00T0003o00<00?l00000o`000?l00P00o`0>ooooo`d00?l030000?l;003o0180003o
2`00o`070000o`L00?l00P000?l>003o02/0003o3_ooool50?l00080oh001P3o00000`3oP000o`00
0?l000040?l00080oh0000<0o`000?n0003oP0000P3oP0070000o`80oh000P000?l50?l00080oh00
1@3o00020?n00080o`002@3oP0030?l00080oh00103o00000`3oP000o`000?l000020?l000@0oh00
0`3o00020?n000D0o`00203oP0000`3o0000oh000?n000020?l00080003o1@3o00020?n000<0o`00
0P3oP0060?l000030?n0003o0000o`0000@0oh001`3o000Hooooo`005_ooool20?l00080oh00803o
00020000o`L0o`000P3oP0070?l00080oh002@3o00000`3oP000o`000?l000040?l000030?n0003o
0000o`0000l0o`0000<0oh000?l0003o00003@3o00020?n000D0o`000P3oP0050?l00080oh002@3o
00020?n000D0o`003_oooolP003o00T0003o3`00o`030000oal00?l02P000?l?003o00D0003o1000
o`090000o`03003o00000?l0003o00800?l03_ooool=003o00`0003o2`00o`0B0000o`/00?l01`00
0?l7003o0080003o3P00o`0[0000o`kooooo1@3o00020?n000H0o`0000<0oh000?l0003o0000103o
00020?n000030?l0003oP000oh000080oh001`000?l20?n00080003o1@3o00020?n000D0o`000P3o
P0020?l000T0oh000`3o00020?n000@0o`0000<0oh000?l0003o00000P3o00040?n000<0o`000P3o
P0050?l000P0oh0000<0o`000?n0003oP0000P3o00020000o`D0o`000P3oP0030?l00080oh001P3o
00000`3oP000o`000?l000040?n000L0o`006?ooool001Kooooo0P3o00020?n000`0o`000P3oP005
0?l00080oh007@3o00020?n00140o`000P3oP00?0?l000030?n0003o0000o`0000@0o`000P3oP00>
0?l00080oh004P3o00000`3oP000003o0000o`020?n000kooooo0P00o`020000oc@00?l00`000?lO
003o00X0003o3`00o`030000o`800?l040000?l2003o00kooooo3@00o`0<0000o`/00?l050000?l7
003o01L0003o2`00o`0I0000o`D0o`000P3oP0020000o`<00?l00P000?l2003o00kooooo103o0007
0000o`<0o`000P3oP0040?l00080oh0000<0o`000?n0003oP00010000?l30?l00080oh0010000?l0
0`3oP000o`000?l000020000o`80oh001`3o00020?n000<0o`00103oP0020?l00080003o00<0oh00
0?l0003o0000103o00000`3oP000003o0000o`020?n00080o`000P3oP0000`000?l0oh000?n00002
0000o`D0o`00203oP0000`3o0000oh000?n000020?l00080oh001@3o00020?n000<0o`000P3oP006
0?l000030?n0003o0000o`000080o`000P3oP0020?l000<0oh000P3o000Hooooo`005_ooool@0?l0
0080oh00403o00020?n000T0o`000P000?l90?l000030000o`3o0000o`0000H0o`0000<0oh000?l0
003o0000103o00000`3oP000o`000?l000090?l00080oh001@3o00020?n000/0o`000P3oP0070?l0
0080oh0000<0003o0?l0003o0000103o00020000o`030?n0003o0000o`0000L0o`000P000?l20?l0
00kooooo0P000?lR003o0080003o=000o`000`000?l00?l0003o0006003o00030000o`00o`000?l0
00/00?l00`000?l4003o00D0003o0P3oP0070000o`@00?l03_ooool20000o`L00?l00P000?l2003o
00L0003o0P3o00000`3oP000003o0000o`020000o`D00?l02@000?l4003o00/0003o2@00o`000`00
0?l00?l0003o000B0000o`/00?l00P000?l3003o0080003o1000o`070000o`030?n000000?l0003o
0080003o103o00000`3oP000o`000?l000020?l000@0003o00<00?l00000o`000?l00P000?l>oooo
o`@0o`0000<0003o003o0000o`000P000?l70?l000@0oh000`3o00040?n00080003o1@3oP0040?l0
00030?n0003o0000o`0000@0o`000P3oP0090?l000030?n000000?l0003o00H0003o0`3o00050?n0
00H0003o0P3oP0050000o`D0o`000P3oP0020?l000D0oh001P3o00030?n00080o`000P3oP0020000
o`T0o`0000<0oh000?l0003o00001`3o00040?n001Sooooo000Foooooa00o`000P3oP00@0?l00080
oh002@3o00020000o`T0o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l000040?l00003
0?n0003o0000o`0000T0o`000P3oP0050?l00080oh002`3o00020?n000L0o`000P3oP0000`000?l0
o`000?l000040?l00080003o00<0oh000?l0003o00001`3o00020000o`80o`003_ooool20000ob80
0?l00P000?ld003o00030000o`00o`000?l000H00?l000<0003o003o0000o`002`00o`030000o`@0
0?l01@000?l20?n000L0003o1000o`0>ooooo`80003o1`00o`020000o`800?l01`000?l20?l00003
0?n000000?l0003o0080003o1@00o`090000o`@00?l02`000?l9003o00030000o`00o`000?l00180
003o2`00o`020000o`<00?l00P000?l4003o00L0003o00<0oh000000o`000?l00P000?l40?l00003
0?n0003o0000o`000080o`0010000?l00`00o`00003o0000o`020000o`kooooo103o00000`000?l0
0?l0003o00020000o`L0o`00103oP0030?l000@0oh000P000?l50?n000@0o`0000<0oh000?l0003o
0000103o00020?n000T0o`0000<0oh000000o`000?l01P000?l30?l000D0oh001P000?l20?n000D0
003o1@3o00020?n00080o`001@3oP0060?l000<0oh000P3o00020?n00080003o2@3o00000`3oP000
o`000?l000070?l000@0oh006?ooool001Kooooo2@3o00020?n000D0o`000P3oP0070?l00080oh00
1`3o00020?n000L0o`000P3oP00^0?l00080oh001P3o00000`3oP000o`000?l000020?l00080oh00
0`3o00040?n00080003o0`3o00020?n00080o`000`000?l90?l000@0003o3_ooool40000og@00?l0
3@000?l5003o00kooooo0P000?l<003o00P0003o00<0oh000000o`000?l010000?l3003o00T0003o
0P00o`0=0000o`T00?l01@000?l20?l000030000o`3oP000oh0000L0003o0P3oP0060000o`L00?l0
1`000?l4003o0100003o0`3o000;0000o`kooooo2`3o00020?n000D0o`000P3oP0020?l000030?n0
00000?l0003o0080oh001@000?l20?n000@0003o00<0oh000?l0003o00000P3o00020?n00080o`00
0`3oP0040?l000<0oh000P3o00020?n00080o`000P3oP0030?l00080oh001@3o00040000o`D0oh00
1`3o00020?n00080o`001@3oP0060?l000D0oh0010000?l70?l000L0oh001@3o00040?n001Sooooo
000Fooooo`T0o`000P3oP0050?l00080oh001`3o00020?n000L0o`000P3oP0070?l00080oh00;P3o
00020?n000H0o`0000<0oh000?l0003o00000P3o00020?n000<0o`00103oP0020000o`<0o`000P3o
P0020?l000<0003o2@3o00040000o`kooooo10000?md003o00d0003o1@00o`0>ooooo`80003o3000
o`080000o`030?n000000?l0003o00@0003o0`00o`090000o`800?l03@000?l9003o00D0003o0P3o
00000`000?l0oh000?n000070000o`80oh001P000?l7003o00L0003o1000o`0@0000o`<0o`002`00
0?l>ooooo`/0o`000P3oP0050?l00080oh000P3o00000`3oP000003o0000o`020?n000D0003o0P3o
P0040000o`030?n0003o0000o`000080o`000P3oP0020?l000<0oh00103o00030?n00080o`000P3o
P0020?l00080oh000`3o00020?n000D0o`0010000?l50?n000L0o`000P3oP0020?l000D0oh001P3o
00050?n000@0003o1`3o00070?n000D0o`00103oP00Hooooo`005_ooool70?l00080oh006@3o0002
0?n000L0o`000P3oP0070?l000@0oh00703o00020?n000D0o`000P3oP0060?l000030?n0003o0000
o`0000T0o`000P3oP0050?l000@0oh000P000?l:0?l000@0003o3_oooomD003o0080003o4P00o`02
0000o`h00?l03P000?l4003o00kooooo4000o`0X0000o`T00?l01@000?l20?n000D0003o103o000C
0000o`H00?l02@000?l7003o00D0003o0P3oP0090000o`kooooo0P3o00020?n000030000o`3o0000
o`000080o`000P3oP0050?l000@0oh001@3o00070?n000L0o`000P3oP0020?l00080oh000`3o0004
0?n000/0o`000`3oP0060?l000030?n0003o0000o`0000/0o`001`3oP0020000o`80o`000`3oP002
0000o`H0o`000`3oP0020000o`T0o`000`3oP0060?l00080oh000`3o00020?n001Sooooo000Foooo
o`L0o`000P3oP00I0?l00080oh001`3o00020?n000L0o`00103oP00L0?l00080oh001@3o00020?n0
00H0o`0000<0oh000?l0003o00002@3o00020?n000D0o`00103oP0020000o`X0o`0010000?l>oooo
oe@00?l00P000?lB003o0080003o3P00o`0>0000o`@00?l03_ooool@003o02P0003o2@00o`050000
o`80oh001@000?l40?l001<0003o1P00o`090000o`L00?l01@000?l20?n000T0003o3_ooool20?l0
0080oh0000<0003o0?l0003o00000P3o00020?n000D0o`00103oP0050?l000L0oh001`3o00020?n0
0080o`000P3oP0030?l000@0oh002`3o00030?n000H0o`0000<0oh000?l0003o00002`3o00070?n0
0080003o0P3o00030?n00080003o1P3o00030?n00080003o2@3o00030?n000H0o`000P3oP0030?l0
0080oh006?ooool001Kooooo1`3o00020?n000D0o`000P3oP00;0?l00080oh001@3o00020?n000L0
o`00103oP0070?l00080oh008`3o00020?n000L0o`000P3oP0090?l00080oh001`3o00020000o`L0
o`000P3oP0030000o`80oh000P3o000>ooooog`00?l000<0003o003o0000o`001P00o`030000o`80
0?l03_ooool>003o00P0003o00<0oh000000o`000?l04P000?l7003o01/0003o0P3o00020000o`03
0?n000000?l0003o01l0003o2P00o`080000o`D00?l03_ooool20?l00080oh001@3o00050?n000@0
o`000P3oP0030?l00080003o0P3oP0020000o`D0o`000P3oP0050?l000@0oh000P3o00030?n000/0
o`00103oP0070?l000<0oh000P000?l20?n000L0o`00103oP0000`000?l0o`000?l000040?l000<0
oh000P000?l20?l00080oh000P3o00030?n00080003o1@3o00020?n00080o`000P3oP0030000o`@0
o`000P3oP0030?l00080oh006?ooool001Kooooo0P3o00020?n000`0o`000P3oP0050?l00080oh00
1`3o00020?n001@0o`000P3oP00G0?l00080oh001`3o00020000o`X0o`000P3oP0040?l00080oh00
5`3o00030000o`@0o`003_oooon6003o0080003o0P00o`0>ooooo`/00?l00P000?l:003o0080003o
0P00o`0E0000o`@00?l05`000?l60?l000<0oh007`000?l3003o00/0003o0P00o`070000o`kooooo
0P3o00020?n000D0o`000P3oP0020?l000030?n0003o0000o`000080o`00103oP0000`3o0000003o
0000o`020?n00080003o1@3o00020?n000D0o`001P3oP0000`000?l0oh000?n000020000o`80oh00
1`3o00040?n000<0o`000P3oP0030?l00080oh001`3o00090?n000@0o`00103oP0070000o`80oh00
00<0o`000000o`000?l00P3oP0090?l00080003o00<0oh000000o`000?l00P3oP0020?l00080003o
1@3o000Hooooo`005_ooool20?l00080oh00303o00020?n000D0o`000P3oP0070?l00080oh00503o
00020?n001L0o`000P3oP0070?l00080003o2P3o00020?n000@0o`000P3oP00G0?l000<0003o103o
000>ooooohH00?l00P000?l2003o00kooooo2`00o`020000o`X00?l00P000?l2003o01D0003o1000
o`0G0000o`H0o`000`3oP00O0000o`<00?l02`000?l2003o00L0003o3_ooool20?l00080oh001@3o
00020?n00080o`0000<0oh000?l0003o00000P3o00040?n000030?l000000?l0003o0080oh000P00
0?l50?l00080oh001@3o00060?n000030000o`3oP000oh000080003o0P3oP0070?l000@0oh000`3o
00020?n000<0o`000P3oP0070?l000T0oh00103o00040?n000L0003o0P3oP0000`3o0000003o0000
o`020?n000T0o`000P000?l00`3oP000003o0000o`020?n00080o`000P000?l50?l001Sooooo000F
oooooaT0o`000P3oP0070?l00080oh001@3o00020?n000D0o`000P3oP00X0?l000030?n0003o0000
o`0000d0o`000P3oP0050?l00080oh001`3o00020000o`T0o`0000<0oh000?l0003o00000P3o000>
ooooodl00?l00`000?l_003o0080003o0`00o`020000o`800?l03_ooool9003o0100003o0P00o`07
0000o`800?l0:@000?l50?l000d0003o1000o`0@0000o`L00?l00P000?l00`00o`00003o0000o`02
0000o`800?l00`000?l4003o00kooooo103oP0050?l000D0oh000P000?l20?n000@0o`0000<0oh00
0000o`000?l00P3oP0020000o`D0o`000P3oP0070?l00080oh000`3o00020?n00080003o2@3o0002
0?n000T0o`000`3oP0020?l00080oh001@3o00060?n000030000o`3oP000oh000080oh000P3o0002
0?n000030000o`3oP000oh000080003o1@3o00060?n000<0o`000P3oP0050000o`800?l010000?l5
0?l00080oh006?ooool001Kooooo6@3o00020?n000L0o`000P3oP0050?l00080oh001@3o00020?n0
02P0o`0000<0oh000?l0003o00003@3o00020?n000D0o`000P3oP0070?l00080003o2@3o00000`3o
P000o`000?l000020?l000koooooC`00o`030000obl00?l00P000?l3003o0080003o0P00o`0>oooo
o`T00?l040000?l2003o00L0003o0P00o`0Y0000o`D0o`003@000?l4003o0100003o1`00o`020000
o`03003o00000?l0003o0080003o0P00o`030000o`@00?l03_ooool40?n000D0o`001@3oP0020000
o`80oh00103o00000`3oP000003o0000o`020?n00080003o1@3o00020?n000L0o`000P3oP0030?l0
0080oh000P000?l90?l00080oh002@3o00030?n00080o`000P3oP0050?l000H0oh0000<0003o0?n0
003oP0000P3oP0020?l00080oh0000<0003o0?n0003oP0000P000?l50?l000H0oh000`3o00020?n0
00D0003o0P00o`040000o`D0o`000P3oP00Hooooo`005_ooool90?l00080oh001@3o00020?n000L0
o`000P3oP0070?l00080oh003P3o00020?n00080o`000P3oP00A0?l00080oh001P3o00030000o`80
oh001@3o00020?n000T0o`000P3oP00B0?l00080003o2@3o00000`3oP000o`000?l000020?l000ko
ooooB`00o`090000obd00?l00P000?l2003o00030000o`00o`000?l000800?l03_ooool20000o`L0
0?l01`000?l;003o00L0003o0P00o`0T0000o`03003o00000?l0003o0080003o103o00030?n001H0
003o0P00o`080000o`800?l01`000?l9003o0080003o0P00o`0>ooooo`D0o`000P3oP0020000o`@0
oh000`000?l60?l000030?n000000?l0003o0080oh000P000?l30?l000H0oh000`3o00040?n000<0
o`000P3oP0020000o`L0o`00103oP0030?l00080oh000P000?l50?l00080oh000P3o00070?n00080
003o2@3o00020?n000030000o`3oP000oh000080oh000P000?l30?l000@0oh000P000?l30?n000@0
o`003P000?l20?l001Sooooo000Fooooo`T0o`000P3oP0050?l00080oh001`3o00020?n000L0o`00
0P3oP00>0?l00080oh000P3o00020?n00140o`000P3oP0060?l000<0003o0P3oP0050?l00080oh00
2@3o00020?n00180o`000P000?l90?l000030?n0003o0000o`000080o`003_oooom;003o00T0003o
;@00o`020000o`800?l000<0003o003o0000o`000P00o`0>ooooo`80003o1`00o`070000o`/00?l0
1`000?l2003o02@0003o00<00?l00000o`000?l00P000?l40?l000<0oh005P000?l2003o00P0003o
0P00o`070000o`T00?l00P000?l2003o00kooooo1@3o00020?n00080003o103oP0030000o`H0o`00
00<0oh000000o`000?l00P3oP0020000o`<0o`001P3oP0030?l000@0oh000`3o00020?n00080003o
1`3o00040?n000<0o`000P3oP0020000o`D0o`000P3oP0020?l000L0oh000P000?l90?l00080oh00
00<0003o0?n0003oP0000P3oP0020000o`<0o`00103oP0020000o`<0oh00103o000>0000o`80o`00
6?ooool001Kooooo1`3o00020?n000@0o`0000<0oh000000o`000?l00P000?l70?l00080oh00C@3o
00020?n000<0o`000P3oP0050?l00080oh001P000?l90?l000030000o`3o0000o`000080o`003_oo
oolm003o0080003o0P00o`000`000?l00?l0003o0007003o00d0003o8000o`020000o`800?l03P00
0?l>ooooo`80003o0P00o`030000oa@00?l01`000?l5003o00d0003o1000o`000`000?l00?l0003o
00020000o`@00?l01`000?l5003o00/0003o0P00o`000`000?l00?l0003o0004003o00T0003o1@00
o`020000o`T00?l00P000?l:003o00@0003o3_ooool50?l00080oh0010000?l20?n000<0003o1P3o
00000`3oP000003o0000o`020000o`80o`000`3oP0020000o`80oh000`3o00020?n00080o`00103o
P0000`3o0000oh000?n000070?l00080oh00103o00020?n000030000o`3oP000oh0000D0o`00103o
P0040?l000<0oh00103o00070?n000D0003o0P3oP0040000o`<0o`00103oP0020000o`D0o`000P3o
P0070000o`80oh001`000?lHooooo`005_ooool70?l00080oh00103o00000`3oP000003o0000o`02
0000o`L0o`000P3oP01=0?l00080oh000`3o00020?n000D0o`000P3oP0060000o`T0o`0000<0003o
0?l0003o00000P3o000>ooooocd00?l00P000?l2003o00030000o`00o`000?l000L00?l03@000?lP
003o0080003o0P00o`0>0000o`kooooo0P000?l2003o00<0003o5000o`070000o`D00?l03@000?l4
003o00030000o`00o`000?l00080003o1000o`070000o`D00?l02`000?l2003o00030000o`00o`00
0?l000@00?l02@000?l5003o0080003o2@00o`020000o`X00?l010000?l>ooooo`D0o`000P3oP004
0000o`80oh000`000?l60?l000030?n000000?l0003o0080003o0P3o00030?n00080003o0P3oP003
0?l00080oh000P3o00040?n000030?l0003oP000oh0000L0o`000P3oP0040?l00080oh0000<0003o
0?n0003oP0001@3o00040?n000@0o`000`3oP0040?l000L0oh001@000?l20?n000@0003o0`3o0004
0?n00080003o1@3o00020?n000L0003o0P3oP0070000oaSooooo000Fooooo`L0o`000P3oP0050?l0
0080oh002@3o00020?n000T0o`000P3oP0050?l00080003o2@3o00020?n000L0o`000P3oP00<0?l0
0080003o503o00000`3oP000o`000?l000020?l00080oh001@3o00020?n000D0o`000P3oP0020000
o`L0o`0010000?l00`3oP000o`000?l000020?l000kooooo9000o`030000oa@00?l01`000?l;003o
00L0003o0P00o`020000obT00?l02@000?l>ooooo`800?l02@000?l9003o00L0003o0P00o`030000
o`L00?l04P000?l8003o00X0003o0P00o`090000o`d00?l00`000?l6003o00<0003o2`00o`030000
o`T00?l010000?l>ooooo`D0o`000P3oP0040000o`80oh000`000?l60?l000030?n000000?l0003o
0080003o0P3o00000`000?l0oh000?n000040?n000<0o`000P3oP0060?l000<0oh000P3o00090?n0
0080003o0P3o00000`3oP000003o0000o`020?n000L0o`000P3oP0090?l00080oh0000<0003o0?l0
003o0000103o00020?n000030?l000000?l0003o0080oh001`3o00020?n000<0003o0P3oP0020?l0
0080oh000P000?l00`3oP000003o0000o`070000o`@0o`006?ooool001Kooooo1`3o00020?n000D0
o`000P3oP0070?l00080oh001@3o00020?n00080o`001@000?l40?l00080003o0P3oP00@0?l00080
oh001@3o00020?n000L0o`000P3oP0050?l00080oh001@3o00020?n000@0o`0000<0oh000?l0003o
00002@3o00020?n000L0o`000P3oP0070?l00080oh000P000?l50?l000kooooo?`00o`070000o`L0
0?l010000?l5003o0080003o0P00o`000`000?l00?l0003o000V003o00L0003o3_ooool9003o0080
003o0`00o`0D0000o`D00?l04P000?l9003o00H0003o00<00?l00000o`000?l00P00o`070000oa@0
0?l00P000?l2003o00D0003o0`00o`020000o`H00?l01@000?l4003o00D0003o3_ooool40?l00003
0000o`3oP000oh000080oh000P000?l20?n000030000o`3o0000o`0000H0o`0000<0oh000000o`00
0?l00P3oP0030000o`80oh000P000?l40?l000030000o`3oP000oh0000L0o`000P3oP0020?l00080
oh001@3o00040?n00080003o00<0oh000?l0003o00002@3o00040?n000030000o`3oP000oh0000L0
oh000P3o00020?n00080003o0P3oP0030?l00080oh001`3o00040?n000030000o`3oP000oh000080
o`00103oP0000`00o`00003o0000o`070?l000@0oh006?ooool001Kooooo1`3o00020?n000D0o`00
0P3oP0070?l00080oh001@3o00020?n00080o`001@000?l40?l00080003o0P3oP00@0?l00080oh00
1@3o00020?n000L0o`000P3oP0050?l00080oh001@3o00020?n000@0o`0000<0oh000?l0003o0000
2@3o00020?n000L0o`000P3oP0070?l00080oh000P000?l50?l000kooooo?`00o`070000o`L00?l0
10000?l5003o0080003o0P00o`000`000?l00?l0003o000V003o00L0003o3_ooool9003o0080003o
0`00o`0D0000o`D00?l04P000?l9003o00H0003o00<00?l00000o`000?l00P00o`070000oa@00?l0
0P000?l2003o00D0003o0`00o`020000o`H00?l01@000?l4003o00D0003o3_ooool40?l000030000
o`3oP000oh000080oh000P000?l20?n000030000o`3o0000o`0000H0o`0000<0oh000000o`000?l0
0P3oP0030000o`80oh000P000?l40?l000030000o`3oP000oh0000L0o`000P3oP0020?l00080oh00
1@3o00040?n00080003o00<0oh000?l0003o00002@3o00040?n000030000o`3oP000oh0000L0oh00
0P3o00020?n00080003o0P3oP0030?l00080oh001`3o00040?n000030000o`3oP000oh000080o`00
103oP0000`00o`00003o0000o`070?l000@0oh006?ooool001Kooooo0P000?lP0?l00080oh001@3o
00020?n001@0o`000P3oP00i0?l00080oh001@3o00020?n00080003o1@3o000>ooooog400?l00P00
0?l@003o00L0003o3_ooool40000o`D00?l010000?l00`00o`00003o0000o`0;0000o`/00?l04P00
0?l:003o00H0003o00<00?l00000o`000?l02`000?l4003o00<0003o2@00o`040000o`800?l00`00
0?l4003o00T0003o00<00?l00000o`000?l01P00o`050000o`kooooo0P000?l50?l00080oh000P3o
00020?n000030000o`3o0000o`000080o`000P3oP0020?l000030?n000000?l0003o0080oh000P00
0?l90?l000<0oh001`3o00020?n000@0o`000P3oP0030?l00080oh00103o00000`3oP000003o0000
o`020?n000L0o`001@3oP0040?l000L0oh002`3o00020?n000D0o`00103oP0000`3o0000oh000?n0
00020?l00080oh000`000?l80?l000030?n0003o0000o`000080oh006?ooool001Kooooo0P000?lP
0?l00080oh001@3o00020?n001@0o`000P3oP00i0?l00080oh001@3o00020?n00080003o1@3o000>
ooooog400?l00P000?l@003o00L0003o3_ooool40000o`D00?l010000?l00`00o`00003o0000o`0;
0000o`/00?l04P000?l:003o00H0003o00<00?l00000o`000?l02`000?l4003o00<0003o2@00o`04
0000o`800?l00`000?l4003o00T0003o00<00?l00000o`000?l01P00o`050000o`kooooo0P000?l5
0?l00080oh000P3o00020?n000030000o`3o0000o`000080o`000P3oP0020?l000030?n000000?l0
003o0080oh000P000?l90?l000<0oh001`3o00020?n000@0o`000P3oP0030?l00080oh00103o0000
0`3oP000003o0000o`020?n000L0o`001@3oP0040?l000L0oh002`3o00020?n000D0o`00103oP000
0`3o0000oh000?n000020?l00080oh000`000?l80?l000030?n0003o0000o`000080oh006?ooool0
01Kooooo103o00000`000?l0o`000?l0000K0?l00080oh00303o00020000obl0o`000P3oP0030?l0
0080oh008P3o000>oooooa/00?l00P000?l00`00o`00003o0000o`0M003o0080003o3P00o`020000
o`/00?l00`000?lR003o00H0003o00<00?l00000o`000?l00P00o`0>ooooo`D0003o0P00o`0@0000
o`l00?l04`000?l9003o00T0003o0P00o`0>0000o`H00?l02@000?l2003o00P0003o0P00o`060000
o`03003o00000?l0003o00/0003o3_ooool20000o`D0o`000P3oP0020000o`80oh002@3o00030?n0
00D0003o0P3oP0020?l00080oh000P3o00000`3oP000003o0000o`020000o`@0o`001@3oP0070?l0
00@0oh000P000?l00`3oP000o`000?l000040?l000030?n0003o0000o`000080o`00103oP0000`3o
0000oh000?n000070?n00080o`000P3oP0090?l00080oh001@3o00040?n000D0o`000P3oP0030000
o`P0o`001@3oP00Hooooo`005_ooool40?l000030000o`3o0000o`0001/0o`000P3oP00<0?l00080
003o;`3o00020?n000<0o`000P3oP00R0?l000kooooo6`00o`020000o`03003o00000?l0003o01d0
0?l00P000?l>003o0080003o2`00o`030000ob800?l01P000?l00`00o`00003o0000o`02003o00ko
oooo1@000?l2003o0100003o3`00o`0C0000o`T00?l02@000?l2003o00h0003o1P00o`090000o`80
0?l020000?l2003o00H0003o00<00?l00000o`000?l02`000?l>ooooo`80003o1@3o00020?n00080
003o0P3oP0090?l000<0oh001@000?l20?n00080o`000P3oP0020?l000030?n000000?l0003o0080
003o103o00050?n000L0o`00103oP0020000o`030?n0003o0000o`0000@0o`0000<0oh000?l0003o
00000P3o00040?n000030?l0003oP000oh0000L0oh000P3o00020?n000T0o`000P3oP0050?l000@0
oh001@3o00020?n000<0003o203o00050?n001Sooooo000Fooooob80o`00103oP0050?l00080oh00
3P3o00020?n000D0o`000P3oP00G0?l00080oh00103o00020?n000<0o`000P3oP00B0?l00080oh00
2@3o00000`3oP000o`000?l000020?l000kooooo?@00o`020000o`800?l000<0003o003o0000o`00
1`00o`060000obL00?l00P000?l3003o0080003o0P00o`020000o`L00?l03_ooool50000o`800?l0
3`000?l:003o0080003o1000o`0>0000o`D00?l00P000?l6003o00L0003o00<00?l00000o`000?l0
4P000?l4003o0100003o3000o`0;0000o`800?l03_ooool20000o`D0o`001P3oP0030000o`80o`00
0P3oP0030?l00080oh001@3o00080?n000030000o`3oP000oh0000L0o`00103oP0070?l000@0oh00
0`000?l40?l00080oh000`000?l20?n000L0003o0P3o00020?n00080003o00<0oh000000o`000?l0
1P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`0000@0oh001@3o00020?n00080o`00
00<0oh000?l0003o00001P3o00000`3oP000o`000?l000020000oaSooooo000Fooooob80o`00103o
P0050?l00080oh003P3o00020?n000D0o`000P3oP00G0?l00080oh00103o00020?n000<0o`000P3o
P00B0?l00080oh002@3o00000`3oP000o`000?l000020?l000kooooo?@00o`020000o`800?l000<0
003o003o0000o`001`00o`060000obL00?l00P000?l3003o0080003o0P00o`020000o`L00?l03_oo
ool50000o`800?l03`000?l:003o0080003o1000o`0>0000o`D00?l00P000?l6003o00L0003o00<0
0?l00000o`000?l04P000?l4003o0100003o3000o`0;0000o`800?l03_ooool20000o`D0o`001P3o
P0030000o`80o`000P3oP0030?l00080oh001@3o00080?n000030000o`3oP000oh0000L0o`00103o
P0070?l000@0oh000`000?l40?l00080oh000`000?l20?n000L0003o0P3o00020?n00080003o00<0
oh000000o`000?l01P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`0000@0oh001@3o
00020?n00080o`0000<0oh000?l0003o00001P3o00000`3oP000o`000?l000020000oaSooooo000F
ooooo`L0o`000P3oP0050?l00080oh004P3o00020?n000L0o`000P3oP0070?l00080oh001@3o0002
0?n001h0o`000P3oP0060?l000030?n0003o0000o`0002@0o`003_oooolm003o0080003o4000o`03
0000o`H00?l00P000?l00`00o`00003o0000o`020000o`800?l00`000?l2003o00@0003o0P00o`00
0`000?l00?l0003o0009003o0080003o4000o`0>ooooo`D0003o0P00o`0@0000oa000?l02`000?l2
003o00@0003o00<00?l00000o`000?l03@000?l3003o00@0003o0P00o`090000o`L00?l05@000?l7
003o00T0003o1000o`0>ooooo`800?l00P000?l00`3o0000003o0000o`020?n00080003o0`3oP002
0000o`L0o`00103oP0030?l000@0oh000P3o00020?n000<0003o0P3o00070?n000L0o`001P3oP002
0000o`03003o00000?l0003o00L0003o1`3o00020000o`80oh00103o00000`000?l0oh000?n00004
0?l00080oh000`3o00040?n000<0o`000P3oP0040000o`D0o`00103oP0030000o`H0o`0000<0oh00
0?l0003o00000P3oP00Hooooo`005_ooool@0?l00080oh00303o00020?n00080o`0010000?l>0?l0
0080oh00403o00020?n001/0o`0000<0oh000?l0003o00000P3o00020?n000<0o`000P3oP0050?l0
0080oh00503o000>ooooocH00?l00`000?l9003o0080003o2`00o`020000o`X00?l00P000?l9003o
00@0003o8000o`0>ooooo`800?l01`000?l20?l000/0003o1@00o`020000o`<00?l00P000?l2003o
00L0003o103oP0090000o`03003o00000?l0003o01d0003o1`00o`0;0000o`D00?l05`000?l2003o
0080003o3_ooool40000o`D0o`000P3oP0050?l00080oh001@3o00020?n000D0o`000P3oP0040000
o`80oh000`000?l60?l000<0oh00103o00020?n000D0o`000P3oP002003o00<0003o1@3o00020?n0
00H0o`0000<0oh000000o`000?l0103oP0070000o`L0o`001P3oP0000`3o0000oh000?n000040?n0
00<0o`000P3oP0040?l000030?n000000?l0003o00L0003o0P3oP0020000oaSooooo000Foooooa00
o`000P3oP00<0?l00080oh000P3o00040000o`h0o`000P3oP00@0?l00080oh006`3o00000`3oP000
o`000?l000020?l00080oh000`3o00020?n000D0o`000P3oP00D0?l000kooooo=P00o`030000o`T0
0?l00P000?l;003o0080003o2P00o`020000o`T00?l010000?lP003o00kooooo0P00o`070000o`80
o`002`000?l5003o0080003o0`00o`020000o`800?l01`000?l40?n000T0003o00<00?l00000o`00
0?l07@000?l7003o00/0003o1@00o`0G0000o`800?l00P000?l>ooooo`@0003o1@3o00020?n000D0
o`000P3oP0050?l00080oh001@3o00020?n000@0003o0P3oP0030000o`H0o`000`3oP0040?l00080
oh001@3o00020?n000800?l00`000?l50?l00080oh001P3o00000`3oP000003o0000o`040?n000L0
003o1`3o00060?n000030?l0003oP000oh0000@0oh000`3o00020?n000@0o`0000<0oh000000o`00
0?l01`000?l20?n00080003o6?ooool001Kooooo1`3o00020?n000T0o`000P3oP00<0?l00080oh00
2@3o00020?n001/0o`0000<0oh000?l0003o0000103o00020?n00180o`0000<0oh000?l0003o0000
0P3o00020?n000h0o`000P3oP0050?l00080oh001@3o00020?n00080o`003_oooolm003o00L0003o
5`00o`040000o`L00?l01`000?lM003o00kooooo0P00o`020000o`<00?l02@000?l=003o00h0003o
0P3o000;0000o`03003o00000?l0003o01H0003o0`00o`020000o`800?l00P000?l5003o02H0003o
0`00o`020000o`kooooo1@000?l40?l00080oh000`3o00040?n000@0o`000`3oP0050?l000@0oh00
0P000?l20?n000030?l0003oP000oh000080003o1@3o00060?n000D0o`00103oP0020000o`L0o`00
1@3oP0040?l000D0003o0P3oP0050000o`/0o`00103oP0050?l00080oh004`000?l20?n00080o`00
6?ooool001Kooooo1`3o00020?n000T0o`000P3oP00<0?l00080oh002@3o00020?n001/0o`0000<0
oh000?l0003o0000103o00020?n00180o`0000<0oh000?l0003o00000P3o00020?n000h0o`000P3o
P0050?l00080oh001@3o00020?n00080o`003_oooolm003o00L0003o5`00o`040000o`L00?l01`00
0?lM003o00kooooo0P00o`020000o`<00?l02@000?l=003o00h0003o0P3o000;0000o`03003o0000
0?l0003o01H0003o0`00o`020000o`800?l00P000?l5003o02H0003o0`00o`020000o`kooooo1@00
0?l40?l00080oh000`3o00040?n000@0o`000`3oP0050?l000@0oh000P000?l20?n000030?l0003o
P000oh000080003o1@3o00060?n000D0o`00103oP0020000o`L0o`001@3oP0040?l000D0003o0P3o
P0050000o`/0o`00103oP0050?l00080oh004`000?l20?n00080o`006?ooool001Kooooo1@3o0002
0?n000L0o`000P3oP0090?l00080oh003P3o00020?n001d0o`0000<0oh000?l0003o00001P3o0000
0`3oP000o`000?l000040?l00080oh002@3o00000`3oP000o`000?l0000B0?l000@0oh001@3o0002
0?n000D0o`000P000?l>oooooe/00?l010000?l7003o00L0003o7@00o`0>ooooo`/00?l00`000?l=
003o0100003o0P3o00050000o`@00?l070000?l2003o00@0003o2@00o`070000o`h00?l01P000?l0
0`00o`00003o0000o`060000o`<00?l00P000?l>ooooo`80003o0P00o`000`000?l0oh000?n00002
0?l000@0oh001`3o00020?n000D0003o0`3o00020?n00080o`00103oP0030?l000@0oh000`3o0004
0?n00080003o1@3o00040?n000L0o`000`3oP0040000o`80o`000`000?l40?l000@0oh000`000?l;
0?l00080oh000P3o00030?n00080o`000P3oP0090000o`03003o00000?l0003o00@0003o0`3o0004
0?n001Sooooo000Fooooo`D0o`000P3oP0070?l00080oh002@3o00020?n000h0o`000P3oP00M0?l0
00030?n0003o0000o`0000H0o`0000<0oh000?l0003o0000103o00020?n000T0o`0000<0oh000?l0
003o00004P3o00040?n000D0o`000P3oP0050?l00080003o3_oooomK003o00@0003o1`00o`070000
oad00?l03_ooool;003o00<0003o3@00o`0@0000o`80o`001@000?l4003o01`0003o0P00o`040000
o`T00?l01`000?l>003o00H0003o00<00?l00000o`000?l01P000?l3003o0080003o3_ooool20000
o`800?l000<0003o0?n0003oP0000P3o00040?n000L0o`000P3oP0050000o`<0o`000P3oP0020?l0
00@0oh000`3o00040?n000<0o`00103oP0020000o`D0o`00103oP0070?l000<0oh0010000?l20?l0
00<0003o103o00040?n000<0003o2`3o00020?n00080o`000`3oP0020?l00080oh002@000?l00`00
o`00003o0000o`040000o`<0o`00103oP00Hooooo`005_ooool50?l00080oh001P3o00000`3oP000
o`000?l000090?l00080oh001`3o00020?n000L0o`000P3oP0050?l00080oh007@3o00000`3oP000
o`000?l000040?l00080oh00803o00020?n000L0o`000P3oP0050?l000kooooo>@00o`020000o`@0
0?l01`000?lE003o00@0003o:`00o`0>oooooad00?l030000?l20?n00080o`000`000?l9003o0180
003o0P3o000>0000o`800?l02`000?l9003o0080003o2@00o`090000o`<00?l00P000?l>ooooo`80
003o1`3o00020?n000<0o`00203oP0030?l00080oh000`3o00020?n00080o`000P3oP0030?l00080
003o103oP0050?l000@0oh001@3o00040?n00080o`001`3oP0000`3o0000oh000?n000020?l000D0
003o0P3o00060?n000<0003o1P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`000080
o`000P3oP0000`000?l0o`000?l000090000o`800?l00P000?l30?l00080oh000P3o000Hooooo`00
5_ooool50?l00080oh001`3o00020?n000L0o`000P3oP0090?l00080oh001`3o00020?n000D0o`00
0P3oP00T0?l000<0oh001P3o00020?n000T0o`0000<0oh000?l0003o00002`3o00020?n000L0o`00
0P3oP0050?l000kooooo?`00o`020000oaL00?l01@000?l]003o00kooooo0P000?l@003o00D0003o
1P00o`0C0000o`/00?l00P000?l5003o00d0003o0P3oP00G0000o`@00?l01@000?l;003o00h0003o
3_ooool40?l000030?n000000?l0003o0080003o103oP0000`000?l0oh000?n000040?l00080oh00
0`3o00020?n00080o`001`3oP0020000o`<0o`00103oP0050?l000@0oh001@3o00060?n000D0o`00
0`3oP0060?l000<0oh00103o00020?n000T0o`000`3oP00;0?l000@0oh000`3o00020?n000D0003o
0P3oP0020000o`D0o`000P3oP0020?l001Sooooo000Fooooo`D0o`000P3oP0070?l00080oh001`3o
00020?n000T0o`000P3oP0070?l00080oh001@3o00020?n002@0o`000`3oP0060?l00080oh002@3o
00000`3oP000o`000?l0000;0?l00080oh001`3o00020?n000D0o`003_oooolo003o0080003o5`00
o`050000obd00?l03_ooool20000oa000?l01@000?l6003o01<0003o2`00o`020000o`D00?l03@00
0?l20?n001L0003o1000o`050000o`/00?l03P000?l>ooooo`@0o`0000<0oh000000o`000?l00P00
0?l40?n000030000o`3oP000oh0000@0o`000P3oP0030?l00080oh000P3o00070?n00080003o0`3o
00040?n000D0o`00103oP0050?l000H0oh001@3o00030?n000H0o`000`3oP0040?l00080oh002@3o
00030?n000/0o`00103oP0030?l00080oh001@000?l20?n00080003o1@3o00020?n00080o`006?oo
ool001Kooooo3P3o00020?n000L0o`000P3oP00B0?l00080oh001@3o00040?n000D0o`000P3oP00K
0?l00080oh001`3o00020?n000T0o`0000<0oh000?l0003o0000503o00020000o`D0o`003_oooolo
003o00D0003o5`00o`020000oad00?l00`000?l2003o0080003o2@00o`0>ooooo`D0003o3@00o`05
0000o`T00?l04P000?lB003o00/0003o0`3o00060000o`D00?l03@000?l2003o00D0003o2`00o`0>
0000o`kooooo103o00000`3oP000o`000?l000020?l00080oh001@000?l40?l000<0oh000P3o0002
0?n00080o`000`3oP0020?l00080oh000P000?l30?l000@0oh000P000?l70?n00080o`0000<0oh00
0?l0003o0000103oP0020000o`<0oh000P000?l20?n000030000o`3o0000o`0000@0o`002`3oP000
0`3o0000oh000?n000020?l000D0oh00103o00020?n00080o`001@3oP0020?l000030?n0003o0000
o`000080003o0P3oP0050000o`H0o`000`3oP0020?l001Sooooo000Fooooo`h0o`000P3oP0070?l0
0080oh004P3o00020?n000D0o`00103oP0050?l00080oh006`3o00020?n000L0o`000P3oP0090?l0
00030?n0003o0000o`0001@0o`000P000?l50?l000kooooo?`00o`050000oaL00?l00P000?lM003o
00<0003o0P00o`020000o`T00?l03_ooool50000o`d00?l01@000?l9003o0180003o4P00o`0;0000
o`<0o`001P000?l5003o00d0003o0P00o`050000o`/00?l03P000?l>ooooo`@0o`0000<0oh000?l0
003o00000P3o00020?n000D0003o103o00030?n00080o`000P3oP0020?l000<0oh000P3o00020?n0
0080003o0`3o00040?n00080003o1`3oP0020?l000030?n0003o0000o`0000@0oh000P000?l30?n0
0080003o0P3oP0000`000?l0o`000?l000040?l000/0oh0000<0o`000?n0003oP0000P3o00050?n0
00@0o`000P3oP0020?l000D0oh000P3o00000`3oP000o`000?l000020000o`80oh001@000?l60?l0
00<0oh000P3o000Hooooo`005_ooool40?l000030?n000000?l0003o00L0o`000P3oP0070?l00080
oh006`3o00020?n002/0o`000P3oP0030?l00080oh001@3o00020?n000h0o`000P3oP0040?l00080
003o1@3o000>ooooodl00?l00`000?l9003o0080003o7@00o`030000o`d00?l03_ooool50000o`80
0?l00P000?l9003o0080003o2@00o`090000o`<00?l02@000?lF003o0180003o0`00o`020000o`80
0?l00`000?l2003o02@0003o3_ooool40?l000<0oh00103o00030?n00080003o0P3oP0020?l000<0
oh000P3o00040?n000<0o`000P000?l20?n000/0003o1`3o00020?n000<0o`001P3oP0050000o`D0
o`000P3oP0020?l00080oh001`000?l30?l00080oh00103o00020?n000030000o`3oP000oh000080
003o1`3o00020?n000D0o`00103oP0020000o`030?n0003o0000o`0000H0o`000`3oP0020?l001So
oooo000Fooooo`@0o`0000<0oh000000o`000?l01`3o00020?n000L0o`000P3oP00K0?l00080oh00
:`3o00020?n000<0o`000P3oP0050?l00080oh003P3o00020?n000@0o`000P000?l50?l000kooooo
C`00o`030000o`T00?l00P000?lM003o00<0003o3@00o`0>ooooo`D0003o0P00o`020000o`T00?l0
0P000?l9003o00T0003o0`00o`090000oaH00?l04P000?l3003o0080003o0P00o`030000o`800?l0
90000?l>ooooo`@0o`000`3oP0040?l000<0oh000P000?l20?n00080o`000`3oP0020?l000@0oh00
0`3o00020000o`80oh002`000?l70?l00080oh000`3o00060?n000D0003o1@3o00020?n00080o`00
0P3oP0070000o`<0o`000P3oP0040?l00080oh0000<0003o0?n0003oP0000P000?l70?l00080oh00
1@3o00040?n00080003o00<0oh000?l0003o00001P3o00030?n00080o`006?ooool001Kooooo103o
00000`3oP000o`000?l000060?l000030?n0003o0000o`0000L0o`000P3oP0070?l00080oh001@3o
00020?n00180o`0010000?lG0?l00080oh00503o00000`3oP000o`000?l000050?l00080oh001`3o
00020?n00080003o0P3o00030000o`@0o`003_oooom=003o00@0003o2P00o`020000oad00?l00P00
0?l>003o00kooooo0P00o`030000o`P00?l02@000?l8003o00@0003o0P00o`020000o`<00?l00P00
0?l2003o00D0003o5`00o`020000o`800?l01`000?lD003o00T0003o5000o`050000o`kooooo0P3o
P0020?l000030?n0003o0000o`0000H0o`0000<0oh000000o`000?l010000?l30?n00080o`000P3o
P0020?l000030?n0003o0000o`0000@0oh000P000?l50?l00080oh000P000?l00`3oP000o`000?l0
00020?n00080o`000P3oP0030?l00080oh0010000?l50?l00080oh002@3o00000`3oP000o`000?l0
00020?l00080oh002@3o00050?n00080003o0P3o00020?n000030?l0003oP000oh000080oh001@3o
00020?n000D0003o2@3o00040?n001Sooooo000Fooooo`@0o`0000<0oh000?l0003o00001P3o0000
0`3oP000o`000?l000070?l00080oh001`3o00020?n000D0o`000P3oP00B0?l000@0003o5`3o0002
0?n001@0o`0000<0oh000?l0003o00001@3o00020?n000L0o`000P3oP0020000o`80o`000`000?l4
0?l000koooooC@00o`040000o`X00?l00P000?lM003o0080003o3P00o`0>ooooo`800?l00`000?l8
003o00T0003o2000o`040000o`800?l00P000?l3003o0080003o0P00o`050000oaL00?l00P000?l2
003o00L0003o5000o`090000oa@00?l01@000?l>ooooo`80oh000P3o00000`3oP000o`000?l00006
0?l000030?n000000?l0003o00@0003o0`3oP0020?l00080oh000P3o00000`3oP000o`000?l00004
0?n00080003o1@3o00020?n00080003o00<0oh000?l0003o00000P3oP0020?l00080oh000`3o0002
0?n000@0003o1@3o00020?n000T0o`0000<0oh000?l0003o00000P3o00020?n000T0o`001@3oP002
0000o`80o`000P3oP0000`3o0000oh000?n000020?n000D0o`000P3oP0050000o`T0o`00103oP00H
ooooo`005_ooool50?l00080oh001P3o00000`3oP000o`000?l000040?l00080oh000`000?l70?l0
0080oh001`3o00020?n000@0o`0000<0oh000?l0003o00001P3o00000`3oP000003o0000o`020000
o`L0o`000P000?l90?l00080oh001`3o00020?n000T0o`0000<0oh000?l0003o0000103o00020?n0
00030?l0003oP000oh0000h0o`000P3oP0020000o`80o`000`000?l40?l000koooooB`00o`060000
o`T00?l00`000?lM003o0080003o3P00o`0>ooooo`D0003o3@00o`020000oa/00?l00`000?lF003o
00030000o`00o`000?l000@00?l01`000?l@003o00d0003o4P00o`030000o`800?l03_ooool40?l0
00<0oh001P3o00030?n00080003o103o00000`3oP000o`000?l000020?n000D0o`000P3oP0050000
o`80oh00103o00020?n000030000o`3o0000o`0000@0o`000P3oP0030?l000@0oh000P000?l50?l0
0080oh000`3o00070?n000@0o`000P3oP0070?l000L0oh000P000?l20?n000<0o`000P3oP0070?l0
00@0oh000P000?l50?l00080oh000P3o00030?n00080o`006?ooool001Kooooo1@3o00020?n000H0
o`0000<0oh000?l0003o00001P3o00000`3oP000o`000?l0000@0?l00080oh003P3o00020?n000L0
o`000P3oP0020000o`80oh00403o00020?n000D0o`000P3oP0090?l00080oh00203o00020?n000T0
o`000P3oP0090?l000kooooo?@00o`020000o``00?l01P000?l7003o00D0003o;@00o`0>ooooo`D0
003o9000o`020000o`@00?l000<0003o003o0000o`004P00o`070000o`800?l02`000?l>003o00H0
003o5@00o`070000o`800?l03_ooool20000o`80o`0000<0003o0?n0003oP0001P3o00030?n000@0
0?l01@3o00020?n000D0o`000P3oP0050000o`80oh001`000?l60?l000<0oh00103o00020?n00080
003o00<0oh000?l0003o00000P3o00020?n000D0o`00103oP0000`000?l0o`000?l000020?l000D0
oh00103o00070?n00080003o0P3o00030?n00080o`000P3oP0050?l000@0oh000P000?l00`3oP000
o`000?l000020000o`L0o`000P3oP00Hooooo`005_ooool50?l00080oh001P3o00000`3oP000o`00
0?l000060?l000030?n0003o0000o`000100o`000P3oP00>0?l00080oh001`3o00020?n00080003o
0P3oP00@0?l00080oh001@3o00020?n000T0o`000P3oP0080?l00080oh002@3o00020?n000T0o`00
3_oooolm003o0080003o3000o`060000o`L00?l01@000?l]003o00kooooo1@000?lT003o0080003o
1000o`000`000?l00?l0003o000B003o00L0003o0P00o`0;0000o`h00?l01P000?lE003o00L0003o
0P00o`0>ooooo`80003o0P3o00000`000?l0oh000?n000060?l000<0oh001000o`050?l00080oh00
1@3o00020?n000D0003o0P3oP0070000o`H0o`000`3oP0040?l00080oh000P000?l00`3oP000o`00
0?l000020?l00080oh001@3o00040?n000030000o`3o0000o`000080o`001@3oP0040?l000L0oh00
0P000?l20?l000<0oh000P3o00020?n000D0o`00103oP0020000o`030?n0003o0000o`000080003o
1`3o00020?n001Sooooo000Fooooo`d0o`0000<0oh000?l0003o00001P3o00000`3oP000o`000?l0
00040?l000030?n0003o0000o`0000T0o`000P3oP00>0?l00080oh001`3o00040?n00080003o1`3o
00020?n000L0o`000P3oP00@0?l00080oh002P3o00020000o`T0o`000P3oP0020000o`D0o`003_oo
oomJ003o00<0003o;@00o`0>ooooo`800?l00P000?lU003o00@0003o0P00o`000`000?l00?l0003o
000=003o00<0003o0P00o`020000o`T00?l01`000?l>003o0080003o2@00o`070000o`@00?l00`00
0?l2003o00L0003o1000o`0>ooooo`80oh000`000?l80?l000<0oh000P000?l70?l00080003o1@3o
00020?n000D0003o1P3o00020?n000D0o`0010000?l50?l00080oh000P000?l70?l000030?n0003o
0000o`000080o`001`3oP0020?l000@0oh001@3o00050?n00080o`000P3oP0020000o`80o`0000<0
003o0?n0003oP0000P3o00020?n000<0o`001P3oP0000`3o0000oh000?n000060?l000030?n00000
0?l0003o0080003o6?ooool001Kooooo3@3o00000`3oP000o`000?l000060?l000030?n0003o0000
o`0000@0o`0000<0oh000?l0003o00002@3o00020?n000h0o`000P3oP0070?l000@0oh000P000?l7
0?l00080oh001`3o00020?n00100o`000P3oP00:0?l00080003o2@3o00020?n00080003o1@3o000>
oooooeX00?l00`000?l]003o00kooooo0P00o`020000obD00?l010000?l2003o00030000o`00o`00
0?l000d00?l00`000?l2003o0080003o2@00o`070000o`h00?l00P000?l9003o00L0003o1000o`03
0000o`800?l01`000?l4003o00kooooo0P3oP0030000o`P0o`000`3oP0020000o`L0o`000P000?l5
0?l00080oh001@000?l60?l00080oh001@3o00040000o`D0o`000P3oP0020000o`L0o`0000<0oh00
0?l0003o00000P3o00070?n00080o`00103oP0050?l000D0oh000P3o00020?n00080003o0P3o0000
0`000?l0oh000?n000020?l00080oh000`3o00060?n000030?l0003oP000oh0000H0o`0000<0oh00
0000o`000?l00P000?lHooooo`005_ooool20?n000/0o`0000<0oh000?l0003o00003P3o00020?n0
00H0o`000`3oP00K0?l00080oh002@3o00020?n000h0o`000P3oP0050?l00080oh00103o00000`3o
P000o`000?l000040?l000030?n000000?l0003o00@0003o1`3o00040000o`D0o`003_oooomJ003o
00<0003o;@00o`0>oooooaH00?l020000?l9003o00T0003o3`00o`030000o`800?l00P000?l7003o
00D0003o1000o`020000o`L00?l03@000?l3003o00@0003o1`00o`0>0000o`800?l03_ooool20?n0
00<0003o103o00020?n000<0o`00103oP0070?l00080oh001@3o00040?n00080003o1`3o00030?n0
0080o`000P000?l20?n000<0o`000P3oP0060000o`X0o`001P3oP0050000o`80oh000P3o00000`3o
P000o`000?l000040?n00080o`001@3oP0020000o`80oh00303o00020?n000D0o`000P3oP0040?l0
00030?n0003o0000o`000080003o6?ooool001Kooooo0P3oP00;0?l000030?n0003o0000o`0000h0
o`000P3oP0060?l000<0oh006`3o00020?n000T0o`000P3oP00>0?l00080oh001@3o00020?n000@0
o`0000<0oh000?l0003o0000103o00000`3oP000003o0000o`040000o`L0o`0010000?l50?l000ko
ooooFP00o`030000obd00?l03_oooolF003o00P0003o2@00o`090000o`l00?l00`000?l2003o0080
003o1`00o`050000o`@00?l00P000?l7003o00d0003o0`00o`040000o`L00?l03P000?l2003o00ko
oooo0P3oP0030000o`@0o`000P3oP0030?l000@0oh001`3o00020?n000D0o`00103oP0020000o`L0
o`000`3oP0020?l00080003o0P3oP0030?l00080oh001P000?l:0?l000H0oh001@000?l20?n00080
o`0000<0oh000?l0003o0000103oP0020?l000D0oh000P000?l20?n000`0o`000P3oP0050?l00080
oh00103o00000`3oP000o`000?l000020000oaSooooo000Fooooo`T0o`00103oP00A0?l00080oh00
1`3o00020?n000H0o`0000<0oh000?l0003o00004P3o00020?n000L0o`000P3oP0050?l00080oh00
403o00020?n000@0o`0000<0oh000?l0003o0000103o00030?n000T0o`001P000?l50?l000kooooo
B000o`050000o`d00?l000<0003o003o0000o`007`00o`070000o`L00?l03_oooolD003o00L0003o
3P00o`060000ob800?l000<0003o003o0000o`004000o`080000o`P00?l00P000?lD003o00kooooo
0P3oP0030?l000@0oh000P000?l20?l000<0003o0P3oP0050?l00080oh000P000?l50?l00080oh00
1@000?l60?l00080oh001@000?l50?l000@0oh0010000?l00`3oP000o`000?l000040?l000030?n0
003o0000o`0000@0oh000P000?l:0?l00080oh000P3o00090?n00080o`000P000?l00`3oP000o`00
0?l000020000o`80oh001`3o00030?n00080o`000P3oP0070?l00080oh006?ooool001Kooooo2@3o
00040?n00140o`000P3oP0070?l00080oh001P3o00000`3oP000o`000?l0000B0?l00080oh001`3o
00020?n000D0o`000P3oP00@0?l00080oh00103o00000`3oP000o`000?l000040?l000<0oh002@3o
00060000o`D0o`003_oooom8003o00D0003o3@00o`000`000?l00?l0003o000O003o00L0003o1`00
o`0>oooooa@00?l01`000?l>003o00H0003o8P00o`000`000?l00?l0003o000@003o00P0003o2000
o`020000oa@00?l03_ooool20?n000<0o`00103oP0020000o`80o`000`000?l20?n000D0o`000P3o
P0020000o`D0o`000P3oP0050000o`H0o`000P3oP0050000o`D0o`00103oP0040000o`030?n0003o
0000o`0000@0o`0000<0oh000?l0003o0000103oP0020000o`X0o`000P3oP0020?l000T0oh000P3o
00020000o`030?n0003o0000o`000080003o0P3oP0070?l000<0oh000P3o00020?n000L0o`000P3o
P00Hooooo`005_ooool;0?l00080oh001@3o00020?n001<0o`000P3oP0060?l000030?n0003o0000
o`000180o`000P3oP0070?l00080oh001`3o00020?n000h0o`000P3oP00<0?l00080oh001P3o0000
0`3oP000003o0000o`070000o`@0o`003_oooom2003o00T0003o<@00o`030000o`/00?l03_oooolI
003o0080003o3P00o`060000o`h00?l00P000?lE003o00H0003o1@00o`020000oa800?l000<0003o
003o0000o`003`00o`000`000?l00?l0003o0002003o00kooooo0P3oP0030?l000@0oh000P000?l2
0?n000X0o`00103oP0050?l00080oh001@000?l60?l00080oh001@000?l20?l000L0oh00103o0003
0?n000T0o`000P3oP0050?l000@0oh000`3o00020?n00080003o0P3oP0030?l000@0oh00103o0000
0`3oP000o`000?l000020?l00080oh003P3o00020?n00080o`0000<0oh000?l0003o00000P3oP00H
ooooo`005_ooool40?l000030?n0003o0000o`0000@0o`000P3oP0070?l00080oh000`3o00020?n0
00<0o`000P3oP0070?l00080oh001P3o00000`3oP000o`000?l000040?l00080oh005@3o00020?n0
00L0o`000P3oP00;0?l000030?n0003o0000o`0000h0o`000P3oP0070?l000@0003o0P3o00020000
o`030?l0003oP000oh000080003o3_ooool2003o0080003o@000o`070000oa000?l010000?lM003o
00<0003o2`00o`0>ooooo`L00?l010000?l<003o00@0003o3P00o`070000o`@00?l02`000?l9003o
00030000o`00o`000?l000@00?l00`000?l2003o00H0003o0`00o`040000o`L00?l00P000?l7003o
0180003o1`00o`0>ooooo`D0o`00103oP0020000o`<0oh00103o00020?n000<0o`00103oP0050?l0
0080oh0010000?l00`3oP000o`000?l000040?l000<0oh001P3o00030?n000H0o`000`3oP0040000
o`D0o`00103oP0020?l000D0oh001@3o00020?n000L0003o0P3oP0060?l000030?n0003o0000o`00
0080o`000`3oP0060?l00080oh001@3o00020?n000D0003o0P3oP00Hooooo`005_ooool40?l00003
0?n0003o0000o`0000@0o`000P3oP0070?l00080oh000`3o00020?n000<0o`000P3oP0070?l00080
oh001P3o00000`3oP000o`000?l000040?l00080oh005@3o00020?n000L0o`000P3oP00;0?l00003
0?n0003o0000o`0000h0o`000P3oP0070?l000@0003o0P3o00020000o`030?l0003oP000oh000080
003o3_ooool2003o0080003o@000o`070000oa000?l010000?lM003o00<0003o2`00o`0>ooooo`L0
0?l010000?l<003o00@0003o3P00o`070000o`@00?l02`000?l9003o00030000o`00o`000?l000@0
0?l00`000?l2003o00H0003o0`00o`040000o`L00?l00P000?l7003o0180003o1`00o`0>ooooo`D0
o`00103oP0020000o`<0oh00103o00020?n000<0o`00103oP0050?l00080oh0010000?l00`3oP000
o`000?l000040?l000<0oh001P3o00030?n000H0o`000`3oP0040000o`D0o`00103oP0020?l000D0
oh001@3o00020?n000L0003o0P3oP0060?l000030?n0003o0000o`000080o`000`3oP0060?l00080
oh001@3o00020?n000D0003o0P3oP00Hooooo`005_ooool;0?l00080oh001`3o00020?n000<0o`00
0P3oP0030?l00080003o1`3o00020?n000H0o`0000<0oh000?l0003o00004P3o00020?n000L0o`00
103oP0050?l00080oh009`3o00020?n000D0o`000P3oP0020?l000kooooo0P00o`030000ocX00?l0
0P000?l8003o0080003o3`00o`050000oaT00?l02`000?l7003o00kooooo0P000?lW003o00H0003o
1@00o`0=0000o`03003o00000?l0003o00T0003o0P00o`0;0000o`X00?l020000?l3003o01@0003o
1`00o`0>ooooo`80o`000P000?l00`3o0000oh000?n000020?n00080003o0`3oP0090?l00080oh00
1`000?l20?n00080003o0`3o00020?n000/0o`000P3oP0020000o`030?n000000?l0003o00@0o`00
0`3oP0020000o`T0o`000P3oP0050?l000@0oh000`3o00020?n000L0o`000P3oP0060?l000030?n0
003o0000o`000080o`000P3oP0000`000?l0o`000?l000040?l000<0oh00103o00020?n00080003o
00<0oh000000o`000?l00P3oP00Hooooo`005_ooool;0?l00080oh001`3o00020?n000<0o`000P3o
P0030?l00080003o1`3o00020?n000H0o`0000<0oh000?l0003o00004P3o00020?n000L0o`00103o
P0050?l00080oh009`3o00020?n000D0o`000P3oP0020?l000kooooo0P00o`030000ocX00?l00P00
0?l8003o0080003o3`00o`050000oaT00?l02`000?l7003o00kooooo0P000?lW003o00H0003o1@00
o`0=0000o`03003o00000?l0003o00T0003o0P00o`0;0000o`X00?l020000?l3003o01@0003o1`00
o`0>ooooo`80o`000P000?l00`3o0000oh000?n000020?n00080003o0`3oP0090?l00080oh001`00
0?l20?n00080003o0`3o00020?n000/0o`000P3oP0020000o`030?n000000?l0003o00@0o`000`3o
P0020000o`T0o`000P3oP0050?l000@0oh000`3o00020?n000L0o`000P3oP0060?l000030?n0003o
0000o`000080o`000P3oP0000`000?l0o`000?l000040?l000<0oh00103o00020?n00080003o00<0
oh000000o`000?l00P3oP00Hooooo`005_ooool20?l00080oh001`3o00020?n000L0o`000`3oP006
0?l000030?n0003o0000o`0000L0o`000P3oP0060?l000030?n0003o0000o`0000H0o`0000<0003o
0?n0003oP0001P3o00000`3oP000003o0000o`040?l000030?n0003o0000o`000080oh002@3o0002
0?n002L0o`000P3oP0070?l00080oh003_ooool2003o0080003o?P00o`060000oa800?l01`000?lL
003o0080003o2`00o`0>ooooo`@0003o1`00o`020000oa`00?l01P000?l5003o00L0003o1P00o`00
0`000?l00?l0003o0005003o0140003o1@00o`020000o`<00?l01P000?l7003o00L0003o1@00o`09
0000o`@00?l03_ooool20?l00080003o1@3oP0020?l00080oh001@3o00020?n000<0o`000P3oP004
0000o`030?l0003oP000oh000080oh0010000?l00`3oP000o`000?l000040?l000<0oh000P3o0006
0?n000030?l0003oP000oh0000@0o`000`3oP0020000o`T0o`000P3oP0030?l000@0oh000P000?l2
0?n000030?l0003oP000oh000080oh00103o00030?n000@0o`000`3oP0040?l000<0oh003@3o0004
0?n000<0003o0P3oP00Hooooo`005_ooool20?l00080oh001`3o00020?n000L0o`000`3oP0060?l0
00030?n0003o0000o`0000L0o`000P3oP0060?l000030?n0003o0000o`0000H0o`0000<0003o0?n0
003oP0001P3o00000`3oP000003o0000o`040?l000030?n0003o0000o`000080oh002@3o00020?n0
02L0o`000P3oP0070?l00080oh003_ooool2003o0080003o?P00o`060000oa800?l01`000?lL003o
0080003o2`00o`0>ooooo`@0003o1`00o`020000oa`00?l01P000?l5003o00L0003o1P00o`000`00
0?l00?l0003o0005003o0140003o1@00o`020000o`<00?l01P000?l7003o00L0003o1@00o`090000
o`@00?l03_ooool20?l00080003o1@3oP0020?l00080oh001@3o00020?n000<0o`000P3oP0040000
o`030?l0003oP000oh000080oh0010000?l00`3oP000o`000?l000040?l000<0oh000P3o00060?n0
00030?l0003oP000oh0000@0o`000`3oP0020000o`T0o`000P3oP0030?l000@0oh000P000?l20?n0
00030?l0003oP000oh000080oh00103o00030?n000@0o`000`3oP0040?l000<0oh003@3o00040?n0
00<0003o0P3oP00Hooooo`005_ooool20?l00080oh001@3o00020?n000/0o`0000<0oh000?l0003o
0000103o00000`3oP000o`000?l000040?l00080oh001@3o00020?n000`0o`000P3oP0070?l00080
oh001`3o00020?n000T0o`000P3oP00<0?l00080oh002@3o00020?n000<0o`001P000?l50?l000@0
oh001@3o00020?n000kooooo0P00o`020000ocd00?l01@000?lB003o00L0003o:`00o`0>ooooo`D0
003o1P00o`020000o`h00?l00P000?l<003o00L0003o0P00o`0;0000o`L00?l040000?l=003o00T0
003o1@00o`090000o`L00?l00P000?l2003o0080003o1@00o`0>ooooo`80oh000P000?l00`00o`00
003o0000o`020000o`80o`000P3oP0050?l00080oh001@3o00090000o`D0o`000P3oP0020?l00080
oh00303o00020?n00080o`001@3oP0060?l000030?n0003o0000o`000080oh001@3o00020?n00080
o`00103oP0030000o`80o`000P3oP0030?l00080oh000P000?l20?n00080003o0`3o00070000o`@0
oh001@3o00060?n000<0003o0P3oP00Hooooo`005_ooool90?l00080oh001@3o00020?n001/0o`00
0P3oP0030?l00080oh000P000?l20?l000030000o`3oP000oh000100o`000P3oP0050?l000@0oh00
2@3o00020?n00100o`000P000?l70?l00080oh000`3o00040000o`D0o`000P3oP00>ooooocd00?l0
2`000?l3003o0080003o1`00o`0;0000ob/00?l03_ooool20000o`800?l000<0003o003o0000o`00
0P00o`050000o`800?l00P000?l;003o00030000o`00o`000?l000/00?l01@000?l6003o0080003o
3P00o`070000oa@00?l02@000?lG003o00D0003o1000o`0>ooooo`D0003o0P00o`020?n000@0003o
00<0oh000?l0003o00000P3o00020?n00080o`0000<0oh000?l0003o00002`000?l30?l000@0oh00
1`3o00040?n00080003o1@3o00040?n000<0o`000P3oP0020?l000<0003o1`3o00020?n00080o`00
103oP0030000o`H0o`000`3oP0040000o`<0oh001`000?l20?n00080o`001@3oP0020?l000H0oh00
00<0003o0?n0003oP0000P000?lHooooo`005_ooool90?l00080oh001@3o00020?n001/0o`000P3o
P0030?l00080oh000P000?l20?l000030000o`3oP000oh000100o`000P3oP0050?l000@0oh002@3o
00020?n00100o`000P000?l70?l00080oh000`3o00040000o`D0o`000P3oP00>ooooocd00?l02`00
0?l3003o0080003o1`00o`0;0000ob/00?l03_ooool20000o`800?l000<0003o003o0000o`000P00
o`050000o`800?l00P000?l;003o00030000o`00o`000?l000/00?l01@000?l6003o0080003o3P00
o`070000oa@00?l02@000?lG003o00D0003o1000o`0>ooooo`D0003o0P00o`020?n000@0003o00<0
oh000?l0003o00000P3o00020?n00080o`0000<0oh000?l0003o00002`000?l30?l000@0oh001`3o
00040?n00080003o1@3o00040?n000<0o`000P3oP0020?l000<0003o1`3o00020?n00080o`00103o
P0030000o`H0o`000`3oP0040000o`<0oh001`000?l20?n00080o`001@3oP0020?l000H0oh0000<0
003o0?n0003oP0000P000?lHooooo`005_ooool90?l00080oh001`3o00020?n000<0o`000P3oP00=
0?l000030?n0003o0000o`0000@0o`000P3oP0050?l000@0003o703o00020?n000D0o`000P3oP00?
0?l000030?n0003o0000o`0000@0o`0000<0oh000?l0003o0000103o00030?n000d0o`003_oooolm
003o00T0003o3P00o`020000o`@00?l00`000?l]003o00kooooo10000?l00`3o0000003o0000o`02
003o00d0003o5@00o`0=0000o`D00?l00P000?l2003o00`0003o1000o`000`000?l00?l0003o000=
003o0080003o00<00?l00000o`000?l01P000?l3003o00D0003o3@00o`050000o`@00?l03_ooool2
0000o`80oh001`000?l20?l000030?n0003o0000o`0000L0oh000P3o00050?n000H0o`000P3oP003
0?l000@0oh000P3o00050?n000@0003o00<0oh000?l0003o00000P3o00040?n000030?l0003oP000
oh000080oh000P3o00000`3oP000o`000?l0000;0?l000@0oh000`3o00020?n000@0o`000`3oP004
0000o`<0oh000P000?l20?n00080003o0`3o00020000o`@0oh000`000?l20?n00080o`000P3oP005
0?l001Sooooo000Fooooo`T0o`000P3oP0070?l00080oh000`3o00020?n000d0o`0000<0oh000?l0
003o0000103o00020?n000D0o`0010000?lL0?l00080oh001@3o00020?n000l0o`0000<0oh000?l0
003o0000103o00000`3oP000o`000?l000040?l000<0oh003@3o000>ooooocd00?l02@000?l>003o
0080003o1000o`030000obd00?l03_ooool40000o`030?l000000?l0003o00800?l03@000?lE003o
00d0003o1@00o`020000o`800?l030000?l4003o00030000o`00o`000?l000d00?l00P000?l00`00
o`00003o0000o`060000o`<00?l01@000?l=003o00D0003o1000o`0>ooooo`80003o0P3oP0070000
o`80o`0000<0oh000?l0003o00001`3oP0020?l000D0oh001P3o00020?n000<0o`00103oP0020?l0
00D0oh0010000?l00`3oP000o`000?l000020?l000@0oh0000<0o`000?n0003oP0000P3oP0020?l0
00030?n0003o0000o`0000/0o`00103oP0030?l00080oh00103o00030?n000@0003o0`3oP0020000
o`80oh000P000?l30?l00080003o103oP0030000o`80oh000P3o00020?n000D0o`006?ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000Wooooog7o00009?ooool0
02;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Co
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Co
oooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo
5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo
5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_oo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5
oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000O
oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000Ooooo
oaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o
1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
7ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolF
o`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0
00Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo
5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo
0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000OoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02
o`00OaKoo`001Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02
o`00OaOoo`00E?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo000j
o`00OaKoogl01?l007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Doooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool003[ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolF
ool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Doooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l0
0ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0
>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo001Do`00O`03o`00
0?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go
001o00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]
o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009oooooma
o`0002Cooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Fooooo`D0o`002000o`0<
0?l00080oh003P3o0004003o00h0o`000P3oP00B0?l00080003o0`3o00020?n000/0o`000P3oP007
0?l00080oh004`3o00020000o`@0o`0000<0oh000?l0003o00000P000?l>ooooo`@0oh002@00o`0:
0?l00080oh001000o`070?l000<0003o0P3o00020?n001@00?l00`3o00020?n000L00?l01P3o0005
003o0080o`005`00o`020?l000`00?l0103o00020000o`80oh0000<0o`000?n0003oP0000P3o000>
ooooo`@00?l02@3o00000`3oP000o`000?l0000=0?l000030?n0003o0000o`000080o`000P000?l3
0?l00080oh00103o00020?n000030?l00000o`000?l000L00?l0203o00000`3oP000o`000?l00004
0?l000030?n00000o`000?l000@0o`000P3oP0090?l000030000o`3o0000o`0000@0003o0P3o0005
0?n000D0o`0010000?l20?l000030?n0003o0000o`000080o`000P000?l20?n000030000o`3o0000
o`000080o`000P3oP0030000o`80o`000P3oP00>ooooo`80oh002@3o00030?n00080o`000P000?l7
0?n00080o`000P3oP0000`3o0000oh000?n000020?l000800?l00`3o00040000o`80o`000P3oP000
0`3o0000oh000?n000060000o`030?n0003o0000o`000080oh000P3o00030?n00080o`000P3oP002
0?l000030?n0003o0000o`000080o`000P000?l30?l00080oh000P3o00070?n000/0o`000P000?l7
0?l00080oh000`3o00020?n00080o`000`000?l20?l000@0003o0`3oP0040?l001Sooooo000Foooo
o`D0o`002000o`0<0?l00080oh003P3o0004003o00h0o`000P3oP00B0?l00080003o0`3o00020?n0
00/0o`000P3oP0070?l00080oh004`3o00020000o`@0o`0000<0oh000?l0003o00000P000?l>oooo
o`@0oh002@00o`0:0?l00080oh001000o`070?l000<0003o0P3o00020?n001@00?l00`3o00020?n0
00L00?l01P3o0005003o0080o`005`00o`020?l000`00?l0103o00020000o`80oh0000<0o`000?n0
003oP0000P3o000>ooooo`@00?l02@3o00000`3oP000o`000?l0000=0?l000030?n0003o0000o`00
0080o`000P000?l30?l00080oh00103o00020?n000030?l00000o`000?l000L00?l0203o00000`3o
P000o`000?l000040?l000030?n00000o`000?l000@0o`000P3oP0090?l000030000o`3o0000o`00
00@0003o0P3o00050?n000D0o`0010000?l20?l000030?n0003o0000o`000080o`000P000?l20?n0
00030000o`3o0000o`000080o`000P3oP0030000o`80o`000P3oP00>ooooo`80oh002@3o00030?n0
0080o`000P000?l70?n00080o`000P3oP0000`3o0000oh000?n000020?l000800?l00`3o00040000
o`80o`000P3oP0000`3o0000oh000?n000060000o`030?n0003o0000o`000080oh000P3o00030?n0
0080o`000P3oP0020?l000030?n0003o0000o`000080o`000P000?l30?l00080oh000P3o00070?n0
00/0o`000P000?l70?l00080oh000`3o00020?n00080o`000`000?l20?l000@0003o0`3oP0040?l0
01Sooooo000Fooooo`80o`000P3oP0030?l000@00?l01@3o00020?n000L0o`000P3oP00>0?l000@0
0?l02`3o00000`000?l0o`000?l000020?n00180o`000P000?l30?l00080oh002`3o00020?n000L0
o`000P3oP003003o0100o`000P000?l40?l000030?n000000?l0003o0080003o3_ooool40?n000T0
0?l02P3o000=003o00<0003o0P3o00020?n001@00?l00`3o00020?n000T00?l0103o000W003o00T0
o`000P000?l20?n000030?l0003oP000oh000080oh003_ooool7003o00H0o`0000<0oh000?l0003o
00000P3o0002003o00h0o`0010000?l30?n000@0o`000P3oP0000`3o00000?l0003o000;003o00`0
o`000P00o`040?l00080003o1@3oP0040?l000L0003o0P3o00030?n000@00?l00`3o00040000o`80
o`0000<0oh000?l0003o00000P3o00020000o`80oh0000<0003o0?l0003o00000P3o00050000o`80
o`000P3oP00>ooooo`@0oh0000<0o`000?n0003oP000103o00030?n00080o`000P3oP0020?l000L0
oh000`3o00040?n000800?l00P3o00000`3oP000003o0000o`020000o`80o`000P3oP0000`3o0000
oh000?n000070?l00080oh001P3o00030?n000@0o`0000<0oh000?l0003o00000P3oP0070000o`80
o`000P3oP0020?l000030?n0003o0000o`000080o`000P3oP0020?l000030?n0003o0000o`000080
oh000P000?l30?l00080oh000P3o00020?n000030?l0003oP000oh0000@0o`000P000?l30?n000@0
003o1@3oP0020?l001Sooooo000Fooooo`80o`000P3oP0030?l000@00?l01@3o00020?n000L0o`00
0P3oP00>0?l000@00?l02`3o00000`000?l0o`000?l000020?n00180o`000P000?l30?l00080oh00
2`3o00020?n000L0o`000P3oP003003o0100o`000P000?l40?l000030?n000000?l0003o0080003o
3_ooool40?n000T00?l02P3o000=003o00<0003o0P3o00020?n001@00?l00`3o00020?n000T00?l0
103o000W003o00T0o`000P000?l20?n000030?l0003oP000oh000080oh003_ooool7003o00H0o`00
00<0oh000?l0003o00000P3o0002003o00h0o`0010000?l30?n000@0o`000P3oP0000`3o00000?l0
003o000;003o00`0o`000P00o`040?l00080003o1@3oP0040?l000L0003o0P3o00030?n000@00?l0
0`3o00040000o`80o`0000<0oh000?l0003o00000P3o00020000o`80oh0000<0003o0?l0003o0000
0P3o00050000o`80o`000P3oP00>ooooo`@0oh0000<0o`000?n0003oP000103o00030?n00080o`00
0P3oP0020?l000L0oh000`3o00040?n000800?l00P3o00000`3oP000003o0000o`020000o`80o`00
0P3oP0000`3o0000oh000?n000070?l00080oh001P3o00030?n000@0o`0000<0oh000?l0003o0000
0P3oP0070000o`80o`000P3oP0020?l000030?n0003o0000o`000080o`000P3oP0020?l000030?n0
003o0000o`000080oh000P000?l30?l00080oh000P3o00020?n000030?l0003oP000oh0000@0o`00
0P000?l30?n000@0003o1@3oP0020?l001Sooooo000Fooooo`80o`000P3oP0000`00o`00o`000?l0
000B0?l00080oh001`3o00020?n00180o`000P000?l30?l00080oh004P3o00020000o`<0o`000P3o
P00D0?l00080oh000`00o`050?l00080003o0P3o00040?n000T0o`0000<0oh000?l0003o00000P3o
000>ooooo`80o`000P3oP009003o00`0o`002`00o`030000o`80o`000P3oP00B003o0080o`000`00
o`020?n000T00?l01@3o000V003o00T0o`000P000?l20?n000030?l000000?l0003o0080oh003_oo
ool9003o00@0o`0000<0oh000?l0003o00001P00o`0<0?l000@0003o0`3oP00D0?l00080003o0P3o
00000`3oP000o`000?l000070?l000H0003o1@3oP0040?l000D0003o1@3oP0060?l000D0003o0P3o
P0020?l000030?n0003o0000o`0000@0o`000P3oP0050?l000D0003o103oP00>ooooo`D0oh00103o
00020000o`<0oh000P3o00020?n000@0o`001@3oP0030?l000@0oh000P00o`020?l000030?n0003o
0000o`000080oh001@3o00020?n000H0o`000`3oP0070?l00080oh00103o00000`3oP000o`000?l0
00020?n000@0o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l000020?l000D0oh000P3o
00040?n00080o`000`3oP0050?l00080003o0P3o00040000o`<0oh000P000?l40?n000030000o`3o
P000oh000080o`006?ooool001Kooooo0P3o0003003o01@0o`00103oP00N0?l00080oh00303o0004
0000o`80o`000P000?l30?l00080oh000P3o00020000oa00o`000P3oP003003o00@0o`000`000?l2
0?l000@0oh002@3o00000`3oP000o`000?l000020?l000kooooo0P3o00020?n000T00?l02P3o000=
003o00<0003o0P3o00020?n000/00?l00P3o0005003o00D0o`000P3oP002003o0080o`001@00o`05
0?l000800?l00P3o000R003o0080003o0`3o00020?n00080o`000P000?l20?n000030?l000000?l0
003o0080o`003_ooool40?n000D00?l02@3o00020?n000T0o`0000<0oh000?l0003o00000P3o0004
0000o`<0oh0010000?l20?l000030?n0003o0000o`0000L0o`000P00o`020?l00080003o0P3o0000
0`3oP000o`000?l000020?l00080oh000`3o00060000o`<0oh00103o00070000o`@0oh0000<0003o
0?l0003o0000103o00030000o`80o`000P3oP0020?l00003003o003o0000o`0000d0o`000`000?l4
0?n000kooooo1@3oP0040?l00080003o0`3oP0020?l00080oh00103o00000`3oP000o`000?l00002
0?n000D0o`00103oP0020?l000030?n0003o0000o`000080oh001@3o00020?n000800?l01@3o0004
0000o`80o`001@3oP0050?l000H0oh000P3o00000`000?l0oh000?n000040?n00080o`0000<0oh00
0?l0003o00001`3oP0040000o`@0oh0000<0o`000?n0003oP0000P00o`020?l000<0003o0P3oP005
0000o`80oh000P3o00090?n001Sooooo000Fooooo`80o`000`00o`0D0?l000@0oh007P3o00020?n0
00`0o`0010000?l20?l00080003o0`3o00020?n00080o`000P000?l@0?l00080oh000`00o`040?l0
00<0003o0P3o00040?n000T0o`0000<0oh000?l0003o00000P3o000>ooooo`80o`000P3oP009003o
00X0o`003@00o`030000o`80o`000P3oP00;003o0080o`001@00o`050?l00080oh000P00o`020?l0
00D00?l01@3o0002003o0080o`008P00o`020000o`<0o`000P3oP0020?l00080003o0P3oP0000`3o
0000003o0000o`020?l000kooooo103oP005003o00T0o`000P3oP0090?l000030?n0003o0000o`00
0080o`0010000?l30?n000@0003o0P3o00000`3oP000o`000?l000070?l000800?l00P3o00020000
o`80o`0000<0oh000?l0003o00000P3o00020?n000<0o`001P000?l30?n000@0o`001`000?l40?n0
00030000o`3o0000o`0000@0o`000`000?l20?l00080oh000P3o00000`00o`00o`000?l0000=0?l0
00<0003o103oP00>ooooo`D0oh00103o00020000o`<0oh000P3o00020?n000@0o`0000<0oh000?l0
003o00000P3oP0050?l000@0oh000P3o00000`3oP000o`000?l000020?n000D0o`000P3oP002003o
00D0o`0010000?l20?l000D0oh001@3o00060?n00080o`0000<0003o0?n0003oP000103oP0020?l0
00030?n0003o0000o`0000L0oh0010000?l40?n000030?l0003oP000oh0000800?l00P3o00030000
o`80oh001@000?l20?n00080o`002@3oP00Hooooo`005_ooool7003o0180o`000P3oP002003o01L0
o`000P00o`050?l00080oh00303o00020000o`@0o`000P000?l@0?l00080oh0000<0o`000000o`00
0?l0103o00020?n000L0o`000`000?l20?l00080oh002`3o00000`3oP000o`000?l000020?l000ko
oooo3@00o`000`3o00000?l0003o00070?l000d00?l00`000?l20?l00080oh002`00o`020?l000D0
0?l01@3o00020?n000800?l01@3o0002003o00D0o`000P00o`060?l000T00?l000<0o`00003o0000
o`001000o`030?l000/00?l00P000?l30?l00080oh000P3o00020000o`80oh0000<0o`000000o`00
0?l00P3o000>ooooo`@0oh001@00o`050?l00080oh000P3o00020?n000T0o`0000<0oh000?l0003o
00000P3o00040000o`<0oh0010000?l20?l000030?n00000o`000?l000800?l01@3o0002003o00H0
o`0000<0oh000000o`000?l00P3o00020?n000<0o`0010000?l30?n00080003o103oP0020000o`03
0?n000000?l0003o0080o`00103oP0000`000?l0o`000?l000020000o`80o`000`000?l20?l00080
oh000P3o00000`00o`00o`000?l000040?l00080oh002@3o00030000o`80oh003_ooool20?n00080
o`0000<0oh000?l0003o00000P3o00020000o`<0oh000P3o00020?n000L0o`000P3oP0030?l00080
0?l0103oP005003o0080oh001@3o00020?n000H0o`0000<0oh000000o`000?l00P000?l20?l00080
oh0000<0o`000000o`000?l01@3o0002003o00@0oh000`000?l60?n00080o`0000<0oh000?l0003o
00001`3oP0040000o`L0oh00103o00000`000?l0o`000?l000020?l000@0003o0`3oP0020?l000L0
oh000P3o000Hooooo`005_ooool7003o0180o`000P3oP002003o01L0o`000P00o`050?l00080oh00
303o00020000o`@0o`000P000?l@0?l00080oh0000<0o`000000o`000?l0103o00020?n000L0o`00
0`000?l20?l00080oh002`3o00000`3oP000o`000?l000020?l000kooooo3@00o`000`3o00000?l0
003o00070?l000d00?l00`000?l20?l00080oh002`00o`020?l000D00?l01@3o00020?n000800?l0
1@3o0002003o00D0o`000P00o`060?l000T00?l000<0o`00003o0000o`001000o`030?l000/00?l0
0P000?l30?l00080oh000P3o00020000o`80oh0000<0o`000000o`000?l00P3o000>ooooo`@0oh00
1@00o`050?l00080oh000P3o00020?n000T0o`0000<0oh000?l0003o00000P3o00040000o`<0oh00
10000?l20?l000030?n00000o`000?l000800?l01@3o0002003o00H0o`0000<0oh000000o`000?l0
0P3o00020?n000<0o`0010000?l30?n00080003o103oP0020000o`030?n000000?l0003o0080o`00
103oP0000`000?l0o`000?l000020000o`80o`000`000?l20?l00080oh000P3o00000`00o`00o`00
0?l000040?l00080oh002@3o00030000o`80oh003_ooool20?n00080o`0000<0oh000?l0003o0000
0P3o00020000o`<0oh000P3o00020?n000L0o`000P3oP0030?l000800?l0103oP005003o0080oh00
1@3o00020?n000H0o`0000<0oh000000o`000?l00P000?l20?l00080oh0000<0o`000000o`000?l0
1@3o0002003o00@0oh000`000?l60?n00080o`0000<0oh000?l0003o00001`3oP0040000o`L0oh00
103o00000`000?l0o`000?l000020?l000@0003o0`3oP0020?l000L0oh000P3o000Hooooo`005_oo
ool7003o00H0o`0000<0oh00003o0000o`002@3o00020?n000800?l04`3o00020?n00080o`000P00
o`0C0?l00080003o103o00020?n000L0o`000P3oP0000`3o0000003o0000o`040?l00080oh001`3o
00020?n000`0o`000P3oP0090?l00080oh001@3o000>oooooa000?l02@3o000;003o00<0003o0P3o
00020?n001800?l01@3o0004003o00`0o`000P00o`060?l000030?n00000o`000?l000d00?l00`3o
000;003o0080003o0`3o00020?n00080o`000P000?l20?n000030?l0003oP000oh000080o`003_oo
ool40?n000D00?l01@3o00020?n00180o`0010000?l30?n000@0003o0P3o00000`3oP0000?l0003o
0002003o00D0o`000P00o`060?l000L0003o00<0o`000?n0003oP0002@000?l20?l00080oh000P00
0?l30?n00080o`001@000?l40?n000@0o`0000<0oh000000o`000?l0103o00000`3oP000003o0000
o`040?l00080oh0000<0003o0?n0003oP0000P000?l40?l000D0003o3_ooool20?n00080o`000`3o
P0040?l00080oh000`3o0002003o00L0o`000P3oP0030?l000800?l00P3oP004003o00L0o`000P3o
P0090?l000030?n000000?l0003o0080003o0P3o00030?n00080003o0P3oP0020?l000L0oh000P00
0?l00`3o0000oh000?n000060?n000<0o`000P3oP0020?l000<0oh0010000?l70?n00080o`000`3o
P0020000o`80o`00103oP0000`3o0000oh000?n000020?n000800?l01@3o00020?n001Sooooo000F
ooooo`L00?l01P3o00000`3oP0000?l0003o00090?l00080oh000P00o`0C0?l00080oh000P3o0002
003o01<0o`000P000?l40?l00080oh001`3o00020?n000030?l000000?l0003o00@0o`000P3oP007
0?l00080oh00303o00020?n000T0o`000P3oP0050?l000kooooo4000o`090?l000/00?l00`000?l2
0?l00080oh004P00o`050?l000@00?l0303o0002003o00H0o`0000<0oh00003o0000o`003@00o`03
0?l000/00?l00P000?l30?l00080oh000P3o00020000o`80oh0000<0o`000?n0003oP0000P3o000>
ooooo`@0oh001@00o`050?l00080oh004P3o00040000o`<0oh0010000?l20?l000030?n00000o`00
0?l000800?l01@3o0002003o00H0o`001`000?l00`3o0000oh000?n000090000o`80o`000P3oP002
0000o`<0oh000P3o00050000o`@0oh00103o00000`3oP000003o0000o`040?l000030?n000000?l0
003o00@0o`000P3oP0000`000?l0oh000?n000020000o`@0o`001@000?l>ooooo`80oh000P3o0003
0?n000@0o`000P3oP0030?l000800?l01`3o00020?n000<0o`000P00o`020?n000@00?l01`3o0002
0?n000T0o`0000<0oh000000o`000?l00P000?l20?l000<0oh000P000?l20?n00080o`001`3oP002
0000o`030?l0003oP000oh0000H0oh000`3o00020?n00080o`000`3oP0040000o`L0oh000P3o0003
0?n00080003o0P3o00040?n000030?l0003oP000oh000080oh000P00o`050?l00080oh006?ooool0
01Kooooo1`00o`060?l00003003o003o0000o`0000/0o`000P00o`0:0?l00080oh000P00o`070?l0
00@00?l01@3o00020?n000`0o`000P000?l40?l00080oh002P3o00020000o`@0o`000P3oP00@0?l0
00030?n0003o0000o`0000d0o`000P3oP0050?l000kooooo1`00o`020?l000L00?l01`3o00020?n0
00L00?l00P3o0002003o00<0003o0P3o00020?n001@00?l00`3o0004003o00`0o`000P00o`060?l0
00030?n00000o`000?l000H00?l000<0o`00003o0000o`001P00o`000`3o00000?l0003o0009003o
0080003o0`3o00020000o`80o`000P000?l20?n000030?l0003oP000oh000080o`003_ooool40?n0
00D00?l01@3o00020?n00100o`000P3oP0040000o`<0oh0010000?l20?l000030?n00000o`000?l0
00800?l00P3o0009003o0080o`001@000?l20?n000030?l0003oP000oh0000T0003o0P3o00050?n0
00@0o`0010000?l00`3o0000oh000?n000020?n000@00?l000<0o`000000o`000?l00P000?l20?l0
00030?n000000?l0003o00@0o`000`000?l40?n000@0o`001@000?l>ooooo`D0oh00103o00040?n0
00L0o`000`000?l40?n000D0o`000P3oP00;0?l00080oh000`3o00020000o`80o`000`3oP0060000
o`80oh0000<0o`000000o`000?l00P3oP0020?l000030?n0003o0000o`000080o`000P3oP0030000
o`H0oh000P000?l30?l00080oh000P3o00020?n000030?l000000?l0003o0080003o103oP0030?l0
00L0oh00103o00020?n000030?l0003oP000oh000080oh000P3o00020?n000D0o`006?ooool001Ko
oooo0P00o`020?l000<00?l0803o00020?n000800?l01`3o0004003o00D0o`000P000?lT0?l00080
oh009@3o00020000o`kooooo4P00o`040?l000L00?l01@3o0002003o00<0003o0P3o00020?n000/0
0?l00P3o0007003o00<0o`001000o`0<0?l000800?l01P3o00000`3oP0000?l0003o000?003o0003
0?l00000o`000?l000T00?l01@3o00020000o`80o`000P000?l20?n000030?l0003oP000oh000080
o`003_ooool40?n000D00?l01@3o00020?n00100o`000P3oP0040000o`030?l0003oP000oh0000@0
o`000P3oP0070?l000L00?l0103o00030000o`@0oh0000<0o`000?n0003oP0001P000?l00`3oP000
003o0000o`020?l000D0oh00103o00040000o`030?l0003oP000oh000080oh001000o`000`3o0000
003o0000o`020000o`80o`0000<0oh000?l0003o0000103o00030000o`80o`000P3oP0040?l000D0
003o3_ooool20?l00080oh001@3o00040?n000D0o`0010000?l50?n000`0o`000P3oP0040?l00080
oh0000<00?l00?l0003o0000103o00030?n000H0003o0P3oP0050000o`80o`0000<0oh000?l0003o
00000P3o00020?n000<0003o203oP0030?l00080oh000P3o00020000o`L0oh000`000?l40?n00080
003o0`3oP0020000o`80o`000P3oP0000`3o0000003o0000o`020?n00080o`000`000?l20?l00080
oh006?ooool001Kooooo0P00o`020?l000<00?l0803o00020?n000800?l01`3o0004003o00D0o`00
0P000?lT0?l00080oh009@3o00020000o`kooooo4P00o`040?l000L00?l01@3o0002003o00<0003o
0P3o00020?n000/00?l00P3o0007003o00<0o`001000o`0<0?l000800?l01P3o00000`3oP0000?l0
003o000?003o00030?l00000o`000?l000T00?l01@3o00020000o`80o`000P000?l20?n000030?l0
003oP000oh000080o`003_ooool40?n000D00?l01@3o00020?n00100o`000P3oP0040000o`030?l0
003oP000oh0000@0o`000P3oP0070?l000L00?l0103o00030000o`@0oh0000<0o`000?n0003oP000
1P000?l00`3oP000003o0000o`020?l000D0oh00103o00040000o`030?l0003oP000oh000080oh00
1000o`000`3o0000003o0000o`020000o`80o`0000<0oh000?l0003o0000103o00030000o`80o`00
0P3oP0040?l000D0003o3_ooool20?l00080oh001@3o00040?n000D0o`0010000?l50?n000`0o`00
0P3oP0040?l00080oh0000<00?l00?l0003o0000103o00030?n000H0003o0P3oP0050000o`80o`00
00<0oh000?l0003o00000P3o00020?n000<0003o203oP0030?l00080oh000P3o00020000o`L0oh00
0`000?l40?n00080003o0`3oP0020000o`80o`000P3oP0000`3o0000003o0000o`020?n00080o`00
0`000?l20?l00080oh006?ooool001Kooooo103o00000`00o`00o`000?l0000K0?l00080oh001@3o
0002003o0100o`000P000?lK0?l00080oh001`3o00020?n00003003o003o0000o`0001l0o`0000<0
oh000?l0003o00000P000?l>ooooob@00?l00`000?l20?l00080oh002`00o`020?l000D00?l01@3o
0004003o00`0o`000P00o`060?l001h00?l01@3o00020000o`@0o`000P3oP0000`3o0000oh000?n0
00020?l000kooooo0P3o00020?n000X00?l0203o0003003o0080003o0`3o00040?n000D0o`000P00
0?l40?l00080oh002P3o0004003o00@0o`000`000?l20?l00080oh000`3o00060000o`<0oh000P3o
00040?n00003003o003o0000o`000080o`0010000?l00`3o0000oh000?n000020?l000@00?l01`3o
00000`3oP000o`000?l000040?l000<0003o0P3o00020?n000@00?l00`000?l20?l000kooooo0P00
o`070?l000@0oh001@3o00040000o`P0oh000P000?l40?n00080o`000`3oP0020?l00080oh000`3o
00020?n000@0o`000P3oP0030?l000@0003o0`3oP0040000o`80o`000`3oP0070000o`P0oh0000<0
o`000?n0003oP000103o00020000o`L0oh000P000?l50?n00080o`000`3oP0040000o`80oh0000<0
o`000?n0003oP0000P3oP0020?l000<0003o103oP00Hooooo`005_ooool40?l00003003o003o0000
o`0001/0o`000P3oP0050?l000800?l0403o00020000oa/0o`000P3oP0070?l00080oh0000<00?l0
0?l0003o00007`3o00000`3oP000o`000?l000020000o`kooooo9000o`030000o`80o`000P3oP00;
003o0080o`001@00o`050?l000@00?l0303o0002003o00H0o`007P00o`050?l00080003o103o0002
0?n000030?l0003oP000oh000080o`003_ooool20?l00080oh002P00o`080?l000<00?l00P000?l3
0?l000@0oh001@3o00020000o`@0o`000P3oP00:0?l000@00?l0103o00030000o`80o`000P3oP003
0?l000H0003o0`3oP0020?l000@0oh0000<00?l00?l0003o00000P3o00040000o`030?l0003oP000
oh000080o`001000o`070?l000030?n0003o0000o`0000@0o`000`000?l20?l00080oh001000o`03
0000o`80o`003_ooool2003o00L0o`00103oP0050?l000@0003o203oP0020000o`@0oh000P3o0003
0?n00080o`000P3oP0030?l00080oh00103o00020?n000<0o`0010000?l30?n000@0003o0P3o0003
0?n000L0003o203oP0000`3o0000oh000?n000040?l00080003o1`3oP0020000o`D0oh000P3o0003
0?n000@0003o0P3oP0000`3o0000oh000?n000020?n00080o`000`000?l40?n001Sooooo000Foooo
oa00o`000P000?l@0?l00080oh000P3o00000`3oP000o`000?l00002003o0100o`000P3oP00<0?l0
0080003o1`3o00020000o`@0o`000P3oP0070?l00080oh002P3o00020?n000T0o`000P3oP00>0?l0
0080003o3_ooool7003o0080o`006`00o`030000o`80o`000P3oP00B003o00D0o`001P00o`0:0?l0
00@00?l01@3o000M003o0080o`000`00o`060?l00080oh0000<0o`000?n0003oP0000P3o000>oooo
o`h00?l01P3o00020?n000030?l00000o`000?l000D0o`000P3oP00=0?l00080oh0000<0o`00003o
0000o`000P00o`050?l000@00?l01@3o00020000o`80o`000P3oP0030?l000H0003o0`3oP0040?l0
0080oh0000<00?l00?l0003o00001`3o00020?n000/0o`000P3oP003003o00@0o`000P000?l30?l0
0080oh001000o`000`000?l0o`000?l000020?l000kooooo0P00o`030?n000@0o`000P3oP002003o
00030?n00000o`000?l00080o`000P3oP0020?l000L0oh0000<0o`000000o`000?l0103o00090?n0
00h0o`0010000?l20?l000030?n000000?l0003o0080003o0P3oP0000`000?l0oh000?n000020000
o`80oh000P000?l>0?n00080003o0P3oP0000`000?l0oh000?n000020?n000@0003o1@3oP0030?l0
0080oh0010000?l20?n000030?l0003oP000oh0000@0oh000`000?l20?n00080003o6?ooool001Ko
oooo403o00020000oa00o`000P3oP0020?l000030?n0003o0000o`0000800?l0403o00020?n000`0
o`000P000?l70?l00080003o103o00020?n000L0o`000P3oP00:0?l00080oh002@3o00020?n000h0
o`000P000?l>ooooo`L00?l00P3o000K003o00<0003o0P3o00020?n001800?l01@3o0006003o00X0
o`001000o`050?l001d00?l00P3o0003003o00H0o`000P3oP0000`3o0000oh000?n000020?l000ko
oooo3P00o`060?l00080oh0000<0o`00003o0000o`001@3o00020?n000d0o`000P3oP0000`3o0000
0?l0003o0002003o00D0o`001000o`050?l00080003o0P3o00020?n000<0o`001P000?l30?n000@0
o`000P3oP0000`00o`00o`000?l000070?l00080oh002`3o00020?n000<00?l0103o00020000o`<0
o`000P3oP004003o00030000o`3o0000o`000080o`003_ooool2003o00<0oh00103o00020?n00080
0?l000<0oh00003o0000o`000P3o00020?n00080o`001`3oP0000`3o0000003o0000o`040?l000T0
oh003P3o00040000o`80o`0000<0oh000000o`000?l00P000?l20?n000030000o`3oP000oh000080
003o0P3oP0020000o`h0oh000P000?l20?n000030000o`3oP000oh000080oh0010000?l50?n000<0
o`000P3oP0040000o`80oh0000<0o`000?n0003oP000103oP0030000o`80oh000P000?lHooooo`00
5_ooool@0?l00080oh00403o00020?n000D0o`000P00o`0>0?l000@0oh001`3o00020000o``0o`00
0P000?l40?l00080oh001`3o00020?n00003003o003o0000o`0000800?l01@3o00020?n000D0o`00
0P3oP0020?l00080oh002`3o00000`3oP000o`000?l000020?l000kooooo1`00o`040?l001T00?l0
0P000?l30?l00080oh005000o`020?l000D00?l0303o0004003o00D0o`005000o`020?l000`00?l0
1P3o00020?n000D0o`003_ooool>003o01P0o`0000<0oh000?l0003o00001P3o00000`3oP0000?l0
003o0002003o0080o`000P00o`030?l000800?l01@3o00020?n00080o`000P3oP0000`00o`00o`00
0?l000060000o`<0oh001P3o00000`00o`00o`000?l00002003o00D0o`000P3oP00;0?l00080oh00
00<00?l00?l0003o000010000?l20?l000030?n0003o0000o`000080oh000P00o`070?l000kooooo
0P00o`020?n000D0o`001@3oP002003o00H0o`000`3oP0040?l000030?n0003o0000o`0000L0oh00
0P3o00040?n000L0o`000P3oP0020?l000030?n0003o0000o`000080003o103o00030000o`@0oh00
00<0003o0?n0003oP0000P3o00020?n00080o`000`3oP0060?l000030?n000000?l0003o00H0oh00
00<0003o0?l0003o0000103oP0020?l000X0oh0010000?l20?l000030?n0003o0000o`000080o`00
0P3oP0020000o`<0oh000P000?lHooooo`005_ooool@0?l00080oh00403o00020?n000D0o`000P00
o`0>0?l000@0oh001`3o00020000o``0o`000P000?l40?l00080oh001`3o00020?n00003003o003o
0000o`0000800?l01@3o00020?n000D0o`000P3oP0020?l00080oh002`3o00000`3oP000o`000?l0
00020?l000kooooo1`00o`040?l001T00?l00P000?l30?l00080oh005000o`020?l000D00?l0303o
0004003o00D0o`005000o`020?l000`00?l01P3o00020?n000D0o`003_ooool>003o01P0o`0000<0
oh000?l0003o00001P3o00000`3oP0000?l0003o0002003o0080o`000P00o`030?l000800?l01@3o
00020?n00080o`000P3oP0000`00o`00o`000?l000060000o`<0oh001P3o00000`00o`00o`000?l0
0002003o00D0o`000P3oP00;0?l00080oh0000<00?l00?l0003o000010000?l20?l000030?n0003o
0000o`000080oh000P00o`070?l000kooooo0P00o`020?n000D0o`001@3oP002003o00H0o`000`3o
P0040?l000030?n0003o0000o`0000L0oh000P3o00040?n000L0o`000P3oP0020?l000030?n0003o
0000o`000080003o103o00030000o`@0oh0000<0003o0?n0003oP0000P3o00020?n00080o`000`3o
P0060?l000030?n000000?l0003o00H0oh0000<0003o0?l0003o0000103oP0020?l000X0oh001000
0?l20?l000030?n0003o0000o`000080o`000P3oP0020000o`<0oh000P000?lHooooo`005_oooolR
0?l00080oh000P3o00000`3oP000o`000?l0000=0?l00080003o00<0o`000?n0003oP0000P3oP002
0?l00080oh003P3o00020000o`030?l0003oP000oh0000@0o`000P3oP0070?l00080oh0000<00?l0
0?l0003o00000P00o`050?l00080oh001@3o00020?n000L0o`000P3oP0020000o`@0o`0000<0oh00
0?l0003o00000P3o000>ooooob@00?l01@3o00020?n001@00?l00P3oP005003o00D0o`000P000?l4
0?l000030?n00000o`000?l000800?l01@3o000D003o00L0o`001`00o`020?n000@0o`000P3oP005
0?l000kooooo0P3o0009003o0080o`0000<00?l00?l0003o00002@3o0004003o00<0o`000P000?l4
0?l000030?n0003o0000o`0000H0o`0000<0oh000?l0003o00000P00o`020?l000800?l0403o0000
0`00o`00o`000?l000020?l000@0003o00<0oh000?l0003o00002@3o0002003o00D0o`000P3oP002
0?l00080003o0`3o00020?n000L0o`0010000?l30?n000@0o`000P00o`070?l000kooooo1@3o0002
0000o`80oh000P3o00030?n000@0o`000P3oP0020?l000<0oh000P00o`030?n000P0o`0000<0oh00
0?l0003o0000103oP0050?l000@0oh000`3o00040000o`80o`000P3oP0030000o`@0oh0000<0003o
0?n0003oP000103oP0020?l000<0oh00103o00020000o`T0oh000`3o00040?n00080o`0000<0oh00
0?l0003o00001@3oP0020?l000@0003o0`3oP0040?l00080oh000P3o00000`3oP000003o0000o`02
0000oaSooooo000Fooooo`L0o`000P3oP002003o02h0o`00103oP0020?l00080oh00803o00020?n0
0003003o003o0000o`0000800?l01@3o0002003o00D0o`000P000?l40?l00080oh002@3o00000`3o
P000o`000?l000020?l000kooooo1`00o`020?l001/00?l01@3o00020?n001@00?l00`3o0004003o
00D0o`000P000?l40?l000030?n00000o`000?l000800?l01@3o000F003o0080o`001@00o`040?l0
0003003o003oP000oh0000/0o`003_ooool70?l000800?l0103o0007003o00D0o`001000o`070?l0
0080003o2@3o00000`3oP000o`000?l00006003o00D0o`000P3oP0090?l00003003o003o0000o`00
00H0o`0000<0oh000?l0003o0000103o0002003o00030?n0003o0000o`0000L0o`000P3oP0020?l0
0080003o0P3o00030?n00080003o0`3o00060000o`D0oh000P3o0002003o00D0o`000P3oP00>oooo
o`80o`001@000?l20?n00080o`000P3oP0050?l00080oh000`3o00020?n000800?l00P3oP0090?l0
00D0oh000P00o`050?l000H0oh0000<0o`000000o`000?l00P000?l50?n000T0003o103oP0020?l0
00030?n0003o0000o`0000@0o`000`000?l60?n000<0003o103oP0020?l000D0003o0P3oP0020000
o`030?n0003o0000o`0000@0003o2@3oP0020000o`030?n000000?l0003o0080003o6?ooool001Ko
oooo1`3o00020?n000800?l0;P3o00040?n00080o`000P3oP00P0?l00080oh0000<00?l00?l0003o
00000P00o`050?l000800?l01@3o00020000o`@0o`000P3oP0090?l000030?n0003o0000o`000080
o`003_ooool7003o0080o`006`00o`050?l00080oh005000o`030?l000@00?l01@3o00020000o`@0
o`0000<0oh00003o0000o`000P00o`050?l001H00?l00P3o0005003o00@0o`0000<00?l00?n0003o
P0002`3o000>ooooo`L0o`000P00o`040?l000L00?l01@3o0004003o00L0o`000P000?l90?l00003
0?n0003o0000o`0000H00?l01@3o00020?n000T0o`0000<00?l00?l0003o00001P3o00000`3oP000
o`000?l000040?l000800?l000<0oh000?l0003o00001`3o00020?n00080o`000P000?l20?l000<0
oh000P000?l30?l000H0003o1@3oP0020?l000800?l01@3o00020?n000kooooo0P3o00050000o`80
oh000P3o00020?n000D0o`000P3oP0030?l00080oh000P00o`020?n000T0o`001@3oP002003o00D0
o`001P3oP0000`3o0000003o0000o`020000o`D0oh002@000?l40?n00080o`0000<0oh000?l0003o
0000103o00030000o`H0oh000`000?l40?n00080o`001@000?l20?n00080003o00<0oh000?l0003o
000010000?l90?n00080003o00<0oh000000o`000?l00P000?lHooooo`005_ooool90?l000800?l0
3P3o00020?n000`0o`000P3oP00V0?l00080003o00<0o`000?n0003oP0003`3o00000`3oP000o`00
0?l00002003o00D0o`000P3oP0050?l000@0003o0P3o00020?n000030?l00000o`000?l000@0003o
0P3o00000`3oP000o`000?l000020?l000kooooo3P00o`020?l000@00?l00P3o000>003o00D0o`00
0P3oP007003o0080o`004P00o`050?l00080003o103o00000`3oP0000?l0003o0002003o00D0o`00
7@00o`050?l00080oh000P3o00020?n000L0o`003_ooool20000o`/0o`001`00o`070?l000800?l0
1`3o00020000oa00o`000`00o`040?l00080oh00403o00030?n000H0o`000P00o`000`3oP000o`00
0?l000020?l000@0003o00<0o`000?n0003oP0001P3o00030?n000@0003o00<0o`000?n0003oP000
10000?l50?n00080o`000P00o`020?n000<0o`000P000?l>ooooo`80o`000P3oP0030000o`H0oh00
0`3o00060000o`<0oh000P00o`070?l00080oh000`3o00020?n000800?l00P3o00020000o`<0o`00
103oP0030?l000@0003o1@3oP0020?l000@0003o1@3oP0020?l000800?l000<0oh000?l0003o0000
1`000?l40?n000D0003o103oP0020?l000<0003o1`3oP0020?l00080003o2@3oP0040000o`<0oh00
0P000?lHooooo`005_ooool90?l000800?l03P3o00020?n000`0o`000P3oP00V0?l00080003o00<0
o`000?n0003oP0003`3o00000`3oP000o`000?l00002003o00D0o`000P3oP0050?l000@0003o0P3o
00020?n000030?l00000o`000?l000@0003o0P3o00000`3oP000o`000?l000020?l000kooooo3P00
o`020?l000@00?l00P3o000>003o00D0o`000P3oP007003o0080o`004P00o`050?l00080003o103o
00000`3oP0000?l0003o0002003o00D0o`007@00o`050?l00080oh000P3o00020?n000L0o`003_oo
ool20000o`/0o`001`00o`070?l000800?l01`3o00020000oa00o`000`00o`040?l00080oh00403o
00030?n000H0o`000P00o`000`3oP000o`000?l000020?l000@0003o00<0o`000?n0003oP0001P3o
00030?n000@0003o00<0o`000?n0003oP00010000?l50?n00080o`000P00o`020?n000<0o`000P00
0?l>ooooo`80o`000P3oP0030000o`H0oh000`3o00060000o`<0oh000P00o`070?l00080oh000`3o
00020?n000800?l00P3o00020000o`<0o`00103oP0030?l000@0003o1@3oP0020?l000@0003o1@3o
P0020?l000800?l000<0oh000?l0003o00001`000?l40?n000D0003o103oP0020?l000<0003o1`3o
P0020?l00080003o2@3oP0040000o`<0oh000P000?lHooooo`005_ooool20?l00080oh002P3o0002
003o00T0o`000P3oP00<0?l00080oh00103o0003003o0080o`000P00o`0G0?l000800?l05P3o0000
0`3oP0000?l0003o0002003o00`0o`000P000?l40?l00080oh001@3o00020000o`80o`0000<0oh00
0?l0003o00000P3o000>ooooo`h00?l00P3o0002003o00@0o`009@00o`060?l000D00?l01@3o0002
0000o`@0o`0000<0oh00003o0000o`001000o`020?l001800?l000<0o`00003o0000o`000P00o`02
0?l000D00?l01@3o00020?n00080o`000P3oP0030?l000@00?l03_oooolI0?l00080oh002@3o0002
0000o`030?l000000?l0003o0080oh000P000?l30?l00080oh00103o0007003o01D0o`000P000?l2
0?n00080o`000P00o`000`3o0000003o0000o`020?l000@0003o00<0o`000?n0003oP0001P3o0000
0`000?l0o`000?l000040000o`030?l0003oP000oh0000@0003o1@3oP0040?l00080oh000`3o0002
0000o`kooooo0P3o00020?n000030000o`3o0000o`0000H0oh001@3o00040000o`<0oh000P00o`02
0?l000030000o`3o0000o`000080o`000P3oP0020?l000<0oh00103o00030000o`80o`001P3oP005
0000o`D0oh00103o00030000o`@0oh000P00o`020?l000030?n0003o0000o`000080o`001@000?l2
0?n000H0003o1@3oP0050000o`@0oh000P3o00000`3oP000003o0000o`040000o`L0oh0010000?l3
0?n00080003o6?ooool001Kooooo0P3o00020?n000X0o`000P00o`090?l00080oh00303o00020?n0
00@0o`000`00o`020?l000800?l05`3o0002003o01H0o`0000<0oh00003o0000o`000P00o`0<0?l0
0080003o103o00020?n000D0o`000P000?l20?l000030?n0003o0000o`000080o`003_ooool>003o
0080o`000P00o`040?l002D00?l01P3o0005003o00D0o`000P000?l40?l000030?n00000o`000?l0
00@00?l00P3o000B003o00030?l00000o`000?l000800?l00P3o0005003o00D0o`000P3oP0020?l0
0080oh000`3o0004003o00kooooo6@3o00020?n000T0o`000P000?l00`3o0000003o0000o`020?n0
0080003o0`3o00020?n000@0o`001`00o`0E0?l00080003o0P3oP0020?l000800?l000<0o`000000
o`000?l00P3o00040000o`030?l0003oP000oh0000H0o`0000<0003o0?l0003o000010000?l00`3o
0000oh000?n000040000o`D0oh00103o00020?n000<0o`000P000?l>ooooo`80o`000P3oP0000`00
0?l0o`000?l000060?n000D0o`0010000?l30?n000800?l00P3o00000`000?l0o`000?l000020?l0
0080oh000P3o00030?n000@0o`000`000?l20?l000H0oh001@000?l50?n000@0o`000`000?l40?n0
00800?l00P3o00000`3oP000o`000?l000020?l000D0003o0P3oP0060000o`D0oh001@000?l40?n0
0080o`0000<0oh000000o`000?l010000?l70?n000@0003o0`3oP0020000oaSooooo000Fooooo`80
0?l05`3o00020?n000800?l02P3o00020?n000@0o`000P00o`0@0?l00080003o203o00020?n00080
0?l06`3o0002003o00X0o`000P000?l40?l00080oh002@3o00000`3oP000o`000?l000020?l000ko
oooo0P3o000<003o00P0o`00<000o`050?l00080003o103o00000`3oP0000?l0003o0004003o0080
o`000`00o`020?n000d00?l01@3o00020?n000D00?l02@3o00020?n000L00?l03_ooool40?l00003
003o003o0000o`0000@0o`000P000?l<0?l00080oh001@3o00020?n00080o`000P000?l00`3o0000
003o0000o`020?n000@0003o00<0o`000?n0003oP0001P3o0003003o00T0o`000P3oP0090?l000<0
003o1P3oP002003o00030?l000000?l0003o00@0o`000P3oP0000`3o0000oh000?n000060?l00003
0000o`3o0000o`0000@0003o00<0o`000?n0003oP00010000?l50?n000@0o`000P3oP0030?l00080
003o3_ooool40?l000<0oh001000o`030?l00080003o0P3o00040000o`<0oh001000o`000`000?l0
o`000?l000020?l00080oh000P3o00000`3oP0000?l0003o00060?l000030000o`3o0000o`0000H0
oh001`000?l20?l000030?n0003o0000o`000080o`000`000?l60?n000D0o`000P3oP0040000o`<0
oh001P000?l50?n000D0003o103oP002003o00<0o`0010000?l70?n000@0003o0`3oP0020?l001So
oooo000Fooooo`800?l05`3o00020?n000800?l02P3o00020?n000@0o`000P00o`0@0?l00080003o
203o00020?n000800?l06`3o0002003o00X0o`000P000?l40?l00080oh002@3o00000`3oP000o`00
0?l000020?l000kooooo0P3o000<003o00P0o`00<000o`050?l00080003o103o00000`3oP0000?l0
003o0004003o0080o`000`00o`020?n000d00?l01@3o00020?n000D00?l02@3o00020?n000L00?l0
3_ooool40?l00003003o003o0000o`0000@0o`000P000?l<0?l00080oh001@3o00020?n00080o`00
0P000?l00`3o0000003o0000o`020?n000@0003o00<0o`000?n0003oP0001P3o0003003o00T0o`00
0P3oP0090?l000<0003o1P3oP002003o00030?l000000?l0003o00@0o`000P3oP0000`3o0000oh00
0?n000060?l000030000o`3o0000o`0000@0003o00<0o`000?n0003oP00010000?l50?n000@0o`00
0P3oP0030?l00080003o3_ooool40?l000<0oh001000o`030?l00080003o0P3o00040000o`<0oh00
1000o`000`000?l0o`000?l000020?l00080oh000P3o00000`3oP0000?l0003o00060?l000030000
o`3o0000o`0000H0oh001`000?l20?l000030?n0003o0000o`000080o`000`000?l60?n000D0o`00
0P3oP0040000o`<0oh001P000?l50?n000D0003o103oP002003o00<0o`0010000?l70?n000@0003o
0`3oP0020?l001Sooooo000Fooooo`800?l06@3o0002003o00D0o`000P3oP0030?l00080oh000P00
o`020?l000800?l05@3o00020000o`<0o`000P3oP00K0?l00080oh000P00o`0>0?l00080oh002`3o
00000`3oP000o`000?l000020?l000kooooo3P00o`080?l000L00?l01@3o000M003o0080o`0000<0
0?l00?l0003o00000P00o`050?l000@0003o0P3o00000`3oP0000?l0003o0004003o0080o`000`00
o`020?n000L00?l0103o0002003o00D0o`000P3oP009003o00D0o`000P3oP007003o00kooooo2@00
o`020?l00080003o0`3o00020?n000@0o`000`000?l20?l00080oh000`3o00020?n00080o`000P3o
P0000`3o0000003o0000o`060000o`030?l0003oP000oh000080o`000P00o`020?l000<00?l02@3o
00020?n000L0o`001@000?l60?n000<0o`000P000?l40?l00080oh0000<0o`000?n0003oP0001P3o
00000`000?l0o`000?l000020?l00080oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P00
0?l40?l00080oh000`3o00020000o`kooooo0P3o00070?n000L0o`001`3oP006003o00<0003o0P3o
00020?n000800?l000<0o`00003o0000o`00103oP0020?l000030000o`3oP000oh000080o`000P3o
P0020?l000030?n000000?l0003o00@0003o0`3oP002003o0080o`000`000?l60?n000D0o`001000
0?l20?l000<0oh001P000?l30?n00080o`000P3oP0020?l000030000o`3oP000oh000080oh000P3o
00000`3oP000o`000?l000020?n000@0o`001@3oP0020?l000D0oh000P3o000Hooooo`005_ooool2
003o0200o`000P3oP0030?l00080oh000P00o`020?l000800?l0403o00020?n001h0o`000P00o`05
0?l00080oh00403o00020?n000T0o`000P3oP0050?l000kooooo3P00o`060?l000T00?l01@3o0002
0?n001D00?l02`3o00020?n000<00?l00P3o00040000o`80o`0000<0oh00003o0000o`001P00o`03
0?l00080oh002@00o`020?l000800?l01@3o00020?n000T00?l01@3o00020?n000L00?l03_ooool4
0?l000L00?l00P000?l30?l00080oh000P00o`020?l000<0003o103oP0070?l000<0oh001P000?l5
0?n00080o`001@00o`090?l00080003o1@3oP002003o0080o`001@000?l60?n00100o`000P000?l2
0?l000<0003o0P3o00020?n000<00?l00P3oP002003o0080oh0000<0o`000000o`000?l0103o0002
0?n000030?l000000?l0003o0080003o3_ooool20000o`L0oh00103o00000`3oP000o`000?l00002
0?n00080o`000`3oP006003o00<0003o0P3o00020?n000800?l000<0oh000?l0003o0000103oP002
0?l000030000o`3oP000oh000080o`000P3oP0020?l000030?n000000?l0003o00@0003o0`3oP004
0?l000<0003o103oP0020?l00080oh000`3o00040000o`80o`0000<0oh000?l0003o000010000?l5
0?n00080o`000P3oP0030?l000@0oh000P3o00000`3oP000o`000?l000020?l00080oh000`3o0004
0?n000D0o`000P3oP0020?l001Sooooo000Fooooo`800?l0803o00020?n000<0o`000P3oP002003o
0080o`000P00o`0@0?l00080oh007P3o0002003o00D0o`000P3oP00@0?l00080oh002@3o00020?n0
00D0o`003_ooool>003o00H0o`002@00o`050?l00080oh005@00o`0;0?l00080oh000`00o`020?l0
00@0003o0P3o00000`3oP0000?l0003o0006003o00<0o`000P3oP009003o0080o`000P00o`050?l0
0080oh002@00o`050?l00080oh001`00o`0>ooooo`@0o`001`00o`020000o`<0o`000P3oP002003o
0080o`000`000?l40?n000L0o`000`3oP0060000o`D0oh000P3o0005003o00T0o`000P000?l50?n0
00800?l00P3o00050000o`H0oh00403o00020000o`80o`000`000?l20?l00080oh000`00o`020?n0
00800?l00P3oP0000`3o0000003o0000o`040?l00080oh0000<0o`000000o`000?l00P000?l>oooo
o`80003o1`3oP0040?l000030?n0003o0000o`000080oh000P3o00030?n000H00?l00`000?l20?l0
0080oh000P00o`000`3oP000o`000?l000040?n00080o`0000<0003o0?n0003oP0000P3o00020?n0
0080o`0000<0oh000000o`000?l010000?l30?n000@0o`000`000?l40?n00080o`000P3oP0030?l0
00@0003o0P3o00000`3oP000o`000?l000040000o`D0oh000P3o00020?n000<0o`00103oP0020?l0
00030?n0003o0000o`000080o`000P3oP0030?l000@0oh001@3o00020?n00080o`006?ooool001Ko
oooo0P00o`0P0?l00080oh001@3o0002003o0280o`000P3oP00@0?l00080oh001@3o00020?n000D0
o`000P00o`090?l00080oh002@3o00020?n000D0o`003_ooool50?l000T00?l01P3o0009003o00D0
o`00103oP00C003o00H0o`000P000?l00`3oP000o`000?l000020?n000<00?l00P3o00040000o`80
o`0000<0oh00003o0000o`002@00o`020?n000d00?l01@3o00020?n000<00?l00P3o0004003o00D0
o`000P3oP007003o00kooooo103o00000`3oP0000?l0003o0004003o00D0o`000P3oP002003o00L0
o`000P3oP0050?l000D0oh001P000?l50?n00080o`001@00o`090?l000@0003o0P3o00000`3oP000
o`000?l00002003o00D0003o103oP00>0?l00080003o0P3o00020000o`80o`000`000?l20?l00080
oh0000<00?l00?l0003o00000P3oP004003o00030?l000000?l0003o0080003o0P3o00070000o`ko
oooo0P3oP0020?l000D0oh0010000?l00`3oP000o`000?l000020?n000D0o`00103oP002003o00<0
003o0P3o00020?n000800?l02@3o00000`000?l0oh000?n000060?n000<0o`0010000?l30?n00080
0?l00P3o00030000o`P0oh000`3o00040000o`80o`0000<0oh000?l0003o000010000?l30?n000H0
o`000P3oP0000`3o0000oh000?n000020?n000<0o`001P3oP0030?l00080oh000P00o`040?n000D0
o`006?ooool001Kooooo0P00o`0P0?l00080oh001@3o0002003o0280o`000P3oP00@0?l00080oh00
1@3o00020?n000D0o`000P00o`090?l00080oh002@3o00020?n000D0o`003_ooool50?l000T00?l0
1P3o0009003o00D0o`00103oP00C003o00H0o`000P000?l00`3oP000o`000?l000020?n000<00?l0
0P3o00040000o`80o`0000<0oh00003o0000o`002@00o`020?n000d00?l01@3o00020?n000<00?l0
0P3o0004003o00D0o`000P3oP007003o00kooooo103o00000`3oP0000?l0003o0004003o00D0o`00
0P3oP002003o00L0o`000P3oP0050?l000D0oh001P000?l50?n00080o`001@00o`090?l000@0003o
0P3o00000`3oP000o`000?l00002003o00D0003o103oP00>0?l00080003o0P3o00020000o`80o`00
0`000?l20?l00080oh0000<00?l00?l0003o00000P3oP004003o00030?l000000?l0003o0080003o
0P3o00070000o`kooooo0P3oP0020?l000D0oh0010000?l00`3oP000o`000?l000020?n000D0o`00
103oP002003o00<0003o0P3o00020?n000800?l02@3o00000`000?l0oh000?n000060?n000<0o`00
10000?l30?n000800?l00P3o00030000o`P0oh000`3o00040000o`80o`0000<0oh000?l0003o0000
10000?l30?n000H0o`000P3oP0000`3o0000oh000?n000020?n000<0o`001P3oP0030?l00080oh00
0P00o`040?n000D0o`006?ooool001Kooooo0P00o`070?l000800?l0403o0002003o00D0o`001@00
o`020?l000800?l08P3o00020?n001h0o`000P3oP0090?l00080oh002@3o00020?n000D0o`003_oo
ool50?l000H00?l00P3o00000`00o`00o`000?l0000=003o00L0o`000P3oP00>003o00@0o`0000<0
0?l00?l0003o00000P000?l20?l00080003o00<0oh000?l0003o00000P3oP002003o00<0o`001000
0?l20?l000030?n00000o`000?l000H00?l00`3o00020?n001L00?l00P3o0004003o00D0o`000P3o
P007003o00kooooo103o00000`3oP0000?l0003o00070?l000800?l04P3o00020?n000<0o`001P00
0?l50?n000L00?l00P3o0004003o00<0o`000P000?l40?l000030?n00000o`000?l000800?l01@00
0?l40?n00080o`001`000?l40?l000`0003o103oP0050?l000@00?l00`3o00020000o`80o`001@00
0?l20?n000kooooo103oP0000`3o0000oh000?n000020?l000T0oh001@3o00040?n000800?l00`00
0?l20?l00080oh000P3o00000`000?l0o`000?l000020?l00080oh000P3o00030000o`@0oh000P3o
00000`3oP000o`000?l000020?n00080003o1@3oP0020?l000<0003o203oP0030?l00080003o0P3o
P0020?l000030?n0003o0000o`000080oh000P3o00020?n000L0o`000P3oP0030?l00080oh000P00
0?l00`3o0000oh000?n000060?n000030?l0003oP000oh0000800?l01`3oP0020000oaSooooo000F
ooooo`800?l01`3o0002003o0100o`000P00o`050?l000D00?l00P3o0002003o0280o`000P3oP00N
0?l00080oh002@3o00020?n000T0o`000P3oP0050?l000kooooo1@3o0006003o0080o`0000<00?l0
0?l0003o00003@00o`070?l00080oh003P00o`040?l00003003o003o0000o`000080003o0P3o0002
0000o`030?n0003o0000o`000080oh000P00o`030?l000@0003o0P3o00000`3oP0000?l0003o0006
003o00<0o`000P3oP00G003o0080o`001000o`050?l00080oh001`00o`0>ooooo`@0o`0000<0oh00
003o0000o`001`3o0002003o0180o`000P3oP0030?l000H0003o1@3oP007003o0080o`001000o`03
0?l00080003o103o00000`3oP0000?l0003o0002003o00D0003o103oP0020?l000L0003o103o000<
0000o`@0oh001@3o0004003o00<0o`000P000?l20?l000D0003o0P3oP00>ooooo`@0oh0000<0o`00
0?n0003oP0000P3o00090?n000D0o`00103oP002003o00<0003o0P3o00020?n00080o`0000<0003o
0?l0003o00000P3o00020?n00080o`000`000?l40?n00080o`0000<0oh000?l0003o00000P3oP002
0000o`D0oh000P3o00030000o`P0oh000`3o00020000o`80oh000P3o00000`3oP000o`000?l00002
0?n00080o`000P3oP0070?l00080oh000`3o00020?n00080003o00<0o`000?n0003oP0001P3oP000
0`3o0000oh000?n00002003o00L0oh000P000?lHooooo`005_ooool2003o01L0o`000P3oP002003o
00D0o`001000o`1B0?l00080oh00403o000>ooooo`800?l00`3o0004003o00@0o`0000<00?l00?l0
003o00003P00o`060?l00080oh002P00o`080?l00003003o003o0000o`000080003o0P3o00030?n0
0080o`000P3oP002003o00<0o`0010000?l20?l000030?n00000o`000?l000H00?l000<0o`00003o
0000o`000P3oP00E003o00@0o`001000o`050?l000T00?l03_ooool20?l000<0oh004@3o00000`3o
P000o`000?l000070?l00080oh000P00o`030?l000@0003o0P3o00030?n00080o`001000o`020?l0
00L00?l02@3o00000`3oP000o`000?l000020?l000D0003o103oP0020?l000<0003o103oP0040?l0
00<0003o0P3o00050000o`H0oh001`3o0002003o00<0o`002@000?l20?n000kooooo103oP0000`3o
0000003o0000o`020000o`D0oh000P3o00060?n000030?l0003oP000oh000080oh000P3o00030000
o`80o`00103oP0000`000?l0o`000?l000020?l00080oh000P3o00030000o`80o`000P3oP0020?l0
00030?n0003o0000o`000080oh000P3o00020?n000030?l0003oP000oh000080o`000`000?l80?n0
00030?l0003oP000oh000080003o103o00000`3oP000o`000?l000040?l00080oh0000<00?l00?l0
003o0000103o00020?n000<0o`000P3oP0020?l000`0oh000P00o`020?n00080003o1@3oP00Hoooo
o`005_ooool4003o00X0o`000P3oP0020?l000800?l01@3o00020?n000800?l000<0o`00003o0000
o`000P3o0004003o02<0o`000P00o`0?0?l000030?n0003o0000o`0000L0o`000P00o`0B0?l00080
oh00403o000>ooooo`D0o`001000o`020?l001<00?l0103o0002003o0080oh002P00o`060?l00080
oh0000<00?l00?l0003o0000103o00030?n00080o`000P3oP003003o0080o`0010000?l20?l00003
0?n00000o`000?l000H00?l000<0o`00003o0000o`000P3oP00E003o00H0o`000P00o`000`3o0000
0?l0003o0007003o0080o`000P00o`0>ooooo`800?l00`3o0002003o00T0o`000P000?l40?l00003
0?n00000o`000?l000L0o`000P3oP0050?l000@0003o0P3o00020?n000<0o`001000o`020?l000L0
0?l00P000?l30?l00080oh000P3o00000`00o`00o`000?l000020?l000D0003o103oP0020?l00080
003o00<0o`000000o`000?l02`3o00050000o`80oh000P000?l70?l00080oh001`3o00070000o`80
oh003_ooool40?n000030?l000000?l0003o0080003o1@3oP0040?l00080oh000P000?l30?l00080
oh000P3o00000`000?l0o`000?l000020?l000@0oh000`000?l20?l00080oh000P3o00000`000?l0
o`000?l000020?l00080oh000P3o00000`000?l0o`000?l000020?n00080o`000P000?l00`3o0000
oh000?n000020?n000<0003o203oP0000`3o0000oh000?n000020?n000@0o`0000<0oh000?l0003o
0000103o00020?n000<00?l00P000?l50?l000@0oh000P3o00030?n00080o`001`3oP004003o0080
003o1@3oP00Hooooo`005_ooool4003o00X0o`000P3oP0020?l000800?l01@3o00020?n000800?l0
00<0o`00003o0000o`000P3o0004003o02<0o`000P00o`0?0?l000030?n0003o0000o`0000L0o`00
0P00o`0B0?l00080oh00403o000>ooooo`D0o`001000o`020?l001<00?l0103o0002003o0080oh00
2P00o`060?l00080oh0000<00?l00?l0003o0000103o00030?n00080o`000P3oP003003o0080o`00
10000?l20?l000030?n00000o`000?l000H00?l000<0o`00003o0000o`000P3oP00E003o00H0o`00
0P00o`000`3o00000?l0003o0007003o0080o`000P00o`0>ooooo`800?l00`3o0002003o00T0o`00
0P000?l40?l000030?n00000o`000?l000L0o`000P3oP0050?l000@0003o0P3o00020?n000<0o`00
1000o`020?l000L00?l00P000?l30?l00080oh000P3o00000`00o`00o`000?l000020?l000D0003o
103oP0020?l00080003o00<0o`000000o`000?l02`3o00050000o`80oh000P000?l70?l00080oh00
1`3o00070000o`80oh003_ooool40?n000030?l000000?l0003o0080003o1@3oP0040?l00080oh00
0P000?l30?l00080oh000P3o00000`000?l0o`000?l000020?l000@0oh000`000?l20?l00080oh00
0P3o00000`000?l0o`000?l000020?l00080oh000P3o00000`000?l0o`000?l000020?n00080o`00
0P000?l00`3o0000oh000?n000020?n000<0003o203oP0000`3o0000oh000?n000020?n000@0o`00
00<0oh000?l0003o0000103o00020?n000<00?l00P000?l50?l000@0oh000P3o00030?n00080o`00
1`3oP004003o0080003o1@3oP00Hooooo`005_ooool4003o01D0o`000P3oP002003o00030?l00000
o`000?l000@0o`000P00o`0S0?l000800?l03`3o00000`3oP000o`000?l00002003o0080o`000P00
o`000`3o00000?l0003o000=0?l000030000o`3o0000o`0000T0o`001000o`050?l00080oh003_oo
ool20?l000800?l000<0o`00003o0000o`000P00o`020?l001<00?l01P3o00020?n000X00?l01P3o
00020?n000<00?l00P3oP002003o0080o`0000<0oh00003o0000o`000P3o0005003o00@0003o0P3o
00000`3oP0000?l0003o0002003o00D0o`006@00o`080?l000030?n00000o`000?l000/00?l03_oo
ool4003o00030?n00000o`000?l000T0o`000P3oP0040?l000030?n0003o0000o`0000L0o`000P3o
P0050?l000@0003o103oP0030?l000@00?l00P3o0007003o00<0003o0P3o00020?n000L0o`001@00
0?l40?n00080o`000P000?l00`3o0000003o0000o`090?l00080oh000P000?l30?l000@0oh001`3o
00020?n000L0o`000P000?l20?l000D0003o3_ooool40?n000<0o`000P000?l50?n00080o`00103o
P0020000o`030?l0003oP000oh000080oh001@3o00020000o`@0oh000`000?l20?l00080oh000P3o
00030000o`80o`000P3oP0020?l000<0003o103oP0020000o`030?l0003oP000oh000080oh000P3o
00000`000?l0oh000?n000060?n000<0o`00103oP0020?l000030?n0003o0000o`0000@0o`000P3o
P0030?l00080003o103o000:0?n000800?l00P3o00050?n00080o`000P3oP0020?l000030?n0003o
0000o`000080oh006?ooool001Kooooo1000o`0E0?l00080oh000P00o`000`3o00000?l0003o0004
0?l000800?l08`3o0002003o00l0o`0000<0oh000?l0003o00000P00o`020?l000800?l000<0o`00
003o0000o`003@3o00000`000?l0o`000?l000090?l000@00?l01@3o00020?n000kooooo0P3o0002
003o00030?l00000o`000?l000800?l00P3o000C003o00H0o`000P3oP00:003o00H0o`000P3oP003
003o0080oh000P00o`020?l000030?n00000o`000?l00080o`001@00o`040000o`80o`0000<0oh00
003o0000o`000P00o`050?l001T00?l0203o00000`3oP0000?l0003o000;003o00kooooo1000o`00
0`3oP0000?l0003o00090?l00080oh00103o00000`3oP000o`000?l000070?l00080oh001@3o0004
0000o`@0oh000`3o0004003o0080o`001`00o`030000o`80o`000P3oP0070?l000D0003o103oP002
0?l00080003o00<0o`000000o`000?l02@3o00020?n00080003o0`3o00040?n000L0o`000P3oP007
0?l00080003o0P3o00050000o`kooooo103oP0030?l00080003o1@3oP0020?l000@0oh000P000?l0
0`3o0000oh000?n000020?n000D0o`000P000?l40?n000<0003o0P3o00020?n00080o`000`000?l2
0?l00080oh000P3o00030000o`@0oh000P000?l00`3o0000oh000?n000020?n00080o`0000<0003o
0?n0003oP0001P3oP0030?l000@0oh000P3o00000`3oP000o`000?l000040?l00080oh000`3o0002
0000o`@0o`002P3oP002003o0080o`001@3oP0020?l00080oh000P3o00000`3oP000o`000?l00002
0?n001Sooooo000Fooooo`T0o`000P3oP003003o03/0o`000P3oP00I0?l000800?l01P3o00000`3o
P000o`000?l000040?l000030000o`3o0000o`000180o`000P3oP00>ooooo`80o`006`00o`070?l0
0080oh002P00o`060?l00080oh000`00o`020?n000800?l00`3o0002003o0080o`001@00o`040000
o`80o`0000<0oh00003o0000o`000P00o`050?l00080oh005`00o`080?l000030?n00000o`000?l0
00/00?l03_ooool4003o00030?n00000o`000?l000@00?l01@3o00020?n00080o`000P3oP0080?l0
00@00?l02@3o00040?n000<0o`003@00o`030000o`80o`000P3oP0070?l000@0003o00<0o`000000
o`000?l00P000?l20?l000<0oh000P000?l40?l00080oh002P3o00020?n00080003o0`3o00020?n0
00H0o`0000<0003o0?l0003o00000P3o00020000o`80o`001@000?l>ooooo`D0o`0010000?l50?n0
0080o`000P3oP0040000o`D0oh000`3o00080?n000<0003o103oP0020?l000<0003o0P3o00020?n0
0080o`000`000?l20?n00080o`000P000?l30?l00080oh000P3o00000`000?l0oh000?n000020?l0
0080oh000P3o00000`3oP000o`000?l000040?n000<0o`000P3oP0020000o`80o`000`3oP0020?l0
00@0003o0P3o00050?n000800?l000<0oh000?l0003o00001000o`050?n00080o`000P3oP0050?l0
0080oh006?ooool001Kooooo2@3o00020?n000<00?l0>`3o00020?n001T0o`000P00o`060?l00003
0?n0003o0000o`0000@0o`0000<0003o0?l0003o00004P3o00020?n000kooooo0P3o000K003o00L0
o`000P3oP00:003o00H0o`000P3oP003003o0080oh000P00o`030?l000800?l00P3o0005003o00@0
003o0P3o00000`3oP0000?l0003o0002003o00D0o`000P3oP00G003o00P0o`0000<0oh00003o0000
o`002`00o`0>ooooo`@00?l000<0oh00003o0000o`001000o`050?l00080oh000P3o00020?n000P0
o`001000o`090?l000@0oh000`3o000=003o00<0003o0P3o00020?n000L0o`0010000?l00`3o0000
003o0000o`020000o`80o`000`3oP0020000o`@0o`000P3oP00:0?l00080oh000P000?l30?l00080
oh001P3o00000`000?l0o`000?l000020?l00080003o0P3o00050000o`kooooo1@3o00040000o`D0
oh000P3o00020?n000@0003o1@3oP0030?l000P0oh000`000?l40?n00080o`000`000?l20?l00080
oh000P3o00030000o`80oh000P3o00020000o`<0o`000P3oP0020?l000030000o`3oP000oh000080
o`000P3oP0020?l000030?n0003o0000o`0000@0oh000`3o00020?n00080003o0P3o00030?n00080
o`0010000?l20?l000D0oh000P00o`000`3oP000o`000?l00004003o00D0oh000P3o00020?n000D0
o`000P3oP00Hooooo`005_ooool;0?l000800?l01@3o0002003o00L0o`000P3oP0090?l00003003o
003o0000o`0000L0o`000P00o`0[0?l00080oh004P3o00020?n000030000o`3o0000o`000080o`00
0P3oP00>0?l00080oh003_ooool20?n000L00?l00P3o000@003o00T0o`000P3oP00:003o00H0o`00
0P3oP003003o0080oh000P00o`030?l000800?l00P3o0005003o0080003o103o00000`3oP0000?l0
003o0002003o00D0o`000P3oP00K003o00@0o`0000<0oh00003o0000o`002`00o`0>ooooo`80oh00
2@00o`090?l00080oh00203o0004003o00/0o`000P000?l30?l000L00?l00P3o0004003o00<0003o
0P3o00020?n000D0o`000P3oP0050?l000@0003o0P3o00030?n00080003o103o00020?n000030?l0
0000o`000?l000@00?l02P3o00020?n000800?l0103o00000`000?l0o`000?l000020?l00080003o
0P3o00050000o`kooooo1@3o00020?n00080o`000P000?l20?l000<0oh000P3o00040000o`D0oh00
0`3o00040?n00080o`000`000?l20?l00080oh00103o00030?n00080o`00103oP0030000o`80o`00
103oP0030?l000/0oh000P3o00000`3oP000o`000?l000020?l00080oh000`3o00020?n00080003o
0P3o00020000o`030?n0003o0000o`000080oh0010000?l80?n000@0o`000P00o`030?l00080oh00
0P000?l40?l000030?n0003o0000o`000080o`006?ooool001Kooooo2`3o0002003o00D0o`000P00
o`070?l00080oh002@3o00000`00o`00o`000?l000070?l000800?l0:`3o00020?n00180o`000P3o
P0000`000?l0o`000?l000020?l00080oh003P3o00020?n000kooooo0P3oP007003o0080o`004000
o`090?l00080oh002P00o`060?l00080oh000`00o`020?n000800?l00`3o0002003o0080o`001@00
o`020000o`@0o`0000<0oh00003o0000o`000P00o`050?l00080oh006`00o`040?l000030?n00000
o`000?l000/00?l03_ooool20?n000T00?l02@3o00020?n000P0o`001000o`0;0?l00080003o0`3o
0007003o0080o`001000o`030000o`80o`000P3oP0050?l00080oh001@3o00040000o`80o`000`3o
P0020000o`@0o`000P3oP0000`3o00000?l0003o0004003o00X0o`000P3oP002003o00@0o`0000<0
003o0?l0003o00000P3o00020000o`80o`001@000?l>ooooo`D0o`000P3oP0020?l00080003o0P3o
00030?n00080o`0010000?l50?n000<0o`00103oP0020?l000<0003o0P3o00020?n000@0o`000`3o
P0020?l000@0oh000`000?l20?l000@0oh000`3o000;0?n00080o`0000<0oh000?l0003o00000P3o
00020?n000<0o`000P3oP0020000o`80o`000P000?l00`3oP000o`000?l000020?n000@0003o203o
P0040?l000800?l00`3o00020?n00080003o103o00000`3oP000o`000?l000020?l001Sooooo000F
ooooo`/0o`000P00o`0P0?l000D00?l00P3o0002003o02h0o`000P3oP00K0?l00080oh000`3o0002
0?n00080o`003_ooool9003o0080o`001`00o`020?l000L00?l02@3o00020?n000X00?l0203o000C
003o00H0o`0000<0oh00003o0000o`001P00o`000`3o0000oh000?n0000K003o00T0o`002@00o`0>
ooooo`80oh001@00o`020?l000800?l02@3o00020?n000030?l000000?l0003o00@0o`0000<0oh00
003o0000o`000P00o`050?l00080003o103o00030000o`80oh001P00o`030?l000@00?l00P000?l3
0?l00080oh000`3o00040?n000D0o`001P000?l30?n000@0003o0P3o00020?n000030?l00000o`00
0?l000d0o`001`00o`020?l000<0003o0P3oP0020000o`<0o`0010000?l>ooooo`@0o`0000<00?l0
0?n0003oP0002@3oP0020?l000@0003o1@3oP0050?l00080oh000P3o00030000o`80o`000P3oP005
0?l00080oh000P3o00020?n000800?l000<0o`000000o`000?l00P3o00020?n000D0o`00103oP000
0`3o0000oh000?n000020?l00080oh000P3o00000`3oP000o`000?l000020?l00080oh001@3o0007
0000o`@0oh000P000?l<0?n00080o`000P00o`030?l000@0003o0P3o00030?n00080003o0P3o000H
ooooo`005_ooool2003o00<0o`000P00o`090?l000@00?l05@3o0007003o00@0o`000P00o`0;0?l0
00030?n00000o`000?l000/0o`000P000?l:0?l00080oh001`3o00020?n001/0o`000P3oP0030?l0
00800?l00P3o000>oooooa/00?l00P3oP0090?l000X00?l01P3o00020?n001400?l01P3o0002003o
00030?l00000o`000?l000800?l00P3o000B003o0080o`003000o`0;0?l000L00?l03_ooool20?n0
00D00?l01`3o0006003o0080oh00203o0006003o00<0o`0010000?l20?l00080oh0000<0o`000?n0
003oP0001P00o`050?l000800?l00P000?l30?l00080oh000`3o00020?n000@0o`002@000?l30?n0
0080003o103o00020?n000030?l00000o`000?l000d0o`001`00o`020?l000<0003o0P3o00040000
o`030?l000000?l0003o0080003o3_ooool40?n00003003o003o0000o`000080oh000P3o00050?n0
0080o`000P3oP0020?l000D0oh000`3o00040?n000D0003o103oP0020?l000D0oh000P00o`020?n0
00800?l01@3o00020?n000<0o`000P000?l20?n00080o`000`3oP0020000o`@0o`0000<0oh000?l0
003o00000P3o00020?n000T0o`001@000?l60?n000030?l0003oP000oh0000@0003o00<0o`000?n0
003oP0002@3o00020?n000@0o`001@000?lHooooo`005_ooool2003o00<0o`000P00o`090?l000@0
0?l05@3o0007003o00@0o`000P00o`0;0?l000030?n00000o`000?l000/0o`000P000?l:0?l00080
oh001`3o00020?n001/0o`000P3oP0030?l000800?l00P3o000>oooooa/00?l00P3oP0090?l000X0
0?l01P3o00020?n001400?l01P3o0002003o00030?l00000o`000?l000800?l00P3o000B003o0080
o`003000o`0;0?l000L00?l03_ooool20?n000D00?l01`3o0006003o0080oh00203o0006003o00<0
o`0010000?l20?l00080oh0000<0o`000?n0003oP0001P00o`050?l000800?l00P000?l30?l00080
oh000`3o00020?n000@0o`002@000?l30?n00080003o103o00020?n000030?l00000o`000?l000d0
o`001`00o`020?l000<0003o0P3o00040000o`030?l000000?l0003o0080003o3_ooool40?n00003
003o003o0000o`000080oh000P3o00050?n00080o`000P3oP0020?l000D0oh000`3o00040?n000D0
003o103oP0020?l000D0oh000P00o`020?n000800?l01@3o00020?n000<0o`000P000?l20?n00080
o`000`3oP0020000o`@0o`0000<0oh000?l0003o00000P3o00020?n000T0o`001@000?l60?n00003
0?l0003oP000oh0000@0003o00<0o`000?n0003oP0002@3o00020?n000@0o`001@000?lHooooo`00
5_ooool7003o00T0o`000P00o`020?l000800?l05`3o0002003o01X0o`000P000?l40?l00080003o
0`3o00020?n000h0o`000P3oP00F0?l000030?n0003o0000o`0000/0o`003_oooolK003o0080oh00
1`3o000<003o00H0o`001`00o`020?l000X00?l01P3o0002003o00<0o`000P00o`020?n000T00?l0
0P3o0003003o0080oh004000o`0=0?l000D00?l03_ooool20?n000<00?l02`3o0004003o0080oh00
00<00?l00?l0003o00002@3o0002003o00<0o`0010000?l20?l00080003o00<0o`000?n0003oP000
1P00o`0<0?l00080oh001`3o0002003o00<0003o0P3o00040000o`<0oh00103o00040?n000<00?l0
103o00020000o`030?l000000?l0003o0080oh000P3o0003003o00H0o`001@000?l20?n00080003o
00<0o`000000o`000?l00P000?l>ooooo`@0oh0000<00?l00?l0003o00000P3oP0020?l00080oh00
00<0o`000?n0003oP0000P000?l40?l000030?n0003o0000o`000080oh001@3o00020?n000@0003o
1@3oP0020?l000D0oh000P00o`020?n000800?l00`3o00060?n000030?l000000?l0003o0080oh00
0`3o00040?n000T0o`000P3oP0030?l000@0oh000P3o00030000o`80oh000P3o00020000o`80o`00
00<0003o0?n0003oP0001@000?l20?n000@0o`000`000?l20?l00080oh000P00o`020?l000D0003o
6?ooool001Kooooo1`00o`090?l000800?l00P3o0002003o01L0o`000P00o`0J0?l00080003o103o
00020000o`<0o`000P3oP00>0?l00080oh005P3o00000`3oP000o`000?l0000;0?l000kooooo6`00
o`020?n000L0o`003000o`060?l000L00?l00P3o000:003o00H0o`000P00o`030?l000800?l00P3o
P009003o0080o`000`00o`020?n001000?l03@3o0005003o00kooooo0P3oP003003o00/0o`001000
o`020?n00003003o003o0000o`0000T0o`000P00o`030?l000@0003o0P3o00020000o`030?l0003o
P000oh0000H00?l0303o00020?n000L0o`000P00o`030000o`80o`0010000?l30?n000@0o`00103o
P003003o00@0o`000P000?l00`3o0000003o0000o`020?n00080o`000`00o`060?l000D0003o0P3o
P0020000o`030?l000000?l0003o0080003o3_ooool40?n00003003o003o0000o`000080oh000P3o
00020?n000030?l0003oP000oh000080003o103o00000`3oP000o`000?l000020?n000D0o`000P3o
P0040000o`D0oh000P3o00050?n000800?l00P3oP002003o00<0o`001P3oP0000`3o0000003o0000
o`020?n000<0o`00103oP0090?l00080oh000`3o00040?n00080o`000`000?l20?n00080o`000P00
0?l20?l000030000o`3oP000oh0000D0003o0P3oP0040?l000<0003o0P3o00020?n000800?l00P3o
00050000oaSooooo000Fooooo`80o`001@00o`0=0?l000800?l000<0o`00003o0000o`003P3o0002
0?n000@0o`000P00o`050?l00080oh004P3o00000`3oP000003o0000o`090?l00080oh003P3o0002
0?n000h0o`000P3oP00D0?l000kooooo0P00o`030?l001H00?l00P3oP0070?l000`00?l01P3o0007
003o00D0o`000P00o`020?l000800?l01`3o00020?n000<0o`000P00o`020?n000T00?l00P3o0003
003o0080oh004000o`0=0?l000030?n0003o0000o`000080o`003_ooool20?n00080o`0000<00?l0
0?l0003o0000103o00020?n000<0o`002`00o`050?l00080oh000P00o`020?l000030?n0003o0000
o`0000@0o`000P000?l00`3o0000oh000?n00006003o00`0o`000P3oP0020?l000<00?l00P3o0002
003o00<0003o103oP0040?l000030?n0003o0000o`000080o`00103oP0000`3o00000?l0003o0004
0?l000D0003o0P3oP00;0?l000D0003o0P3oP0030?l000@0003o3_ooool40?n000<0o`000P3oP002
0?l00080oh0000<0o`000?n0003oP00010000?l20?l000030?n00000o`000?l00080oh000P3o0000
0`3oP000o`000?l000020?n00080o`000P000?l50?n000T0o`000P00o`050?l000H0oh0000<0o`00
0000o`000?l00P3oP0020?l000<0oh000P000?l40?n000<0003o0P3o00090?n00080o`000P3oP003
0000o`80o`000P000?l20?l000030000o`3oP000oh000080o`000`000?l20?n00080003o0P3o0003
0000o`@0oh00103o00050000oaSooooo000Fooooo`80o`001@00o`0=0?l000800?l000<0o`00003o
0000o`003P3o00020?n000@0o`000P00o`050?l00080oh004P3o00000`3oP000003o0000o`090?l0
0080oh003P3o00020?n000h0o`000P3oP00D0?l000kooooo0P00o`030?l001H00?l00P3oP0070?l0
00`00?l01P3o0007003o00D0o`000P00o`020?l000800?l01`3o00020?n000<0o`000P00o`020?n0
00T00?l00P3o0003003o0080oh004000o`0=0?l000030?n0003o0000o`000080o`003_ooool20?n0
0080o`0000<00?l00?l0003o0000103o00020?n000<0o`002`00o`050?l00080oh000P00o`020?l0
00030?n0003o0000o`0000@0o`000P000?l00`3o0000oh000?n00006003o00`0o`000P3oP0020?l0
00<00?l00P3o0002003o00<0003o103oP0040?l000030?n0003o0000o`000080o`00103oP0000`3o
00000?l0003o00040?l000D0003o0P3oP00;0?l000D0003o0P3oP0030?l000@0003o3_ooool40?n0
00<0o`000P3oP0020?l00080oh0000<0o`000?n0003oP00010000?l20?l000030?n00000o`000?l0
0080oh000P3o00000`3oP000o`000?l000020?n00080o`000P000?l50?n000T0o`000P00o`050?l0
00H0oh0000<0o`000000o`000?l00P3oP0020?l000<0oh000P000?l40?n000<0003o0P3o00090?n0
0080o`000P3oP0030000o`80o`000P000?l20?l000030000o`3oP000oh000080o`000`000?l20?n0
0080003o0P3o00030000o`@0oh00103o00050000oaSooooo000Fooooo`@0o`0000<0oh00003o0000
o`00403o0002003o0080o`000P00o`050?l00080003o0`3o00020?n001l0o`0000<0oh000?l0003o
00000P3o00020?n002D0o`000P3oP00D0?l000kooooo1000o`000`3o00000?l0003o000D003o0080
oh001`3o000I003o0180o`000P3oP0050?l00080oh001@00o`020?l000800?l00P3o000E003o00D0
o`000P00o`0;0?l000kooooo0P3oP003003o00H0o`000P3oP0030?l000800?l01@3o0004003o0080
003o0`3o00020?n000@00?l000<0oh000?l0003o00001P000?l30?n000H00?l02@3o00000`000?l0
o`000?l000020?l00080oh001`3o00030000o`@0oh00103o00000`3oP000o`000?l000020?l00080
oh002@3o00050000o`@0oh000`3o00020000o`@0o`000`000?l20?l00080oh000P3o00000`3oP000
003o0000o`020000o`kooooo2`3o00020?n000T0003o00<0oh000?l0003o00000P3oP0020?l00003
0?n0003o0000o`0000H0o`000`3oP0040?l00080oh001@3o00020?n000D0o`001`3oP0020000o`80
o`001@000?l60?n000<0003o1P3oP0000`3o0000oh000?n000020?n000800?l00P3o00030000o`80
o`001@000?l20?n00080o`000P3oP0000`3o0000003o0000o`040?n000<0003o103oP0040?l000<0
003o0P3oP00Hooooo`005_ooool40?l000030?n00000o`000?l00100o`000P00o`020?l000800?l0
1@3o00020000o`<0o`000P3oP00O0?l000030?n0003o0000o`000080o`000P3oP00U0?l00080oh00
503o000>ooooo`@00?l000<0o`00003o0000o`005000o`020?n000L0o`006@00o`0B0?l00080oh00
1@3o00020?n000D00?l00P3o0002003o0080o`005@00o`050?l000800?l02`3o000>ooooo`80oh00
0`00o`060?l00080oh000`3o0002003o00D0o`001000o`020000o`<0o`000P3oP004003o00030?n0
003o0000o`0000H0003o0`3oP006003o00T0o`0000<0003o0?l0003o00000P3o00020?n000L0o`00
0`000?l40?n000@0o`0000<0oh000?l0003o00000P3o00020?n000T0o`001@000?l40?n000<0o`00
0P000?l40?l000<0003o0P3o00020?n00080o`0000<0oh000000o`000?l00P000?l>ooooo`/0o`00
0P3oP0090000o`030?n0003o0000o`000080oh000P3o00000`3oP000o`000?l000060?l000<0oh00
103o00020?n000D0o`000P3oP0050?l000L0oh000P000?l20?l000D0003o1P3oP0030000o`H0oh00
00<0o`000?n0003oP0000P3oP002003o0080o`000`000?l20?l000D0003o0P3oP0020?l00080oh00
00<0o`000000o`000?l0103oP0030000o`@0oh00103o00030000o`80oh006?ooool001Kooooo5P3o
00000`3oP000o`000?l000090?l00080003o0`3o00020?n002l0o`000P00o`030?l000@00?l0:@3o
000>ooooo`800?l00`3o0002003o0080oh004P00o`020?n000D0o`006`00o`050?l00080oh002`3o
0007003o0080oh001@00o`090?l00080oh004000o`050?l000800?l02`3o000>ooooo`80oh003P3o
0002003o0080o`000P00o`050?l000<0003o0P3o00020?n00080o`000P00o`000`3oP000o`000?l0
00040?l00080003o0`3oP0020?l000800?l02`3o00000`000?l0o`000?l000020?l00080oh001@3o
00050000o`@0oh000P3o0002003o00D0o`000P3oP0090?l000D0003o103oP0030?l00080003o0P3o
00020?n000<0o`000P000?l20?n00080o`0000<0oh000000o`000?l00P000?l>ooooo`@0o`001@3o
P0020?l00080oh000`000?l20?n000@0003o1@3oP0050?l00080oh00103o00030?n000@0o`000P3o
P0000`3o0000003o0000o`020?l000D0oh000P3o00040?n000L0o`000P000?l00`3o0000003o0000
o`020?n00080003o0P3oP0030000o`80o`00103oP0050?l000800?l00P3o00030?n00080o`000P00
0?l50?n00080o`000`3oP0020000o`80oh000P3o00020?n000030?l000000?l0003o0080oh00103o
00000`000?l0o`000?l000020?n001Sooooo000FoooooaH0o`0000<0oh000?l0003o0000103o0000
0`000?l0o`000?l000020?l00080oh00=03o0007003o0080o`000P00o`000`3o00000?l0003o0007
0?l000@00?l03P3o00020?n000T0o`003_ooool50?l000800?l00P3oP002003o0080o`003P00o`02
0?n000D0o`006`00o`020000o`<0o`000P3oP0050?l00080oh00103o000<003o00H0o`000P3oP005
0?l001000?l0103o0005003o0080o`000P00o`050?l000kooooo0P3oP00@0?l000D00?l0103o0003
0000o`80o`000P3oP0040?l000030?n0003o0000o`0000H0003o1@3oP002003o00<0o`001000o`04
0?l000030000o`3o0000o`000080oh001@3o00060000o`D0oh000P3o0002003o00D0o`000P3oP005
0?l00080oh000P3o00050000o`@0oh000`3o00020000o`80o`000P3oP0030?l00080003o1@3o0004
0000o`kooooo0P3o00050?n000@0o`000`3oP0080000o`D0oh001@3o00040?n00080003o00<0o`00
0?n0003oP0000P3o00020000o`80oh0000<0o`000000o`000?l00P000?l20?l000<0oh000P3o0004
0?n00080o`0000<0oh000?l0003o00000P3o00050000o`80oh000P000?l50?n00080o`00103oP003
0?l00080oh000P00o`020?l000030?n000000?l0003o0080oh000P000?l70?n000D0o`000P3oP002
0000o`80oh0000<0o`000000o`000?l00P000?l20?l00080oh000`000?l20?n001Sooooo000Foooo
oaH0o`0000<0oh000?l0003o0000103o00000`000?l0o`000?l000020?l00080oh00=03o0007003o
0080o`000P00o`000`3o00000?l0003o00070?l000@00?l03P3o00020?n000T0o`003_ooool50?l0
00800?l00P3oP002003o0080o`003P00o`020?n000D0o`006`00o`020000o`<0o`000P3oP0050?l0
0080oh00103o000<003o00H0o`000P3oP0050?l001000?l0103o0005003o0080o`000P00o`050?l0
00kooooo0P3oP00@0?l000D00?l0103o00030000o`80o`000P3oP0040?l000030?n0003o0000o`00
00H0003o1@3oP002003o00<0o`001000o`040?l000030000o`3o0000o`000080oh001@3o00060000
o`D0oh000P3o0002003o00D0o`000P3oP0050?l00080oh000P3o00050000o`@0oh000`3o00020000
o`80o`000P3oP0030?l00080003o1@3o00040000o`kooooo0P3o00050?n000@0o`000`3oP0080000
o`D0oh001@3o00040?n00080003o00<0o`000?n0003oP0000P3o00020000o`80oh0000<0o`000000
o`000?l00P000?l20?l000<0oh000P3o00040?n00080o`0000<0oh000?l0003o00000P3o00050000
o`80oh000P000?l50?n00080o`00103oP0030?l00080oh000P00o`020?l000030?n000000?l0003o
0080oh000P000?l70?n000D0o`000P3oP0020000o`80oh0000<0o`000000o`000?l00P000?l20?l0
0080oh000`000?l20?n001Sooooo000Fooooo`800?l01@3o0002003o00D0o`000P3oP0060?l00003
0?n0003o0000o`0000T0o`000P3oP00T0?l000030000o`3o0000o`000080o`000P3oP0090?l00080
oh002P3o0002003o00H0o`0000<0oh00003o0000o`00403o00020?n000T0o`003_ooool40?l00003
0?n00000o`000?l00080oh00=000o`050?l00080oh000P000?l30?l00080oh00103o000<003o00H0
o`000P3oP0050?l000h00?l01P3o0009003o00D0o`003_ooool20?n000T0o`000P3oP0070?l00080
0?l01@3o00030000o`80o`000P3oP0040?l000030?n0003o0000o`0000@0o`000P000?l00`3o0000
oh000?n000020?l000800?l00`3o0004003o00L0o`000P3oP0050?l00080oh0010000?l00`3oP000
003o0000o`040?l00080oh0000<0o`00003o0000o`001000o`050?l000T0003o103oP0030?l00080
003o0P3o00020?n000<00?l00P000?l40?l000D0003o3_ooool20?l000D0oh0010000?l30?n00080
o`001P000?l00`3oP0000?l0003o0002003o0080o`000`000?l20?l00080oh000P000?l00`3o0000
oh000?n000020?n00080003o0P3oP0030?l00080oh000P3o00030?n000@0003o0P3o00050?n00080
o`000`000?l40?n000@0003o0`3oP0040?l000<0oh000P3o00020?n000@0o`000`3oP0040000o`D0
oh000P3o00070?n00080o`000P3oP0000`3o0000003o0000o`020000o`80o`000P3oP0000`000?l0
o`000?l000020?n001Sooooo000Fooooo`800?l01@3o0002003o00D0o`000P3oP0060?l000030?n0
003o0000o`0000T0o`000P3oP00T0?l000030000o`3o0000o`000080o`000P3oP0090?l00080oh00
2P3o0002003o00H0o`0000<0oh00003o0000o`00403o00020?n000T0o`003_ooool40?l000030?n0
0000o`000?l00080oh00=000o`050?l00080oh000P000?l30?l00080oh00103o000<003o00H0o`00
0P3oP0050?l000h00?l01P3o0009003o00D0o`003_ooool20?n000T0o`000P3oP0070?l000800?l0
1@3o00030000o`80o`000P3oP0040?l000030?n0003o0000o`0000@0o`000P000?l00`3o0000oh00
0?n000020?l000800?l00`3o0004003o00L0o`000P3oP0050?l00080oh0010000?l00`3oP000003o
0000o`040?l00080oh0000<0o`00003o0000o`001000o`050?l000T0003o103oP0030?l00080003o
0P3o00020?n000<00?l00P000?l40?l000D0003o3_ooool20?l000D0oh0010000?l30?n00080o`00
1P000?l00`3oP0000?l0003o0002003o0080o`000`000?l20?l00080oh000P000?l00`3o0000oh00
0?n000020?n00080003o0P3oP0030?l00080oh000P3o00030?n000@0003o0P3o00050?n00080o`00
0`000?l40?n000@0003o0`3oP0040?l000<0oh000P3o00020?n000@0o`000`3oP0040000o`D0oh00
0P3o00070?n00080o`000P3oP0000`3o0000003o0000o`020000o`80o`000P3oP0000`000?l0o`00
0?l000020?n001Sooooo000Fooooo`800?l00`3o0004003o01T0o`000P3oP0090?l000800?l05`3o
00020?n000030000o`3o0000o`000080o`000P3oP00B0?l000800?l000<0o`00003o0000o`001P3o
00000`3oP0000?l0003o000@0?l00080oh000P3o00020?n000D0o`003_ooool40?l000030?n0003o
0000o`000080oh004P00o`020?n002000?l01@3o00020?n00080003o0`3o00020?n000@0o`005000
o`050?l000h00?l0103o000;003o00D0o`003_ooool20?n000T0o`000P3oP00@0?l000030000o`3o
0000o`000080oh000P000?l20?l000030?n0003o0000o`000080o`000P3oP0030?l00080oh000P3o
0002003o0080o`0000<00?l00?l0003o00003@3o00000`3oP000o`000?l000020000o`80oh000P00
0?l00`3oP000003o0000o`040?l00080oh0000<0o`00003o0000o`000P3oP004003o00030?l00000
o`000?l00080o`001@000?l60?n000L0o`000P3oP003003o00@0003o0P3o00000`3oP000003o0000
o`020000o`kooooo0P3o00030?n00080o`0010000?l50?n000@0003o0P3o00030?n000800?l00P3o
P0030000o`80o`000P3oP0020000o`<0o`000P3oP0020000o`80oh0000<0o`000?n0003oP0000P3o
P0020?l000<0oh001P3o00020000o`<0oh001@000?l40?n000@0003o00<0o`000?n0003oP000103o
00050?n00080003o103o00000`3oP000003o0000o`040000o`<0oh000P3o00040?n000030?l0003o
P000oh0000@0o`000P3oP0000`3o0000003o0000o`040?l00080oh0000<0003o0?l0003o00000P3o
000Hooooo`005_ooool2003o00<0o`001000o`0I0?l00080oh002@3o0002003o01L0o`000P3oP000
0`000?l0o`000?l000020?l00080oh004P3o0002003o00030?l00000o`000?l000H0o`0000<0oh00
003o0000o`00403o00020?n00080o`000P3oP0050?l000kooooo103o00000`3oP000o`000?l00002
0?n001800?l00P3oP00P003o00D0o`000P3oP0020000o`<0o`000P3oP0040?l001@00?l01@3o000>
003o00@0o`002`00o`050?l000kooooo0P3oP0090?l00080oh00403o00000`000?l0o`000?l00002
0?n00080003o0P3o00000`3oP000o`000?l000020?l00080oh000`3o00020?n00080o`000P00o`02
0?l00003003o003o0000o`0000d0o`0000<0oh000?l0003o00000P000?l20?n00080003o00<0oh00
0000o`000?l0103o00020?n000030?l00000o`000?l00080oh001000o`000`3o00000?l0003o0002
0?l000D0003o1P3oP0070?l00080oh000`00o`040000o`80o`0000<0oh000000o`000?l00P000?l>
ooooo`80o`000`3oP0020?l000@0003o1@3oP0040000o`80o`000`3oP002003o0080oh000`000?l2
0?l00080oh000P000?l30?l00080oh000P000?l20?n000030?l0003oP000oh000080oh000P3o0003
0?n000H0o`000P000?l30?n000D0003o103oP0040000o`030?l0003oP000oh0000@0o`001@3oP002
0000o`@0o`0000<0oh000000o`000?l010000?l30?n00080o`00103oP0000`3o0000oh000?n00004
0?l00080oh0000<0o`000000o`000?l0103o00020?n000030000o`3o0000o`000080o`006?ooool0
01Kooooo0P00o`020?l000D00?l01@3o00020?n001d0o`000P00o`0G0?l00080oh0000<0003o0?l0
003o00000P3o00020?n00180o`000P00o`0A0?l00080oh001`3o00020?n000@0o`000P3oP0000`00
o`00o`000?l00002003o00kooooo1`3o00020?n003@00?l01`3o00020000o`<0o`000P3oP0040?l0
00L00?l00P3o0002003o00030?n0003o0000o`0000H00?l01@3o000>003o0080o`003@00o`050?l0
00kooooo0P3oP0090?l00080oh003P3o00020000o`<0o`000P3oP0020000o`80o`0000<0oh000000
o`000?l00P3o00020?n000<0o`000P3oP0020?l000800?l00P3o00000`00o`00o`000?l0000=0?l0
00030?n0003o0000o`000080003o0P3oP0020000o`030?l000000?l0003o00@0003o0P3oP0030?l0
0080oh001000o`000`3o00000?l0003o00020?l000D0003o103oP0090?l00080oh000`00o`020000
o`@0o`0000<0oh000000o`000?l00P000?l>ooooo`80o`000`3oP0020?l000@0003o0`3oP0020?l0
00@0003o0P3o00030?n000800?l00P3o00030000o`80o`000P3oP0050?l000L0oh000P3o00020?n0
00800?l00P3oP0000`00o`00o`000?l000040?l000<0003o0P3oP0090000o`@0oh0000<0o`000?n0
003oP0000P00o`020?l000D0oh000P000?l20?l000<0oh000P3o00040000o`L0oh000`3o00020?n0
00@00?l00P3o00000`3oP000o`000?l000020?n00080o`000P3oP0000`000?l0o`000?l000020?n0
01Sooooo000Fooooo`80o`001`00o`050?l00080oh001`00o`0;0?l000800?l08P3o00020?n000X0
o`000P00o`0P0?l00080oh000P00o`050?l00080oh00103o0002003o00<0o`000P00o`0>ooooo`80
oh000P3o00000`3oP0000?l0003o00020?n000h00?l00P3o000T003o00@0o`0000<00?l00?l0003o
00000P000?l30?l00080oh00103o00020?n000<00?l01P3o00000`3oP000o`000?l00007003o0080
o`007`00o`050?l000kooooo0P3oP002003o00L0o`000P3oP00:0?l000@0003o1@3o00020?n000@0
003o00<0oh000000o`000?l00P3o00040?n000030?l0003oP000oh0000H0o`0000<0oh000?l0003o
0000103o00020?n00003003o003o0000o`0000@0o`0000<0oh000?l0003o00000P000?l20?n000<0
o`001P000?l20?n000030?l00000o`000?l00080oh001`00o`020?l000D0003o103oP00<0?l00080
0?l00P000?l40?l000030?n000000?l0003o0080003o3_ooool20?l00080oh000`00o`020?n000@0
o`001@000?l20?n00080o`000`3oP004003o00030000o`3o0000o`000080o`000P3oP0050?l000H0
oh000`3o00020?n000800?l00`3oP0080?l000030000o`3oP000oh000080oh000`3o00060000o`80
oh0000<0o`000?n0003oP0000P00o`020?l000D0oh00103o00050?n00080o`001`3oP0050?l00080
oh001P3o00000`3oP000o`000?l000020?n00080o`001@3oP0020000oaSooooo000Fooooo`80o`00
1`00o`050?l00080oh001`00o`0;0?l000800?l08P3o00020?n000X0o`000P00o`0P0?l00080oh00
0P00o`050?l00080oh00103o0002003o00<0o`000P00o`0>ooooo`80oh000P3o00000`3oP0000?l0
003o00020?n000h00?l00P3o000T003o00@0o`0000<00?l00?l0003o00000P000?l30?l00080oh00
103o00020?n000<00?l01P3o00000`3oP000o`000?l00007003o0080o`007`00o`050?l000kooooo
0P3oP002003o00L0o`000P3oP00:0?l000@0003o1@3o00020?n000@0003o00<0oh000000o`000?l0
0P3o00040?n000030?l0003oP000oh0000H0o`0000<0oh000?l0003o0000103o00020?n00003003o
003o0000o`0000@0o`0000<0oh000?l0003o00000P000?l20?n000<0o`001P000?l20?n000030?l0
0000o`000?l00080oh001`00o`020?l000D0003o103oP00<0?l000800?l00P000?l40?l000030?n0
00000?l0003o0080003o3_ooool20?l00080oh000`00o`020?n000@0o`001@000?l20?n00080o`00
0`3oP004003o00030000o`3o0000o`000080o`000P3oP0050?l000H0oh000`3o00020?n000800?l0
0`3oP0080?l000030000o`3oP000oh000080oh000`3o00060000o`80oh0000<0o`000?n0003oP000
0P00o`020?l000D0oh00103o00050?n00080o`001`3oP0050?l00080oh001P3o00000`3oP000o`00
0?l000020?n00080o`001@3oP0020000oaSooooo000Fooooo`@0o`0000<0oh00003o0000o`000P00
o`090?l000D00?l02@3o0002003o00/0o`000P3oP00>0?l00080oh001`3o00020?n000X0o`000P00
o`0=0?l000800?l01@3o00020?n001L0o`001000o`030?l000800?l03_ooool20?n00080o`0000<0
oh00003o0000o`001P00o`050?l00080oh000`00o`060?l000D00?l0103o000G003o00@0o`0000<0
0?l00?l0003o00000P000?l30?l00080oh00103o00020?n000030?l00000o`000?l000H0o`0000<0
oh000?l0003o00001`00o`020?l001l00?l01@3o000>ooooo`80oh000P00o`070?l00080oh001`3o
0002003o00030?l000000?l0003o0080003o0P3oP0030?l00080oh002`000?l30?n000800?l03@3o
00020?n00003003o003o0000o`0000L0o`000P000?l20?n000<0o`001P000?l20?n000030?l00000
o`000?l00080oh000P00o`070?l000D0003o103oP0020000o`T0o`000`00o`070?l000@0003o3_oo
ool20?l000D00?l00P3oP002003o0080oh000`000?l20?l00080oh000P000?l00`3o0000oh000?n0
00020?n00080o`0000<0oh000?l0003o00000P3o00020?n000L0o`00103oP0000`3o0000oh000?n0
00020?n00080o`000`3oP0090?l000@0oh001`3o00040?n000D00?l02`3o00020?n000D0o`001`3o
P0040?l000<00?l01P3o00000`3oP000o`000?l000020?l00080oh000P3o00030?n00080003o6?oo
ool001Kooooo103o00000`3oP0000?l0003o0002003o00T0o`001@00o`090?l000800?l02`3o0002
0?n000h0o`000P3oP0070?l00080oh002P3o0002003o00d0o`000P00o`050?l00080oh005`3o0004
003o00<0o`000P00o`0>ooooo`80oh000P3o00000`3oP0000?l0003o0006003o00D0o`000P3oP003
003o00H0o`001@00o`040?l001L00?l0103o00000`00o`00o`000?l000020000o`<0o`000P3oP004
0?l00080oh0000<0o`00003o0000o`001P3o00000`3oP000o`000?l00007003o0080o`007`00o`05
0?l000kooooo0P3oP002003o00L0o`000P3oP0070?l000800?l000<0o`000000o`000?l00P000?l2
0?n000<0o`000P3oP00;0000o`<0oh000P00o`0=0?l00080oh0000<00?l00?l0003o00001`3o0002
0000o`80oh000`3o00060000o`80oh0000<0o`00003o0000o`000P3oP002003o00L0o`001@000?l4
0?n00080003o2@3o0003003o00L0o`0010000?l>ooooo`80o`001@00o`020?n000800?l00P3oP003
0000o`80o`000P3oP0020000o`030?l0003oP000oh000080oh000P3o00000`3oP000o`000?l00002
0?l00080oh001`3o00040?n000030?l0003oP000oh000080oh000P3o00030?n000T0o`00103oP007
0?l000@0oh001@00o`0;0?l00080oh001@3o00070?n000@0o`000`00o`060?l000030?n0003o0000
o`000080o`000P3oP0020?l000<0oh000P000?lHooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05
oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolGo`3o00Cooooo5ol00?l4oooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o01oooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo
0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKo
o`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`001?oooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l0
07oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol0
07lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOoo`001?l0
07lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol0
07l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo0004oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1Co`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1C
o`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o01go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;oooooL_l0000Wooooog7o00009ooooomao`0002Oooooo
L_l0000Sooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool20?l000800?l0
803o00030?n000T0o`000P00o`020?l000D0oh007@3o00020?n000D0o`001P3oP00<0?l000@0oh00
1@3o00050?n000@0o`000P3oP0070?l000kooooo3@3o000C003o00L0o`003@00o`0E0?l000800?l0
0P3o000>003o00T0o`003@00o`0D0?l00003003o003o0000o`0000800?l03_ooool20?l003/00?l0
0P3o0005003o00/0o`003P00o`070?l001@00?l02@3o0007003o0080o`003_ooool>0?n00080o`00
5P3oP0000`3o0000oh000?n000090?n00080o`00103oP0000`3o0000oh000?n0000]0?n000@0o`00
1@3oP0020?l001L0oh006?ooool001Kooooo0P3o0002003o0200o`000`3oP0090?l000800?l00P3o
00050?n001d0o`000P3oP0050?l000H0oh00303o00040?n000D0o`001@3oP0040?l00080oh001`3o
000>ooooo`d0o`004`00o`070?l000d00?l05@3o0002003o0080o`003P00o`090?l000d00?l0503o
00000`00o`00o`000?l00002003o00kooooo0P3o000k003o0080o`001@00o`0;0?l000h00?l01`3o
000D003o00T0o`001`00o`020?l000kooooo3P3oP0020?l001H0oh0000<0o`000?n0003oP0002@3o
P0020?l000@0oh0000<0o`000?n0003oP000;@3oP0040?l000D0oh000P3o000G0?n001Sooooo000F
ooooo`@0o`0000<00?l00?l0003o00007@3o00020?n000h0o`001@3oP0060?l00080oh001`3o0000
0`3oP000o`000?l000060?l000<0oh000P3o00020?n00200o`001@3oP0040?l000T0oh003_ooool;
0?l001<00?l02@3o0008003o00030?l00000o`000?l000/0o`000P00o`090?l000<00?l00P3o000B
003o00@0o`003P00o`0D0?l000D00?l03_ooool50?l003@00?l0203o0007003o00L0o`004P00o`07
0?l000h00?l01P3o00000`00o`00o`000?l000040?l000L00?l03_oooolB0?n00080o`00<03oP005
0?l00440oh006?ooool001Kooooo103o00000`00o`00o`000?l0000M0?l00080oh003P3o00050?n0
00H0o`000P3oP0070?l000030?n0003o0000o`0000H0o`000`3oP0020?l00080oh00803o00050?n0
00@0o`002@3oP00>ooooo`/0o`004`00o`090?l000P00?l000<0o`00003o0000o`002`3o0002003o
00T0o`000`00o`020?l001800?l0103o000>003o01@0o`001@00o`0>ooooo`D0o`00=000o`080?l0
00L00?l01`3o000B003o00L0o`003P00o`060?l00003003o003o0000o`0000@0o`001`00o`0>oooo
oa80oh000P3o000`0?n000D0o`00@@3oP00Hooooo`005_ooool>0?l00080oh009P3o00050?n000@0
o`000`3oP0020?l000800?l00P3o00030?n000@0o`002@3oP0020?l000030?n0003o0000o`0001d0
o`000`3oP0060?l000L0oh003_ooool50?l000800?l00P3o000=003o00D0o`001`00o`020?l00080
0?l000<0o`00003o0000o`000P00o`020?l000800?l000<0o`00003o0000o`001000o`070?l000@0
0?l0203o000]003o00H0o`0000<00?l00?l0003o00000P00o`040?l000<00?l00P3o000>ooooo`T0
o`00<000o`020?l000800?l01@3o0006003o00L0o`003P00o`090?l001T00?l00P3o0009003o00ko
oooo4P3oP0040?l001h0oh001@3o00090?n00180o`007@3oP0030?l001H0oh006?ooool001Kooooo
403o00020?n000D0o`000P3oP00O0?l000<0oh003P3o00040?n000@0o`001@3oP0040?l000030?n0
003o0000o`0000@0o`000P3oP00R0?l000D0oh003_ooool2003o00L0o`003P00o`040?l001/00?l0
0P3o0003003o0080o`001000o`0<0?l002800?l00P3o0003003o00H0o`000P00o`030?l000800?l0
103o0005003o00kooooo1`3o000;003o00D0o`004000o`060?l000/00?l00`3o0004003o0080o`00
2000o`020?l000800?l0103o000^003o0080o`002@00o`0>ooooo`d0oh001`3o000T0?n000030?l0
003oP000oh000480oh000P3o00090?n00080o`006?ooool001Kooooo403o00020?n000D0o`000P3o
P00O0?l000<0oh003P3o00040?n000@0o`001@3oP0040?l000030?n0003o0000o`0000@0o`000P3o
P00R0?l000D0oh003_ooool2003o00L0o`003P00o`040?l001/00?l00P3o0003003o0080o`001000
o`0<0?l002800?l00P3o0003003o00H0o`000P00o`030?l000800?l0103o0005003o00kooooo1`3o
000;003o00D0o`004000o`060?l000/00?l00`3o0004003o0080o`002000o`020?l000800?l0103o
000^003o0080o`002@00o`0>ooooo`d0oh001`3o000T0?n000030?l0003oP000oh000480oh000P3o
00090?n00080o`006?ooool001Kooooo2`3o0002003o01<0o`00103oP00^0?l000@0oh00103o0003
0?n000@0o`000P3oP00>0?l00080oh003P3o0002003o00D0o`000P3oP00>ooooo`@00?l000<0o`00
003o0000o`00>P00o`0<0?l001/00?l01`3o0005003o0080o`000P00o`040?l000h00?l03_ooool7
0?l000/00?l0103o000A003o00P0o`001@00o`090?l000`00?l02@3o000]003o0080o`002@00o`0>
oooooa80oh000P3o000P0?n000@0o`003P3oP0030?l00440oh006?ooool001Kooooo2`3o0002003o
01<0o`00103oP00^0?l000@0oh00103o00030?n000@0o`000P3oP00>0?l00080oh003P3o0002003o
00D0o`000P3oP00>ooooo`@00?l000<0o`00003o0000o`00>P00o`0<0?l001/00?l01`3o0005003o
0080o`000P00o`040?l000h00?l03_ooool70?l000/00?l0103o000A003o00P0o`001@00o`090?l0
00`00?l02@3o000]003o0080o`002@00o`0>oooooa80oh000P3o000P0?n000@0o`003P3oP0030?l0
0440oh006?ooool001Kooooo1@3o00020?n000@0o`000P00o`0N0?l00080oh00=P3o00000`3oP000
o`000?l0000;0?l000D0oh00503o000>oooooc/00?l02@3o0002003o00<0o`000P00o`020?l000D0
0?l00P3o000D003o0080o`008000o`0>ooooo`L0o`002`00o`040?l00003003o003o0000o`0000@0
0?l000<0o`00003o0000o`000P00o`020?l000L00?l00P3o0003003o0080o`000P00o`050?l00100
0?l02`3o0006003o00030?l00000o`000?l00080o`009000o`030?l000@00?l03_oooolB0?n00080
o`007P3oP0040?l00180oh0000<0o`000?n0003oP0002`3oP0040?l00300oh006?ooool001Kooooo
1@3o00020?n000@0o`000P00o`0N0?l00080oh00=P3o00000`3oP000o`000?l0000;0?l000D0oh00
503o000>oooooc/00?l02@3o0002003o00<0o`000P00o`020?l000D00?l00P3o000D003o0080o`00
8000o`0>ooooo`L0o`002`00o`040?l00003003o003o0000o`0000@00?l000<0o`00003o0000o`00
0P00o`020?l000L00?l00P3o0003003o0080o`000P00o`050?l001000?l02`3o0006003o00030?l0
0000o`000?l00080o`009000o`030?l000@00?l03_oooolB0?n00080o`007P3oP0040?l00180oh00
00<0o`000?n0003oP0002`3oP0040?l00300oh006?ooool001Kooooo1@3o00020?n000@0o`000P00
o`0N0?l00080oh001`3o00040?n000h0o`000`3oP00J0?l000030?n0003o0000o`000100o`00103o
P00<0?l000800?l00P3o000>ooooob800?l00P3o000R003o0080o`000`00o`070?l002l00?l00P3o
0007003o00kooooo1@3o0004003o0080o`000`00o`080?l000L00?l000<0o`00003o0000o`000P00
o`020?l000<00?l0103o0002003o00`0o`004000o`0;0?l000H00?l000<0o`00003o0000o`001`00
o`040?l000800?l01@3o0002003o0080o`0000<00?l00?l0003o00001P3o0007003o00<0o`000P00
o`020?l000koooooQP3oP0020?l00080oh006?ooool001Kooooo1`3o00020?n00080o`000P00o`00
0`3o0000oh000?n0000V0?l00080oh00403o00000`3oP000o`000?l0000V0?l00080oh000`3o0006
0?n000D0o`00103oP0050?l000kooooo8P00o`020?l001D00?l01P3o000<003o00L0o`004@00o`07
0?l000X00?l00P3o0007003o0080o`000P00o`040?l000<00?l00P3o000>ooooo`80o`001`00o`02
0?l000<00?l0203o000<003o0080o`002@00o`050?l000H00?l000<0o`00003o0000o`001000o`03
0?l000L00?l03@3o000@003o0080o`001000o`030?l000800?l00P3o00000`00o`00o`000?l00009
0?l000@00?l01`3o000>ooooogH0oh000P3o000B0?n001Sooooo000Fooooo`L0o`000P3oP0020?l0
00800?l000<0o`000?n0003oP0009P3o00020?n00100o`0000<0oh000?l0003o00009P3o00020?n0
00<0o`001P3oP0050?l000@0oh001@3o000>ooooob800?l00P3o000E003o00H0o`003000o`070?l0
01400?l01`3o000:003o0080o`001`00o`020?l000800?l0103o0003003o0080o`003_ooool20?l0
00L00?l00P3o0003003o00P0o`003000o`020?l000T00?l01@3o0006003o00030?l00000o`000?l0
00@00?l00`3o0007003o00d0o`004000o`020?l000@00?l00`3o0002003o0080o`0000<00?l00?l0
003o00002@3o0004003o00L0o`003_oooomf0?n00080o`004P3oP00Hooooo`005_ooool2003o0080
o`0000<00?l00?l0003o00002@3o00040?n00100o`000`00o`0M0?l000800?l00P3o00030?n000H0
o`000`3oP00K0?l000800?l01`3o00040?n000L0o`000`3oP0040?l000kooooo8000o`040?l000D0
0?l00P3o000@003o0080o`002`00o`0<0?l001800?l00P3o000D003o00T0o`001@00o`0>ooooo`T0
0?l00P3o000G003o0080o`001@00o`070?l000l00?l00`3o0009003o00T0o`003@00o`0B0?l00003
003o003o0000o`0000T0o`001`00o`040?l000koooooE03oP0020?l001T0oh000P3o000I0?n001So
oooo000Fooooo`800?l00P3o00000`00o`00o`000?l000090?l000@0oh00403o0003003o01d0o`00
0P00o`020?l000<0oh001P3o00030?n001/0o`000P00o`070?l000@0oh001`3o00030?n000@0o`00
3_oooolP003o00@0o`001@00o`020?l001000?l00P3o000;003o00`0o`004P00o`020?l001@00?l0
2@3o0005003o00kooooo2@00o`020?l001L00?l00P3o0005003o00L0o`003`00o`030?l000T00?l0
2@3o000=003o0180o`0000<00?l00?l0003o00002@3o0007003o00@0o`003_oooomD0?n00080o`00
6@3oP0020?l001T0oh006?ooool001Kooooo0P00o`0@0?l00080oh002@3o00000`00o`00o`000?l0
000?0?l00003003o003o0000o`000200o`00103oP0040?l000030?n0003o0000o`0000d0o`000P00
o`0G0?l000<0oh00103o000>oooooah00?l03@3o000D003o00<0o`001000o`070?l000@0oh000`3o
000?003o00<0o`003@00o`070?l000800?l02@3o0005003o00kooooo8P00o`020?l000D00?l0103o
000B003o0080o`002P00o`090?l000/00?l0103o0007003o0080o`001@00o`020?l00003003o003o
0000o`0000T0o`002@00o`020?l000kooooo5P3oP0050?l00080oh0000<0o`000?n0003oP000903o
P0020?l000`0oh001P3o000W0?n000@0o`001`3oP00Hooooo`005_ooool2003o0100o`000P3oP009
0?l00003003o003o0000o`0000l0o`0000<00?l00?l0003o0000803o00040?n000@0o`0000<0oh00
0?l0003o00003@3o0002003o01L0o`000`3oP0040?l000kooooo7P00o`0=0?l001@00?l00`3o0004
003o00L0o`00103oP0030?l000l00?l00`3o000=003o00L0o`000P00o`090?l000D00?l03_oooolR
003o0080o`001@00o`040?l001800?l00P3o000:003o00T0o`002`00o`040?l000L00?l00P3o0005
003o0080o`0000<00?l00?l0003o00002@3o0009003o0080o`003_oooolF0?n000D0o`000P3oP000
0`3o0000oh000?n0000T0?n00080o`00303oP0060?l002L0oh00103o00070?n001Sooooo000Foooo
oad0o`0000<00?l00?l0003o00002`3o00020?n000D0o`001P3oP00L0?l00080oh002`3o00020?n0
02L0o`003_oooolN003o0080o`000P00o`090?l001/00?l01@3o00060?n000D0o`003@00o`000`3o
00000?l0003o000=003o00030?l00000o`000?l000H00?l02@3o0005003o00kooooo3P00o`020?l0
01T00?l00P3o000D003o0080o`008000o`030?l002@00?l00P3o000>oooooaH0oh001@3o001_0?n0
01Sooooo000Foooooad0o`0000<00?l00?l0003o00002`3o00020?n000D0o`001P3oP00L0?l00080
oh002`3o00020?n002L0o`003_oooolN003o0080o`000P00o`090?l001/00?l01@3o00060?n000D0
o`003@00o`000`3o00000?l0003o000=003o00030?l00000o`000?l000H00?l02@3o0005003o00ko
oooo3P00o`020?l001T00?l00P3o000D003o0080o`008000o`030?l002@00?l00P3o000>oooooaH0
oh001@3o001_0?n001Sooooo000Foooooa00o`000P3oP00;0?l00003003o003o0000o`0001@0o`00
1@3oP0040?l00080oh00;P3o00020?n001/0o`003_oooolR003o00T0o`002`00o`020?l001400?l0
3@3o000V003o00T0o`001@00o`0>ooooobL00?l0103o000V003o00030?l00000o`000?l000d00?l0
1`3o0002003o0080o`007000o`020?l000kooooo5`3oP0040?l006l0oh006?ooool001Kooooo1@00
o`060?l000800?l000<0o`000?n0003oP0000P3oP00G0?l000800?l02`3o00030?n001H0o`000P3o
P00B0?l000030?n0003o0000o`000080o`000P3oP0030?l000@0oh001`3o00020?n00100o`003_oo
oolN003o0080o`000P00o`040?l001800?l02@3o0008003o00d0o`000P00o`020?l001X00?l00P3o
0004003o00h0o`000P00o`0>ooooobL00?l00P3o000R003o00L0o`005000o`060?l000h00?l00P3o
000>003o00kooooo7P3oP0020?l00180oh000P3o00070?n00080o`000P3oP0020?l004T0oh006?oo
ool001Kooooo1@00o`060?l000800?l000<0o`000?n0003oP0000P3oP00G0?l000800?l02`3o0003
0?n001H0o`000P3oP00B0?l000030?n0003o0000o`000080o`000P3oP0030?l000@0oh001`3o0002
0?n00100o`003_oooolN003o0080o`000P00o`040?l001800?l02@3o0008003o00d0o`000P00o`02
0?l001X00?l00P3o0004003o00h0o`000P00o`0>ooooobL00?l00P3o000R003o00L0o`005000o`06
0?l000h00?l00P3o000>003o00kooooo7P3oP0020?l00180oh000P3o00070?n00080o`000P3oP002
0?l004T0oh006?ooool001Kooooo1@00o`0;0?l000@0oh002@3o00000`00o`00o`000?l0000H0?l0
00030?n0003o0000o`0001@0o`000P3oP00N0?l000@0oh001@3o00040?n000h0o`003_oooolN003o
0080o`000P00o`040?l00003003o003o0000o`0001000?l00P3o0002003o00L0o`001@00o`0;0?l0
00@00?l00P3o000R003o00X0o`001000o`0>ooooobT00?l00P3o000M003o00X0o`004@00o`090?l0
00h00?l00`3o000=003o00kooooo803oP0020?l00100oh000P3o001F0?n001Sooooo000Fooooo`D0
0?l02`3o00040?n000T0o`0000<00?l00?l0003o0000603o00000`3oP000o`000?l0000D0?l00080
oh007P3o00040?n000D0o`00103oP00>0?l000kooooo7P00o`020?l000800?l0103o00000`00o`00
o`000?l0000@003o0080o`000P00o`070?l000D00?l02`3o0004003o0080o`008P00o`0:0?l000@0
0?l03_oooolY003o0080o`007@00o`0:0?l001400?l02@3o000>003o00<0o`003@00o`0>ooooob00
oh000P3o000@0?n00080o`00EP3oP00Hooooo`005_ooool4003o01h0o`000P3oP00;0?l00003003o
003o0000o`000080o`000P00o`0L0?l000@0oh006@3o00040?n000D0o`00103oP0070?l000<0oh00
103o000>oooooah00?l01P3o000E003o0080o`000P00o`070?l000L00?l00P3o0002003o0080o`00
00<00?l00?l0003o0000:@00o`090?l000@00?l03_ooool70?l000l00?l000<0o`00003o0000o`00
3P00o`040?l001h00?l02@3o000A003o00X0o`002`00o`050?l000800?l00P3o0002003o00<0o`00
1000o`0>oooooaL0oh000P3o000R0?n00080o`001`3oP0020?l004@0oh006?ooool001Kooooo1000
o`0N0?l00080oh002`3o00000`00o`00o`000?l000020?l000800?l0703o00040?n001T0o`00103o
P0050?l000@0oh001`3o00030?n000@0o`003_oooolN003o00H0o`005@00o`020?l000800?l01`3o
0007003o0080o`000P00o`020?l00003003o003o0000o`0002T00?l02@3o0004003o00kooooo1`3o
000?003o00030?l00000o`000?l000h00?l0103o000N003o00T0o`004@00o`0:0?l000/00?l01@3o
0002003o0080o`000P00o`030?l000@00?l03_oooolG0?n00080o`008P3oP0020?l000L0oh000P3o
00140?n001Sooooo000Fooooo`@00?l0303o0002003o0080o`000P00o`0C0?l00080oh009`3o0004
0?n001T0o`00103oP0070?l00080oh001`3o00050?n00080o`003_oooolN003o00P0o`006@00o`02
0?l000P00?l0103o0002003o0080o`001`00o`020?l00003003o003o0000o`0002800?l00P3o0002
003o00<0o`001000o`0>ooooo`D00?l00P3o000@003o0080o`003P00o`040?l002000?l01`3o000A
003o00030?l00000o`000?l000@0o`003P00o`0>0?l000@00?l03_ooooli0?n000H0o`001@3oP002
0?l002h0oh001P3o000@0?n001Sooooo000Fooooo`@00?l0303o0002003o0080o`000P00o`0C0?l0
0080oh009`3o00040?n001T0o`00103oP0070?l00080oh001`3o00050?n00080o`003_oooolN003o
00P0o`006@00o`020?l000P00?l0103o0002003o0080o`001`00o`020?l00003003o003o0000o`00
02800?l00P3o0002003o00<0o`001000o`0>ooooo`D00?l00P3o000@003o0080o`003P00o`040?l0
02000?l01`3o000A003o00030?l00000o`000?l000@0o`003P00o`0>0?l000@00?l03_ooooli0?n0
00H0o`001@3oP0020?l002h0oh001P3o000@0?n001Sooooo000Fooooo`@00?l01`3o0002003o00L0
o`000P00o`0C0?l000@0oh008P3o0002003o00030?l0003oP000oh000080oh00103o00030?n001T0
o`000P00o`070?l000800?l00P3o00050?n00080o`003_oooolm003o00@0o`002P00o`020?l000@0
0?l000<0o`00003o0000o`001P00o`030?l002800?l01`3o0004003o00kooooo2`00o`020?l000`0
0?l00P3o000<003o0080o`001000o`020?l001`00?l01`3o000O003o0080o`001@00o`070?l00080
0?l02@3o000>ooooo`/0oh000P3o000g0?n000@0o`00<03oP0040?l000h0oh006?ooool001Kooooo
1000o`030?l00080oh001`3o00020?n001@0o`0000<00?l00?l0003o00000P3o00040?n000T0o`00
00<00?l00?l0003o00000P3o00020?n001`0o`000P3oP00@0?l00080oh002@3o0002003o0100o`00
3_oooolN003o0080o`000P00o`020?l001L00?l0103o0002003o00030?l00000o`000?l000L00?l0
0P3o0002003o0080o`006`00o`000`3o00000?l0003o000@003o00L0o`001000o`0>ooooo`800?l0
0P3o00000`00o`00o`000?l0000=003o00L0o`000P00o`000`3o00000?l0003o0009003o00L0o`00
4@00o`000`3o00000?l0003o0007003o00/0o`004000o`040?l000D00?l02`3o0002003o00h0o`00
3_ooool@0?n00080o`00DP3oP0020?l00180oh001@3o000=0?n001Sooooo000Fooooo`@00?l00`3o
00020?n000L0o`000P3oP00D0?l00003003o003o0000o`000080o`00103oP0090?l00003003o003o
0000o`000080o`000P3oP00L0?l00080oh00403o00020?n000T0o`000P00o`0@0?l000kooooo7P00
o`020?l000800?l00P3o000G003o00@0o`000P00o`000`3o00000?l0003o0007003o0080o`000P00
o`020?l001/00?l000<0o`00003o0000o`004000o`070?l000@00?l03_ooool2003o0080o`0000<0
0?l00?l0003o00003@00o`070?l000800?l000<0o`00003o0000o`002@00o`070?l001400?l000<0
o`00003o0000o`001`00o`0;0?l001000?l0103o0005003o00/0o`000P00o`0>0?l000kooooo403o
P0020?l00580oh000P3o000B0?n000D0o`003@3oP00Hooooo`005_ooool4003o00`0o`00103oP00B
0?l00003003o003o0000o`0001@0o`00103oP0050?l000<0oh00:P3o00000`00o`00o`000?l0000D
0?l000koooooF000o`020?l002L00?l01@3o0004003o00kooooo0P00o`020?l000X00?l00P3o0004
003o00L0o`002@00o`0<0?l001400?l000<0o`00003o0000o`001`00o`090?l001d00?l01`3o0009
003o0080o`000P00o`050?l000kooooo8P3oP0040?l001`0oh001P3o000`0?n00080o`000P3oP003
0?l000/0oh006?ooool001Kooooo1000o`0<0?l000@0oh004P3o00000`00o`00o`000?l0000D0?l0
00@0oh001@3o00030?n002X0o`0000<00?l00?l0003o0000503o000>oooooeP00?l00P3o000W003o
00D0o`001000o`0>ooooo`800?l00P3o000:003o0080o`001000o`070?l000T00?l0303o000A003o
00030?l00000o`000?l000L00?l02@3o000M003o00L0o`002@00o`020?l000800?l01@3o000>oooo
ob80oh00103o000L0?n000H0o`00<03oP0020?l00080oh000`3o000;0?n001Sooooo000Fooooo`@0
0?l000<0o`000?n0003oP0007`3o00000`00o`00o`000?l0000M0?l000D0oh00103o00030?n00240
o`0000<00?l00?l0003o00003`3o00000`00o`00o`000?l000020?l000kooooo103o000d003o00T0
o`006@00o`000`3o00000?l0003o000R003o00T0o`000P00o`0>ooooo`@0o`004000o`090?l000L0
0?l0303o000A003o00<0o`000P00o`020?l000<00?l00P3o000F003o00<0o`000P00o`020?l00080
0?l000<0o`00003o0000o`001000o`030?l000800?l01`3o0002003o00T0o`003_ooool;0?n00080
o`00LP3oP0020?l000D0oh00103o000Hooooo`005_ooool4003o00030?l0003oP000oh0001l0o`00
00<00?l00?l0003o00007@3o00050?n000@0o`000`3oP00Q0?l00003003o003o0000o`0000l0o`00
00<00?l00?l0003o00000P3o000>ooooo`@0o`00=000o`090?l001T00?l000<0o`00003o0000o`00
8P00o`090?l000800?l03_ooool40?l001000?l02@3o0007003o00`0o`004@00o`030?l000800?l0
0P3o0003003o0080o`005P00o`030?l000800?l00P3o0002003o00030?l00000o`000?l000@00?l0
0`3o0002003o00L0o`000P00o`090?l000kooooo2`3oP0020?l00780oh000P3o00050?n000@0o`00
6?ooool001Kooooo1000o`030?n001l0o`0000<00?l00?l0003o00007`3o00030?n000@0o`001@3o
P00T0?l000@0oh001@3o00020?n000L0o`003_oooolN003o00H0o`005`00o`060?l003h00?l01`3o
0004003o00kooooo0P00o`020?l000`00?l02`3o0002003o00<0o`000P00o`090?l00080oh000`3o
000A003o00<0o`000P00o`020?l001000?l00P3o000:003o00H0o`002@00o`0<0?l000T00?l00P3o
000>ooooo`d0o`005@3oP0040?l002L0oh000P3o000^0?n000H0o`000P3oP0050?l001Sooooo000F
ooooo`@00?l000<0o`000?n0003oP0000P3oP0040?l000<0oh005P3o00000`00o`00o`000?l00006
0?l00003003o003o0000o`000180o`000P00o`020?l000<0oh001P3o00000`3oP000o`000?l0000V
0?l00080oh001@3o00040?n000D0o`003_oooolP003o0080o`004000o`020?l000D00?l0203o000k
003o00030?l00000o`000?l000L0o`001000o`0>ooooo`800?l00P3o000<003o0080o`000P00o`07
0?l000T00?l03P3o000?003o00030?l00000o`000?l000800?l00P3o00000`00o`00o`000?l00002
0?l000@00?l000<0o`00003o0000o`003`00o`070?l000T00?l02@3o00000`00o`00o`000?l0000;
003o00koooooL`3oP0000`3o0000oh000?n000090?n000@0o`001`3oP00Hooooo`005_ooool4003o
00030?l0003oP000oh000080oh00103o00030?n001H0o`0000<00?l00?l0003o00001P3o00000`00
o`00o`000?l0000B0?l000800?l00P3o00030?n000H0o`0000<0oh000?l0003o00009P3o00020?n0
00D0o`00103oP0050?l000kooooo8000o`020?l001000?l00P3o0005003o00P0o`00>`00o`000`3o
00000?l0003o00070?l000@00?l03_ooool2003o0080o`003000o`020?l000800?l01`3o0009003o
00h0o`003`00o`000`3o00000?l0003o0002003o0080o`0000<00?l00?l0003o00000P3o0004003o
00030?l00000o`000?l000l00?l01`3o0009003o00T0o`0000<00?l00?l0003o00002`00o`0>oooo
og<0oh0000<0o`000?n0003oP0002@3oP0040?l000L0oh006?ooool001Kooooo1000o`090?l000D0
oh00:@3o00060?n000P0o`000P3oP00;0?l000800?l00P3o00000`3oP000o`000?l0000=0?l00080
0?l00`3o0002003o0180o`000`3oP0040?l000kooooo>@00o`080?l000X00?l00P3o000G003o0080
o`005`00o`040?l000800?l00`3o0004003o00kooooo4P00o`050?l000800?l00P3o0007003o0100
o`005000o`020?l00003003o003o0000o`0000/0o`001@00o`020?l000@00?l01`3o000<003o0080
o`000P00o`070?l000/00?l03_oooom80?n000030?l0003oP000oh000380oh000P3o000;0?n001So
oooo000Fooooo`@00?l02@3o00050?n002T0o`001P3oP0080?l00080oh002`3o0002003o0080o`00
00<0oh000?l0003o00003@3o0002003o00<0o`000P00o`0B0?l000<0oh00103o000>ooooocT00?l0
203o000:003o0080o`005`00o`020?l001L00?l0103o0002003o00<0o`001000o`0>oooooa800?l0
1@3o0002003o0080o`001`00o`0@0?l001@00?l00P3o00000`00o`00o`000?l0000;0?l000D00?l0
0P3o0004003o00L0o`003000o`020?l000800?l01`3o000;003o00koooooB03oP0000`3o0000oh00
0?n0000b0?n00080o`002`3oP00Hooooo`005_ooool4003o01L0o`000P00o`0K0?l00003003o003o
0000o`0000H0oh0000<0o`000?n0003oP0000P3oP00>0?l000@00?l00P3o00030?n002P0o`0000<0
oh000?l0003o00000P3o000>ooooo`L00?l00P3o000_003o00030?l00000o`000?l000H00?l000<0
o`00003o0000o`001`00o`040?l003/00?l03_oooolF003o00030?l00000o`000?l00080o`002`00
o`000`3o00000?l0003o00090?l001/00?l02@3o0005003o0080o`001000o`070?l000/00?l03P3o
0009003o00koooooB03oP0000`3o0000oh000?n0000o0?n001Sooooo000Fooooo`@00?l05`3o0002
003o01/0o`0000<00?l00?l0003o00001P3oP0000`3o0000oh000?n000020?n000h0o`001000o`02
0?l000<0oh00:03o00000`3oP000o`000?l000020?l000kooooo1`00o`020?l002l00?l000<0o`00
003o0000o`001P00o`000`3o00000?l0003o0007003o00@0o`00>`00o`0>oooooaH00?l000<0o`00
003o0000o`000P3o000;003o00030?l00000o`000?l000T0o`006`00o`090?l000D00?l00P3o0004
003o00L0o`002`00o`0>0?l000T00?l03_oooom80?n000030?l0003oP000oh0003l0oh006?ooool0
01Kooooo0P00o`0k0?l00080oh001@3o00040?n000D0o`000P3oP00U0?l00080oh00503o000>oooo
ocP00?l000<0o`00003o0000o`003P00o`020?l000800?l00P3o000b003o0080o`001`00o`0>oooo
ob/00?l0103o00000`00o`00o`000?l0000M003o0080o`004000o`020?l001D00?l00P3o0003003o
0080o`002`00o`0>ooooo`80o`00=P3oP0050?l004d0oh006?ooool001Kooooo0P00o`0k0?l00080
oh001@3o00040?n000D0o`000P3oP00U0?l00080oh00503o000>ooooocP00?l000<0o`00003o0000
o`003P00o`020?l000800?l00P3o000b003o0080o`001`00o`0>ooooob/00?l0103o00000`00o`00
o`000?l0000M003o0080o`004000o`020?l001D00?l00P3o0003003o0080o`002`00o`0>ooooo`80
o`00=P3oP0050?l004d0oh006?ooool001Kooooo0P00o`090?l00080oh000`3o0002003o03L0o`00
0P00o`040?l00080oh00803o0002003o00030?l0003oP000oh000080oh001@3o00020?n000@0o`00
0P00o`050?l000koooooB000o`030?l000d00?l00P3o000:003o0080o`006`00o`020?l000L00?l0
3_ooool[003o0080o`009@00o`040?l000800?l00P3o0007003o0080o`000`00o`020?l001000?l0
0P3o000@003o00kooooo6@3oP0090?l001L0oh00103o000;0?n000030?l0003oP000oh0003l0oh00
6?ooool001Kooooo0P00o`050?l000800?l00P3o00030?n000d0o`000P00o`0>0?l000800?l00`3o
00020?n001L0o`000P00o`0[0?l00080oh001@3o00040?n000T0o`003_oooomH003o0080o`009`00
o`050?l000@00?l03_ooool20?l002h00?l00P3o000b003o0080o`009000o`0>oooooa00oh001P3o
00030?n00080o`000P3oP0000`3o0000oh000?n0000K0?n000@0o`00?@3oP0000`3o0000oh000?n0
000;0?n001Sooooo000Fooooo`800?l01@3o0002003o0080o`000`3oP00=0?l000800?l03P3o0002
003o00<0o`000P3oP00G0?l000800?l0:`3o00020?n000D0o`00103oP0090?l000koooooF000o`02
0?l002L00?l01@3o0004003o00kooooo0P3o000^003o0080o`00<P00o`020?l002@00?l03_ooool@
0?n000H0o`000`3oP0020?l00080oh0000<0o`000?n0003oP0006`3oP0040?l003d0oh0000<0o`00
0?n0003oP0002`3oP00Hooooo`005_ooool2003o00/0o`000`3oP0060?l000030?n0003o0000o`00
00h0o`000P00o`040?l000800?l02P3o00020?n000/0o`000P00o`0U0?l000800?l0103o00000`00
o`00o`000?l000090?l000@0oh001`3o000>oooood@00?l01`3o000f003o00D0o`001000o`0>oooo
o`80o`00D000o`080?l001X00?l00P3o000@003o0080o`000P00o`0>ooooodP0oh0000<0o`000?n0
003oP000?`3oP00Hooooo`005_ooool2003o00/0o`000`3oP0060?l000030?n0003o0000o`0000h0
o`000P00o`040?l000800?l02P3o00020?n000/0o`000P00o`0U0?l000800?l0103o00000`00o`00
o`000?l000090?l000@0oh001`3o000>oooood@00?l01`3o000f003o00D0o`001000o`0>ooooo`80
o`00D000o`080?l001X00?l00P3o000@003o0080o`000P00o`0>ooooodP0oh0000<0o`000?n0003o
P000?`3oP00Hooooo`005_ooool2003o01@0o`0000<0oh000?l0003o0000803o00020?n000d0o`00
00<00?l00?l0003o00002@3o0002003o0100o`000P00o`050?l000@00?l0403o00040?n000030?l0
0000o`000?l000800?l03_oooolo003o0080o`0000<00?l00?l0003o00001`3o000f003o00D0o`00
1000o`0>ooooo`@0o`009`00o`020?l001h00?l00P3o0005003o00@0o`000P00o`020?l000L00?l0
0P3o000A003o0080o`005000o`0>ooooodP0oh0000<0o`000?n0003oP000?`3oP00Hooooo`005_oo
ool2003o01@0o`0000<0oh000?l0003o0000803o00020?n000d0o`0000<00?l00?l0003o00002@3o
0002003o0100o`000P00o`050?l000@00?l0403o00040?n000030?l00000o`000?l000800?l03_oo
oolo003o0080o`0000<00?l00?l0003o00001`3o000f003o00D0o`001000o`0>ooooo`@0o`009`00
o`020?l001h00?l00P3o0005003o00@0o`000P00o`020?l000L00?l00P3o000A003o0080o`005000
o`0>ooooodP0oh0000<0o`000?n0003oP000?`3oP00Hooooo`005_oooolN0?l00080oh008P3o0004
0?n000D0o`00103oP00;0?l00003003o003o0000o`0000T0o`000P00o`070?l000800?l0403o0004
0?n000D0o`003_oooold003o0080o`001`00o`0B0?l000`00?l00P3o0004003o00L0o`001`00o`02
0?l001000?l00P3o0007003o00kooooo0P00o`030?l001P00?l000<0o`00003o0000o`002`00o`02
0?l001h00?l00P3o000;003o0080o`006P00o`020?l000d00?l00P3o0005003o00kooooo803oP004
0?l002D0oh000P3o000X0?n000030?l0003oP000oh0000H0oh000`3o000;0?n001Sooooo000Foooo
oah0o`000P3oP00R0?l000@0oh001@3o00040?n000/0o`0000<00?l00?l0003o00002@3o0002003o
00L0o`000P00o`0@0?l000@0oh001@3o000>oooooc@00?l00P3o0007003o0180o`003000o`020?l0
00@00?l01`3o0007003o0080o`004000o`020?l000L00?l03_ooool2003o00<0o`006000o`000`3o
00000?l0003o000;003o0080o`007P00o`020?l000/00?l00P3o000J003o0080o`003@00o`020?l0
00D00?l03_oooolP0?n000@0o`009@3oP0020?l002P0oh0000<0o`000?n0003oP0001P3oP0030?l0
00/0oh006?ooool001Kooooo0P00o`0L0?l00080oh001P3o00000`3oP000o`000?l0000?0?l000<0
0?l0403o00060?n001D0o`000P00o`070?l000800?l00P3o00000`3oP000o`000?l0000D0?l000ko
oooo:`00o`050?l000800?l0103o0009003o00D0o`001@3oP0060?l000`00?l01P3o000Y003o00ko
oooo0P00o`030?l001P00?l000<0o`00003o0000o`00:`00o`020?l000@00?l00`3o0004003o00D0
o`00;@00o`0>ooooocP0oh0000<0o`000?n0003oP000C`3oP00Hooooo`005_ooool2003o0200o`00
0P00o`030?l00080oh000P3o0002003o0080o`0000<0oh000?l0003o00001`3o0002003o0180o`00
103oP0030?l00080oh003P3o0002003o00@0o`000P00o`030?l000800?l06@3o000>ooooocT00?l0
0P3o0004003o00L0o`001@3oP0040?l000/00?l01@3o0002003o00<0o`009P00o`0>ooooo`@00?l0
00<0o`00003o0000o`009000o`020?l002800?l01`3o000G003o0080o`003P00o`040?l000@00?l0
1@3o000>ooooogX0oh000`3o000=0?n001Sooooo000Fooooo`800?l0803o0002003o00<0o`000P3o
P0020?l000800?l00P3o00000`3oP000o`000?l000070?l000800?l04P3o00040?n000<0o`000P3o
P00>0?l000800?l0103o0002003o00<0o`000P00o`0I0?l000kooooo>@00o`020?l000@00?l01`3o
00050?n000@0o`002`00o`050?l000800?l00`3o000V003o00kooooo1000o`000`3o00000?l0003o
000T003o0080o`008P00o`070?l001L00?l00P3o000>003o00@0o`001000o`050?l000koooooNP3o
P0030?l000d0oh006?ooool001Kooooo0P00o`0Y0?l000800?l0:@3o00020?n000`0o`001000o`02
0?l000800?l00`3o0002003o00<0o`00103oP00B0?l000kooooo0P00o`020?l001L00?l00`3o000B
003o00H0o`000`00o`020?l000H00?l01`3o00000`3oP000o`000?l000020?l001@00?l00`3o000M
003o0080o`001`00o`0>ooooobH00?l000<0o`00003o0000o`000P00o`020?l000L00?l00P3o0003
003o0080o`005`00o`040?l001@00?l00P3o00000`00o`00o`000?l000040?l000L00?l01`3o0005
003o00@0o`003_oooomj0?n00080o`003P3oP00Hooooo`005_ooool2003o02T0o`000P00o`0Y0?l0
0080oh00303o0004003o0080o`000P00o`030?l000800?l00`3o00040?n00180o`003_ooool2003o
0080o`005`00o`030?l001800?l01P3o0003003o0080o`001P00o`070?l000030?n0003o0000o`00
0080o`005000o`030?l001d00?l00P3o0007003o00kooooo9P00o`000`3o00000?l0003o0002003o
0080o`001`00o`020?l000<00?l00P3o000G003o00@0o`005000o`020?l00003003o003o0000o`00
00@0o`001`00o`070?l000D00?l0103o000>ooooogX0oh000P3o000>0?n001Sooooo000FoooooaH0
o`0000<00?l00?l0003o00004P3o0002003o00L0o`000P00o`0;0?l000030?n0003o0000o`0000h0
o`000P00o`0F0?l000<00?l00P3o0002003o00T0o`000`00o`0=0?l000kooooo0P00o`020?l003h0
0?l03@3o000k003o00kooooo:`00o`020?l000<00?l00P3o0002003o00@0o`0000<00?l00?l0003o
00001000o`020?l001400?l0103o000I003o0080o`000`00o`0=0?l000D00?l0103o000>ooooocl0
oh000P3o000`0?n00080o`005`3oP00Hooooo`005_oooolF0?l00003003o003o0000o`000180o`00
0P00o`070?l000800?l02`3o00000`3oP000o`000?l0000>0?l000800?l05P3o0003003o0080o`00
0P00o`090?l000<00?l03@3o000>ooooo`800?l00P3o000n003o00d0o`00>`00o`0>ooooob/00?l0
0P3o0003003o0080o`000P00o`040?l00003003o003o0000o`0000@00?l00P3o000A003o00@0o`00
6@00o`020?l000<00?l03@3o0005003o00@0o`003_oooolo0?n00080o`00<03oP0020?l001L0oh00
6?ooool001Kooooo1@3o0002003o0180o`000P00o`0V0?l000030?n0003o0000o`0000h0o`000P00
o`040?l000<00?l04@3o0003003o00@0o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l0
00020?l00080oh001`3o000>ooooo`800?l00P3o000e003o01H0o`005@00o`020?l002@00?l03_oo
ool4003o00030?l00000o`000?l002@00?l0103o00000`00o`00o`000?l00007003o0080o`005000
o`020?l00003003o003o0000o`000080o`001@00o`040?l000T00?l0103o00000`00o`00o`000?l0
0005003o00l0o`001`00o`0>ooooocl0oh000P3o000C0?n00080o`00=03oP00Hooooo`005_ooool5
0?l000800?l03`3o00000`00o`00o`000?l00002003o03l0o`0000<00?l00?l0003o0000103o0002
003o00<0o`000P00o`040?l000<00?l01@3o0002003o00L0o`000P00o`060?l000<00?l00P3o000>
ooooo`800?l00P3o000g003o01H0o`004P00o`030?l002@00?l03_ooool[003o0080o`004P00o`02
0?l000X00?l00P3o0002003o00L0o`001@00o`040?l001D00?l02`3o0009003o0080o`003_ooool5
0?n00080o`003`3oP0030?l000T0oh00103o00000`3oP000o`000?l0001Q0?n001Sooooo000Foooo
o`D0o`000P00o`0?0?l00003003o003o0000o`0000800?l0?`3o00000`00o`00o`000?l000040?l0
00800?l00`3o0002003o00@0o`000`00o`050?l000800?l01`3o0002003o00H0o`000`00o`020?l0
00kooooo0P00o`020?l003L00?l05P3o000B003o00<0o`009000o`0>ooooob/00?l00P3o000B003o
0080o`002P00o`020?l000800?l01`3o0005003o00@0o`005@00o`0;0?l000T00?l00P3o000>oooo
o`D0oh000P3o000?0?n000<0o`002@3oP0040?l000030?n0003o0000o`000640oh006?ooool001Ko
oooo0P00o`0>0?l00080oh00103o00000`00o`00o`000?l0000V0?l000800?l06@3o00000`00o`00
o`000?l0000?0?l000<00?l01@3o0002003o00L0o`000P00o`0;0?l000kooooo>@00o`090?l00080
0?l02`3o000B003o00L0o`001000o`000`3o00000?l0003o0004003o00030?l00000o`000?l001@0
0?l03_oooolF003o00030?l00000o`000?l000@0o`003P00o`020?l002@00?l01`3o0003003o00P0
o`002@00o`030?l000@00?l0303o0009003o0080o`003_ooool20?n000T0o`00O`3oP00Hooooo`00
5_ooool2003o00h0o`000P3oP0040?l00003003o003o0000o`0002H0o`000P00o`0I0?l00003003o
003o0000o`0000l0o`000`00o`050?l000800?l01`3o0002003o00/0o`003_ooooli003o00T0o`00
0P00o`0;0?l001800?l01`3o0004003o00030?l00000o`000?l000@00?l000<0o`00003o0000o`00
5000o`0>oooooaH00?l000<0o`00003o0000o`00103o000>003o0080o`009000o`070?l000<00?l0
203o0009003o00<0o`001000o`0<0?l000T00?l00P3o000>ooooo`80oh002@3o001o0?n001Sooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?o
oooo000Rooooo`03o`000?oooooooooo01kooooo00?o0?l0ooooooooool04_ooool00ol0o`3ooooo
ooooo`03ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0?l0ooooooooool04_ooool00ol0o`3ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo00;ooooo00?o0?l0ooooooooool04oooool00ol0o`3ooooo
ooooo`0gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0o`3ooooo
ooooo`0Cooooo`03o`3o0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l0
0?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`008?oooolFo`00o`Cooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Gooooo5_ooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo000Poooo
oaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o03So001o5_l00?l4o`00OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o03So001o5_l00?l5o`00OaKoogl01?l007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o00;o001o5ooo000jo`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo
001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0>?l007lF
o`00o`Co001o5oooO`04o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0>?l007lF
o`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l0
0?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool0
07l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03
o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03
o`000?l007oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oooombo`0002Oo
ooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo000Foooooc80o`000P3oP00h0?l000<0oh006`3o000>ooooo`@0oh001@000?l40?n000X0
003o103oP0020000o`D0oh000P3o00050?n000T0003o5P3oP0050?l000@0oh001`000?l20?n00003
0000o`3oP000oh0000@0oh001@3o00040?n000<0003o5P3oP0020000o`D0oh003_ooool@0000o`80
oh00<P000?l40?n000T0003o1@3oP0070000o`L0oh0050000?l70?n000H0003o0`3oP0020000o`ko
oooo2@3oP0040?l000T0oh000`000?l20?n00080003o1@3oP0020000oa@0oh000`3o00060?n000<0
o`001@3oP0020000o`@0oh000P000?l00`3oP000003o0000o`060?n000<0o`001P3oP0000`000?l0
oh000?n000020?n00080003o0`3oP0040?l000/0oh002P3o00040?n001Sooooo000Foooooc80o`00
0P3oP00h0?l000<0oh006`3o000>ooooo`@0oh001@000?l40?n000X0003o103oP0020000o`D0oh00
0P3o00050?n000T0003o5P3oP0050?l000@0oh001`000?l20?n000030000o`3oP000oh0000@0oh00
1@3o00040?n000<0003o5P3oP0020000o`D0oh003_ooool@0000o`80oh00<P000?l40?n000T0003o
1@3oP0070000o`L0oh0050000?l70?n000H0003o0`3oP0020000o`kooooo2@3oP0040?l000T0oh00
0`000?l20?n00080003o1@3oP0020000oa@0oh000`3o00060?n000<0o`001@3oP0020000o`@0oh00
0P000?l00`3oP000003o0000o`060?n000<0o`001P3oP0000`000?l0oh000?n000020?n00080003o
0`3oP0040?l000/0oh002P3o00040?n001Sooooo000Foooooc00o`001P3oP00g0?l00080oh006`3o
000>ooooo`L0oh000P000?l20?n001<0003o2`3oP00=0000o`<0oh000P000?l40?n00080o`001`3o
P0070?l000<0oh001P000?l20?n000030000o`3oP000oh000080oh00103o00000`3oP000o`000?l0
00060?n000<0003o3@3oP0000`3o0000oh000?n000040?n00080003o1@3oP00>oooooa@0003o0P3o
P00<0000o`80oh008P000?l20?n000T0003o1@3oP0040000o``0oh002`000?l20?n000T0003o1@3o
P0090000o`kooooo2`3oP0020?l000X0oh00103o00050?n000@0003o503oP0030?l00080oh000P3o
00020?n000<0o`003P3oP0040000o`@0oh001`3o00020?n000030?l0003oP000oh0000@0oh00303o
00020?n00080o`000P3oP00:0?l000@0oh006?ooool001Kooooo<03o00060?n003L0o`000P3oP00K
0?l000kooooo1`3oP0020000o`80oh004`000?l;0?n000d0003o0`3oP0020000o`@0oh000P3o0007
0?n000L0o`000`3oP0060000o`80oh0000<0003o0?n0003oP0000P3oP0040?l000030?n0003o0000
o`0000H0oh000`000?l=0?n000030?l0003oP000oh0000@0oh000P000?l50?n000kooooo50000?l2
0?n000`0003o0P3oP00R0000o`80oh002@000?l50?n000@0003o303oP00;0000o`80oh002@000?l5
0?n000T0003o3_ooool;0?n00080o`002P3oP0040?l000D0oh0010000?lD0?n000<0o`000P3oP002
0?l00080oh000`3o000>0?n000@0003o103oP0070?l00080oh0000<0o`000?n0003oP000103oP00<
0?l00080oh000P3o00020?n000X0o`00103oP00Hooooo`005_oooon:0?l000kooooo103oP00C0000
o`@0oh001@000?l70?n001@0003o1P3oP0030?l000D0oh00103o00020?n000L0003o2@3oP0040?l0
00030?n0003o0000o`0000@0oh001@000?lK0?n000kooooo?@000?l20?n00080003o403oP0000`00
0?l0oh000?n000020?n00080003o4P3oP0020000o`P0oh005P000?l>ooooo`D0oh000P000?l40?n0
00D0o`001P3oP0070?l000<0oh0010000?l;0?n000D0o`00103oP0070?l000<0oh00103o00030?n0
0080003o1`3oP0020000o`H0oh000`3o00040?n000<0o`00103oP00B0?l00080oh00303o00020?n0
01Sooooo000FooooohX0o`003_oooolF0000o`D0oh001`000?l50?n001H0003o103oP0050?l000T0
oh000P000?l00`3oP000003o0000o`0;0?n000@0o`0000<0oh000?l0003o0000103oP0050000o`T0
oh0010000?l>0?n000kooooo7P000?l20?n00080003o0P3oP00I0000o`80oh000P000?l@0?n00003
0000o`3oP000oh0000H0oh0000<0003o0?n0003oP0001`000?l?0?n001D0003o0P3oP00>ooooo`D0
oh000P000?l40?n000L0o`00103oP0070?l000D0003o1`3oP0020000o`D0oh00103o000=0?n00003
0?l0003oP000oh0000@0oh000`000?l?0?n000<0o`001P3oP0030?l00080oh00803o00020?n001So
oooo000FooooohX0o`003_oooolF0000o`D0oh001`000?l50?n001H0003o103oP0050?l000T0oh00
0P000?l00`3oP000003o0000o`0;0?n000@0o`0000<0oh000?l0003o0000103oP0050000o`T0oh00
10000?l>0?n000kooooo7P000?l20?n00080003o0P3oP00I0000o`80oh000P000?l@0?n000030000
o`3oP000oh0000H0oh0000<0003o0?n0003oP0001`000?l?0?n001D0003o0P3oP00>ooooo`D0oh00
0P000?l40?n000L0o`00103oP0070?l000D0003o1`3oP0020000o`D0oh00103o000=0?n000030?l0
003oP000oh0000@0oh000`000?l?0?n000<0o`001P3oP0030?l00080oh00803o00020?n001Sooooo
000FooooohX0o`003_oooolI0000o`80oh000`000?l20?n00080003o103oP0000`000?l0oh000?n0
000H0000o`D0oh000P000?l70?n00080003o00<0oh000000o`000?l02`3oP0020000o`T0oh001`00
0?lI0?n000kooooo80000?l40?n00080003o00<0oh000000o`000?l03@000?l20?n000D0003o903o
P0020000oa00oh001@000?l70?n000L0003o103oP00>ooooo`D0oh000P000?l20?n000L0o`001`3o
P0060?l000030?n000000?l0003o0080003o403oP0020?l000L0oh000P3o00090?n000D0003o103o
P0020?l000T0oh0000<0o`000?n0003oP0000P3o00050?n00080o`000P3oP0070?l000@0oh004P3o
00030?n00080003o6?ooool001KoooooRP3o000>oooooaT0003o0P3oP0030000o`80oh000P000?l4
0?n000030000o`3oP000oh0001P0003o1@3oP0020000o`L0oh000P000?l00`3oP000003o0000o`0;
0?n00080003o2@3oP0070000oaT0oh003_oooolP0000o`@0oh000P000?l00`3oP000003o0000o`0=
0000o`80oh001@000?lT0?n00080003o403oP0050000o`L0oh001`000?l40?n000kooooo1@3oP002
0000o`80oh001`3o00070?n000H0o`0000<0oh000000o`000?l00P000?l@0?n00080o`001`3oP002
0?l000T0oh001@000?l40?n00080o`002@3oP0000`3o0000oh000?n000020?l000D0oh000P3o0002
0?n000L0o`00103oP00B0?l000<0oh000P000?lHooooo`005_oooon:0?l000kooooo6@000?l20?n0
00<0003o203oP0000`000?l0oh000?n0000F0000o`L0oh001`000?l20?n000<0003o2@3oP0080000
o`030?n000000?l0003o0080003o0P3oP00<0000o`80oh0010000?l>0?n000kooooo50000?l20?n0
00X0003o103oP0020000o`030?n000000?l0003o0100003o0P3oP0020000o`@0oh001@000?lK0?n0
0080003o1`3oP0050000o`@0oh001@000?l20?n000L0003o103oP0000`000?l0oh000?n000020?n0
00kooooo0P3o00050?n000T0o`001`3oP0020?l000@0oh001@000?l=0?n000030?l0003oP000oh00
00@0oh000`3o00020?n000@0o`000P3oP0050?l000<0oh000P000?l20?n000L0o`00503oP0070?l0
00L0oh002`3o00040?n000030?l0003oP000oh000080oh006?ooool001KoooooRP3o000>oooooaT0
003o0P3oP0030000o`P0oh0000<0003o0?n0003oP0005P000?l70?n000L0003o0P3oP0030000o`T0
oh0020000?l00`3oP000003o0000o`020000o`80oh0030000?l20?n000@0003o3P3oP00>oooooa@0
003o0P3oP00:0000o`@0oh000P000?l00`3oP000003o0000o`0@0000o`80oh000P000?l40?n000D0
003o6`3oP0020000o`L0oh001@000?l40?n000D0003o0P3oP0070000o`@0oh0000<0003o0?n0003o
P0000P3oP00>ooooo`80o`001@3oP0090?l000L0oh000P3o00040?n000D0003o3@3oP0000`3o0000
oh000?n000040?n000<0o`000P3oP0040?l00080oh001@3o00030?n00080003o0P3oP0070?l001@0
oh001`3o00070?n000/0o`00103oP0000`3o0000oh000?n000020?n001Sooooo000FooooohX0o`00
3_ooool40000o`030?n000000?l0003o0100003o103oP0030000o`80oh000P3o00040?n000030000
o`3oP000oh0002@0003o0P3oP0030000o`80oh0090000?l;0?n00080003o0`3oP0020000o`kooooo
6`000?l20?n000<0003o2@3oP0040000o`80oh0000<0003o0?n0003oP0000P3oP0070000o`80oh00
1`000?lR0?n00180003o0P3oP0070000o`80oh000`000?l40?n000kooooo0P3oP0030?l00180oh00
0P3o00040?n000L0003o0`3oP0020?l00180oh003@3o00050?n000L0o`004P3oP0040?l000<0oh00
1`3o00040?n000D0o`000P3oP0020?l000T0oh006?ooool001KoooooRP3o000>ooooo`T0003o0P3o
P0020000o`030?n000000?l0003o00h0003o0P3oP0020?l000@0oh009@000?l70?n00240003o00<0
oh000000o`000?l00P000?l20?n00080003o303oP0020000o`kooooo90000?l20?n000L0003o0P3o
P00@0000ob@0oh0000<0003o0?n0003oP00080000?l20?n00080003o3_ooool40?n000<0o`001P3o
P0030000o`L0oh000P3o000>0?n00080o`003`3oP0000`3o0000oh000?n000090?l00080oh000P3o
00070?n000T0o`001`3oP0020?l000D0oh00103o00030?n000@0o`000`3oP0020000o`80oh001`00
0?l;0?n001Sooooo000FooooohX0o`003_ooool90000o`80oh000P000?l00`3oP000003o0000o`0>
0000o`80oh000P3o00040?n002D0003o1`3oP00Q0000o`030?n000000?l0003o0080003o0P3oP002
0000o``0oh000P000?l>ooooob@0003o0P3oP0070000o`80oh0040000?lT0?n000030000o`3oP000
oh000200003o0P3oP0020000o`kooooo103oP0030?l000H0oh000`000?l70?n00080o`003P3oP002
0?l000l0oh0000<0o`000?n0003oP0002@3o00020?n00080o`001`3oP0090?l000L0oh000P3o0005
0?n000@0o`000`3oP0040?l000<0oh000P000?l20?n000L0003o2`3oP00Hooooo`005_oooon10?l0
00@0oh001@3o000>ooooo`80003o0P3oP00B0000o`030?n000000?l0003o0080oh000P000?l30?n0
0080o`00103oP00G0000o`@0oh0000<0003o0?n0003oP0001`000?l90?n00100003o0P3oP0020000
o`80oh002@000?l00`3oP000003o0000o`060000o`X0oh0010000?l>oooooa00003o0P3oP0020000
o`80oh0040000?l00`3oP000003o0000o`040000o`80oh0000<0003o0?n0003oP0001`000?l20?n0
0080003o0P3oP0030000o`@0oh000P000?l:0?n00080003o0P3oP0050000o`80oh001`000?l20?n0
02@0003o3_ooool20?n000L0o`000P3oP0070000o`D0oh000P3o00020?n00080o`000`3oP0020?l0
00L0oh00103o00050?n00080003o2`3oP0090?l000L0oh001`3o00040?n000030000o`3oP000oh00
00T0oh00103o00020?n000030?l0003oP000oh0000/0oh000`000?l;0?n00080o`006?ooool001Ko
ooooP@3o00040?n000D0o`003_ooool20000o`80oh004P000?l00`3oP000003o0000o`020?n00080
003o0`3oP0020?l000@0oh005`000?l40?n000030000o`3oP000oh0000L0003o2@3oP00@0000o`80
oh000P000?l20?n000T0003o00<0oh000000o`000?l01P000?l:0?n000@0003o3_ooool@0000o`80
oh000P000?l20?n00100003o00<0oh000000o`000?l010000?l20?n000030000o`3oP000oh0000L0
003o0P3oP0020000o`80oh000`000?l40?n00080003o2P3oP0020000o`80oh001@000?l20?n000L0
003o0P3oP00T0000o`kooooo0P3oP0070?l00080oh001`000?l50?n00080o`000P3oP0020?l000<0
oh000P3o00070?n000@0o`001@3oP0020000o`/0oh002@3o00070?n000L0o`00103oP0000`000?l0
oh000?n000090?n000@0o`000P3oP0000`3o0000oh000?n0000;0?n000<0003o2`3oP0020?l001So
oooo000FooooohX0o`003_ooool=0000o`030?n000000?l0003o00T0003o0P3oP0020000o`<0oh00
0P3o00040?n001<0003o0P3oP0070000o`80oh000P000?l30?n00080003o1`3oP0040000o`80oh00
30000?l20?n000T0003o0P3oP0020000o`<0oh000P000?l90?n00080o`001`3oP00>ooooob00003o
0P3oP0090000o`L0oh002`000?l40?n000030000o`3oP000oh0000h0oh002@000?l40?n00080003o
0P3oP00W0000o`kooooo103oP0030?l000H0oh001@000?lG0?n000@0o`001@3oP0020000o`d0oh00
00<0o`000?n0003oP0000P3o00090?n000T0o`000P3oP0000`000?l0oh000?n0000K0?n000L0003o
1`3oP0020?l00080oh006?ooool001KoooooRP3o000>ooooo`d0003o00<0oh000000o`000?l02@00
0?l20?n00080003o0`3oP0020?l000@0oh004`000?l20?n000L0003o0P3oP0020000o`<0oh000P00
0?l70?n000@0003o0P3oP00<0000o`80oh002@000?l20?n00080003o0`3oP0020000o`T0oh000P3o
00070?n000kooooo80000?l20?n000T0003o1`3oP00;0000o`@0oh0000<0003o0?n0003oP0003P3o
P0090000o`@0oh000P000?l20?n002L0003o3_ooool40?n000<0o`001P3oP0050000oaL0oh00103o
00050?n00080003o3@3oP0000`3o0000oh000?n000020?l000T0oh002@3o00020?n000030000o`3o
P000oh0001/0oh001`000?l70?n00080o`000P3oP00Hooooo`005_oooold0?l00080oh00E03o000>
oooooad0003o0`3oP0020000o`@0oh0000<0003o0?n0003oP0000P3oP00D0000o`D0oh00103o000>
0?n000@0003o0`3oP0020000o`D0oh0010000?l20?n000<0003o403oP0060?l000L0oh003_oooolP
0000o`80oh002@000?l40?n001X0003o103oP00B0000o`80oh00:@000?l>ooooo`@0oh001@3o0005
0?n000@0003o4P3oP0020?l000h0oh00103o00000`3oP000o`000?l000060?n000030?l0003oP000
oh0000@0o`002P3oP0020?l000/0oh000P000?l50?n00080o`001`3oP0020000o`T0oh000`000?l;
0?n00080o`006?ooool001Kooooo=03o00020?n005@0o`003_oooolM0000o`<0oh000P000?l40?n0
00030000o`3oP000oh000080oh0050000?l50?n000@0o`003P3oP0040000o`<0oh000P000?l50?n0
00@0003o0P3oP0030000oa00oh001P3o00070?n000kooooo80000?l20?n000T0003o103oP00J0000
o`@0oh004P000?l20?n002T0003o3_ooool40?n000D0o`001@3oP0040000oa80oh000P3o000>0?n0
00@0o`0000<0oh000?l0003o00001P3oP0000`3o0000oh000?n000040?l000X0oh000P3o000;0?n0
0080003o1@3oP0020?l000L0oh000P000?l90?n000<0003o2`3oP0020?l001Sooooo000Foooood40
o`0000<0oh000?l0003o0000AP3o000>ooooo`80003o0P3oP00P0000o`80oh0000<0003o0?n0003o
P0000P3oP00>0000o`@0oh000P000?l30?n000l0o`00303oP0020000o`80oh000P000?l00`3oP000
003o0000o`020000o`80oh001@000?l>0?n000H0o`001`3oP00>ooooobd0003o0P3oP00:0000o`80
oh005`000?l20?n00080003o0P3oP0070000o`80oh00:@000?l>ooooo`D0oh00103o00070?n00080
003o2`3oP0000`3o0000oh000?n0000=0?n00080o`0000<0oh000?l0003o00000P3oP0070?l000L0
oh001`3o00060?n00080003o0`3oP0020?l001T0oh000P3o00020?n000030?l0003oP000oh000080
oh0010000?l<0?n00080o`006?ooool001Kooooo@@3o00000`3oP000o`000?l000160?l000kooooo
80000?l20?n00080003o1@3oP00@0000o`/0oh001@3o000D0?n000H0003o00<0oh000000o`000?l0
0P000?l20?n00080003o4`3oP0040?l000L0oh003_ooooli0000o`80oh0010000?l30?n000@0003o
0P3oP00:0000o`80oh000P000?l40?n00300003o3_ooool50?n000H0o`001@3oP0020000o`@0oh00
00<0o`000?n0003oP000103oP0000`3o0000oh000?n0000;0?n000@0o`002P3oP0060?l000T0oh00
0`3o00090?n00080o`00503oP0020?l000<0oh000P3o000<0?n00080003o103oP0020000o`D0oh00
6?ooool001Kooooo@@3o00000`3oP000o`000?l000160?l000kooooo80000?l20?n00080003o1@3o
P00@0000o`/0oh001@3o000D0?n000H0003o00<0oh000000o`000?l00P000?l20?n00080003o4`3o
P0040?l000L0oh003_ooooli0000o`80oh0010000?l30?n000@0003o0P3oP00:0000o`80oh000P00
0?l40?n00300003o3_ooool50?n000H0o`001@3oP0020000o`@0oh0000<0o`000?n0003oP000103o
P0000`3o0000oh000?n0000;0?n000@0o`002P3oP0060?l000T0oh000`3o00090?n00080o`00503o
P0020?l000<0oh000P3o000<0?n00080003o103oP0020000o`D0oh006?ooool001KoooooRP3o000>
oooooad0003o00<0oh000000o`000?l010000?l20?n000030000o`3oP000oh000180003o2@3oP005
0?l000l0oh000P3o000@0?n00080003o1`3oP0090000o`T0oh0000<0003o0?n0003oP0000P3oP00>
oooooc00003o0P3oP0070000o`T0oh0010000?l70?n000D0003o103oP0020000o`80oh00<0000?l>
ooooo`@0oh001`3o000;0?n000030?l0003oP000oh0001l0oh0000<0o`000?n0003oP0003@3oP005
0?l000L0oh00103o000L0?n00080o`001`3oP0020000o`/0oh006?ooool001KoooooRP3o000>oooo
oad0003o00<0oh000000o`000?l010000?l20?n000030000o`3oP000oh000180003o2@3oP0050?l0
00l0oh000P3o000@0?n00080003o1`3oP0090000o`T0oh0000<0003o0?n0003oP0000P3oP00>oooo
oc00003o0P3oP0070000o`T0oh0010000?l70?n000D0003o103oP0020000o`80oh00<0000?l>oooo
o`@0oh001`3o000;0?n000030?l0003oP000oh0001l0oh0000<0o`000?n0003oP0003@3oP0050?l0
00L0oh00103o000L0?n00080o`001`3oP0020000o`/0oh006?ooool001KoooooRP3o000>ooooocT0
003o3`3oP0000`3o0000oh000?n000020?l00080oh000P3o00050?n000@0o`000`3oP0060000o`D0
oh001`000?l40?n000T0003o3P3oP00>ooooocl0003o0P3oP0050000o`80oh000`000?l20?n000L0
003o0P3oP00K0000o`80oh0000<0003o0?n0003oP00050000?l>ooooo`80oh002@3o00070?n000D0
o`00503oP0020?l00080oh0000<0o`000?n0003oP000103oP0030?l000T0oh002`3o00070?n000@0
o`002`3oP0000`3o0000oh000?n000020?n00080o`003P3oP0040?l000L0oh000`3o00040?n001So
oooo000FooooohX0o`003_ooooli0000o`l0oh0000<0o`000?n0003oP0000P3o00020?n00080o`00
1@3oP0040?l000<0oh001P000?l50?n000L0003o103oP0090000o`h0oh003_oooolo0000o`80oh00
1@000?l20?n000<0003o0P3oP0070000o`80oh006`000?l20?n000030000o`3oP000oh0001@0003o
3_ooool20?n000T0o`001`3oP0050?l001@0oh000P3o00020?n000030?l0003oP000oh0000@0oh00
0`3o00090?n000/0o`001`3oP0040?l000/0oh0000<0o`000?n0003oP0000P3oP0020?l000h0oh00
103o00070?n000<0o`00103oP00Hooooo`005_oooolW0?l00080oh00H@3o000>oooooad0003o00<0
oh000000o`000?l00P3oP0020000o`D0oh003@000?l20?n000<0003o0P3oP0040000o`X0oh001P3o
00000`3oP000003o0000o`090?n000H0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000
o`040?n000<0003o0P3oP0040000o`T0oh0000<0003o0?n0003oP0000P3oP00>ooooo`80003o0P3o
P00J0000o`@0oh007@000?l70?n000D0003o2`3oP0070000o`H0oh000`000?l60?n00140003o2@3o
P0040000o`kooooo103oP0050?l000T0oh001`3o00070?n00080o`002`3oP0030?l000@0oh001@3o
00090?n000T0o`002@3oP0020?l001L0oh000P000?l20?n00080003o2@3oP0000`000?l0oh000?n0
00040?n000<0o`00103oP00Hooooo`005_oooolW0?l00080oh00H@3o000>oooooad0003o00<0oh00
0000o`000?l00P3oP0020000o`D0oh003@000?l20?n000<0003o0P3oP0040000o`X0oh001P3o0000
0`3oP000003o0000o`090?n000H0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`04
0?n000<0003o0P3oP0040000o`T0oh0000<0003o0?n0003oP0000P3oP00>ooooo`80003o0P3oP00J
0000o`@0oh007@000?l70?n000D0003o2`3oP0070000o`H0oh000`000?l60?n00140003o2@3oP004
0000o`kooooo103oP0050?l000T0oh001`3o00070?n00080o`002`3oP0030?l000@0oh001@3o0009
0?n000T0o`002@3oP0020?l001L0oh000P000?l20?n00080003o2@3oP0000`000?l0oh000?n00004
0?n000<0o`00103oP00Hooooo`005_oooolW0?l00080oh00H@3o000>ooooo`h0003o0P3oP00=0000
o`T0oh0040000?l20?n000030000o`3oP000oh0000@0003o1@3oP0020?l000L0oh00103o000<0?n0
00@0003o1@3oP00;0000o`/0oh0000<0003o0?n0003oP0002`3oP00>ooooob/0003o103oP0000`00
0?l0oh000?n0000=0000o`T0oh0000<0003o0?n0003oP0000P3oP0020000o`L0oh003P000?l20?n0
0080003o0P3oP00C0000o`d0oh003_ooool40?n000<0o`00103oP0020?l000030?n0003o0000o`00
00H0o`001@3oP0020000o`D0oh000P3o00090?n000<0o`000P3oP0060?l000X0oh000P000?l50?n0
0080o`00103oP0030?l00080oh000P3o00050?n00080003o103oP0050?l00080oh000P3o00070?n0
0080003o1@3oP0020?l000T0oh000`3o00040?n001Sooooo000Fooooocl0o`000P3oP0190?l000ko
oooo7@000?l70?n00100003o103oP0030000oaH0oh000`000?lD0?n00180003o0P3oP0000`000?l0
oh000?n000090?n00080003o3_oooolV0000o`<0oh000P000?l20?n000h0003o0P3oP0020000oa/0
oh000`000?l20?n000D0003o203oP00A0000o`P0oh0000<0003o0?n0003oP0000P3oP00>ooooo`@0
oh0000<0o`000?n0003oP000103oP0020?l000030?n0003o0000o`0000T0oh000P000?l90?n000<0
o`001P3oP0030?l00080oh001P3o00070?n000D0003o2`3oP0020?l000030?n0003o0000o`0000L0
oh000P000?l40?n000/0o`00203oP0020000o`@0oh001@000?l70?n00080003o0P3oP00Hooooo`00
5_oooolo0?l00080oh00B@3o000>oooooad0003o1`3oP00@0000o`@0oh000`000?lF0?n000<0003o
503oP00B0000o`80oh0000<0003o0?n0003oP0002@3oP0020000o`kooooo9P000?l30?n00080003o
0P3oP00>0000o`80oh000P000?lK0?n000<0003o0P3oP0050000o`P0oh004@000?l80?n000030000
o`3oP000oh000080oh003_ooool40?n000030?l0003oP000oh0000@0oh000P3o00000`3oP000o`00
0?l000090?n00080003o2@3oP0030?l000H0oh000`3o00020?n000H0o`001`3oP0050000o`/0oh00
0P3o00000`3oP000o`000?l000070?n00080003o103oP00;0?l000P0oh000P000?l40?n000D0003o
1`3oP0020000o`80oh006?ooool001KoooooRP3o000>ooooob00003o0P3oP00B0000o`D0oh001000
0?l;0?n000030?l0003oP000oh0000T0oh000P000?l40?n000030?l0003oP000oh0000/0oh003P00
0?l60?n000030000o`3oP000oh0000/0oh003_oooolI0000o`80oh000`000?l20?n000H0003o2P3o
P00A0000oaD0oh000P000?lD0?n000030000o`3oP000oh0000T0003o0P3oP0030000o`P0oh0000<0
003o0?n0003oP0000P3oP00>ooooo`80003o0`3oP0020?l000@0oh001@3o00090?n000L0003o103o
P0030?l000@0oh001@3o00020?n000L0o`002@3oP0020000o`@0oh0000<0o`000?n0003oP0005P3o
P0050?l000H0oh0000<0o`000?n0003oP000103oP0030000o`80oh000P000?l30?n00080003o2@3o
P0020?l001Sooooo000FooooohX0o`003_oooolP0000o`80oh004P000?l50?n000@0003o2`3oP000
0`3o0000oh000?n000090?n00080003o103oP0000`3o0000oh000?n0000;0?n000h0003o1P3oP000
0`000?l0oh000?n0000;0?n000kooooo6@000?l20?n000<0003o0P3oP0060000o`X0oh004@000?lE
0?n00080003o503oP0000`000?l0oh000?n000090000o`80oh000`000?l80?n000030000o`3oP000
oh000080oh003_ooool20000o`<0oh000P3o00040?n000D0o`002@3oP0070000o`@0oh000`3o0004
0?n000D0o`000P3oP0070?l000T0oh000P000?l40?n000030?l0003oP000oh0001H0oh001@3o0006
0?n000030?l0003oP000oh0000@0oh000`000?l20?n00080003o0`3oP0020000o`T0oh000P3o000H
ooooo`005_oooomo0?l00080oh002@3o000>ooooob00003o103oP00>0000o`H0oh0000<0003o0?n0
003oP0003@3oP0000`3o0000oh000?n000060?n000030000o`3oP000oh000080003o103oP0000`3o
0000oh000?n0000;0?n00100003o103oP0000`000?l0oh000?n000070?n00080003o0P3oP00>oooo
obH0003o2P3oP0020000o`80oh001`000?l40?n000<0003o0P3oP0020000o`L0oh000P000?l20?n0
00030000o`3oP000oh000080oh000P000?l;0?n000<0003o0P3oP0020000o`80oh000`000?l70?n0
00L0003o103oP0020000o`80oh000`000?l20?n000kooooo0P000?l<0?n00080o`002`3oP0050000
o`H0oh0000<0o`000?n0003oP0001`3oP00;0?l000H0oh00203o000H0?n000<0o`000P3oP0020?l0
00h0oh000P000?l40?n000030?l0003oP000oh000080oh0010000?l30?n00080o`006?ooool001Ko
ooooO`3o00020?n000T0o`003_oooolP0000o`@0oh003P000?l60?n000030000o`3oP000oh0000d0
oh0000<0o`000?n0003oP0001P3oP0000`000?l0oh000?n000020000o`@0oh0000<0o`000?n0003o
P0002`3oP00@0000o`@0oh0000<0003o0?n0003oP0001`3oP0020000o`80oh003_oooolV0000o`X0
oh000P000?l20?n000L0003o103oP0030000o`80oh000P000?l70?n00080003o0P3oP0000`000?l0
oh000?n000020?n00080003o2`3oP0030000o`80oh000P000?l20?n000<0003o1`3oP0070000o`@0
oh000P000?l20?n000<0003o0P3oP00>ooooo`80003o303oP0020?l000/0oh001@000?l60?n00003
0?l0003oP000oh0000L0oh002`3o00060?n000P0o`00603oP0030?l00080oh000P3o000>0?n00080
003o103oP0000`3o0000oh000?n000020?n000@0003o0`3oP0020?l001Sooooo000Foooooh<0o`00
0P3oP0050?l000kooooo0P000?l20?n00380003o0P3oP0000`000?l0oh000?n0000F0?n000D0003o
103oP0000`3o0000oh000?n000020?n00200003o1`3oP0040000o`kooooo6@000?l40?n000X0003o
103oP0020000o`<0oh003@000?l40?n000030000o`3oP000oh0002T0oh000P000?lG0?n000@0003o
3_ooool50000ob/0oh001P3o00020?n000030?l0003oP000oh000080oh00103o00000`3oP000o`00
0?l000070?l000L0oh000P000?l90?n00080003o503oP0070000o`80oh0000<0o`000?n0003oP000
0P3oP0020000o`<0oh00103o000Hooooo`005_oooon:0?l000kooooo=0000?lI0?n00080o`00403o
P00N0000o`T0oh0010000?l>ooooo`80oh000P000?l00`3oP000003o0000o`0B0000o`@0oh0000<0
003o0?n0003oP0001`000?l40?n00080003o1`3oP00@0000o`80oh000P000?l<0?n00080003o1`3o
P0040000o`80oh001`000?l20?n000D0003o1`3oP0020000o`L0oh002@000?l>ooooo`80003o0P3o
P0000`000?l0oh000?n0000;0?n000@0o`001@3oP0020000o`<0oh000P3o000=0?n000030?l0003o
P000oh000100oh001`3o00080?n000030?l0003oP000oh0001@0oh001`3o00090?n00080003o0P3o
P0030000o`80oh000P000?l50?n00080o`006?ooool001KoooooRP3o000>oooooc@0003o6@3oP002
0?l00100oh007P000?l90?n000@0003o3_ooool20?n00080003o00<0oh000000o`000?l04P000?l4
0?n000030000o`3oP000oh0000L0003o103oP0020000o`L0oh0040000?l20?n00080003o303oP002
0000o`L0oh0010000?l20?n000L0003o0P3oP0050000o`L0oh000P000?l70?n000T0003o3_ooool2
0000o`80oh0000<0003o0?n0003oP0002`3oP0040?l000D0oh000P000?l30?n00080o`003@3oP000
0`3o0000oh000?n0000@0?n000L0o`00203oP0000`3o0000oh000?n0000D0?n000L0o`002@3oP002
0000o`80oh000`000?l20?n00080003o1@3oP0020?l001Sooooo000FooooohX0o`003_oooold0000
o`h0oh000P000?l20?n000<0003o2`3oP0020000o`T0oh000P000?l20?n001T0003o2P3oP0040000
o`kooooo1@3oP00R0000o`@0oh000P000?l20?n000h0003o1@3oP0020000o`L0oh000P000?l70?n0
01d0003o1`3oP0040000o`030?n000000?l0003o0080oh0010000?l00`3oP000003o0000o`020000
o`kooooo3@3oP0000`000?l0oh000?n000020?n000@0o`007P3oP0040000oa40oh000P3o00020?n0
0080o`000P3oP0000`3o0000oh000?n000020?n000D0003o3@3oP0070?l000L0oh0010000?l20?n0
00030000o`3oP000oh0000@0oh001@3o00020?n001Sooooo000FooooohX0o`003_oooold0000o`h0
oh000P000?l20?n000<0003o2`3oP0020000o`T0oh000P000?l20?n001T0003o2P3oP0040000o`ko
oooo1@3oP00R0000o`@0oh000P000?l20?n000h0003o1@3oP0020000o`L0oh000P000?l70?n001d0
003o1`3oP0040000o`030?n000000?l0003o0080oh0010000?l00`3oP000003o0000o`020000o`ko
oooo3@3oP0000`000?l0oh000?n000020?n000@0o`007P3oP0040000oa40oh000P3o00020?n00080
o`000P3oP0000`3o0000oh000?n000020?n000D0003o3@3oP0070?l000L0oh0010000?l20?n00003
0000o`3oP000oh0000@0oh001@3o00020?n001Sooooo000FooooohX0o`003_oooold0000o`h0oh00
0P000?l90?n000@0o`003P3oP00P0000o`@0oh000P000?l00`3oP000003o0000o`020000o`kooooo
1@3oP00;0000o`@0oh00:`000?lE0?n002H0003o0P3oP00>0000o`kooooo103o00030?n000@0o`00
0P3oP0030000o`80oh001@3o000?0?n000030?l0003oP000oh0000/0oh000P000?l30?n000@0o`00
1@3oP0020000o`D0oh00103o00040?n000030?l0003oP000oh000080oh000P000?l20?n000030000
o`3oP000oh000080003o103oP0000`000?l0oh000?n000020?n000/0o`001@3oP0050000o`80oh00
2@3o00020?n001Sooooo000FooooohX0o`003_oooold0000o`h0oh000P000?l90?n000@0o`003P3o
P00P0000o`@0oh000P000?l00`3oP000003o0000o`020000o`kooooo1@3oP00;0000o`@0oh00:`00
0?lE0?n002H0003o0P3oP00>0000o`kooooo103o00030?n000@0o`000P3oP0030000o`80oh001@3o
000?0?n000030?l0003oP000oh0000/0oh000P000?l30?n000@0o`001@3oP0020000o`D0oh00103o
00040?n000030?l0003oP000oh000080oh000P000?l20?n000030000o`3oP000oh000080003o103o
P0000`000?l0oh000?n000020?n000/0o`001@3oP0050000o`80oh002@3o00020?n001Sooooo000F
ooooohX0o`003_ooool>0000o`80oh003@000?l30?n00080003o0P3oP00@0000o`T0oh000P3o000>
0?n000@0o`00303oP0040000o`80oh002P000?l20?n000@0003o00<0oh000000o`000?l010000?l2
0?n000030000o`3oP000oh000080003o0P3oP0070000o`kooooo6@000?l20?n002/0003o1@3oP002
0000o`D0oh007`000?l50?n001@0003o3_ooool40?l000D0oh000P3o00030?n00080003o103oP003
0?l000d0oh000P3o000>0?n00080003o1@3oP0060?l000P0oh00103o000@0?n000@0o`001`3oP00<
0?l000@0oh000P000?l50?n000L0o`00103oP00Hooooo`005_oooon:0?l000kooooo3P000?l20?n0
00d0003o0`3oP0020000o`80oh0040000?l90?n00080o`003P3oP0040?l000`0oh0010000?l20?n0
00X0003o0P3oP0040000o`030?n000000?l0003o00@0003o0P3oP0000`000?l0oh000?n000020000
o`80oh001`000?l>oooooaT0003o0P3oP00[0000o`D0oh000P000?l50?n001l0003o1@3oP00D0000
o`kooooo103o00050?n00080o`000`3oP0020000o`@0oh000`3o000=0?n00080o`003P3oP0020000
o`D0oh001P3o00080?n000@0o`00403oP0040?l000L0oh00303o00040?n00080003o1@3oP0070?l0
00@0oh006?ooool001KoooooRP3o000>oooooad0003o0`3oP00D0000o`T0oh000P3o00050?n00080
o`001`3oP0020?l00100oh003P000?l40?n00080003o00<0oh000000o`000?l00P000?l=0?n000<0
003o0P3oP00>ooooocl0003o0P3oP00b0000o`030?n000000?l0003o01@0003o3_ooool40?l000D0
oh000P3o00030?n00080003o1P3oP0000`3o0000003o0000o`070?n00080003o103oP0000`3o0000
oh000?n000020?n00080003o4P3oP0020?l000030?n0003o0000o`0000L0oh00103o00050?n000L0
o`000P3oP0040?l000L0oh003P3o00020?n000@0003o0`3oP0070?l000@0oh006?ooool001Kooooo
RP3o000>ooooo`@0003o1`3oP00B0000o`<0oh005P000?l20?n000030000o`3oP000oh0000T0oh00
0P3o00020?n000030?l0003oP000oh000080oh000P3o000B0?n000D0003o0P3oP0070000o`80oh00
1`000?l;0?n000L0003o3_oooon30000o`<0oh000P000?l20?n000kooooo103o00050?n000@0o`00
0`3oP0040000o`T0oh0000<0o`000?n0003oP0000P000?l40?n000<0o`00103oP0020?l001<0oh00
0P3o00090?n00080o`001`3oP0090?l00080oh000P000?l50?n000h0o`00103oP0020000o`<0oh00
0P3o00090?n001Sooooo000FooooohX0o`003_ooool40000o`L0oh004P000?l30?n001H0003o0P3o
P0000`000?l0oh000?n000090?n00080o`000P3oP0000`3o0000oh000?n000020?n00080o`004P3o
P0050000o`80oh001`000?l20?n000L0003o2`3oP0070000o`koooooP`000?l30?n00080003o0P3o
P00>ooooo`@0o`001@3oP0040?l000<0oh0010000?l90?n000030?l0003oP000oh000080003o103o
P0030?l000@0oh000P3o000C0?n00080o`002@3oP0020?l000L0oh002@3o00020?n00080003o1@3o
P00>0?l000@0oh000P000?l30?n00080o`002@3oP00Hooooo`005_oooon:0?l000kooooo2@000?l2
0?n00180003o00<0oh000000o`000?l05P000?l20?n000030000o`3oP000oh0001L0oh000P000?l@
0?n00080o`00103oP0050000o`80oh001`000?l70?n00080003o0P3oP0070000o`koooooP@000?l2
0?n000L0003o3_ooool20?n00080o`000`3oP0060?l000D0oh000P000?l30?n00080003o103oP000
0`3o0000oh000?n000020000o`h0oh001P000?l;0?n000030?l0003oP000oh0000@0oh0000<0003o
0?n0003oP0001P3oP0000`3o0000oh000?n000020?n000T0o`00103oP0030?l00080oh000P3o0002
0?n000030?l0003oP000oh0000T0o`00103oP0070?l000L0oh006?ooool001KoooooRP3o000>oooo
o`T0003o0P3oP00B0000o`030?n000000?l0003o01H0003o0P3oP0000`000?l0oh000?n0000G0?n0
0080003o403oP0020?l000@0oh001@000?l20?n000L0003o1`3oP0020000o`80oh001`000?l>oooo
oh40003o0P3oP0070000o`kooooo0P3oP0020?l000<0oh001P3o00050?n00080003o0`3oP0020000
o`@0oh0000<0o`000?n0003oP0000P000?l>0?n000H0003o2`3oP0000`3o0000oh000?n000040?n0
00030000o`3oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP0090?l000@0oh000`3o00020?n0
0080o`000P3oP0000`3o0000oh000?n000090?l000@0oh001`3o00070?n001Sooooo000FooooohX0
o`003_oooolf0000o`<0oh000P000?l20?n00080003o2@3oP0000`3o0000oh000?n000070?n000@0
003o0P3oP0020000oa00oh004P000?l00`3oP000003o0000o`040?n000L0003o3_oooomM0000o`80
oh00:`000?l>ooooo`@0oh002P3o00040?n00080003o0`3oP0020000o`@0oh0000<0o`000?n0003o
P0000P3oP0020000o`L0oh000P3o00030?n000P0003o5`3oP0020000o`L0oh001`3o00050?n00080
o`000P3oP0020?l00080oh0000<0o`000?n0003oP0002@3o00040?n000D0o`002@3oP00Hooooo`00
5_oooon:0?l000kooooo=P000?l30?n00080003o0P3oP0020000o`T0oh0000<0o`000?n0003oP000
1`3oP0040000o`80oh000P000?l@0?n00180003o00<0oh000000o`000?l0103oP0070000o`kooooo
G@000?l20?n002/0003o3_ooool40?n000X0o`00103oP0020000o`<0oh000P000?l40?n000030?l0
003oP000oh000080oh000P000?l70?n00080o`000`3oP0080000oaL0oh000P000?l70?n000L0o`00
1@3oP0020?l00080oh000P3o00020?n000030?l0003oP000oh0000T0o`00103oP0050?l000T0oh00
6?ooool001KoooooO@3o00040?n000T0o`003_oooolK0000o`<0oh000P000?l20?n001@0003o0P3o
P0000`000?l0oh000?n0000G0?n000@0003o0P3oP0020000o``0oh000P000?l20?n00100003o0P3o
P00>0000o`koooooC`000?l30?n00080003o0P3oP0070000o`80oh00:`000?l>ooooo`@0oh001@3o
00050?n00080o`000P3oP0020000o`<0oh000P000?l90?n000@0003o1@3oP0020?l00080oh002@00
0?l>0?n000L0o`00103oP0000`000?l0oh000?n000040?n00080o`0000<0oh000?l0003o00001`3o
P0090?l000L0oh00103o00050?n000@0o`002@3oP00Hooooo`005_oooomm0?l000@0oh002@3o000>
oooooa/0003o0`3oP0020000o`80oh0050000?l20?n000030000o`3oP000oh0001L0oh0010000?l2
0?n00080003o303oP0020000o`80oh0040000?l20?n000h0003o3_oooom?0000o`<0oh000P000?l2
0?n000L0003o0P3oP00[0000o`kooooo103oP0050?l000D0oh000P3o00020?n00080003o0`3oP002
0000o`T0oh0010000?l50?n00080o`000P3oP0090000o`h0oh001`3o00040?n000030000o`3oP000
oh0000@0oh000P3o00000`3oP000o`000?l000070?n000T0o`001`3oP0040?l000D0oh00103o0009
0?n001Sooooo000FooooodP0o`0000<0oh000?l0003o0000<@3o00050?n000T0o`003_oooolK0000
o`<0oh000P3o00020?n001@0003o2`3oP0000`000?l0oh000?n0000=0?n000`0003o1`3oP00F0000
o`80oh001`000?l50?n00080003o3_oooomA0000o`<0oh006@000?l20?n001H0003o00<0oh000000
o`000?l00P000?l>ooooo`80oh000`3o00080?n000030000o`3oP000oh0000L0oh0010000?l70?n0
00D0003o103oP0020?l00080oh002P000?l90?n000/0o`001`3oP00=0?l000<0oh002`3o00070?n0
0080o`001@3oP0040?l000T0oh006?ooool001KoooooO@3o00040?n000T0o`003_ooool50000o`80
oh000P000?l20?n00100003o0`3oP0020?l00080oh0050000?l@0?n00080003o2@3oP0050000o`80
oh000`000?l80?n001T0003o2P3oP0040000o`kooooo0P3oP00;0000o`030?n000000?l0003o04/0
003o0P3oP0070000o`@0oh000P000?l20?n001h0003o3_ooool40?l00100oh002@000?l50?n000@0
003o1@3oP0020?l000D0oh002@000?l40?n00080o`001@3oP0050?l000T0oh003@3o00020?n000L0
o`001`3oP0030?l00080oh001P3o00070?n00080003o00<0oh000000o`000?l00P3oP00Hooooo`00
5_oooomm0?l000@0oh002@3o000>ooooo`D0003o0P3oP0020000o`80oh0040000?l30?n00080o`00
0P3oP00D0000oa00oh000P000?l90?n000D0003o0P3oP0030000o`P0oh006@000?l:0?n000@0003o
3_ooool20?n000/0003o00<0oh000000o`000?l0B`000?l20?n000L0003o103oP0020000o`80oh00
7P000?l>ooooo`@0o`00403oP0090000o`D0oh0010000?l50?n00080o`001@3oP0090000o`@0oh00
0P3o00050?n000D0o`002@3oP00=0?l00080oh001`3o00070?n000<0o`000P3oP0060?l000L0oh00
0P000?l00`3oP000003o0000o`020?n001Sooooo000Fooooogl0o`000P3oP0090?l000kooooo2@00
0?l20?n00100003o1`3oP00@0000o`80oh000P000?l50?n00080o`00103oP0000`000?l0oh000?n0
00020?n00080003o2P3oP0040000o`80oh000P000?l90?n001`0003o0P3oP0020000o`D0oh000P00
0?l>ooooo`D0003o0P3oP0160000o`D0oh004@000?l@0?n001L0003o3_oooolG0?n000l0003o00<0
oh000?l0003o00001P3o00000`3oP000o`000?l000040?n00080003o1@3oP00D0?l000D0oh001`3o
00020?n00080o`000P3oP0070?l000X0oh00203o000:0?n000@0o`006?ooool001KoooooO`3o0002
0?n000T0o`003_ooool90000o`80oh0040000?l70?n00100003o0P3oP0020000o`D0oh000P3o0004
0?n000030000o`3oP000oh000080oh000P000?l:0?n000@0003o0P3oP0020000o`T0oh0070000?l2
0?n00080003o1@3oP0020000o`kooooo1@000?l20?n004H0003o1@3oP00A0000oa00oh005`000?l>
oooooaL0oh003`000?l00`3oP000o`000?l000060?l000030?n0003o0000o`0000@0oh000P000?l5
0?n001@0o`001@3oP0070?l00080oh000P3o00020?n000L0o`002P3oP0080?l000X0oh00103o000H
ooooo`005_ooool20?n00080o`0000<0oh000?l0003o0000503o00020?n006d0o`003_ooool>0000
o`80oh002`000?l20?n000030000o`3oP000oh0001T0003o0P3oP0020?l000`0oh000P3o00060?n0
00D0003o0P3oP0020000o`X0oh000P000?l20?n001@0003o1@3oP0020000o`80oh001@000?l>oooo
o`D0003o0P3oP00O0000o`D0oh000P000?l20?n000030000o`3oP000oh000080003o0P3oP0020000
o`030?n000000?l0003o0100003o1P3oP00B0000o`T0oh001@000?l20?n001L0003o3_ooool20?l0
00<0oh000P000?l20?n00080003o2`3oP00@0000o`D0oh001`3o00040?n000<0003o103oP0050?l0
0080oh003@3o00050?n000L0o`001P3oP0070?l000X0oh002@3o00090?n000@0o`006?ooool001Ko
oooo0P3oP0020?l000030?n0003o0000o`0001@0o`000P3oP01]0?l000kooooo3P000?l20?n000/0
003o0P3oP0000`000?l0oh000?n0000I0000o`80oh000P3o000<0?n00080o`001P3oP0050000o`80
oh000P000?l:0?n00080003o0P3oP00D0000o`D0oh000P000?l20?n000D0003o3_ooool50000o`80
oh007`000?l50?n00080003o0P3oP0000`000?l0oh000?n000020000o`80oh000P000?l00`3oP000
003o0000o`0@0000o`H0oh004P000?l90?n000D0003o0P3oP00G0000o`kooooo0P3o00030?n00080
003o0P3oP0020000o`/0oh0040000?l50?n000L0o`00103oP0030000o`@0oh001@3o00020?n000d0
o`001@3oP0070?l000H0oh001`3o000:0?n000T0o`002@3oP0040?l001Sooooo000Fooooo`80oh00
I03o00020?n00280o`003_ooool20000o`D0oh00<P000?l60?n00080o`00203oP0040?l000D0oh00
10000?l20?n00080003o0`3oP0020000o`T0oh0010000?l00`3oP000003o0000o`0@0000o`L0oh00
10000?l>ooooo`D0003o0P3oP00P0000o`@0oh000P000?l20?n000030000o`3oP000oh0000H0003o
00<0oh000000o`000?l010000?l50?n000D0003o1P3oP0070000o`80oh001`000?l20?n000<0003o
203oP0050000o`80oh005`000?l>ooooo`80o`000P3oP0070000o`T0oh004`000?l60?n000D0o`00
3@3oP0050?l00080oh000P3o00000`3oP000o`000?l000060?l000L0oh000`3o00060?n000T0o`00
403oP0050?l000@0oh000P3o00000`3oP000o`000?l000020?l001Sooooo000Fooooo`h0o`000P3o
P01j0?l000kooooo0P000?l20?n000030000o`3oP000oh000380003o4P3oP0020?l000/0oh000P00
0?l@0?n00080003o00<0oh000000o`000?l02`000?l<0?n000@0003o3_ooool50000o`80oh009P00
0?l20?n000030000o`3oP000oh000080003o0P3oP0020000o`030?n000000?l0003o00H0003o00<0
oh000000o`000?l080000?l20?n000T0003o0P3oP00I0000o`kooooo0P000?l30?n000H0003o1`3o
P0020000o`80oh0000<0003o0?n0003oP00010000?l00`3oP000003o0000o`060?n000030000o`3o
P000oh0000@0oh001@3o000;0?n000L0o`001@3oP0020?l00080oh00103o00030?n00080003o1`3o
P0020000o`@0oh002@3o000>0?n000L0o`001@3oP0040?l001Sooooo000Fooooo`h0o`000P3oP01j
0?l000kooooo0P000?l20?n000030000o`3oP000oh000380003o4P3oP0020?l000/0oh000P000?l@
0?n00080003o00<0oh000000o`000?l02`000?l<0?n000@0003o3_ooool50000o`80oh009P000?l2
0?n000030000o`3oP000oh000080003o0P3oP0020000o`030?n000000?l0003o00H0003o00<0oh00
0000o`000?l080000?l20?n000T0003o0P3oP00I0000o`kooooo0P000?l30?n000H0003o1`3oP002
0000o`80oh0000<0003o0?n0003oP00010000?l00`3oP000003o0000o`060?n000030000o`3oP000
oh0000@0oh001@3o000;0?n000L0o`001@3oP0020?l00080oh00103o00030?n00080003o1`3oP002
0000o`@0oh002@3o000>0?n000L0o`001@3oP0040?l001Sooooo000Fooooogd0o`000P3oP00;0?l0
00kooooo0P000?l20?n000030000o`3oP000oh0003@0003o6@3oP0020000o`80oh002@000?l30?n0
0080003o2@3oP00=0000o`<0oh000P3o00050?n000@0003o3_ooool50000o`80oh00;@000?l20?n0
0080003o00<0oh000000o`000?l010000?l20?n000P0003o203oP00N0000o`80oh000P000?l00`3o
P000003o0000o`020?n000h0003o0P3oP0020000o`kooooo1@3oP0060000o`80oh000`3o00020?n0
0080003o4P3oP0000`3o0000oh000?n000060?n000D0o`000P3oP0020?l000L0oh001@3o00040?n0
00<0003o1`3oP0020?l000l0oh002@3o00050?n00080o`001`3oP0020000o`<0oh000P3o00090?n0
01Sooooo000Fooooogd0o`000P3oP00;0?l000kooooo0P000?l20?n000030000o`3oP000oh0003@0
003o6@3oP0020000o`80oh002@000?l30?n00080003o2@3oP00=0000o`<0oh000P3o00050?n000@0
003o3_ooool50000o`80oh00;@000?l20?n00080003o00<0oh000000o`000?l010000?l20?n000P0
003o203oP00N0000o`80oh000P000?l00`3oP000003o0000o`020?n000h0003o0P3oP0020000o`ko
oooo1@3oP0060000o`80oh000`3o00020?n00080003o4P3oP0000`3o0000oh000?n000060?n000D0
o`000P3oP0020?l000L0oh001@3o00040?n000<0003o1`3oP0020?l000l0oh002@3o00050?n00080
o`001`3oP0020000o`<0oh000P3o00090?n001Sooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`00
02OoooooLOl0000Wooooog7o00009ooooomao`0002Cooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Go
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o1?oooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo
5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0PoooooaKoogl01?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l0
0?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool000Cooooo5_l0o`0PoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool000Cooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool000Cooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo
003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o023ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000OoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool001oooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?l007oo001o00?o001o5_oo000Oo`00OaOo003o7ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o00;o001o5_oo0005o`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o00;o001o5ooo000Oo`00OaKo003o7ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o01go001o5_l0o`0Po`00OaKoogl01?l007l00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolF
ool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o00;o001o5ooo001Do`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol0
07lFo`3o023o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool005Co
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool005Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?l007oo001o06ko001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o06go001o00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oooomb
o`0002OoooooLOl0000Wooooog7o00009ooooomao`0002Cooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo000Fooooo`80oh00403o00020000o`80o`0000<0003o0?l0003o00000P000?l3
0?l00080003o103o00020000o`<0o`000P000?l20?l00080003o3P3o00020000o`80o`0000<0003o
0?l0003o00000P3o00020000o`<0o`000P000?l50?l000@0003o103o00000`000?l0o`000?l0000;
0000o`@0o`000`000?l20?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00002`3o000>
ooooo`80o`000P3oP00E003o0080oh000`00o`060?l00080oh0000<00?l00?n0003oP0004P00o`07
0?l00080oh001@00o`0;0?l000@0oh000P00o`030?l000800?l02@3o00020?n000D00?l0103o0000
0`3oP0000?l0003o0006003o00030?l0003oP000oh0000800?l01@3o00020?n000800?l03_ooool5
0?l00080oh001P00o`070?l00080oh0000<0o`000000o`000?l0103o00000`000?l0o`000?l00002
0000o`D0o`000P00o`040?l00080003o7P3o00090000o`D0o`0010000?l;0?l00080003o1`3o0000
0`3oP0000?l0003o0004003o00L0o`000P000?l70?l000kooooo0P3o0002003o00030?n00000o`00
0?l000@00?l00`3oP006003o00D0oh001000o`050?n000L00?l00P3o00020?n000800?l000<0oh00
003o0000o`001`00o`020?n000H00?l000<0oh00003o0000o`000P3oP0020?l000030?n00000o`00
0?l000800?l01`3oP006003o00D0o`000P00o`020?n00003003o003o0000o`0000@0o`000P3oP000
0`00o`00oh000?n00002003o0080oh000`00o`020?n000/0o`000`3oP002003o0080o`006?ooool0
01Kooooo0P3oP00@0?l00080003o0P3o00000`000?l0o`000?l000020000o`<0o`000P000?l40?l0
0080003o0`3o00020000o`80o`000P000?l>0?l00080003o0P3o00000`000?l0o`000?l000020?l0
0080003o0`3o00020000o`D0o`0010000?l40?l000030000o`3o0000o`0000/0003o103o00030000
o`80o`000P000?l30?l00080003o103o00000`000?l0o`000?l0000;0?l000kooooo0P3o00020?n0
01D00?l00P3oP003003o00H0o`000P3oP0000`00o`00oh000?n0000B003o00L0o`000P3oP005003o
00/0o`00103oP002003o00<0o`000P00o`090?l00080oh001@00o`040?l000030?n00000o`000?l0
00H00?l000<0o`000?n0003oP0000P00o`050?l00080oh000P00o`0>ooooo`D0o`000P3oP006003o
00L0o`000P3oP0000`3o0000003o0000o`040?l000030000o`3o0000o`000080003o1@3o0002003o
00@0o`000P000?lN0?l000T0003o1@3o00040000o`/0o`000P000?l70?l000030?n00000o`000?l0
00@00?l01`3o00020000o`L0o`003_ooool20?l000800?l000<0oh00003o0000o`001000o`030?n0
00H00?l01@3oP004003o00D0oh001`00o`020?l00080oh000P00o`000`3oP0000?l0003o0007003o
0080oh001P00o`000`3oP0000?l0003o00020?n00080o`0000<0oh00003o0000o`000P00o`070?n0
00H00?l01@3o0002003o0080oh0000<00?l00?l0003o0000103o00020?n00003003o003oP000oh00
00800?l00P3oP003003o0080oh002`3o00030?n000800?l00P3o000Hooooo`005_ooool50?l00080
003o0P3o00020000o`/0o`0000<0003o0?l0003o00000P000?l90?l00080003o0`3o00020000o`80
o`000P000?l30?l00080003o2@3o00020000o`80o`0000<0003o0?l0003o00001`3o00020000o`D0
o`0010000?l40?l000030000o`3o0000o`0000/0003o103o00030000o`d0o`0000<0003o0?l0003o
00002`3o000>ooooo`80o`000P3oP00J003o00H0o`000P3oP0000`00o`00oh000?n0000B003o00L0
o`000P3oP005003o00@0o`000P00o`050?l000@0oh000`00o`020?l000800?l02@3o00020?n000D0
0?l0103o00000`3oP0000?l0003o0006003o00<0o`000P00o`050?l00080oh000P00o`0>ooooo`D0
o`000P3oP002003o00@0o`0000<0003o0?l0003o0000103o00020?n000030?l000000?l0003o00@0
o`0000<0003o0?l0003o00000P000?l40?l000030?n00000o`000?l000@0o`000P000?l00`3o0000
oh000?n0000F0?l000030000o`3o0000o`000080003o1@3o00040000o`80o`000P000?l00`3o0000
003o0000o`020000o`/0o`000P000?l70?l000030?n00000o`000?l000800?l02@3o00020000o`L0
o`003_ooool20?n000800?l00`3oP004003o00<0oh001P00o`030?n000800?l00P3oP003003o00@0
oh001000o`000`3oP0000?l0003o00020?l00080oh000P00o`030?n000l00?l000<0oh00003o0000
o`000P00o`020?l000D0oh000P00o`050?n000H00?l00`3o00060?n000<00?l01`3o00020?n00080
0?l00P3oP0000`00o`00oh000?n000020?n000/0o`000`3oP0040?l001Sooooo000Fooooo`D0o`00
0P000?l20?l00080003o2`3o00000`000?l0o`000?l000020000o`T0o`000P000?l30?l00080003o
0P3o00020000o`<0o`000P000?l90?l00080003o0P3o00000`000?l0o`000?l000070?l00080003o
1@3o00040000o`@0o`0000<0003o0?l0003o00002`000?l40?l000<0003o3@3o00000`000?l0o`00
0?l0000;0?l000kooooo0P3o00020?n001X00?l01P3o00020?n00003003o003oP000oh0001800?l0
1`3o00020?n000D00?l0103o0002003o00D0o`00103oP003003o0080o`000P00o`090?l00080oh00
1@00o`040?l000030?n00000o`000?l000H00?l00`3o0002003o00D0o`000P3oP002003o00kooooo
1@3o00020?n000800?l0103o00000`000?l0o`000?l000040?l00080oh0000<0o`000000o`000?l0
103o00000`000?l0o`000?l000020000o`@0o`0000<0oh00003o0000o`00103o00020000o`030?l0
003oP000oh0001H0o`0000<0003o0?l0003o00000P000?l50?l000@0003o0P3o00020000o`030?l0
00000?l0003o0080003o2`3o00020000o`L0o`0000<0oh00003o0000o`000P00o`090?l00080003o
1`3o000>ooooo`80oh000P00o`030?n000@00?l00`3oP006003o00<0oh000P00o`020?n000<00?l0
103oP004003o00030?n00000o`000?l00080o`000P3oP002003o00<0oh003`00o`000`3oP0000?l0
003o0002003o0080o`001@3oP002003o00D0oh001P00o`030?l000H0oh000`00o`070?l00080oh00
0P00o`020?n00003003o003oP000oh000080oh002`3o00030?n000@0o`006?ooool001Kooooo0P3o
00020000o`D0o`000P000?l;0?l000030000o`3o0000o`000080003o2@3o00020000o`<0o`000P00
0?l20?l00080003o0`3o00020000o`T0o`000P000?l20?l000030000o`3o0000o`000100o`001000
0?l50?l000/0003o103o00030000o`L0o`000P000?lB0?l000kooooo0P3o00020?n001X00?l01P3o
00020?n00003003o003oP000oh0001800?l01`3o00040?n000<00?l02`3o00040?n000<00?l03@3o
00020?n000D00?l0103o00030?n000H00?l00`3o0002003o00D0o`000P3oP002003o00kooooo1@3o
00040?n000h0o`000P000?l20?l00080003o0`3o00020000o`D0o`000P3oP0070?l00080oh000P00
o`0;0?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o00001`3o00040000o`80o`000P00
0?l00`3o0000003o0000o`040000o`<0o`000P3oP00=0?l000030?n00000o`000?l000800?l00P3o
00020000o`h0o`003_ooool20?n000800?l000<0oh00003o0000o`001000o`020?n000L00?l00`3o
P002003o0080oh000`00o`040?n000@00?l000<0oh00003o0000o`00103oP003003o0080oh003`00
o`000`3oP0000?l0003o0002003o0080o`001`3oP002003o00030?n00000o`000?l000H00?l02@3o
P003003o00L0o`000P3oP005003o0080oh001`3o00040?n00080o`001`3oP00Hooooo`005_ooool2
0?l00080003o1@3o00020000o`80o`0000<0003o0?l0003o00001P3o00000`000?l0o`000?l00002
0000o`T0o`000P000?l70?l00080003o0`3o00020000o`d0o`0000<0003o0?l0003o0000403o0004
0000o`D0o`004P000?l40?l000<0oh003`3o00000`000?l0o`000?l000020?l000kooooo0P3o0002
0?n000L00?l00P3oP00:003o0080oh001@00o`060?l00080oh0000<00?l00?n0003oP0004P00o`04
0?l000<0003o0P3o00020?n000800?l0303o00040?n000800?l000<0003o0?l0003o00002`3o0002
0?n000<00?l01P3o00030?n000800?l00P3o0002003o00<0o`000P00o`020000o`80o`000`3oP002
003o00kooooo1@3o00040?n001@0o`000`000?l70?l00080oh001`3o00020?n000@0o`000P000?l7
0?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o00001`3o00040000o`D0o`0010000?l2
0?l00080003o00<0o`000?n0003oP0002`3o00020000o`030?l00000o`000?l000@0o`000P000?l>
0?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP007003o0080oh000`00o`04
0?n000<00?l00P3oP004003o00030?n00000o`000?l000@0oh000`00o`020?n000800?l00P3oP005
003o0080oh000P00o`030?n000T00?l0103oP002003o00<0oh001P00o`000`3oP000o`000?l00007
0?n000@00?l0103o00030?n000@00?l00`3oP0040?l00080003o0`3o00020?n000800?l01`3oP00H
ooooo`005_ooool20?l00080003o1@3o00020000o`80o`0000<0003o0?l0003o00001P3o00000`00
0?l0o`000?l000020000o`T0o`000P000?l70?l00080003o0`3o00020000o`d0o`0000<0003o0?l0
003o0000403o00040000o`D0o`004P000?l40?l000<0oh003`3o00000`000?l0o`000?l000020?l0
00kooooo0P3o00020?n000L00?l00P3oP00:003o0080oh001@00o`060?l00080oh0000<00?l00?n0
003oP0004P00o`040?l000<0003o0P3o00020?n000800?l0303o00040?n000800?l000<0003o0?l0
003o00002`3o00020?n000<00?l01P3o00030?n000800?l00P3o0002003o00<0o`000P00o`020000
o`80o`000`3oP002003o00kooooo1@3o00040?n001@0o`000`000?l70?l00080oh001`3o00020?n0
00@0o`000P000?l70?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o00001`3o00040000
o`D0o`0010000?l20?l00080003o00<0o`000?n0003oP0002`3o00020000o`030?l00000o`000?l0
00@0o`000P000?l>0?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP007003o
0080oh000`00o`040?n000<00?l00P3oP004003o00030?n00000o`000?l000@0oh000`00o`020?n0
00800?l00P3oP005003o0080oh000P00o`030?n000T00?l0103oP002003o00<0oh001P00o`000`3o
P000o`000?l000070?n000@00?l0103o00030?n000@00?l00`3oP0040?l00080003o0`3o00020?n0
00800?l01`3oP00Hooooo`005_ooool=0?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o
00000P000?l90?l00080003o1`3o00020000o`<0o`000P000?l=0?l000030000o`3o0000o`0000/0
o`000P000?l30?l00080003o1`3o000B0000o`D0o`000P3oP00D0?l000kooooo0P3o00030?n000H0
0?l00P3oP00:003o00@0oh000`00o`060?l00080oh0000<00?l00?n0003oP0004P00o`040?l000<0
003o0P3o00020?n000800?l000<0o`000000o`000?l02@3o00020?n000@0o`0000<0003o0?l0003o
00000P3o00020000o`L0o`000P3oP003003o00H0o`000`3oP002003o00L0o`000P00o`020000o`80
o`000`3oP002003o00kooooo1@3o00040?n000800?l01@3o00020000o`80o`000P000?l00`3o0000
0?l0003o00070?l00080003o3P3o00040?n00080o`000P000?l70?l00080003o1`3o00000`000?l0
o`000?l000070?l000@0003o0P3o00020000o`030?l000000?l0003o0080003o1@3o00020?n000h0
o`001000o`0>0?l00080oh000P3o000>ooooo`80oh000P00o`000`3oP0000?l0003o0004003o0080
oh000`00o`020?n000L00?l01@3oP00;003o0080oh000P00o`020?n00003003o003oP000oh000080
0?l00P3oP005003o0080oh000P00o`030?n000H00?l000<0oh00003o0000o`000P00o`020?n00080
0?l000<0o`000?n0003oP000103oP002003o00030?n0003o0000o`000080oh000P00o`030?n000@0
0?l0103o00030?n000@00?l000<0oh00003o0000o`001`3o00040?n000800?l00P3oP0000`00o`00
oh000?n000020?n001Sooooo000Fooooo`d0o`0000<0003o0?l0003o00001P3o00000`000?l0o`00
0?l000020000o`T0o`000P000?l70?l00080003o0`3o00020000o`d0o`0000<0003o0?l0003o0000
2`3o00020000o`<0o`000P000?l70?l00180003o1@3o00020?n001@0o`003_ooool20?l000<0oh00
1P00o`020?n000X00?l0103oP003003o00H0o`000P3oP0000`00o`00oh000?n0000B003o00@0o`00
0`000?l20?l00080oh000P00o`000`3o0000003o0000o`090?l00080oh00103o00000`000?l0o`00
0?l000020?l00080003o1`3o00020?n000<00?l01P3o00030?n000800?l01`3o0002003o0080003o
0P3o00030?n000800?l03_ooool50?l000@0oh000P00o`050?l00080003o0P3o00020000o`030?l0
0000o`000?l000L0o`000P000?l>0?l000@0oh000P3o00020000o`L0o`000P000?l70?l000030000
o`3o0000o`0000L0o`0010000?l20?l00080003o00<0o`000000o`000?l00P000?l50?l00080oh00
3P3o0004003o00h0o`000P3oP0020?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l0
0P3oP003003o0080oh001`00o`050?n000/00?l00P3oP002003o0080oh0000<00?l00?n0003oP000
0P00o`020?n000D00?l00P3oP002003o00<0oh001P00o`000`3oP0000?l0003o0002003o0080oh00
0P00o`000`3o0000oh000?n000040?n000800?l000<0oh000?l0003o00000P3oP002003o00<0oh00
1000o`040?l000<0oh001000o`000`3oP0000?l0003o00070?l000@0oh000P00o`020?n00003003o
003oP000oh000080oh006?ooool001Kooooo3@3o00050000o`@0o`0000<0003o0?l0003o00000P00
0?l<0?l00080003o103o00020000o`<0o`000P000?l=0?l000030000o`3o0000o`0000D0o`000P00
0?l40?l00080003o0`3o00020000o`L0o`002`000?l20?l000D0003o2@3o00040000o`h0o`003_oo
ool20?l000800?l000<0oh00003o0000o`001000o`020?n000T00?l00`3o00040?n00003003o003o
0000o`0000@0o`000P3oP00B003o00030?l0003oP000oh0000@0o`000`000?l20?l00080oh000`3o
00020000o`80o`0010000?l30?l00080oh00103o00000`000?l0o`000?l000020?l00080003o1`3o
00020?n000<00?l01P3o00030?n000H00?l00`3o0004003o0080o`000`3oP002003o00kooooo0P3o
P0030?l000@0oh001000o`030?l00080003o0P3o00020000o`030?n00000o`000?l000@0o`0000<0
003o0?l0003o00001P000?l:0?l00080oh00103o00020000o`<0o`000P000?l20?l00080003o4@3o
00040000o`80o`000P000?l00`3o0000003o0000o`0G0?l000H00?l01@3o00020000o`80o`000P00
0?l00`3o0000003o0000o`020?l000kooooo0P00o`030?n000800?l00P3o0002003o0080oh000`00
o`020?n000L00?l01@3oP00;003o00L0oh001000o`050?n000800?l00P3oP00;003o00030?n00000
o`000?l000800?l00P3oP003003o00H0oh000P00o`000`3oP0000?l0003o00020?n000800?l01@3o
P002003o00T0oh000P00o`030?n000H0o`001@3oP002003o00<0oh000P00o`020?n001Sooooo000F
ooooo`d0o`001@000?l40?l000030000o`3o0000o`000080003o303o00020000o`@0o`000P000?l3
0?l00080003o3@3o00000`000?l0o`000?l000050?l00080003o103o00020000o`<0o`000P000?l7
0?l000/0003o0P3o00050000o`T0o`0010000?l>0?l000kooooo0P3o0002003o00030?n00000o`00
0?l000@00?l00P3oP009003o00<0o`00103oP0000`00o`00o`000?l000040?l00080oh004P00o`00
0`3o0000oh000?n000040?l000<0003o0P3o00020?n000<0o`000P000?l20?l000@0003o0`3o0002
0?n000@0o`0000<0003o0?l0003o00000P3o00020000o`L0o`000P3oP003003o00H0o`000`3oP006
003o00<0o`001000o`020?l000<0oh000P00o`0>ooooo`80oh000`3o00040?n000@00?l00`3o0002
0000o`80o`000P000?l00`3oP0000?l0003o00040?l000030000o`3o0000o`0000H0003o2P3o0002
0?n000@0o`000P000?l30?l00080003o0P3o00020000oa40o`0010000?l20?l00080003o00<0o`00
0000o`000?l05`3o0006003o00D0o`000P000?l20?l00080003o00<0o`000000o`000?l00P3o000>
ooooo`800?l00`3oP002003o0080o`000P00o`020?n000<00?l00P3oP007003o00D0oh002`00o`07
0?n000@00?l01@3oP002003o0080oh002`00o`000`3oP0000?l0003o0002003o0080oh000`00o`06
0?n000800?l000<0oh00003o0000o`000P3oP002003o00D0oh000P00o`090?n000800?l00`3oP006
0?l000D0oh000P00o`030?n000800?l00P3oP00Hooooo`005_ooool40?l000030000o`3o0000o`00
00H0o`001@000?l40?l000030000o`3o0000o`000080003o2@3o00020000o`030?l000000?l0003o
00T0o`000P000?l=0?l000030000o`3o0000o`000080o`000P000?l00`3o0000003o0000o`040?l0
0080003o0`3o00020000o`L0o`002`000?l40?l000<0003o2`3o00020000o`h0o`003_ooool20?l0
00800?l000<0oh00003o0000o`001000o`020?n000T00?l00`3o00040?n00003003o003o0000o`00
00@0o`000P3oP0000`3o00000?l0003o000?003o00030?l0003oP000oh0000@0o`000`000?l20?l0
0080oh000`3o00020000o`80o`0010000?l30?l00080oh00103o00000`000?l0o`000?l0000;0?l0
00@0oh0000<00?l00?l0003o0000103o00030?n000H00?l000<0o`000?n0003oP0001P00o`000`3o
P0000?l0003o0002003o00kooooo0P3oP0070?l000D00?l00P3o00020000o`80o`000P000?l00`3o
P0000?l0003o00090?l000@0003o2P3o00020?n000/0o`000P000?l20?l000<0003o3P3o00040000
o`80o`000P000?l00`3o0000003o0000o`020?l00080003o2@3o00020000o`P0o`000P3oP006003o
00L0o`000P000?l00`3o0000003o0000o`020?l000kooooo0P00o`020?n000<00?l00P3o00020?n0
00D00?l00P3oP007003o0080oh001@00o`040?n000<00?l02@3oP004003o0080oh001@00o`020?n0
00L00?l00P3oP002003o00030?n00000o`000?l000@00?l00P3o00070?n000800?l000<0o`000?n0
003oP0000P3oP002003o00/0oh0000<0o`000?n0003oP0001`3oP0040?l000L0oh000P00o`030?n0
00800?l00P3oP00Hooooo`005_ooool40?l000030?n0003o0000o`0000H0o`001@000?l40?l00003
0000o`3o0000o`000080003o303o00020000o`@0o`000P000?l30?l00080003o3@3o00000`000?l0
o`000?l000050?l00080003o103o00020000o`<0o`000P000?l70?l00080003o0P3o00030000o`80
o`000P000?l20?l000D0003o1@3o00020000o`@0o`000P000?l>0?l000kooooo0P3o0002003o0003
0?n00000o`000?l000@00?l00P3oP009003o00<0o`00103oP0070?l00080oh000`3o00020?n000/0
0?l00`3o00020?n000@0o`000`000?l20?l00080oh000`3o00020000o`80o`001@000?l20?l00080
oh00103o00000`000?l0o`000?l000020?l00080003o1`3o00040?n00003003o003o0000o`0000@0
o`000`3oP006003o00030?l0003oP000oh0000@00?l00P3o00000`000?l0oh000?n00002003o00ko
oooo0P3oP0050?l000800?l00P3oP002003o00<0o`000P000?l20?l00080003o00<0o`00003o0000
o`001@3o00020000o`80o`0010000?l:0?l00080oh000P00o`0;0?l000D0003o1`3o00020?n00080
0?l00P3oP0090?l000D0003o103o00000`000?l0o`000?l000070?l00080003o103o00030?n000H0
0?l01`3o00050000o`80o`003_ooool2003o0080oh000`3o00040?n000D00?l00P3oP007003o0080
oh001@00o`040?n000D00?l01P3oP00:003o00@0oh001`00o`020?n000800?l000<0oh00003o0000
o`001P00o`050?n000D00?l0103oP002003o00<0oh001000o`020?n000800?l000<0o`00003o0000
o`000P3oP002003o00<0oh000P3o00040?n00003003o003oP000oh0000/0oh006?ooool001Kooooo
103o00000`3oP000o`000?l000060?l000D0003o103o00000`000?l0o`000?l000020000o``0o`00
0P000?l40?l00080003o0`3o00020000o`d0o`0000<0003o0?l0003o00001@3o00020000o`@0o`00
0P000?l30?l00080003o1`3o00020000o`80o`000`000?l20?l00080003o0P3o00050000o`D0o`00
0P000?l40?l00080003o3P3o000>ooooo`80o`000P00o`000`3oP0000?l0003o0004003o0080oh00
2@00o`030?l000@0oh001`3o00020?n000<0o`000P3oP00;003o00<0o`000P3oP0040?l000<0003o
0P3o00020?n000<0o`000P000?l20?l000D0003o0P3o00020?n000@0o`0000<0003o0?l0003o0000
0P3o00020000o`L0o`00103oP0000`00o`00o`000?l000040?l000<0oh001P00o`000`3o0000oh00
0?n00004003o0080o`0000<0003o0?n0003oP0000P00o`0>ooooo`80oh001@3o0002003o0080oh00
0P00o`030?l00080003o0P3o00020000o`030?l00000o`000?l000D0o`000P000?l20?l000@0003o
2P3o00020?n000800?l02`3o00050000o`L0o`000P3oP002003o0080oh002@3o00050000o`@0o`00
00<0003o0?l0003o00001`3o00020000o`@0o`000`3oP006003o00L0o`001@000?l20?l000kooooo
0P00o`020?n000<0o`00103oP005003o0080oh001`00o`020?n000D00?l0103oP005003o00H0oh00
2P00o`040?n000L00?l00P3oP002003o00030?n00000o`000?l000H00?l01@3oP005003o00@0oh00
0P00o`030?n000@00?l00P3oP002003o00030?l00000o`000?l00080oh000P00o`030?n00080o`00
103oP0000`00o`00oh000?n0000;0?n001Sooooo000Fooooo`80003o0P3o00000`000?l0o`000?l0
00060?l000030000o`3o0000o`000080003o103o00000`000?l0o`000?l000020000o``0o`000P00
0?l40?l00080003o0`3o00020000o`L0o`000P000?l40?l000030000o`3o0000o`0000D0o`001P00
0?l50?l00080003o0P3o00020000o`030?l000000?l0003o00@0003o0P3o00000`000?l0o`000?l0
00020000o`80o`001@000?l20?l00080003o00<0o`000000o`000?l01P3o00000`000?l0o`000?l0
000;0?l000kooooo1000o`000`3oP0000?l0003o0004003o0080oh002@00o`030?l00080oh000`00
o`060?l00080oh000`00o`020?n000/00?l00P3o00000`00o`00oh000?n000040?l00080003o00<0
o`000?n0003oP0000P3oP0090?l000<0003o1P3o00030000o`@0o`000P000?l70?l000@0oh000`00
o`040?l000030?n00000o`000?l000@00?l01@3o0002003o0080003o0P3o00000`000?l0oh000?n0
0002003o00kooooo0P000?l70?l00080oh001@3o00020?n000800?l0403o00030000o`T0o`000P3o
P002003o00/0o`001@000?l70?l00080oh000P00o`020?n000L0o`002`000?lA0?l00080oh000P00
o`0;0?l00080003o1@3o000>ooooo`800?l00P3oP0030?l000@0oh003000o`040?n000D00?l0103o
P003003o00H0oh000P00o`000`3oP0000?l0003o0004003o0080oh0000<00?l00?n0003oP0001000
o`020?n000<00?l00P3oP003003o0080oh000P00o`040?l000<0oh001P00o`050?n000800?l00P3o
P005003o0080oh001@00o`020?n000800?l01@3oP002003o0080oh000`00o`040?n000800?l00`3o
P002003o01Sooooo000Fooooo`80003o0P3o00000`000?l0o`000?l000060?l000030000o`3o0000
o`000080003o103o00000`000?l0o`000?l000020000o``0o`000P000?l40?l00080003o0`3o0002
0000o`L0o`000P000?l40?l000030000o`3o0000o`0000D0o`001P000?l50?l00080003o0P3o0002
0000o`030?l000000?l0003o00@0003o0P3o00000`000?l0o`000?l000020000o`80o`001@000?l2
0?l00080003o00<0o`000000o`000?l01P3o00000`000?l0o`000?l0000;0?l000kooooo1000o`00
0`3oP0000?l0003o0004003o0080oh002@00o`030?l00080oh000`00o`060?l00080oh000`00o`02
0?n000/00?l00P3o00000`00o`00oh000?n000040?l00080003o00<0o`000?n0003oP0000P3oP009
0?l000<0003o1P3o00030000o`@0o`000P000?l70?l000@0oh000`00o`040?l000030?n00000o`00
0?l000@00?l01@3o0002003o0080003o0P3o00000`000?l0oh000?n00002003o00kooooo0P000?l7
0?l00080oh001@3o00020?n000800?l0403o00030000o`T0o`000P3oP002003o00/0o`001@000?l7
0?l00080oh000P00o`020?n000L0o`002`000?lA0?l00080oh000P00o`0;0?l00080003o1@3o000>
ooooo`800?l00P3oP0030?l000@0oh003000o`040?n000D00?l0103oP003003o00H0oh000P00o`00
0`3oP0000?l0003o0004003o0080oh0000<00?l00?n0003oP0001000o`020?n000<00?l00P3oP003
003o0080oh000P00o`040?l000<0oh001P00o`050?n000800?l00P3oP005003o0080oh001@00o`02
0?n000800?l01@3oP002003o0080oh000`00o`040?n000800?l00`3oP002003o01Sooooo000Foooo
o`80003o0P3o00000`000?l0o`000?l000020000o`@0o`0000<0003o0?l0003o00001P3o00000`00
0?l0o`000?l000020000o``0o`000P000?l40?l00080003o1`3o00020000o`T0o`0000<0003o0?l0
003o00001@3o00020000o`T0o`000P000?l20?l00080003o00<0o`000000o`000?l00P000?l40?l0
00030000o`3o0000o`000080003o0P3o00050000o`80o`000P000?l00`3o0000003o0000o`060?l0
00030000o`3o0000o`0000/0o`003_ooool20?n000800?l000<0oh00003o0000o`001000o`030?n0
00T00?l0103oP003003o00H0o`001@00o`020?n001000?l01`3o00040?n000T0o`000P000?l50?l0
0080003o1`3o00020000o`L0o`00103oP003003o00@0o`0000<0oh00003o0000o`001000o`070?l0
0080003o0P3o00000`000?l0oh000?n00002003o00kooooo0P000?l70?l00080oh001@3o00020?n0
00800?l00`3o0004003o00L0o`000P000?l;0?l000<0oh000P00o`0=0?l000030000o`3o0000o`00
00T0o`001000o`030?l000l0003o2@3o00000`000?l0o`000?l000050?l00080oh000P00o`0B0?l0
00kooooo0P00o`050?l000@0oh002@00o`020?l00003003o003oP000oh0000L00?l0103oP003003o
00H0oh000P00o`030?n000L00?l00P3oP004003o0080oh002000o`040?n000@00?l00`3oP006003o
00T0oh0000<00?l00?n0003oP0000P00o`020?n000D00?l00P3oP005003o0080oh000P00o`020?n0
00D00?l00P3oP002003o00D0oh006?ooool001Kooooo0P000?l20?l000030000o`3o0000o`000080
003o103o00000`000?l0o`000?l000060?l000030000o`3o0000o`000080003o303o00020000o`@0
o`000P000?l70?l00080003o2@3o00000`000?l0o`000?l000050?l00080003o2@3o00020000o`80
o`000P000?l00`3o0000003o0000o`020000o`@0o`0000<0003o0?l0003o00000P000?l20?l000D0
003o0P3o00020000o`030?l000000?l0003o00H0o`0000<0003o0?l0003o00002`3o000>ooooo`80
oh000P00o`000`3oP0000?l0003o0004003o00<0oh002@00o`040?n000<00?l01P3o0005003o0080
oh004000o`070?l000@0oh002@3o00020000o`D0o`000P000?l70?l00080003o1`3o00040?n000<0
0?l0103o00000`3oP0000?l0003o0004003o00L0o`000P000?l20?l000030000o`3oP000oh000080
0?l03_ooool20000o`L0o`000P3oP0050?l00080oh000P00o`030?l000@00?l01`3o00020000o`/0
o`000`3oP002003o00d0o`0000<0003o0?l0003o00002@3o0004003o00<0o`003`000?l90?l00003
0000o`3o0000o`0000D0o`000P3oP002003o0180o`003_ooool2003o00D0o`00103oP009003o0080
o`0000<00?l00?n0003oP0001`00o`040?n000<00?l01P3oP002003o00<0oh001`00o`020?n000@0
0?l00P3oP008003o00@0oh001000o`030?n000H00?l02@3oP0000`00o`00oh000?n00002003o0080
oh001@00o`020?n000D00?l00P3oP002003o0080oh001@00o`020?n000800?l01@3oP00Hooooo`00
5_ooool20?n00080o`0000<0003o0?l0003o00000P000?l=0?l000030000o`3o0000o`000080003o
4P3o00020000o`030?l000000?l0003o00@0o`000P000?l90?l000030000o`3o0000o`0000D0o`00
10000?l70?l00080003o0P3o00020000o`030?l000000?l0003o00T0o`000P000?l20?l00080003o
00<0o`000000o`000?l00P3o00020000o`030?l000000?l0003o00H0o`0000<0003o0?l0003o0000
0P000?l90?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP00:003o00@0oh00
0`00o`020?l000T00?l00P3oP00@003o00L0o`00103oP0090?l00080003o3P3o0002003o00<0o`00
1P00o`020?n000<00?l0103o0007003o0080o`0000<0003o0?l0003o00000P3o00040000o`030?l0
003oP000oh0000800?l03_ooool90?l000800?l02@3o00020?n000<00?l0103o00000`000?l0o`00
0?l0000?0?l000<0oh000P00o`090?l00080003o1@3o00020000o`h0o`003`000?l00`3o0000oh00
0?n000060?l000030000o`3o0000o`0000D0o`000P3oP002003o00T0o`000P000?l70?l000kooooo
0P00o`050?l000L0oh001P00o`020?l000<0oh001@00o`040?n000D00?l01P3oP002003o00<0oh00
1`00o`020?n000@00?l00`3oP007003o00@0oh001000o`000`3oP0000?l0003o0004003o00<0oh00
0P00o`020?n000800?l00P3oP0000`3o0000oh000?n000040?n000D0o`000P3oP003003o0080oh00
0P00o`050?n000@00?l00P3oP002003o00030?l0003oP000oh000080oh006?ooool001Kooooo0P3o
P0020?l000030000o`3o0000o`000080003o3@3o00000`000?l0o`000?l000020000oa80o`000P00
0?l00`3o0000003o0000o`040?l00080003o2@3o00000`000?l0o`000?l000050?l000@0003o1`3o
00020000o`80o`000P000?l00`3o0000003o0000o`090?l00080003o0P3o00020000o`030?l00000
0?l0003o0080o`000P000?l00`3o0000003o0000o`060?l000030000o`3o0000o`000080003o2@3o
000>ooooo`80oh000P00o`000`3oP0000?l0003o0004003o0080oh002P00o`040?n000<00?l00P3o
0009003o0080oh004000o`070?l000@0oh002@3o00020000o`h0o`000P00o`030?l000H00?l00P3o
P003003o00@0o`001`00o`020?l000030000o`3o0000o`000080o`0010000?l00`3o0000oh000?n0
0002003o00kooooo2@3o0002003o00T0o`000P3oP003003o00@0o`0000<0003o0?l0003o00003`3o
00030?n000800?l02@3o00020000o`D0o`000P000?l>0?l000l0003o00<0o`000?n0003oP0001P3o
00000`000?l0o`000?l000050?l00080oh000P00o`090?l00080003o1`3o000>ooooo`800?l01@3o
00070?n000H00?l00P3o00030?n000D00?l0103oP005003o00H0oh000P00o`030?n000L00?l00P3o
P004003o00<0oh001`00o`040?n000@00?l000<0oh00003o0000o`001000o`030?n000800?l00P3o
P002003o0080oh0000<0o`000?n0003oP000103oP0050?l00080oh000`00o`020?n000800?l01@3o
P004003o0080oh000P00o`000`3o0000oh000?n000020?n001Sooooo000Fooooo`@0o`0000<0003o
0?l0003o00000P000?l=0?l000030000o`3o0000o`000080003o5@3o00020000o`@0o`000P000?l9
0?l000030000o`3o0000o`000080003o0`3o00040000o`L0o`000P000?l20?l00080003o303o0002
0000o`80o`000P000?l50?l00080003o1`3o00020000o`<0o`000P000?l90?l000kooooo0P3oP002
003o00030?n00000o`000?l000@00?l00P3oP00A003o0080oh002@00o`020?n001000?l0103o0002
0000o`030?l0003oP000oh000080oh002@3o00020000o`T0o`0000<0oh00003o0000o`000P00o`05
0?l000/00?l0103o0007003o0080o`0000<0003o0?l0003o00000P3o00020000o`<0o`00103oP00>
ooooo`80o`000P3oP0050?l000800?l02@3o00020?n000<00?l0103o00000`000?l0o`000?l0000@
0?l00080oh002`3o00020000o`D0o`000P000?l30?l00080003o0P3o00020000o`L0o`000P000?l3
0?l000H0003o2`3o00000`000?l0oh000?n000070?l000800?l00P3o00020?n00003003o003o0000
o`000080o`000P000?l70?l000kooooo1@00o`020?l000L0oh001000o`020?n00080o`0000<00?l0
0?n0003oP0001@00o`020?n000L00?l01P3oP002003o00030?l0003oP000oh0000@0oh000`00o`02
0?n000@00?l00`3oP007003o00@0oh001000o`000`3oP0000?l0003o0002003o00D0oh000P00o`04
0?n000<0o`001P3oP0050?l00080oh001@00o`040?n000800?l000<0oh00003o0000o`001P00o`05
0?n001Sooooo000Fooooo`@0o`0000<0003o0?l0003o00003`3o00000`000?l0o`000?l000020000
oa/0o`000P000?l90?l000030000o`3o0000o`0000D0o`0010000?l;0?l00080003o303o00020000
o`T0o`000P000?l70?l00080003o3P3o000>ooooo`80oh002@00o`020?n001`00?l00P3oP00@003o
00@0o`000P000?l00`3o0000oh000?n000020?n000<0o`000P000?l40?l00080003o2@3o00000`3o
P0000?l0003o00040?l000<0oh002@00o`060?l000L00?l00P3o00000`000?l0o`000?l000070?l0
00@0oh003_ooool20?l00080oh001@3o0007003o00@0o`000P3oP003003o00@0o`001`000?l<0?l0
0080oh004P3o00020000o`<0o`000P000?l20?l000L0003o0P3o00020000o`L0o`000P000?l20?l0
00030000o`3o0000o`0000H0o`0000<0003o0?l0003o00001`3o00020?n000800?l00P3oP0000`00
o`00o`000?l000020?l00080003o1`3o000>ooooo`D00?l00P3o00070?n000@00?l00P3oP0020?l0
0003003o003oP000oh0000D00?l00P3oP007003o00@0oh001@00o`060?n000<00?l0103oP004003o
00030?n00000o`000?l000D00?l00P3o0002003o0080oh000P00o`000`3oP0000?l0003o0002003o
0080o`000`3oP0020?l00080oh000P000?l30?l000H0oh001@3o00020?n000D00?l02@3oP006003o
00<0oh000P00o`0Hooooo`005_ooool40?l000030000o`3o0000o`0000l0o`0000<0003o0?l0003o
00000P000?lK0?l00080003o2@3o00000`000?l0o`000?l000050?l000@0003o2`3o00020000o``0
o`000P000?l90?l00080003o1`3o00020000o`h0o`003_ooool20?n000T00?l00P3oP00L003o0080
oh004000o`040?l00080003o00<0o`000?n0003oP0000P3oP0030?l00080003o103o00020000o`T0
o`0000<0oh00003o0000o`00103o00030?n000T00?l01P3o0007003o0080o`0000<0003o0?l0003o
00001`3o00040?n000kooooo0P3o00020?n000D0o`001`00o`040?l00080oh000`00o`040?l000L0
003o303o00020?n00180o`000P000?l30?l00080003o0P3o00070000o`80o`000P000?l70?l00080
003o0P3o00000`000?l0o`000?l000060?l000030000o`3o0000o`0000L0o`000P3oP002003o0080
oh0000<00?l00?l0003o00000P3o00020000o`L0o`003_ooool5003o0080o`001`3oP004003o0080
oh000P3o00000`00o`00oh000?n00005003o0080oh001`00o`040?n000D00?l01P3oP003003o00@0
oh001000o`000`3oP0000?l0003o0005003o0080o`000P00o`020?n000800?l000<0oh00003o0000
o`000P00o`020?l000<0oh000P3o00020?n00080003o0`3o00060?n000D0o`000P3oP005003o00T0
oh001P00o`030?n000800?l06?ooool001Kooooo103o00000`000?l0o`000?l0000;0?l00080003o
0P3o00000`000?l0o`000?l000020000oa/0o`000P000?l30?l00080003o103o00000`000?l0o`00
0?l000050?l000@0003o2`3o00020000oaL0o`000P000?l00`3o0000003o0000o`040?l000<0003o
0P3o00020000o`T0o`003_ooool;003o0080oh00;P00o`020?l000D0003o0P3o00020?n000800?l0
00<0o`000000o`000?l00P3o00040000oa00o`000`3oP009003o00H0o`0000<0oh00003o0000o`00
1P00o`0:0?l000@0oh003_ooool20?l00080oh0000<00?l00?l0003o00000P3o00020?n000L00?l0
0P3o0002003o02/0o`0000<0003o0?l0003o00000P000?l30?l00080003o0P3o00090000o`@0o`00
00<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00001P3o00000`000?l0oh00
0?n00002003o00<0o`00103oP005003o0080003o0P3o00020000o`80o`0000<0003o0?l0003o0000
0P3o000>ooooo`D00?l00P3o00070?n000@00?l00P3oP003003o0080oh001@00o`020?n000L00?l0
0P3oP004003o0080oh000`00o`040?n000<00?l0103oP004003o00030?n00000o`000?l000@00?l0
00<0oh000?l0003o00000P00o`050?n000@00?l01`3oP0020?l00080oh000`3o00040?n000800?l0
1@3o00020?n000800?l000<0oh00003o0000o`002`3oP002003o0080o`000`3oP002003o01Sooooo
000Fooooo`@0o`0000<0003o0?l0003o00002`3o00020000o`80o`0000<0003o0?l0003o00000P00
0?lK0?l00080003o0`3o00020000o`@0o`0000<0003o0?l0003o00001@3o00040000o`/0o`000P00
0?lG0?l00080003o00<0o`000000o`000?l0103o00030000o`80o`000P000?l90?l000kooooo2`00
o`020?n002h00?l00P3o00050000o`80o`000P3oP002003o00030?l000000?l0003o0080o`001000
0?l@0?l000<0oh002@00o`060?l000030?n00000o`000?l000H00?l02P3o00040?n000kooooo0P3o
00020?n00003003o003o0000o`000080o`000P3oP007003o0080o`000P00o`0[0?l000030000o`3o
0000o`000080003o0`3o00020000o`80o`002@000?l40?l000030000o`3o0000o`000080o`000P00
0?l20?l000030000o`3o0000o`0000H0o`0000<0003o0?n0003oP0000P00o`030?l000@0oh001@00
o`020000o`80o`000P000?l20?l000030000o`3o0000o`000080o`003_ooool5003o0080o`001`3o
P004003o0080oh000`00o`020?n000D00?l00P3oP007003o0080oh001000o`020?n000<00?l0103o
P003003o00@0oh001000o`000`3oP0000?l0003o0004003o00030?n0003o0000o`0000800?l01@3o
P004003o00L0oh000P3o00020?n000<0o`00103oP002003o00D0o`000P3oP002003o00030?n00000
o`000?l000/0oh000P00o`020?l000<0oh000P00o`0Hooooo`005_ooool40?l000030000o`3o0000
o`0000l0o`0000<0003o0?l0003o00000P000?lK0?l00080003o0`3o00020000o`@0o`0000<0003o
0?l0003o00001@3o00020000o`d0o`000P000?l00`3o0000003o0000o`040000o`80o`0000<0003o
0?l0003o00002`3o00050000o`@0o`000`000?l20?l00080003o2@3o000>ooooocP00?l000<0oh00
003o0000o`000P3o00070000o`80oh000P00o`030?l000H0003o00<0o`000000o`000?l03@3o0003
0?n000T00?l01P3o00000`3oP0000?l0003o0006003o00X0o`00103oP00>ooooo`80003o0`3oP002
0?l000@0oh001@3o00020?n000@00?l0;03o00020000o`/0o`002@000?l70?l00080003o0P3o0000
0`000?l0o`000?l000060?l000030000o`3oP000oh0000800?l00P3o00000`00o`00oh000?n00006
003o00030?l000000?l0003o0080o`000P000?l20?l000030000o`3o0000o`000080003o3_ooool5
003o0080o`001P3oP003003o00H0oh0000<00?l00?n0003oP0001@00o`040?n000D00?l00P3oP004
003o0080oh000`00o`040?n000<00?l00P3oP004003o00<0oh000P00o`070?n000@00?l00P3oP005
003o00@0o`000`3oP0020?l00080oh000`3o00040?n000800?l01`3o0002003o00030?n00000o`00
0?l000/0oh000P00o`020?l000<0oh000P00o`0Hooooo`005_ooool40?l000030000o`3o0000o`00
00l0o`0000<0003o0?l0003o00000P000?lK0?l00080003o0`3o00020000o`@0o`0000<0003o0?l0
003o00001@3o00020000o`d0o`000P000?l00`3o0000003o0000o`040000o`80o`0000<0003o0?l0
003o00002`3o00050000o`@0o`000`000?l20?l00080003o2@3o000>ooooocP00?l000<0oh00003o
0000o`000P3o00070000o`80oh000P00o`030?l000H0003o00<0o`000000o`000?l03@3o00030?n0
00T00?l01P3o00000`3oP0000?l0003o0006003o00X0o`00103oP00>ooooo`80003o0`3oP0020?l0
00@0oh001@3o00020?n000@00?l0;03o00020000o`/0o`002@000?l70?l00080003o0P3o00000`00
0?l0o`000?l000060?l000030000o`3oP000oh0000800?l00P3o00000`00o`00oh000?n00006003o
00030?l000000?l0003o0080o`000P000?l20?l000030000o`3o0000o`000080003o3_ooool5003o
0080o`001P3oP003003o00H0oh0000<00?l00?n0003oP0001@00o`040?n000D00?l00P3oP004003o
0080oh000`00o`040?n000<00?l00P3oP004003o00<0oh000P00o`070?n000@00?l00P3oP005003o
00@0o`000`3oP0020?l00080oh000`3o00040?n000800?l01`3o0002003o00030?n00000o`000?l0
00/0oh000P00o`020?l000<0oh000P00o`0Hooooo`005_ooool40?l000030000o`3o0000o`0000@0
o`000P3oP0050?l00080003o0P3o00000`000?l0o`000?l0000M0?l00080003o0`3o00020000o``0
o`000P000?l=0?l00080003o00<0o`000000o`000?l01`000?l80?l000030000o`3o0000o`000080
o`000P000?l00`3o0000003o0000o`040?l000<0003o0P3o00020000o`T0o`003_oooolf003o0080
o`0000<0oh000?l0003o00000P3o00050000o`80o`000P3oP002003o00<0o`001P000?l00`3o0000
003o0000o`0=0?l000<0oh00103o00020?n000800?l000<0oh000?l0003o0000103o00000`3oP000
0?l0003o0006003o00030?n0003o0000o`0000T0o`000P00o`0>ooooo`80003o1@3o00020?n000L0
o`000P3oP00E0?l00080003o503o00020000o`<0o`000P000?l=0?l000L0003o1`3o00050000o`@0
o`001@000?l20?l000800?l00`3o00020?n000@00?l00`3o00020000o`80o`000P000?l50?l00080
003o3_ooool5003o00H0oh001@00o`020?n00080o`001`3oP005003o00H0oh002P00o`090?n000H0
0?l00`3oP002003o00T0oh000P00o`020?n000D00?l0103o00000`3oP0000?l0003o0002003o00@0
oh0000<0o`000?n0003oP0000P3oP002003o0080oh001@3o0002003o00030?n00000o`000?l000@0
o`001`3oP004003o00030?n00000o`000?l000800?l06?ooool001Kooooo103o00000`000?l0o`00
0?l000040?l00080oh001@3o00020000o`80o`0000<0003o0?l0003o00007@3o00020000o`<0o`00
0P000?l<0?l00080003o3@3o00020000o`030?l000000?l0003o00L0003o203o00000`000?l0o`00
0?l000020?l00080003o00<0o`000000o`000?l0103o00030000o`80o`000P000?l90?l000kooooo
=P00o`020?l000030?n0003o0000o`000080o`001@000?l20?l00080oh000P00o`030?l000H0003o
00<0o`000000o`000?l03@3o00030?n000@0o`000P3oP002003o00030?n0003o0000o`0000@0o`00
00<0oh00003o0000o`001P00o`000`3oP000o`000?l000090?l000800?l03_ooool20000o`D0o`00
0P3oP0070?l00080oh005@3o00020000oa@0o`000P000?l30?l00080003o3@3o00070000o`L0o`00
1@000?l40?l000D0003o0P3o0002003o00<0o`000P3oP004003o00<0o`000P000?l20?l00080003o
1@3o00020000o`kooooo1@00o`060?n000D00?l00P3oP0020?l000L0oh001@00o`060?n000X00?l0
2@3oP006003o00<0oh000P00o`090?n000800?l00P3oP005003o00@0o`0000<0oh00003o0000o`00
0P00o`040?n000030?l0003oP000oh000080oh000P00o`020?n000D0o`000P00o`000`3oP0000?l0
003o00040?l000L0oh001000o`000`3oP0000?l0003o0002003o01Sooooo000Fooooo`@0o`0000<0
003o0?l0003o00000P3o00040?n000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o
0000o`0001L0o`000P000?l90?l00080003o1`3o00020000o`<0o`000P000?l=0?l00080003o00<0
o`000000o`000?l02@000?l;0?l00080003o00<0o`000000o`000?l00P3o00050000o`80o`000P00
0?l90?l000kooooo=P00o`020?l00003003o003o0000o`000080o`0010000?l<0?l00080003o0`3o
00020000o`H0o`0000<0003o0?l0003o00000P00o`090?l00080oh000P00o`000`3oP000o`000?l0
00040?l000030?n00000o`000?l000H00?l000<0oh00003o0000o`000P3oP002003o0080oh001@00
o`0>ooooo`L0o`000P000?l@0?l00080003o0`3o00020000o`L0o`000P000?l90?l00080oh00103o
00000`00o`00o`000?l000020?l00080003o0`3o00020000oa00o`0010000?l70?l000L0003o0P3o
00020000o`X0o`000P3oP0070?l00080003o0P3o00020000o`L0o`003_ooool2003o0080oh0000<0
0?l00?n0003oP000103oP005003o0080oh000P00o`020?n00003003o003oP000oh0000@00?l02P3o
P002003o00H0oh0000<00?l00?n0003oP0001`3oP006003o00<0oh000P00o`040?n00003003o003o
P000oh000080oh000P00o`020?n000<00?l00P3oP0040?l000030?n00000o`000?l000800?l01@3o
P002003o0080oh000P3o00020?n000D0o`000P00o`000`3oP0000?l0003o00060?l000D0oh000P00
o`020?l000<0oh000P00o`0Hooooo`005_ooool40?l000030000o`3o0000o`0000/0o`000P000?l2
0?l000030000o`3o0000o`0000D0o`000P000?l70?l00080003o1`3o00020000o`T0o`000P000?l7
0?l00080003o0`3o00020000o`d0o`000P000?l00`3o0000003o0000o`020?l000L0003o0P3o0002
0000o`80o`0000<0003o0?l0003o00001@3o00020000o`T0o`000P000?l90?l000kooooo8000o`04
0?l001000?l0103o00000`00o`00o`000?l000020?l000@0003o00<0o`000?n0003oP0000P00o`07
0?l00080003o2`3o00000`000?l0o`000?l00002003o00/0o`000P00o`000`3oP000o`000?l00004
0?l000030?n00000o`000?l000H00?l000<0oh00003o0000o`000P3oP0020?l000<0oh001000o`0>
ooooo`L0o`000P000?l@0?l00080003o0P3o00000`000?l0o`000?l000070?l00080003o1P3o0000
0`000?l0o`000?l000040?n00080o`0000<0oh000?l0003o00002`3o00020000o`L0o`000P3oP005
0?l00080003o1`3o00050000oa00o`000P3oP00D0?l000kooooo0P00o`020?n00003003o003oP000
oh0000800?l00P3oP005003o0080oh001@00o`040?n000<00?l02@3oP002003o0080oh001@00o`02
0?n000800?l01@3oP006003o00<0oh001000o`020?n00003003o003oP000oh000080oh000P00o`02
0?n000<00?l00P3oP004003o00030?n00000o`000?l000800?l01`3oP002003o0080o`000P3oP000
0`00o`00oh000?n000020?n000800?l000<0o`000?n0003oP0000P3oP0040?l000D0oh001@00o`02
0?n000800?l06?ooool001Kooooo103o00000`000?l0o`000?l0000;0?l00080003o0P3o00000`00
0?l0o`000?l000050?l00080003o1`3o00020000o`L0o`000P000?l90?l00080003o1`3o00020000
o`<0o`000P000?l=0?l00080003o00<0o`000000o`000?l00P3o00070000o`80o`000P000?l20?l0
00030000o`3o0000o`0000D0o`000P000?l90?l00080003o2@3o000>ooooob000?l0103o000@003o
00@0o`0000<00?l00?l0003o00000P3o00040000o`030?l0003oP000oh0000800?l01`3o00020000
o`/0o`0000<0003o0?l0003o00000P00o`0;0?l000800?l000<0oh000?l0003o0000103o00000`3o
P0000?l0003o0006003o00030?n00000o`000?l00080oh000P3o00030?n000@00?l03_ooool70?l0
0080003o403o00020000o`80o`0000<0003o0?l0003o00001`3o00020000o`H0o`0000<0003o0?l0
003o0000103oP0020?l000030?n0003o0000o`0000/0o`000P000?l70?l00080oh001@3o00020000
o`L0o`001@000?l@0?l00080oh00503o000>ooooo`800?l00P3oP0000`00o`00oh000?n00002003o
0080oh001@00o`020?n000D00?l0103oP003003o00T0oh000P00o`020?n000D00?l00P3oP002003o
00D0oh001P00o`030?n000@00?l00P3oP0000`00o`00oh000?n000020?n000800?l00P3oP003003o
0080oh001000o`000`3oP0000?l0003o0002003o00L0oh000P00o`020?l00080oh0000<00?l00?n0
003oP0000P3oP002003o00030?l0003oP000oh000080oh00103o00050?n000D00?l00P3oP002003o
01Sooooo000Fooooo`@0o`0000<0003o0?l0003o00002`3o00020000o`80o`0000<0003o0?l0003o
00000P000?l30?l00080003o1`3o00020000o`L0o`000P000?lB0?l00080003o0`3o00020000o`80
o`000P000?l30?l00080003o1`3o00020000o`80o`001`000?l20?l00080003o0P3o00000`000?l0
o`000?l000050?l00080003o2@3o00020000o`T0o`003_oooolP003o0080o`00103oP00<003o00H0
o`0000<00?l00?n0003oP000103o00020000o`030?l0003oP000oh0000800?l01`3o00020000o`D0
o`000P3oP0040?l000030000o`3o0000o`0000@0o`000P00o`070?l000800?l000<0oh000?l0003o
0000103o00000`3oP0000?l0003o0006003o00030?n00000o`000?l000H0o`000`3oP002003o00ko
oooo0P3o0002003o00`0o`000P3oP002003o00T0o`000`000?l70?l00080003o103o00030000o`80
o`000P3oP0040?l000030?n0003o0000o`000080o`000P000?l20?l000<0003o0P3o00020000oaL0
o`001@000?l90?l00080003o103o00000`000?l0o`000?l0000?0?l000030000o`3o0000o`000080
o`003_ooool4003o00<0oh001000o`020?n000<00?l00P3oP007003o0080oh000`00o`020?n00080
0?l0103oP003003o0080oh001000o`0:0?n000800?l00P3oP002003o00<0oh001000o`020?n00003
003o003oP000oh0000H0oh000`00o`040?n000800?l000<0oh00003o0000o`001P00o`030?n00080
0?l0103oP0000`00o`00oh000?n000020?n000800?l000<0o`000?n0003oP0000P00o`040?l000D0
oh001000o`050?n001Sooooo000Fooooo`@0o`0000<0003o0?l0003o00002`3o00020000o`80o`00
00<0003o0?l0003o00000P000?l30?l00080003o1`3o00020000o`L0o`000P000?lB0?l00080003o
0`3o00020000o`80o`000P000?l30?l00080003o1`3o00020000o`80o`001`000?l20?l00080003o
0P3o00000`000?l0o`000?l000050?l00080003o2@3o00020000o`T0o`003_oooolP003o0080o`00
103oP00<003o00H0o`0000<00?l00?n0003oP000103o00020000o`030?l0003oP000oh0000800?l0
1`3o00020000o`D0o`000P3oP0040?l000030000o`3o0000o`0000@0o`000P00o`070?l000800?l0
00<0oh000?l0003o0000103o00000`3oP0000?l0003o0006003o00030?n00000o`000?l000H0o`00
0`3oP002003o00kooooo0P3o0002003o00`0o`000P3oP002003o00T0o`000`000?l70?l00080003o
103o00030000o`80o`000P3oP0040?l000030?n0003o0000o`000080o`000P000?l20?l000<0003o
0P3o00020000oaL0o`001@000?l90?l00080003o103o00000`000?l0o`000?l0000?0?l000030000
o`3o0000o`000080o`003_ooool4003o00<0oh001000o`020?n000<00?l00P3oP007003o0080oh00
0`00o`020?n000800?l0103oP003003o0080oh001000o`0:0?n000800?l00P3oP002003o00<0oh00
1000o`020?n00003003o003oP000oh0000H0oh000`00o`040?n000800?l000<0oh00003o0000o`00
1P00o`030?n000800?l0103oP0000`00o`00oh000?n000020?n000800?l000<0o`000?n0003oP000
0P00o`040?l000D0oh001000o`050?n001Sooooo000Fooooo`L0o`000P000?l=0?l000030000o`3o
0000o`000080003o0`3o00020000oa@0o`000P000?l>0?l00080003o1`3o00020000o`<0o`000P00
0?l70?l00080003o0P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0
003o0?l0003o00000P000?l30?l00080003o103o00020000o`<0o`000P000?l90?l000kooooo7P00
o`040?l000@0oh003P00o`020?l000<00?l00P3oP0070?l00080oh000P00o`070?l00080003o2`3o
00000`000?l0o`000?l000020?n00080o`000P00o`000`3o0000oh000?n00006003o00030?n0003o
0000o`0000@0o`0000<0oh00003o0000o`001P00o`000`3oP0000?l0003o00060?l000<0oh000P00
o`0>ooooo`80o`001@00o`020?l000800?l01`3o0004003o00h0o`000P000?l00`3o0000003o0000
o`040?l000<0003o4@3o00030000oa80o`000P3oP0070?l000D0003o2@3o00020000o`@0o`0000<0
003o0?l0003o00001P3o00050000o`@0o`0000<0003o0?l0003o00000P3o000>ooooo`80oh000P00
o`030?n000@00?l00P3oP003003o00H0oh000`00o`020?n000D00?l01P3oP0000`00o`00o`000?l0
00040?n000<00?l01P3oP002003o00030?n00000o`000?l00080oh000P00o`090?n00003003o003o
P000oh0000@0oh000`00o`040?n000@00?l000<0oh00003o0000o`001000o`030?n000@00?l0103o
P0000`00o`00oh000?n000020?n000800?l00`3oP002003o0080oh000P3o00030?n000800?l01@3o
P0020?l00080oh006?ooool001Kooooo1`3o00020000o`d0o`0000<0003o0?l0003o00000P000?l3
0?l00080003o503o00020000o`h0o`000P000?l70?l00080003o0`3o00020000o`L0o`000P000?l2
0?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`000?l00002
0000o`<0o`000P000?l40?l00080003o0`3o00020000o`T0o`003_oooolN003o00@0o`00103oP00>
003o0080o`000`00o`020?n000L0o`000P3oP002003o00L0o`000P000?l;0?l000030000o`3o0000
o`000080oh000P3o0002003o00030?l0003oP000oh0000H00?l000<0oh000?l0003o0000103o0000
0`3oP0000?l0003o0006003o00030?n00000o`000?l000H0o`000`3oP002003o00kooooo0P3o0005
003o0080o`000P00o`070?l000@00?l03P3o00020000o`030?l000000?l0003o00@0o`000`000?lA
0?l000<0003o4P3o00020?n000L0o`001@000?l90?l00080003o103o00000`000?l0o`000?l00006
0?l000D0003o103o00000`000?l0o`000?l000020?l000kooooo0P3oP002003o00<0oh001000o`02
0?n000<00?l01P3oP003003o0080oh001@00o`060?n00003003o003o0000o`0000@0oh000`00o`06
0?n000800?l000<0oh00003o0000o`000P3oP002003o00T0oh0000<00?l00?n0003oP000103oP003
003o00@0oh001000o`000`3oP0000?l0003o0004003o00<0oh001000o`040?n00003003o003oP000
oh000080oh000P00o`030?n000800?l00P3oP0020?l000<0oh000P00o`050?n00080o`000P3oP00H
ooooo`005_ooool;0?l00080003o2@3o00000`000?l0o`000?l000020000o`L0o`000P000?l70?l0
0080003o1`3o00020000o`h0o`000P000?l20?l000030000o`3o0000o`000080o`000P000?l30?l0
0080003o0P3o00020000o`L0o`000P000?l20?l000030000o`3o0000o`000080o`000P000?l20?l0
00030000o`3o0000o`000080003o0`3o00020000o`@0o`000P000?l30?l00080003o2@3o000>oooo
oah00?l0103o00020?n001000?l00P000?l3003o0080oh000P3o00020000o`<0o`00103oP0070?l0
0080003o1@3o00020?n000@0o`0000<0003o0?l0003o0000103oP005003o0080oh001000o`000`00
0?l0o`000?l000040?l000`00?l01P3o00030?n000800?l03_ooool20?l000D00?l00P3o0002003o
0080oh001@3o00020?n000D0o`000P00o`0D0?l000030000o`3o0000o`000080oh000P3o0002003o
00T0o`001@000?l90?l00080003o2@3o00000`000?l0o`000?l000070000o`H0o`000P3oP003003o
00@0o`0000<0003o0?l0003o00000P3o0002003o00<0o`0010000?l40?l000030000o`3o0000o`00
0080003o3_ooool4003o00030?n00000o`000?l000@00?l00`3oP002003o00H0oh000`00o`020?n0
00L00?l00P3oP003003o0080o`00103oP002003o00<0o`00103oP002003o00030?n0003o0000o`00
00H0oh0000<00?l00?n0003oP0001@3oP002003o00H0oh0000<00?l00?n0003oP0001P00o`000`3o
P0000?l0003o0006003o00030?n00000o`000?l000@00?l00P3o00050?n000800?l0303oP004003o
00<0oh000P3o00020?n001Sooooo000Fooooo`/0o`000P000?l<0?l00080003o1`3o00020000ob@0
o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l20?l000D0003o3@3o00020000o`80
o`0000<0003o0?l0003o00000P000?lG0?l00080003o3_oooolM003o00D0o`000P3oP00B003o0080
oh0000<00?l00?n0003oP0000P3o00040000o`030?l0003oP000oh0000h0o`000P000?l20?n000@0
o`0000<0003o0?l0003o0000103oP002003o00030?l00000o`000?l00080oh001000o`000`000?l0
o`000?l000040?l000<0oh001`00o`080?l000<0oh000P00o`0>ooooo`80o`001@00o`020?l00080
0?l00P3oP0050?l00080oh001@3o0002003o00T0o`000P000?l50?l00080oh000P3o00000`000?l0
o`000?l000020000o`80o`000P00o`070?l00080003o203o00020000o`80o`000P000?l50?l00080
003o103o00000`000?l0o`000?l000040000o`80o`0000<0003o0?l0003o00001P3o0003003o00@0
o`0000<0003o0?l0003o00000P3o0004003o00030?l000000?l0003o00@0003o1@3o00020000o`ko
oooo103oP007003o00<0oh000P00o`060?n00003003o003oP000oh000080oh000`00o`020?n00080
0?l00P3oP005003o00@0oh000P00o`030?l000@0oh000P00o`030?l000H0oh000`00o`050?n000@0
0?l00P3oP003003o00@0oh001000o`030?n000H00?l000<0oh00003o0000o`001000o`090?n000<0
o`001P3oP0000`00o`00oh000?n00006003o00030?n0003o0000o`000080oh006?ooool001Kooooo
2`3o00020000o``0o`000P000?l70?l00080003o903o00000`000?l0o`000?l000020?l00080003o
0`3o00020000o`80o`001@000?l=0?l00080003o0P3o00000`000?l0o`000?l000020000oaL0o`00
0P000?l>oooooad00?l01@3o00020?n001800?l00P3oP0000`00o`00oh000?n000020?l000@0003o
00<0o`000?n0003oP0003P3o00020000o`80oh00103o00000`000?l0o`000?l000040?n000800?l0
00<0o`00003o0000o`000P3oP004003o00030000o`3o0000o`0000@0o`000`3oP007003o00P0o`00
0`3oP002003o00kooooo0P3o0005003o0080o`000P00o`020?n000D0o`000P3oP0050?l000800?l0
2@3o00020000o`D0o`000P3oP0020?l000030000o`3o0000o`000080003o0P3o0002003o00L0o`00
0P000?l80?l00080003o0P3o00020000o`D0o`000P000?l40?l000030000o`3o0000o`0000@0003o
0P3o00000`000?l0o`000?l000060?l000<00?l0103o00000`000?l0o`000?l000020?l000@00?l0
00<0o`000000o`000?l010000?l50?l00080003o3_ooool40?n000L00?l00`3oP002003o00H0oh00
00<00?l00?n0003oP0000P3oP003003o0080oh000P00o`020?n000D00?l0103oP002003o00<0o`00
103oP002003o00<0o`001P3oP003003o00D0oh001000o`020?n000<00?l0103oP004003o00<0oh00
1P00o`000`3oP0000?l0003o0004003o00T0oh000`3o00060?n00003003o003oP000oh0000H00?l0
00<0oh000?l0003o00000P3oP00Hooooo`005_ooool20?l00080003o1`3o00020000o``0o`000P00
0?l20?l000030000o`3o0000o`0001l0o`000P000?l00`3o0000003o0000o`040?l000030000o`3o
0000o`0000/0o`001@000?l40?l000@0003o0`3o00040000o`T0o`0000<0003o0?l0003o00004P3o
00020000o`kooooo7@00o`050?l00080oh000P00o`000`3oP0000?l0003o000=003o0080oh000`00
o`020?l000@0003o1`3o00000`000?l0o`000?l000040000o`<0o`000P000?l60?l000030000o`3o
0000o`0000@0oh001@00o`020?n000D00?l01P3o00030?n000@00?l00P3oP00:0?l000@00?l03_oo
ool20?l00080oh000`00o`020?l000800?l03P3o0004003o00L0o`000P000?l00`3o0000003o0000
o`020?l00080oh000P00o`0@0?l00080003o3P3o00070000o`@0o`0000<0003o0?l0003o00001P00
0?l90?l000030?n00000o`000?l000D0o`000P000?l20?l00080oh000P00o`000`3o0000003o0000
o`040000o`D0o`000P000?l>ooooo`T00?l00P3o00030?n000800?l0103oP003003o00@0oh005000
o`030?l000@0oh000P00o`030?l00080oh000P00o`020?n00003003o003oP000oh0000@0oh001@00
o`040?n00003003o003oP000oh0000800?l00P3oP003003o0080oh001000o`020?l000030?n00000
o`000?l000800?l00P3o00070?n000D0o`001P3oP0000`00o`00oh000?n00006003o00<0o`000P3o
P00Hooooo`005_ooool20?l00080003o1`3o00020000o``0o`000P000?l20?l000030000o`3o0000
o`0001l0o`000P000?l00`3o0000003o0000o`040?l000030000o`3o0000o`0000/0o`001@000?l4
0?l000@0003o0`3o00040000o`T0o`0000<0003o0?l0003o00004P3o00020000o`kooooo7@00o`05
0?l00080oh000P00o`000`3oP0000?l0003o000=003o0080oh000`00o`020?l000@0003o1`3o0000
0`000?l0o`000?l000040000o`<0o`000P000?l60?l000030000o`3o0000o`0000@0oh001@00o`02
0?n000D00?l01P3o00030?n000@00?l00P3oP00:0?l000@00?l03_ooool20?l00080oh000`00o`02
0?l000800?l03P3o0004003o00L0o`000P000?l00`3o0000003o0000o`020?l00080oh000P00o`0@
0?l00080003o3P3o00070000o`@0o`0000<0003o0?l0003o00001P000?l90?l000030?n00000o`00
0?l000D0o`000P000?l20?l00080oh000P00o`000`3o0000003o0000o`040000o`D0o`000P000?l>
ooooo`T00?l00P3o00030?n000800?l0103oP003003o00@0oh005000o`030?l000@0oh000P00o`03
0?l00080oh000P00o`020?n00003003o003oP000oh0000@0oh001@00o`040?n00003003o003oP000
oh0000800?l00P3oP003003o0080oh001000o`020?l000030?n00000o`000?l000800?l00P3o0007
0?n000D0o`001P3oP0000`00o`00oh000?n00006003o00<0o`000P3oP00Hooooo`005_ooool20?l0
0080003o00<00?l00?l0003o00003@3o00020000o`L0o`0000<0003o0?l0003o00001P3o00000`00
0?l0o`000?l000070?l00080oh00403o00020000o`L0o`000P000?l40?l000030000o`3o0000o`00
0080o`000P000?l20?l000030000o`3o0000o`000080o`0010000?l00`3o0000003o0000o`020?l0
0080003o2@3o00000`000?l0o`000?l000070?l00080003o2`3o000>oooooah00?l0103o00020?n0
00800?l000<0oh00003o0000o`001000o`020?n000L00?l00P3oP003003o00T0o`000P3oP0070?l0
00@0003o00<0o`000000o`000?l01`3o00040?n000800?l00P3oP00:003o00H0o`000`3oP004003o
00D0o`000P000?l20?l00080003o00<0o`00003o0000o`000P3oP00>ooooo`/0o`000P3oP00<0?l0
0080oh002@3o00020000o`030?l000000?l0003o0080o`001000o`090?l00003003o003oP000oh00
00d0o`0000<0003o0?l0003o00000P000?l20?l000L0003o1`3o00060000oa40o`000P000?l20?l0
0080oh000`3o00060000o`L0o`003_ooool4003o00<0oh000P00o`020?l000<0oh000P00o`040?n0
00<00?l0103oP003003o0080oh003`00o`030?l000@0oh001@00o`020?n000800?l00P3oP003003o
00@0oh000`00o`040?n000<0o`000P3oP002003o00@0oh0000<00?l00?n0003oP0000P00o`040?l0
00030?n00000o`000?l000H0o`001@3oP0050?l000@0oh000P00o`030?n000H00?l00`3o00020?n0
01Sooooo000Fooooo`80o`000P000?l00`00o`00o`000?l0000=0?l00080003o1`3o00000`000?l0
o`000?l000060?l000030000o`3o0000o`0000L0o`000P3oP00@0?l00080003o1`3o00020000o`@0
o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00000P3o00040000o`03
0?l000000?l0003o0080o`000P000?l90?l000030000o`3o0000o`0000L0o`000P000?l;0?l000ko
oooo7P00o`040?l00080oh000P00o`000`3oP0000?l0003o0004003o0080oh001`00o`020?n000<0
0?l02@3o00020?n000L0o`0010000?l00`3o0000003o0000o`070?l000@0oh000P00o`020?n000X0
0?l01P3o00030?n000@00?l01@3o00020000o`80o`000P000?l00`3o00000?l0003o00020?n000ko
oooo2`3o00020?n000`0o`000P3oP0090?l00080003o00<0o`000000o`000?l00P3o0004003o00T0
o`0000<00?l00?n0003oP0003@3o00000`000?l0o`000?l000020000o`80o`001`000?l70?l000H0
003o4@3o00020000o`80o`000P3oP0030?l000H0003o1`3o000>ooooo`@00?l00`3oP002003o0080
o`000`3oP002003o00@0oh000`00o`040?n000<00?l00P3oP00?003o00<0o`00103oP005003o0080
oh000P00o`020?n000<00?l0103oP003003o00@0oh000`3o00020?n000800?l0103oP0000`00o`00
oh000?n00002003o00@0o`0000<0oh00003o0000o`001P3o00050?n000D0o`00103oP002003o00<0
oh001P00o`030?l00080oh006?ooool001Kooooo0P3o00020?n000030?l000000?l0003o00d0o`00
0P000?l00`3o0000003o0000o`070?l00080003o1`3o00020000o`L0o`000P3oP0090?l00080003o
0`3o00020000o`80o`000P000?l90?l000030000o`3o0000o`000080o`000P000?l20?l000030000
o`3o0000o`0000H0003o1`3o00020000o`L0o`0000<0003o0?l0003o00000P3o00020000o`<0o`00
0P000?l;0?l000kooooo8P00o`020?n000800?l000<0oh00003o0000o`000P00o`020?l000<0oh00
2`00o`090?l00080oh000P00o`050?l000@0003o403o00020?n000<00?l00P3o0007003o0080o`00
1@3oP004003o0080o`0000<0003o0?l0003o00000P000?l50?l000800?l00P3oP00>ooooo`/0o`00
0P3oP00:0?l000@0oh002@3o00020000o`030?l000000?l0003o0080o`001@00o`090?l00080oh00
3@3o00000`000?l0o`000?l000020?l000L0003o2@3o00020000o`80o`000P000?lA0?l00080003o
2@3o00040000o`L0o`003_ooool20?n000<00?l00P3oP002003o00D0oh000P00o`020?n000800?l0
0P3o00050?n000<00?l0103oP005003o0080oh001000o`050?n000800?l0103oP003003o0080oh00
1`00o`040?n00003003o003oP000oh000080oh002@3o00040?n00003003o003oP000oh0000H0o`00
00<0oh000?l0003o00000P3o00020000o`80o`001`3oP0030?l000@0oh000P00o`030?n000H00?l0
1@3o000Hooooo`005_ooool20?l00080oh0000<0o`000000o`000?l03@3o00020000o`030?l00000
0?l0003o00L0o`000P000?l70?l00080003o1`3o00020?n000T0o`000P000?l30?l00080003o0P3o
00020000o`T0o`0000<0003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00001P00
0?l70?l00080003o1`3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`/0o`003_oo
oolR003o0080oh000P00o`000`3oP0000?l0003o0002003o0080o`000`3oP00;003o00T0o`000P3o
P002003o00D0o`0010000?l@0?l00080oh000`00o`020?l000L00?l00P3o00050?n000@00?l00P3o
00000`000?l0o`000?l000020000o`D0o`000P00o`020?n000kooooo2`3o00020?n000X0o`00103o
P0090?l00080003o00<0o`000000o`000?l00P3o0005003o00T0o`000P3oP00=0?l000030000o`3o
0000o`000080o`001`000?l90?l00080003o0P3o00020000oa40o`000P000?l90?l000@0003o1`3o
000>ooooo`80oh000`00o`020?n000800?l01@3oP002003o0080oh000P00o`020?l000D0oh000`00
o`040?n000D00?l00P3oP004003o00D0oh000P00o`040?n000<00?l00P3oP007003o00@0oh0000<0
0?l00?n0003oP0000P3oP0090?l000@0oh0000<00?l00?n0003oP0001P3o00000`3oP000o`000?l0
00020?l00080003o0P3o00070?n000<0o`00103oP002003o00<0oh001P00o`050?l001Sooooo000F
ooooo`80o`000P3oP00:0?l00080003o1`3o00020000o`L0o`000P000?l70?l00080003o1`3o0002
0?n000T0o`000P000?l70?l00080003o2@3o00000`000?l0o`000?l000060?l000030000o`3o0000
o`000080003o0P3o00020000o`L0o`000P000?l00`3o0000003o0000o`040?l000030000o`3o0000
o`000180o`000P000?l>ooooobH00?l000<0oh00003o0000o`000P00o`020?l000800?l000<0oh00
003o0000o`000P3oP005003o00H0o`000P000?l30?l000@00?l04P3o00000`000?l0o`000?l00009
0?l000/00?l00P3oP007003o0080o`0000<0003o0?l0003o00000P000?l50?l000800?l00P3oP00>
ooooo`/0o`000P3oP00:0?l00080oh001000o`000`3o0000003o0000o`040?l00080003o00<0o`00
0000o`000?l00P3o00020?n000800?l02P3o00020?n000800?l01`3o00020000o`80o`0000<0003o
0?l0003o00000P3o00070000o`d0o`000P000?lJ0?l00080003o2`3o000>ooooo`80oh000`00o`04
0?n000800?l00P3o00030?n000L00?l0103oP003003o00@0oh002`00o`020?n00003003o003oP000
oh0000800?l0103oP003003o00@0oh001@00o`040?n00003003o003oP000oh0000@0oh001`3o0004
0?n000<00?l00P3oP002003o00<0oh00103o00020000o`80o`000`3oP002003o00<0oh000P3o0004
0?n000800?l00`3oP006003o00D0o`006?ooool001Kooooo5`3o00020000o`80o`000P000?l30?l0
0080003o0P3o00020000o`<0o`000P000?l40?l000D0oh002@3o00020000o`L0o`000P000?l00`3o
0000003o0000o`090?l00080003o1`3o00020000o`L0o`000P000?l20?l00080003o00<0o`000000
o`000?l06@3o00020000o`kooooo6`00o`020?n000T00?l000<0oh00003o0000o`000P00o`020?l0
00800?l000<0oh00003o0000o`000P3oP005003o00@0o`000P000?l20?l000030000o`3oP000oh00
00800?l02`3o00000`3oP000o`000?l00007003o00/0o`00103oP007003o0080o`0000<00?l00?n0
003oP0001000o`020?l000030000o`3o0000o`0000@0o`000P3oP0000`00o`00oh000?n000020?n0
00kooooo2`3o00020?n00003003o003o0000o`000080o`000P00o`030?l00080oh001000o`000`3o
0000003o0000o`070?l00080003o0P3o00020000o`D0o`000P3oP0050?l00080oh000P00o`090?l0
0080oh001@3o00020000o`80o`001@000?l50?l00080003o3@3o00020?n000<00?l02`3o00020000
o`L0o`000P000?l50?l000kooooo0P3oP005003o0080oh000P00o`020?l000<0oh001`00o`060?n0
0003003o003oP000oh000080oh001`00o`020?n000800?l00P3oP005003o00@0oh000`00o`040?n0
00800?l00`3o00090?n000800?l02@3o00020?n00003003o003oP000oh000080oh000P00o`0>0?n0
0080o`001`3oP004003o00<0oh000P00o`020?n000800?l01@3o000Hooooo`005_oooolG0?l00080
003o0P3o00020000o`<0o`000P000?l20?l00080003o0`3o00020000o`@0o`001@3oP0090?l00080
003o1`3o00020000o`030?l000000?l0003o00T0o`000P000?l70?l00080003o1`3o00020000o`80
o`000P000?l00`3o0000003o0000o`0I0?l00080003o3_oooolK003o0080oh002@00o`000`3oP000
0?l0003o0002003o0080o`000P00o`000`3oP0000?l0003o00020?n000D00?l0103o00020000o`80
o`0000<0003o0?n0003oP0000P00o`0;0?l000030?n0003o0000o`0000L00?l02`3o00040?n000L0
0?l00P3o00000`00o`00oh000?n00004003o0080o`0000<0003o0?l0003o0000103o00020?n00003
003o003oP000oh000080oh003_ooool;0?l00080oh0000<00?l00?l0003o00000P3o0002003o00<0
o`000P3oP004003o00030?l000000?l0003o00L0o`000P000?l20?l00080003o1@3o00020?n000D0
o`000P3oP002003o00T0o`000P3oP0050?l00080003o0P3o00050000o`D0o`000P000?l=0?l00080
oh000`00o`0;0?l00080003o1`3o00020000o`D0o`003_ooool20?n000D00?l00P3oP002003o0080
o`000`3oP007003o00H0oh0000<00?l00?n0003oP0000P3oP007003o0080oh000P00o`020?n000D0
0?l0103oP003003o00@0oh000P00o`030?l000T0oh000P00o`090?l00080oh0000<00?l00?n0003o
P0000P3oP002003o00h0oh000P3o00070?n000@00?l00`3oP002003o0080oh000P00o`050?l001So
oooo000FoooooaL0o`000P000?l20?l00080003o1`3o00020000oaL0o`000P000?l20?l000030000
o`3o0000o`0000D0o`000P000?l90?l00080003o3@3o00000`000?l0o`000?l000020000o`80o`00
0P000?l00`3o0000003o0000o`070?l00080003o103o00000`000?l0o`000?l0000;0?l000kooooo
6`00o`020?n001800?l000<0oh00003o0000o`001`00o`040?l000D0003o0P3oP0040?l000030000
o`3o0000o`000080003o103o00000`3oP0000?l0003o00020?n000@00?l0303o00040?n000D00?l0
103o00000`00o`00oh000?n000060?l000030000o`3o0000o`0000@0o`000P3oP0000`3o0000oh00
0?n00002003o00kooooo103o00000`00o`00o`000?l000040?l00080oh001`00o`030?l00080oh00
1000o`000`3o0000003o0000o`020?l00080003o0P3o00000`000?l0oh000?n0000@0?l00080oh00
0P00o`050?l00080003o0P3o00020?n000D0o`000P000?l20?l000D0003o1@3o00020000o`/0o`00
103oP005003o00L0o`001@000?l60?l00080003o00<0o`000000o`000?l00P3o000>ooooo`80oh00
1@00o`020?n000800?l00P3oP0000`00o`00oh000?n00006003o00D0oh001@00o`020?n000D00?l0
0P3oP004003o0080oh001@00o`040?n000<00?l0103oP0050?l000T0oh000P3o00030?n000H0o`00
0P3oP0000`00o`00oh000?n000020?n000800?l01@3oP002003o00D0oh00103o00070?n000@00?l0
1@3oP009003o01Sooooo000FoooooaL0o`000P000?l20?l00080003o1`3o00020000oaL0o`000P00
0?l20?l000030000o`3o0000o`0000D0o`000P000?l90?l00080003o3@3o00000`000?l0o`000?l0
00020000o`80o`000P000?l00`3o0000003o0000o`070?l00080003o103o00000`000?l0o`000?l0
000;0?l000kooooo6`00o`020?n001800?l000<0oh00003o0000o`001`00o`040?l000D0003o0P3o
P0040?l000030000o`3o0000o`000080003o103o00000`3oP0000?l0003o00020?n000@00?l0303o
00040?n000D00?l0103o00000`00o`00oh000?n000060?l000030000o`3o0000o`0000@0o`000P3o
P0000`3o0000oh000?n00002003o00kooooo103o00000`00o`00o`000?l000040?l00080oh001`00
o`030?l00080oh001000o`000`3o0000003o0000o`020?l00080003o0P3o00000`000?l0oh000?n0
000@0?l00080oh000P00o`050?l00080003o0P3o00020?n000D0o`000P000?l20?l000D0003o1@3o
00020000o`/0o`00103oP005003o00L0o`001@000?l60?l00080003o00<0o`000000o`000?l00P3o
000>ooooo`80oh001@00o`020?n000800?l00P3oP0000`00o`00oh000?n00006003o00D0oh001@00
o`020?n000D00?l00P3oP004003o0080oh001@00o`040?n000<00?l0103oP0050?l000T0oh000P3o
00030?n000H0o`000P3oP0000`00o`00oh000?n000020?n000800?l01@3oP002003o00D0oh00103o
00070?n000@00?l01@3oP009003o01Sooooo000Fooooo`@0o`0000<0003o0?l0003o00001P3o0000
0`000?l0o`000?l000070?l00080003o0P3o00020000o`L0o`000P000?l00`3o0000003o0000o`07
0?l00080003o103o00020000o`T0o`0000<0003o0?l0003o00001@3o00020000o`d0o`000P000?l9
0?l000030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o0080o`000P000?l9
0?l000030000o`3o0000o`0000/0o`003_oooolK003o0080oh0000<00?l00?l0003o00000P3o000=
003o00030?n00000o`000?l000@00?l00P3oP0000`00o`00o`000?l000020?l000@0003o00<0o`00
0?n0003oP000103o00000`000?l0o`000?l000040000o`80o`0000<0oh00003o0000o`000P3oP004
003o00`0o`00103oP002003o00030?n00000o`000?l000D0o`000P3oP0060?l000030?n0003o0000
o`0000L0o`001000o`0>ooooo`80oh000P3o00000`00o`00o`000?l000040?l00080oh000`00o`02
0?n000L0o`000P00o`0B0?l00080003o00<0o`000000o`000?l02@3o0002003o00D0o`000P000?l2
0?l00080oh001@3o00050000o`80o`0010000?l30?l00080003o2`3o00040?n000D00?l01`3o0007
0000o`@0o`000P000?l00`3o0000003o0000o`020?l000kooooo0P3oP003003o00@0oh000P00o`02
0?n00003003o003oP000oh000080oh001000o`000`3oP0000?l0003o00020?n000D00?l00P3oP004
003o00<0oh000P00o`040?n000D00?l0103oP003003o00@0oh001@3o00050?n000@00?l00P3o0003
0?n000@0o`002@3oP002003o00<0oh000P3o0002003o00@0oh001@00o`050?n000H00?l01@3oP004
003o00030?n00000o`000?l000800?l06?ooool001Kooooo103o00000`000?l0o`000?l000060?l0
00030000o`3o0000o`0000L0o`000P000?l20?l00080003o1`3o00020000o`030?l000000?l0003o
00L0o`000P000?l40?l00080003o2@3o00000`000?l0o`000?l000050?l00080003o3@3o00020000
o`T0o`0000<0003o0?l0003o00000P000?l20?l00080003o00<0o`000000o`000?l00P3o00020000
o`T0o`0000<0003o0?l0003o00002`3o000>oooooa/00?l00P3oP0000`00o`00o`000?l000020?l0
00d00?l000<0oh00003o0000o`001000o`020?n00003003o003o0000o`000080o`0010000?l00`3o
0000oh000?n000040?l000030000o`3o0000o`0000@0003o0P3o00000`3oP0000?l0003o00020?n0
00@00?l0303o00040?n000800?l000<0oh00003o0000o`001@3o00020?n000H0o`0000<0oh000?l0
003o00001`3o0004003o00kooooo0P3oP0020?l00003003o003o0000o`0000@0o`000P3oP003003o
0080oh001`3o0002003o0180o`000P000?l00`3o0000003o0000o`090?l000800?l01@3o00020000
o`80o`000P3oP0050?l000D0003o0P3o00040000o`<0o`000P000?l;0?l000@0oh001@00o`070?l0
00L0003o103o00020000o`030?l000000?l0003o0080o`003_ooool20?n000<00?l0103oP002003o
0080oh0000<00?l00?n0003oP0000P3oP004003o00030?n00000o`000?l00080oh001@00o`020?n0
00@00?l00`3oP002003o00@0oh001@00o`040?n000<00?l0103oP0050?l000D0oh001000o`020?l0
00<0oh00103o00090?n000800?l00`3oP0020?l000800?l0103oP005003o00D0oh001P00o`050?n0
00@00?l000<0oh00003o0000o`000P00o`0Hooooo`005_ooool40?l000030000o`3o0000o`0000H0
o`0000<0003o0?l0003o00005`3o00020000o`L0o`000P000?lB0?l00080003o0`3o00020000o`@0
o`000P000?l70?l00080003o00<0o`000000o`000?l00P3o00020000o`80o`0000<0003o0?l0003o
00000P000?l90?l00080003o5`3o000>oooooa/00?l00P3oP0000`00o`00o`000?l0000B003o00@0
o`000P3oP0000`00o`00oh000?n000070?l00080oh002@3o00020000o`<0o`00103oP004003o00D0
o`000P3oP0050?l000@0oh000P00o`000`3oP0000?l0003o00040?l000<0oh001000o`020?l00003
0?n0003o0000o`0000L0o`000P00o`020?l000kooooo0P3oP0020?l000030?n000000?l0003o00@0
o`000P3oP003003o0080oh001@3o00020000oaH0o`0000<0003o0?l0003o00001`3o00020?n00080
0?l01@3o00060000o`D0o`000P000?l20?l000030000o`3o0000o`0000@0003o0`3o00020000o`/0
o`00103oP005003o00T0o`001`000?l50?l000@0003o3_ooool5003o00P0oh0000<00?l00?l0003o
0000103oP002003o00030?n00000o`000?l00080oh000`00o`020?l00080oh001000o`030?n00080
0?l0103oP00<003o0080oh000P00o`020?n000<0o`001@3oP002003o00@0o`000`3oP0040?l00080
oh000P00o`030?l000@0oh000P00o`000`3oP000o`000?l00002003o00@0oh001@00o`020?n000D0
0?l00P3oP002003o00D0oh002@00o`0Hooooo`005_ooool40?l000030000o`3o0000o`0000H0o`00
00<0003o0?l0003o00005`3o00020000o`L0o`000P000?lB0?l00080003o0`3o00020000o`@0o`00
0P000?l70?l00080003o00<0o`000000o`000?l00P3o00020000o`80o`0000<0003o0?l0003o0000
0P000?l90?l00080003o5`3o000>oooooa/00?l00P3oP0000`00o`00o`000?l0000B003o00@0o`00
0P3oP0000`00o`00oh000?n000070?l00080oh002@3o00020000o`<0o`00103oP004003o00D0o`00
0P3oP0050?l000@0oh000P00o`000`3oP0000?l0003o00040?l000<0oh001000o`020?l000030?n0
003o0000o`0000L0o`000P00o`020?l000kooooo0P3oP0020?l000030?n000000?l0003o00@0o`00
0P3oP003003o0080oh001@3o00020000oaH0o`0000<0003o0?l0003o00001`3o00020?n000800?l0
1@3o00060000o`D0o`000P000?l20?l000030000o`3o0000o`0000@0003o0`3o00020000o`/0o`00
103oP005003o00T0o`001`000?l50?l000@0003o3_ooool5003o00P0oh0000<00?l00?l0003o0000
103oP002003o00030?n00000o`000?l00080oh000`00o`020?l00080oh001000o`030?n000800?l0
103oP00<003o0080oh000P00o`020?n000<0o`001@3oP002003o00@0o`000`3oP0040?l00080oh00
0P00o`030?l000@0oh000P00o`000`3oP000o`000?l00002003o00@0oh001@00o`020?n000D00?l0
0P3oP002003o00D0oh002@00o`0Hooooo`005_ooool40?l000030000o`3o0000o`000080003o3@3o
00000`000?l0o`000?l000020000o``0o`000P000?l70?l00080003o4P3o00020000o`T0o`000P00
0?l70?l00080003o00<0o`000000o`000?l00P3o00020000o`80o`0000<0003o0?l0003o0000903o
000>oooooa/00?l00P3oP007003o0080oh003000o`020?l000800?l00P3oP0000`00o`00oh000?n0
0002003o00D0o`000P3oP004003o00`0o`000P3oP0050?l00080oh000P3o00020?n000<0o`00103o
P007003o00@0o`0000<00?l00?n0003oP0001P00o`030?n000@0o`001`00o`0>ooooo`80oh000`3o
00020000o`@0o`001@00o`070?l00080003o0P3o00020000oa80o`0000<0003o0?l0003o00001`3o
00020?n000800?l0103o00070000o`<0o`000P000?l70?l000@0003o2@3o00020000o`D0o`00103o
P005003o00<0o`000P000?l60?l000L0003o0`3o00020000o`80o`003_ooool4003o00D0oh000P00
o`020?n000D0o`000P3oP002003o00030?n00000o`000?l00080oh000`00o`020?l000@0oh000P00
o`000`3oP000o`000?l000020?l000@0oh001`00o`020?n000<00?l01P3o00070?n00003003o003o
0000o`0000@0o`000`3oP0020?l000800?l00P3oP002003o00<0o`00103oP002003o00<0oh000P00
o`070?n000800?l00`3oP004003o00T0oh000P00o`020?n000D00?l06?ooool001Kooooo0P00o`02
0?l000030000o`3o0000o`000080003o1`3o00020000o`@0o`0000<0003o0?l0003o00000P000?lY
0?l00080003o4P3o00050000o`80o`000P000?l20?l000030000o`3o0000o`000080o`000P000?lP
0?l000kooooo6`00o`020?n000L00?l00P3oP00@003o0080oh0000<00?l00?n0003oP0000P00o`05
0?l00080oh001000o`000`3o0000oh000?n000020?n000800?l00P3o00000`000?l0o`000?l00002
0?n000D0o`000P3oP007003o0080oh002@00o`040?l00003003o003oP000oh0000H00?l000<0oh00
003o0000o`000P00o`020?l000800?l000<0o`00003o0000o`000P00o`0>ooooo`80o`001@3oP004
0?l000<00?l02@3o00020000o`80o`000P000?l@0?l000<0003o2@3o0004003o00@0o`001`000?l3
0?l00080003o0P3o00020000o`030?l000000?l0003o00@0003o2@3o00030000o`H0o`000`3oP004
003o00<0o`0050000?l20?l000kooooo1000o`050?n000800?l00P3oP0050?l000D0oh000P00o`02
0?n000D00?l0103oP005003o0080o`00103oP007003o0080oh000`00o`020000o`@0o`001`3oP007
0?l000<0oh000P3o0002003o0080oh000P3o00000`000?l0o`000?l000040?n000800?l000<0oh00
003o0000o`00103o00050?n000800?l01@3oP0020?l000@0oh0000<00?l00?n0003oP0001000o`02
0?n000D00?l06?ooool001Kooooo0P00o`020?l000030000o`3o0000o`000080003o1`3o00020000
o`@0o`0000<0003o0?l0003o00000P000?lY0?l00080003o4P3o00050000o`80o`000P000?l20?l0
00030000o`3o0000o`000080o`000P000?lP0?l000kooooo6`00o`020?n000L00?l00P3oP00@003o
0080oh0000<00?l00?n0003oP0000P00o`050?l00080oh001000o`000`3o0000oh000?n000020?n0
00800?l00P3o00000`000?l0o`000?l000020?n000D0o`000P3oP007003o0080oh002@00o`040?l0
0003003o003oP000oh0000H00?l000<0oh00003o0000o`000P00o`020?l000800?l000<0o`00003o
0000o`000P00o`0>ooooo`80o`001@3oP0040?l000<00?l02@3o00020000o`80o`000P000?l@0?l0
00<0003o2@3o0004003o00@0o`001`000?l30?l00080003o0P3o00020000o`030?l000000?l0003o
00@0003o2@3o00030000o`H0o`000`3oP004003o00<0o`0050000?l20?l000kooooo1000o`050?n0
00800?l00P3oP0050?l000D0oh000P00o`020?n000D00?l0103oP005003o0080o`00103oP007003o
0080oh000`00o`020000o`@0o`001`3oP0070?l000<0oh000P3o0002003o0080oh000P3o00000`00
0?l0o`000?l000040?n000800?l000<0oh00003o0000o`00103o00050?n000800?l01@3oP0020?l0
00@0oh0000<00?l00?n0003oP0001000o`020?n000D00?l06?ooool001Kooooo103o00000`000?l0
o`000?l000020000o`L0o`000P000?l50?l00080oh002@3o00020000o`L0o`000P000?lU0?l00080
003o103o00020000o`030?l000000?l0003o0080o`000P000?l20?l000030000o`3o0000o`000080
o`000P000?l20?l000030000o`3o0000o`0000D0o`000P000?lD0?l000kooooo6`00o`020?n000L0
0?l00P3oP00@003o0080oh0000<00?l00?n0003oP0001`3o00020?n000800?l00`3o00020?n000H0
o`0000<0003o0?l0003o00000P3oP0050?l00080oh001`00o`020?n000/00?l00P3o00000`00o`00
oh000?n00006003o00030?n00000o`000?l000800?l00P3o0003003o0080o`000P00o`0>ooooo`80
o`001@3oP0040?l000<00?l03@3o00020000o`030?l000000?l0003o00L0o`000P000?l40?l000<0
003o1P3o00020?n000030?l00000o`000?l000@00?l00P3o00070000o`L0o`000P000?l00`3o0000
003o0000o`040000o`L0o`0010000?l70?l000<0oh001000o`030?l001@0003o0P3o000>ooooo`80
0?l01`3oP002003o0080oh001@3o00050?n000T00?l0103oP003003o00P0oh000`00o`020?n00080
0?l00P3oP003003o00@0o`001`3oP0030?l000@00?l0103o00030?n000800?l00P3oP0020?l00003
0000o`3o0000o`0000@0oh000P00o`030?n000@0o`000`3oP004003o00D0oh000P00o`040?n000L0
0?l00P3oP005003o01Sooooo000Fooooo`@0o`0000<0003o0?l0003o00000P000?l70?l00080003o
1@3o00020?n000T0o`000P000?l70?l00080003o9@3o00020000o`@0o`000P000?l00`3o0000003o
0000o`020?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o0P3o00000`000?l0o`00
0?l000050?l00080003o503o000>oooooa/00?l00P3oP007003o0080oh004000o`020?n00003003o
003oP000oh0000L0o`000P3oP002003o00<0o`000P3oP0060?l000030000o`3o0000o`000080oh00
1@3o00020?n000L00?l00P3oP00;003o0080o`0000<00?l00?n0003oP0001P00o`000`3oP0000?l0
003o0002003o0080o`000`00o`020?l000800?l03_ooool20?l000D0oh00103o0003003o00d0o`00
0P000?l00`3o0000003o0000o`070?l00080003o103o00030000o`H0o`000P3oP0000`3o00000?l0
003o0004003o0080o`001`000?l70?l00080003o00<0o`000000o`000?l010000?l70?l000@0003o
1`3o00030?n000@00?l00`3o000D0000o`80o`003_ooool2003o00L0oh000P00o`020?n000D0o`00
1@3oP009003o00@0oh000`00o`080?n000<00?l00P3oP002003o0080oh000`00o`040?l000L0oh00
0`3o0004003o00@0o`000`3oP002003o0080oh000P3o00000`000?l0o`000?l000040?n000800?l0
0`3oP0040?l000<0oh001000o`050?n000800?l0103oP007003o0080oh001@00o`0Hooooo`005_oo
ool40?l000030000o`3o0000o`000080003o0P3o00020000o`X0o`000P3oP0040?l000030000o`3o
0000o`0000/0o`000P000?lU0?l00080003o1`3o00020000o`80o`000P000?l70?l00080003o0P3o
00000`000?l0o`000?l000050?l00080003o503o000>oooooa/00?l00P3oP007003o0080oh004000
o`020?n00003003o003o0000o`0000L0o`000P3oP0050?l00080oh000P00o`020?l000800?l000<0
003o0?l0003o00000P3oP0040?l000030000o`3o0000o`0000H00?l000<0o`00003o0000o`000P3o
P009003o0080o`0000<00?l00?n0003oP0002`00o`020?l000L00?l03_ooool20?l000D0oh000P3o
0002003o0080oh0000<00?l00?l0003o0000103o00020?n000D0o`000P000?l00`3o0000003o0000
o`040?l000D0003o103o00050000o`@0o`000P3oP0000`3o00000?l0003o0004003o0080o`001`00
0?l70?l00080003o00<0o`000000o`000?l02`3o00050000o`H0o`001@3oP002003o00<0o`005000
0?l20?l000kooooo0P00o`030?n000800?l00P3oP002003o00D0oh000P3o00050?n000T00?l0103o
P003003o00P0oh000`00o`020?n000800?l00P3oP003003o00H0o`000`3oP002003o00<0oh001000
o`040?l000<0oh001000o`020?n000030?l0003oP000oh0000@0oh000P00o`030?n000@0o`000`3o
P004003o0080oh0000<00?l00?n0003oP0001P3oP003003o0080oh000P00o`020?n000D00?l06?oo
ool001Kooooo103o00000`000?l0o`000?l000020000o`80o`000P000?l:0?l00080oh00103o0000
0`000?l0o`000?l0000;0?l00080003o9@3o00020000o`L0o`000P000?l20?l00080003o1`3o0002
0000o`80o`0000<0003o0?l0003o00001@3o00020000oa@0o`003_oooolK003o0080oh001`00o`02
0?n001000?l00P3oP0000`00o`00o`000?l000070?l00080oh001@3o00020?n000800?l00P3o0002
003o00030000o`3o0000o`000080oh00103o00000`000?l0o`000?l00006003o00030?l00000o`00
0?l00080oh002@00o`020?l00003003o003oP000oh0000/00?l00P3o0007003o00kooooo0P3o0005
0?n00080o`000P00o`020?n00003003o003o0000o`0000@0o`000P3oP0050?l00080003o00<0o`00
0000o`000?l0103o00050000o`@0o`001@000?l40?l00080oh0000<0o`00003o0000o`001000o`02
0?l000L0003o1`3o00020000o`030?l000000?l0003o00/0o`001@000?l60?l000D0oh000P00o`03
0?l001@0003o0P3o000>ooooo`800?l00`3oP002003o0080oh000P00o`050?n00080o`001@3oP009
003o00@0oh000`00o`080?n000<00?l00P3oP002003o0080oh000`00o`060?l000<0oh000P00o`03
0?n000@00?l0103o00030?n000@00?l00P3oP0000`3o0000oh000?n000040?n000800?l00`3oP004
0?l000<0oh001000o`020?n00003003o003oP000oh0000H0oh000`00o`020?n000800?l00P3oP005
003o01Sooooo000Fooooo`800?l01@3o00020000o`80o`000P000?l:0?l00080oh00103o00000`00
0?l0o`000?l000060?l000030000o`3o0000o`000080o`000P000?lB0?l00080003o1`3o00000`00
0?l0o`000?l000020?l00080003o0`3o00020000o`L0o`000P000?l20?l00080003o1`3o00020000
o`80o`0000<0003o0?l0003o00000P000?l30?l00080003o503o000>oooooa/00?l00`3oP006003o
0080oh004000o`020?n00003003o003o0000o`0000L0o`000P3oP0050?l00080oh001P3o00000`00
0?l0o`000?l000060?l000030000o`3o0000o`000080o`000P3oP0030?l000800?l00P3oP005003o
00L0o`000P3oP00@003o0080oh000P00o`0>ooooo`@0o`000`3oP0040?l00080oh000`3o00020000
o`80o`000P000?l00`3o00000?l0003o00020?n000<0o`0010000?l20?l000D0003o0P3o00050000
o`T0o`000P3oP002003o00@0o`001`000?l30?l00080003o0P3o00070000o`T0o`001@000?l60?l0
00D0oh001000o`000`3o0000003o0000o`0B0000o`80o`003_ooool4003o00030?n00000o`000?l0
0080oh000P00o`0<0?n000T00?l0103oP003003o00P0oh000`00o`020?n000L00?l00P3oP005003o
0080oh000P00o`030?n000800?l00P3oP0020?l000D0oh001000o`020?n000030?l0003oP000oh00
0080oh001000o`0:0?n000L00?l00P3oP002003o0080oh000P00o`000`3oP0000?l0003o00060?n0
00D00?l06?ooool001Kooooo2`3o00020000o`L0o`000P000?l00`3o0000003o0000o`040?l00003
0000o`3o0000o`000080003o103o00000`000?l0o`000?l000090?l00080oh002`3o00020000o`L0
o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l20?l00080003o403o00020000oaL0
o`000P3oP0070?l000kooooo6`00o`020?n000L00?l00P3oP00C003o01P0o`0000<0003o0?l0003o
00001P3o00000`000?l0o`000?l000020?l00080oh000`3o0002003o0080oh001000o`050?l00080
oh0000<0o`00003o0000o`003@00o`020?l00003003o003oP000oh0000800?l03_ooool40?l000<0
oh000P3o0002003o0080oh000`3o00020000o`80o`000P000?l00`3o0000oh000?n00002003o00<0
o`0010000?l20?l000<0003o103o00050000o`/0o`000P00o`040?l000L0003o0`3o00020000o`80
o`001`000?l20?l00080oh001@3o00050000o`H0o`001@3oP002003o00<0o`001P000?l30?l000d0
003o3_ooool7003o0080oh000P00o`050?n000800?l00P3oP002003o00030?n00000o`000?l000L0
0?l0103oP003003o00H0oh000P3o00000`00o`00oh000?n000020?n000@00?l000<0oh00003o0000
o`000P00o`020?n000800?l000<0oh00003o0000o`000P3o00030?n000800?l00P3o00070?n00080
0?l0103oP0000`00o`00oh000?n000020?n000800?l00P3oP0000`3o0000oh000?n000070?n000L0
0?l00P3oP006003o00030?n00000o`000?l000H0oh001@00o`0Hooooo`005_ooool;0?l00080003o
1`3o00020000o`030?l000000?l0003o00@0o`0000<0003o0?l0003o00000P000?l40?l000030000
o`3o0000o`0000T0o`000P3oP00;0?l00080003o1`3o00000`000?l0o`000?l000020?l00080003o
0`3o00020000o`80o`000P000?l@0?l00080003o5`3o00020?n000L0o`003_oooolK003o0080oh00
1`00o`020?n001<00?l0603o00000`000?l0o`000?l000060?l000030000o`3o0000o`000080o`00
0P3oP0030?l000800?l00P3oP004003o00D0o`000P3oP0000`3o00000?l0003o000=003o0080o`00
00<00?l00?n0003oP0000P00o`0>ooooo`@0o`000`3oP0020?l000800?l00P3oP0030?l00080003o
0P3o00020000o`030?l0003oP000oh0000800?l00`3o00040000o`80o`000`000?l40?l000D0003o
2`3o0002003o00@0o`001`000?l30?l00080003o0P3o00070000o`80o`000P3oP0050?l000D0003o
1P3o00050?n000800?l00`3o00060000o`<0o`003@000?l>ooooo`L00?l00P3oP002003o00D0oh00
0P00o`020?n000800?l000<0oh00003o0000o`001`00o`040?n000<00?l01P3oP0020?l00003003o
003oP000oh000080oh001000o`000`3oP0000?l0003o0002003o0080oh000P00o`000`3oP0000?l0
003o00020?l000<0oh000P00o`020?l000L0oh000P00o`040?n00003003o003oP000oh000080oh00
0P00o`020?n000030?l0003oP000oh0000L0oh001`00o`020?n000H00?l000<0oh00003o0000o`00
1P3oP005003o01Sooooo000Foooooa@0o`000P000?l00`3o0000003o0000o`040?l000030000o`3o
0000o`000080003o3@3o00000`000?l0o`000?l000020?l00080003o303o00020000o`@0o`0000<0
003o0?l0003o00001`3o00020000o`80o`000P000?l@0?l00080003o803o000>oooooa/00?l00P3o
P00L003o0240o`0000<0003o0?l0003o00000P000?l70?l00080oh001000o`050?l00080oh0000<0
o`00003o0000o`002`00o`040?l000D00?l03_ooool40?l000030?n0003o0000o`000080o`00103o
P0030?l00080003o0P3o00020000o`030?l0003oP000oh0000800?l01@3o00020000o`80o`001@00
0?l20?l000D0003o3`3o00090000o`L0o`001@000?l20?l000@0oh001@3o00070000o`@0o`001@3o
P002003o00<0o`0020000?l00`3o0000003o0000o`0;0000o`kooooo1`00o`020?n000L00?l0103o
P002003o00030?n00000o`000?l00080oh000P00o`090?n00003003o003oP000oh0000T0oh001P00
o`000`3oP0000?l0003o0002003o0080oh000P00o`000`3oP0000?l0003o0002003o00<0oh001P00
o`020?n000X00?l00P3o00040?n000<00?l02`3oP004003o00030?l0003oP000oh0000H00?l000<0
oh00003o0000o`000P3oP002003o0080oh001@00o`0Hooooo`005_oooolD0?l00080003o00<0o`00
0000o`000?l0103o00000`000?l0o`000?l000020000o`d0o`0000<0003o0?l0003o00000P3o0002
0000o``0o`000P000?l40?l000030000o`3o0000o`0000L0o`000P000?l20?l00080003o403o0002
0000ob00o`003_oooolK003o0080oh007000o`0Q0?l000030000o`3o0000o`000080003o1`3o0002
0?n000@00?l01@3o00020?n000030?l00000o`000?l000/00?l0103o0005003o00kooooo103o0000
0`3oP000o`000?l000020?l000@0oh000`3o00020000o`80o`000P000?l00`3o0000oh000?n00002
003o00D0o`000P000?l20?l000D0003o0P3o00050000o`l0o`002@000?l70?l000D0003o0P3o0004
0?n000D0o`001`000?l40?l000D0oh000P00o`030?l000P0003o00<0o`000000o`000?l02`000?l>
ooooo`L00?l00P3oP007003o00@0oh000P00o`000`3oP0000?l0003o00020?n000800?l02@3oP000
0`00o`00oh000?n000090?n000H00?l000<0oh00003o0000o`000P00o`020?n000800?l000<0oh00
003o0000o`000P00o`030?n000H00?l00P3oP00:003o0080o`00103oP003003o00/0oh001000o`00
0`3o0000oh000?n00006003o00030?n00000o`000?l00080oh000P00o`020?n000D00?l06?ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000Wooooog;o00008ooo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Go
oooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaOo0?l07ooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000j
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaOo0?l07ooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
7ooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o
00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0
003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo
02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00
O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
oombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo000Fooooo`80oh00803o00020?n00100o`000P3oP00Y0?l000L0oh003@3o
00000`3oP000o`000?l000040?n00100o`003_ooool20?l000D00?l03@000?l7003o00<0003o1000
o`050?l000@00?l00P000?l2003o00030000o`00o`000?l000l00?l00`3oP004003o00<0003o7`00
o`030000o`H00?l000<0o`00003o0000o`005000o`0>ooooob80003o1000o`0S0000o`T00?l06000
0?l2003o01X0003o1000o`0>ooooo`@0o`00403oP007003o0080oh001`00o`020?l000<00?l00P3o
00070?n000L00?l0103oP002003o0080oh0000<0o`000?n0003oP0000P3oP0020?l000030?n0003o
0000o`0000@0o`007P3oP002003o00D0oh000P00o`060?n000<0o`001`00o`040?l001Sooooo000F
ooooo`80oh00803o00020?n00100o`000P3oP00Y0?l000L0oh003@3o00000`3oP000o`000?l00004
0?n00100o`003_ooool20?l000D00?l03@000?l7003o00<0003o1000o`050?l000@00?l00P000?l2
003o00030000o`00o`000?l000l00?l00`3oP004003o00<0003o7`00o`030000o`H00?l000<0o`00
003o0000o`005000o`0>ooooob80003o1000o`0S0000o`T00?l060000?l2003o01X0003o1000o`0>
ooooo`@0o`00403oP007003o0080oh001`00o`020?l000<00?l00P3o00070?n000L00?l0103oP002
003o0080oh0000<0o`000?n0003oP0000P3oP0020?l000030?n0003o0000o`0000@0o`007P3oP002
003o00D0oh000P00o`060?n000<0o`001`00o`040?l001Sooooo000Fooooo`D0oh00:`3o00020?n0
0080o`00103oP00>0?l000L0oh00903o00070?n00080o`000P3oP00>0?l000kooooo0P3o00020?n0
00<00?l02`000?l7003o00D0003o1000o`020?n000<0o`000P00o`0=0000o`D00?l00P3oP004003o
00<0o`009P00o`030000o`/00?l0103o00000`00o`00o`000?l00002003o0080oh001`00o`0>oooo
ob80003o1000o`000`000?l00?l0003o000R0000o`H00?l040000?l<003o00L0003o5P00o`0>oooo
obT0oh000P3o00020?n00080o`0000<0oh00003o0000o`001P00o`070?n000<0o`001P3oP0000`3o
0000oh000?n000020?l000@0oh001@00o`020000o`<00?l03`3oP003003o01T0oh000P3o00020?n0
01Sooooo000Fooooo`D0oh00:`3o00020?n00080o`00103oP00>0?l000L0oh00903o00070?n00080
o`000P3oP00>0?l000kooooo0P3o00020?n000<00?l02`000?l7003o00D0003o1000o`020?n000<0
o`000P00o`0=0000o`D00?l00P3oP004003o00<0o`009P00o`030000o`/00?l0103o00000`00o`00
o`000?l00002003o0080oh001`00o`0>ooooob80003o1000o`000`000?l00?l0003o000R0000o`H0
0?l040000?l<003o00L0003o5P00o`0>ooooobT0oh000P3o00020?n00080o`0000<0oh00003o0000
o`001P00o`070?n000<0o`001P3oP0000`3o0000oh000?n000020?l000@0oh001@00o`020000o`<0
0?l03`3oP003003o01T0oh000P3o00020?n001Sooooo000Fooooo`80oh000P3o00050?n000@0o`00
0`3oP00X0?l000030?n0003o0000o`0000d0o`001@3oP0020?l00080oh008`3o00040?n000/0o`00
1@3oP0020?l000kooooo103o0003003o00L0003o2`00o`050000o`@00?l0103oP0000`00o`00003o
0000o`0=0000o`/00?l00`3o00020?n000T00?l00P3o000>003o0080oh002`00o`030000oa800?l0
0P3oP007003o00kooooo0P00o`0N0000o`H00?l05`000?l2003o00<0003o0P00o`0;0000oaL00?l0
0P000?lP003o0080003o3_ooool=0?n000030?l0003oP000oh000080o`000P00o`0:0?n000800?l0
2@3oP0020?l000L0oh001`00o`080?n000030?l00000o`000?l000@00?l01`3o00070?n000L00?l0
5`3oP008003o00030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_oo
ool40?l000030?n0003o0000o`000080o`00103oP0030?l00080oh00=03o00020?n000030?l0003o
P000oh0000L0oh00;@3o00020?n00080o`001`3oP00>ooooo`D00?l03`000?l3003o00T0003o2`00
o`0;0000o``00?l00P3o0009003o0080o`007@00o`000`000?l00?l0003o000>003o00@0oh000P3o
00020?n000D00?l03_ooool2003o01h0003o2@00o`0=0000oc000?l00P000?lR003o00kooooo1`3o
P002003o01D0oh000P00o`070?l000/0oh001000o`0C0?n000800?l02@3oP007003o00T0o`00103o
P002003o0100oh000P00o`030?l00080oh001@3o00020?n000800?l06?ooool001Kooooo103o0000
0`3oP000o`000?l000020?l000@0oh000`3o00020?n003@0o`000P3oP0000`3o0000oh000?n00007
0?n002d0o`000P3oP0020?l000L0oh003_ooool5003o00l0003o0`00o`090000o`/00?l02`000?l<
003o0080o`002@00o`020?l001d00?l000<0003o003o0000o`003P00o`040?n00080o`000P3oP005
003o00kooooo0P00o`0N0000o`T00?l03@000?l`003o0080003o8P00o`0>ooooo`L0oh000P00o`0E
0?n000800?l01`3o000;0?n000@00?l04`3oP002003o00T0oh001`00o`090?l000@0oh000P00o`0@
0?n000800?l00`3o00020?n000D0o`000P3oP002003o01Sooooo000Foooooa80o`00103oP0030?l0
00@0oh0000<0o`000?n0003oP0000P3oP00_0?l000030?n0003o0000o`000380o`000P3oP0020?l0
00kooooo1`00o`0K0000o`T00?l040000?l2003o0080003o6`00o`000`3oP0000?l0003o000;003o
0080003o0P00o`030000o`h00?l00P3oP00;003o00kooooo0P00o`0I0000o`<00?l00P000?l;003o
00d0003o0`00o`040000oa000?l00`3oP006003o00D0003o:`00o`020000o`kooooo3P3oP00@003o
00@0oh001@3o000K0?n000H00?l06`3oP009003o0140oh001P3o0002003o00<0oh000P00o`0Hoooo
o`005_oooolB0?l000@0oh000`3o00040?n000030?l0003oP000oh000080oh00;`3o00000`3oP000
o`000?l0000b0?l00080oh000P3o000>ooooo`L00?l06`000?l9003o0100003o0P00o`020000oa/0
0?l000<0oh00003o0000o`002`00o`020000o`800?l00`000?l>003o0080oh002`00o`0>ooooo`80
0?l06@000?l3003o0080003o2`00o`0=0000o`<00?l010000?l@003o00<0oh001P00o`050000ob/0
0?l00P000?l>ooooo`h0oh004000o`040?n000D0o`006`3oP006003o01/0oh002@00o`0A0?n000H0
o`000P00o`030?n000800?l06?ooool001Kooooo0P3oP00K0?l000030?n0003o0000o`0000L0oh00
0P3o00040?n003/0o`000P3oP0030?l000L0oh005P3o000>ooooo`80003o0`00o`0K0000o`/00?l0
5`000?l6003o00<0003o3@00o`030?n000/00?l01`000?lM003o00kooooo1000o`0E0000o`D00?l0
10000?l9003o00h0003o5000o`070?n000@00?l01@000?l7003o00@0003o6@00o`020000o`800?l0
1@000?l>ooooo`T0oh000P3o00070?n000D00?l01`3oP004003o00@0oh0000<0o`000?n0003oP000
1`3oP0020?l000800?l01`3o00020?n000@00?l01`3oP009003o00L0oh001`00o`020?n000<00?l0
0P3oP002003o0280oh006?ooool001Kooooo0P3oP00K0?l000030?n0003o0000o`0000L0oh000P3o
00040?n003/0o`000P3oP0030?l000L0oh005P3o000>ooooo`80003o0`00o`0K0000o`/00?l05`00
0?l6003o00<0003o3@00o`030?n000/00?l01`000?lM003o00kooooo1000o`0E0000o`D00?l01000
0?l9003o00h0003o5000o`070?n000@00?l01@000?l7003o00@0003o6@00o`020000o`800?l01@00
0?l>ooooo`T0oh000P3o00070?n000D00?l01`3oP004003o00@0oh0000<0o`000?n0003oP0001`3o
P0020?l000800?l01`3o00020?n000@00?l01`3oP009003o00L0oh001`00o`020?n000<00?l00P3o
P002003o0280oh006?ooool001Kooooo103oP00R0?l000<0oh002`3o00020?n000L0o`000P3oP00P
0?l00080oh002@3o00020?n000<0o`002@3oP00B0?l000kooooo7P000?l4003o00@0oh001@00o`0G
0000o`@00?l01@000?l@003o0140003o1`00o`000`000?l00?l0003o0009003o00@0oh000`00o`04
0000o`kooooo8P000?l;003o0080003o00<00?l00000o`000?l02@000?l=003o00030000o`00o`00
0?l000800?l0103oP0000`3o00000?l0003o0002003o00d0003o00<00?l00000o`000?l05`00o`02
0000o`L00?l010000?l>ooooo`h0oh001000o`0<0?n000@00?l02`3oP0020?l000X0oh000P3o0006
0?n000<00?l0103o0005003o01@0oh001@00o`090?n000800?l0403oP002003o00L0oh006?ooool0
01Kooooo0P3o00020?n000D0o`000P3oP00[0?l00080oh003P3o00020?n002T0o`001`3oP00B0?l0
00kooooo10000?l3003o01L0003o2`00o`0F0000o`L00?l01`000?l>003o01@0003o0P00o`050000
oa000?l010000?l>oooooa@0003o0P00o`0@0000o`L00?l03P000?l@003o00L0oh001000o`0=0000
obL00?l03_ooool20?n000<0o`000P3oP0020?l000T0oh000P3o00050?n000D0o`001P00o`0E0?n0
00H0o`000`00o`070?n000@00?l0903oP002003o0100oh001@3o0002003o01Sooooo000Fooooo`80
o`000P3oP0050?l00080oh00:`3o00020?n000h0o`000P3oP00Y0?l000L0oh004P3o000>ooooo`@0
003o0`00o`0G0000o`/00?l05P000?l7003o00L0003o3P00o`0D0000o`800?l01@000?l@003o00@0
003o3_oooolD0000o`800?l040000?l7003o00h0003o4000o`070?n000@00?l03@000?lW003o00ko
oooo0P3oP0030?l00080oh000P3o00090?n00080o`001@3oP0050?l000H00?l05@3oP0060?l000<0
0?l01`3oP004003o02@0oh000P00o`0@0?n000D0o`000P00o`0Hooooo`005_ooool;0?l00080oh00
0`3o00020?n000`0o`000P3oP00K0?l00080oh002@3o00020?n000030?l0003oP000oh000080oh00
9P3o00000`3oP000o`000?l000040?n000T0o`000P3oP0050?l000kooooo1@000?l2003o01L0003o
1P00o`020?n00003003o00000?l0003o00/0003o4P00o`050000o`T00?l00P000?l5003o01/0003o
2@00o`020?n000D00?l010000?l>ooooo`@00?l03P000?l5003o00d0003o3000o`020000o`800?l0
2@000?lG003o00l0003o1@00o`020000oa000?l00P000?l3003o0080003o2@00o`0>ooooo`T0o`00
1@3oP002003o00H0oh001`3o00030?n000800?l01`3oP0040?l00080oh0000<0o`00003o0000o`00
1000o`090?n000800?l05`3oP002003o00<0oh001`3o000@0?n000@00?l02@3oP0050?l000@0oh00
6?ooool001Kooooo2`3o00020?n000<0o`000P3oP00<0?l00080oh006`3o00020?n000T0o`000P3o
P0000`3o0000oh000?n000020?n002H0o`0000<0oh000?l0003o0000103oP0090?l00080oh001@3o
000>ooooo`D0003o0P00o`0G0000o`H00?l00P3oP0000`00o`00003o0000o`0;0000oa800?l01@00
0?l9003o0080003o1@00o`0K0000o`T00?l00P3oP005003o00@0003o3_ooool4003o00h0003o1@00
o`0=0000o``00?l00P000?l2003o00T0003o5`00o`0?0000o`D00?l00P000?l@003o0080003o0`00
o`020000o`T00?l03_ooool90?l000D0oh000P00o`060?n000L0o`000`3oP002003o00L0oh00103o
00020?n000030?l00000o`000?l000@00?l02@3oP002003o01L0oh000P00o`030?n000L0o`00403o
P004003o00T0oh001@3o00040?n001Sooooo000Foooooa80o`00103oP0030?l000@0oh000`3o0002
0?n002T0o`00103oP00M0?l000030?n0003o0000o`0001@0o`000`3oP0040?l000kooooo0P000?l5
003o01L0003o2@00o`0=0000o`D00?l0103oP005003o00@0oh000`00o`020000o`800?l01@3oP00D
003o00L0003o1P00o`000`000?l00?l0003o0004003o00L0oh000P3o0005003o0080003o3_ooool2
003o0180003o0`00o`0=0000o`L00?l010000?l5003o00d0003o4`00o`0=0000obT00?l03_ooool7
0?n000H00?l00`000?l2003o00L0oh00103o000B0?n000030?l0003oP000oh0001T0oh001P00o`07
0?n000800?l00`3oP0020?l00080oh000P3o000<0?n000T00?l00P3oP0050?l000/0oh006?ooool0
01Kooooo4P3o00040?n000<0o`00103oP0030?l00080oh00:@3o00040?n001d0o`0000<0oh000?l0
003o0000503o00030?n000@0o`003_ooool20000o`D00?l05`000?l9003o00d0003o1@00o`040?n0
00D00?l0103oP003003o0080003o0P00o`050?n001@00?l01`000?l6003o00030000o`00o`000?l0
00@00?l01`3oP0020?l000D00?l00P000?l>ooooo`800?l04P000?l3003o00d0003o1`00o`040000
o`D00?l03@000?lC003o00d0003o:@00o`0>ooooo`L0oh001P00o`030000o`800?l01`3oP0040?l0
0180oh0000<0o`000?n0003oP0006@3oP006003o00L0oh000P00o`030?n00080o`000P3oP0020?l0
00`0oh002@00o`020?n000D0o`002`3oP00Hooooo`005_ooool20?n001h0o`001P3oP0050?l000@0
oh00DP3o00090?n000kooooo0P000?l5003o00l0003o0`00o`090000o`800?l040000?l5003o0080
o`000P00o`070?l000T00?l01@3oP00F003o00D0003o1P00o`000`000?l00?l0003o000=003o0080
o`000`00o`020000o`kooooo0P00o`0]0000o`03003o00000?l0003o00l0003o4000o`0<0000o`d0
0?l04P000?l7003o00<0003o0P00o`020000o`kooooo3P3oP002003o01l0oh0000<0o`00003o0000
o`003@3oP002003o00D0o`007P3oP0020?l00080oh00103o00000`3oP000o`000?l0000K0?n001So
oooo000Fooooo`80oh007P3o00060?n000D0o`00103oP01B0?l000T0oh003_ooool20000o`D00?l0
3`000?l3003o00T0003o0P00o`0@0000o`D00?l00P3o0002003o00L0o`002@00o`050?n001H00?l0
1@000?l6003o00030000o`00o`000?l000d00?l00P3o0003003o0080003o3_ooool2003o02d0003o
00<00?l00000o`000?l03`000?l@003o00`0003o3@00o`0B0000o`L00?l00`000?l2003o0080003o
3_ooool>0?n000800?l07`3oP0000`3o00000?l0003o000=0?n000800?l01@3o000N0?n00080o`00
0P3oP0040?l000030?n0003o0000o`0001/0oh006?ooool001Kooooo103oP0000`3o0000oh000?n0
000O0?l000030?n0003o0000o`0000@0o`000`3oP0020?l000@0oh003P3o00020?n001d0o`0000<0
oh000?l0003o00008P3o00020?n000kooooo0P000?l5003o02d0003o0P00o`0<0?n00080o`002@00
o`050?l000@00?l00P3o000>003o00L0003o1P00o`000`000?l00?l0003o000B003o0080003o3_oo
ool2003o02d0003o00<00?l00000o`000?l04P000?l=003o0180003o1@00o`0B0000o`L00?l01@00
0?l4003o00kooooo503oP0020?l000D00?l00`3o000F0?n00080o`002@3oP0020?l000D0oh000`3o
0004003o0080oh000P00o`050?n00080o`000P3oP0000`00o`00oh000?n0000=0?n000<0o`006`3o
P0020?l001Sooooo000Fooooo`80o`000P3oP0030?l000@0oh000P3o00030?n002@0o`001@3oP006
0?l00080oh000`3o00040?n00480o`003_ooool20000o`L00?l02`000?l7003o0080003o2P00o`0A
0000o`L00?l00P3oP00:003o00/0oh001000o`000`3oP0000?l0003o0009003o00L0003o1P00o`00
0`000?l00?l0003o000D003o00kooooo@P000?l?003o01<0003o1P00o`0B0000o`<00?l01P000?l5
003o00kooooo1`3oP0020?l00180oh000`3o00040?n000@00?l01`3oP0030?l000H0oh000P00o`0E
0?n000@00?l01`3o000E0?n000@0o`001`3oP0070?l000/0oh006?ooool001Kooooo0P3o00020?n0
00<0o`00103oP0020?l000<0oh00903o00050?n000H0o`000P3oP0030?l000@0oh00@P3o000>oooo
o`80003o1`00o`0;0000o`L00?l00P000?l:003o0140003o1`00o`020?n000X00?l02`3oP004003o
00030?n00000o`000?l000T00?l01`000?l6003o00030000o`00o`000?l001@00?l03_oooom20000
o`l00?l04`000?l6003o0180003o0`00o`060000o`D00?l03_ooool70?n00080o`004P3oP0030?l0
00@0oh001000o`070?n000<0o`001P3oP002003o01D0oh001000o`070?l001D0oh00103o00070?n0
00L0o`002`3oP00Hooooo`005_ooool90?l000@0oh0000<0o`000?n0003oP0001P3oP00^0?l00080
oh00A03o000>ooooo`80003o1`00o`0E0000o`T00?l04P000?l4003o00@0oh002P00o`020?l00080
oh006@00o`050000o`H00?l00`000?lB003o0080003o3_oooom40000oa@00?l0;@000?l5003o00ko
oooo0P3o00020?n000030?l0003oP000oh000100oh00103o00070?n000800?l00P3oP0030?l000L0
oh001000o`020?n000800?l000<0o`000?n0003oP0001P3oP0000`00o`00oh000?n000040?n000T0
0?l00`3oP0020?l00080oh001@3o000I0?n000@0o`002`3oP0000`00o`00oh000?n000020?n001So
oooo000Fooooo`T0o`00103oP0000`3o0000oh000?n000060?n002h0o`000P3oP0140?l000kooooo
0P000?l7003o01D0003o2@00o`0B0000o`@00?l0103oP00:003o0080o`000P3oP00I003o00D0003o
1P00o`030000oa800?l00P000?l>oooood@0003o5000o`0]0000o`D00?l03_ooool20?l00080oh00
00<0o`000?n0003oP000403oP0040?l000L0oh000P00o`020?n000<0o`001`3oP004003o0080oh00
0P00o`000`3o0000oh000?n000060?n00003003o003oP000oh0000@0oh002@00o`030?n00080o`00
0P3oP0050?l001T0oh00103o000;0?n00003003o003oP000oh000080oh006?ooool001Kooooo5P3o
00000`3oP000o`000?l000070?l000@0oh00803o00020?n000<0o`000P3oP0040?l00080oh00:@3o
00030?n000d0o`003_ooool40000o`D00?l02`000?l3003o00L0003o2000o`0B0000o`<00?l01P3o
P00:003o00@0o`005`00o`070000o`H00?l01`000?l>003o0080003o3_oooolI0000o`800?l02`00
0?l7003o0180003o0P00o`000`000?l00?l0003o00040000o`03003o00000?l0003o0080003o2`00
o`0<0000o`800?l06`000?l9003o00kooooo1`3o00060?n000030?l0003oP000oh0000H0oh001`3o
00050?n000@00?l000<0oh000?l0003o00003`3oP0030?l00080oh001@00o`180?n001Sooooo000F
oooooaH0o`0000<0oh000?l0003o00001`3o00040?n00200o`000P3oP0030?l00080oh00103o0002
0?n002T0o`000`3oP00=0?l000kooooo10000?l5003o00/0003o0`00o`070000o`P00?l04P000?l3
003o00H0oh002P00o`040?l001L00?l01`000?l6003o00L0003o3P00o`020000o`kooooo6@000?l2
003o00/0003o1`00o`0B0000o`800?l000<0003o003o0000o`0010000?l00`00o`00003o0000o`02
0000o`/00?l030000?l2003o01/0003o2@00o`0>ooooo`L0o`001P3oP0000`3o0000oh000?n00006
0?n000L0o`001@3oP004003o00030?n0003o0000o`0000l0oh000`3o00020?n000D00?l0B03oP00H
ooooo`005_ooool50?n001H0o`000`3oP0020?l000H0oh00<P3o00020?n00200o`000`3oP0080?l0
00030?n0003o0000o`000080o`003_oooolN0000o`P00?l040000?lb003o00D0003o1P00o`070000
o`<00?l00P000?l;003o00kooooo9P000?l9003o01<0003o6000o`090000o`D00?l050000?l:003o
0080003o0P00o`0>ooooo`d0oh0000<0o`000?n0003oP0002`3oP0020?l00100oh000P3o00090?n0
00<0o`002@00o`020?l001T0oh000P3o00030?n000800?l04P3oP0070?l000H00?l000<0003o003o
0000o`000P00o`0Hooooo`005_ooool50?n001H0o`000`3oP0020?l000H0oh00<P3o00020?n00200
o`000`3oP0080?l000030?n0003o0000o`000080o`003_oooolN0000o`P00?l040000?lb003o00D0
003o1P00o`070000o`<00?l00P000?l;003o00kooooo9P000?l9003o01<0003o6000o`090000o`D0
0?l050000?l:003o0080003o0P00o`0>ooooo`d0oh0000<0o`000?n0003oP0002`3oP0020?l00100
oh000P3o00090?n000<0o`002@00o`020?l001T0oh000P3o00030?n000800?l04P3oP0070?l000H0
0?l000<0003o003o0000o`000P00o`0Hooooo`005_ooool90?n00080o`000P3oP00G0?l000<0oh00
103o00040?n000<0o`000P3oP00P0?l000@0oh002@3o00020?n001X0o`001P3oP0070?l000kooooo
7P000?l8003o0100003o9000o`000`000?l00?l0003o0004003o0080oh001@00o`050000o`H00?l0
1`000?l7003o0080oh001`00o`0>ooooo`@00?l080000?l>003o01@0003o4P00o`030000o`800?l0
10000?l5003o00L0003o1P00o`050000o`h00?l010000?l>oooooad0oh000`3o00040?n000L00?l0
1@3oP0080?l000L0oh000P00o`030?n000800?l04P3oP002003o00`0oh00103o00020?n000<0o`00
6`3oP00Hooooo`005_ooool20?l00080oh001@3o00040?n000030?l0003oP000oh0001H0o`0000<0
oh000?l0003o00001P3o00000`3oP000o`000?l000060?n004h0o`00103oP00>ooooob00003o1000
o`0B0000oaT00?l00P000?l7003o00<0003o2@00o`0;0000o`@00?l01`000?l3003o0080003o2`00
o`0>ooooo`80003o0P00o`0R0000o`L00?l00P000?l3003o0080003o1000o`0>0000obh00?l01000
0?l>003o0080003o0P00o`0>ooooo`80oh000P00o`0C0?n000800?l01@3oP0040?l000T00?l08P3o
P002003o00L0o`001@00o`060?n00080o`002@3oP0050?l001@0oh0000<00?l00?n0003oP0000P3o
P00Hooooo`005_ooool20?l00080oh001@3o00040?n000030?l0003oP000oh0001H0o`0000<0oh00
0?l0003o00001P3o00000`3oP000o`000?l000060?n004h0o`00103oP00>ooooob00003o1000o`0B
0000oaT00?l00P000?l7003o00<0003o2@00o`0;0000o`@00?l01`000?l3003o0080003o2`00o`0>
ooooo`80003o0P00o`0R0000o`L00?l00P000?l3003o0080003o1000o`0>0000obh00?l010000?l>
003o0080003o0P00o`0>ooooo`80oh000P00o`0C0?n000800?l01@3oP0040?l000T00?l08P3oP002
003o00L0o`001@00o`060?n00080o`002@3oP0050?l001@0oh0000<00?l00?n0003oP0000P3oP00H
ooooo`005_ooool;0?l00080oh001`3o00020?n000P0o`000P3oP00B0?l00080oh000P3o00020?n0
00T0o`0000<0oh000?l0003o0000103oP0120?l000kooooo=P000?lB003o00030000o`00o`000?l0
01P00?l030000?l4003o00<0003o3`00o`000`3oP0000?l0003o0002003o00kooooo1@00o`0Q0000
o`T00?l05`000?l9003o0080oh008`00o`020000o`L00?l00P3oP007003o0080003o0P00o`0>oooo
o`L0oh00103o000I0?n000<00?l00P3o000O0?n00003003o003oP000oh0000@00?l03P3oP0090?l0
01d0oh000P3o00000`3oP000o`000?l000020?l001Sooooo000Fooooo`/0o`000P3oP0070?l00080
oh00203o00020?n00180o`000P3oP0020?l00080oh002@3o00000`3oP000o`000?l000040?n00480
o`003_oooolf0000oa800?l000<0003o003o0000o`006000o`0<0000o`@00?l00`000?l?003o0003
0?n00000o`000?l000800?l03_ooool5003o0240003o2@00o`0G0000o`T00?l00P3oP00S003o0080
003o1`00o`020?n000L00?l00P000?l2003o00kooooo1`3oP0040?l001T0oh000`00o`020?l001l0
oh0000<00?l00?n0003oP0001000o`0>0?n000T0o`007@3oP0020?l000030?n0003o0000o`000080
o`006?ooool001Kooooo503o00020?n000<0o`00103oP0000`3o0000oh000?n0000Q0?l000P0oh00
1P3o00020?n002<0o`00103oP00B0?l000kooooo0P000?l3003o01d0003o0P00o`0E0000obX00?l0
30000?l2003o00L0003o4000o`020000o`kooooo1000o`0R0000o`T00?l04`000?lF003o0080003o
4000o`090000oaL00?l03_ooool90?n000D0o`008P3oP006003o00<0oh00103o0005003o00H0oh00
1@00o`090?n000L00?l00P3o00040?n000030?l0003oP000oh000080oh000P00o`0B0?n00003003o
003o0000o`000080o`002@3oP00Hooooo`005_oooolD0?l00080oh000`3o00040?n000030?l0003o
P000oh000240o`00203oP0060?l00080oh008`3o00040?n00180o`003_ooool20000o`<00?l07@00
0?l2003o01D0003o:P00o`0<0000o`800?l01`000?l@003o0080003o3_ooool4003o0280003o2@00
o`0C0000oaH00?l00P000?l@003o00T0003o5`00o`0>ooooo`T0oh001@3o000R0?n000H00?l00`3o
P0040?l000D00?l01P3oP005003o00T0oh001`00o`020?l000@0oh0000<0o`000?n0003oP0000P3o
P002003o0180oh0000<00?l00?l0003o00000P3o00090?n001Sooooo000Fooooo`D0oh00603o0009
0?n00280o`001@3oP0040?l000030?n0003o0000o`000080o`00103oP00G0?l00080oh001`3o0002
0?n000h0o`003_ooool20000o`D00?l0<P000?l=003o00<0003o2@00o`060000o`T00?l07P000?l7
003o00@0003o3_ooool4003o01L0003o0`00o`080000o`D00?l00P3oP003003o0140003o3P00o`07
0?n000T00?l00P000?lC003o00@0003o4P00o`0>ooooo`@00?l01`3oP0070?l000h0oh001000o`03
0?n000H0o`002@3oP0020?l000X0oh00103o00070?n000T00?l00P3oP002003o01<0oh000P00o`02
0?n000800?l00`3oP002003o0180oh006?ooool001Kooooo2@3oP00K0?l00080oh0000<0o`000?n0
003oP000103oP0030?l00080oh00803o00020?n002P0o`0000<0oh000?l0003o0000103o00020?n0
00<0o`000P3oP00>ooooo`80003o1@00o`0I0000o`@00?l05@000?lD003o0080oh000`00o`090000
o`@00?l06@000?l>003o00@0003o3_ooool7003o0080003o1`00o`040000o`X00?l020000?l9003o
01D0003o4000o`020?l000800?l00`000?l=003o00L0003o3@00o`000`3oP0000?l0003o000;003o
00kooooo403oP0060?l000030?n00000o`000?l000h0oh002@3o000=0?n000@00?l01`3oP0000`00
o`00oh000?n000060?n000<00?l08P3oP002003o00L0oh000P00o`090?n001Sooooo000Fooooo`T0
oh006`3o00020?n000030?l0003oP000oh0000@0oh000`3o00020?n00200o`000P3oP00X0?l00003
0?n0003o0000o`0000@0o`000P3oP0030?l00080oh003_ooool20000o`D00?l06@000?l4003o01D0
003o5000o`020?n000<00?l02@000?l4003o01T0003o3P00o`040000o`kooooo1`00o`020000o`L0
0?l010000?l:003o00P0003o2@00o`0E0000oa000?l00P3o0002003o00<0003o3@00o`070000o`d0
0?l000<0oh00003o0000o`002`00o`0>oooooa00oh001P3o00000`3oP0000?l0003o000>0?n000T0
o`003@3oP004003o00L0oh0000<00?l00?n0003oP0001P3oP003003o0280oh000P00o`070?n00080
0?l02@3oP00Hooooo`005_ooool20?l00080oh001@3o00020?n00080o`001@3oP0040?l000030?n0
003o0000o`0001@0o`000P3oP0030?l000@0oh000P3o00050?n001d0o`0000<0oh000?l0003o0000
9P3o0002003o00<0oh000P3o000>ooooo`80003o0`00o`0d0000oaT00?l020000?l3003o0200003o
2000o`050000o`kooooo1@00o`040000o`L00?l00P000?l5003o0080003o0P00o`0<0000o`/00?l0
4P000?lB003o00L0003o2`00o`070000oa/00?l03_ooool20?n000L0o`003P3oP004003o00L0oh00
1@3o000J0?n00003003o003oP000oh0000T0oh000P3o00070?n000D00?l00P3o00060?n000L0o`00
0`00o`0=0?n000D00?l02`3oP00Hooooo`005_ooool20?l00080oh001@3o00020?n00080o`001@3o
P0040?l000030?n0003o0000o`0001@0o`000P3oP0030?l000@0oh000P3o00050?n001d0o`0000<0
oh000?l0003o00009P3o0002003o00<0oh000P3o000>ooooo`80003o0`00o`0d0000oaT00?l02000
0?l3003o0200003o2000o`050000o`kooooo1@00o`040000o`L00?l00P000?l5003o0080003o0P00
o`0<0000o`/00?l04P000?lB003o00L0003o2`00o`070000oa/00?l03_ooool20?n000L0o`003P3o
P004003o00L0oh001@3o000J0?n00003003o003oP000oh0000T0oh000P3o00070?n000D00?l00P3o
00060?n000L0o`000`00o`0=0?n000D00?l02`3oP00Hooooo`005_ooool>0?l000H0oh000P3o0005
0?n001T0o`00103oP00[0?l000030?n0003o0000o`0000T0oh005P3o00030?n00080o`003_ooool4
0000o`03003o00000?l0003o01T0003o0P00o`0B0000o`@00?l000<0003o003o0000o`007@00o`0R
0000o`800?l000<0003o003o0000o`001P00o`050000o`kooooo1@00o`080000o`<00?l02@000?l2
003o00`0003o2`00o`020000o`800?l04P000?l>003o00T0003o1@00o`090000o`T00?l00P000?l7
003o00L0003o0P00o`020000o`kooooo0P00o`0E0?n000800?l00P3oP002003o01/0oh001@3o0004
0?n000P00?l02@3o00020?n000H00?l000<0oh000?l0003o0000103o00030?n000H0o`000P3oP007
0?l000T0oh000`00o`020?l000T0oh006?ooool001Kooooo3P3o00060?n00080o`001@3oP00I0?l0
00@0oh00:`3o00000`3oP000o`000?l000090?n001H0o`000`3oP0020?l000kooooo10000?l00`00
o`00003o0000o`0I0000o`800?l04P000?l4003o00030000o`00o`000?l001d00?l08P000?l2003o
00030000o`00o`000?l000H00?l01@000?l>ooooo`D00?l020000?l3003o00T0003o0P00o`0<0000
o`/00?l00P000?l2003o0180003o3P00o`090000o`D00?l02@000?l9003o0080003o1`00o`070000
o`800?l00P000?l>ooooo`800?l05@3oP002003o0080oh000P00o`0K0?n000D0o`00103oP008003o
00T0o`000P3oP006003o00030?n0003o0000o`0000@0o`000`3oP0060?l00080oh001`3o00090?n0
00<00?l00P3o00090?n001Sooooo000Fooooo`80oh004P3o00090?n000030?l0003oP000oh0000H0
o`0000<0oh000?l0003o00004P3o00020?n00080o`000`3oP0090?l00080oh005P3o00030?n00080
o`001`3oP00K0?l000kooooo10000?l00`00o`00003o0000o`0G0000o`H00?l030000?l8003o00<0
003o9000o`020000o`800?l05@000?l=003o00D0003o3_ooool5003o00/0003o1`00o`0B0000o`L0
0?l010000?l2003o01D0003o0P00o`020000o`<00?l03`000?l2003o00T0003o4@00o`0=0000o`ko
oooo3@3oP003003o01d0oh000P3o00030?n000L0o`00103oP0040?l002L0oh000P3o00020?n000<0
o`002`3oP003003o00H0oh001`3o000Hooooo`005_ooool20?n00180o`002@3oP0000`3o0000oh00
0?n000060?l000030?n0003o0000o`000180o`000P3oP0020?l000<0oh002@3o00020?n001H0o`00
0`3oP0020?l000L0oh006`3o000>ooooo`@0003o00<00?l00000o`000?l05`000?l6003o00`0003o
2000o`030000ob@00?l00P000?l2003o01D0003o3@00o`050000o`kooooo1@00o`0;0000o`L00?l0
4P000?l7003o00@0003o0P00o`0E0000o`800?l00P000?l3003o00l0003o0P00o`090000oa400?l0
3@000?l>ooooo`d0oh000`00o`0M0?n00080o`000`3oP0070?l000@0oh00103o000W0?n00080o`00
0P3oP0030?l000/0oh000`00o`060?n000L0o`006?ooool001Kooooo1`3oP00D0?l00080oh0000<0
o`000?n0003oP0002`3oP00M0?l000030?n0003o0000o`0000L0oh00603o00020?n000030?l0003o
P000oh0001/0o`003_ooool40000o`03003o00000?l0003o01L0003o2000o`0:0000oc@00?l04P00
0?l@003o00@0003o3_ooool4003o02D0003o1`00o`0o0000o`D00?l04@000?l00`00o`00003o0000
o`020000o`kooooo0P3oP005003o00H0oh002@00o`000`3o00000?l0003o00040?l000L00?l01@3o
P00;0?l00180oh001@00o`0F0?n00080o`004@3oP0060?l000D00?l0103o00070?n001Sooooo000F
ooooo`L0oh001P3o00030?n001T0o`000P3oP0040?l000<0oh001P3o00000`3oP000o`000?l0000@
0?l000T0oh000P3o00040?n00300o`003_ooool20000o`D00?l010000?l3003o0100003o1P00o`0G
0000ob/00?l040000?lB003o0080003o3_ooool[0000o`D00?l0=0000?l4003o0280003o3_ooool5
003o00P0oh001@00o`020000o`800?l000<0oh00003o0000o`00103o00000`00o`00oh000?n0000F
0?n000<00?l05P3oP002003o00030?l00000o`000?l000/0o`00103oP0090?l000030?n0003o0000
o`0000800?l02@3oP007003o0080o`001`3oP00Hooooo`005_ooool70?n000H0o`000`3oP00I0?l0
0080oh00103o00030?n000H0o`0000<0oh000?l0003o0000403o00090?n00080o`00103oP00`0?l0
00kooooo0P000?l5003o00@0003o0`00o`0@0000o`H00?l05`000?l[003o0100003o4P00o`020000
o`kooooo:`000?l5003o03@0003o1000o`0R0000o`kooooo1@00o`080?n000D00?l00P000?l2003o
00030?n00000o`000?l000@0o`0000<00?l00?n0003oP0005P3oP003003o01H0oh000P00o`000`3o
00000?l0003o000;0?l000@0oh002@3o00000`3oP000o`000?l00002003o00T0oh001`00o`020?l0
00L0oh006?ooool001Kooooo3P3o00020?n000H0o`0000<0oh000?l0003o00005P3o00070?n000<0
o`00103oP0020?l000<0oh00403o00020?n00080o`001`3oP0020?l00080oh007P3o00060?n000D0
o`003_ooool40000o`03003o00000?l0003o01L0003o1P00o`0G0000o`@00?l00P3oP003003o00@0
003o7P00o`0B0000oa000?l00P000?l>ooooob/0003o0P00o`0T0000o`D00?l03P000?l6003o01T0
003o0P00o`050000o`kooooo1@00o`020?n000@0o`00:`3oP009003o01D0oh000P3o00070?n000@0
o`00803oP0020?l000L0oh006?ooool001Kooooo3P3o00020?n000H0o`0000<0oh000?l0003o0000
5P3o00070?n000<0o`00103oP0020?l000<0oh00403o00020?n00080o`001`3oP0020?l00080oh00
7P3o00060?n000D0o`003_ooool40000o`03003o00000?l0003o01L0003o1P00o`0G0000o`@00?l0
0P3oP003003o00@0003o7P00o`0B0000oa000?l00P000?l>ooooob/0003o0P00o`0T0000o`D00?l0
3P000?l6003o01T0003o0P00o`050000o`kooooo1@00o`020?n000@0o`00:`3oP009003o01D0oh00
0P3o00070?n000@0o`00803oP0020?l000L0oh006?ooool001Kooooo0P3oP00@0?l00080oh000`3o
00020?n00080o`001@3oP00H0?l000L0oh000`3o00020?n001H0o`000`3oP00R0?l000/0oh003_oo
ool;0000o`<00?l03`000?l5003o01L0003o1000o`040?n000<00?l010000?l7003o0080003o4000
o`020?n000<00?l040000?l=003o00L0003o3_oooolY0000o`H00?l08`000?l4003o00h0003o1P00
o`0I0000o`800?l01@000?l>ooooo`80oh000P00o`0:0?n000@0o`003P3oP00?0?l000030?n00000
o`000?l000800?l00P3oP007003o00L0oh001000o`0>0?n000/0o`005@3oP0020?l00100oh000P3o
000Hooooo`005_ooool20?n00100o`000P3oP0030?l00080oh000P3o00050?n001P0o`001`3oP003
0?l00080oh005P3o00030?n00280o`002`3oP00>ooooo`/0003o0`00o`0?0000o`D00?l05`000?l4
003o00@0oh000`00o`040000o`L00?l00P000?l@003o0080oh000`00o`0@0000o`d00?l01`000?l>
ooooobT0003o1P00o`0S0000o`@00?l03P000?l6003o01T0003o0P00o`050000o`kooooo0P3oP002
003o00X0oh00103o000>0?n000l0o`0000<0oh00003o0000o`000P00o`020?n000L00?l01`3oP004
003o00h0oh002`3o000E0?n00080o`00403oP0020?l001Sooooo000Fooooo`@0oh004`3o00020?n0
0080o`001@3oP00M0?l00080oh008P3o00020?n00280o`001@3oP00>ooooo`80003o3P00o`0=0000
o`L00?l05@000?l6003o0080oh001@00o`020000o`L00?l01`000?l@003o0180003o2@00o`040000
o`<00?l00P000?l>ooooobT0003o1P00o`0S0000o`H00?l030000?l6003o00`0003o0P00o`0;0000
o`800?l01@000?l>oooooaT0oh001@3o000B0?n000H00?l00P3oP003003o00d0oh000`00o`020?l0
00d0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n0000D0?n000T0o`001`3oP00Hoooo
o`005_ooool40?n001<0o`000P3oP0020?l000D0oh007@3o00020?n00280o`000P3oP00R0?l000D0
oh003_ooool20000o`h00?l03@000?l7003o01D0003o1P00o`020?n000D00?l00P000?l7003o00L0
003o4000o`0B0000o`T00?l010000?l3003o0080003o3_oooolY0000o`H00?l08`000?l6003o00`0
003o1P00o`0<0000o`800?l02`000?l2003o00D0003o3_oooolI0?n000D0o`004P3oP006003o0080
oh000`00o`0=0?n000<00?l00P3o000=0?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003o
P000503oP0090?l000L0oh006?ooool001Kooooo1@3oP00K0?l000L0oh001P3o00020?n001L0o`00
0`3oP0020?l000@0oh001@3o00020?n001d0o`0000<0oh000?l0003o0000503o000>ooooo`80003o
3P00o`060000o`<00?l00P000?l9003o01D0003o5P00o`030000o`800?l01`000?l4003o01/0003o
4000o`0>ooooobT0003o1P00o`0U0000o`800?l03P000?l6003o00X0003o1000o`0;0000o`800?l0
1@000?l>ooooo`80o`00<P3oP005003o00T0oh000P00o`0;0?n000D0o`003@3oP0050?l000H0oh00
1@3o000I0?n001Sooooo000Fooooo`@0o`000`3oP0040?l000<0oh000P3o00020?n00100o`002@3o
P0020?l000<0oh005P3o00030?n00080o`001P3oP0000`3o0000oh000?n0000T0?l000800?l00`3o
P00=0?l000kooooo4000o`060000o`<00?l01@000?l6003o0100003o1000o`000`000?l00?l0003o
000D003o0080003o1`00o`020000o`D00?l05`000?lD003o00kooooo1000o`0U0000o`H00?l09`00
0?l7003o00@0003o1@00o`020?n000@00?l01@000?l;003o00<0003o1`00o`040000o`kooooo2@3o
P0040?l001<0oh001000o`0P0?n00080o`001@3oP002003o00@0oh0000<0o`00003o0000o`00103o
P0020?l000`0oh000P3o00050?n000L0o`00503oP002003o01Sooooo000Fooooo`@0o`000`3oP004
0?l000<0oh000P3o00020?n00100o`002@3oP0020?l000<0oh005P3o00030?n00080o`001P3oP000
0`3o0000oh000?n0000T0?l000800?l00`3oP00=0?l000kooooo4000o`060000o`<00?l01@000?l6
003o0100003o1000o`000`000?l00?l0003o000D003o0080003o1`00o`020000o`D00?l05`000?lD
003o00kooooo1000o`0U0000o`H00?l09`000?l7003o00@0003o1@00o`020?n000@00?l01@000?l;
003o00<0003o1`00o`040000o`kooooo2@3oP0040?l001<0oh001000o`0P0?n00080o`001@3oP002
003o00@0oh0000<0o`00003o0000o`00103oP0020?l000`0oh000P3o00050?n000L0o`00503oP002
003o01Sooooo000Fooooo`/0o`002`3oP00I0?l000030?n0003o0000o`0000@0o`000P3oP00C0?l0
0080oh000P3o00030?n002@0o`002@3oP00;0?l000kooooo0P00o`020?l000X00?l020000?l00`00
o`00003o0000o`040000o`L00?l05@000?lD003o0080o`004P00o`0G0000oa800?l03_ooool20000
o`<00?l03`000?l3003o0180003o1P00o`0P0000o`<00?l00P000?l?003o00030000o`00o`000?l0
00L00?l010000?lD003o00D0003o3_ooool50?n001T0o`001000o`020000o`D00?l00P3o000D0?n0
0080o`001`3oP0030?l000800?l01`3oP002003o00/0o`000P3oP0030?l00080oh000P3o000:0?n0
00H0o`00403oP00Hooooo`005_ooool;0?l000/0oh006@3o00000`3oP000o`000?l000040?l00080
oh004`3o00020?n00080o`000`3oP00T0?l000T0oh002`3o000>ooooo`800?l00P3o000:003o00P0
003o00<00?l00000o`000?l010000?l7003o01D0003o5000o`020?l001800?l05`000?lB003o00ko
oooo0P000?l3003o00l0003o0`00o`0B0000o`H00?l080000?l3003o0080003o3`00o`000`000?l0
0?l0003o0007003o00@0003o5000o`050000o`kooooo1@3oP00I0?l000@00?l00P000?l5003o0080
o`00503oP0020?l000L0oh000`3o0002003o00L0oh000P00o`0;0?l00080oh000`3o00020?n00080
o`002P3oP0060?l00100oh006?ooool001Kooooo3P3o00060?n00080o`0000<0oh000?l0003o0000
7`3o00030?n001d0o`000P00o`090?l000030?n0003o0000o`000180o`001`3oP002003o0080oh00
1`3o000>ooooo`T00?l00P000?l3003o02d0003o3P00o`060?l001800?l05`000?l7003o00@0oh00
1`00o`0>ooooo`D00?l03`000?l3003o0180003o1P00o`0>0000o`@00?l020000?l8003o00<0003o
0P00o`020000o`L00?l01@000?l8003o00030000o`00o`000?l000800?l00P000?lE003o0080003o
3_ooool>0?n00080o`00503oP005003o0080o`002@3oP005003o0240oh002@3o00050?n000@0o`00
4`3oP004003o0080003o1@3oP00Hooooo`005_ooool>0?l000H0oh000P3o00000`3oP000o`000?l0
000O0?l000<0oh007@3o0002003o00T0o`0000<0oh000?l0003o00004P3o00070?n000800?l00P3o
P0070?l000kooooo2@00o`020000o`<00?l0;@000?l>003o00H0o`004P00o`0G0000o`L00?l0103o
P007003o00kooooo1@00o`0?0000o`<00?l04P000?l6003o00h0003o1000o`080000o`P00?l00`00
0?l2003o0080003o1`00o`050000o`P00?l000<0003o003o0000o`000P00o`020000oaD00?l00P00
0?l>ooooo`h0oh000P3o000D0?n000D00?l00P3o00090?n000D00?l08@3oP0090?l000D0oh00103o
000C0?n000@00?l00P000?l50?n001Sooooo000Fooooo`D0oh000P3o00020?n000h0o`000P3oP004
0?l000030?n0003o0000o`000080o`000P3oP00E0?l000@0oh000P3o00030?n001H0o`000P3oP00:
0?l00080oh000P3o00020?n001<0o`000P3oP002003o00D0o`000P3oP0020?l000kooooo4000o`0Y
0000oa000?l0103o000G003o01H0003o1@00o`040?l000L00?l03_ooool5003o0140003o00<00?l0
0000o`000?l040000?l7003o00H0003o0P00o`000`000?l00?l0003o00020000o`800?l02@000?lK
003o00030000o`00o`000?l002800?l00P000?l>ooooocP0oh0000<00?l00?l0003o00000P3o000@
0?n00080o`00=`3oP0040?l001Sooooo000Fooooo`T0oh005@3o00020?n000@0o`000`3oP00K0?l0
00@0oh000P3o00030?n000l0o`0000<0oh000?l0003o00000P3o00040?n000030?l0003oP000oh00
0080oh000P3o00020?n001D0o`000P3oP0030?l000@0oh003_ooool9003o0080003o0P00o`0^0000
o`h00?l00P3oP00K003o01@0003o1@00o`040?l000L00?l03_ooool7003o00l0003o00<00?l00000
o`000?l050000?l2003o00L0003o1@00o`0>0000o`@00?l010000?l00`00o`00003o0000o`04003o
00h0003o1P00o`000`000?l00?l0003o000K003o00kooooo103oP003003o01T0oh000P00o`0W0?n0
00H0o`001@3oP002003o0180oh000P3o00030?n00080o`000P00o`0<0?n00080o`002`3oP00Hoooo
o`005_ooool90?n001D0o`000P3oP0040?l000<0oh006`3o00040?n00080o`000`3oP00?0?l00003
0?n0003o0000o`000080o`00103oP0000`3o0000oh000?n000020?n00080o`000P3oP00E0?l00080
oh000`3o00040?n000kooooo2@00o`020000o`800?l0;P000?l>003o0080oh006`00o`0D0000o`D0
0?l0103o0007003o00kooooo1`00o`0?0000o`03003o00000?l0003o01@0003o0P00o`070000o`D0
0?l03P000?l4003o00@0003o00<00?l00000o`000?l01000o`0>0000o`H00?l000<0003o003o0000
o`006`00o`0>ooooo`@0oh000`00o`0I0?n000800?l09`3oP0060?l000D0oh000P00o`0B0?n00080
o`000`3oP0020?l000800?l0303oP0020?l000/0oh006?ooool001Kooooo0P3oP0020?l000<0oh00
2@3o00020?n00180o`001@3oP00I0?l000H0oh006@3o00070?n00080o`001@3oP00K0?l000kooooo
2@00o`020000o`<00?l0;`000?lD003o00<0003o4P00o`070000o`@00?l01`000?l7003o0080oh00
2@00o`0>ooooo`D00?l0<@000?l2003o0140003o1000o`070000o`@00?l030000?l8003o00030000
o`00o`000?l001/00?l03_ooool40?n000D00?l0103oP0000`3o0000oh000?n0000;0?n00080o`00
6`3oP0000`00o`00oh000?n0000B0?n000@0o`005@3oP0040?l00200oh006?ooool001Kooooo0P3o
P0020?l000<0oh002@3o00020?n00180o`001@3oP00I0?l000H0oh006@3o00070?n00080o`001@3o
P00K0?l000kooooo2@00o`020000o`<00?l0;`000?lD003o00<0003o4P00o`070000o`@00?l01`00
0?l7003o0080oh002@00o`0>ooooo`D00?l0<@000?l2003o0140003o1000o`070000o`@00?l03000
0?l8003o00030000o`00o`000?l001/00?l03_ooool40?n000D00?l0103oP0000`3o0000oh000?n0
000;0?n00080o`006`3oP0000`00o`00oh000?n0000B0?n000@0o`005@3oP0040?l00200oh006?oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
496493A9C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E
3D35443F5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158
304A4E79586597494660556B62516A689177476985848751514D71706D714D607A657474
8377524F767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A628142
9A747FBB47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D
601F676463723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F
62538766817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C
7174A25A9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B
6A9779C0766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
4E57CBD1CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F
4B3B68385F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E
494362607491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64
684F304C5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47
646F9AB5625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B
7221827F425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F855162
6F7298488F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C
694E5F55D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA
5C8B7F967FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
505D846D739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E54
3B4A955B5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E57
4B4A476F809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676
655E385463505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B509238
8E7678B93872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C3966
6E55C9C2625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A44641503481
91607E566B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F
715B61658D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9D
ADAC6D6D74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
4F58A7B6BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B
363F44424954413B43483D2A454B5648524588735D274A5B54574D548069567651665256
543D4D5D797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E
646341334756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D
915F76933CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E67
825460505458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C
867DBF756A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F
6674927BAFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A72
5E984E939EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
4C66D3CBDCB959708C5489638461549B5F898193B184635B234E374C38662427235D6772
334890624F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B55
3F4662536C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C
4E3D3C4D50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B
744A7FB83F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E726137534478
7A5A817D64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873
764C5E52A56946B38C697069955F8D885048546F6A52555C475475807971896A856C6968
71776A70A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E5690
90C195B488B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
4A60A28C9CA45F64876E746A7882606D608390988475676744583F514050364E40615A66
4046806B5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B4948
4C4243455E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B61274861534544
5851322B424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F
7B48608D4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A3823
4240B4A555823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578
888A8C95A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B
7058656BB476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C966687
71B969608AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
5D55BA96967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D51
3A405F5F5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C
504B4C4F5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E81
7660344C685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649
876FA8B453C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D38
4B25635B5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F
8C5D8379A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F5148
53545E57886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A196
8581537E5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
7555B7C5D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D
5E4C475B575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C
583D4C5064546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C
6E5A4051545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C
6E5687CA488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D
53377876433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D4470815243
5B739E4F55523189745C7A63806EB36773334585643C50594662636A57546D4C575A5370
62798672CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A
3B71757C79A73A496144938551AB765B784338515670666B7E426B78A36593BB
785C8372A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242
273C5D6C879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B4542
5649433F767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C4362
58533637463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B
74728BCC38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D651550
5D216B7E34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E
917E8B558F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A6465
5C5765696D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256
609B5B73819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
4F65D9E0DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A69
46646E7A616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D40
4A50414839376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A
72733F493E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E6732
84685D7F46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C
5F4597B84F537187607A786166383D233B4756639073584B42664278596B6E4E494A4645
5C647B4C40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553
555F65849F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267
577B816C79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
4D67DFF39F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50
534A50609098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E6148605847
64404C536172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C484174
665538636635454659384C3C54445B687A534F4875734D6348755A26673138304C4C6040
61618AB4495F4B354745484D393A3B403B4752853F543C5D3766A8507A59717136517578
83654E5A535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D53705060727762
657794526E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E
71897683A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886
577D7C8B81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
415F59B1E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A687150
3B4F855F54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D46
5D493D484F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B
5D694A3B4C556D4A5343473F42555878825E655556866C7F4E475A525C45675353438021
8D6D76B341C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E
5266B4AD63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671
634D7E66744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E
60707965AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C
5973509295BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
3E6B92609DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B
3E426A5164686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F
6E4E545C6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B
6B6A404C5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2E
A28A86AC648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D
6A5F968144535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D89
7F69BF5675602C65435852518458825E7763404A4E72A979495559735E5B7A5855595450
5B636D63AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B
5A697A765E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
3E59C1BF62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C
5C4A87877968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A
5642535A535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982
655A5E7B765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A
5D6C9CD445897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D5743
5863C9925A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E
4D435A4E79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A56515433
547272569464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E
6E866A77719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
49625764775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A
41428172868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B47
603358705C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A
74575C3B514C554D6744574548515855624B50614968556633534D51598184514E63894A
6E6463A2599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E
6D2F7E722A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B
7342954A8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F
56464042B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F
5277678A989C33394654958470A3533D5C3F496364868D855E55919195909EA0
3E57456CF497383A5B4C594849475060453E908F7D6C55583E34293A3445334334243051
48397C4E535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344
674E60697D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B81
94834F485B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C
6F7AA3BF4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D
634589846D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D4149573680
6F64BF54591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F
418C82498B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F5669
3D9D87AF66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
485C6476F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B
4F3A6A5A6B754725494E313D657639385E3926364447353B2B3F48445252455E4C445552
4839575D4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B425077
5E574A5E5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D54
7C7AB1B64F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C3358
60758A6F3352578764A77166832647706E44615D9A684856406D276947628B57839863B5
B0556D48973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E
62605A68A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B
48A79AA78CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
4C4D5C538DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E44536549
3F47737D7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E7957564333
52554233475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C
4551382031444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B
5F507E935F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253
525FCD94436868874561745E74304640545D785C8774634C43532386785F54564C525C64
645C955964766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F35
4A6F6E3879605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771
788E6583BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
49529360C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B
3E2D6560545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B
4D4B3F47826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A4864
4B6542493B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E13
705195805490253D645997C84645424835257182836548865F6F6258AA59694542534A74
69447A50506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C574873
5F4FAE6677434754607283607D849F89A3264F575C78899444504668786275654E465862
40777546957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B
3D6F5E774977579780477E747259295E924C4B7B8594717D6750939077728B84
5D4FA190996C58777B4533646D575775664C8C90896E4C552E493A424363353E43695163
43334E5A5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F435558
5140584B52355F5052617071606A544469524B6B9E8C635B5945535D374336573C393977
4746496A5A39544959394B44473C43666B46364B84786D5B3C8438394056606D67424918
8D76CA785B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A564648
4C437E6E57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A
6D528753795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E69
4E8E6459A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E
4C93A5A784AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
6B4CA56A468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B64
4643565A6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D5843
4E444B3D4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B4849
445244283D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B
493D9C9363612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C57
4D4ACC90393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A6
75448F508C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C
615B4E62905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C
526F708C78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
5C4077644E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C
41495F4F4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C53705844
5D485A5A6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B
736062484A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C26
6F638983767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E
51386D523B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B47
5548B44C53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A
507C552C7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76
829B7D7F84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
4746814E3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475
504C55636157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A40
5C5F4C4A7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B4373
4C3E4552484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D55426529
8C4574A8A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A
592887684165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D
574789586E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264
438B62468B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B588963
3B6B7A704BA091B49659768A868C54615D395169997946535865809297809A95
4942805E546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A
49535B778579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F
5351544D4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B53
4C484237493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C425629
7C5767927B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B
715A8E6E4B41567A538750535B3946615D69A0798A63687942512B4D565868593D494198
502889538B79545958833645607DB75B744D638A4543605B596A4567895C6F694C666167
54756755A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F65
4F74937E64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
46457D525F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59
484E5F746D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A
59674D468389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E70
71575A374D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D496015
7544536B77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95
803AB19533553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F
543486456B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A0
64885E6089564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660
719B808A90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
4545AC715979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A
496960735D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E
6F5A8056575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F
4F3B3F55573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D
934381744FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B
5F3F8371556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590
523C7D53808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69
528D383599374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B
4971877C94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
4E6065493D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F686065
4C6872877C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B4331
5354594749647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D4841463649
4F4F433242435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021
773D9E7A4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C
6B49876F31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C55
2A296A518B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A
71B64046A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084
658DA59385CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
515E835E4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A
4959595B4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F
685179586263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D79
6E535B4854506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F28
7630986E30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84
735ECA9749575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D2767
243585446555375459954B655470AA648F224153444B6A546C675872A68295954D565F68
627A5171BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D
81988789C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
53799A6D577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A61
4C736B726E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C
5F526E667D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A81
4B454F4E554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E
9646C1781AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE
90477E7842604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4
393C774971645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B
7CAB5260774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D78
4C687C8089B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
516672665178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D79
426962877D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245
584C6251556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A
504F513855405C394E473D423244346D653C504F6357676648894F57664B4762624A4835
9040BC7F21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E
5F509D6E58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D503878
314376548D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C8381
6A72364F8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B96888788
5390B0C1C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
4761826964875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B63
3E5D4D6955576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A43
6C546D556076B5524A9F617B606D89555E846A94B7E2C15970634F6F6278366060605270
6C5668506D60664E605460503555427663465B506656698F68755648525B504A5A525233
8A3AC297248480659B68B28E605A45544F4640682950265841A11F4254596B434A573095
7453C182335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D
514074435956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F
616F347EBE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E66
6CA19DD0C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
4364705F6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B75
447868936F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E
5D4573687D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388
474E5B576A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E
9035BE9533869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159
573FBA853C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A
473D72567F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F506169
7B68518EB94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F
5D97A6A39ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
4067756B76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C6153
4B636165737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D
6243625A63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F64425536544976
44615042574751494549495F345537685541554F8B425E48476E4051755256526559626D
9B5BCAA0347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F2263
6C429B7B3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F72
4D34704C5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A72
70694D85B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362
537A8992A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
3E68684F3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E6066
3D6B5478624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D43735249
6043676A7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B72
6C6261546054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658
644ED17F3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA4
8A5AB99F6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476
674E75617A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D60
6163626F9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B70
70868DA7A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
4755735F595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D
485D566C62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744
676A5C58866A524C51523D65695E744151614974608E805C5441655A465F4956526B4769
4030415C48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E6657
61239C723774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81
716BBF96878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B99
7E486445656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A73
88907C6FB24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470
529FACB093CB908E918E964374AC918F694A56638465715D46576D844C7068B0
4C45756A6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A
5879598E745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A
56446D697A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474
383B4F6D573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B
6421A15029BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C67
5061DC9C4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E3469
79436B3F725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E6369
5E674D72AD4761655F843B4F4D52674E608273926394675345555C46549A696983655874
5F627582B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
4F5A7661555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D69
48668A786A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D894743
56455D567073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B
425749475E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F4844
5D54AD682A57927B995373627B8B5660444C5F7138443656388F474F5A7A573547452187
56356D3F365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F
7C608E5D8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F
6675548FB73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82
858974A2C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
7357796954835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E604957
4260415D4E5167393928363C4C5B545455383951544B4A50384E4C414C695A5647676775
58416E7D9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A573562
2546505558526F484F62394A4D553D75465E73456E4571483F783E475F75775054596051
63457B4F3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E
4C4ACA7E436C483C27867342954E304B48316757655D30563974638858667D3D4F523E71
66537A5577595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F40556467
8295476C86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C
506EB79599B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
5C47927C6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875
557F588C6355914A432528525B615D427B3342558449498724406944563925543E733128
443B433355576130325970843D377A4C614F255065C574414E45494C4B493146444A3366
2B50496E5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E
3626A46C3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E
665ED28636666B8139937946523937534F4A75467F603C52257148884D5B6836625E4675
7750724A786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F58
5C583A66874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C
535C54588CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
44487B5356884C57994965685265466156625F455D6E53443055463A3D634A3A61638160
3E5D66676F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F47
5B44735A685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E3664
2E775645514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248
502CA9751C686670A76DBE9A85985563475873913E3636582B754B53656C74515D584781
9379F9B54A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E75
5776A6627F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A
6B7D6E94944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C406686659577
54787C9B88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
43497C5F7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A
4D794A7758516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D
4D4D5C529078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F4572
45444B4C504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E
62438C71344756648F518C6C556E3D456973535941523253188E4E5883967948476151B7
7D85D6A351694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B65
4C5867406063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D5258
707349616D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175
537C8D8381BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
4465826A70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D
405A4F7B806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A58
4F446960635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D
355D48494B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483
845E9982425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F
8275D38A5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F
2C43663C73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E55
59934E6A6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E9788
52587AABA6B058807D8CB17DAB7E4570576465605E488654434670656478698C
41719E7156786B697944434B51534055494A504F72816D49356F413B39841D456477836A
42765E6D4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F914042
59506A55645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A
3D5C5C475163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82
A256A47F2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E
647BDD8B3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A76
3B638D48616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F6966
4590519F7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455
677B8FA9ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
3A6A58485469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F
39573C504F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D604159
5948525F9184B944478385A07B62863869724D8471927E545359866D5462426E76652C99
4D644D4A50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8F
D274BB8D3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395
695DB0633F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F56
3060773E595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49
637F52574D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF81
8771A47795B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
41708B605B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C7661
41684D786950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A
57485B564F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D87
4C42565C575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AA
A34A6D7B4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F51614495
6684CC7E4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E
56637F415C664F866A63356D51673E6A67385A52225E371B4C4A6E515859525150466449
5274495F69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A558
6B74A97D9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
49728F808678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F
3D5049506065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E
4A4B515A5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F
41475E3F555673744F665D62467A5571515474596E5C586B8C795149747490A96E545894
9653C589345D6B628C4B70664D5E4949534D708454655062348166818B6C7F6185705590
9FB1B9755F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F6977
4B64874764513C84617A586A677D486D56518B714963511D58556752726E656F694A6750
626C509D7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F
7D898B6AAEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
4E667252514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F
4748523D494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E3158
5859505D746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D56495264695686
4A524944556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F5572855984
964384734487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D0
8F99DB88466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E
2B52755A8D583E704A81336D748456765035525137683C3B766669666B5A6762453F6658
61833F6057227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A
7C669C9AAEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
3E63877E8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A
384843595E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B
4B4B5866595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F564066
41504B3950565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8
BD6C9870536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C3866
66709765908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E
506B7A52835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E7269
66834B756247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C
59436A6094AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
3D877D473B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F61
3B5F5A5B3D375348533630324365463B534748634C3F374B3846525D60492B4C4D492956
6F603B4C546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B
3B5D3C41496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B6062
9B4DA089597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579
618BDD673E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B
474A5C62897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E
546577E08C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B67
95567558A399237063B5A267914164823C4C3A495B505546435298735A77937E
4055555B52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D7459
42487557525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B3466
32455455674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55
383E3B38484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818A
A26A98754B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F
819C916852647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E
37546C5C6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC591
68713E624F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B9876
5796D16C977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
3E77916F5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C53
415050565861874A4F3035384452445250443C2C573F4D593E484650616360664955486E
4A3F59675355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E
31494C7B44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528B
BF569C52366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1
A1CECCAA6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B
8C827B607F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C80
9CA737777E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E48
6247574BA786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
409284594E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A59
4750625A515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D663573
4A504976585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E
37472934354E3E3E433F364642515B58324D44526146594837423E415885667B63554A70
8464B35831607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F454884
79CDEF9C8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465
353E686A8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7
684C5FAB8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A743446149
8F427B39B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
44727C594C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C6255
3C684864524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B96
5453587C695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70
475D474D685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E3954
7E58DE863B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D3559
44727F4A464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979
317F7C6C865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C5281
69622E614D32794E573A53463857688150526A4648365F5B45513D58733623522D568E46
4C3F90558D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
42939567586F54535C4052775242518893885D48535D554D37554B454263623261816D58
515A597570648E4E51223C5943515444814462677B525F75354D523F624E3358485F4867
3F3F4667504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C
3E44344C3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564
884D9D733A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976
519CB154797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254
344D495468423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D
6E6E48783E2C59487F64735B54705453655C583D623E806D2E4F39629145327434406757
8D5A6E4AD47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
4A978257496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D7453
3A53626850575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A
3F534A7C574977486571918F40522433665D968FA69269564C514F6D39563565364C4774
4C5C3C3D4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F
924FB980436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F
59ABCB38433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A43408983
386058829E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E4340
71B94CA65A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F
4B60946D835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
4B5660524B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C403750
4747315B505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8
525E5E826E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B62
5061344C525F93734B51474E3F4E4D9559525672805391775A4D3C488877796858634864
9A82AD816E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C8
5498B35E505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048
216B5F514E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A
455D67534645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F
4C5E8F64B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
4D68886C616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344
404B474D505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B
394245654F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E
304945554946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988
C5B8B77F4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B
64B5CE5D776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F5955
29695C5F6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B
7A7E2D632F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A
915A9557B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
4D666341456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D44514846
3158465B4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C
505D4A866A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B4654
4F6349344A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43
A17DA45A5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A6195
81E1D33D53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E
4C6D6B545F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F
6051328D30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D
4A608594D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
48628B524A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D5350
3F50476358536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753
304D3F5B4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C55
43473B434B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616D
B7A5CA8363A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB
5197AF5257666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49
285E60728C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B585131
7A5258932C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540
515D8E649D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
4144524D5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B3344
4E4A324B555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B68
4B6347685F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C535770
5860373D576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79
CB7D9D4F4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F506682
75D0C6578E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60
385C3D4F534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A
8B5F46864037503554546C513845618C4A6888525B6469544446495B66295C8A43556835
52358D3DBF436A79566E769CC067B2884679426D879864475E687A739962879D
55695A3D33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D45
29444A4D362F4E4A4E273446505E4351535566676559517941525F535A28334C5F634751
4C543E5D65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A4750
4E4C2F48455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A
666697676583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B9727783
91EDD8546055676153A93370714078584879656A8245595B59368B833B7A586971669C5E
4F8951555A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28
614550A72F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A6734
4F49A160C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
5866683E3F493946533555432F2F5652435659595965563739693A3753894B3952567857
375254665B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F48
3C3F334A44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D5950
3B4535363E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F663857
9B6DBA6D5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB
798B8A67574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B
2B5A5B5A7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643
753D5EAD54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B75
7E5D726DDB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
5E4C6D414C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F
3D5F456C534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F64
3E4B6575473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E58
384459613A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85
B7708A57436B658A844F895B6268936B667668323D4659575A7C4E874D674D6585354351
46E8A43D7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63
468C4747494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51
AC58769123585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42
496D9068B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
575669534848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C
3D5C5357564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F58
47463F665750574A7B616B744B5834455940494E3E232B523B454D533F413B552E403947
4541253B3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653
767BDA94717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC387666
5BA3992C52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580
345D445A6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449
653D5D6A3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E47
6C4E6875B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
53667D413B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C
3A5C6360473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F
4543655D4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A48546366
4A5F464A53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F
9D57D370617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A73
4AC7A44B85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A59435751
5A5C494C533678714234465F6B7146532350531E60733A344E5A5F4C436B614A36464044
6A3B81B1484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B4241
5A8C897BAC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
5C4D6E434058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C52
4462476A7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E518064
3B3F444F43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C
333B625B3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A
9B53D28874A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F87
67D7B780986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B75
70A5525050403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D62
8935615925756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D
6B5770BEA638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
595E805A6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F
4C5C47634F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D75
45764D7A68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B
466144424B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90
C4A4E78E6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F
70EAC13F4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B
335325555C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C
492C6A62304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B625145
60608E76913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
567C784A485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A156
46675E6C5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F726170746160
3F704C697765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F7068
3B5E47514E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D53
7E5FA4837A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B365
3E7B56358F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C36
4B8B2C475B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D
5728A0A451595134463E74334865914A575355474C516D67607953575943728243634A3F
4E7497978F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
64696844494E404A5139533A48445A564F7B484E4733424332493942435045485350544D
4F484753616C5845503841434157444548455570734B62725A724D435E4E5B4753776975
448855746253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D
594F45464D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678
A689C09391AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E5450
5DC6A53E5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B42
3F4B4D97A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B49
6A205C5617563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55
655172A0942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
58676C564F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C
457058874F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A5155
4E5F316FB76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E4862
4D47384C3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80
A57BAD6180AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B
52D2A145785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C5258
47582C535D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139
531B72641F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F
545874B4A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
51646E444964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D49
4957675E555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263
408C3D7279753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F3149
624529384B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87
A96591507A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D
88E89B2D75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D
4C7148727C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A40
6628B2891E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B
654F79A27347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
5B717C4644603D524C345446413D614E538A5070654E6038324B4435443847487E557657
4672586B5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B7165
4856425064574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F6755
46503944485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D
6F499B6BA09F4879486B9633584F7B6357696245633E6239856A60794957416B65728747
3B8465317251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C546413
44651E7C82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B5133
4A2D6A653E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A
538996A17823505F97946C5D7F49743E4558535949785E5C507985686B70858C
5E7A8F58506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259
556E5C6779754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762
426D364E818026385E71706C4480355670486549415346444A36602A482437353340323E
552D2C3F40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9
816EA1767875458B717990557F71523D385A6A3E47328E43925450743E641C83914B4556
7FCFA6617744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C6112
7A992D586736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D56
5D24778023522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F44
3E78709A96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
59735A4945534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853
406A856B4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E625260
4F6B3E3B4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F
464040514B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773
705F85498D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F
87F4A352535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E
6C842C95792F52415054828371739B61506E572A4946304429466C552F54574346545354
7038777E3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F3858
5D52738C632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
5F787D4743655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C
44574E665267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156
355E6561689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48
343B5F55404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F
8890BD5DAFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B
77A7984C5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D
5A664C52614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B
4C29AD9A4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940
606893BA6A426D759870638075525D5C705D486A428149656FACB575958D5775
5C51695D5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D
6578575F5C6C5652462849615F60416049454F49563F47543B473045483449354E584E61
4060334B5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E
35423E46374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB
6F8EC3575868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D72
86E07C657A549A48835F4C875161541946824B624A5173425A64E08F5954504E47396627
5B814F635B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365
632A715E2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F67
6873A0E0B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
5558604445525A584543494A443753534C604B694C49572E36564F4555404648585E7450
495A6261546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D
405D435553872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B
45274148344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E844088
5B79B969928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA553
5AA774485544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D42
66782B5E5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C
4D1E8F6B27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D49
5F725F72775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
5F4452495858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A
475A4F6C606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148
414C3F405772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D
421F323F354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A90
5186C07AC3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C8750
7BD37A456B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A5642
5B725176814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A
473599804C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63
546265BE735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
5D5C7B4A666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F
5E78567E8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D
41683B2D677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C
4D38434F4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9
588BA25087677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F8458
80D774404C46884B6E504C7B3B5047204D644B80436374446253D6745966496851428855
98A05A505971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D52
4B297450287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A59
4B6C7CEB6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
5A6269444E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D
50795A66526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F
514E34299B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34
471B2E394F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F49644094
5F979178B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B61
94F67A33745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A976
4E53496357354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A605658
5A2E7E502D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B42542650
5863559764586B497978737E676775335E4B594C61573F4A586C535C606F7060
5550594B506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E
527A837C5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B
44512D30595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D
5127364D404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA
499D7871C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA588
83947062745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C
4F59479B7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347
413DC89040652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C
456F62BD7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
5451654C554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D54
4359455B53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D
41595E3F83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A
532F634245435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C
57B67053884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E68729660
98E5745C77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E668072
5A683C4A5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B
5A2C6A5B387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C4368
3C5F51CA6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
4C64704D6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C58
4C65576A5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E
404B31247E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F
4F2834313E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC6
39E670538B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C8447
88B36B475E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F
6883504E453146315A307B415E677A4C363E49434B4B3B5133614B495246632944474345
5148A66F4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C
4B894E945E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
4B5B674C5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C6348
416551534B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C
485E49217E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B38
444051534B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7
799E6269708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C
7AAD5F435A3C514891465045256B522E856E49483E6851625F44B659995F494B62748948
39503B938342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C
4F316E5D2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49
365B45A949858061A37A7599475B62407E49575858516069447B7C857B88996F
51618577795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C57
6A7D516889804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D
434E49377B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E5438
4C2D3A37414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C4
4ECA5E5175529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B525948
99D56883955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D37
69695153556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C
44478C6255653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F79
36624FB54954443C5F4F595E54906C355960A759644A2F424285655B69735F83
505C4F2E4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F4627
3B474C42375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D
4956593BA76748527B5F72404D65718A4451533252434E373A603F394E39502E504D5242
56324236444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB0
6DD35E514D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740
AADC5E494C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B7745
73793D525143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C
43257D45314B216A454652194D46654F556263774E5E5928424837404240834144272756
567666D162715945A3636677325D50396C3D52455A61464A3A815D707B607B85
56686F4682534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A6948
45546260596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A5049
3D50604467513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F5054
564948555B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC1
8FD05782954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A32
85B3504D59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E
4450486A6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C
47398B6638551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C4856
2E58538D578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
5C65614C80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D
4B514C636969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357
466E716D8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C42474037
3C32442C3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A4
8FC6375C5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045
B1CF5F606951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B30
545061937844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250
492E7936415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A
385F48944A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
5168734E786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A
5A5C67556460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56
554F795EA2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C49
4D3E4A395858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C
8CC8397A88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2F
A1C3525F60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323
574A2A5B5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B
4943914A3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E383544
43825CAF4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
576A5E486057536036685265463C6D819579438655595B1B412A39294846224367526345
4A4B4F554A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E
4C536D699C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E
4B46475D6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAAC
BCD662C1AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732F
C1D96E4E646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F
5F574A8C623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F513952
37396E333F40244E3547552E37396C394764495238676548485E45573A445C36423F3246
2E4C7A955F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
6B6F6D3D8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F
60705A604A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E49445547
61456E76A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F3141
364245274C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389
CCC1569A807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A
7C8B5E6C665763688938755342734D5589535B8A4F5F376C5773A64594736E8F30645854
90775356565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B
442F682A6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E
3153538C3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
677C735D7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447
515D6370766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A47
6A5758628C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F37633544
3D485528604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62
C9A94A995B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38
C1CA4B4040545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C
533E315A3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246
343B6B33482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C4343
52625480409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
685A43394C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F42
505960474C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C5932
3F66565879424248768F6A354D3361604047393143403F37415F373F394B353B3557353A
2F4D4D4449535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6A
B0804AD66572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B
9E973D603C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B
503D3A8844474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B
3B3F6D345B44353F15624A203636633C5D773D3E475D613B503C375A3356413C69253541
47475F7C236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
477B684B89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D
6672645F55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D
555D55779F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031
274C461D3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71
D0825BB762957E4157264D68404925403446434A2D7938977552534852487689465E5A32
AFB838493D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C
6A4E4651345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D
3231691B64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E
5138549E4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
44806C566B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D
4F5B6B556165595438485141543A453B3E312251455F253250183E44374F405245664F36
5E71676C8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53
463D49345C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344
D8804E8E3E866662782862801734375051734254287462BE76624552435C726B316D7880
BDB1765E585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A41884541
484133535C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D51
3955823A6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D
6A66618F53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
5F7057436B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45
614C5F5053614D613F494B445C4941424E3D375D38442F525827564947533333465E533B
63705D75A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D56
2548493863535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3A
A56871A6378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628
AF9A545A31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D
4D3F52674A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C
36556B307B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F48
53456788527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
717A6E578259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A7849
6F566E5F56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D
645F5195A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C
29454229414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81
CE8BA5CF74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983E
B7C7506952904C68A6655C52746F5C6C7F6189858E73526341A472567C4B835445544737
4A4559703D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E
345065258E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B47
4D318687345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
7F7F58486B5A677A41777074504F786D835552644A5E4E243C3A38364D4C456053515956
68525354615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C38
58554B596B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E
2E4A4540545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6F
C87B7F87458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D35
8F713E542A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D
9B2E4655356B48653F37443160546D4958502D699F28332955565B41434A5C28315E3648
3267712A5828323314584432242E3537214D43492850424344288C87377722394D31514B
57374C4A328137828A5B6556506C5C54525D725256474C596F634D5164545578
888657486B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C7245
5950624E585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C
5D506693974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B34
2A4442565A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40
B756928A5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2E
D7B82E502DA18265656184415353305B7E456F68574E4B615094894B66423F43447E3939
5E35546E2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955
294A642D623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A
4D256F46218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
79705952824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F
6B465B73766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B4745
5364439B9C455B5447506549783A355A454954422D4B434B38502147104823414D4A2854
1D3C353E4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64
AD82C1AB54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F
8089556051652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B36
6123394B265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E
2870641B7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843
540C655231A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
877D5D4E654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B7542
6F5A674A5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53
544E376268293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D57
3E4D5B6C6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA89
9C536765468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702D
C6982B431AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E
5727436849374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D53
3941471F5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D54
6032723C37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
8B7E55496B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C
57585E4E5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E
4F704F90742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A
2449313C3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058
A14790885D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E47
9E8B304337843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E37
42213E463839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F
2964533D5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D46284469
9156753D68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
8172564A7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B
7A6283506774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C57
4D4349A1753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D393848
2A2F2B4946552844344F3457558B5357515F65615B44446848415D696D80695342875460
87378E5060864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49
AC913E492D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141
572B3F4D2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F
39545D3F5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D40
4C36AA667B70397E6D7FBB434D5C439B49675868A35055537863656684665575
8F938E8B844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C48
7768736D986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F30
4B4F578A4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E
2D40346244582E5B364C3D6356645D9765484D8C6030685E444F59793674507345675571
9643A951506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50
C3A63C57368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39
842D4259334437641A442F3E472D4634333D24496A343E2E59435432485A473736463441
28665269983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551
601E6E2D6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
8F86523A4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63
765E4D3061604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E
554E55976A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C413641
3B4942353F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E7566
6C63C65F5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63
C98038583E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227
543D5B682E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A
2F624A2F4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E
5C4793357044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
6F7C594C6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F6546
4C5A715F765D5B665760555C6037513C56454855394F433F433657455F6F427552536651
5C5C559D74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A514556
475045574F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F
9763735F57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678B
EAA543473E832363494B683958484A585041757565724E3D669A2A54455484465C632955
70232D2D28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D
385C3648682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E42
5750B24378673E6F3F5A8433533F245731604D556840495772535560655C4F80
86796A66694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B
4F4C4E42594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C55
6471659D4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F
2A392E573A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA8
91749345625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A5344
7E7D465C3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342
563C5D57303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58
398C4F4A4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E5287486356
5A5C7F415C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
879A5D486E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238
655E734A6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D53
494764953F4869959C7E53466A576B856571586036504248534251523958426472484855
324C3D5D506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF
7F7A916882925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368
BA65597451674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E
4B25564C2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D61
1F582D3D573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766
844D7C35675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
6BA3574C5A40505846644E603A636C4E645A847667844835614939465849374953746139
4A506044584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C47
5F646776537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338
566E483C4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D6
8198CD3B5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8A
B781484E405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D59
4B1648504A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C
24662A71653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236
554B7E56A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
695F6261565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B5044
5B696350655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49
404F819F4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F414657
3A46384D4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B8
5C7AA166877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D5555555370
5F44595F6B7661926161734F81594A52504369688069665D559A6F765970815167641E69
6A325F383342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B53
1E5833463533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A
7B66823E4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
6F783D32615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E
4068593E47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A
53506A6F33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E
3D5C4763486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D7
8F92A94572613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183
BC4C635A3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046
404D9D63364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B50
26681D54483947305B4B355E555B544B7759514453362D3E46646666506D364275516D71
7E5E7F41643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
58764F487055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F
6A537153755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B5364615345
68706C702352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135
405B34414166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F
7979B264878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8C
A93C4555455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D
3F375B373E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942
426F545742576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C
5F939B6498565374476B4658652838363B653845373E644964565A5C54686B56
63615C5460606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058
615E5C466E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E51
48457B7826323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E
46522C4D3659464445363D40526743504D564E536A659F4772744B78347050916C656EC3
7685AA5F8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96
AE4166534F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C99
3126743A5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63
465B61884834444D754E26564C564C4951456954A288515C49454936509D44736964794C
5CA099527128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
5F744C4A63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49
666D69516A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D
5466AC8C2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F6231
3F4C3B63335565583A38444765775262474C49616B47643E374459562B504A64599556BA
3E638B509D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4
B02954413848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A
455EA84A3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49
528B38514A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73
787B77578E2C657852A86D5491425430365439463638464B6E4B4C5947637669
597D51507D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A5542
6351604A7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A20466657555851
5859655F495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030
565C3B433C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4
225E5D29694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4
C22A7E79629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B
444E71364E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A46
3F4E3B703D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D
50BB964A782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
57806B6279617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E52
7C706C667F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A586150
51718A8D41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A5020
35462C532848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C
24777F45B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D88
8A4F7148474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3
646C8C4E634959543B5F477A516366445250256F504E565F51693C48477141424F2B4246
45624380433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B6959
6070826A9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
547452506662775B536864463A646D55714E746745584338495B536B5168676A60764F3C
4D535C475849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A63
5D77AB893444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B
4E554467475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C2
3461452F784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CE
B73EA345484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B69695296
7EA7C34445284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E
59752F542F43652D682720283049404679464543917163632C635C2665AD29505A88785E
52BF89738F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
508A5D527C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246
775B6A5B88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D
746F75893C44655467685663582B40746A63495844553F47623C372A5A3A454A66364020
52562F4B3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C3
45813C3E8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8
B5453F26683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA6564487
46505F43745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E
374C3563242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C
33B98165733463606B7D436F75427761626142683A4137597F43506B4E547251
4E667E655C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E516064
615756656F555D5A5B6068745049575342335750632A3A5039454A647030463A6E535857
5C58AE81445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E
42462B5538544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB
58A47B5794384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC9
94377E36533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA
427E723E432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E5247
4B5D40842B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B
525D5E6D74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
565A373D61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C
5B635C5260605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D
5D5E9570323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D
53563C7138545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE
645F3A56B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BA
AD3A82394F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A88
4865894B4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B
3D65387A3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55
536E635A7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
4D84474D66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B4850
5854605A6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264
796BA5945F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B
54543E5446514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB7
44604141933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB1
7A48A4387C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB
4F647746601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C
4E5D4286305A694D95293E1F505B47416647554C844869554B5A651F41972C4A34503554
2C7F5E4C4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
50884C4C6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A58
7C68644E5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D
5B61C270333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B4354324335
6263375F4147584065416061845E536E5165555C70808351354246595A665968769245B4
609E4555A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC
77466739493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486
557F82485446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D
416C3F8C394A502F5B323720473945375144684B844445492D4C5526396430392664457E
3DA5685758347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
627B4C475655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B
5161637A604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F5374
52738A683D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E
57703B5F434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD7
4B624355914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C8
7B3A7A3F5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E77
4E847242492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B40
5C6E37622A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C
3D4F5D65533763416162244C45427926373D4371314640585948657F55506A60
6A6C48494B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C
645C57515751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F62
659695774C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C
6C6844514F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5
456D4C4381235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC0
69479C346A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B
488F646475254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D9139
516140703749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F
446C645F674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
5C617C75624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E3952
77727D627551674E4A5A4F533F515D4337394E334E2E314151614A564B2F503354564562
5575975C283753536A55314D384350533849365837394233434039182B27411F362E4121
302F3A4031414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D7
55876B56935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B4
6C3C603B5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C
55C0844246397718533A51563F985C3942383369453B425C395B294643492A28523E4D30
4E6654A7414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E
5A827D536C526A2C578B47584B3D51374D545D663B484474554541664550865B
6D6B474B5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955
677A7164806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F
5190957F434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F
51534B53375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB
656A4D40663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E
524B6939631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B86
4E848251553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C30
66773259245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C
2470374B445F864E5B763366462D492044343F64284C3B9661486C79555B8166
6A7B4F4E6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C
6975645960344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D76654358
4A7DDF9B4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A
58534F424A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B
4068784972195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893
694C6934572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C5788
73A066545A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F7339
5C5A357225455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F
427948625238505171804254352C4D2A474168864F4C5170604F5568634F6865
6C7C59616947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284
707E8483895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68
676B66605A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C
494C4A4B52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C7
49825F54921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B0
5C405C46543548473E81405D512E645F5D714C50415E8E75896790764E543736815C5780
57B3706A633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F
5E6C4A804650535B6F3E471C5840524B444751315A2F415242566840373C427A47524151
45A1417160476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
826E5756545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D
525F506D63684F444245445D434C5466435055596338494C92B64B7C6E3D592956664665
6C8A8EA548497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940
564F465C52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E1
3945435BAC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A2
61515A45783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A
4065654E4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C39
5C663B6221524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E754347
2B554C6D4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
81664A52758A734E5D964B554E656D67768171646D5943535B46406E5669334FA3864751
78855D6470796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C57
7D749D754B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E
4C4C51404C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA1
5149796E9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F91
3D5D6A394F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F
4A996354564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C
5E4D41651C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C
335746B6653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
71945A615A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C515762
4F57616D533E5046374B53683B344C4940473E444E38472D46403E4331293A3439383754
7A658B8C909F665F6F75726D293553483F4038475137435F643C3930572A501B5A375138
5B393C3D564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC
545E7357A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A4
4049493058235332366A445A463285556F774A4449545D74B3418659394631407736648F
72AA608F555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D4537
64644D6E4A555861804840546B534940383E47324B394940234E43384254435639576D7B
4B533C525B5A7340B5723E5D5A394138485493905554597564595561767B9195
6D61525152585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E57
7090765C765C60443D4749554E55666641554B58693650276959385A343E652246503B5A
406096702C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420
292E4B3336535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB9
6B854B8BCD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F577393
5A5E603E56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB
9996645D635540419D4A59569896484F56537191585F424E4C584547624D45465A525A41
6A645C903E52493A584646334C2C42354657564554474B555D94540D3A7F43714C473257
70855974866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
72684E58777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953
526A5760544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851
566BA26E4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A40
6C3E40234B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A185
4955312F69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB6
65636C5265516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B0
9D69526A4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E726640
7771424E4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C63
45733A635B628B447C5842634748554E763F616831545E8E545A6F5864546891
6D704E425C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D
728C775E77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F86533059
6D596256758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28
322B441F4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E
5D645146AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A2806999486588
4079713D6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F
94927446634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B
52595C903F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A3758
536653866B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
706F70596166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C583349
54734E515965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D
5967B573323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E303833
4931491952484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA0
47542E41913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F49
4546424757406840435860845E507A5249674C656153686D93528858415F464E5993C3B3
76785947496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C
785F41603C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C
669E6A564257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
607743444E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D4163
718860586D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F
545E6259464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B50
5B3A41326154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D84
49553024711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC3
726780575F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A
3E7D5349355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A47
66665C693B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F
5B8C4C5C4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
64745747484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A
83757C836C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D
636A7F7352527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A4539
4444502B5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C
71815B477E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C
449E813D6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C
4551406664494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B
6856718A4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E
79955592505373576847456242675B3F4B19323A268C5594424782754E4F6E57
6483693F5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159
726F4C465C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F
667F9076454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A464342
4C455A415E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C
465738337B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD
374C4B3D623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B
6F993E333949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B5236434234
8E5F48553A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42
466A644D46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
7B5F6A485755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D
6C696B61574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557
605D8265443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A
4B32742B595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F
4875532B6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E81
30664B374535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A31
4A5E245246724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F5042
66625E64474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D
5D895A857A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
8C654F4D606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B
7B534E6555535141445445613D4E4E434F403D39452D4127484654661E21422F59402548
506C5F5B403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C
623F3E2C56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B
7A86503C6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B545870407291
2F68463E4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C
66792A492F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F6238
6F515E66325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637
497D6988575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
91897C4450568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E6969594573
7D6F606C6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E52
5665856C51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A483132
3F265A374C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F
3B5A372A7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C6094
6D6D5955796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F
65764D433D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F404433
8C4B4B56335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D
437E5963457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
887545434C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E
6C7655594E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A53
4C70B46A40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235
412E4F2D4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D
667C3B2689199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA
3B61576C75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B425755
8B881E3F27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D
7152645C3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858
427D4972496C604E6357586C415B524D58296760364863954B6058605268625D
95795665908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F
56684C59694E4B34474D46504847454E6867404451505926313C5A652638504362483946
504A6355677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B4555
633863455A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570
527E6040823E5F6F4C66425910493D574453528973A061634E4E5A317578485968474459
42644C3A4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA882
8E873F7336492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E
7546706B425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E
48757EB1708150464C315D754969654C5727615A3F4879A3493F48454E616B78
8D785B47465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68
675B5A72635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D
38576D6D374242497444445D334F592B55363F37463B393229342E2C433131333744312E
3B1F58373B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B396
3E6078477A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A3
4969535B625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E
7D713C3C45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E
6D6454533F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F
576C4A5748745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
8D5F4E4E69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040
685A49514D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E
4E6382714B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B403137
3B224B33435A383930533D536C616732493D53532E411B35503C503B4849515B80586D70
5566796BB04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A
46575165574E543C4B633F4841AA9339664D23222A492846536989433149559E49658645
8B631648324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B
6E647E7B4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F
414C72B154494C5756355F6A386035495A3244392F427CBE4B48625458576794
928948524D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C
726B4C55604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C49
5D5A5C56605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A
60385E435A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC77
3E71624C6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F
3B7553464A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB040
4E33417F32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA16852
7E67746837522B6B6A32433645423752254B3949433C3A3D6563414D693548324B405241
5B5C56555A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
9B7E49505A7F744A7E744E2F4581726FB3A99062545E40503C3E46516565805962514575
8F8062776D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F45
4F556C5C3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327
331D554F444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F
32656A5A7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A1
4952474E4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F
6055224143442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E525341
7F50696C4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C45
60565393567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
9C8862516F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D3954
8B534358568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D
606A6B6446586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E46
4E3067555F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B6
5363686A8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D
66716C574A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D8670
6554504F4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A
8647756951692C6366354D48414343A53F47265E4B2F3039535528415429404245436E53
5F3E7DBF75A165634F348E6C466945384C485947463D5D814948625550545B76
966A4551556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A
505C4F59503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57
505E926C415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445
482D5348505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E628669
26548567836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166
419B5C4A47448327444E2C82386C6E20402E324D3D5B5174354A6F354657474956769362
73473855234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D
704E88763952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D
55414858525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
93944A51576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B
876F6D8276555A333F5B53664754603C49573E3C452740252944635812295247754A2D45
4D4A36483D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F
5A20504B4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B
3D558162742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A7
4F6131373D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB863
89484A7A368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A
7846524E42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E5042
7E5756824D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
9A8D51578A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D
7F774B535B6B572F47453847545D5541455A525B5B34653532535A611E2B513333444847
4048755C545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E2728
3817533134442D382A4543523D435240463A5446687F4A5555585E34536645364442BA83
2469647FA7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B1
6B91593F4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F34
52331C41344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A
9B3E5F4C3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C
45434B4D3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
8569464C5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C3743
537651576B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B555854
53659E6B3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A
4F1F4D414446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348
214E372F52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B78
688074594564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A
4B443450365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A59
7C5A63564F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C47
7A4D4F5D6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
877F354F4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F48
6F664C607461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D
454B4E5149444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B4738
46215B3E444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C
406C6960724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C
3A914339335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B526040
50334254295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D6438817861
947278785B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A5271
8A653F4B50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
958242564C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259
626E5C7F58565336424231453743563345534D4B4A2C6736294A495C3428475451675F67
4D6D6D703B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B40453436
40395B4556503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D71
2856576BA03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D6890
4838324C46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E
5E5638393278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D
8A44534642613958483D37503846465B48444F7E6850443E474733784835532E8341483D
3C433F513C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
77864648556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F
684B5267585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E575548
4D4F6E5E383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A4132
4239634B594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C359776
2C61756B764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F6097
3B783D5B4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D49939354
4922285112542A544436464E752246422527522340314E415647524A4E5240634B68615C
884560424C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F617555
5F475B60367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
6F77536367666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D
534B5D6851564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C
5F646D6A3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F41
49305447524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E84
43AF9669742A7F6F27813C433A6C605A565467946AD56A913F63186B997C126871385572
5371413739718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E54
6B3D3538376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E5631967642
8B49724F465C215B3432323A385A50565457227F524951304C5E416644345F4B473F4548
83353C4C356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
68754B4145463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B744958
856256756492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C
435E6C62434F554C603C48542B254A7166423F353A453D403C4327283633352D2B463624
2F37543E4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A
436B705F7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95
356B414631525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA536
4E261A35185041514152523A76578997605A883C6239584675384854493B3263414F4A6B
9B4B4A3D314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C
7F4A516C4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
614C25548E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F40
5E454A567086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C443645
6457725C454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F23
2F3741414648433B464936635148594C522C5A572259394C4B3E4335373D367575398768
31807250523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F66
39692F5734435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B39
4F2C343F1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F
724390564D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C66
7743455E618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
6E602F383F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E61
816454717C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343
444E5D55394C45405829337826295D4E58523E403F3F4A6D46422450382A364B33483240
4B3C504947313E5725362661413C582B394845485091453D4942553D44473E72753C866E
3F8E7B5E6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E
4C5929443546522C574D329E3D79773454524C5C46446E923F7473316655475F4C889955
52391D2D155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D4840
69274C3F3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B
715D595656663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
68973B3A475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F62
80664E626E775136283B4844354D564146564C4B522C60271748474C2B2B313239503059
4E685C65384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E
3D334B3B563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E
47567792966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D
4269304749486021613F207960959E234E582D60425B5E715F64703B385545596599A657
503D385B39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B715337
6515652E3A50256E41363C5935464371464647764544412246474470323D843044454B54
6C617977496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59551 L
.2381 .59551 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59551 L
.2381 .59551 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02252 L
.95238 .02252 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02252 L
.95238 .02252 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01835 L
.2381 .01835 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01835 L
.2381 .01835 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .48892 L
.47619 .48892 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .48892 L
.47619 .48892 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11785 L
.71429 .11785 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11785 L
.71429 .11785 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF8000FF800000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FFFF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF800000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF00FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00FF0000FF00000000FF
FF80000000FF00FF000000FF00FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FFFF000000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
FF80000000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FFFF800000FF00
0000FFFF80000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FFFF8000FF0000FF00000000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000FF00000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000
FF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF00FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF0000FF0000FF0000FF000000FF0000FFFF0000FF000000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FFFF000000FF00FF00000000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF00FF000000FF0000FF00FF00FF00000000FF00FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FFFF0000FF00000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FFFF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF00000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .11076 L
.47619 .11076 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .11076 L
.47619 .11076 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .50248 L
.71429 .50248 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .50248 L
.71429 .50248 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF800000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01418 L
.2381 .01418 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01418 L
.2381 .01418 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01439 L
.47619 .01439 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01439 L
.47619 .01439 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01335 L
.71429 .01335 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .59989 L
.95238 .59989 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .59989 L
.95238 .59989 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF000000FF00FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooooaKoo`001?oooolG
o`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00
oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0
003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02
oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04
oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04
ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`00
9?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oo
oooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07Ooo
oolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo
001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co
001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000oooo
ooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00
Ool007l0D_l007lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?oo
ool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l0
07lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo
001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co
001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0goooooaOo003o7oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000T
ooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03
o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo
00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
ooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo
000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooooooo
o`0Sooooo`009?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02?ooooo000Tooooog7o
00009_oooomao`0002OoooooLOl0000Vooooog7o00009Oooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Goooo
ocP0o`0000<0oh000?l0003o0000C`3o000>ooooo`80oh007000o`040000o`80o`000`3oP002003o
0080003o4`00o`020000oa000?l00P000?l7003o00@0003o00<00?l00000o`000?l0103o000<003o
0080003o0P3oP007003o00X0003o1000o`0>ooooo`80003o0P00o`000`000?l00?l0003o0004003o
01T0003o00<00?l00000o`000?l06`000?l2003o00D0003o0P00o`0W0000o`D00?l04P000?l>oooo
ob80oh000P00o`1V0?n001Wooooo000GooooocP0o`0000<0oh000?l0003o0000C`3o000>ooooo`80
oh007000o`040000o`80o`000`3oP002003o0080003o4`00o`020000oa000?l00P000?l7003o00@0
003o00<00?l00000o`000?l0103o000<003o0080003o0P3oP007003o00X0003o1000o`0>ooooo`80
003o0P00o`000`000?l00?l0003o0004003o01T0003o00<00?l00000o`000?l06`000?l2003o00D0
003o0P00o`0W0000o`D00?l04P000?l>ooooob80oh000P00o`1V0?n001Wooooo000Goooooc@0o`00
1@3oP01=0?l000@0oh003_ooool20?n001h00?l00P000?l20?l000<0oh0010000?l`003o0080003o
0`00o`020?l00080003o3P00o`020000o`L00?l00`3o00020000o`80oh000P000?l00`00o`00003o
0000o`02003o00kooooo2@00o`0N0000o`800?l01`000?l2003o00<0003o1P00o`0i0000o`03003o
00000?l0003o0180003o3_oooom60?n00080o`00@P3oP00Iooooo`005ooooold0?l000D0oh00C@3o
00040?n000kooooo0P3oP00N003o0080003o0P3o00030?n000@0003o<000o`020000o`<00?l00P3o
00020000o`h00?l00P000?l7003o00<0o`000P000?l20?n00080003o00<00?l00000o`000?l00P00
o`0>ooooo`T00?l07P000?l2003o00L0003o0P00o`030000o`H00?l0>@000?l00`00o`00003o0000
o`0B0000o`koooooAP3oP0020?l00480oh006Oooool001Oooooo=P3o00020?n00140o`000P3oP004
0?l00080oh00=03o00030?n00080o`003_ooool2003o0080oh008@00o`020000o`800?l00P000?lA
003o0080003o4P00o`020000o`T00?l00`000?l20?l000800?l00P000?lE003o00D0003o0P00o`02
0?n000D0003o0P00o`0>ooooo`T00?l00P000?l00`00o`00003o0000o`1V0000o`<00?l04P000?l>
ooooodH0oh000P3o000^0?n00080o`004P3oP00Iooooo`005oooool@0?l00080oh00=`3o00040?n0
02H0o`000`3oP00@0?l00080oh000P3o000>ooooo`@0003o8000o`030000o`800?l00P000?l@003o
00D0003o4000o`020000o`L00?l00P000?l7003o0080003o4`00o`020000o`800?l00P000?l00`3o
P0000?l0003o00020000o`80oh000`000?l2003o00kooooo10000?l5003o0080003o00<00?l00000
o`000?l0:`000?l2003o00L0003o0P00o`0A0000o`800?l03@000?l00`00o`00003o0000o`0=0000
o`03003o00000?l0003o0180003o3_oooomK0?n00080o`00803oP0020?l000/0oh006Oooool001Oo
oooo403o00020?n003L0o`00103oP00V0?l000<0oh00403o00020?n00080o`003_ooool40000ob00
0?l00`000?l2003o0080003o4000o`050000oa000?l00P000?l7003o0080003o1`00o`020000oa<0
0?l00P000?l2003o0080003o00<0oh00003o0000o`000P000?l20?n000<0003o0P00o`0>ooooo`@0
003o1@00o`020000o`03003o00000?l0003o02/0003o0P00o`070000o`800?l04@000?l2003o00d0
003o00<00?l00000o`000?l03@000?l00`00o`00003o0000o`0B0000o`koooooF`3oP0020?l00200
oh000P3o000;0?n001Wooooo000Gooooog@0o`000P3oP00D0?l000kooooo0P000?lR003o00<0003o
0P00o`020000oa400?l020000?l3003o00@0003o1@00o`020000o`<00?l00P000?l;003o0080003o
2@00o`000`000?l00?l0003o0007003o00H0003o0`00o`040000o`03003o00000?l0003o00800?l0
3_ooool40000o`P00?l040000?l2003o0180003o1000o`050000o`800?l000<0003o003o0000o`00
40000?l40?n00280003o0`00o`0B0000o`koooooAP3oP0020000od80oh006Oooool001OoooooM03o
00020?n001@0o`003_ooool20000ob800?l00`000?l2003o0080003o4@00o`080000o`<00?l01000
0?l5003o0080003o0`00o`020000o`/00?l00P000?l9003o00030000o`00o`000?l000L00?l01P00
0?l3003o00@0003o00<00?l00000o`000?l00P00o`0>ooooo`@0003o2000o`0@0000o`800?l04P00
0?l4003o00D0003o0P00o`000`000?l00?l0003o000@0000o`@0oh008P000?l3003o0180003o3_oo
oom60?n00080003o@P3oP00Iooooo`005ooooon:0?l000kooooo5@00o`020000o`d00?l00`000?l2
003o0080003o4000o`070000o`<00?l03@000?l2003o00<0003o4000o`020000o`h00?l00P000?l2
003o00<0003o0P00o`070000o`800?l03_ooool40000o`P00?l0;@000?l2003o0180003o1@3oP002
003o01<0003o0P00o`0;0000o`D00?l040000?l>ooooohX0oh006Oooool001OoooooRP3o000>oooo
oaD00?l00P000?l=003o00<0003o0P00o`020000oa000?l01`000?l3003o00d0003o0P00o`030000
oa000?l00P000?l>003o0080003o0P00o`030000o`800?l01`000?l2003o00kooooo10000?l8003o
02d0003o0P00o`0B0000o`D0oh000P00o`0C0000o`800?l02`000?l5003o0100003o3_oooon:0?n0
01Wooooo000Goooooh<0o`000P3oP0050?l000kooooo5@00o`020000o`h00?l00P000?l2003o0080
003o4`00o`040000o`<00?l00P000?l2003o00T0003o0`00o`020000o`800?l00P000?lP003o00<0
003o1000o`050000o`800?l03_ooool40000o`X00?l08P000?l2003o00T0003o00<00?l00000o`00
0?l03`000?l30?n00080o`008`000?l4003o0100003o3_oooon:0?n001Wooooo000GooooocH0o`00
0P3oP01B0?l000kooooo7000o`040000o`@00?l01@000?lB003o00L0003o0`00o`020000o`800?l0
2@000?l3003o0080003o0P00o`020000ob800?l000<0003o003o0000o`001`000?l2003o00kooooo
10000?l8003o00T0003o0P00o`0K0000o`800?l05`000?l90?n001h0003o0`00o`0D0000o`kooooo
RP3oP00Iooooo`005ooooolf0?l00080oh00DP3o000>oooooa`00?l010000?l4003o00D0003o4P00
o`070000o`<00?l00P000?l2003o00T0003o0`00o`020000o`800?l00P000?lR003o00030000o`00
o`000?l000L0003o0P00o`0>ooooo`@0003o2000o`090000o`800?l06`000?l2003o01L0003o2@3o
P00N0000o`<00?l050000?l>ooooohX0oh006Oooool001OoooooP`3o00030?n000@0o`003_oooolU
003o0080003o0P00o`020000oa000?l01`000?l3003o00d0003o0P00o`050000ob000?l01@000?l2
003o00L0003o0P00o`0>ooooo`@0003o1@00o`090000o`800?l07P000?l2003o01T0003o0`3oP00T
0000o`<00?l02@000?l2003o00L0003o3_oooon:0?n001Wooooo000Goooooh<0o`000`3oP0040?l0
00kooooo9@00o`020000o`800?l00P000?l@003o00L0003o0`00o`0=0000o`800?l01@000?lP003o
00D0003o0P00o`070000o`800?l03_ooool40000o`D00?l02@000?l2003o01h0003o0P00o`0I0000
o`<0oh0090000?l3003o00T0003o0P00o`070000o`koooooRP3oP00Iooooo`005ooooomB0?l00080
oh00<@3o00000`3oP000o`000?l000020?l000kooooo9@00o`020000o`800?l00P000?lA003o00H0
003o1`00o`040000o`030?n0003o0000o`000080o`000P000?l00`00o`00003o0000o`020000obL0
0?l00P3o00030000o`@00?l03_ooool20000o`T00?l01@000?l;003o01D0003o1000o`0C0000o`80
0?l010000?l50?n00280003o00<00?l00000o`000?l02@000?l4003o00D0003o3_ooool=0?n00003
003o003oP000oh0007X0oh006Oooool001OoooooDP3o00020?n00340o`0000<0oh000?l0003o0000
0P3o000>ooooobD00?l00P000?l2003o0080003o4@00o`060000o`L00?l010000?l00`3oP000o`00
0?l000020?l00080003o00<00?l00000o`000?l00P000?lW003o0080o`000`000?l4003o00kooooo
0P000?l9003o00D0003o2`00o`0E0000o`@00?l04`000?l2003o00@0003o1@3oP00R0000o`03003o
00000?l0003o00T0003o1000o`050000o`kooooo3@3oP0000`00o`00oh000?n0001j0?n001Wooooo
000Goooooc@0o`000P3oP01D0?l000kooooo9000o`000`000?l00?l0003o0002003o0080003o7000
o`040000o`D0oh000P3o00070000ob800?l00P000?l70?l000<0003o0P00o`0>ooooo`80003o0P00
o`030000o`L00?l01P000?l5003o01L0003o1`00o`0@0000o`@00?l09`000?l5003o00@0003o0P00
o`030000o`800?l01`000?l>ooooohX0oh006Oooool001Oooooo=03o00020?n005@0o`003_oooolT
003o00030000o`00o`000?l000800?l00P000?lL003o00@0003o1@3oP0020?l000L0003o8P00o`02
0000o`L0o`000`000?l2003o00kooooo0P000?l2003o00<0003o1`00o`060000o`D00?l05`000?l7
003o0100003o1000o`0W0000o`D00?l010000?l2003o00<0003o0P00o`070000o`koooooRP3oP00I
ooooo`005ooooon:0?l000kooooo9000o`030000oaL00?l00P000?l=003o00D0o`000P000?l00`00
o`00o`000?l0000Y003o0080o`001`000?l>ooooo`@00?l01@000?l5003o0080003o0P00o`050000
o`800?l00P000?l00`00o`00003o0000o`0k0000o`800?l06P000?l2003o00@0003o0P00o`030000
o`800?l01`000?l>oooooaL0oh000P000?l2003o06l0oh006Oooool001Oooooo3P3o00020?n007X0
o`003_ooooln003o0080o`000P000?l7003o00@0003o0`3o0005003o00@0003o8000o`020000o`80
0?l000<0003o003o0000o`000P00o`070000o`kooooo0P000?l2003o00030000o`00o`000?l000T0
0?l01@000?l2003o00h0003o0P00o`0P0000o`800?l03P000?l2003o01L0003o0P00o`090000o`80
0?l00`000?l2003o00L0003o3_oooon:0?n001Wooooo000Gooooo`h0o`000P3oP01j0?l000kooooo
?P00o`020?l00080003o1`00o`040000o`<0o`001@00o`040000ob000?l00P000?l2003o00030000
o`00o`000?l000800?l01`000?l>ooooo`80003o0P00o`000`000?l00?l0003o0009003o00D0003o
0P00o`0>0000o`800?l080000?l2003o00h0003o0P00o`0G0000o`800?l02@000?l2003o00<0003o
0P00o`070000o`koooooRP3oP00Iooooo`005ooooom?0?l00080oh00>@3o000>oooooc`00?l00P00
0?l2003o0080003o1`00o`020000o`800?l01@000?lN003o0080003o2@00o`0>0000o`kooooo1000
0?l3003o00@0003o1`00o`020000o`03003o00000?l0003o00@0003o00<00?l00000o`000?l00P00
o`0G0000o`800?l00P000?l00`00o`00003o0000o`0I0000o`800?l05@000?l2003o0100003o0P00
o`070000o`koooooRP3oP00Iooooo`005ooooom?0?l00080oh00>@3o000>oooooc`00?l00P000?l2
003o0080003o1`00o`020000o`800?l01@000?lN003o0080003o2@00o`0>0000o`kooooo10000?l3
003o00@0003o1`00o`020000o`03003o00000?l0003o00@0003o00<00?l00000o`000?l00P00o`0G
0000o`800?l00P000?l00`00o`00003o0000o`0I0000o`800?l05@000?l2003o0100003o0P00o`07
0000o`koooooRP3oP00Iooooo`005ooooolR0?l00080oh00H@3o00000`3oP000o`000?l000020?l0
00kooooo?000o`020000o`800?l00P000?l>003o0080003o2@00o`020000ob000?l01`000?l5003o
00kooooo50000?l00`00o`00003o0000o`020000o`800?l00`000?l2003o01T0003o0`00o`1=0000
o`koooooA03oP0020?l004@0oh006Oooool001Oooooo8P3o00020?n00640o`0000<0oh000?l0003o
00000P3o000>oooooc`00?l00P000?l2003o0080003o3P00o`020000o`T00?l00P000?lP003o00L0
003o1@00o`0>oooooa@0003o00<00?l00000o`000?l00P000?l2003o00<0003o0P00o`0I0000o`<0
0?l0C@000?l>oooood@0oh000P3o00140?n001Wooooo000GooooohD0o`0000<0oh000?l0003o0000
0P3o000>oooooc`00?l01P000?l5003o00@0003o0P3o00000`00o`00o`000?l000020000o`D00?l0
0P000?lG003o0080003o2`00o`050000o`L00?l03_oooolN0000o`800?l05@000?l4003o0080003o
00<00?l00000o`000?l02@000?l2003o02/0003o0`00o`0B0000o`koooooA03oP0020?l004@0oh00
6Oooool001OoooooQ@3o00000`3oP000o`000?l000020?l000kooooo?000o`060000o`D00?l01000
0?l20?l00003003o003o0000o`000080003o1@00o`020000oaL00?l00P000?l;003o00D0003o1`00
o`0>oooooah0003o0P00o`0E0000o`@00?l00P000?l00`00o`00003o0000o`090000o`800?l0:`00
0?l3003o0180003o3_oooom40?n00080o`00A03oP00Iooooo`005oooool[0?l00080oh00G@3o000>
oooooc`00?l010000?l5003o0080003o0P00o`040000o`03003o003o0000o`000080003o1@00o`02
0000o`800?l00P000?l5003o0080003o00<00?l00000o`000?l00P000?l2003o00<0003o0P00o`02
0000oaL00?l03_ooool50000o`800?l06`000?l2003o00h0003o0P00o`030000o`800?l040000?l2
003o00h0003o0P00o`0^0000o`koooooA03oP0020000oc80oh000P3o000@0?n001Wooooo000Goooo
ohX0o`003_oooolR003o0080003o5@00o`0;0000o`D00?l02@000?l7003o00@0003o2000o`040000
o`@00?l000<0003o003o0000o`000P000?l>003o0080003o1`00o`0>ooooo`800?l080000?l2003o
0100003o00<00?l00000o`000?l00P00o`0@0000o`800?l03P000?l2003o00h0003o0P00o`0N0000
o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo8P00o`020000oaD00?l02`000?l5003o00T0
003o1`00o`040000o`P00?l010000?l4003o00030000o`00o`000?l00080003o3P00o`020000o`L0
0?l03_ooool2003o0200003o0P00o`0@0000o`03003o00000?l0003o00800?l040000?l2003o00h0
003o0P00o`0>0000o`800?l07P000?l>ooooohX0oh006Oooool001OoooooRP3o000>oooooc/00?l0
2@000?l5003o00T0003o2@00o`030000o`L00?l010000?l2003o00<0003o0P00o`020000o`h00?l0
0P000?l7003o00kooooo10000?l3003o00T0003o1000o`0S0000o`800?l05@000?l20?n000D0003o
0P00o`020000o`800?l08P000?l00`00o`00003o0000o`090000o`koooooRP3oP00Iooooo`005ooo
oon:0?l000kooooo>`00o`090000o`D00?l02@000?l9003o00<0003o1`00o`040000o`800?l00`00
0?l2003o0080003o3P00o`020000o`L00?l03_ooool40000o`<00?l02@000?l4003o02<0003o0P00
o`0E0000o`80oh001@000?l2003o0080003o0P00o`0R0000o`03003o00000?l0003o00T0003o3_oo
oon:0?n001Wooooo000GooooodP0o`0000<0oh000?l0003o0000?`3o000>oooooc/00?l01`000?l7
003o00T0003o2@00o`030000ob000?l010000?l7003o00kooooo0P000?l9003o00<0003o0P00o`02
0000o`<00?l05P000?l00`3oP000003o0000o`040000o`<00?l050000?l2003o03h0003o3_oooomo
0?n000800?l02@3oP00Iooooo`005ooooom80?l000030?n0003o0000o`0003l0o`003_oooolk003o
00L0003o1`00o`090000o`T00?l00`000?lP003o00@0003o1`00o`0>ooooo`80003o2@00o`030000
o`800?l00P000?l3003o01H0003o00<0oh000000o`000?l010000?l3003o01@0003o0P00o`0n0000
o`koooooO`3oP002003o00T0oh006Oooool001OoooooRP3o000>oooooah00?l01P000?l@003o0003
0000o`00o`000?l000800?l030000?l4003o00T0003o2@00o`030000ob000?l00P000?l9003o00ko
oooo0P000?l:003o00H0003o0P00o`050000o`800?l03P000?l30?n000H0003o1`00o`0n0000o`@0
0?l03P000?l>ooooo`@0003oN`3oP002003o00T0oh006Oooool001Oooooo1@3o00020?n000L0o`00
0P3oP01c0?l00080oh001@3o000>ooooob000?l00P000?lI003o00L0003o0P00o`000`000?l00?l0
003o0002003o00@0003o00<00?l00000o`000?l00P000?l5003o00H0003o;000o`0>ooooo`80003o
2P00o`020000o`800?l01`000?l4003o01L0003o2@00o`000`000?l00?l0003o000F0000o`030?l0
00000?l0003o01T0003o0P00o`050000o`H00?l030000?l>ooooogl0oh000P00o`090?n001Wooooo
000Gooooo`D0o`000P3oP0070?l00080oh00L`3o00020?n000D0o`003_oooolP003o0080003o6@00
o`070000o`800?l000<0003o003o0000o`000P00o`040000o`03003o00000?l0003o0080003o1@00
o`060000ob`00?l03_ooool20000o`X00?l00P000?l2003o00L0003o1000o`0G0000o`T00?l000<0
003o003o0000o`005P000?l00`3o0000003o0000o`0I0000o`800?l01@000?l6003o00`0003o3_oo
oomo0?n000800?l02@3oP00Iooooo`005oooool>0?l00080oh00:`3o00020?n004H0o`000P3oP005
0?l000kooooo8000o`020000oaT00?l02P000?l6003o00L0003o0`00o`080000oa`00?l010000?l0
0`00o`00003o0000o`09003o00kooooo0P000?l:003o0080003o0P00o`090000o`D00?l050000?l<
003o0380003o1000o`050000o`800?l03P000?l>ooooogd0oh000P000?l;0?n001Wooooo000Goooo
o`h0o`000P3oP00[0?l00080oh00AP3o00020?n000D0o`003_oooolP003o0080003o6@00o`0:0000
o`H00?l01`000?l3003o00P0003o7000o`040000o`03003o00000?l0003o00T00?l03_ooool20000
o`X00?l00P000?l2003o00T0003o1@00o`0D0000o``00?l0<P000?l4003o00D0003o0P00o`0>0000
o`koooooO@3oP0020000o`/0oh006Oooool001Oooooo103o00000`3oP000o`000?l000230?l000ko
oooo8000o`020000oaT00?l000<0003o003o0000o`000P00o`020000o`T00?l00P000?l3003o0080
003o0`00o`080000oa`00?l010000?l<003o00kooooo1@000?l2003o0080003o0`00o`020000o`80
0?l02@000?l2003o01L0003o3000o`040000o`800?l0A@000?l>ooooohX0oh006Oooool001Oooooo
103o00000`3oP000o`000?l000230?l000kooooo8000o`020000oaT00?l000<0003o003o0000o`00
0P00o`020000o`T00?l00P000?l3003o0080003o0`00o`080000oa`00?l010000?l<003o00kooooo
1@000?l2003o0080003o0`00o`020000o`800?l02@000?l2003o01L0003o3000o`040000o`800?l0
A@000?l>ooooohX0oh006Oooool001OoooooRP3o000>oooooc/00?l000<0003o003o0000o`000P00
o`020000o`T00?l00P000?l30?l00080003o0`00o`080000oa`00?l010000?l<003o00kooooo1@00
0?l7003o00T0003o1P00o`000`000?l00?l0003o00040000o`800?l01`000?l00`00o`00003o0000
o`02003o0080003o3000o`0V0000o`<00?l02`000?l2003o00030000o`00o`000?l00080003o0P00
o`0>0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo>`00o`000`000?l00?l0003o0002
003o0080003o2@00o`020000o`<0o`000P000?l3003o00P0003o7000o`040000o``00?l03_ooool5
0000o`L00?l02@000?l6003o00030000o`00o`000?l000@0003o0P00o`070000o`03003o00000?l0
003o00800?l00P000?l<003o02H0003o0`00o`0;0000o`800?l000<0003o003o0000o`000P000?l2
003o00h0003o3_oooon:0?n001Wooooo000Gooooo`80o`000P3oP01;0?l00080oh00>@3o000>oooo
od/00?l00P000?l00`3o0000003o0000o`020000o`L00?l010000?lL003o00L0003o2@00o`0>oooo
o`D0003o1`00o`090000o`800?l00P000?l3003o0080003o1000o`0:0000o`800?l010000?l5003o
0080003o1@00o`0V0000o`03003o00000?l0003o00/0003o2@00o`0>0000o`koooooRP3oP00Ioooo
o`005oooool=0?l000030?n0003o0000o`000200o`000P3oP01H0?l000kooooo?000o`020000o`d0
0?l00P000?l00`00o`00003o0000o`0;003o0080003o7000o`050000o`800?l00P000?l7003o00ko
oooo1@000?l4003o0080003o2@00o`000`000?l00?l0003o0005003o0080003o2@00o`0;0000o`D0
0?l00P000?l5003o02H0003o00<00?l00000o`000?l010000?l3003o00@0003o1`00o`0@0000o`ko
oooo403oP004003o07H0oh006Oooool001Oooooo3@3o00000`3oP000o`000?l0000P0?l00080oh00
F03o000>oooooc`00?l00P000?l=003o0080003o00<00?l00000o`000?l02`00o`020000oa`00?l0
1@000?l2003o0080003o1`00o`0>ooooo`D0003o1000o`020000o`T00?l000<0003o003o0000o`00
1@00o`020000o`T00?l02`000?l5003o0080003o1@00o`0V0000o`03003o00000?l0003o00@0003o
0`00o`040000o`L00?l040000?l>oooooa00oh001000o`1f0?n001Wooooo000GooooocT0o`000P3o
P0160?l00080oh001`3o000>oooooc`00?l00P000?l;003o00@0003o3000o`040000o`<00?l00P00
0?lI003o00<0003o0P00o`020000o`L00?l03_ooool40000o`03003o00000?l0003o00800?l00P00
0?l9003o00030000o`00o`000?l000D00?l01P000?l2003o00h0003o1@00o`020000o`D00?l01`00
0?l2003o00H0003o00<00?l00000o`000?l04P000?l2003o00030000o`00o`000?l000800?l00P00
0?l3003o01/0003o3_oooon:0?n001Wooooo000GooooocT0o`000P3oP0160?l00080oh001`3o000>
oooooc`00?l00P000?l;003o00@0003o3000o`040000o`<00?l00P000?lI003o00<0003o0P00o`02
0000o`L00?l03_ooool40000o`03003o00000?l0003o00800?l00P000?l9003o00030000o`00o`00
0?l000D00?l01P000?l2003o00h0003o1@00o`020000o`D00?l01`000?l2003o00H0003o00<00?l0
0000o`000?l04P000?l2003o00030000o`00o`000?l000800?l00P000?l3003o01/0003o3_oooon:
0?n001Wooooo000Goooooh<0o`000P3oP0050?l000kooooo8000o`020000oa`00?l010000?l2003o
00030000o`00o`000?l000800?l01`000?l9003o00@0003o7000o`020000o`D00?l01@000?l4003o
00kooooo10000?l00`00o`00003o0000o`02003o0080003o2P00o`040000o`800?l01`000?l2003o
00h0003o1@00o`040000o`<00?l01`000?l6003o03h0003o3_oooon:0?n001Wooooo000Goooooh<0
o`000P3oP0050?l000kooooo8000o`020000oa`00?l010000?l2003o00030000o`00o`000?l00080
0?l01`000?l9003o00@0003o7000o`020000o`D00?l01@000?l4003o00kooooo10000?l00`00o`00
003o0000o`02003o0080003o2P00o`040000o`800?l01`000?l2003o00h0003o1@00o`040000o`<0
0?l01`000?l6003o03h0003o3_oooon:0?n001Wooooo000Gooooodd0o`000P3oP00k0?l000kooooo
?000o`020000o`800?l00P000?l2003o00`0003o2@00o`020000o`D00?l00P000?lI003o00X0003o
0P00o`020000o`kooooo1@00o`060000o`L00?l040000?l3003o00d0003o1@00o`020000o`<00?l0
90000?l2003o02L0003o3_oooon:0?n001Wooooo000Gooooodd0o`000P3oP00k0?l000kooooo?000
o`020000o`800?l00P000?l2003o00`0003o2@00o`020000o`D00?l00P000?lI003o00X0003o0P00
o`020000o`kooooo1@00o`060000o`L00?l040000?l3003o00d0003o1@00o`020000o`<00?l09000
0?l2003o02L0003o3_oooon:0?n001Wooooo000GooooohX0o`003_ooooll003o00P0003o1@3oP005
0000o`L00?l00P000?l6003o00030000o`00o`000?l001/00?l00P000?l00`00o`00003o0000o`09
003o00kooooo0P00o`090000o`L00?l00P000?l00`00o`00003o0000o`0=0000o`03003o00000?l0
003o00d0003o0`00o`020000o`<00?l0:@000?l4003o0200003o3_oooon:0?n001Wooooo000Goooo
odd0o`000P3oP00`0?l00080oh002@3o000>oooooc`00?l01P000?l2003o00030000o`3oP000oh00
00@0oh004000o`030000obH00?l000<0003o003o0000o`000P00o`0>ooooo`L00?l010000?l3003o
00@0003o1@00o`0R0000o`<00?l07@000?l4003o00P0003o0P00o`0R0000o`koooooF03oP0030?l0
02l0oh006Oooool001OoooooC@3o00020?n00300o`000P3oP0090?l000kooooo?000o`060000o`80
0?l000<0003o0?n0003oP000103oP00@003o00<0003o9P00o`000`000?l00?l0003o0002003o00ko
oooo1`00o`040000o`<00?l010000?l5003o0280003o0`00o`0M0000o`@00?l020000?l2003o0280
003o3_oooomH0?n000<0o`00;`3oP00Iooooo`005ooooon:0?l000kooooo?000o`060000o`800?l0
0`000?l2003o00@0003o3P00o`020000ob<00?l00P000?l7003o00kooooo0P000?l7003o0080003o
0`00o`060000o`<00?l08P000?l5003o01/0003o1@00o`0[0000o`koooooRP3oP00Iooooo`005ooo
oon:0?l000kooooo?000o`060000o`800?l00`000?l2003o00@0003o3P00o`020000ob<00?l00P00
0?l7003o00kooooo0P000?l7003o0080003o0`00o`060000o`<00?l08P000?l5003o01/0003o1@00
o`0[0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo0P00o`020000oc`00?l02@000?l2
0?n000h00?l010000?l/003o00kooooo10000?l7003o00030000o`00o`000?l000H0003o0`00o`0T
0000o`<00?l06`000?l4003o00<0003o0P00o`0W0000o`kooooo?`3oP0020?l004T0oh006Oooool0
01OoooooRP3o000>ooooo`800?l00P000?ll003o00T0003o0P3oP00>003o00@0003o;000o`0>oooo
o`@0003o1`00o`000`000?l00?l0003o00060000o`<00?l090000?l3003o01/0003o1000o`030000
o`800?l09`000?l>ooooocl0oh000P3o00190?n001Wooooo000Gooooo`80oh00R03o000>ooooo`80
0?l00P000?ll003o00T0003o1000o`000`000?l00?l0003o0005003o00T0003o:`00o`0>ooooo`D0
003o1000o`0>0000o`@00?l080000?l00`00o`00003o0000o`0b0000o`800?l05`000?l>ooooohX0
oh006Oooool001OoooooP@3o00020?n000L0o`003_ooooll003o00d0003o0P00o`020?l000<0003o
1000o`090000ob`00?l03_ooool20000o`800?l000<0003o003o0000o`000P00o`0b0000o`03003o
00000?l0003o01d0003o0P00o`0/0000o`kooooo1@3oP002003o08<0oh006Oooool001OoooooP@3o
00020?n000L0o`003_ooooll003o00d0003o0P00o`020?l000<0003o1000o`090000ob`00?l03_oo
ool20000o`800?l000<0003o003o0000o`000P00o`0b0000o`03003o00000?l0003o01d0003o0P00
o`0/0000o`kooooo1@3oP002003o08<0oh006Oooool001OoooooRP3o000>ooooocT00?l00P000?l0
0`00o`00003o0000o`070000o`800?l02`000?l2003o00<0003o0P00o`040000o`L00?l000<0003o
003o0000o`008P00o`0>ooooo`L0003o0P00o`0b0000o`03003o00000?l0003o01d0003o0P00o`0N
0000o`800?l030000?l>ooooo`@0oh000`00o`020000o`800?l0O`3oP00Iooooo`005ooooon:0?l0
00kooooo>@00o`020000o`03003o00000?l0003o00L0003o0P00o`0;0000o`800?l00`000?l2003o
00@0003o1`00o`000`000?l00?l0003o000R003o00kooooo1`000?l2003o0380003o00<00?l00000
o`000?l07@000?l2003o01h0003o0P00o`0<0000o`kooooo103oP003003o0080003o0P00o`1o0?n0
01Wooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.00595501 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13382 -12 -4.5 ]
[-0.0125 .13382 0 4.5 ]
[-0.0125 .25292 -12 -4.5 ]
[-0.0125 .25292 0 4.5 ]
[-0.0125 .37202 -12 -4.5 ]
[-0.0125 .37202 0 4.5 ]
[-0.0125 .49112 -12 -4.5 ]
[-0.0125 .49112 0 4.5 ]
[-0.0125 .61022 -18 -4.5 ]
[-0.0125 .61022 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13382 m
1 .13382 L
s
0 .25292 m
1 .25292 L
s
0 .37202 m
1 .37202 L
s
0 .49112 m
1 .49112 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13382 m
.00625 .13382 L
s
[(20)] -0.0125 .13382 1 0 Mshowa
0 .25292 m
.00625 .25292 L
s
[(40)] -0.0125 .25292 1 0 Mshowa
0 .37202 m
.00625 .37202 L
s
[(60)] -0.0125 .37202 1 0 Mshowa
0 .49112 m
.00625 .49112 L
s
[(80)] -0.0125 .49112 1 0 Mshowa
0 .61022 m
.00625 .61022 L
s
[(100)] -0.0125 .61022 1 0 Mshowa
.125 Mabswid
0 .04449 m
.00375 .04449 L
s
0 .07427 m
.00375 .07427 L
s
0 .10404 m
.00375 .10404 L
s
0 .16359 m
.00375 .16359 L
s
0 .19337 m
.00375 .19337 L
s
0 .22314 m
.00375 .22314 L
s
0 .28269 m
.00375 .28269 L
s
0 .31247 m
.00375 .31247 L
s
0 .34224 m
.00375 .34224 L
s
0 .40179 m
.00375 .40179 L
s
0 .43157 m
.00375 .43157 L
s
0 .46134 m
.00375 .46134 L
s
0 .52089 m
.00375 .52089 L
s
0 .55067 m
.00375 .55067 L
s
0 .58044 m
.00375 .58044 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13382 m
1 .13382 L
s
.99375 .25292 m
1 .25292 L
s
.99375 .37202 m
1 .37202 L
s
.99375 .49112 m
1 .49112 L
s
.99375 .61022 m
1 .61022 L
s
.125 Mabswid
.99625 .04449 m
1 .04449 L
s
.99625 .07427 m
1 .07427 L
s
.99625 .10404 m
1 .10404 L
s
.99625 .16359 m
1 .16359 L
s
.99625 .19337 m
1 .19337 L
s
.99625 .22314 m
1 .22314 L
s
.99625 .28269 m
1 .28269 L
s
.99625 .31247 m
1 .31247 L
s
.99625 .34224 m
1 .34224 L
s
.99625 .40179 m
1 .40179 L
s
.99625 .43157 m
1 .43157 L
s
.99625 .46134 m
1 .46134 L
s
.99625 .52089 m
1 .52089 L
s
.99625 .55067 m
1 .55067 L
s
.99625 .58044 m
1 .58044 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .5032 L
.06452 .5032 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .5032 L
.06452 .5032 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .47101 L
.22581 .47101 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .47101 L
.22581 .47101 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .60332 L
.3871 .60332 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .60332 L
.3871 .60332 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .51741 L
.54839 .51741 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .51741 L
.54839 .51741 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .50989 L
.70968 .50989 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .50989 L
.70968 .50989 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .51072 L
.87097 .51072 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .51072 L
.87097 .51072 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .30944 L
.09677 .30944 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .30944 L
.09677 .30944 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .30797 L
.25806 .30797 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .30797 L
.25806 .30797 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .01472 L
.41935 .01472 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .49254 L
.58065 .49254 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .49254 L
.58065 .49254 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .38719 L
.74194 .38719 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .38719 L
.74194 .38719 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .54019 L
.90323 .54019 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .54019 L
.90323 .54019 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .37298 L
.12903 .37298 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .37298 L
.12903 .37298 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .14243 L
.29032 .14243 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .14243 L
.29032 .14243 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .47268 L
.45161 .47268 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .47268 L
.45161 .47268 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .01472 L
.6129 .01472 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .01472 L
.6129 .01472 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .12445 L
.77419 .12445 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .12445 L
.77419 .12445 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .33138 L
.93548 .33138 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .33138 L
.93548 .33138 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .44425 L
.16129 .44425 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .44425 L
.16129 .44425 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .28393 L
.32258 .28393 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .28393 L
.32258 .28393 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .38385 L
.48387 .38385 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .38385 L
.48387 .38385 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .57426 L
.64516 .57426 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .57426 L
.64516 .57426 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .2647 L
.80645 .2647 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .2647 L
.80645 .2647 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .22018 L
.96774 .22018 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .22018 L
.96774 .22018 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`0002kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Qoooooooo0000IOl0000;ooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`coogl02ol0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000;ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_o
oooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool001Oooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00Wo
oooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000@ooooo`Go00000oooool2o`0000Oooooo00?o0000ooooooooool02?ooool<
ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004Oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?oo
ool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002ooo
ool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3Ooo
O`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`coo`002ol0
o`0<o`00o`coogl02_l007l<ool000_o0?l03?l00?l<oomo00_o001o3?oo000;o`00O`_o003o3?oo
O`0;o`00O`_oo`003Ol0o`0:o`00O`googl02_l007l<ool000co0?l02_l007l=oomo00[o001o3?oo
000;o`3o00co003o3?ooO`08o`00O`Co00002oooool001?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l0
0?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02ooo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`00
2ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o
3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_o
oooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0017ooooo
0ol00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02ooo
ool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00002Oooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<
o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:oooo
o`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0
o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool<
ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool0
00_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_o
oooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`00
2oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02ooo
ool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o
00go003o5?ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo
2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl0
2_ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02ooo
ool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;
ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:oooo
o`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03Ol00?lFoooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo
2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl0
2_ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Booooo`?o00000ooo
ool2o`0000Oooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo
000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_oo
ool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0=o`00oaKooooo00?o
0000ooooooooool02Oooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo
000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_oo
ool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0=o`00oaKooooo00?o
0000ooooooooool02Oooool0013ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Kooooo0ol0
0008o`00O`coo`002ol0o`0<o`00o`coogl02_l007l<ool000co0?l02ol007l<oomo00_o001o3?oo
000;o`00O`_o003o3?ooO`0;o`00O`_oo`003Ol0o`0:o`00O`googl02_l007l<ool000co0?l02_l0
07l=oomo00[o001o3?oo000;o`3o00go003o4ol007l4o`0000_ooooo000@ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`00
2ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o
3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo
3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool<ool000_o0?l0
3?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl0
2oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`00
2ol0o`0=o`00oaKooooo00?o0000ooooooooool02Oooool001;ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0=o`00oaKooooo
00?o0000ooooooooool02Oooool001?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o
0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?oo
O`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<
o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o
3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l0
0?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02ooo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<
o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;
ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lF
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool<ool000_o0?l03?l00?l<oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5?ooool3o`00
00_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000<o`3o02;ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl0
2_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0
o`0Rooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l08_ooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Q
ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o02;ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool0
00_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0Rooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go
003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`00
2ol0o`0<o`00o`coogl02_ooool<ool000co0?l08_ooool<ool000_ooooo2ol00?l<oomo00_ooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l0
0?l<oomo00[ooooo3?oo000<o`3o02;ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`003?l0o`0Rooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=
oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool=ool0
02gooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o
00002Oooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000]ooooo`coo`002oooool;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go
003o5?ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo
000]ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;
ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<
ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<oomo
00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00
oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[o
oooo3?l00?l<oomo00[ooooo3Ooo000]ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go
0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool=ool002gooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl0
2_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Ooo
ool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<
oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`003?l0o`0R
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:oooo
o`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo
00Wooooo000Qooooo`;o00002Oooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000]ooooo`co
o`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027o
oooo3?oo000<o`3o023ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_oo
ool=ool002gooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;
ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<
ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000co0?l08_ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`co
ogl02_ooool=ool002gooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`go
ogl02_ooool<ool000co0?l08Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo
3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
8Oooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<
oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`003?l0o`0R
ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?oo
O`0:ooooo`goo`00;Oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000@
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo
2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000@ooooo`Co00000oooool01?l0003ooooooooo
ool00006ooooo`?o00002?l007l=ool000[o001o3?l00?l<oomo00[o001o3Ooo000]o`00O`coo`00
2ol007l;o`00o`coogl02ol007l;ool000go0?l02_l007l=oomo00[o001o3?oo000<o`3o027o001o
3?oo000<o`3o01oo001o1?l0000;ooooo`004?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00
;Oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Qooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`00
5_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool001;ooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`goo`005_oo
ool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_oo
ool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Q
ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000<o`3o02;ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`go
o`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool=ool002co
oooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Ooo
ool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool=ool002cooooo3?oo
000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=
ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:
ooooo`googl02_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00
oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08?ooool3o`00
00_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002go
oooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`co
o`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l0
2_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo
000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000F
ooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=
oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;oooo
o`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Roooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`co
ogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[o
oooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o
5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_oo
ool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo
000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;
ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool0
02gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=ool001Ko
oooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`go
ogl02_ooool=ool002cooooo3?oo000<o`3o023ooooo0ol0000;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo
000]ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?oo
ool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]oooo
o`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool0
00co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`00;?ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[o
oooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool002cooooo3Ooo000]ooooo`coo`002ooo
ool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=
ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/
ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027o
oooo0_l00009ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool;ool000go
0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Pooooo`?o00002oooool0027ooooo
00?o0000ooooooooool02?ooool=ool002cooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo
000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0
o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000/
ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool=
ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool002cooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool002gooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool002gooooo2ooo000=o`3o00[ooooo
3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool002gooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`00I_ooool<ool002gooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004Oooool3o`00
00Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00;Oooool;ool0
00go0?l02_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo
00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00;Oooool;ool000go0?l02_ooool=
oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000@oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`?o00002?l0
07l=ool006Ko001o3?oo000]o`00O`_oo`003Ol0o`0:o`00O`googl02_l007l=ool002co001o3?oo
000<o`3o01oo001o1?l0000;ooooo`004Oooool3o`0000?ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool002gooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`goo`00;?ooool<ool000co0?l08_ooool00ol0003oooooooooo`09ooooo`004?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`08ooooo`goo`00I_ooool<ool002gooooo3?oo000Fooooo`googl02_ooool=ool002cooooo
3?oo000<o`3o02;ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool006Ko
oooo3?oo000]ooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool0
2?ooool=ool006Kooooo3?oo000]ooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`00
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo
000]ooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo000]ooooo`coo`005_ooool=
oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo07_ooooo3?oo000]ooooo`coo`005_ooool=oomo00[ooooo3Ooo000/oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_o
oooo3?oo000]ooooo`coo`005_ooool=oomo04oooooo3?l0o`0Rooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo000]ooooo`coo`005_ooool=oomo04oooooo
3?l0o`0Rooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo
001?ooooo`googl0Coooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0001l
ooooo`coo`00Coooool=oomo04oooooo3?l0o`0Pooooo`?o00002oooool0027ooooo00?o0000oooo
ooooool0Noooool<ool004oooooo3OooO`1?ooooo`co0?l08_ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`1kooooo`coo`00Coooool=oomo04oooooo3?l0o`0Rooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo001?ooooo`googl0
Coooool<o`3o02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0Nooo
ool<ool004oooooo3OooO`1?ooooo`co0?l08_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`1kooooo`coo`00Coooool=oomo04oooooo3?l0o`0Rooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo001?ooooo`googl0Coooool<o`3o
02;ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0Noooool<ool004oo
oooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo
3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`1kooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo0_l0001l
ooooo`coo`00Coooool=oomo07_ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`1koooo
o`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool0Noooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo07_ooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`1kooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool0Noooool<ool004oooooo3OooO`1mooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo001?ooooo`googl0OOooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`1kooooo`coo`00Coooool=oomo07go
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0Noooool<ool004oooooo
3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo07_ooooo3?oo
001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`1k
ooooo`coo`00fOooool00ol0003oooooooooo`09ooooo`008Oooool2o`0007cooooo3?oo003Goooo
o`?o00002oooool0027ooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool0Noooool<ool00=Wooooo00?o0000ooooooooool02Oooool000_ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0Noooool<ool00=Wooooo00?o
0000ooooooooool02Oooool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`00
0?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00006ooooo`?o0000oooooomNooooo`Co00002oooool000cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`003?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000;ooooo`;o00001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Koooooool0001Uo`0000_ooooo000<
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000oooooomgooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00@Oooool3o`00
03Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000fooooo`?o0000;_ooool004;o
oooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eooooo`05o`000?oooooooooo
ooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool00000=?oo
ool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?ooool00ol0003ooooooooo
o`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003oooooooooool0000iooooo`03o`00
0?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003oooooooooo`0dooooo`05o`000?oo
ooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000003Gooooo
1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_ooool01Ol0003ooooooooo
oooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o0000=Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`000?oooooooooo03Gooooo
0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000=_ooool2o`0002kooooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.119489, -8.82962, \
0.0174717, 0.473218}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.00594868 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13369 -12 -4.5 ]
[-0.0125 .13369 0 4.5 ]
[-0.0125 .25266 -12 -4.5 ]
[-0.0125 .25266 0 4.5 ]
[-0.0125 .37164 -12 -4.5 ]
[-0.0125 .37164 0 4.5 ]
[-0.0125 .49061 -12 -4.5 ]
[-0.0125 .49061 0 4.5 ]
[-0.0125 .60958 -18 -4.5 ]
[-0.0125 .60958 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13369 m
.00625 .13369 L
s
[(20)] -0.0125 .13369 1 0 Mshowa
0 .25266 m
.00625 .25266 L
s
[(40)] -0.0125 .25266 1 0 Mshowa
0 .37164 m
.00625 .37164 L
s
[(60)] -0.0125 .37164 1 0 Mshowa
0 .49061 m
.00625 .49061 L
s
[(80)] -0.0125 .49061 1 0 Mshowa
0 .60958 m
.00625 .60958 L
s
[(100)] -0.0125 .60958 1 0 Mshowa
.125 Mabswid
0 .04446 m
.00375 .04446 L
s
0 .0742 m
.00375 .0742 L
s
0 .10395 m
.00375 .10395 L
s
0 .16343 m
.00375 .16343 L
s
0 .19318 m
.00375 .19318 L
s
0 .22292 m
.00375 .22292 L
s
0 .28241 m
.00375 .28241 L
s
0 .31215 m
.00375 .31215 L
s
0 .34189 m
.00375 .34189 L
s
0 .40138 m
.00375 .40138 L
s
0 .43112 m
.00375 .43112 L
s
0 .46087 m
.00375 .46087 L
s
0 .52035 m
.00375 .52035 L
s
0 .5501 m
.00375 .5501 L
s
0 .57984 m
.00375 .57984 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13369 m
1 .13369 L
s
.99375 .25266 m
1 .25266 L
s
.99375 .37164 m
1 .37164 L
s
.99375 .49061 m
1 .49061 L
s
.99375 .60958 m
1 .60958 L
s
.125 Mabswid
.99625 .04446 m
1 .04446 L
s
.99625 .0742 m
1 .0742 L
s
.99625 .10395 m
1 .10395 L
s
.99625 .16343 m
1 .16343 L
s
.99625 .19318 m
1 .19318 L
s
.99625 .22292 m
1 .22292 L
s
.99625 .28241 m
1 .28241 L
s
.99625 .31215 m
1 .31215 L
s
.99625 .34189 m
1 .34189 L
s
.99625 .40138 m
1 .40138 L
s
.99625 .43112 m
1 .43112 L
s
.99625 .46087 m
1 .46087 L
s
.99625 .52035 m
1 .52035 L
s
.99625 .5501 m
1 .5501 L
s
.99625 .57984 m
1 .57984 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .59893 L
.2381 .59893 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .59893 L
.2381 .59893 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .49224 L
.47619 .49224 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .49224 L
.47619 .49224 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .50581 L
.71429 .50581 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .50581 L
.71429 .50581 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00DOooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`0003gooooo001Booooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0??ooool005;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol0000mooooo`00D_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
03kooooo001Booooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000?_ooool0057ooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l0000n
ooooo`00D_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0??ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool0027oooooool0001Uo`0000_ooooo000Qooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`006?ooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00002oooool0
01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`005oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000?ooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl03Oooool4o`0000_ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
3ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool001;ooooo0ol00003ooooo`;o
00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000;ooooo
00Co0000oooooooooooo00001_ooool3o`0000koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0=ooooo`Co00002oooool0013ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`Co
00000oooool01?l0003oooooooooool00006ooooo`?o00003_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo00gooooo1?l0000;ooooo`004?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>
ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0017ooooo0ol00004ooooo`;o00001oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000?o
oooo00Co0000oooooooooooo00001_ooool3o`0000koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0=ooooo`Co00002oooool0013ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`00IOoo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2
o`0000Oooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o
00002oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
0;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o0000
2oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wo
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o00002ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool0ooooool<ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`002oooool3o`0000Co
oooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`3oooooo`coooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?ooooooHOooool00ol0
003oooooooooo`09ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001_ooool3o`000?ooooooG_ooool4o`0000_ooooo000<oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`09ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02Oooool000_ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001_ooooooo`0006Go00002oooool000cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo0_l0003oooooogOooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo001Aooooo`?o0000DOooool5o`00053ooooo0ol0
001Cooooo`?o0000?Oooool005;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0
001?ooooo`05o`000?ooooooooooooooool00000Doooool00ol0003oooooooooo`0looooo`00D_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0C_oo
ool5o`0003gooooo001Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0D?ooool2
o`00057ooooo00Co0000oooooooooooo0000?_ooool005;ooooo00?o0000ooooooooool0D?ooool0
1Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00
000nooooo`00DOooool2o`0005;ooooo00Go0000ooooooooooooooooo`00001?ooooo`05o`000?oo
ooooooooooooool00000D_ooool2o`0003kooooo001Booooo`03o`000?oooooooooo057ooooo0ol0
001Aooooo`?o0000E?ooool00ol0003oooooooooo`0looooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.00675159, -8.83902, \
0.0118357, 0.473722}}],

Cell[BoxData[
    \(89.99648999649`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #4 (16 clusters per band)", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 4;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CDCC99744C330025
D2A0988C2F3D1227
C5B59E6D4D420E31
E1A28D813E300E28
B9A08B6F46350E39
E7969B94353D102D
D4BCA4875E4E173F
FFE7C4CA5A6B4352
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
775B94A397DB8AA3
4152AA6094CC6DA0
32353C35623D4367
28271B00201C1A22
5646292D26021216
86A0596D6E5A663B
A9A475FF7C8BA44E
A985DAA396D57899
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F1B36221F30483D
291C001033121F3E
2C31162F28304237
9B534F7C4D4E524E
9C979D8955BB7065
F29DC1FFA9A7A6A7
C584BFA77EDE7571
A893747FA68978BF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A720017790B1D4D
4589125F37116D0B
A7610B9532336313
688F2D85346B640C
DE3617FF08589C32
A6437A840FE33913
851C5F9A1289756D
0C105A0120600416
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
321B192419252844
4543595A5679646F
89C2BDCEBFB3A57A
D3E0FFF3FEE2D387
7C61746C6B787260
38211C18211A2C2E
2B2407100004021F
C78CB6A37C7D7497
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D171C252E201B08
0C0B0A0006050803
13190B120E0A060C
0F0A0E0D221E2421
121A192E2D2D2319
1C12121F1C181B0D
0C0913090B150C11
4347709BFFCA8440
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A87663660465513
19AA4C4EB0073B47
14F51567B60F971E
5F8822DD6903DD0E
3CCD0881B33A980D
646200D7362BFF03
71391388335C8401
27302235110A1D2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B03815A002306D08
E34956A90F8E430A
CD2CA3AF0AB64C50
F404999C22D84272
900CD85E21FF2487
6600A24859B111B5
311B8A1B49A40C89
0B370F0A4808151C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3B242B211D337525
3241153C06495C0D
7380366C47767A3D
445B3A3822567E17
807E5F55467A6E32
325B1E2C1D355B00
3C480B20252C6617
97FF90CE81C0F6C9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28291D1B212A352E
322F241F1D131A14
121B0A1702150F0E
0A0A00080403080E
0010070B080B0C12
11100E06090C1016
17150E101C14192A
49404E4E4478FFC6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
563054481D6E4908
400B8D3F155B3B10
5C668927566F1928
3F71E324528F3016
46DFC420E65E1F69
36F3C935E5687E58
2BEAB139FF5A8674
3A33247F2C2BA400
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5BCE38BAA836CC1B
719930D37F57FF1B
534F20944F57BB13
381F166421447800
40162D3F08464C0C
381D5322104A2900
444C77133F571418
2C8138597E255B11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
221F5986B8CADC8A
032A493EC89FC079
1E105C67A798D56D
001B5244A493B96F
191F506CADA8DF67
002B5247C8A6E672
261A6C75AFACDD6A
37357169FFD8CBA9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C2F2021160B0904
0E08060714000E05
080D081108141013
0A0C0E12050E130E
0A0C0E0C09090E0F
04040D030D0C0B0E
06190E1B0F15110B
DFFFC18F523E343C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A64831B913A195C
2C9F880A87644230
1C70A31FA5354157
13F73D11FF1C5162
2B7D687C911DC820
2398234AC70D6A44
347B127D6309C007
2A2845031A611D00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B819F07024FF2874
BC14CB7E71D430C3
741ABD3759DD128C
15099D0B6C8B0AB5
103B3409734E0D7C
07213102332A1D39
275E051A55000923
A511406A223C3E1F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool7olg=c@Ooc<c<1onI
VIT7ogAdM0KoC4a<1olc<c<7o`0000Ko9BDU1_ooool6ogMgM`OoFe]K1onDU9@7oj>SX`OoUiNG1ooK
fm/7ohZ:RPKoXj>S1Oooool7oalO7`Oo6a/K1olf=SH7ob8R8POo7alO1ol`<307odQ8B0Ko?Cdm1Ooo
ool7oaXJ6POoLW9b1ol00007oaLG5`OoNGUi1_l;2`/7oadM7@KoCDe=1_ooool7oc8b<POo6a/K1_lI
6AT7ob@T90Oo6ATI1olU9BD7obPX:0KoA4A41Oooool7o`d=3@Oo5aLG1olL71`7obDU9@Oo;Rh^1olP
8207oa/K6`Ko20P81Oooool7oaXJ6POoQhN71omVIVH7ocHf=POoH61P1om6ATH6oeEEE@Ko4a<C1_oo
ool7ok2`/0Oo>3Ph1olE5AD6oj2PX0Oo0P821ol`<307ofe]K@Ko20P83oooool000gooooo1oo=cLd7
olc<c0OoVIVI1omdM7@6oda<C0Oo<c<c1ol00006obDU9@Kooooo1_mgMgL7oe]KF`OoU9BD1onSXj<7
oiNGU`Oofm_K1on:RXX6oj>SX`Gooooo1olO7al7oa/K6`Oo=SHf1olR8R87oalO7`Oo<30`1om8B4P6
ocdm?@Gooooo1olJ6QX7og9bLPOo00001olG5aL7ogUiN@Ko2`/;1olM7Ad6ode=C@Kooooo1olb<S87
oa/K6`Ko6ATI1olT92@7oaTI6@Oo9BDU1olX:2P6odA4A0Gooooo1ol=3@d7oaLG5`Oo71`L1olU9BD7
obh^;POo820P1olK6a/6o`P820Gooooo1olJ6QX7ohN7Q`OoIVIV1olf=SH7of1PH0OoATI61_mEEED6
oa<C4`Kooooo1on`/;07ocPh>0Oo5ADE1_nPX:07o`820POo<30`1om]KFd6o`P820oooooo000=oooo
o`OocLg=1oo<c<`7oiVIV@OoM7Ad1_m<C4`7oc<c<`Oo00001_lU9BD6ooooo`KoMgMg1omKFe/7oiBD
U0OoXj>S1onGUiL7om_Kf`OoRXZ:1_nSXj<5ooooo`Oo7alO1olK6a/7ocHf=POo8R8R1olO7al7oc0`
<0OoB4Q81_lm?Cd5ooooo`Oo6QXJ1ombLW87o`0000Oo5aLG1omiNGT6o`/;2`Oo7AdM1_m=CDd6oooo
o`Oo<S8b1olK6a/6oaTI6@Oo92@T1olI6AT7obDU9@Oo:2PX1_m4A4@5ooooo`Oo3@d=1olG5aL7oa`L
70Oo9BDU1ol^;Rh7ob0P80Oo6a/K1_l820P5ooooo`Oo6QXJ1on7QhL7ofIVIPOo=SHf1omPH607odI6
APKoEEEE1_lC4a<6ooooo`Oo/;2`1olh>3P7oaDE5@KoX:2P1ol20P87oc0`<0OoKFe]1_l820P?oooo
o`003Oooool7olg=c@Ooc<c<1onIVIT7ogAdM0KoC4a<1olc<c<7o`0000Ko9BDU1_ooool6ogMgM`Oo
Fe]K1onDU9@7oj>SX`OoUiNG1ooKfm/7ohZ:RPKoXj>S1Oooool7oalO7`Oo6a/K1olf=SH7ob8R8POo
7alO1ol`<307odQ8B0Ko?Cdm1Oooool7oaXJ6POoLW9b1ol00007oaLG5`OoNGUi1_l;2`/7oadM7@Ko
CDe=1_ooool7oc8b<POo6a/K1_lI6AT7ob@T90Oo6ATI1olU9BD7obPX:0KoA4A41Oooool7o`d=3@Oo
5aLG1olL71`7obDU9@Oo;Rh^1olP8207oa/K6`Ko20P81Oooool7oaXJ6POoQhN71omVIVH7ocHf=POo
H61P1om6ATH6oeEEE@Ko4a<C1_ooool7ok2`/0Oo>3Ph1olE5AD6oj2PX0Oo0P821ol`<307ofe]K@Ko
20P83oooool000gooooo1oo=cLd7olc<c0OoVIVI1omdM7@6oda<C0Oo<c<c1ol00006obDU9@Kooooo
1_mgMgL7oe]KF`OoU9BD1onSXj<7oiNGU`Oofm_K1on:RXX6oj>SX`Gooooo1olO7al7oa/K6`Oo=SHf
1olR8R87oalO7`Oo<30`1om8B4P6ocdm?@Gooooo1olJ6QX7og9bLPOo00001olG5aL7ogUiN@Ko2`/;
1olM7Ad6ode=C@Kooooo1olb<S87oa/K6`Ko6ATI1olT92@7oaTI6@Oo9BDU1olX:2P6odA4A0Gooooo
1ol=3@d7oaLG5`Oo71`L1olU9BD7obh^;POo820P1olK6a/6o`P820Gooooo1olJ6QX7ohN7Q`OoIVIV
1olf=SH7of1PH0OoATI61_mEEED6oa<C4`Kooooo1on`/;07ocPh>0Oo5ADE1_nPX:07o`820POo<30`
1om]KFd6o`P820oooooo000=ooooo`OocLg=1oo<c<`7oiVIV@OoM7Ad1_m<C4`7oc<c<`Oo00001_lU
9BD6ooooo`KoMgMg1omKFe/7oiBDU0OoXj>S1onGUiL7om_Kf`OoRXZ:1_nSXj<5ooooo`Oo7alO1olK
6a/7ocHf=POo8R8R1olO7al7oc0`<0OoB4Q81_lm?Cd5ooooo`Oo6QXJ1ombLW87o`0000Oo5aLG1omi
NGT6o`/;2`Oo7AdM1_m=CDd6ooooo`Oo<S8b1olK6a/6oaTI6@Oo92@T1olI6AT7obDU9@Oo:2PX1_m4
A4@5ooooo`Oo3@d=1olG5aL7oa`L70Oo9BDU1ol^;Rh7ob0P80Oo6a/K1_l820P5ooooo`Oo6QXJ1on7
QhL7ofIVIPOo=SHf1omPH607odI6APKoEEEE1_lC4a<6ooooo`Oo/;2`1olh>3P7oaDE5@KoX:2P1ol2
0P87oc0`<0OoKFe]1_l820P?ooooo`003Oooool7om;BdPOoX:2P1onHV9P7ohb<S0Ko;bl_1olm?Cd7
oa8B4PKo9bLW1_ooool6od51@@OoDU9B1onZZZX7of1PH0OoU9BD1oo<c<`7ofe]K@KoX:2P1Oooool7
obTY:@Oo71`L1ol00007oa0@40Oo<c<c1olB4Q87oalO7`Ko?Shn1Oooool7odE5A@OoRHV91olB4Q87
oemOG`Oo=cLg1_lA4A47ofe]K@Ko2`/;1_ooool7odE5A@Oo@d=31_mIFET7oeYJFPOoEUIF1omiNGT7
ofATI0KoKfm_1Oooool7o``<30Oo2`/;1ol:2PX7o`0000Oo1PH61ol51@D7o`P820Ko0`<31Oooool7
oaTI6@OoZZZZ1om<C4`7odi>CPOo/;2`1ol71`L6oc/k>`KoAdM71_ooool7on?Sh`OoBDU91omFEUH6
ojVYZ@Oo3`l?1on>SXh7od=3@`Ko2PX:3oooool000gooooo1ooBd]87oj2PX0OoV9RH1on<S8`6obl_
;`Oo?Cdm1olB4Q86obLW9`Kooooo1_m1@D47oe9BDPOoZZZZ1omPH607oiBDU0Ooc<c<1om]KFd6oj2P
X0Gooooo1olY:BT7oa`L70Oo00001ol@4107oc<c<`Oo4Q8B1olO7al6ochn?PGooooo1om5ADD7ohV9
R@Oo4Q8B1omOGel7ocLg=`Ko4A4A1om]KFd6o`/;2`Kooooo1om5ADD7od=3@`KoFEUI1omJFUX7oeIF
EPOoNGUi1omTI6@6ofm_K`Gooooo1ol<30`7o`/;2`Oo2PX:1ol00007o`H61POo1@D51ol820P6o`<3
0`Gooooo1olI6AT7ojZZZPOoC4a<1om>CTh7ok2`/0Oo1`L71_lk>c/6odM7A`Kooooo1ooShn<7odU9
B@OoEUIF1_nYZJT7o`l?3`OoSXj>1om3@d<6o`X:2Poooooo000=ooooo`Ood];B1onPX:07oiRHV0Oo
S8b<1_l_;bl7ocdm?@Oo4Q8B1_lW9bL6ooooo`Ko@D511omBDU87ojZZZPOoH61P1onDU9@7olc<c0Oo
KFe]1_nPX:05ooooo`Oo:BTY1olL71`7o`0000Oo410@1olc<c<7oa8B4POo7alO1_ln?Sh5ooooo`Oo
ADE51on9RHT7oa8B4POoGemO1olg=cL6oa4A4@OoKFe]1_l;2`/6ooooo`OoADE51om3@d<6oeUIF@Oo
FUYJ1omFEUH7ogUiN@OoI6AT1_m_Kfl5ooooo`Oo30`<1ol;2`/7o`X:2POo00001ol61PH7o`D51@Oo
20P81_l30`<5ooooo`Oo6ATI1onZZZX7oda<C0OoCTi>1on`/;07o`L71`Ko>c/k1_m7AdL6ooooo`Oo
hn?S1om9BDT7oeIFEPKoZJVY1ol?3`l7ohj>SPOo@d=31_l:2PX?ooooo`003Oooool7om;BdPOoX:2P
1onHV9P7ohb<S0Ko;bl_1olm?Cd7oa8B4PKo9bLW1_ooool6od51@@OoDU9B1onZZZX7of1PH0OoU9BD
1oo<c<`7ofe]K@KoX:2P1Oooool7obTY:@Oo71`L1ol00007oa0@40Oo<c<c1olB4Q87oalO7`Ko?Shn
1Oooool7odE5A@OoRHV91olB4Q87oemOG`Oo=cLg1_lA4A47ofe]K@Ko2`/;1_ooool7odE5A@Oo@d=3
1_mIFET7oeYJFPOoEUIF1omiNGT7ofATI0KoKfm_1Oooool7o``<30Oo2`/;1ol:2PX7o`0000Oo1PH6
1ol51@D7o`P820Ko0`<31Oooool7oaTI6@OoZZZZ1om<C4`7odi>CPOo/;2`1ol71`L6oc/k>`KoAdM7
1_ooool7on?Sh`OoBDU91omFEUH6ojVYZ@Oo3`l?1on>SXh7od=3@`Ko2PX:3oooool000gooooo1ooB
d]87oj2PX0OoV9RH1on<S8`6obl_;`Oo?Cdm1olB4Q86obLW9`Kooooo1_m1@D47oe9BDPOoZZZZ1omP
H607oiBDU0Ooc<c<1om]KFd6oj2PX0Gooooo1olY:BT7oa`L70Oo00001ol@4107oc<c<`Oo4Q8B1olO
7al6ochn?PGooooo1om5ADD7ohV9R@Oo4Q8B1omOGel7ocLg=`Ko4A4A1om]KFd6o`/;2`Kooooo1om5
ADD7od=3@`KoFEUI1omJFUX7oeIFEPOoNGUi1omTI6@6ofm_K`Gooooo1ol<30`7o`/;2`Oo2PX:1ol0
0007o`H61POo1@D51ol820P6o`<30`Gooooo1olI6AT7ojZZZPOoC4a<1om>CTh7ok2`/0Oo1`L71_lk
>c/6odM7A`Kooooo1ooShn<7odU9B@OoEUIF1_nYZJT7o`l?3`OoSXj>1om3@d<6o`X:2Poooooo000=
ooooo`Ood];B1onPX:07oiRHV0OoS8b<1_l_;bl7ocdm?@Oo4Q8B1_lW9bL6ooooo`Ko@D511omBDU87
ojZZZPOoH61P1onDU9@7olc<c0OoKFe]1_nPX:05ooooo`Oo:BTY1olL71`7o`0000Oo410@1olc<c<7
oa8B4POo7alO1_ln?Sh5ooooo`OoADE51on9RHT7oa8B4POoGemO1olg=cL6oa4A4@OoKFe]1_l;2`/6
ooooo`OoADE51om3@d<6oeUIF@OoFUYJ1omFEUH7ogUiN@OoI6AT1_m_Kfl5ooooo`Oo30`<1ol;2`/7
o`X:2POo00001ol61PH7o`D51@Oo20P81_l30`<5ooooo`Oo6ATI1onZZZX7oda<C0OoCTi>1on`/;07
o`L71`Ko>c/k1_m7AdL6ooooo`Oohn?S1om9BDT7oeIFEPKoZJVY1ol?3`l7ohj>SPOo@d=31_l:2PX?
ooooo`003Oooool7om;BdPOoX:2P1onHV9P7ohb<S0Ko;bl_1olm?Cd7oa8B4PKo9bLW1_ooool6od51
@@OoDU9B1onZZZX7of1PH0OoU9BD1oo<c<`7ofe]K@KoX:2P1Oooool7obTY:@Oo71`L1ol00007oa0@
40Oo<c<c1olB4Q87oalO7`Ko?Shn1Oooool7odE5A@OoRHV91olB4Q87oemOG`Oo=cLg1_lA4A47ofe]
K@Ko2`/;1_ooool7odE5A@Oo@d=31_mIFET7oeYJFPOoEUIF1omiNGT7ofATI0KoKfm_1Oooool7o``<
30Oo2`/;1ol:2PX7o`0000Oo1PH61ol51@D7o`P820Ko0`<31Oooool7oaTI6@OoZZZZ1om<C4`7odi>
CPOo/;2`1ol71`L6oc/k>`KoAdM71_ooool7on?Sh`OoBDU91omFEUH6ojVYZ@Oo3`l?1on>SXh7od=3
@`Ko2PX:3oooool000gooooo1oo5aLD7okFe]@OoWYjN1om]KFd6ode=C@Oo@T921ol>3Ph6oc4a<@Ko
oooo1_lb<S87ocDe=@Oo?3`l1ole=CD7of9RHPOo?Cdm1om3@d<6ofMWI`Gooooo1ol/;2`7oc4a<@Oo
5QHF1ol_;bl7obPX:0Oo<30`1om2@T86ocLg=`Gooooo1onWYjL7of5QH@Oo2`/;1onEUID7oc8b<PKo
<c<c1omSHf<6oa<C4`Kooooo1on9RHT7ol;2`PKo_Kfm1oo>c/h7okno_`Oo/k>c1onUYJD6ogYjNPGo
oooo1olC4a<7oaTI6@Oo2`/;1olB4Q87o`h>3POo2PX:1ol61PH6o``<30Gooooo1olD51@7ooGem@Oo
5ADE1omWIfL7okJf]POo3`l?1_nGUiL6oahN7PKooooo1oo=cLd7ob`/;0OoXj>S1_n_[jl7o`X:2POo
][Jf1om<C4`6oe1@D0oooooo000=ooooo`OoaLG51one]KD7oijNWPOoKFe]1_m=CDd7od92@POo3Ph>
1_la<C46ooooo`Ko<S8b1ole=CD7oc`l?0Oo=CDe1omRHV87ocdm?@Oo@d=31_mWIfL5ooooo`Oo;2`/
1ola<C47oaHF5POo;bl_1olX:2P7oc0`<0Oo@T921_lg=cL5ooooo`OoYjNW1omQHF47o`/;2`OoUIFE
1olb<S86oc<c<`OoHf=S1_lC4a<6ooooo`OoRHV91oo2`/86okfm_@Ooc/k>1ono_kl7ok>c/`OoYJFU
1_mjNWX5ooooo`Oo4a<C1olI6AT7o`/;2`Oo4Q8B1ol>3Ph7o`X:2POo1PH61_l<30`5ooooo`Oo51@D
1ooemOD7oaDE5@OoIfMW1onf][H7o`l?3`KoUiNG1_lN7Qh6ooooo`OocLg=1ol/;2`7oj>SX`Ko[jn_
1ol:2PX7okJf]POoC4a<1_m@D50?ooooo`003Oooool7olG5a@Oo]KFe1onNWYh7ofe]K@KoCDe=1om2
@T87o`h>3PKo<C4a1_ooool6oc8b<POo=CDe1oll?3`7ocDe=@OoHV9R1olm?Cd7od=3@`KoIfMW1Ooo
ool7ob`/;0Oo<C4a1olF5QH7obl_;`Oo:2PX1ol`<307od92@PKo=cLg1Oooool7ojNWY`OoHF5Q1ol;
2`/7oiFEU@Oo<S8b1_lc<c<7of=SH`Ko4a<C1_ooool7ohV9R@Oo`/;21_nm_Kd7olk>cPOo_kno1onc
/k<7ojFUY@KoNWYj1Oooool7oa<C4`Oo6ATI1ol;2`/7oa8B4POo3Ph>1ol:2PX7o`H61PKo30`<1Ooo
ool7oa@D50OomOGe1olE5AD7ofMWI`Oo][Jf1ol?3`l6oiNGU`Ko7QhN1_ooool7olg=c@Oo;2`/1onS
Xj<6ojn_[`Oo2PX:1onf][H7oda<C0KoD51@3oooool000gooooo1oo5aLD7okFe]@OoWYjN1om]KFd6
ode=C@Oo@T921ol>3Ph6oc4a<@Kooooo1_lb<S87ocDe=@Oo?3`l1ole=CD7of9RHPOo?Cdm1om3@d<6
ofMWI`Gooooo1ol/;2`7oc4a<@Oo5QHF1ol_;bl7obPX:0Oo<30`1om2@T86ocLg=`Gooooo1onWYjL7
of5QH@Oo2`/;1onEUID7oc8b<PKo<c<c1omSHf<6oa<C4`Kooooo1on9RHT7ol;2`PKo_Kfm1oo>c/h7
okno_`Oo/k>c1onUYJD6ogYjNPGooooo1olC4a<7oaTI6@Oo2`/;1olB4Q87o`h>3POo2PX:1ol61PH6
o``<30Gooooo1olD51@7ooGem@Oo5ADE1omWIfL7okJf]POo3`l?1_nGUiL6oahN7PKooooo1oo=cLd7
ob`/;0OoXj>S1_n_[jl7o`X:2POo][Jf1om<C4`6oe1@D0oooooo000=ooooo`OoaLG51one]KD7oijN
WPOoKFe]1_m=CDd7od92@POo3Ph>1_la<C46ooooo`Ko<S8b1ole=CD7oc`l?0Oo=CDe1omRHV87ocdm
?@Oo@d=31_mWIfL5ooooo`Oo;2`/1ola<C47oaHF5POo;bl_1olX:2P7oc0`<0Oo@T921_lg=cL5oooo
o`OoYjNW1omQHF47o`/;2`OoUIFE1olb<S86oc<c<`OoHf=S1_lC4a<6ooooo`OoRHV91oo2`/86okfm
_@Ooc/k>1ono_kl7ok>c/`OoYJFU1_mjNWX5ooooo`Oo4a<C1olI6AT7o`/;2`Oo4Q8B1ol>3Ph7o`X:
2POo1PH61_l<30`5ooooo`Oo51@D1ooemOD7oaDE5@OoIfMW1onf][H7o`l?3`KoUiNG1_lN7Qh6oooo
o`OocLg=1ol/;2`7oj>SX`Ko[jn_1ol:2PX7okJf]POoC4a<1_m@D50?ooooo`003Oooool7olG5a@Oo
]KFe1onNWYh7ofe]K@KoCDe=1om2@T87o`h>3PKo<C4a1_ooool6oc8b<POo=CDe1oll?3`7ocDe=@Oo
HV9R1olm?Cd7od=3@`KoIfMW1Oooool7ob`/;0Oo<C4a1olF5QH7obl_;`Oo:2PX1ol`<307od92@PKo
=cLg1Oooool7ojNWY`OoHF5Q1ol;2`/7oiFEU@Oo<S8b1_lc<c<7of=SH`Ko4a<C1_ooool7ohV9R@Oo
`/;21_nm_Kd7olk>cPOo_kno1onc/k<7ojFUY@KoNWYj1Oooool7oa<C4`Oo6ATI1ol;2`/7oa8B4POo
3Ph>1ol:2PX7o`H61PKo30`<1Oooool7oa@D50OomOGe1olE5AD7ofMWI`Oo][Jf1ol?3`l6oiNGU`Ko
7QhN1_ooool7olg=c@Oo;2`/1onSXj<6ojn_[`Oo2PX:1onf][H7oda<C0KoD51@3oooool000gooooo
1oo5aLD7okFe]@OoWYjN1om]KFd6ode=C@Oo@T921ol>3Ph6oc4a<@Kooooo1_lb<S87ocDe=@Oo?3`l
1ole=CD7of9RHPOo?Cdm1om3@d<6ofMWI`Gooooo1ol/;2`7oc4a<@Oo5QHF1ol_;bl7obPX:0Oo<30`
1om2@T86ocLg=`Gooooo1onWYjL7of5QH@Oo2`/;1onEUID7oc8b<PKo<c<c1omSHf<6oa<C4`Kooooo
1on9RHT7ol;2`PKo_Kfm1oo>c/h7okno_`Oo/k>c1onUYJD6ogYjNPGooooo1olC4a<7oaTI6@Oo2`/;
1olB4Q87o`h>3POo2PX:1ol61PH6o``<30Gooooo1olD51@7ooGem@Oo5ADE1omWIfL7okJf]POo3`l?
1_nGUiL6oahN7PKooooo1oo=cLd7ob`/;0OoXj>S1_n_[jl7o`X:2POo][Jf1om<C4`6oe1@D0oooooo
000=ooooo`OohN7Q1onRXZ87ohf=S@OoPH611_ln?Sh7oc0`<0Oo3Ph>1_lX:2P6ooooo`Ko:2PX1olW
9bL7oa/K6`Oo00001olP8207oa`L70Oo6QXJ1_lR8R85ooooo`OoVi^K1omCDe<7odm?C`OoO7al1om=
CDd7odi>CPOoDU9B1_m>CTh5ooooo`OoJ6QX1on?Shl7obd];@OoQHF51old=3@6of][J`OoI6AT1_l<
30`6ooooo`Oodm?C1ooPh>06ooooo`Oolo?c1oono_h7on;RhPOodm?C1_n7QhL5ooooo`Oo3`l?1ol:
2PX7o`h>3POo3@d=1olR8R87oahN7POo92@T1_lQ8B45ooooo`OoGemO1on8R8P7ob8R8POogMgM1omY
JFT7o`<30`KogMgM1_l>3Ph6ooooo`Oom?Cd1ol410@7oiVIV@KoW9bL1olR8R87omSHf0Oo@T921_mb
LW8?ooooo`003Oooool7on7Qh@OoXZ:R1on=SHd7oh61P@Ko?Shn1ol`<307o`h>3PKo:2PX1_ooool6
obPX:0Oo9bLW1olK6a/7o`0000Oo820P1olL71`7oaXJ6PKo8R8R1Oooool7oi^KV`OoDe=C1om?Cdl7
ogalO0OoCDe=1om>CTh7oe9BDPKoCTi>1Oooool7ofQXJ0OoShn?1ol];Bd7ohF5Q@Oo=3@d1_m[Jf/7
ofATI0Ko30`<1_ooool7om?Cd`Ooh>3P1_ooool7oo?cl`Ooo_kn1ooRh^87om?Cd`KoQhN71Oooool7
o`l?3`Oo2PX:1ol>3Ph7o`d=3@Oo8R8R1olN7Qh7ob@T90Ko8B4Q1Oooool7oemOG`OoR8R81olR8R87
omgMg@OoJFUY1ol30`<6omgMg@Ko3Ph>1_ooool7ooCdm0Oo10@41onIVIT6oibLW0Oo8R8R1ooHf=P7
od92@PKoLW9b3oooool000gooooo1ooQhN47oj:RXPOoSHf=1on1PH46ochn?POo<30`1ol>3Ph6obPX
:0Kooooo1_lX:2P7obLW9`Oo6a/K1ol00007ob0P80Oo71`L1olJ6QX6ob8R8PGooooo1onKVi/7oe=C
D`OoCdm?1omlO7`7ode=C@OoCTi>1omBDU86odi>CPGooooo1omXJ6P7ohn?S`Oo;Bd]1on5QHD7oc@d
=0KoJf][1omTI6@6o``<30Kooooo1ooCdm<7on3Ph0Kooooo1ooclo<7ooknoPOoh^;R1ooCdm<6ohN7
Q`Gooooo1ol?3`l7o`X:2POo3Ph>1ol=3@d7ob8R8POo7QhN1olT92@6ob4Q8@Gooooo1omOGel7ohR8
R0Oo8R8R1ooMgMd7ofUYJ@Oo0`<31_oMgMd6o`h>3PKooooo1oodm?@7o`@410OoVIVI1_nLW9`7ob8R
8POof=SH1om2@T86og9bLPoooooo000=ooooo`OohN7Q1onRXZ87ohf=S@OoPH611_ln?Sh7oc0`<0Oo
3Ph>1_lX:2P6ooooo`Ko:2PX1olW9bL7oa/K6`Oo00001olP8207oa`L70Oo6QXJ1_lR8R85ooooo`Oo
Vi^K1omCDe<7odm?C`OoO7al1om=CDd7odi>CPOoDU9B1_m>CTh5ooooo`OoJ6QX1on?Shl7obd];@Oo
QHF51old=3@6of][J`OoI6AT1_l<30`6ooooo`Oodm?C1ooPh>06ooooo`Oolo?c1oono_h7on;RhPOo
dm?C1_n7QhL5ooooo`Oo3`l?1ol:2PX7o`h>3POo3@d=1olR8R87oahN7POo92@T1_lQ8B45ooooo`Oo
GemO1on8R8P7ob8R8POogMgM1omYJFT7o`<30`KogMgM1_l>3Ph6ooooo`Oom?Cd1ol410@7oiVIV@Ko
W9bL1olR8R87omSHf0Oo@T921_mbLW8?ooooo`003Oooool7on7Qh@OoXZ:R1on=SHd7oh61P@Ko?Shn
1ol`<307o`h>3PKo:2PX1_ooool6obPX:0Oo9bLW1olK6a/7o`0000Oo820P1olL71`7oaXJ6PKo8R8R
1Oooool7oi^KV`OoDe=C1om?Cdl7ogalO0OoCDe=1om>CTh7oe9BDPKoCTi>1Oooool7ofQXJ0OoShn?
1ol];Bd7ohF5Q@Oo=3@d1_m[Jf/7ofATI0Ko30`<1_ooool7om?Cd`Ooh>3P1_ooool7oo?cl`Ooo_kn
1ooRh^87om?Cd`KoQhN71Oooool7o`l?3`Oo2PX:1ol>3Ph7o`d=3@Oo8R8R1olN7Qh7ob@T90Ko8B4Q
1Oooool7oemOG`OoR8R81olR8R87omgMg@OoJFUY1ol30`<6omgMg@Ko3Ph>1_ooool7ooCdm0Oo10@4
1onIVIT6oibLW0Oo8R8R1ooHf=P7od92@PKoLW9b3oooool000gooooo1ooQhN47oj:RXPOoSHf=1on1
PH46ochn?POo<30`1ol>3Ph6obPX:0Kooooo1_lX:2P7obLW9`Oo6a/K1ol00007ob0P80Oo71`L1olJ
6QX6ob8R8PGooooo1onKVi/7oe=CD`OoCdm?1omlO7`7ode=C@OoCTi>1omBDU86odi>CPGooooo1omX
J6P7ohn?S`Oo;Bd]1on5QHD7oc@d=0KoJf][1omTI6@6o``<30Kooooo1ooCdm<7on3Ph0Kooooo1ooc
lo<7ooknoPOoh^;R1ooCdm<6ohN7Q`Gooooo1ol?3`l7o`X:2POo3Ph>1ol=3@d7ob8R8POo7QhN1olT
92@6ob4Q8@Gooooo1omOGel7ohR8R0Oo8R8R1ooMgMd7ofUYJ@Oo0`<31_oMgMd6o`h>3PKooooo1ood
m?@7o`@410OoVIVI1_nLW9`7ob8R8POof=SH1om2@T86og9bLPoooooo000=ooooo`Oo^KVi1onPX:07
oh^;R`OoKfm_1_m6ATH7ocDe=@Oo3Ph>1_li>CT6ooooo`KoEUIF1om6ATH7obTY:@Oo;Bd]1olV9RH7
o`820POo4Q8B1_lF5QH5ooooo`OoW9bL1onGUiL7oifMW@OoRHV91omEEED7ok^k^`OoL71`1_mUIFD5
ooooo`Oog]kN1olf=SH7oaLG5`Oooooo1ol820P6oeQHF0OoW9bL1_lb<S86ooooo`OoO7al1omQHF46
ogAdM0OoK6a/1om[Jf/7ogQhN0OoLW9b1_mPH605ooooo`Oo4Q8B1olJ6QX7oaTI6@Oo;Rh^3_l];Bd7
ob<S8`Ko6ATI1Oooool7oc`l?0OocLg=1ol820P7oh61P@Oo/k>c1olj>SX6oiRHV0Ko3@d=1_ooool7
oi2@T0Oo30`<1ooHf=P6oeiNGPOo8B4Q1oooool7ob@T90KoQhN73oooool000gooooo1oni^KT7oj2P
X0OoRh^;1om_Kfl6odI6APOo=CDe1ol>3Ph6ocTi>@Kooooo1_mFEUH7odI6APOo:BTY1ol];Bd7obHV
9POo0P821olB4Q86oaHF5PGooooo1onLW9`7oiNGU`OoWIfM1on9RHT7oeEEE@Oo^k^k1om`L706ofEU
I@Gooooo1ooNg]h7ocHf=POo5aLG1oooool7o`P820KoF5QH1onLW9`6oc8b<PKooooo1omlO7`7of5Q
H@KoM7Ad1om/K6`7of][J`OoN7Qh1ombLW86of1PH0Gooooo1olB4Q87oaXJ6POo6ATI1ol^;Rh>obd]
;@Oo8b<S1_lI6AT5ooooo`Oo?3`l1oo=cLd7o`P820OoPH611onc/k<7ocXj>PKoV9RH1_l=3@d6oooo
o`OoT92@1ol<30`7omSHf0KoGUiN1olQ8B47ooooo`Oo92@T1_n7QhL?ooooo`003Oooool7okVi^@Oo
X:2P1on;Rh/7ofm_K`KoATI61ole=CD7o`h>3PKo>CTi1_ooool6oeIFEPOoATI61olY:BT7obd];@Oo
9RHV1ol20P87oa8B4PKo5QHF1Oooool7oibLW0OoUiNG1onMWId7ohV9R@OoEEEE1onk^k/7og1`L0Ko
IFEU1Oooool7omkNgPOo=SHf1olG5aL7ooooo`Oo20P81_mHF5P7oibLW0Ko<S8b1_ooool7ogalO0Oo
HF5Q1_mdM7@7ofa/K0OoJf][1omhN7P7og9bLPKoH61P1Oooool7oa8B4POo6QXJ1olI6AT7obh^;Pko
;Bd]1olS8b<6oaTI6@Gooooo1oll?3`7olg=c@Oo20P81on1PH47ok>c/`Oo>SXj1_nHV9P6o`d=3@Ko
oooo1on@T907o``<30Oof=SH1_mNGUh7ob4Q8@Oooooo1olT92@6ohN7Q`oooooo000=ooooo`Oo^KVi
1onPX:07oh^;R`OoKfm_1_m6ATH7ocDe=@Oo3Ph>1_li>CT6ooooo`KoEUIF1om6ATH7obTY:@Oo;Bd]
1olV9RH7o`820POo4Q8B1_lF5QH5ooooo`OoW9bL1onGUiL7oifMW@OoRHV91omEEED7ok^k^`OoL71`
1_mUIFD5ooooo`Oog]kN1olf=SH7oaLG5`Oooooo1ol820P6oeQHF0OoW9bL1_lb<S86ooooo`OoO7al
1omQHF46ogAdM0OoK6a/1om[Jf/7ogQhN0OoLW9b1_mPH605ooooo`Oo4Q8B1olJ6QX7oaTI6@Oo;Rh^
3_l];Bd7ob<S8`Ko6ATI1Oooool7oc`l?0OocLg=1ol820P7oh61P@Oo/k>c1olj>SX6oiRHV0Ko3@d=
1_ooool7oi2@T0Oo30`<1ooHf=P6oeiNGPOo8B4Q1oooool7ob@T90KoQhN73oooool000gooooo1oni
^KT7oj2PX0OoRh^;1om_Kfl6odI6APOo=CDe1ol>3Ph6ocTi>@Kooooo1_mFEUH7odI6APOo:BTY1ol]
;Bd7obHV9POo0P821olB4Q86oaHF5PGooooo1onLW9`7oiNGU`OoWIfM1on9RHT7oeEEE@Oo^k^k1om`
L706ofEUI@Gooooo1ooNg]h7ocHf=POo5aLG1oooool7o`P820KoF5QH1onLW9`6oc8b<PKooooo1oml
O7`7of5QH@KoM7Ad1om/K6`7of][J`OoN7Qh1ombLW86of1PH0Gooooo1olB4Q87oaXJ6POo6ATI1ol^
;Rh>obd];@Oo8b<S1_lI6AT5ooooo`Oo?3`l1oo=cLd7o`P820OoPH611onc/k<7ocXj>PKoV9RH1_l=
3@d6ooooo`OoT92@1ol<30`7omSHf0KoGUiN1olQ8B47ooooo`Oo92@T1_n7QhL?ooooo`003Oooool7
okVi^@OoX:2P1on;Rh/7ofm_K`KoATI61ole=CD7o`h>3PKo>CTi1_ooool6oeIFEPOoATI61olY:BT7
obd];@Oo9RHV1ol20P87oa8B4PKo5QHF1Oooool7oibLW0OoUiNG1onMWId7ohV9R@OoEEEE1onk^k/7
og1`L0KoIFEU1Oooool7omkNgPOo=SHf1olG5aL7ooooo`Oo20P81_mHF5P7oibLW0Ko<S8b1_ooool7
ogalO0OoHF5Q1_mdM7@7ofa/K0OoJf][1omhN7P7og9bLPKoH61P1Oooool7oa8B4POo6QXJ1olI6AT7
obh^;Pko;Bd]1olS8b<6oaTI6@Gooooo1oll?3`7olg=c@Oo20P81on1PH47ok>c/`Oo>SXj1_nHV9P6
o`d=3@Kooooo1on@T907o``<30Oof=SH1_mNGUh7ob4Q8@Oooooo1olT92@6ohN7Q`oooooo000=oooo
o`Oo^KVi1onPX:07oh^;R`OoKfm_1_m6ATH7ocDe=@Oo3Ph>1_li>CT6ooooo`KoEUIF1om6ATH7obTY
:@Oo;Bd]1olV9RH7o`820POo4Q8B1_lF5QH5ooooo`OoW9bL1onGUiL7oifMW@OoRHV91omEEED7ok^k
^`OoL71`1_mUIFD5ooooo`Oog]kN1olf=SH7oaLG5`Oooooo1ol820P6oeQHF0OoW9bL1_lb<S86oooo
o`OoO7al1omQHF46ogAdM0OoK6a/1om[Jf/7ogQhN0OoLW9b1_mPH605ooooo`Oo4Q8B1olJ6QX7oaTI
6@Oo;Rh^3_l];Bd7ob<S8`Ko6ATI1Oooool7oc`l?0OocLg=1ol820P7oh61P@Oo/k>c1olj>SX6oiRH
V0Ko3@d=1_ooool7oi2@T0Oo30`<1ooHf=P6oeiNGPOo8B4Q1oooool7ob@T90KoQhN73oooool000go
oooo1ooWinL7oiJFUPOoVi^K1onDU9@6ocDe=@Oo?Cdm1ol@4106obd];@Kooooo1_n6QXH7oj2PX0Oo
FEUI1om]KFd7ofi^KPOoFUYJ1omVIVH6oc/k>`Gooooo1oobl_87oifMW@Oo`L711oooool7ojVYZ@Oo
YjNW1onVYZH6ojNWY`Gooooo1onVYZH7od=3@`OoNWYj1on4Q8@7o`l?3`Kohn?S1oli>CT6oa<C4`Ko
oooo1olh>3P7ob4Q8@Ko71`L1olH61P7ob4Q8@Oo6QXJ1ol/;2`6obh^;PGooooo1olL71`>oa8B4POo
7alO1olL71`7oaPH60Oo6a/K1_l=3@d5ooooo`OoI6AT1omRHV87o`0000OoemOG1olf=SH7ob/[:`Ko
oooo1_l30`<6ooooo`OoIVIV1ol00007oj:RXPKoB4Q81omIFET7ok6a/@Oo4A4A1_ne]KD?ooooo`00
3Oooool7onOWi`OoUYJF1onKVi/7oiBDU0Ko=CDe1olm?Cd7oa0@40Ko;Bd]1_ooool6ohJ6QPOoX:2P
1omIFET7ofe]K@OoKVi^1omJFUX7ofIVIPKo>c/k1Oooool7oo;blPOoWIfM1oo1`L47ooooo`OoZJVY
1onWYjL7ojJVYPKoYjNW1Oooool7ojJVYPOo@d=31omjNWX7ohB4Q0Oo3`l?1_oShn<7ocTi>@Ko4a<C
1_ooool7ocPh>0Oo8B4Q1_lL71`7oaPH60Oo8B4Q1olJ6QX7ob`/;0Ko;Rh^1Oooool7oa`L70ko4Q8B
1olO7al7oa`L70Oo61PH1olK6a/6o`d=3@Gooooo1omTI6@7of9RHPOo00001ooGemL7ocHf=POo:b/[
1_ooool6o`<30`Kooooo1omVIVH7o`0000OoXZ:R1_m8B4P7oeUIF@Oo/K6a1olA4A46okFe]@oooooo
000=ooooo`OoinOW1onFUYH7oi^KV`OoU9BD1_le=CD7ocdm?@Oo410@1_l];Bd6ooooo`KoQXJ61onP
X:07oeUIF@OoKFe]1om^KVh7oeYJFPOoIVIV1_lk>c/5ooooo`Ool_;b1onMWId7ol71`@Oooooo1onY
ZJT7ojNWY`OoYZJV1_nWYjL5ooooo`OoYZJV1om3@d<7ogYjNPOoQ8B41ol?3`l6on?Sh`Oo>CTi1_lC
4a<6ooooo`Oo>3Ph1olQ8B46oa`L70Oo61PH1olQ8B47oaXJ6POo;2`/1_l^;Rh5ooooo`Oo71`L3_lB
4Q87oalO7`Oo71`L1olH61P7oa/K6`Ko3@d=1Oooool7ofATI0OoHV9R1ol00007omOGe`Oo=SHf1ol[
:b/6ooooo`Ko0`<31_ooool7ofIVIPOo00001onRXZ86odQ8B0OoFEUI1ona/K47oa4A4@Ko]KFe3ooo
ool000gooooo1ooWinL7oiJFUPOoVi^K1onDU9@6ocDe=@Oo?Cdm1ol@4106obd];@Kooooo1_n6QXH7
oj2PX0OoFEUI1om]KFd7ofi^KPOoFUYJ1omVIVH6oc/k>`Gooooo1oobl_87oifMW@Oo`L711oooool7
ojVYZ@OoYjNW1onVYZH6ojNWY`Gooooo1onVYZH7od=3@`OoNWYj1on4Q8@7o`l?3`Kohn?S1oli>CT6
oa<C4`Kooooo1olh>3P7ob4Q8@Ko71`L1olH61P7ob4Q8@Oo6QXJ1ol/;2`6obh^;PGooooo1olL71`>
oa8B4POo7alO1olL71`7oaPH60Oo6a/K1_l=3@d5ooooo`OoI6AT1omRHV87o`0000OoemOG1olf=SH7
ob/[:`Kooooo1_l30`<6ooooo`OoIVIV1ol00007oj:RXPKoB4Q81omIFET7ok6a/@Oo4A4A1_ne]KD?
ooooo`003Oooool7onOWi`OoUYJF1onKVi/7oiBDU0Ko=CDe1olm?Cd7oa0@40Ko;Bd]1_ooool6ohJ6
QPOoX:2P1omIFET7ofe]K@OoKVi^1omJFUX7ofIVIPKo>c/k1Oooool7oo;blPOoWIfM1oo1`L47oooo
o`OoZJVY1onWYjL7ojJVYPKoYjNW1Oooool7ojJVYPOo@d=31omjNWX7ohB4Q0Oo3`l?1_oShn<7ocTi
>@Ko4a<C1_ooool7ocPh>0Oo8B4Q1_lL71`7oaPH60Oo8B4Q1olJ6QX7ob`/;0Ko;Rh^1Oooool7oa`L
70ko4Q8B1olO7al7oa`L70Oo61PH1olK6a/6o`d=3@Gooooo1omTI6@7of9RHPOo00001ooGemL7ocHf
=POo:b/[1_ooool6o`<30`Kooooo1omVIVH7o`0000OoXZ:R1_m8B4P7oeUIF@Oo/K6a1olA4A46okFe
]@oooooo000=ooooo`OoinOW1onFUYH7oi^KV`OoU9BD1_le=CD7ocdm?@Oo410@1_l];Bd6ooooo`Ko
QXJ61onPX:07oeUIF@OoKFe]1om^KVh7oeYJFPOoIVIV1_lk>c/5ooooo`Ool_;b1onMWId7ol71`@Oo
oooo1onYZJT7ojNWY`OoYZJV1_nWYjL5ooooo`OoYZJV1om3@d<7ogYjNPOoQ8B41ol?3`l6on?Sh`Oo
>CTi1_lC4a<6ooooo`Oo>3Ph1olQ8B46oa`L70Oo61PH1olQ8B47oaXJ6POo;2`/1_l^;Rh5ooooo`Oo
71`L3_lB4Q87oalO7`Oo71`L1olH61P7oa/K6`Ko3@d=1Oooool7ofATI0OoHV9R1ol00007omOGe`Oo
=SHf1ol[:b/6ooooo`Ko0`<31_ooool7ofIVIPOo00001onRXZ86odQ8B0OoFEUI1ona/K47oa4A4@Ko
]KFe3oooool000gooooo1ooWinL7oiJFUPOoVi^K1onDU9@6ocDe=@Oo?Cdm1ol@4106obd];@Kooooo
1_n6QXH7oj2PX0OoFEUI1om]KFd7ofi^KPOoFUYJ1omVIVH6oc/k>`Gooooo1oobl_87oifMW@Oo`L71
1oooool7ojVYZ@OoYjNW1onVYZH6ojNWY`Gooooo1onVYZH7od=3@`OoNWYj1on4Q8@7o`l?3`Kohn?S
1oli>CT6oa<C4`Kooooo1olh>3P7ob4Q8@Ko71`L1olH61P7ob4Q8@Oo6QXJ1ol/;2`6obh^;PGooooo
1olL71`>oa8B4POo7alO1olL71`7oaPH60Oo6a/K1_l=3@d5ooooo`OoI6AT1omRHV87o`0000OoemOG
1olf=SH7ob/[:`Kooooo1_l30`<6ooooo`OoIVIV1ol00007oj:RXPKoB4Q81omIFET7ok6a/@Oo4A4A
1_ne]KD?ooooo`003Oooool7omCDe0Oo_;bl1onTY:@7ohN7Q`KoGUiN1om>CTh7oaLG5`Ko?clo1_oo
ool6ojVYZ@OoY:BT1omeMGD7ooooo`OoO7al1on;Rh/7ojBTY0KoCTi>1Oooool7olG5a@OoQ8B41ono
_kl7ojNWY`OoOWin1ooNg]h7ogEeM@KoLG5a1Oooool7ohF5Q@Oo71`L1omOGel7oiZJVPOo4Q8B1_n9
RHT7ogEeM@KoKFe]1_ooool7ob/[:`Oo92@T1_l71`L7oa0@40Oo00001ol410@7o`820PKo7alO1Ooo
ool7o``<30Oo2@T91olC4a<7o`T92@Oo2`/;1olE5AD7o``<30Ko4A4A1Oooool7og5aL@Oo>CTi1olC
4a<7ohR8R0Oo<c<c1omLG5`6ohB4Q0Ko0@411_ooool7oc4a<@Oo6a/K1on:RXX6oa/K6`OoBDU91onT
Y:@7o``<30KoRHV93oooool000gooooo1ooDe=@7okbl_0OoY:BT1on7QhL6oeiNGPOoCTi>1olG5aL6
oclo?`Kooooo1_nYZJT7ojBTY0OoMGEe1oooool7ogalO0OoRh^;1onTY:@6odi>CPGooooo1oo5aLD7
ohB4Q0Oo_kno1onWYjL7oginOPOog]kN1omeMGD6og5aL@Gooooo1on5QHD7oa`L70OoGemO1onJVYX7
oa8B4PKoRHV91omeMGD6ofe]K@Kooooo1ol[:b/7ob@T90Ko1`L71ol@4107o`0000Oo10@41ol20P86
oalO7`Gooooo1ol<30`7o`T92@Oo4a<C1ol92@T7o`/;2`Oo5ADE1ol<30`6oa4A4@Gooooo1omaLG47
ocTi>@Oo4a<C1on8R8P7oc<c<`OoG5aL1_n4Q8@6o`410@Kooooo1ola<C47oa/K6`OoRXZ:1_lK6a/7
odU9B@OoY:BT1ol<30`6ohV9R@oooooo000=ooooo`Ooe=CD1onl_;`7ojBTY0OoQhN71_mNGUh7odi>
CPOo5aLG1_lo?cl6ooooo`KoZJVY1onTY:@7ogEeM@Oooooo1omlO7`7oh^;R`OoY:BT1_m>CTh5oooo
o`OoaLG51on4Q8@7okno_`OoYjNW1omnOWh7omkNgPOoMGEe1_maLG45ooooo`OoQHF51olL71`7oemO
G`OoVYZJ1olB4Q86ohV9R@OoMGEe1_m]KFd6ooooo`Oo:b/[1olT92@6o`L71`Oo410@1ol00007o`@4
10Oo0P821_lO7al5ooooo`Oo30`<1ol92@T7oa<C4`Oo2@T91ol;2`/7oaDE5@Oo30`<1_lA4A45oooo
o`OoLG5a1oli>CT7oa<C4`OoR8R81olc<c<7oeaLG0KoQ8B41_l10@46ooooo`Oo<C4a1olK6a/7ohZ:
RPKo6a/K1om9BDT7ojBTY0Oo30`<1_n9RHT?ooooo`003Oooool7omCDe0Oo_;bl1onTY:@7ohN7Q`Ko
GUiN1om>CTh7oaLG5`Ko?clo1_ooool6ojVYZ@OoY:BT1omeMGD7ooooo`OoO7al1on;Rh/7ojBTY0Ko
CTi>1Oooool7olG5a@OoQ8B41ono_kl7ojNWY`OoOWin1ooNg]h7ogEeM@KoLG5a1Oooool7ohF5Q@Oo
71`L1omOGel7oiZJVPOo4Q8B1_n9RHT7ogEeM@KoKFe]1_ooool7ob/[:`Oo92@T1_l71`L7oa0@40Oo
00001ol410@7o`820PKo7alO1Oooool7o``<30Oo2@T91olC4a<7o`T92@Oo2`/;1olE5AD7o``<30Ko
4A4A1Oooool7og5aL@Oo>CTi1olC4a<7ohR8R0Oo<c<c1omLG5`6ohB4Q0Ko0@411_ooool7oc4a<@Oo
6a/K1on:RXX6oa/K6`OoBDU91onTY:@7o``<30KoRHV93oooool000gooooo1ooDe=@7okbl_0OoY:BT
1on7QhL6oeiNGPOoCTi>1olG5aL6oclo?`Kooooo1_nYZJT7ojBTY0OoMGEe1oooool7ogalO0OoRh^;
1onTY:@6odi>CPGooooo1oo5aLD7ohB4Q0Oo_kno1onWYjL7oginOPOog]kN1omeMGD6og5aL@Gooooo
1on5QHD7oa`L70OoGemO1onJVYX7oa8B4PKoRHV91omeMGD6ofe]K@Kooooo1ol[:b/7ob@T90Ko1`L7
1ol@4107o`0000Oo10@41ol20P86oalO7`Gooooo1ol<30`7o`T92@Oo4a<C1ol92@T7o`/;2`Oo5ADE
1ol<30`6oa4A4@Gooooo1omaLG47ocTi>@Oo4a<C1on8R8P7oc<c<`OoG5aL1_n4Q8@6o`410@Kooooo
1ola<C47oa/K6`OoRXZ:1_lK6a/7odU9B@OoY:BT1ol<30`6ohV9R@oooooo000=ooooo`Ooe=CD1onl
_;`7ojBTY0OoQhN71_mNGUh7odi>CPOo5aLG1_lo?cl6ooooo`KoZJVY1onTY:@7ogEeM@Oooooo1oml
O7`7oh^;R`OoY:BT1_m>CTh5ooooo`OoaLG51on4Q8@7okno_`OoYjNW1omnOWh7omkNgPOoMGEe1_ma
LG45ooooo`OoQHF51olL71`7oemOG`OoVYZJ1olB4Q86ohV9R@OoMGEe1_m]KFd6ooooo`Oo:b/[1olT
92@6o`L71`Oo410@1ol00007o`@410Oo0P821_lO7al5ooooo`Oo30`<1ol92@T7oa<C4`Oo2@T91ol;
2`/7oaDE5@Oo30`<1_lA4A45ooooo`OoLG5a1oli>CT7oa<C4`OoR8R81olc<c<7oeaLG0KoQ8B41_l1
0@46ooooo`Oo<C4a1olK6a/7ohZ:RPKo6a/K1om9BDT7ojBTY0Oo30`<1_n9RHT?ooooo`005?ooool7
onOWi`Ooa<C41oo:b/X6oeYJFPOoJf][1om3@d<6oe9BDPKooooo1_nYZJT7ohF5Q@Oof][J1onSXj<7
oiJFUPOoeMGE1omhN7P6oiVIV@Gooooo1onXZ:P7oi>CT`OoM7Ad1omoOgl7ojJVYPOoRHV91omhN7P6
okno_`Gooooo1ol<30`7oa0@40OoFUYJ1ol10@47ob0P80KoH61P1ol410@6oaHF5PKooooo1oo7alL7
ohb<S0Ko][Jf1onSXj<7ogalO0OoOGem1omdM7@6oiNGU`Gooooo1om3@d<7odM7A`OoL71`1onKVi/7
ooooo`Oob/[:1on4Q8@6od10@0Gooooo1olW9bL7oc0`<0Oo8R8R1ole=CD7oa4A4@Oo2PX:1_lM7Ad6
obd];@Kooooo1ol;2`/7ocLg=`Oo3`l?1_l:2PX7odQ8B0Oo20P81olE5AD6oa`L70oooooo000Doooo
o`OoinOW1oo4a<@7ol[:bPKoFUYJ1om[Jf/7od=3@`KoDU9B1_ooool6ojVYZ@OoQHF51ooJf]X7oj>S
X`OoUYJF1ooEeMD7ogQhN0KoVIVI1Oooool7ojRXZ0OoTi>C1omdM7@7ogmoO`OoYZJV1on9RHT7ogQh
N0Ko_kno1Oooool7o``<30Oo410@1omJFUX7o`410@Oo820P1_mPH607o`@410Ko5QHF1_ooool7olO7
a`OoS8b<1_nf][H7oj>SX`OoO7al1ommOGd7ogAdM0KoUiNG1Oooool7od=3@`OoAdM71om`L707oi^K
V`Oooooo1oo:b/X7ohB4Q0Ko@4101Oooool7obLW9`Oo<30`1olR8R87ocDe=@Oo4A4A1ol:2PX6oadM
7@Ko;Bd]1_ooool7o`/;2`Oo=cLg1ol?3`l6o`X:2POoB4Q81ol820P7oaDE5@Ko71`L3oooool001Co
oooo1ooWinL7olC4a0Oob/[:1_mJFUX7of][J`Oo@d=31_mBDU86ooooo`KoZJVY1on5QHD7om[JfPOo
Xj>S1onFUYH7omGEe@OoN7Qh1_nIVIT5ooooo`OoZ:RX1onCTi<7ogAdM0OoOgmo1onVYZH7ohV9R@Oo
N7Qh1_no_kl5ooooo`Oo30`<1ol@4107oeYJFPOo0@411olP8206of1PH0Oo10@41_lF5QH6ooooo`Oo
alO71on<S8`6okJf]POoXj>S1omlO7`7ogemO@OoM7Ad1_nGUiL5ooooo`Oo@d=31om7AdL7og1`L0Oo
Vi^K1oooool7ol[:bPOoQ8B41_m0@405ooooo`Oo9bLW1ol`<307ob8R8POo=CDe1olA4A47o`X:2PKo
7AdM1_l];Bd6ooooo`Oo2`/;1olg=cL7o`l?3`Ko2PX:1om8B4P7o`P820Oo5ADE1_lL71`?ooooo`00
5?ooool7onOWi`Ooa<C41oo:b/X6oeYJFPOoJf][1om3@d<6oe9BDPKooooo1_nYZJT7ohF5Q@Oof][J
1onSXj<7oiJFUPOoeMGE1omhN7P6oiVIV@Gooooo1onXZ:P7oi>CT`OoM7Ad1omoOgl7ojJVYPOoRHV9
1omhN7P6okno_`Gooooo1ol<30`7oa0@40OoFUYJ1ol10@47ob0P80KoH61P1ol410@6oaHF5PKooooo
1oo7alL7ohb<S0Ko][Jf1onSXj<7ogalO0OoOGem1omdM7@6oiNGU`Gooooo1om3@d<7odM7A`OoL71`
1onKVi/7ooooo`Oob/[:1on4Q8@6od10@0Gooooo1olW9bL7oc0`<0Oo8R8R1ole=CD7oa4A4@Oo2PX:
1_lM7Ad6obd];@Kooooo1ol;2`/7ocLg=`Oo3`l?1_l:2PX7odQ8B0Oo20P81olE5AD6oa`L70oooooo
000Dooooo`OoinOW1oo4a<@7ol[:bPKoFUYJ1om[Jf/7od=3@`KoDU9B1_ooool6ojVYZ@OoQHF51ooJ
f]X7oj>SX`OoUYJF1ooEeMD7ogQhN0KoVIVI1Oooool7ojRXZ0OoTi>C1omdM7@7ogmoO`OoYZJV1on9
RHT7ogQhN0Ko_kno1Oooool7o``<30Oo410@1omJFUX7o`410@Oo820P1_mPH607o`@410Ko5QHF1_oo
ool7olO7a`OoS8b<1_nf][H7oj>SX`OoO7al1ommOGd7ogAdM0KoUiNG1Oooool7od=3@`OoAdM71om`
L707oi^KV`Oooooo1oo:b/X7ohB4Q0Ko@4101Oooool7obLW9`Oo<30`1olR8R87ocDe=@Oo4A4A1ol:
2PX6oadM7@Ko;Bd]1_ooool7o`/;2`Oo=cLg1ol?3`l6o`X:2POoB4Q81ol820P7oaDE5@Ko71`L3ooo
ool001Cooooo1ooWinL7olC4a0Oob/[:1_mJFUX7of][J`Oo@d=31_mBDU86ooooo`KoZJVY1on5QHD7
om[JfPOoXj>S1onFUYH7omGEe@OoN7Qh1_nIVIT5ooooo`OoZ:RX1onCTi<7ogAdM0OoOgmo1onVYZH7
ohV9R@OoN7Qh1_no_kl5ooooo`Oo30`<1ol@4107oeYJFPOo0@411olP8206of1PH0Oo10@41_lF5QH6
ooooo`OoalO71on<S8`6okJf]POoXj>S1omlO7`7ogemO@OoM7Ad1_nGUiL5ooooo`Oo@d=31om7AdL7
og1`L0OoVi^K1oooool7ol[:bPOoQ8B41_m0@405ooooo`Oo9bLW1ol`<307ob8R8POo=CDe1olA4A47
o`X:2PKo7AdM1_l];Bd6ooooo`Oo2`/;1olg=cL7o`l?3`Ko2PX:1om8B4P7o`P820Oo5ADE1_lL71`?
ooooo`005?ooool7onOWi`Ooa<C41oo:b/X6oeYJFPOoJf][1om3@d<6oe9BDPKooooo1_nYZJT7ohF5
Q@Oof][J1onSXj<7oiJFUPOoeMGE1omhN7P6oiVIV@Gooooo1onXZ:P7oi>CT`OoM7Ad1omoOgl7ojJV
YPOoRHV91omhN7P6okno_`Gooooo1ol<30`7oa0@40OoFUYJ1ol10@47ob0P80KoH61P1ol410@6oaHF
5PKooooo1oo7alL7ohb<S0Ko][Jf1onSXj<7ogalO0OoOGem1omdM7@6oiNGU`Gooooo1om3@d<7odM7
A`OoL71`1onKVi/7ooooo`Oob/[:1on4Q8@6od10@0Gooooo1olW9bL7oc0`<0Oo8R8R1ole=CD7oa4A
4@Oo2PX:1_lM7Ad6obd];@Kooooo1ol;2`/7ocLg=`Oo3`l?1_l:2PX7odQ8B0Oo20P81olE5AD6oa`L
70oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo000=ooooo`Oo>c/k1olT92@7ob/[:`Oo8B4Q1_lM7Ad7oc<c<`OoMGEe
1_lU9BD6ooooo`Ko:2PX1olY:BT7oadM7@Oo6a/K1olQ8B47obXZ:POo=CDe1_l^;Rh5ooooo`OoEUIF
1ol`<307oeADE0OoB4Q81olM7Ad7ofi^KPOoBDU91_l820P5ooooo`OoFe]K1oo>c/h7ocPh>0Oo^[Zj
1onXZ:P6ocHf=POoc<c<1_lK6a/6ooooo`Oo8R8R1olO7al6oeUIF@OoQXJ61onh^;P7ol[:bPOog=cL
1_n:RXX5ooooo`Oo;2`/1ol_;bl7ob0P80Oo8B4Q1olF5QH7o`/;2`Oo2@T91_l410@5ooooo`Oo>SXj
1omTI6@7oh>3P`Oo6a/K1onATI47ocXj>PKo6ATI1_mLG5`6ooooo`Oo^;Rh1olI6AT7oo3`l0KoL71`
1olT92@7ooooo`Oo:2PX1_mdM7@?ooooo`003Oooool7oc/k>`Oo92@T1ol[:b/7ob4Q8@Ko7AdM1olc
<c<7ogEeM@Ko9BDU1_ooool6obPX:0Oo:BTY1olM7Ad7oa/K6`Oo8B4Q1olZ:RX7ocDe=@Ko;Rh^1Ooo
ool7oeIFEPOo<30`1omDE5@7odQ8B0Oo7AdM1om^KVh7odU9B@Ko20P81Oooool7oe]KF`Ooc/k>1olh
>3P7okZj^POoZ:RX1_lf=SH7olc<c0Ko6a/K1_ooool7ob8R8POo7alO1_mIFET7ohJ6QPOo^;Rh1oo:
b/X7omcLg0KoRXZ:1Oooool7ob`/;0Oo;bl_1olP8207ob4Q8@Oo5QHF1ol;2`/7o`T92@Ko10@41Ooo
ool7ocXj>POoI6AT1on3Ph<7oa/K6`OoTI6A1olj>SX6oaTI6@KoG5aL1_ooool7okRh^0Oo6ATI1oo`
l?06og1`L0Oo92@T1oooool7obPX:0KoM7Ad3oooool000gooooo1olk>c/7ob@T90Oo:b/[1olQ8B46
oadM7@Oo<c<c1omeMGD6obDU9@Kooooo1_lX:2P7obTY:@Oo7AdM1olK6a/7ob4Q8@Oo:RXZ1ole=CD6
obh^;PGooooo1omFEUH7oc0`<0OoE5AD1om8B4P7oadM7@OoKVi^1om9BDT6o`P820Gooooo1omKFe/7
olk>cPOo>3Ph1onj^[X7ojRXZ0Ko=SHf1oo<c<`6oa/K6`Kooooo1olR8R87oalO7`KoFEUI1on6QXH7
okRh^0Oob/[:1ooLg=`6ohZ:RPGooooo1ol/;2`7obl_;`Oo820P1olQ8B47oaHF5POo2`/;1ol92@T6
o`@410Gooooo1olj>SX7ofATI0OoPh>31olK6a/7oi6AT@Oo>SXj1_lI6AT6oeaLG0Kooooo1onh^;P7
oaTI6@Ool?3`1_m`L707ob@T90Oooooo1olX:2P6ogAdM0oooooo000=ooooo`Oo>c/k1olT92@7ob/[
:`Oo8B4Q1_lM7Ad7oc<c<`OoMGEe1_lU9BD6ooooo`Ko:2PX1olY:BT7oadM7@Oo6a/K1olQ8B47obXZ
:POo=CDe1_l^;Rh5ooooo`OoEUIF1ol`<307oeADE0OoB4Q81olM7Ad7ofi^KPOoBDU91_l820P5oooo
o`OoFe]K1oo>c/h7ocPh>0Oo^[Zj1onXZ:P6ocHf=POoc<c<1_lK6a/6ooooo`Oo8R8R1olO7al6oeUI
F@OoQXJ61onh^;P7ol[:bPOog=cL1_n:RXX5ooooo`Oo;2`/1ol_;bl7ob0P80Oo8B4Q1olF5QH7o`/;
2`Oo2@T91_l410@5ooooo`Oo>SXj1omTI6@7oh>3P`Oo6a/K1onATI47ocXj>PKo6ATI1_mLG5`6oooo
o`Oo^;Rh1olI6AT7oo3`l0KoL71`1olT92@7ooooo`Oo:2PX1_mdM7@?ooooo`003Oooool7oc/k>`Oo
92@T1ol[:b/7ob4Q8@Ko7AdM1olc<c<7ogEeM@Ko9BDU1_ooool6obPX:0Oo:BTY1olM7Ad7oa/K6`Oo
8B4Q1olZ:RX7ocDe=@Ko;Rh^1Oooool7oeIFEPOo<30`1omDE5@7odQ8B0Oo7AdM1om^KVh7odU9B@Ko
20P81Oooool7oe]KF`Ooc/k>1olh>3P7okZj^POoZ:RX1_lf=SH7olc<c0Ko6a/K1_ooool7ob8R8POo
7alO1_mIFET7ohJ6QPOo^;Rh1oo:b/X7omcLg0KoRXZ:1Oooool7ob`/;0Oo;bl_1olP8207ob4Q8@Oo
5QHF1ol;2`/7o`T92@Ko10@41Oooool7ocXj>POoI6AT1on3Ph<7oa/K6`OoTI6A1olj>SX6oaTI6@Ko
G5aL1_ooool7okRh^0Oo6ATI1oo`l?06og1`L0Oo92@T1oooool7obPX:0KoM7Ad3oooool000gooooo
1olk>c/7ob@T90Oo:b/[1olQ8B46oadM7@Oo<c<c1omeMGD6obDU9@Kooooo1_lX:2P7obTY:@Oo7AdM
1olK6a/7ob4Q8@Oo:RXZ1ole=CD6obh^;PGooooo1omFEUH7oc0`<0OoE5AD1om8B4P7oadM7@OoKVi^
1om9BDT6o`P820Gooooo1omKFe/7olk>cPOo>3Ph1onj^[X7ojRXZ0Ko=SHf1oo<c<`6oa/K6`Kooooo
1olR8R87oalO7`KoFEUI1on6QXH7okRh^0Oob/[:1ooLg=`6ohZ:RPGooooo1ol/;2`7obl_;`Oo820P
1olQ8B47oaHF5POo2`/;1ol92@T6o`@410Gooooo1olj>SX7ofATI0OoPh>31olK6a/7oi6AT@Oo>SXj
1_lI6AT6oeaLG0Kooooo1onh^;P7oaTI6@Ool?3`1_m`L707ob@T90Oooooo1olX:2P6ogAdM0oooooo
000=ooooo`Oo>c/k1olT92@7ob/[:`Oo8B4Q1_lM7Ad7oc<c<`OoMGEe1_lU9BD6ooooo`Ko:2PX1olY
:BT7oadM7@Oo6a/K1olQ8B47obXZ:POo=CDe1_l^;Rh5ooooo`OoEUIF1ol`<307oeADE0OoB4Q81olM
7Ad7ofi^KPOoBDU91_l820P5ooooo`OoFe]K1oo>c/h7ocPh>0Oo^[Zj1onXZ:P6ocHf=POoc<c<1_lK
6a/6ooooo`Oo8R8R1olO7al6oeUIF@OoQXJ61onh^;P7ol[:bPOog=cL1_n:RXX5ooooo`Oo;2`/1ol_
;bl7ob0P80Oo8B4Q1olF5QH7o`/;2`Oo2@T91_l410@5ooooo`Oo>SXj1omTI6@7oh>3P`Oo6a/K1onA
TI47ocXj>PKo6ATI1_mLG5`6ooooo`Oo^;Rh1olI6AT7oo3`l0KoL71`1olT92@7ooooo`Oo:2PX1_md
M7@?ooooo`003Oooool7oc8b<POo@D511olE5AD7oc`l?0Ko1PH61om9BDT7oeaLG0Ko3@d=1_ooool6
oc8b<POo;bl_1olT92@7oalO7`Oo7AdM1olC4a<7oaXJ6PKo51@D1Oooool7od10@0Oo2`/;1on=SHd7
oclo?`Oo5ADE1omKFe/7oc/k>`Ko410@1Oooool7og5aL@OoVIVI1ol`<307om?Cd`OoOgmo1_mGEeL7
ooooo`Ko6a/K1_ooool7o`<30`Oo:RXZ1_m9BDT7ochn?POob<S81onOWil7ol30`0KoNGUi1Oooool7
o`h>3POo20P81ol61PH7o`L71`Oo51@D1ol00007o`h>3PKo1@D51Oooool7ob`/;0OoWinO1on8R8P7
o`X:2POoQhN71omTI6@6od92@PKo<30`1_ooool7okbl_0Oo51@D1oo;bl/6oginOPOoLG5a1ooDe=@7
oc0`<0Ko`l?33oooool000gooooo1olb<S87od51@@Oo5ADE1oll?3`6o`H61POoBDU91omLG5`6o`d=
3@Kooooo1_lb<S87obl_;`Oo92@T1olO7al7oadM7@Oo4a<C1olJ6QX6oa@D50Gooooo1om0@407o`/;
2`OoSHf=1olo?cl7oaDE5@OoFe]K1olk>c/6oa0@40Gooooo1omaLG47oiVIV@Oo<30`1ooCdm<7ogmo
O`KoEeMG1oooool6oa/K6`Kooooo1ol30`<7obXZ:PKoBDU91oln?Sh7olS8b0OoWinO1oo0`<06ogUi
N@Gooooo1ol>3Ph7o`P820Oo1PH61ol71`L7oa@D50Oo00001ol>3Ph6o`D51@Gooooo1ol/;2`7oinO
W`OoR8R81ol:2PX7ohN7Q`OoI6AT1_m2@T86oc0`<0Kooooo1onl_;`7oa@D50Oobl_;1_mnOWh7og5a
L@Ooe=CD1ol`<306ol?3``oooooo000=ooooo`Oo<S8b1om1@D47oaDE5@Oo?3`l1_l61PH7odU9B@Oo
G5aL1_l=3@d6ooooo`Ko<S8b1ol_;bl7ob@T90Oo7alO1olM7Ad7oa<C4`Oo6QXJ1_lD51@5ooooo`Oo
@4101ol;2`/7ohf=S@Oo?clo1olE5AD7oe]KF`Oo>c/k1_l@4105ooooo`OoLG5a1onIVIT7oc0`<0Oo
dm?C1omoOgl6oeMGE`Oooooo1_lK6a/6ooooo`Oo0`<31olZ:RX6odU9B@Oo?Shn1oo8b<P7oinOW`Oo
`<301_miNGT5ooooo`Oo3Ph>1ol820P7o`H61POo1`L71olD51@7o`0000Oo3Ph>1_l51@D5ooooo`Oo
;2`/1onOWil7ohR8R0Oo2PX:1on7QhL7ofATI0Ko@T921_l`<306ooooo`Oo_;bl1olD51@7ol_;b`Ko
OWin1omaLG47omCDe0Oo<30`1_o3`l<?ooooo`003Oooool7oc8b<POo@D511olE5AD7oc`l?0Ko1PH6
1om9BDT7oeaLG0Ko3@d=1_ooool6oc8b<POo;bl_1olT92@7oalO7`Oo7AdM1olC4a<7oaXJ6PKo51@D
1Oooool7od10@0Oo2`/;1on=SHd7oclo?`Oo5ADE1omKFe/7oc/k>`Ko410@1Oooool7og5aL@OoVIVI
1ol`<307om?Cd`OoOgmo1_mGEeL7ooooo`Ko6a/K1_ooool7o`<30`Oo:RXZ1_m9BDT7ochn?POob<S8
1onOWil7ol30`0KoNGUi1Oooool7o`h>3POo20P81ol61PH7o`L71`Oo51@D1ol00007o`h>3PKo1@D5
1Oooool7ob`/;0OoWinO1on8R8P7o`X:2POoQhN71omTI6@6od92@PKo<30`1_ooool7okbl_0Oo51@D
1oo;bl/6oginOPOoLG5a1ooDe=@7oc0`<0Ko`l?33oooool000gooooo1olb<S87od51@@Oo5ADE1oll
?3`6o`H61POoBDU91omLG5`6o`d=3@Kooooo1_lb<S87obl_;`Oo92@T1olO7al7oadM7@Oo4a<C1olJ
6QX6oa@D50Gooooo1om0@407o`/;2`OoSHf=1olo?cl7oaDE5@OoFe]K1olk>c/6oa0@40Gooooo1oma
LG47oiVIV@Oo<30`1ooCdm<7ogmoO`KoEeMG1oooool6oa/K6`Kooooo1ol30`<7obXZ:PKoBDU91oln
?Sh7olS8b0OoWinO1oo0`<06ogUiN@Gooooo1ol>3Ph7o`P820Oo1PH61ol71`L7oa@D50Oo00001ol>
3Ph6o`D51@Gooooo1ol/;2`7oinOW`OoR8R81ol:2PX7ohN7Q`OoI6AT1_m2@T86oc0`<0Kooooo1onl
_;`7oa@D50Oobl_;1_mnOWh7og5aL@Ooe=CD1ol`<306ol?3``oooooo000=ooooo`Oo<S8b1om1@D47
oaDE5@Oo?3`l1_l61PH7odU9B@OoG5aL1_l=3@d6ooooo`Ko<S8b1ol_;bl7ob@T90Oo7alO1olM7Ad7
oa<C4`Oo6QXJ1_lD51@5ooooo`Oo@4101ol;2`/7ohf=S@Oo?clo1olE5AD7oe]KF`Oo>c/k1_l@4105
ooooo`OoLG5a1onIVIT7oc0`<0Oodm?C1omoOgl6oeMGE`Oooooo1_lK6a/6ooooo`Oo0`<31olZ:RX6
odU9B@Oo?Shn1oo8b<P7oinOW`Oo`<301_miNGT5ooooo`Oo3Ph>1ol820P7o`H61POo1`L71olD51@7
o`0000Oo3Ph>1_l51@D5ooooo`Oo;2`/1onOWil7ohR8R0Oo2PX:1on7QhL7ofATI0Ko@T921_l`<306
ooooo`Oo_;bl1olD51@7ol_;b`KoOWin1omaLG47omCDe0Oo<30`1_o3`l<?ooooo`003Oooool7oc8b
<POo@D511olE5AD7oc`l?0Ko1PH61om9BDT7oeaLG0Ko3@d=1_ooool6oc8b<POo;bl_1olT92@7oalO
7`Oo7AdM1olC4a<7oaXJ6PKo51@D1Oooool7od10@0Oo2`/;1on=SHd7oclo?`Oo5ADE1omKFe/7oc/k
>`Ko410@1Oooool7og5aL@OoVIVI1ol`<307om?Cd`OoOgmo1_mGEeL7ooooo`Ko6a/K1_ooool7o`<3
0`Oo:RXZ1_m9BDT7ochn?POob<S81onOWil7ol30`0KoNGUi1Oooool7o`h>3POo20P81ol61PH7o`L7
1`Oo51@D1ol00007o`h>3PKo1@D51Oooool7ob`/;0OoWinO1on8R8P7o`X:2POoQhN71omTI6@6od92
@PKo<30`1_ooool7okbl_0Oo51@D1oo;bl/6oginOPOoLG5a1ooDe=@7oc0`<0Ko`l?33oooool000go
oooo1omcLg<7oh20P0Oo=SHf1om/K6`6odM7A`OoMWIf1omjNWX6ocdm?@Kooooo1_lB4Q87oa/K6`Oo
2PX:1olG5aL7o`820POo5ADE1ol?3`l6o`h>3PGooooo1omLG5`7ofIVIPOoRHV91olW9bL7oeIFEPOo
Kfm_1olI6AT6obPX:0Gooooo1omCDe<7odm?C`Oo820P1onDU9@7odm?C`KoEeMG1onk^k/6oa<C4`Ko
oooo1olN7Qh7oa0@40KoG5aL1omWIfL7ojNWY`OoV9RH1ooEeMD6ofe]K@Gooooo1ol820P7o`d=3@Oo
20P81olA4A47o`P820Oo51@D1ol@4106oa<C4`Gooooo1olL71`7og1`L0OoXj>S1olO7al7ojFUY@Oo
=CDe1_m1@D46oeMGE`Kooooo1omdM7@7oaXJ6POo_Kfm1_lg=cL7oeUIF@OogMgM1olB4Q86ohb<S0oo
oooo000=ooooo`OoLg=c1on0P807ocHf=POoK6a/1_m7AdL7ogIfMPOoNWYj1_lm?Cd6ooooo`Ko4Q8B
1olK6a/7o`X:2POo5aLG1ol20P87oaDE5@Oo3`l?1_l>3Ph5ooooo`OoG5aL1omVIVH7ohV9R@Oo9bLW
1omFEUH7ofm_K`Oo6ATI1_lX:2P5ooooo`OoDe=C1om?Cdl7ob0P80OoU9BD1om?Cdl6oeMGE`Oo^k^k
1_lC4a<6ooooo`Oo7QhN1ol@4106oeaLG0OoIfMW1onWYjL7oiRHV0OoeMGE1_m]KFd5ooooo`Oo20P8
1ol=3@d7o`P820Oo4A4A1ol820P7oa@D50Oo410@1_lC4a<5ooooo`Oo71`L1om`L707oj>SX`Oo7alO
1onUYJD7ocDe=@Ko@D511_mGEeL6ooooo`OoM7Ad1olJ6QX7okfm_@Ko=cLg1omIFET7omgMg@Oo4Q8B
1_n<S8`?ooooo`003Oooool7og=cL`OoP8201olf=SH7ofa/K0KoAdM71omfMWH7ogYjNPKo?Cdm1_oo
ool6oa8B4POo6a/K1ol:2PX7oaLG5`Oo0P821olE5AD7o`l?3`Ko3Ph>1Oooool7oeaLG0OoIVIV1on9
RHT7obLW9`OoEUIF1om_Kfl7oaTI6@Ko:2PX1Oooool7oe=CD`OoCdm?1olP8207oiBDU0OoCdm?1_mG
EeL7ok^k^`Ko4a<C1_ooool7oahN7POo410@1_mLG5`7ofMWI`OoYjNW1onHV9P7omGEe@KoKFe]1Ooo
ool7o`P820Oo3@d=1ol820P7oa4A4@Oo20P81olD51@7oa0@40Ko4a<C1Oooool7oa`L70OoL71`1onS
Xj<7oalO7`OoYJFU1ole=CD6od51@@KoEeMG1_ooool7ogAdM0Oo6QXJ1onm_Kd6ocLg=`OoFEUI1ooM
gMd7oa8B4PKoS8b<3oooool000gooooo1omcLg<7oh20P0Oo=SHf1om/K6`6odM7A`OoMWIf1omjNWX6
ocdm?@Kooooo1_lB4Q87oa/K6`Oo2PX:1olG5aL7o`820POo5ADE1ol?3`l6o`h>3PGooooo1omLG5`7
ofIVIPOoRHV91olW9bL7oeIFEPOoKfm_1olI6AT6obPX:0Gooooo1omCDe<7odm?C`Oo820P1onDU9@7
odm?C`KoEeMG1onk^k/6oa<C4`Kooooo1olN7Qh7oa0@40KoG5aL1omWIfL7ojNWY`OoV9RH1ooEeMD6
ofe]K@Gooooo1ol820P7o`d=3@Oo20P81olA4A47o`P820Oo51@D1ol@4106oa<C4`Gooooo1olL71`7
og1`L0OoXj>S1olO7al7ojFUY@Oo=CDe1_m1@D46oeMGE`Kooooo1omdM7@7oaXJ6POo_Kfm1_lg=cL7
oeUIF@OogMgM1olB4Q86ohb<S0oooooo000=ooooo`OoLg=c1on0P807ocHf=POoK6a/1_m7AdL7ogIf
MPOoNWYj1_lm?Cd6ooooo`Ko4Q8B1olK6a/7o`X:2POo5aLG1ol20P87oaDE5@Oo3`l?1_l>3Ph5oooo
o`OoG5aL1omVIVH7ohV9R@Oo9bLW1omFEUH7ofm_K`Oo6ATI1_lX:2P5ooooo`OoDe=C1om?Cdl7ob0P
80OoU9BD1om?Cdl6oeMGE`Oo^k^k1_lC4a<6ooooo`Oo7QhN1ol@4106oeaLG0OoIfMW1onWYjL7oiRH
V0OoeMGE1_m]KFd5ooooo`Oo20P81ol=3@d7o`P820Oo4A4A1ol820P7oa@D50Oo410@1_lC4a<5oooo
o`Oo71`L1om`L707oj>SX`Oo7alO1onUYJD7ocDe=@Ko@D511_mGEeL6ooooo`OoM7Ad1olJ6QX7okfm
_@Ko=cLg1omIFET7omgMg@Oo4Q8B1_n<S8`?ooooo`003Oooool7og=cL`OoP8201olf=SH7ofa/K0Ko
AdM71omfMWH7ogYjNPKo?Cdm1_ooool6oa8B4POo6a/K1ol:2PX7oaLG5`Oo0P821olE5AD7o`l?3`Ko
3Ph>1Oooool7oeaLG0OoIVIV1on9RHT7obLW9`OoEUIF1om_Kfl7oaTI6@Ko:2PX1Oooool7oe=CD`Oo
Cdm?1olP8207oiBDU0OoCdm?1_mGEeL7ok^k^`Ko4a<C1_ooool7oahN7POo410@1_mLG5`7ofMWI`Oo
YjNW1onHV9P7omGEe@KoKFe]1Oooool7o`P820Oo3@d=1ol820P7oa4A4@Oo20P81olD51@7oa0@40Ko
4a<C1Oooool7oa`L70OoL71`1onSXj<7oalO7`OoYJFU1ole=CD6od51@@KoEeMG1_ooool7ogAdM0Oo
6QXJ1onm_Kd6ocLg=`OoFEUI1ooMgMd7oa8B4PKoS8b<3oooool000gooooo1om4A4@7oe]KF`Oo>SXj
1olh>3P6ob8R8POoEUIF1omnOWh6oaLG5`Kooooo3Ol:2PX7o`0000Oo20P81ol410@7o`<30`Oo20P8
1_l>3Ph5ooooo`Oo?clo1omaLG47on?Sh`Oo92@T1omBDU87ohn?S`Oo<30`1_lF5QH5ooooo`Oo>3Ph
1olO7al7oaHF5POoI6AT1olQ8B46odA4A0OoN7Qh1_l00006ooooo`Oo00001olK6a/6oe9BDPOoA4A4
1onTY:@7oi>CT`Oo^KVi1_m_Kfl5ooooo`Oo2PX:1ol<30`7o`h>3POo4Q8B1ol51@D7o`h>3POo4a<C
1_l>3Ph5ooooo`Oo4a<C1oogmoL7ocdm?@Oo4A4A1oooool7oa`L70KoDE5A1_mRHV86ooooo`Oo5ADE
1ol92@T7oifMW@Ko2`/;1om/K6`7oh^;R`Oo2PX:1_ne]KD?ooooo`003Oooool7odA4A0OoFe]K1olj
>SX7ocPh>0Ko8R8R1omFEUH7oginOPKo5aLG1_ooool=o`X:2POo00001ol820P7o`@410Oo0`<31ol8
20P6o`h>3PGooooo1olo?cl7og5aL@Oohn?S1olT92@7oe9BDPOoShn?1ol`<306oaHF5PGooooo1olh
>3P7oalO7`Oo5QHF1omTI6@7ob4Q8@KoA4A41omhN7P6o`0000Kooooo1ol00007oa/K6`KoDU9B1om4
A4@7ojBTY0OoTi>C1oni^KT6ofm_K`Gooooo1ol:2PX7o``<30Oo3Ph>1olB4Q87o`D51@Oo3Ph>1olC
4a<6o`h>3PGooooo1olC4a<7ooOgm`Oo?Cdm1olA4A47ooooo`Oo71`L1_mADE46of9RHPKooooo1olE
5AD7o`T92@OoWIfM1_l;2`/7ofa/K0OoRh^;1ol:2PX6okFe]@oooooo000=ooooo`OoA4A41omKFe/7
ocXj>POo>3Ph1_lR8R87oeIFEPOoOWin1_lG5aL6ooooo`go2PX:1ol00007o`P820Oo10@41ol30`<7
o`P820Ko3Ph>1Oooool7oclo?`OoLG5a1ooShn<7ob@T90OoDU9B1on?Shl7oc0`<0Ko5QHF1Oooool7
ocPh>0Oo7alO1olF5QH7ofATI0Oo8B4Q1_m4A4@7ogQhN0Ko00001_ooool7o`0000Oo6a/K1_mBDU87
odA4A0OoY:BT1onCTi<7okVi^@KoKfm_1Oooool7o`X:2POo30`<1ol>3Ph7oa8B4POo1@D51ol>3Ph7
oa<C4`Ko3Ph>1Oooool7oa<C4`OomoOg1olm?Cd7oa4A4@Oooooo1olL71`6oe5AD@KoHV9R1_ooool7
oaDE5@Oo2@T91onMWId6o`/;2`OoK6a/1on;Rh/7o`X:2PKo]KFe3oooool000gooooo1om4A4@7oe]K
F`Oo>SXj1olh>3P6ob8R8POoEUIF1omnOWh6oaLG5`Kooooo3Ol:2PX7o`0000Oo20P81ol410@7o`<3
0`Oo20P81_l>3Ph5ooooo`Oo?clo1omaLG47on?Sh`Oo92@T1omBDU87ohn?S`Oo<30`1_lF5QH5oooo
o`Oo>3Ph1olO7al7oaHF5POoI6AT1olQ8B46odA4A0OoN7Qh1_l00006ooooo`Oo00001olK6a/6oe9B
DPOoA4A41onTY:@7oi>CT`Oo^KVi1_m_Kfl5ooooo`Oo2PX:1ol<30`7o`h>3POo4Q8B1ol51@D7o`h>
3POo4a<C1_l>3Ph5ooooo`Oo4a<C1oogmoL7ocdm?@Oo4A4A1oooool7oa`L70KoDE5A1_mRHV86oooo
o`Oo5ADE1ol92@T7oifMW@Ko2`/;1om/K6`7oh^;R`Oo2PX:1_ne]KD?ooooo`003Oooool7odA4A0Oo
Fe]K1olj>SX7ocPh>0Ko8R8R1omFEUH7oginOPKo5aLG1_ooool=o`X:2POo00001ol820P7o`@410Oo
0`<31ol820P6o`h>3PGooooo1olo?cl7og5aL@Oohn?S1olT92@7oe9BDPOoShn?1ol`<306oaHF5PGo
oooo1olh>3P7oalO7`Oo5QHF1omTI6@7ob4Q8@KoA4A41omhN7P6o`0000Kooooo1ol00007oa/K6`Ko
DU9B1om4A4@7ojBTY0OoTi>C1oni^KT6ofm_K`Gooooo1ol:2PX7o``<30Oo3Ph>1olB4Q87o`D51@Oo
3Ph>1olC4a<6o`h>3PGooooo1olC4a<7ooOgm`Oo?Cdm1olA4A47ooooo`Oo71`L1_mADE46of9RHPKo
oooo1olE5AD7o`T92@OoWIfM1_l;2`/7ofa/K0OoRh^;1ol:2PX6okFe]@oooooo000=ooooo`OoA4A4
1omKFe/7ocXj>POo>3Ph1_lR8R87oeIFEPOoOWin1_lG5aL6ooooo`go2PX:1ol00007o`P820Oo10@4
1ol30`<7o`P820Ko3Ph>1Oooool7oclo?`OoLG5a1ooShn<7ob@T90OoDU9B1on?Shl7oc0`<0Ko5QHF
1Oooool7ocPh>0Oo7alO1olF5QH7ofATI0Oo8B4Q1_m4A4@7ogQhN0Ko00001_ooool7o`0000Oo6a/K
1_mBDU87odA4A0OoY:BT1onCTi<7okVi^@KoKfm_1Oooool7o`X:2POo30`<1ol>3Ph7oa8B4POo1@D5
1ol>3Ph7oa<C4`Ko3Ph>1Oooool7oa<C4`OomoOg1olm?Cd7oa4A4@Oooooo1olL71`6oe5AD@KoHV9R
1_ooool7oaDE5@Oo2@T91onMWId6o`/;2`OoK6a/1on;Rh/7o`X:2PKo]KFe3oooool000gooooo1om4
A4@7oe]KF`Oo>SXj1olh>3P6ob8R8POoEUIF1omnOWh6oaLG5`Kooooo3Ol:2PX7o`0000Oo20P81ol4
10@7o`<30`Oo20P81_l>3Ph5ooooo`Oo?clo1omaLG47on?Sh`Oo92@T1omBDU87ohn?S`Oo<30`1_lF
5QH5ooooo`Oo>3Ph1olO7al7oaHF5POoI6AT1olQ8B46odA4A0OoN7Qh1_l00006ooooo`Oo00001olK
6a/6oe9BDPOoA4A41onTY:@7oi>CT`Oo^KVi1_m_Kfl5ooooo`Oo2PX:1ol<30`7o`h>3POo4Q8B1ol5
1@D7o`h>3POo4a<C1_l>3Ph5ooooo`Oo4a<C1oogmoL7ocdm?@Oo4A4A1oooool7oa`L70KoDE5A1_mR
HV86ooooo`Oo5ADE1ol92@T7oifMW@Ko2`/;1om/K6`7oh^;R`Oo2PX:1_ne]KD?ooooo`003Oooool7
oh20P0OoOWin1omOGel7oeEEE@KoATI61omjNWX7ofi^KPKo<S8b1_ooool6o`0000Oo410@1ol71`L7
o`/;2`Oo20P81ol;2`/7o``<30Ko4Q8B1Oooool7odI6APOogmoO1oo4a<@7ob0P80Ooi^KV1omNGUh7
oalO7`KoJFUY1Oooool7od10@0Oo5QHF1ol];Bd7oclo?`Oo20P81_m6ATH7oda<C0Ko30`<1_ooool7
oaTI6@Oo7alO1_m@D507ofa/K0Oo[Jf]1onXZ:P7omoOg`KoIfMW1Oooool7o`X:2POo30`<1ol>3Ph7
o``<30ko2@T91ol>3Ph6o`l?3`Gooooo1ol[:b/7ogemO@OoJ6QX1omlO7`7oi6AT@Oo7AdM1_o8b<P6
ob0P80Kooooo1ol@4107oc/k>`Oo=3@d1_l92@T7og=cL`OoCTi>1ol=3@d6ogalO0oooooo000=oooo
o`OoP8201omnOWh7oemOG`OoEEEE1_m6ATH7ogYjNPOoKVi^1_lb<S86ooooo`Ko00001ol@4107o`L7
1`Oo2`/;1ol820P7o`/;2`Oo30`<1_lB4Q85ooooo`OoATI61ooOgml7olC4a0Oo820P1ooVi^H7oeiN
GPOo7alO1_mYJFT5ooooo`Oo@4101olF5QH7obd];@Oo?clo1ol820P6odI6APOoC4a<1_l<30`6oooo
o`Oo6ATI1olO7al6oe1@D0OoK6a/1on][Jd7ojRXZ0OogmoO1_mWIfL5ooooo`Oo2PX:1ol<30`7o`h>
3POo30`<3_l92@T7o`h>3PKo3`l?1Oooool7ob/[:`OoOGem1omXJ6P7ogalO0OoTI6A1olM7Ad6olS8
b0Ko820P1_ooool7oa0@40Oo>c/k1old=3@6o`T92@OoLg=c1om>CTh7o`d=3@KoO7al3oooool000go
oooo1on0P807oginOPOoGemO1omEEED6odI6APOoNWYj1om^KVh6oc8b<PKooooo1_l00007oa0@40Oo
1`L71ol;2`/7o`P820Oo2`/;1ol<30`6oa8B4PGooooo1om6ATH7omoOg`Ooa<C41olP8207onKViPOo
GUiN1olO7al6ofUYJ@Gooooo1om0@407oaHF5POo;Bd]1olo?cl7o`P820KoATI61om<C4`6o``<30Ko
oooo1olI6AT7oalO7`KoD51@1om/K6`7ojf][@OoZ:RX1ooOgml6ofMWI`Gooooo1ol:2PX7o``<30Oo
3Ph>1ol<30`>o`T92@Oo3Ph>1_l?3`l5ooooo`Oo:b/[1ommOGd7ofQXJ0OoO7al1onATI47oadM7@Ko
b<S81_lP8206ooooo`Oo410@1olk>c/7oc@d=0Ko2@T91omcLg<7odi>CPOo3@d=1_mlO7`?ooooo`00
3Oooool7oh20P0OoOWin1omOGel7oeEEE@KoATI61omjNWX7ofi^KPKo<S8b1_ooool6o`0000Oo410@
1ol71`L7o`/;2`Oo20P81ol;2`/7o``<30Ko4Q8B1Oooool7odI6APOogmoO1oo4a<@7ob0P80Ooi^KV
1omNGUh7oalO7`KoJFUY1Oooool7od10@0Oo5QHF1ol];Bd7oclo?`Oo20P81_m6ATH7oda<C0Ko30`<
1_ooool7oaTI6@Oo7alO1_m@D507ofa/K0Oo[Jf]1onXZ:P7omoOg`KoIfMW1Oooool7o`X:2POo30`<
1ol>3Ph7o``<30ko2@T91ol>3Ph6o`l?3`Gooooo1ol[:b/7ogemO@OoJ6QX1omlO7`7oi6AT@Oo7AdM
1_o8b<P6ob0P80Kooooo1ol@4107oc/k>`Oo=3@d1_l92@T7og=cL`OoCTi>1ol=3@d6ogalO0oooooo
000=ooooo`OoP8201omnOWh7oemOG`OoEEEE1_m6ATH7ogYjNPOoKVi^1_lb<S86ooooo`Ko00001ol@
4107o`L71`Oo2`/;1ol820P7o`/;2`Oo30`<1_lB4Q85ooooo`OoATI61ooOgml7olC4a0Oo820P1ooV
i^H7oeiNGPOo7alO1_mYJFT5ooooo`Oo@4101olF5QH7obd];@Oo?clo1ol820P6odI6APOoC4a<1_l<
30`6ooooo`Oo6ATI1olO7al6oe1@D0OoK6a/1on][Jd7ojRXZ0OogmoO1_mWIfL5ooooo`Oo2PX:1ol<
30`7o`h>3POo30`<3_l92@T7o`h>3PKo3`l?1Oooool7ob/[:`OoOGem1omXJ6P7ogalO0OoTI6A1olM
7Ad6olS8b0Ko820P1_ooool7oa0@40Oo>c/k1old=3@6o`T92@OoLg=c1om>CTh7o`d=3@KoO7al3ooo
ool000gooooo1on0P807oginOPOoGemO1omEEED6odI6APOoNWYj1om^KVh6oc8b<PKooooo1_l00007
oa0@40Oo1`L71ol;2`/7o`P820Oo2`/;1ol<30`6oa8B4PGooooo1om6ATH7omoOg`Ooa<C41olP8207
onKViPOoGUiN1olO7al6ofUYJ@Gooooo1om0@407oaHF5POo;Bd]1olo?cl7o`P820KoATI61om<C4`6
o``<30Kooooo1olI6AT7oalO7`KoD51@1om/K6`7ojf][@OoZ:RX1ooOgml6ofMWI`Gooooo1ol:2PX7
o``<30Oo3Ph>1ol<30`>o`T92@Oo3Ph>1_l?3`l5ooooo`Oo:b/[1ommOGd7ofQXJ0OoO7al1onATI47
oadM7@Kob<S81_lP8206ooooo`Oo410@1olk>c/7oc@d=0Ko2@T91omcLg<7odi>CPOo3@d=1_mlO7`?
ooooo`003Oooool7oh20P0OoOWin1omOGel7oeEEE@KoATI61omjNWX7ofi^KPKo<S8b1_ooool6o`00
00Oo410@1ol71`L7o`/;2`Oo20P81ol;2`/7o``<30Ko4Q8B1Oooool7odI6APOogmoO1oo4a<@7ob0P
80Ooi^KV1omNGUh7oalO7`KoJFUY1Oooool7od10@0Oo5QHF1ol];Bd7oclo?`Oo20P81_m6ATH7oda<
C0Ko30`<1_ooool7oaTI6@Oo7alO1_m@D507ofa/K0Oo[Jf]1onXZ:P7omoOg`KoIfMW1Oooool7o`X:
2POo30`<1ol>3Ph7o``<30ko2@T91ol>3Ph6o`l?3`Gooooo1ol[:b/7ogemO@OoJ6QX1omlO7`7oi6A
T@Oo7AdM1_o8b<P6ob0P80Kooooo1ol@4107oc/k>`Oo=3@d1_l92@T7og=cL`OoCTi>1ol=3@d6ogal
O0oooooo000=ooooo`Oo<S8b1omKFe/7oahN7POo;2`/1_lM7Ad7ocDe=@OoFe]K1_l00006ooooo`Ko
4A4A1ol@4107o`h>3POo1PH61ol92@T7o``<30Oo410@1_lF5QH5ooooo`Oo=SHf1ooclo<7olW9b@Oo
=CDe1ooUiND7ofQXJ0OoOWin1_mHF5P5ooooo`Oo>3Ph1olM7Ad7oe=CD`Oo8R8R1ol@4106odY:BPOo
:BTY1_l00006ooooo`Oo00001ol[:b/6oe9BDPOoAdM71oo8b<P7ojJVYPOoi^KV1_mbLW85ooooo`ko
10@41ol=3@d7o`<30`Oo3@d=1ol<30`7o`/;2`Ko3Ph>1Oooool7ob<S8`OoV9RH1olS8b<7odY:BPOo
alO71ol=3@d6ofYZJPKoA4A41_ooool7o`L71`Oo8B4Q1ola<C46o`820POo<c<c1olZ:RX7oadM7@Ko
>CTi3oooool000gooooo1olb<S87oe]KF`Oo7QhN1ol/;2`6oadM7@Oo=CDe1omKFe/6o`0000Kooooo
1_lA4A47oa0@40Oo3Ph>1ol61PH7o`T92@Oo30`<1ol@4106oaHF5PGooooo1olf=SH7oo?cl`OobLW9
1ole=CD7onGUi@OoJ6QX1omnOWh6oeQHF0Gooooo1olh>3P7oadM7@OoDe=C1olR8R87oa0@40KoBTY:
1olY:BT6o`0000Kooooo1ol00007ob/[:`KoDU9B1om7AdL7olS8b0OoYZJV1ooVi^H6og9bLPGooooo
3_l410@7o`d=3@Oo0`<31ol=3@d7o``<30Oo2`/;1_l>3Ph5ooooo`Oo8b<S1onHV9P7ob<S8`OoBTY:
1oo7alL7o`d=3@KoJVYZ1_m4A4@6ooooo`Oo1`L71olQ8B47oc4a<@Ko0P821olc<c<7obXZ:POo7AdM
1_li>CT?ooooo`003Oooool7oc8b<POoFe]K1olN7Qh7ob`/;0Ko7AdM1ole=CD7oe]KF`Ko00001_oo
ool6oa4A4@Oo410@1ol>3Ph7o`H61POo2@T91ol<30`7oa0@40Ko5QHF1Oooool7ocHf=POolo?c1oo9
bLT7ocDe=@OoiNGU1omXJ6P7oginOPKoF5QH1Oooool7ocPh>0Oo7AdM1omCDe<7ob8R8POo410@1_m:
BTX7obTY:@Ko00001_ooool7o`0000Oo:b/[1_mBDU87odM7A`Oob<S81onVYZH7onKViPKoLW9b1Ooo
ool>o`@410Oo3@d=1ol30`<7o`d=3@Oo30`<1ol;2`/6o`h>3PGooooo1olS8b<7oiRHV0Oo8b<S1om:
BTX7olO7a`Oo3@d=1_mZJVX6odA4A0Kooooo1ol71`L7ob4Q8@Oo<C4a1_l20P87oc<c<`Oo:RXZ1olM
7Ad6ocTi>@oooooo000=ooooo`Oo<S8b1omKFe/7oahN7POo;2`/1_lM7Ad7ocDe=@OoFe]K1_l00006
ooooo`Ko4A4A1ol@4107o`h>3POo1PH61ol92@T7o``<30Oo410@1_lF5QH5ooooo`Oo=SHf1ooclo<7
olW9b@Oo=CDe1ooUiND7ofQXJ0OoOWin1_mHF5P5ooooo`Oo>3Ph1olM7Ad7oe=CD`Oo8R8R1ol@4106
odY:BPOo:BTY1_l00006ooooo`Oo00001ol[:b/6oe9BDPOoAdM71oo8b<P7ojJVYPOoi^KV1_mbLW85
ooooo`ko10@41ol=3@d7o`<30`Oo3@d=1ol<30`7o`/;2`Ko3Ph>1Oooool7ob<S8`OoV9RH1olS8b<7
odY:BPOoalO71ol=3@d6ofYZJPKoA4A41_ooool7o`L71`Oo8B4Q1ola<C46o`820POo<c<c1olZ:RX7
oadM7@Ko>CTi3oooool000gooooo1olb<S87oe]KF`Oo7QhN1ol/;2`6oadM7@Oo=CDe1omKFe/6o`00
00Kooooo1_lA4A47oa0@40Oo3Ph>1ol61PH7o`T92@Oo30`<1ol@4106oaHF5PGooooo1olf=SH7oo?c
l`OobLW91ole=CD7onGUi@OoJ6QX1omnOWh6oeQHF0Gooooo1olh>3P7oadM7@OoDe=C1olR8R87oa0@
40KoBTY:1olY:BT6o`0000Kooooo1ol00007ob/[:`KoDU9B1om7AdL7olS8b0OoYZJV1ooVi^H6og9b
LPGooooo3_l410@7o`d=3@Oo0`<31ol=3@d7o``<30Oo2`/;1_l>3Ph5ooooo`Oo8b<S1onHV9P7ob<S
8`OoBTY:1oo7alL7o`d=3@KoJVYZ1_m4A4@6ooooo`Oo1`L71olQ8B47oc4a<@Ko0P821olc<c<7obXZ
:POo7AdM1_li>CT?ooooo`003Oooool7oc8b<POoFe]K1olN7Qh7ob`/;0Ko7AdM1ole=CD7oe]KF`Ko
00001_ooool6oa4A4@Oo410@1ol>3Ph7o`H61POo2@T91ol<30`7oa0@40Ko5QHF1Oooool7ocHf=POo
lo?c1oo9bLT7ocDe=@OoiNGU1omXJ6P7oginOPKoF5QH1Oooool7ocPh>0Oo7AdM1omCDe<7ob8R8POo
410@1_m:BTX7obTY:@Ko00001_ooool7o`0000Oo:b/[1_mBDU87odM7A`Oob<S81onVYZH7onKViPKo
LW9b1Oooool>o`@410Oo3@d=1ol30`<7o`d=3@Oo30`<1ol;2`/6o`h>3PGooooo1olS8b<7oiRHV0Oo
8b<S1om:BTX7olO7a`Oo3@d=1_mZJVX6odA4A0Kooooo1ol71`L7ob4Q8@Oo<C4a1_l20P87oc<c<`Oo
:RXZ1olM7Ad6ocTi>@oooooo000=ooooo`Oo?3`l1om8B4P7o`/;2`Oo820P1_lU9BD7ob`/;0OoIVIV
1_lG5aL6ooooo`Ko5aLG1olE5AD7o`h>3POo410@1olL71`7oa@D50Oo6ATI1_lZ:RX5ooooo`Oo:b/[
1ooZj^X7ok6a/@Oo>CTi1oooool7oeYJFPOoQXJ61_mdM7@5ooooo`OoA4A41om<C4`7ogMgM`Oo4a<C
1olo?cl6oeMGE`Oo51@D1_lH61P6ooooo`Oo9RHV1olJ6QX6ofa/K0OoMGEe1on_[jl7ojb/[0OogMgM
1_mZJVX5ooooo`Oo1PH61olI6AT7o`h>3POo6a/K1ol?3`l7oaDE5@Oo4A4A1_l;2`/5ooooo`Oo=3@d
1omkNg/7oa8B4POoOGem1omSHf<7o`T92@Ko`<301_l71`L6ooooo`Oo9bLW1omNGUh7o`D51@Ko6QXJ
1omEEED7o`0000Oo2@T91_lS8b<?ooooo`003Oooool7oc`l?0OoB4Q81ol;2`/7ob0P80Ko9BDU1ol/
;2`7ofIVIPKo5aLG1_ooool6oaLG5`Oo5ADE1ol>3Ph7oa0@40Oo71`L1olD51@7oaTI6@Ko:RXZ1Ooo
ool7ob/[:`Ooj^[Z1ona/K47ocTi>@Oooooo1omJFUX7ohJ6QPKoM7Ad1Oooool7odA4A0OoC4a<1omg
MgL7oa<C4`Oo?clo1_mGEeL7oa@D50Ko61PH1_ooool7obHV9POo6QXJ1_m/K6`7ogEeM@Oo[jn_1on/
[:`7omgMg@KoJVYZ1Oooool7o`H61POo6ATI1ol>3Ph7oa/K6`Oo3`l?1olE5AD7oa4A4@Ko2`/;1Ooo
ool7oc@d=0OoNg]k1olB4Q87ogemO@OoHf=S1ol92@T6ol30`0Ko1`L71_ooool7obLW9`OoGUiN1ol5
1@D6oaXJ6POoEEEE1ol00007o`T92@Ko8b<S3oooool000gooooo1oll?3`7odQ8B0Oo2`/;1olP8206
obDU9@Oo;2`/1omVIVH6oaLG5`Kooooo1_lG5aL7oaDE5@Oo3Ph>1ol@4107oa`L70Oo51@D1olI6AT6
obXZ:PGooooo1ol[:b/7on[ZjPOo/K6a1oli>CT7ooooo`OoFUYJ1on6QXH6ogAdM0Gooooo1om4A4@7
oda<C0OoMgMg1olC4a<7oclo?`KoEeMG1olD51@6oaPH60Kooooo1olV9RH7oaXJ6PKoK6a/1omeMGD7
ojn_[`Oo[:b/1ooMgMd6ofYZJPGooooo1ol61PH7oaTI6@Oo3Ph>1olK6a/7o`l?3`Oo5ADE1olA4A46
o`/;2`Gooooo1old=3@7og]kN`Oo4Q8B1ommOGd7of=SH`Oo2@T91_o0`<06o`L71`Kooooo1olW9bL7
oeiNGPOo1@D51_lJ6QX7oeEEE@Oo00001ol92@T6ob<S8`oooooo000=ooooo`Oo?3`l1om8B4P7o`/;
2`Oo820P1_lU9BD7ob`/;0OoIVIV1_lG5aL6ooooo`Ko5aLG1olE5AD7o`h>3POo410@1olL71`7oa@D
50Oo6ATI1_lZ:RX5ooooo`Oo:b/[1ooZj^X7ok6a/@Oo>CTi1oooool7oeYJFPOoQXJ61_mdM7@5oooo
o`OoA4A41om<C4`7ogMgM`Oo4a<C1olo?cl6oeMGE`Oo51@D1_lH61P6ooooo`Oo9RHV1olJ6QX6ofa/
K0OoMGEe1on_[jl7ojb/[0OogMgM1_mZJVX5ooooo`Oo1PH61olI6AT7o`h>3POo6a/K1ol?3`l7oaDE
5@Oo4A4A1_l;2`/5ooooo`Oo=3@d1omkNg/7oa8B4POoOGem1omSHf<7o`T92@Ko`<301_l71`L6oooo
o`Oo9bLW1omNGUh7o`D51@Ko6QXJ1omEEED7o`0000Oo2@T91_lS8b<?ooooo`003Oooool7oc`l?0Oo
B4Q81ol;2`/7ob0P80Ko9BDU1ol/;2`7ofIVIPKo5aLG1_ooool6oaLG5`Oo5ADE1ol>3Ph7oa0@40Oo
71`L1olD51@7oaTI6@Ko:RXZ1Oooool7ob/[:`Ooj^[Z1ona/K47ocTi>@Oooooo1omJFUX7ohJ6QPKo
M7Ad1Oooool7odA4A0OoC4a<1omgMgL7oa<C4`Oo?clo1_mGEeL7oa@D50Ko61PH1_ooool7obHV9POo
6QXJ1_m/K6`7ogEeM@Oo[jn_1on/[:`7omgMg@KoJVYZ1Oooool7o`H61POo6ATI1ol>3Ph7oa/K6`Oo
3`l?1olE5AD7oa4A4@Ko2`/;1Oooool7oc@d=0OoNg]k1olB4Q87ogemO@OoHf=S1ol92@T6ol30`0Ko
1`L71_ooool7obLW9`OoGUiN1ol51@D6oaXJ6POoEEEE1ol00007o`T92@Ko8b<S3oooool000gooooo
1oll?3`7odQ8B0Oo2`/;1olP8206obDU9@Oo;2`/1omVIVH6oaLG5`Kooooo1_lG5aL7oaDE5@Oo3Ph>
1ol@4107oa`L70Oo51@D1olI6AT6obXZ:PGooooo1ol[:b/7on[ZjPOo/K6a1oli>CT7ooooo`OoFUYJ
1on6QXH6ogAdM0Gooooo1om4A4@7oda<C0OoMgMg1olC4a<7oclo?`KoEeMG1olD51@6oaPH60Kooooo
1olV9RH7oaXJ6PKoK6a/1omeMGD7ojn_[`Oo[:b/1ooMgMd6ofYZJPGooooo1ol61PH7oaTI6@Oo3Ph>
1olK6a/7o`l?3`Oo5ADE1olA4A46o`/;2`Gooooo1old=3@7og]kN`Oo4Q8B1ommOGd7of=SH`Oo2@T9
1_o0`<06o`L71`Kooooo1olW9bL7oeiNGPOo1@D51_lJ6QX7oeEEE@Oo00001ol92@T6ob<S8`oooooo
000=ooooo`Oo?3`l1om8B4P7o`/;2`Oo820P1_lU9BD7ob`/;0OoIVIV1_lG5aL6ooooo`Ko5aLG1olE
5AD7o`h>3POo410@1olL71`7oa@D50Oo6ATI1_lZ:RX5ooooo`Oo:b/[1ooZj^X7ok6a/@Oo>CTi1ooo
ool7oeYJFPOoQXJ61_mdM7@5ooooo`OoA4A41om<C4`7ogMgM`Oo4a<C1olo?cl6oeMGE`Oo51@D1_lH
61P6ooooo`Oo9RHV1olJ6QX6ofa/K0OoMGEe1on_[jl7ojb/[0OogMgM1_mZJVX5ooooo`Oo1PH61olI
6AT7o`h>3POo6a/K1ol?3`l7oaDE5@Oo4A4A1_l;2`/5ooooo`Oo=3@d1omkNg/7oa8B4POoOGem1omS
Hf<7o`T92@Ko`<301_l71`L6ooooo`Oo9bLW1omNGUh7o`D51@Ko6QXJ1omEEED7o`0000Oo2@T91_lS
8b<?ooooo`003Oooool7oiNGU`Oooooo1on@T907olk>cPKoPH611oo0`<07ooKfmPKobLW91_ooool6
odU9B@Oo@4103_m>CTh7odA4A0OoN7Qh1oooool6olK6aPGooooo1olj>SX7oc<c<`Oo92@T1omoOgl7
ob`/;0Oo:b/[1onTY:@6o`0000Gooooo1ol/;2`7oh61P@Oo>3Ph1omIFET7oginOPKo9BDU1omKFe/6
oa4A4@Kooooo1olg=cL7ocDe=@KoLG5a1omYJFT7ooooo`Oof=SH1oo;bl/6ojVYZ@Gooooo1ooOgml7
ooooo`Oo`L711on?Shl7oe9BDPOo?Shn1old=3@6oc`l?0Gooooo1olZ:RX7obPX:0OoADE51ol30`<7
oaXJ6POoHF5Q1_lM7Ad6o`0000Kooooo1onUYJD7oa4A4@Oo@4101_mZJVX7ob8R8POo?3`l1oln?Sh6
oalO7`oooooo000=ooooo`OoUiNG1oooool7oi2@T0Ooc/k>1_n1PH47ol30`0Oom_Kf1_o9bLT6oooo
o`KoBDU91om0@40>odi>CPOoA4A41omhN7P7ooooo`Koa/K61Oooool7ocXj>POo<c<c1olT92@7ogmo
O`Oo;2`/1ol[:b/7ojBTY0Ko00001Oooool7ob`/;0OoPH611olh>3P7oeUIF@OoOWin1_lU9BD7oe]K
F`Ko4A4A1_ooool7ocLg=`Oo=CDe1_maLG47ofUYJ@Oooooo1ooHf=P7ol_;b`KoZJVY1Oooool7omoO
g`Oooooo1oo1`L47ohn?S`OoDU9B1oln?Sh7oc@d=0Ko?3`l1Oooool7obXZ:POo:2PX1om5ADD7o`<3
0`Oo6QXJ1omQHF46oadM7@Ko00001_ooool7ojFUY@Oo4A4A1om0@406ofYZJPOo8R8R1oll?3`7ochn
?PKo7alO3oooool000gooooo1onGUiL7ooooo`OoT92@1oo>c/h6oh61P@Oo`<301oofm_H6olW9b@Ko
oooo1_m9BDT7od10@0koCTi>1om4A4@7ogQhN0Oooooo1_o6a/H5ooooo`Oo>SXj1olc<c<7ob@T90Oo
Ogmo1ol/;2`7ob/[:`OoY:BT1_l00005ooooo`Oo;2`/1on1PH47ocPh>0OoFEUI1omnOWh6obDU9@Oo
Fe]K1_lA4A46ooooo`Oo=cLg1ole=CD6og5aL@OoJFUY1oooool7omSHf0Oobl_;1_nYZJT5ooooo`Oo
gmoO1oooool7ol71`@OoShn?1omBDU87ochn?POo=3@d1_ll?3`5ooooo`Oo:RXZ1olX:2P7odE5A@Oo
0`<31olJ6QX7of5QH@Ko7AdM1_l00006ooooo`OoYJFU1olA4A47od10@0KoJVYZ1olR8R87oc`l?0Oo
?Shn1_lO7al?ooooo`003Oooool7oiNGU`Oooooo1on@T907olk>cPKoPH611oo0`<07ooKfmPKobLW9
1_ooool6odU9B@Oo@4103_m>CTh7odA4A0OoN7Qh1oooool6olK6aPGooooo1olj>SX7oc<c<`Oo92@T
1omoOgl7ob`/;0Oo:b/[1onTY:@6o`0000Gooooo1ol/;2`7oh61P@Oo>3Ph1omIFET7oginOPKo9BDU
1omKFe/6oa4A4@Kooooo1olg=cL7ocDe=@KoLG5a1omYJFT7ooooo`Oof=SH1oo;bl/6ojVYZ@Gooooo
1ooOgml7ooooo`Oo`L711on?Shl7oe9BDPOo?Shn1old=3@6oc`l?0Gooooo1olZ:RX7obPX:0OoADE5
1ol30`<7oaXJ6POoHF5Q1_lM7Ad6o`0000Kooooo1onUYJD7oa4A4@Oo@4101_mZJVX7ob8R8POo?3`l
1oln?Sh6oalO7`oooooo000=ooooo`OoUiNG1oooool7oi2@T0Ooc/k>1_n1PH47ol30`0Oom_Kf1_o9
bLT6ooooo`KoBDU91om0@40>odi>CPOoA4A41omhN7P7ooooo`Koa/K61Oooool7ocXj>POo<c<c1olT
92@7ogmoO`Oo;2`/1ol[:b/7ojBTY0Ko00001Oooool7ob`/;0OoPH611olh>3P7oeUIF@OoOWin1_lU
9BD7oe]KF`Ko4A4A1_ooool7ocLg=`Oo=CDe1_maLG47ofUYJ@Oooooo1ooHf=P7ol_;b`KoZJVY1Ooo
ool7omoOg`Oooooo1oo1`L47ohn?S`OoDU9B1oln?Sh7oc@d=0Ko?3`l1Oooool7obXZ:POo:2PX1om5
ADD7o`<30`Oo6QXJ1omQHF46oadM7@Ko00001_ooool7ojFUY@Oo4A4A1om0@406ofYZJPOo8R8R1oll
?3`7ochn?PKo7alO3oooool000gooooo1onGUiL7ooooo`OoT92@1oo>c/h6oh61P@Oo`<301oofm_H6
olW9b@Kooooo1_m9BDT7od10@0koCTi>1om4A4@7ogQhN0Oooooo1_o6a/H5ooooo`Oo>SXj1olc<c<7
ob@T90OoOgmo1ol/;2`7ob/[:`OoY:BT1_l00005ooooo`Oo;2`/1on1PH47ocPh>0OoFEUI1omnOWh6
obDU9@OoFe]K1_lA4A46ooooo`Oo=cLg1ole=CD6og5aL@OoJFUY1oooool7omSHf0Oobl_;1_nYZJT5
ooooo`OogmoO1oooool7ol71`@OoShn?1omBDU87ochn?POo=3@d1_ll?3`5ooooo`Oo:RXZ1olX:2P7
odE5A@Oo0`<31olJ6QX7of5QH@Ko7AdM1_l00006ooooo`OoYJFU1olA4A47od10@0KoJVYZ1olR8R87
oc`l?0Oo?Shn1_lO7al?ooooo`003Oooool7oiNGU`Oooooo1on@T907olk>cPKoPH611oo0`<07ooKf
mPKobLW91_ooool6odU9B@Oo@4103_m>CTh7odA4A0OoN7Qh1oooool6olK6aPGooooo1olj>SX7oc<c
<`Oo92@T1omoOgl7ob`/;0Oo:b/[1onTY:@6o`0000Gooooo1ol/;2`7oh61P@Oo>3Ph1omIFET7ogin
OPKo9BDU1omKFe/6oa4A4@Kooooo1olg=cL7ocDe=@KoLG5a1omYJFT7ooooo`Oof=SH1oo;bl/6ojVY
Z@Gooooo1ooOgml7ooooo`Oo`L711on?Shl7oe9BDPOo?Shn1old=3@6oc`l?0Gooooo1olZ:RX7obPX
:0OoADE51ol30`<7oaXJ6POoHF5Q1_lM7Ad6o`0000Kooooo1onUYJD7oa4A4@Oo@4101_mZJVX7ob8R
8POo?3`l1oln?Sh6oalO7`oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo0000
\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-1.97241, \
-0.428616, 0.147467, 0.147467}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-10.7743, -0.428616, 0.147467, 0.147467}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-19.5537, -0.423519, 0.147297, 0.147297}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-28.3874, -0.428616, 0.147467, 0.147467}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-37.1894, -0.428616, 0.147467, 0.147467}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-45.9384, -0.423519, 0.147297, \
0.147297}, {{371.625, 425.875}, {116.812, 62.5}} -> {-54.8024, -0.428616, \
0.147467, 0.147467}, {{431.312, 485.562}, {116.812, 62.5}} -> {-63.6044, \
-0.428616, 0.147467, 0.147467}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-1.97241, -9.23055, 0.147467, 0.147467}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-10.7743, -9.23055, 0.147467, 0.147467}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-19.5537, -9.21532, 0.147297, 0.147297}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-28.3874, -9.23055, 0.147467, 0.147467}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-37.1894, -9.23055, 0.147467, \
0.147467}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-45.9384, -9.21532, \
0.147297, 0.147297}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-54.8024, \
-9.23055, 0.147467, 0.147467}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-63.6044, -9.23055, 0.147467, 0.147467}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
24282F3E77E6D7C9
181A284268E8E3C1
10081F4270F6E5C8
13091F456CFFFDBD
0C00164D6CF4F2BD
14171D4975EDFEC1
1E0A21516BE7E9C1
271E2D4B74C1DFB7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A08B4812164B771A
DE824B0A1D387223
BD7F320125667222
FF67240A2D4E7243
D2641D0037807038
FE430B1C3B616A6A
C2411413528D6351
D92A092F43575989
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
391046E9832B199B
251444DC7A210355
2F1767FF610B1A88
162659ED5B080D3A
24357BF24000296F
1B3A79DE3D022F24
2C578BCC230B3A51
224882A92A02401E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
21241136054CD346
1825102B0162E75C
122602330765F84D
0F1C132B0380FF57
0923002D1990FC41
0A15142B129DEA52
071B092C2FA3D537
0007132B1E98B839
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
251E2219100212CD
180B140F0F0710DB
1E1526160F0015FF
1106111918050FF1
1B0C221A180014FF
13080D1817030DCF
1C0D161A1F0A11D3
0D02071313020A99
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D24C78521742838
0E28D97210651922
1726F17E1381112E
0532F45D096A0F1C
0F3AFF5E0F6E0029
0647F5430A600F1D
1454E83C14560526
0A4CC52702480A1A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5718042A78804D66
7E221E86795E28E4
3E0809458F823263
68083B9873451AFF
26001E6995722068
43065D99682D14FB
14063F80884B1E65
39207498491D12EB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DE608410601E9460
F84A8F0C6723AA62
FA4F9413791BA57F
FF359F127420BB89
F33A96157E16AFA4
E62994106E1CB39F
D1317D15671491B2
B41762004D108A95
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4D37759ADE58CDD9
0F1527A7DB6DA6C7
03071E8CBF0EA8B2
003014A4C44D8EBC
05133F8CAD34AD82
012827B4FF5195C7
29204490F361CF97
154642B4C97DA8F3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
35D757252D24003A
37E8451A2415043A
44FA4C2224160032
44FF390E200C0135
56F43E2423100937
53FB310E280A0C2C
64DD34292314173A
56D3291026111529
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
274ED4712F2B1736
2062E4732D280A30
1D58FB712B2B112B
1769FF6B252F0023
2958FD66292B0D22
196CFF5E1F35051E
3464EC6225312527
2568CD4B1B370F2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
916E28295FBF519F
66420D007AF97B55
8947144167CC45C9
5231020DAAFF5552
7A2819577DBB31E3
3E25012EC9E42E53
6416316487952CDE
221E033CCDBA223A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
935B2728181F2FE8
8F6A2725131134E5
A26D221C091327D5
99722520030929DE
9D7D2A1E070D20E1
9E702821001228F9
9276361F110F29FF
896F272D142728EF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3EA4E79F2B298F5C
2BA6FF821E35AC3E
56CEDD651533B83D
4FCEF7520051D82D
78EFC536144BD22F
7BE9D0260778ED33
94F49818306FD342
8ED6A41D2396E456
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
201E2C23DB311E33
280E101ADB220F15
20131B20FF200F14
22100A23F4150805
170F1827F118110F
19060C37E7130907
1D0D1E43C6131514
14001337AE100905
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36492C79E574350C
34502984F35A2905
35582E95FF662F04
365A2897FC462103
3B6534A6F84D2702
3F5F2DA9DE331E00
3F663CB0CF3C2808
3C552FA1B0251503
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool7ob@T90Oo:2PX1ol_
;bl7ochn?PKoMgMg1ooVi^H7omOGe`KobLW91_ooool6oj2PX0OoRh^;1om8B4P7oa8B4POo5QHF1om;
Bd/7ogMgM`Ko6QXJ1Oooool7ocTi>@Oo410@1om6ATH7onWYj@OoPh>31ol[:b/7oaTI6@KoVi^K1Ooo
ool7ob4Q8@Oo92@T1olA4A47ocHf=POo1@D51_m<C4`7om?Cd`KoATI61_ooool7obDU9@Oo7QhN1_lR
8R87oaTI6@Oo410@1ol20P87oa8B4PKocLg=1Oooool7oadM7@Oo92@T1oo7alL7ohF5Q@Oo8B4Q1omd
M7@7obPX:0Ko>3Ph1Oooool7oeMGE`Oo61PH1ol410@7obXZ:POoN7Qh1on0P806ode=C@KoIVIV1_oo
ool7omkNgPOoH61P1on4Q8@6oa0@40OoH61P1olN7Qh7oiBDU0KoH61P3oooool000gooooo1olT92@7
obPX:0Oo;bl_1oln?Sh6ogMgM`Ooi^KV1ooGemL6olW9b@Kooooo1_nPX:07oh^;R`OoB4Q81olB4Q87
oaHF5POoBd];1omgMgL6oaXJ6PGooooo1oli>CT7oa0@40OoATI61ooYjNT7oh>3P`Oo:b/[1olI6AT6
oi^KV`Gooooo1olQ8B47ob@T90Oo4A4A1olf=SH7o`D51@KoC4a<1ooCdm<6odI6APKooooo1olU9BD7
oahN7PKo8R8R1olI6AT7oa0@40Oo0P821olB4Q86olg=c@Gooooo1olM7Ad7ob@T90OoalO71on5QHD7
ob4Q8@OoM7Ad1olX:2P6ocPh>0Gooooo1omGEeL7oaPH60Oo10@41olZ:RX7ogQhN0OoP8201_m=CDd6
ofIVIPKooooo1ooNg]h7of1PH0OoQ8B41_l@4107of1PH0Oo7QhN1onDU9@6of1PH0oooooo000=oooo
o`Oo92@T1olX:2P7obl_;`Oo?Shn1_mgMgL7onKViPOoemOG1_o9bLT6ooooo`KoX:2P1on;Rh/7odQ8
B0Oo4Q8B1olF5QH7od];B`OoMgMg1_lJ6QX5ooooo`Oo>CTi1ol@4107odI6APOojNWY1on3Ph<7ob/[
:`Oo6ATI1_nKVi/5ooooo`Oo8B4Q1olT92@7oa4A4@Oo=SHf1ol51@D6oda<C0Oodm?C1_m6ATH6oooo
o`Oo9BDU1olN7Qh6ob8R8POo6ATI1ol@4107o`820POo4Q8B1_o=cLd5ooooo`Oo7AdM1olT92@7olO7
a`OoQHF51olQ8B47ogAdM0Oo:2PX1_lh>3P5ooooo`OoEeMG1olH61P7o`@410Oo:RXZ1omhN7P7oh20
P0KoCDe=1_mVIVH6ooooo`Oog]kN1omPH607ohB4Q0Ko410@1omPH607oahN7POoU9BD1_mPH60?oooo
o`003Oooool7ob@T90Oo:2PX1ol_;bl7ochn?PKoMgMg1ooVi^H7omOGe`KobLW91_ooool6oj2PX0Oo
Rh^;1om8B4P7oa8B4POo5QHF1om;Bd/7ogMgM`Ko6QXJ1Oooool7ocTi>@Oo410@1om6ATH7onWYj@Oo
Ph>31ol[:b/7oaTI6@KoVi^K1Oooool7ob4Q8@Oo92@T1olA4A47ocHf=POo1@D51_m<C4`7om?Cd`Ko
ATI61_ooool7obDU9@Oo7QhN1_lR8R87oaTI6@Oo410@1ol20P87oa8B4PKocLg=1Oooool7oadM7@Oo
92@T1oo7alL7ohF5Q@Oo8B4Q1omdM7@7obPX:0Ko>3Ph1Oooool7oeMGE`Oo61PH1ol410@7obXZ:POo
N7Qh1on0P806ode=C@KoIVIV1_ooool7omkNgPOoH61P1on4Q8@6oa0@40OoH61P1olN7Qh7oiBDU0Ko
H61P3oooool000gooooo1olT92@7obPX:0Oo;bl_1oln?Sh6ogMgM`Ooi^KV1ooGemL6olW9b@Kooooo
1_nPX:07oh^;R`OoB4Q81olB4Q87oaHF5POoBd];1omgMgL6oaXJ6PGooooo1oli>CT7oa0@40OoATI6
1ooYjNT7oh>3P`Oo:b/[1olI6AT6oi^KV`Gooooo1olQ8B47ob@T90Oo4A4A1olf=SH7o`D51@KoC4a<
1ooCdm<6odI6APKooooo1olU9BD7oahN7PKo8R8R1olI6AT7oa0@40Oo0P821olB4Q86olg=c@Gooooo
1olM7Ad7ob@T90OoalO71on5QHD7ob4Q8@OoM7Ad1olX:2P6ocPh>0Gooooo1omGEeL7oaPH60Oo10@4
1olZ:RX7ogQhN0OoP8201_m=CDd6ofIVIPKooooo1ooNg]h7of1PH0OoQ8B41_l@4107of1PH0Oo7QhN
1onDU9@6of1PH0oooooo000=ooooo`Oo92@T1olX:2P7obl_;`Oo?Shn1_mgMgL7onKViPOoemOG1_o9
bLT6ooooo`KoX:2P1on;Rh/7odQ8B0Oo4Q8B1olF5QH7od];B`OoMgMg1_lJ6QX5ooooo`Oo>CTi1ol@
4107odI6APOojNWY1on3Ph<7ob/[:`Oo6ATI1_nKVi/5ooooo`Oo8B4Q1olT92@7oa4A4@Oo=SHf1ol5
1@D6oda<C0Oodm?C1_m6ATH6ooooo`Oo9BDU1olN7Qh6ob8R8POo6ATI1ol@4107o`820POo4Q8B1_o=
cLd5ooooo`Oo7AdM1olT92@7olO7a`OoQHF51olQ8B47ogAdM0Oo:2PX1_lh>3P5ooooo`OoEeMG1olH
61P7o`@410Oo:RXZ1omhN7P7oh20P0KoCDe=1_mVIVH6ooooo`Oog]kN1omPH607ohB4Q0Ko410@1omP
H607oahN7POoU9BD1_mPH60?ooooo`003Oooool7oaPH60Oo6QXJ1olX:2P7od92@PKoJ6QX1ooXj>P7
on?Sh`Ko`L711_ooool6omkNgPOoPX:21om;Bd/7o`X:2POo7AdM1olh>3P7og9bLPKo8b<S1Oooool7
obDU9@Oo51@D1om4A4@7omcLg0OoNWYj1olQ8B47o`<30`KoEEEE1Oooool7oaPH60Oo9BDU1ol@4107
ob/[:`Oo0@411_mRHV87onOWi`KoG5aL1_ooool7oaPH60Oo2`/;1_lD51@>o`l?3`Oo1`L71ol@4106
om_Kf`Gooooo1ol>3Ph7obPX:0OofMWI1ombLW87oa0@40OoIFEU1olI6AT6ob8R8PGooooo1omnOWh7
ob8R8POo7QhN1on6QXH7ogUiN@OoGUiN1_lX:2P6onCTi0Kooooo1oohn?P7odY:BPOoShn?1_l<30`7
ofMWI`Oo8b<S1onZZZX6of9RHPoooooo000=ooooo`Oo61PH1olJ6QX7obPX:0Oo@T921_mXJ6P7onSX
j0Oohn?S1_o1`L46ooooo`Kog]kN1on2PX87od];B`Oo2PX:1olM7Ad7ocPh>0OoLW9b1_lS8b<5oooo
o`Oo9BDU1olD51@7odA4A0Oog=cL1omjNWX7ob4Q8@Oo0`<31_mEEED5ooooo`Oo61PH1olU9BD7oa0@
40Oo:b/[1ol10@46of9RHPOoinOW1_mLG5`6ooooo`Oo61PH1ol;2`/6oa@D50ko3`l?1ol71`L7oa0@
40Kofm_K1Oooool7o`h>3POo:2PX1ooIfMT7og9bLPOo410@1omUIFD7oaTI6@Ko8R8R1Oooool7ogin
OPOo8R8R1olN7Qh7ohJ6QPOoNGUi1omNGUh6obPX:0Koi>CT1_ooool7ooShn0OoBTY:1on?Shl6o``<
30OoIfMW1olS8b<7ojZZZPKoHV9R3oooool000gooooo1olH61P7oaXJ6POo:2PX1om2@T86ofQXJ0Oo
j>SX1ooShn<6ol71`@Kooooo1_oNg]h7oh:2PPOoBd];1ol:2PX7oadM7@Oo>3Ph1ombLW86ob<S8`Go
oooo1olU9BD7oa@D50OoA4A41ooLg=`7ogYjNPOo8B4Q1ol30`<6oeEEE@Gooooo1olH61P7obDU9@Oo
410@1ol[:b/7o`410@KoHV9R1ooWinL6oeaLG0Kooooo1olH61P7o`/;2`Ko51@D3_l?3`l7o`L71`Oo
410@1_oKfm/5ooooo`Oo3Ph>1olX:2P7omWIf@OoLW9b1ol@4107ofEUI@Oo6ATI1_lR8R85ooooo`Oo
OWin1olR8R87oahN7POoQXJ61omiNGT7oeiNGPKo:2PX1_oTi>@6ooooo`Oon?Sh1om:BTX7ohn?S`Ko
30`<1omWIfL7ob<S8`OoZZZZ1_mRHV8?ooooo`003Oooool7oaPH60Oo6QXJ1olX:2P7od92@PKoJ6QX
1ooXj>P7on?Sh`Ko`L711_ooool6omkNgPOoPX:21om;Bd/7o`X:2POo7AdM1olh>3P7og9bLPKo8b<S
1Oooool7obDU9@Oo51@D1om4A4@7omcLg0OoNWYj1olQ8B47o`<30`KoEEEE1Oooool7oaPH60Oo9BDU
1ol@4107ob/[:`Oo0@411_mRHV87onOWi`KoG5aL1_ooool7oaPH60Oo2`/;1_lD51@>o`l?3`Oo1`L7
1ol@4106om_Kf`Gooooo1ol>3Ph7obPX:0OofMWI1ombLW87oa0@40OoIFEU1olI6AT6ob8R8PGooooo
1omnOWh7ob8R8POo7QhN1on6QXH7ogUiN@OoGUiN1_lX:2P6onCTi0Kooooo1oohn?P7odY:BPOoShn?
1_l<30`7ofMWI`Oo8b<S1onZZZX6of9RHPoooooo000=ooooo`Oo61PH1olJ6QX7obPX:0Oo@T921_mX
J6P7onSXj0Oohn?S1_o1`L46ooooo`Kog]kN1on2PX87od];B`Oo2PX:1olM7Ad7ocPh>0OoLW9b1_lS
8b<5ooooo`Oo9BDU1olD51@7odA4A0Oog=cL1omjNWX7ob4Q8@Oo0`<31_mEEED5ooooo`Oo61PH1olU
9BD7oa0@40Oo:b/[1ol10@46of9RHPOoinOW1_mLG5`6ooooo`Oo61PH1ol;2`/6oa@D50ko3`l?1ol7
1`L7oa0@40Kofm_K1Oooool7o`h>3POo:2PX1ooIfMT7og9bLPOo410@1omUIFD7oaTI6@Ko8R8R1Ooo
ool7oginOPOo8R8R1olN7Qh7ohJ6QPOoNGUi1omNGUh6obPX:0Koi>CT1_ooool7ooShn0OoBTY:1on?
Shl6o``<30OoIfMW1olS8b<7ojZZZPKoHV9R3oooool000gooooo1olH61P7oaXJ6POo:2PX1om2@T86
ofQXJ0Ooj>SX1ooShn<6ol71`@Kooooo1_oNg]h7oh:2PPOoBd];1ol:2PX7oadM7@Oo>3Ph1ombLW86
ob<S8`Gooooo1olU9BD7oa@D50OoA4A41ooLg=`7ogYjNPOo8B4Q1ol30`<6oeEEE@Gooooo1olH61P7
obDU9@Oo410@1ol[:b/7o`410@KoHV9R1ooWinL6oeaLG0Kooooo1olH61P7o`/;2`Ko51@D3_l?3`l7
o`L71`Oo410@1_oKfm/5ooooo`Oo3Ph>1olX:2P7omWIf@OoLW9b1ol@4107ofEUI@Oo6ATI1_lR8R85
ooooo`OoOWin1olR8R87oahN7POoQXJ61omiNGT7oeiNGPKo:2PX1_oTi>@6ooooo`Oon?Sh1om:BTX7
ohn?S`Ko30`<1omWIfL7ob<S8`OoZZZZ1_mRHV8?ooooo`003Oooool7oaPH60Oo6QXJ1olX:2P7od92
@PKoJ6QX1ooXj>P7on?Sh`Ko`L711_ooool6omkNgPOoPX:21om;Bd/7o`X:2POo7AdM1olh>3P7og9b
LPKo8b<S1Oooool7obDU9@Oo51@D1om4A4@7omcLg0OoNWYj1olQ8B47o`<30`KoEEEE1Oooool7oaPH
60Oo9BDU1ol@4107ob/[:`Oo0@411_mRHV87onOWi`KoG5aL1_ooool7oaPH60Oo2`/;1_lD51@>o`l?
3`Oo1`L71ol@4106om_Kf`Gooooo1ol>3Ph7obPX:0OofMWI1ombLW87oa0@40OoIFEU1olI6AT6ob8R
8PGooooo1omnOWh7ob8R8POo7QhN1on6QXH7ogUiN@OoGUiN1_lX:2P6onCTi0Kooooo1oohn?P7odY:
BPOoShn?1_l<30`7ofMWI`Oo8b<S1onZZZX6of9RHPoooooo000=ooooo`Oo410@1ol820P7oalO7`Oo
@T921_m`L707ooKfmPOoiNGU1_o8b<P6ooooo`Ko_Kfm1omoOgl7oc8b<POo0@411olU9BD7ofIVIPOo
LW9b1_lR8R85ooooo`Oo;bl_1olG5aL7ofMWI`Oooooo1omQHF47o`/;2`Oo6QXJ1_n8R8P5ooooo`Oo
4Q8B1olV9RH7o`820POo<c<c1ol71`L6ofEUI@Oon?Sh1_m=CDd6ooooo`Oo7QhN1olE5AD6obHV9POo
5QHF1ol?3`l7o`0000Oo5ADE2oooool7oaLG5`Oo9RHV1ooalO47oginOPOo4a<C1on1PH47oa4A4@Ko
;Rh^1Oooool7ochn?POo20P81ol92@T7odE5A@OoShn?1on2PX86oc8b<PKoHf=S1_ooool7oo[jnPOo
Cdm?1onDU9@6oa<C4`OoNGUi1olK6a/7ojFUY@KoOgmo3oooool000gooooo1ol@4107o`P820Oo7alO
1om2@T86og1`L0Oom_Kf1ooUiND6olS8b0Kooooo1_nm_Kd7ogmoO`Oo<S8b1ol10@47obDU9@OoIVIV
1ombLW86ob8R8PGooooo1ol_;bl7oaLG5`OoIfMW1oooool7of5QH@Oo2`/;1olJ6QX6ohR8R0Gooooo
1olB4Q87obHV9POo0P821olc<c<7o`L71`KoIFEU1oohn?P6ode=C@Kooooo1olN7Qh7oaDE5@Ko9RHV
1olF5QH7o`l?3`Oo00001olE5AD;ooooo`Oo5aLG1olV9RH7oo7al@OoOWin1olC4a<7oh61P@Oo4A4A
1_l^;Rh5ooooo`Oo?Shn1ol820P7o`T92@OoADE51on?Shl7oh:2PPKo<S8b1_mSHf<6ooooo`Oon_[j
1om?Cdl7oiBDU0Ko4a<C1omiNGT7oa/K6`OoYJFU1_moOgl?ooooo`003Oooool7oa0@40Oo20P81olO
7al7od92@PKoL71`1oofm_H7onGUi@Kob<S81_ooool6okfm_@OoOgmo1olb<S87o`410@Oo9BDU1omV
IVH7og9bLPKo8R8R1Oooool7obl_;`Oo5aLG1omWIfL7ooooo`OoHF5Q1ol;2`/7oaXJ6PKoR8R81Ooo
ool7oa8B4POo9RHV1ol20P87oc<c<`Oo1`L71_mUIFD7ooShn0KoCDe=1_ooool7oahN7POo5ADE1_lV
9RH7oaHF5POo3`l?1ol00007oaDE5@_ooooo1olG5aL7obHV9POolO7a1omnOWh7oa<C4`OoPH611olA
4A46obh^;PGooooo1oln?Sh7o`P820Oo2@T91om5ADD7ohn?S`OoPX:21_lb<S86of=SH`Kooooo1ooj
n_X7odm?C`OoU9BD1_lC4a<7ogUiN@Oo6a/K1onUYJD6ogmoO`oooooo000=ooooo`Oo410@1ol820P7
oalO7`Oo@T921_m`L707ooKfmPOoiNGU1_o8b<P6ooooo`Ko_Kfm1omoOgl7oc8b<POo0@411olU9BD7
ofIVIPOoLW9b1_lR8R85ooooo`Oo;bl_1olG5aL7ofMWI`Oooooo1omQHF47o`/;2`Oo6QXJ1_n8R8P5
ooooo`Oo4Q8B1olV9RH7o`820POo<c<c1ol71`L6ofEUI@Oon?Sh1_m=CDd6ooooo`Oo7QhN1olE5AD6
obHV9POo5QHF1ol?3`l7o`0000Oo5ADE2oooool7oaLG5`Oo9RHV1ooalO47oginOPOo4a<C1on1PH47
oa4A4@Ko;Rh^1Oooool7ochn?POo20P81ol92@T7odE5A@OoShn?1on2PX86oc8b<PKoHf=S1_ooool7
oo[jnPOoCdm?1onDU9@6oa<C4`OoNGUi1olK6a/7ojFUY@KoOgmo3oooool000gooooo1ol@4107o`P8
20Oo7alO1om2@T86og1`L0Oom_Kf1ooUiND6olS8b0Kooooo1_nm_Kd7ogmoO`Oo<S8b1ol10@47obDU
9@OoIVIV1ombLW86ob8R8PGooooo1ol_;bl7oaLG5`OoIfMW1oooool7of5QH@Oo2`/;1olJ6QX6ohR8
R0Gooooo1olB4Q87obHV9POo0P821olc<c<7o`L71`KoIFEU1oohn?P6ode=C@Kooooo1olN7Qh7oaDE
5@Ko9RHV1olF5QH7o`l?3`Oo00001olE5AD;ooooo`Oo5aLG1olV9RH7oo7al@OoOWin1olC4a<7oh61
P@Oo4A4A1_l^;Rh5ooooo`Oo?Shn1ol820P7o`T92@OoADE51on?Shl7oh:2PPKo<S8b1_mSHf<6oooo
o`Oon_[j1om?Cdl7oiBDU0Ko4a<C1omiNGT7oa/K6`OoYJFU1_moOgl?ooooo`003Oooool7oa0@40Oo
20P81olO7al7od92@PKoL71`1oofm_H7onGUi@Kob<S81_ooool6okfm_@OoOgmo1olb<S87o`410@Oo
9BDU1omVIVH7og9bLPKo8R8R1Oooool7obl_;`Oo5aLG1omWIfL7ooooo`OoHF5Q1ol;2`/7oaXJ6PKo
R8R81Oooool7oa8B4POo9RHV1ol20P87oc<c<`Oo1`L71_mUIFD7ooShn0KoCDe=1_ooool7oahN7POo
5ADE1_lV9RH7oaHF5POo3`l?1ol00007oaDE5@_ooooo1olG5aL7obHV9POolO7a1omnOWh7oa<C4`Oo
PH611olA4A46obh^;PGooooo1oln?Sh7o`P820Oo2@T91om5ADD7ohn?S`OoPX:21_lb<S86of=SH`Ko
oooo1oojn_X7odm?C`OoU9BD1_lC4a<7ogUiN@Oo6a/K1onUYJD6ogmoO`oooooo000=ooooo`Oo410@
1ol820P7oalO7`Oo@T921_m`L707ooKfmPOoiNGU1_o8b<P6ooooo`Ko_Kfm1omoOgl7oc8b<POo0@41
1olU9BD7ofIVIPOoLW9b1_lR8R85ooooo`Oo;bl_1olG5aL7ofMWI`Oooooo1omQHF47o`/;2`Oo6QXJ
1_n8R8P5ooooo`Oo4Q8B1olV9RH7o`820POo<c<c1ol71`L6ofEUI@Oon?Sh1_m=CDd6ooooo`Oo7QhN
1olE5AD6obHV9POo5QHF1ol?3`l7o`0000Oo5ADE2oooool7oaLG5`Oo9RHV1ooalO47oginOPOo4a<C
1on1PH47oa4A4@Ko;Rh^1Oooool7ochn?POo20P81ol92@T7odE5A@OoShn?1on2PX86oc8b<PKoHf=S
1_ooool7oo[jnPOoCdm?1onDU9@6oa<C4`OoNGUi1olK6a/7ojFUY@KoOgmo3oooool000gooooo1olC
4a<7o`T92@Oo7alO1om5ADD6ofa/K0Oooooo1oomoOd6okfm_@cooooo1omWIfL7ob@T90Oo2PX:1ol]
;Bd7odi>CPOoLW9b1_m3@d<5ooooo`Oo5QHF1olV9RH7oeUIF@OokNg]1omKFe/7o`P820Oo3@d=1_lj
>SX5ooooo`Oo3`l?1olL71`7oa<C4`Oo:b/[1ol30`<6oh20P0Oooooo1_mGEeL6ooooo`Oo4A4A1ol6
1PH6oa4A4@Oo6ATI1olH61P7o`D51@Oo3`l?1_oalO45ooooo`Oo1@D51olb<S87ooCdm0OoGEeM1ol9
2@T7ofYZJPOo3`l?1_lL71`5ooooo`OoJ6QX1ol820P7oc/k>`OoV9RH1omcLg<7odE5A@Ko6QXJ4ooo
ool7ocDe=@OoWinO1_lB4Q87ogAdM0Oo820P1onk^k/6ohV9R@oooooo000=ooooo`Oo4a<C1ol92@T7
oalO7`OoADE51_m/K6`7ooooo`OooOgm1_nm_Kd<ooooo`OoIfMW1olT92@7o`X:2POo;Bd]1om>CTh7
og9bLPKo@d=31Oooool7oaHF5POo9RHV1omIFET7ong]k@OoFe]K1ol820P7o`d=3@Ko>SXj1Oooool7
o`l?3`Oo71`L1olC4a<7ob/[:`Oo0`<31_n0P807ooooo`KoEeMG1_ooool7oa4A4@Oo1PH61_lA4A47
oaTI6@Oo61PH1ol51@D7o`l?3`KolO7a1Oooool7o`D51@Oo<S8b1oodm?@7oeeMG@Oo2@T91omZJVX7
o`l?3`Ko71`L1Oooool7ofQXJ0Oo20P81olk>c/7oiRHV0OoLg=c1om5ADD6oaXJ6Q?ooooo1ole=CD7
oinOW`Ko4Q8B1omdM7@7ob0P80Oo^k^k1_n9RHT?ooooo`003Oooool7oa<C4`Oo2@T91olO7al7odE5
A@KoK6a/1oooool7oogmo@Ko_Kfm3?ooool7ofMWI`Oo92@T1ol:2PX7obd];@OoCTi>1ombLW86od=3
@`Gooooo1olF5QH7obHV9POoFEUI1oo]kNd7oe]KF`Oo20P81ol=3@d6ocXj>PGooooo1ol?3`l7oa`L
70Oo4a<C1ol[:b/7o`<30`KoP8201oooool6oeMGE`Kooooo1olA4A47o`H61PKo4A4A1olI6AT7oaPH
60Oo1@D51ol?3`l6oo7al@Gooooo1ol51@D7oc8b<POom?Cd1omMGEd7o`T92@OoJVYZ1ol?3`l6oa`L
70Gooooo1omXJ6P7o`P820Oo>c/k1onHV9P7og=cL`OoADE51_lJ6QXCooooo`Oo=CDe1onOWil6oa8B
4POoM7Ad1olP8207ok^k^`KoRHV93oooool000gooooo1olC4a<7o`T92@Oo7alO1om5ADD6ofa/K0Oo
oooo1oomoOd6okfm_@cooooo1omWIfL7ob@T90Oo2PX:1ol];Bd7odi>CPOoLW9b1_m3@d<5ooooo`Oo
5QHF1olV9RH7oeUIF@OokNg]1omKFe/7o`P820Oo3@d=1_lj>SX5ooooo`Oo3`l?1olL71`7oa<C4`Oo
:b/[1ol30`<6oh20P0Oooooo1_mGEeL6ooooo`Oo4A4A1ol61PH6oa4A4@Oo6ATI1olH61P7o`D51@Oo
3`l?1_oalO45ooooo`Oo1@D51olb<S87ooCdm0OoGEeM1ol92@T7ofYZJPOo3`l?1_lL71`5ooooo`Oo
J6QX1ol820P7oc/k>`OoV9RH1omcLg<7odE5A@Ko6QXJ4oooool7ocDe=@OoWinO1_lB4Q87ogAdM0Oo
820P1onk^k/6ohV9R@oooooo000=ooooo`Oo4a<C1ol92@T7oalO7`OoADE51_m/K6`7ooooo`OooOgm
1_nm_Kd<ooooo`OoIfMW1olT92@7o`X:2POo;Bd]1om>CTh7og9bLPKo@d=31Oooool7oaHF5POo9RHV
1omIFET7ong]k@OoFe]K1ol820P7o`d=3@Ko>SXj1Oooool7o`l?3`Oo71`L1olC4a<7ob/[:`Oo0`<3
1_n0P807ooooo`KoEeMG1_ooool7oa4A4@Oo1PH61_lA4A47oaTI6@Oo61PH1ol51@D7o`l?3`KolO7a
1Oooool7o`D51@Oo<S8b1oodm?@7oeeMG@Oo2@T91omZJVX7o`l?3`Ko71`L1Oooool7ofQXJ0Oo20P8
1olk>c/7oiRHV0OoLg=c1om5ADD6oaXJ6Q?ooooo1ole=CD7oinOW`Ko4Q8B1omdM7@7ob0P80Oo^k^k
1_n9RHT?ooooo`003Oooool7oa<C4`Oo2@T91olO7al7odE5A@KoK6a/1oooool7oogmo@Ko_Kfm3?oo
ool7ofMWI`Oo92@T1ol:2PX7obd];@OoCTi>1ombLW86od=3@`Gooooo1olF5QH7obHV9POoFEUI1oo]
kNd7oe]KF`Oo20P81ol=3@d6ocXj>PGooooo1ol?3`l7oa`L70Oo4a<C1ol[:b/7o`<30`KoP8201ooo
ool6oeMGE`Kooooo1olA4A47o`H61PKo4A4A1olI6AT7oaPH60Oo1@D51ol?3`l6oo7al@Gooooo1ol5
1@D7oc8b<POom?Cd1omMGEd7o`T92@OoJVYZ1ol?3`l6oa`L70Gooooo1omXJ6P7o`P820Oo>c/k1onH
V9P7og=cL`OoADE51_lJ6QXCooooo`Oo=CDe1onOWil6oa8B4POoM7Ad1olP8207ok^k^`KoRHV93ooo
ool000gooooo1ol<30`7o`0000Oo5QHF1om=CDd6ofa/K0Oom?Cd1oobl_86okfm_@Kooooo1_oBd]87
ofATI0Oo7AdM1ol00007ocLg=`OoP8201om`L706ocPh>0Gooooo1olT92@7ocDe=@OoNg]k1oobl_87
od10@0Oo00001olY:BT6ofm_K`Gooooo1ol92@T7ob<S8`Oo00001ol];Bd7oaTI6@KoT92@1oolo?`6
od51@@Kooooo1olK6a/7o``<30Ko8R8R1olJ6QX7oaPH60Oo00001olD51@;ooooo`Oo3`l?1olj>SX7
ooooo`OoGUiN1ol?3`l7ofi^KPOo00001_lY:BT5ooooo`Oo9RHV1ol00007oahN7POoJFUY1onEUID7
og9bLPKo820P1_mXJ6P6ooooo`Oolo?c1olj>SX7oiJFUPKo5ADE1omnOWh7oaHF5POo[jn_1_nTY:@?
ooooo`003Oooool7o``<30Oo00001olF5QH7ode=C@KoK6a/1oodm?@7oo;blPKo_Kfm1_ooool6om;B
dPOoI6AT1olM7Ad7o`0000Oo=cLg1on0P807og1`L0Ko>3Ph1Oooool7ob@T90Oo=CDe1omkNg/7oo;b
lPOo@4101ol00007obTY:@KoKfm_1Oooool7o`T92@Oo8b<S1ol00007obd];@Oo6ATI1_n@T907oocl
o0Ko@D511_ooool7oa/K6`Oo30`<1_lR8R87oaXJ6POo61PH1ol00007oa@D50_ooooo1ol?3`l7ocXj
>POooooo1omNGUh7o`l?3`OoKVi^1ol00006obTY:@Gooooo1olV9RH7o`0000Oo7QhN1omYJFT7oiFE
U@OoLW9b1_lP8206ofQXJ0Kooooo1ooclo<7ocXj>POoUYJF1_lE5AD7oginOPOo5QHF1on_[jl6ojBT
Y0oooooo000=ooooo`Oo30`<1ol00007oaHF5POoCDe=1_m/K6`7ooCdm0Ool_;b1_nm_Kd6ooooo`Ko
d];B1omTI6@7oadM7@Oo00001olg=cL7oh20P0OoL71`1_lh>3P5ooooo`Oo92@T1ole=CD7og]kN`Oo
l_;b1om0@407o`0000Oo:BTY1_m_Kfl5ooooo`Oo2@T91olS8b<7o`0000Oo;Bd]1olI6AT6oi2@T0Oo
o?cl1_m1@D46ooooo`Oo6a/K1ol<30`6ob8R8POo6QXJ1olH61P7o`0000Oo51@D2oooool7o`l?3`Oo
>SXj1oooool7oeiNGPOo3`l?1om^KVh7o`0000Ko:BTY1Oooool7obHV9POo00001olN7Qh7ofUYJ@Oo
UIFE1ombLW86ob0P80KoJ6QX1_ooool7oo?cl`Oo>SXj1onFUYH6oaDE5@OoOWin1olF5QH7ojn_[`Ko
Y:BT3oooool000gooooo1ol<30`7o`0000Oo5QHF1om=CDd6ofa/K0Oom?Cd1oobl_86okfm_@Kooooo
1_oBd]87ofATI0Oo7AdM1ol00007ocLg=`OoP8201om`L706ocPh>0Gooooo1olT92@7ocDe=@OoNg]k
1oobl_87od10@0Oo00001olY:BT6ofm_K`Gooooo1ol92@T7ob<S8`Oo00001ol];Bd7oaTI6@KoT92@
1oolo?`6od51@@Kooooo1olK6a/7o``<30Ko8R8R1olJ6QX7oaPH60Oo00001olD51@;ooooo`Oo3`l?
1olj>SX7ooooo`OoGUiN1ol?3`l7ofi^KPOo00001_lY:BT5ooooo`Oo9RHV1ol00007oahN7POoJFUY
1onEUID7og9bLPKo820P1_mXJ6P6ooooo`Oolo?c1olj>SX7oiJFUPKo5ADE1omnOWh7oaHF5POo[jn_
1_nTY:@?ooooo`003Oooool7o``<30Oo00001olF5QH7ode=C@KoK6a/1oodm?@7oo;blPKo_Kfm1_oo
ool6om;BdPOoI6AT1olM7Ad7o`0000Oo=cLg1on0P807og1`L0Ko>3Ph1Oooool7ob@T90Oo=CDe1omk
Ng/7oo;blPOo@4101ol00007obTY:@KoKfm_1Oooool7o`T92@Oo8b<S1ol00007obd];@Oo6ATI1_n@
T907ooclo0Ko@D511_ooool7oa/K6`Oo30`<1_lR8R87oaXJ6POo61PH1ol00007oa@D50_ooooo1ol?
3`l7ocXj>POooooo1omNGUh7o`l?3`OoKVi^1ol00006obTY:@Gooooo1olV9RH7o`0000Oo7QhN1omY
JFT7oiFEU@OoLW9b1_lP8206ofQXJ0Kooooo1ooclo<7ocXj>POoUYJF1_lE5AD7oginOPOo5QHF1on_
[jl6ojBTY0oooooo000=ooooo`Oo30`<1ol00007oaHF5POoCDe=1_m/K6`7ooCdm0Ool_;b1_nm_Kd6
ooooo`Kod];B1omTI6@7oadM7@Oo00001olg=cL7oh20P0OoL71`1_lh>3P5ooooo`Oo92@T1ole=CD7
og]kN`Ool_;b1om0@407o`0000Oo:BTY1_m_Kfl5ooooo`Oo2@T91olS8b<7o`0000Oo;Bd]1olI6AT6
oi2@T0Ooo?cl1_m1@D46ooooo`Oo6a/K1ol<30`6ob8R8POo6QXJ1olH61P7o`0000Oo51@D2oooool7
o`l?3`Oo>SXj1oooool7oeiNGPOo3`l?1om^KVh7o`0000Ko:BTY1Oooool7obHV9POo00001olN7Qh7
ofUYJ@OoUIFE1ombLW86ob0P80KoJ6QX1_ooool7oo?cl`Oo>SXj1onFUYH6oaDE5@OoOWin1olF5QH7
ojn_[`KoY:BT3oooool000gooooo1ol<30`7o`0000Oo5QHF1om=CDd6ofa/K0Oom?Cd1oobl_86okfm
_@Kooooo1_oBd]87ofATI0Oo7AdM1ol00007ocLg=`OoP8201om`L706ocPh>0Gooooo1olT92@7ocDe
=@OoNg]k1oobl_87od10@0Oo00001olY:BT6ofm_K`Gooooo1ol92@T7ob<S8`Oo00001ol];Bd7oaTI
6@KoT92@1oolo?`6od51@@Kooooo1olK6a/7o``<30Ko8R8R1olJ6QX7oaPH60Oo00001olD51@;oooo
o`Oo3`l?1olj>SX7ooooo`OoGUiN1ol?3`l7ofi^KPOo00001_lY:BT5ooooo`Oo9RHV1ol00007oahN
7POoJFUY1onEUID7og9bLPKo820P1_mXJ6P6ooooo`Oolo?c1olj>SX7oiJFUPKo5ADE1omnOWh7oaHF
5POo[jn_1_nTY:@?ooooo`003Oooool7oa@D50Oo5aLG1olM7Ad7odU9B@KoMGEe1oo]kNd7ooknoPKo
`L711_ooool6ooknoPOo@d=31ol;2`/7oa`L70Oo>c/k1omQHF4=ofYZJPGooooo1olK6a/7ocXj>POo
NGUi1ooNg]h7ocdm?@Oo0P821ol_;bl6ob@T90Gooooo1ol:2PX7oaDE5@Oo51@D1ol[:b/7oa8B4PKo
WIfM1ooZj^X6oe9BDPKooooo1olC4a<7o`P820Ko3@d=1olH61P7oaLG5`Oo0`<31ol=3@d6olo?c`Go
oooo1ol61PH7odM7A`OomOGe1om3@d<7o`X:2POoH61P1ol?3`l6oadM7@Gooooo1om3@d<7o`H61POo
GEeM1onIVIT7ofQXJ0Oo;Bd]1_lD51@6oo_kn`Kooooo1ooVi^H7obTY:@OoU9BD1_l@4107ofi^KPOo
71`L1onc/k<6oinOW`oooooo000=ooooo`Oo51@D1olG5aL7oadM7@OoBDU91_meMGD7ong]k@Ooo_kn
1_o1`L46ooooo`Koo_kn1om3@d<7o`/;2`Oo71`L1olk>c/7of5QH@goJVYZ1Oooool7oa/K6`Oo>SXj
1omiNGT7omkNgPOo?Cdm1ol20P87obl_;`Ko92@T1Oooool7o`X:2POo5ADE1olD51@7ob/[:`Oo4Q8B
1_nMWId7on[ZjPKoDU9B1_ooool7oa<C4`Oo20P81_l=3@d7oaPH60Oo5aLG1ol30`<7o`d=3@Koclo?
1Oooool7o`H61POoAdM71ooemOD7od=3@`Oo2PX:1omPH607o`l?3`Ko7AdM1Oooool7od=3@`Oo1PH6
1omMGEd7oiVIV@OoJ6QX1ol];Bd6oa@D50Kono_k1_ooool7onKViPOo:BTY1onDU9@6oa0@40OoKVi^
1olL71`7ok>c/`KoWinO3oooool000gooooo1olD51@7oaLG5`Oo7AdM1om9BDT6ogEeM@OokNg]1oon
o_h6ol71`@Kooooo1_ono_h7od=3@`Oo2`/;1olL71`7oc/k>`OoHF5Q3OmZJVX5ooooo`Oo6a/K1olj
>SX7ogUiN@Oog]kN1olm?Cd7o`820POo;bl_1_lT92@5ooooo`Oo2PX:1olE5AD7oa@D50Oo:b/[1olB
4Q86oifMW@Ooj^[Z1_mBDU86ooooo`Oo4a<C1ol820P6o`d=3@Oo61PH1olG5aL7o`<30`Oo3@d=1_o?
cll5ooooo`Oo1PH61om7AdL7ooGem@Oo@d=31ol:2PX7of1PH0Oo3`l?1_lM7Ad5ooooo`Oo@d=31ol6
1PH7oeeMG@OoVIVI1omXJ6P7obd];@Ko51@D1_okno/6ooooo`Ooi^KV1olY:BT7oiBDU0Ko410@1om^
KVh7oa`L70Oo/k>c1_nOWil?ooooo`003Oooool7oa@D50Oo5aLG1olM7Ad7odU9B@KoMGEe1oo]kNd7
ooknoPKo`L711_ooool6ooknoPOo@d=31ol;2`/7oa`L70Oo>c/k1omQHF4=ofYZJPGooooo1olK6a/7
ocXj>POoNGUi1ooNg]h7ocdm?@Oo0P821ol_;bl6ob@T90Gooooo1ol:2PX7oaDE5@Oo51@D1ol[:b/7
oa8B4PKoWIfM1ooZj^X6oe9BDPKooooo1olC4a<7o`P820Ko3@d=1olH61P7oaLG5`Oo0`<31ol=3@d6
olo?c`Gooooo1ol61PH7odM7A`OomOGe1om3@d<7o`X:2POoH61P1ol?3`l6oadM7@Gooooo1om3@d<7
o`H61POoGEeM1onIVIT7ofQXJ0Oo;Bd]1_lD51@6oo_kn`Kooooo1ooVi^H7obTY:@OoU9BD1_l@4107
ofi^KPOo71`L1onc/k<6oinOW`oooooo000=ooooo`Oo51@D1olG5aL7oadM7@OoBDU91_meMGD7ong]
k@Ooo_kn1_o1`L46ooooo`Koo_kn1om3@d<7o`/;2`Oo71`L1olk>c/7of5QH@goJVYZ1Oooool7oa/K
6`Oo>SXj1omiNGT7omkNgPOo?Cdm1ol20P87obl_;`Ko92@T1Oooool7o`X:2POo5ADE1olD51@7ob/[
:`Oo4Q8B1_nMWId7on[ZjPKoDU9B1_ooool7oa<C4`Oo20P81_l=3@d7oaPH60Oo5aLG1ol30`<7o`d=
3@Koclo?1Oooool7o`H61POoAdM71ooemOD7od=3@`Oo2PX:1omPH607o`l?3`Ko7AdM1Oooool7od=3
@`Oo1PH61omMGEd7oiVIV@OoJ6QX1ol];Bd6oa@D50Kono_k1_ooool7onKViPOo:BTY1onDU9@6oa0@
40OoKVi^1olL71`7ok>c/`KoWinO3oooool000gooooo1olD51@7oaLG5`Oo7AdM1om9BDT6ogEeM@Oo
kNg]1oono_h6ol71`@Kooooo1_ono_h7od=3@`Oo2`/;1olL71`7oc/k>`OoHF5Q3OmZJVX5ooooo`Oo
6a/K1olj>SX7ogUiN@Oog]kN1olm?Cd7o`820POo;bl_1_lT92@5ooooo`Oo2PX:1olE5AD7oa@D50Oo
:b/[1olB4Q86oifMW@Ooj^[Z1_mBDU86ooooo`Oo4a<C1ol820P6o`d=3@Oo61PH1olG5aL7o`<30`Oo
3@d=1_o?cll5ooooo`Oo1PH61om7AdL7ooGem@Oo@d=31ol:2PX7of1PH0Oo3`l?1_lM7Ad5ooooo`Oo
@d=31ol61PH7oeeMG@OoVIVI1omXJ6P7obd];@Ko51@D1_okno/6ooooo`Ooi^KV1olY:BT7oiBDU0Ko
410@1om^KVh7oa`L70Oo/k>c1_nOWil?ooooo`003Oooool7oa@D50Oo5aLG1olM7Ad7odU9B@KoMGEe
1oo]kNd7ooknoPKo`L711_ooool6ooknoPOo@d=31ol;2`/7oa`L70Oo>c/k1omQHF4=ofYZJPGooooo
1olK6a/7ocXj>POoNGUi1ooNg]h7ocdm?@Oo0P821ol_;bl6ob@T90Gooooo1ol:2PX7oaDE5@Oo51@D
1ol[:b/7oa8B4PKoWIfM1ooZj^X6oe9BDPKooooo1olC4a<7o`P820Ko3@d=1olH61P7oaLG5`Oo0`<3
1ol=3@d6olo?c`Gooooo1ol61PH7odM7A`OomOGe1om3@d<7o`X:2POoH61P1ol?3`l6oadM7@Gooooo
1om3@d<7o`H61POoGEeM1onIVIT7ofQXJ0Oo;Bd]1_lD51@6oo_kn`Kooooo1ooVi^H7obTY:@OoU9BD
1_l@4107ofi^KPOo71`L1onc/k<6oinOW`oooooo000=ooooo`Oo7QhN1ol:2PX7ob4Q8@OoDE5A1_m[
Jf/7onOWi`OojNWY1_o1`L46ooooo`Ko`/;21om1@D47oa@D50Oo4a<C1omBDU87ohf=S@OoHf=S1_mA
DE45ooooo`Oo;2`/1omGEeL7oh^;R`Ooc<c<1olS8b<7o`/;2`Oo>SXj1_mADE45ooooo`Oo1`L71olK
6a/7o`T92@Oo;2`/1ol_;bl6oj>SX`OoeMGE1_lg=cL6ooooo`Oo71`L1ol=3@d6oaHF5POo6QXJ1olO
7al7o`X:2POo4A4A1_oCdm<5ooooo`Oo51@D1omDE5@7onSXj0Oo?3`l1olD51@7oeIFEPOo1@D51_lV
9RH5ooooo`Oo51@D1ol61PH7oclo?`OoP8201on8R8P7od];B`Ko7QhN1_mUIFD6ooooo`OodM7A1ola
<C47ogemO@Ko5ADE1omWIfL7oa@D50OoTI6A1_nb/[8?ooooo`003Oooool7oahN7POo2PX:1olQ8B47
oe5AD@KoJf][1ooWinL7onWYj@Ko`L711_ooool6ol;2`POo@D511olD51@7oa<C4`OoDU9B1on=SHd7
of=SH`KoDE5A1Oooool7ob`/;0OoEeMG1on;Rh/7olc<c0Oo8b<S1ol;2`/7ocXj>PKoDE5A1Oooool7
o`L71`Oo6a/K1ol92@T7ob`/;0Oo;bl_1_nSXj<7omGEe@Ko=cLg1_ooool7oa`L70Oo3@d=1_lF5QH7
oaXJ6POo7alO1ol:2PX7oa4A4@Kodm?C1Oooool7oa@D50OoE5AD1ooXj>P7oc`l?0Oo51@D1omFEUH7
o`D51@Ko9RHV1Oooool7oa@D50Oo1PH61olo?cl7oh20P0OoR8R81om;Bd/6oahN7PKoIFEU1_ooool7
om7Ad@Oo<C4a1ommOGd6oaDE5@OoIfMW1olD51@7oi6AT@Ko/[:b3oooool000gooooo1olN7Qh7o`X:
2POo8B4Q1omADE46of][J`OoinOW1ooYjNT6ol71`@Kooooo1_o2`/87od51@@Oo51@D1olC4a<7oe9B
DPOoSHf=1omSHf<6oe5AD@Gooooo1ol/;2`7oeMGE`OoRh^;1oo<c<`7ob<S8`Oo2`/;1olj>SX6oe5A
D@Gooooo1ol71`L7oa/K6`Oo2@T91ol/;2`7obl_;`KoXj>S1ooEeMD6ocLg=`Kooooo1olL71`7o`d=
3@Ko5QHF1olJ6QX7oalO7`Oo2PX:1olA4A46om?Cd`Gooooo1olD51@7oeADE0Ooj>SX1oll?3`7oa@D
50OoEUIF1ol51@D6obHV9PGooooo1olD51@7o`H61POo?clo1on0P807ohR8R0OoBd];1_lN7Qh6ofEU
I@Kooooo1ooAdM47oc4a<@OoOGem1_lE5AD7ofMWI`Oo51@D1onATI46ok:b/Poooooo000=ooooo`Oo
7QhN1ol:2PX7ob4Q8@OoDE5A1_m[Jf/7onOWi`OojNWY1_o1`L46ooooo`Ko`/;21om1@D47oa@D50Oo
4a<C1omBDU87ohf=S@OoHf=S1_mADE45ooooo`Oo;2`/1omGEeL7oh^;R`Ooc<c<1olS8b<7o`/;2`Oo
>SXj1_mADE45ooooo`Oo1`L71olK6a/7o`T92@Oo;2`/1ol_;bl6oj>SX`OoeMGE1_lg=cL6ooooo`Oo
71`L1ol=3@d6oaHF5POo6QXJ1olO7al7o`X:2POo4A4A1_oCdm<5ooooo`Oo51@D1omDE5@7onSXj0Oo
?3`l1olD51@7oeIFEPOo1@D51_lV9RH5ooooo`Oo51@D1ol61PH7oclo?`OoP8201on8R8P7od];B`Ko
7QhN1_mUIFD6ooooo`OodM7A1ola<C47ogemO@Ko5ADE1omWIfL7oa@D50OoTI6A1_nb/[8?ooooo`00
3Oooool7oahN7POo2PX:1olQ8B47oe5AD@KoJf][1ooWinL7onWYj@Ko`L711_ooool6ol;2`POo@D51
1olD51@7oa<C4`OoDU9B1on=SHd7of=SH`KoDE5A1Oooool7ob`/;0OoEeMG1on;Rh/7olc<c0Oo8b<S
1ol;2`/7ocXj>PKoDE5A1Oooool7o`L71`Oo6a/K1ol92@T7ob`/;0Oo;bl_1_nSXj<7omGEe@Ko=cLg
1_ooool7oa`L70Oo3@d=1_lF5QH7oaXJ6POo7alO1ol:2PX7oa4A4@Kodm?C1Oooool7oa@D50OoE5AD
1ooXj>P7oc`l?0Oo51@D1omFEUH7o`D51@Ko9RHV1Oooool7oa@D50Oo1PH61olo?cl7oh20P0OoR8R8
1om;Bd/6oahN7PKoIFEU1_ooool7om7Ad@Oo<C4a1ommOGd6oaDE5@OoIfMW1olD51@7oi6AT@Ko/[:b
3oooool000gooooo1olN7Qh7o`X:2POo8B4Q1omADE46of][J`OoinOW1ooYjNT6ol71`@Kooooo1_o2
`/87od51@@Oo51@D1olC4a<7oe9BDPOoSHf=1omSHf<6oe5AD@Gooooo1ol/;2`7oeMGE`OoRh^;1oo<
c<`7ob<S8`Oo2`/;1olj>SX6oe5AD@Gooooo1ol71`L7oa/K6`Oo2@T91ol/;2`7obl_;`KoXj>S1ooE
eMD6ocLg=`Kooooo1olL71`7o`d=3@Ko5QHF1olJ6QX7oalO7`Oo2PX:1olA4A46om?Cd`Gooooo1olD
51@7oeADE0Ooj>SX1oll?3`7oa@D50OoEUIF1ol51@D6obHV9PGooooo1olD51@7o`H61POo?clo1on0
P807ohR8R0OoBd];1_lN7Qh6ofEUI@Kooooo1ooAdM47oc4a<@OoOGem1_lE5AD7ofMWI`Oo51@D1onA
TI46ok:b/Poooooo000=ooooo`Oo9bLW1olN7Qh7obd];@OoBd];1_mdM7@7ol71`@OogmoO1_ng]kL6
ooooo`KofMWI1olZ:RX7o`T92@Oo;bl_1om3@d<7oeMGE`OoFEUI1_n9RHT5ooooo`Oo8R8R1om8B4P7
oh:2PPOoZJVY1olZ:RX7o`820POo@4101_lN7Qh5ooooo`Oo00001ol71`L7oa<C4`Oo:b/[1olN7Qh6
oiRHV0Oo^;Rh1_li>CT6ooooo`Oo3@d=1ol20P86o`L71`ko4a<C1ol20P87o`X:2PKoVIVI1Oooool7
o`X:2POoC4a<1oo5aLD7obLW9`Oo0P821om8B4P7o`X:2PKo6QXJ1Oooool7ocTi>@Oo820P1omdM7@7
oiRHV0OoBDU91olM7Ad6oa8B4PKojn_[1_ooool7okBd]0Oo5aLG1omRHV86o`0000OoCDe=1ol@4107
ohZ:RPKoUIFE3oooool000gooooo1olW9bL7oahN7POo;Bd]1om;Bd/6ogAdM0Oo`L711ooOgml6okNg
]`Kooooo1_oIfMT7obXZ:POo2@T91ol_;bl7od=3@`OoEeMG1omIFET6ohV9R@Gooooo1olR8R87odQ8
B0OoPX:21onYZJT7obXZ:POo0P821om0@406oahN7PGooooo1ol00007o`L71`Oo4a<C1ol[:b/7oahN
7PKoV9RH1onh^;P6ocTi>@Kooooo1ol=3@d7o`820PKo1`L73_lC4a<7o`820POo2PX:1_nIVIT5oooo
o`Oo2PX:1om<C4`7olG5a@Oo9bLW1ol20P87odQ8B0Oo2PX:1_lJ6QX5ooooo`Oo>CTi1olP8207ogAd
M0OoV9RH1om9BDT7oadM7@Ko4Q8B1_o[jn/6ooooo`Oo];Bd1olG5aL7of9RHPKo00001om=CDd7oa0@
40OoRXZ:1_nEUID?ooooo`003Oooool7obLW9`Oo7QhN1ol];Bd7od];B`KoM7Ad1oo1`L47omoOg`Ko
]kNg1_ooool6omWIf@Oo:RXZ1ol92@T7obl_;`Oo@d=31omGEeL7oeUIF@KoRHV91Oooool7ob8R8POo
B4Q81on2PX87ojVYZ@Oo:RXZ1ol20P87od10@0Ko7QhN1Oooool7o`0000Oo1`L71olC4a<7ob/[:`Oo
7QhN1_nHV9P7okRh^0Ko>CTi1_ooool7o`d=3@Oo0P821_l71`L>oa<C4`Oo0P821ol:2PX6oiVIV@Go
oooo1ol:2PX7oda<C0OoaLG51olW9bL7o`820POoB4Q81ol:2PX6oaXJ6PGooooo1oli>CT7ob0P80Oo
M7Ad1onHV9P7odU9B@Oo7AdM1_lB4Q86on_[j`Kooooo1ond];@7oaLG5`OoHV9R1_l00007ode=C@Oo
410@1on:RXX6oiFEU@oooooo000=ooooo`Oo9bLW1olN7Qh7obd];@OoBd];1_mdM7@7ol71`@OogmoO
1_ng]kL6ooooo`KofMWI1olZ:RX7o`T92@Oo;bl_1om3@d<7oeMGE`OoFEUI1_n9RHT5ooooo`Oo8R8R
1om8B4P7oh:2PPOoZJVY1olZ:RX7o`820POo@4101_lN7Qh5ooooo`Oo00001ol71`L7oa<C4`Oo:b/[
1olN7Qh6oiRHV0Oo^;Rh1_li>CT6ooooo`Oo3@d=1ol20P86o`L71`ko4a<C1ol20P87o`X:2PKoVIVI
1Oooool7o`X:2POoC4a<1oo5aLD7obLW9`Oo0P821om8B4P7o`X:2PKo6QXJ1Oooool7ocTi>@Oo820P
1omdM7@7oiRHV0OoBDU91olM7Ad6oa8B4PKojn_[1_ooool7okBd]0Oo5aLG1omRHV86o`0000OoCDe=
1ol@4107ohZ:RPKoUIFE3oooool000gooooo1olW9bL7oahN7POo;Bd]1om;Bd/6ogAdM0Oo`L711ooO
gml6okNg]`Kooooo1_oIfMT7obXZ:POo2@T91ol_;bl7od=3@`OoEeMG1omIFET6ohV9R@Gooooo1olR
8R87odQ8B0OoPX:21onYZJT7obXZ:POo0P821om0@406oahN7PGooooo1ol00007o`L71`Oo4a<C1ol[
:b/7oahN7PKoV9RH1onh^;P6ocTi>@Kooooo1ol=3@d7o`820PKo1`L73_lC4a<7o`820POo2PX:1_nI
VIT5ooooo`Oo2PX:1om<C4`7olG5a@Oo9bLW1ol20P87odQ8B0Oo2PX:1_lJ6QX5ooooo`Oo>CTi1olP
8207ogAdM0OoV9RH1om9BDT7oadM7@Ko4Q8B1_o[jn/6ooooo`Oo];Bd1olG5aL7of9RHPKo00001om=
CDd7oa0@40OoRXZ:1_nEUID?ooooo`003Oooool7obLW9`Oo7QhN1ol];Bd7od];B`KoM7Ad1oo1`L47
omoOg`Ko]kNg1_ooool6omWIf@Oo:RXZ1ol92@T7obl_;`Oo@d=31omGEeL7oeUIF@KoRHV91Oooool7
ob8R8POoB4Q81on2PX87ojVYZ@Oo:RXZ1ol20P87od10@0Ko7QhN1Oooool7o`0000Oo1`L71olC4a<7
ob/[:`Oo7QhN1_nHV9P7okRh^0Ko>CTi1_ooool7o`d=3@Oo0P821_l71`L>oa<C4`Oo0P821ol:2PX6
oiVIV@Gooooo1ol:2PX7oda<C0OoaLG51olW9bL7o`820POoB4Q81ol:2PX6oaXJ6PGooooo1oli>CT7
ob0P80OoM7Ad1onHV9P7odU9B@Oo7AdM1_lB4Q86on_[j`Kooooo1ond];@7oaLG5`OoHV9R1_l00007
ode=C@Oo410@1on:RXX6oiFEU@oooooo000=ooooo`Oo9bLW1olN7Qh7obd];@OoBd];1_mdM7@7ol71
`@OogmoO1_ng]kL6ooooo`KofMWI1olZ:RX7o`T92@Oo;bl_1om3@d<7oeMGE`OoFEUI1_n9RHT5oooo
o`Oo8R8R1om8B4P7oh:2PPOoZJVY1olZ:RX7o`820POo@4101_lN7Qh5ooooo`Oo00001ol71`L7oa<C
4`Oo:b/[1olN7Qh6oiRHV0Oo^;Rh1_li>CT6ooooo`Oo3@d=1ol20P86o`L71`ko4a<C1ol20P87o`X:
2PKoVIVI1Oooool7o`X:2POoC4a<1oo5aLD7obLW9`Oo0P821om8B4P7o`X:2PKo6QXJ1Oooool7ocTi
>@Oo820P1omdM7@7oiRHV0OoBDU91olM7Ad6oa8B4PKojn_[1_ooool7okBd]0Oo5aLG1omRHV86o`00
00OoCDe=1ol@4107ohZ:RPKoUIFE3oooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool000gooooo1om=CDd7ocLg=`OoMGEe
1onJVYX6omkNgPOoF5QH1oo=cLd6omWIf@Kooooo1_le=CD7omOGe`OoEeMG1olU9BD7obd];@Oo92@T
1ol00006ocXj>PGooooo1olW9bL7odi>CPOoe=CD1omaLG47obl_;`Oo:b/[1olG5aL6ocHf=PGooooo
1onATI47ofi^KPOo:2PX1olY:BT7oemOG`Ko_kno1omADE46oinOW`Kooooo1onCTi<7oe]KF`Ko9bLW
1olX:2P7oaPH60Oo7alO1ol_;bl6onSXj0Gooooo1oln?Sh7ojBTY0OoinOW1onOWil7ob/[:`Oo:BTY
1on?Shl6oeaLG0Gooooo1olP8207oahN7POo;2`/1olS8b<7om_Kf`Oo<C4a1_lN7Qh6oc<c<`Kooooo
1olf=SH7odU9B@Oo;2`/1_miNGT7onGUi@OoM7Ad1ole=CD6o``<30oooooo000=ooooo`OoCDe=1olg
=cL7ogEeM@OoVYZJ1_oNg]h7oeQHF0OocLg=1_oIfMT6ooooo`Ko=CDe1ooGemL7oeMGE`Oo9BDU1ol]
;Bd7ob@T90Oo00001_lj>SX5ooooo`Oo9bLW1om>CTh7omCDe0OoLG5a1ol_;bl7ob/[:`Oo5aLG1_lf
=SH5ooooo`OoTI6A1om^KVh7obPX:0Oo:BTY1omOGel6okno_`OoDE5A1_nOWil6ooooo`OoTi>C1omK
Fe/6obLW9`Oo:2PX1olH61P7oalO7`Oo;bl_1_oXj>P5ooooo`Oo?Shn1onTY:@7onOWi`OoWinO1ol[
:b/7obTY:@OoShn?1_mLG5`5ooooo`Oo820P1olN7Qh7ob`/;0Oo8b<S1ooKfm/7oc4a<@Ko7QhN1_lc
<c<6ooooo`Oo=SHf1om9BDT7ob`/;0KoNGUi1ooUiND7ogAdM0Oo=CDe1_l<30`?ooooo`003Oooool7
ode=C@Oo=cLg1omeMGD7oiZJVPKog]kN1omHF5P7olg=c@KofMWI1_ooool6ocDe=@OoemOG1omGEeL7
obDU9@Oo;Bd]1olT92@7o`0000Ko>SXj1Oooool7obLW9`OoCTi>1ooDe=@7og5aL@Oo;bl_1ol[:b/7
oaLG5`Ko=SHf1Oooool7oi6AT@OoKVi^1olX:2P7obTY:@OoGemO1_no_kl7oe5AD@KoWinO1_ooool7
oi>CT`OoFe]K1_lW9bL7obPX:0Oo61PH1olO7al7obl_;`Koj>SX1Oooool7ochn?POoY:BT1ooWinL7
oinOW`Oo:b/[1olY:BT7ohn?S`KoG5aL1Oooool7ob0P80Oo7QhN1ol/;2`7ob<S8`Oofm_K1ola<C46
oahN7PKo<c<c1_ooool7ocHf=POoBDU91ol/;2`6ogUiN@OoiNGU1omdM7@7ocDe=@Ko30`<3oooool0
00gooooo1om=CDd7ocLg=`OoMGEe1onJVYX6omkNgPOoF5QH1oo=cLd6omWIf@Kooooo1_le=CD7omOG
e`OoEeMG1olU9BD7obd];@Oo92@T1ol00006ocXj>PGooooo1olW9bL7odi>CPOoe=CD1omaLG47obl_
;`Oo:b/[1olG5aL6ocHf=PGooooo1onATI47ofi^KPOo:2PX1olY:BT7oemOG`Ko_kno1omADE46oinO
W`Kooooo1onCTi<7oe]KF`Ko9bLW1olX:2P7oaPH60Oo7alO1ol_;bl6onSXj0Gooooo1oln?Sh7ojBT
Y0OoinOW1onOWil7ob/[:`Oo:BTY1on?Shl6oeaLG0Gooooo1olP8207oahN7POo;2`/1olS8b<7om_K
f`Oo<C4a1_lN7Qh6oc<c<`Kooooo1olf=SH7odU9B@Oo;2`/1_miNGT7onGUi@OoM7Ad1ole=CD6o``<
30oooooo000=ooooo`OoCDe=1olg=cL7ogEeM@OoVYZJ1_oNg]h7oeQHF0OocLg=1_oIfMT6ooooo`Ko
=CDe1ooGemL7oeMGE`Oo9BDU1ol];Bd7ob@T90Oo00001_lj>SX5ooooo`Oo9bLW1om>CTh7omCDe0Oo
LG5a1ol_;bl7ob/[:`Oo5aLG1_lf=SH5ooooo`OoTI6A1om^KVh7obPX:0Oo:BTY1omOGel6okno_`Oo
DE5A1_nOWil6ooooo`OoTi>C1omKFe/6obLW9`Oo:2PX1olH61P7oalO7`Oo;bl_1_oXj>P5ooooo`Oo
?Shn1onTY:@7onOWi`OoWinO1ol[:b/7obTY:@OoShn?1_mLG5`5ooooo`Oo820P1olN7Qh7ob`/;0Oo
8b<S1ooKfm/7oc4a<@Ko7QhN1_lc<c<6ooooo`Oo=SHf1om9BDT7ob`/;0KoNGUi1ooUiND7ogAdM0Oo
=CDe1_l<30`?ooooo`003Oooool7ode=C@Oo=cLg1omeMGD7oiZJVPKog]kN1omHF5P7olg=c@KofMWI
1_ooool6ocDe=@OoemOG1omGEeL7obDU9@Oo;Bd]1olT92@7o`0000Ko>SXj1Oooool7obLW9`OoCTi>
1ooDe=@7og5aL@Oo;bl_1ol[:b/7oaLG5`Ko=SHf1Oooool7oi6AT@OoKVi^1olX:2P7obTY:@OoGemO
1_no_kl7oe5AD@KoWinO1_ooool7oi>CT`OoFe]K1_lW9bL7obPX:0Oo61PH1olO7al7obl_;`Koj>SX
1Oooool7ochn?POoY:BT1ooWinL7oinOW`Oo:b/[1olY:BT7ohn?S`KoG5aL1Oooool7ob0P80Oo7QhN
1ol/;2`7ob<S8`Oofm_K1ola<C46oahN7PKo<c<c1_ooool7ocHf=POoBDU91ol/;2`6ogUiN@OoiNGU
1omdM7@7ocDe=@Ko30`<3oooool000gooooo1om=CDd7ocLg=`OoMGEe1onJVYX6omkNgPOoF5QH1oo=
cLd6omWIf@Kooooo1_le=CD7omOGe`OoEeMG1olU9BD7obd];@Oo92@T1ol00006ocXj>PGooooo1olW
9bL7odi>CPOoe=CD1omaLG47obl_;`Oo:b/[1olG5aL6ocHf=PGooooo1onATI47ofi^KPOo:2PX1olY
:BT7oemOG`Ko_kno1omADE46oinOW`Kooooo1onCTi<7oe]KF`Ko9bLW1olX:2P7oaPH60Oo7alO1ol_
;bl6onSXj0Gooooo1oln?Sh7ojBTY0OoinOW1onOWil7ob/[:`Oo:BTY1on?Shl6oeaLG0Gooooo1olP
8207oahN7POo;2`/1olS8b<7om_Kf`Oo<C4a1_lN7Qh6oc<c<`Kooooo1olf=SH7odU9B@Oo;2`/1_mi
NGT7onGUi@OoM7Ad1ole=CD6o``<30oooooo000=ooooo`Oo3`l?1olE5AD7obLW9`OoYjNW1_oKfm/7
ofe]K@OoYZJV1_o7alL6ooooo`Ko=cLg1ooXj>P7odE5A@Oo6QXJ1olT92@7oaDE5@Oo10@41_lj>SX5
ooooo`Oo820P1omRHV87onCTi0OoLg=c1ol];Bd7obPX:0Oo2PX:1_l`<305ooooo`OoIVIV1om2@T87
o`d=3@Oo00001omjNWX6ooWin@OoNg]k1_mEEED6ooooo`OoShn?1omZJVX6obLW9`Oo9BDU1olC4a<7
oa4A4@Oo=3@d1_oUiND5ooooo`Oo:b/[1onVYZH7ooooo`OoPX:21olN7Qh7ocDe=@Oo[:b/1_ln?Sh5
ooooo`Oo:2PX1ol>3Ph7oa0@40Oo6QXJ1ooKfm/7ob8R8PKo3`l?1_lE5AD6ooooo`Oo=3@d1om@D507
obTY:@KoQ8B41ooclo<7oeYJFPOo:BTY1_l51@D?ooooo`003Oooool7o`l?3`Oo5ADE1olW9bL7ojNW
Y`Kofm_K1om]KFd7ojJVYPKoalO71_ooool6ocLg=`Ooj>SX1om5ADD7oaXJ6POo92@T1olE5AD7o`@4
10Ko>SXj1Oooool7ob0P80OoHV9R1ooTi>@7og=cL`Oo;Bd]1olX:2P7o`X:2PKo<30`1Oooool7ofIV
IPOo@T921ol=3@d7o`0000OoNWYj1_oinOT7og]kN`KoEEEE1_ooool7ohn?S`OoJVYZ1_lW9bL7obDU
9@Oo4a<C1olA4A47oc@d=0KoiNGU1Oooool7ob/[:`OoYZJV1oooool7oh:2PPOo7QhN1ole=CD7ojb/
[0Ko?Shn1Oooool7obPX:0Oo3Ph>1ol@4107oaXJ6POofm_K1olR8R86o`l?3`Ko5ADE1_ooool7oc@d
=0OoD51@1olY:BT6ohB4Q0Oolo?c1omJFUX7obTY:@Ko1@D53oooool000gooooo1ol?3`l7oaDE5@Oo
9bLW1onWYjL6om_Kf`OoKFe]1onVYZH6olO7a`Kooooo1_lg=cL7onSXj0OoADE51olJ6QX7ob@T90Oo
5ADE1ol410@6ocXj>PGooooo1olP8207of9RHPOoi>CT1omcLg<7obd];@Oo:2PX1ol:2PX6oc0`<0Go
oooo1omVIVH7od92@POo3@d=1ol00007ogYjNPKonOWi1omkNg/6oeEEE@Kooooo1on?Shl7ofYZJPKo
9bLW1olU9BD7oa<C4`Oo4A4A1old=3@6onGUi@Gooooo1ol[:b/7ojJVYPOooooo1on2PX87oahN7POo
=CDe1on/[:`6ochn?PGooooo1olX:2P7o`h>3POo410@1olJ6QX7om_Kf`Oo8R8R1_l?3`l6oaDE5@Ko
oooo1old=3@7oe1@D0Oo:BTY1_n4Q8@7oo?cl`OoFUYJ1olY:BT6o`D51@oooooo000=ooooo`Oo3`l?
1olE5AD7obLW9`OoYjNW1_oKfm/7ofe]K@OoYZJV1_o7alL6ooooo`Ko=cLg1ooXj>P7odE5A@Oo6QXJ
1olT92@7oaDE5@Oo10@41_lj>SX5ooooo`Oo820P1omRHV87onCTi0OoLg=c1ol];Bd7obPX:0Oo2PX:
1_l`<305ooooo`OoIVIV1om2@T87o`d=3@Oo00001omjNWX6ooWin@OoNg]k1_mEEED6ooooo`OoShn?
1omZJVX6obLW9`Oo9BDU1olC4a<7oa4A4@Oo=3@d1_oUiND5ooooo`Oo:b/[1onVYZH7ooooo`OoPX:2
1olN7Qh7ocDe=@Oo[:b/1_ln?Sh5ooooo`Oo:2PX1ol>3Ph7oa0@40Oo6QXJ1ooKfm/7ob8R8PKo3`l?
1_lE5AD6ooooo`Oo=3@d1om@D507obTY:@KoQ8B41ooclo<7oeYJFPOo:BTY1_l51@D?ooooo`003Ooo
ool7o`l?3`Oo5ADE1olW9bL7ojNWY`Kofm_K1om]KFd7ojJVYPKoalO71_ooool6ocLg=`Ooj>SX1om5
ADD7oaXJ6POo92@T1olE5AD7o`@410Ko>SXj1Oooool7ob0P80OoHV9R1ooTi>@7og=cL`Oo;Bd]1olX
:2P7o`X:2PKo<30`1Oooool7ofIVIPOo@T921ol=3@d7o`0000OoNWYj1_oinOT7og]kN`KoEEEE1_oo
ool7ohn?S`OoJVYZ1_lW9bL7obDU9@Oo4a<C1olA4A47oc@d=0KoiNGU1Oooool7ob/[:`OoYZJV1ooo
ool7oh:2PPOo7QhN1ole=CD7ojb/[0Ko?Shn1Oooool7obPX:0Oo3Ph>1ol@4107oaXJ6POofm_K1olR
8R86o`l?3`Ko5ADE1_ooool7oc@d=0OoD51@1olY:BT6ohB4Q0Oolo?c1omJFUX7obTY:@Ko1@D53ooo
ool000gooooo1ol?3`l7oaDE5@Oo9bLW1onWYjL6om_Kf`OoKFe]1onVYZH6olO7a`Kooooo1_lg=cL7
onSXj0OoADE51olJ6QX7ob@T90Oo5ADE1ol410@6ocXj>PGooooo1olP8207of9RHPOoi>CT1omcLg<7
obd];@Oo:2PX1ol:2PX6oc0`<0Gooooo1omVIVH7od92@POo3@d=1ol00007ogYjNPKonOWi1omkNg/6
oeEEE@Kooooo1on?Shl7ofYZJPKo9bLW1olU9BD7oa<C4`Oo4A4A1old=3@6onGUi@Gooooo1ol[:b/7
ojJVYPOooooo1on2PX87oahN7POo=CDe1on/[:`6ochn?PGooooo1olX:2P7o`h>3POo410@1olJ6QX7
om_Kf`Oo8R8R1_l?3`l6oaDE5@Kooooo1old=3@7oe1@D0Oo:BTY1_n4Q8@7oo?cl`OoFUYJ1olY:BT6
o`D51@oooooo000=ooooo`Oo3`l?1olE5AD7obLW9`OoYjNW1_oKfm/7ofe]K@OoYZJV1_o7alL6oooo
o`Ko=cLg1ooXj>P7odE5A@Oo6QXJ1olT92@7oaDE5@Oo10@41_lj>SX5ooooo`Oo820P1omRHV87onCT
i0OoLg=c1ol];Bd7obPX:0Oo2PX:1_l`<305ooooo`OoIVIV1om2@T87o`d=3@Oo00001omjNWX6ooWi
n@OoNg]k1_mEEED6ooooo`OoShn?1omZJVX6obLW9`Oo9BDU1olC4a<7oa4A4@Oo=3@d1_oUiND5oooo
o`Oo:b/[1onVYZH7ooooo`OoPX:21olN7Qh7ocDe=@Oo[:b/1_ln?Sh5ooooo`Oo:2PX1ol>3Ph7oa0@
40Oo6QXJ1ooKfm/7ob8R8PKo3`l?1_lE5AD6ooooo`Oo=3@d1om@D507obTY:@KoQ8B41ooclo<7oeYJ
FPOo:BTY1_l51@D?ooooo`003Oooool7o`<30`Oo1`L71olN7Qh7ohb<S0Ko_kno1ol>3Ph7ojRXZ0Ko
/[:b1_ooool6odA4A0Oon_[j1om<C4`7ob8R8POo92@T1olF5QH7o`0000Ko<S8b1Oooool7oadM7@Oo
F5QH1ookno/7og5aL@ko:b/[1olA4A46ob/[:`Gooooo1on9RHT7odM7A`Oo51@D1om1@D47ofMWI`Ko
c<c<1om5ADD6olW9b@Kooooo1onRXZ87ofe]K@Ko8R8R1olL71`7o`T92@Oo4a<C1olW9bL6omGEe@Go
oooo1omFEUH7olk>cPOogMgM1omUIFD7oaDE5@Oo<c<c1onh^;P6ocdm?@Gooooo1olP8207oa<C4`Oo
6a/K1olP8207ooooo`Oo820P1_l?3`l6oa@D50Kooooo1ole=CD7oeQHF0Oo;Rh^1_nEUID7ooooo`Oo
IVIV1ol_;bl6o`@410oooooo000=ooooo`Oo0`<31ol71`L7oahN7POoS8b<1_no_kl7o`h>3POoZ:RX
1_nb/[86ooooo`KoA4A41oojn_X7oda<C0Oo8R8R1olT92@7oaHF5POo00001_lb<S85ooooo`Oo7AdM
1omHF5P7oo_kn`OoLG5a3_l[:b/7oa4A4@Ko:b/[1Oooool7ohV9R@OoAdM71olD51@7od51@@OoIfMW
1_o<c<`7odE5A@KobLW91_ooool7oj:RXPOoKFe]1_lR8R87oa`L70Oo2@T91olC4a<7obLW9`KoeMGE
1Oooool7oeIFEPOoc/k>1ooMgMd7ofEUI@Oo5ADE1olc<c<7okRh^0Ko?Cdm1Oooool7ob0P80Oo4a<C
1olK6a/7ob0P80Oooooo1olP8206o`l?3`Ko51@D1_ooool7ocDe=@OoF5QH1ol^;Rh6oiFEU@Oooooo
1omVIVH7obl_;`Ko10@43oooool000gooooo1ol30`<7o`L71`Oo7QhN1on<S8`6okno_`Oo3Ph>1onX
Z:P6ok:b/PKooooo1_m4A4@7oo[jnPOoC4a<1olR8R87ob@T90Oo5QHF1ol00006oc8b<PGooooo1olM
7Ad7oeQHF0Oono_k1omaLG4>ob/[:`Oo4A4A1_l[:b/5ooooo`OoRHV91om7AdL7oa@D50Oo@D511omW
IfL6olc<c0OoADE51_o9bLT6ooooo`OoXZ:R1om]KFd6ob8R8POo71`L1ol92@T7oa<C4`Oo9bLW1_oE
eMD5ooooo`OoEUIF1oo>c/h7omgMg@OoIFEU1olE5AD7oc<c<`Oo^;Rh1_lm?Cd5ooooo`Oo820P1olC
4a<7oa/K6`Oo820P1oooool7ob0P80Ko3`l?1_lD51@6ooooo`Oo=CDe1omHF5P7obh^;PKoUIFE1ooo
ool7ofIVIPOo;bl_1_l410@?ooooo`003Oooool7o`<30`Oo1`L71olN7Qh7ohb<S0Ko_kno1ol>3Ph7
ojRXZ0Ko/[:b1_ooool6odA4A0Oon_[j1om<C4`7ob8R8POo92@T1olF5QH7o`0000Ko<S8b1Oooool7
oadM7@OoF5QH1ookno/7og5aL@ko:b/[1olA4A46ob/[:`Gooooo1on9RHT7odM7A`Oo51@D1om1@D47
ofMWI`Koc<c<1om5ADD6olW9b@Kooooo1onRXZ87ofe]K@Ko8R8R1olL71`7o`T92@Oo4a<C1olW9bL6
omGEe@Gooooo1omFEUH7olk>cPOogMgM1omUIFD7oaDE5@Oo<c<c1onh^;P6ocdm?@Gooooo1olP8207
oa<C4`Oo6a/K1olP8207ooooo`Oo820P1_l?3`l6oa@D50Kooooo1ole=CD7oeQHF0Oo;Rh^1_nEUID7
ooooo`OoIVIV1ol_;bl6o`@410oooooo000=ooooo`Oo0`<31ol71`L7oahN7POoS8b<1_no_kl7o`h>
3POoZ:RX1_nb/[86ooooo`KoA4A41oojn_X7oda<C0Oo8R8R1olT92@7oaHF5POo00001_lb<S85oooo
o`Oo7AdM1omHF5P7oo_kn`OoLG5a3_l[:b/7oa4A4@Ko:b/[1Oooool7ohV9R@OoAdM71olD51@7od51
@@OoIfMW1_o<c<`7odE5A@KobLW91_ooool7oj:RXPOoKFe]1_lR8R87oa`L70Oo2@T91olC4a<7obLW
9`KoeMGE1Oooool7oeIFEPOoc/k>1ooMgMd7ofEUI@Oo5ADE1olc<c<7okRh^0Ko?Cdm1Oooool7ob0P
80Oo4a<C1olK6a/7ob0P80Oooooo1olP8206o`l?3`Ko51@D1_ooool7ocDe=@OoF5QH1ol^;Rh6oiFE
U@Oooooo1omVIVH7obl_;`Ko10@43oooool000gooooo1ol30`<7o`L71`Oo7QhN1on<S8`6okno_`Oo
3Ph>1onXZ:P6ok:b/PKooooo1_m4A4@7oo[jnPOoC4a<1olR8R87ob@T90Oo5QHF1ol00006oc8b<PGo
oooo1olM7Ad7oeQHF0Oono_k1omaLG4>ob/[:`Oo4A4A1_l[:b/5ooooo`OoRHV91om7AdL7oa@D50Oo
@D511omWIfL6olc<c0OoADE51_o9bLT6ooooo`OoXZ:R1om]KFd6ob8R8POo71`L1ol92@T7oa<C4`Oo
9bLW1_oEeMD5ooooo`OoEUIF1oo>c/h7omgMg@OoIFEU1olE5AD7oc<c<`Oo^;Rh1_lm?Cd5ooooo`Oo
820P1olC4a<7oa/K6`Oo820P1oooool7ob0P80Ko3`l?1_lD51@6ooooo`Oo=CDe1omHF5P7obh^;PKo
UIFE1oooool7ofIVIPOo;bl_1_l410@?ooooo`003Oooool7o`0000Oo<30`1olD51@7ojBTY0Koa<C4
1om=CDd7ohj>SPKo_;bl1_ooool6odA4A0Oooooo1oli>CT7o`h>3POo820P1ol<30`7o`410@Ko=CDe
1Oooool7oaLG5`OoJFUY1oooool7of][J`Oo9BDU1ol_;bl7o`0000Ko8b<S1Oooool7oe9BDPOo<C4a
1ol20P87o`d=3@OoZZZZ1_ooool7oeEEE@KoDU9B1_ooool7oiVIV@OoLW9b1_lU9BD7ob0P80Oo0`<3
1ol92@T7obTY:@Kog]kN1Oooool7odm?C`Ooc/k>1oogmoL7oe9BDPOo00001omADE47omSHf0Ko;Bd]
1Oooool7ob8R8POo410@1ol:2PX7ob<S8`Oom?Cd1olE5AD6o`P820Ko1@D51_ooool7ocHf=POoFUYJ
1olX:2P6oiNGU`Ooo?cl1om6ATH7ob4Q8@Ko0`<33oooool000gooooo1ol00007oc0`<0Oo51@D1onT
Y:@6olC4a0OoCDe=1on>SXh6okbl_0Kooooo1_m4A4@7ooooo`Oo>CTi1ol>3Ph7ob0P80Oo30`<1ol1
0@46ocDe=@Gooooo1olG5aL7ofUYJ@Oooooo1om[Jf/7obDU9@Oo;bl_1ol00006ob<S8`Gooooo1omB
DU87oc4a<@Oo0P821ol=3@d7ojZZZPKooooo1omEEED6oe9BDPKooooo1onIVIT7og9bLPKo9BDU1olP
8207o`<30`Oo2@T91olY:BT6omkNgPGooooo1om?Cdl7olk>cPOomoOg1omBDU87o`0000OoDE5A1ooH
f=P6obd];@Gooooo1olR8R87oa0@40Oo2PX:1olS8b<7ooCdm0Oo5ADE1_l820P6o`D51@Kooooo1olf
=SH7oeYJFPOo:2PX1_nGUiL7ooclo0OoATI61olQ8B46o`<30`oooooo000=ooooo`Oo00001ol`<307
oa@D50OoY:BT1_o4a<@7ode=C@OoSXj>1_nl_;`6ooooo`KoA4A41oooool7ocTi>@Oo3Ph>1olP8207
o``<30Oo0@411_le=CD5ooooo`Oo5aLG1omYJFT7ooooo`OoJf][1olU9BD7obl_;`Oo00001_lS8b<5
ooooo`OoDU9B1ola<C47o`820POo3@d=1onZZZX6ooooo`OoEEEE1_mBDU86ooooo`OoVIVI1ombLW86
obDU9@Oo820P1ol30`<7o`T92@Oo:BTY1_oNg]h5ooooo`OoCdm?1oo>c/h7ooOgm`OoDU9B1ol00007
oe5AD@Oof=SH1_l];Bd5ooooo`Oo8R8R1ol@4107o`X:2POo8b<S1oodm?@7oaDE5@Ko20P81_l51@D6
ooooo`Oo=SHf1omJFUX7obPX:0KoUiNG1oolo?`7odI6APOo8B4Q1_l30`<?ooooo`003Oooool7o`00
00Oo<30`1olD51@7ojBTY0Koa<C41om=CDd7ohj>SPKo_;bl1_ooool6odA4A0Oooooo1oli>CT7o`h>
3POo820P1ol<30`7o`410@Ko=CDe1Oooool7oaLG5`OoJFUY1oooool7of][J`Oo9BDU1ol_;bl7o`00
00Ko8b<S1Oooool7oe9BDPOo<C4a1ol20P87o`d=3@OoZZZZ1_ooool7oeEEE@KoDU9B1_ooool7oiVI
V@OoLW9b1_lU9BD7ob0P80Oo0`<31ol92@T7obTY:@Kog]kN1Oooool7odm?C`Ooc/k>1oogmoL7oe9B
DPOo00001omADE47omSHf0Ko;Bd]1Oooool7ob8R8POo410@1ol:2PX7ob<S8`Oom?Cd1olE5AD6o`P8
20Ko1@D51_ooool7ocHf=POoFUYJ1olX:2P6oiNGU`Ooo?cl1om6ATH7ob4Q8@Ko0`<33oooool000go
oooo1ol00007oc0`<0Oo51@D1onTY:@6olC4a0OoCDe=1on>SXh6okbl_0Kooooo1_m4A4@7ooooo`Oo
>CTi1ol>3Ph7ob0P80Oo30`<1ol10@46ocDe=@Gooooo1olG5aL7ofUYJ@Oooooo1om[Jf/7obDU9@Oo
;bl_1ol00006ob<S8`Gooooo1omBDU87oc4a<@Oo0P821ol=3@d7ojZZZPKooooo1omEEED6oe9BDPKo
oooo1onIVIT7og9bLPKo9BDU1olP8207o`<30`Oo2@T91olY:BT6omkNgPGooooo1om?Cdl7olk>cPOo
moOg1omBDU87o`0000OoDE5A1ooHf=P6obd];@Gooooo1olR8R87oa0@40Oo2PX:1olS8b<7ooCdm0Oo
5ADE1_l820P6o`D51@Kooooo1olf=SH7oeYJFPOo:2PX1_nGUiL7ooclo0OoATI61olQ8B46o`<30`oo
oooo000=ooooo`Oo00001ol`<307oa@D50OoY:BT1_o4a<@7ode=C@OoSXj>1_nl_;`6ooooo`KoA4A4
1oooool7ocTi>@Oo3Ph>1olP8207o``<30Oo0@411_le=CD5ooooo`Oo5aLG1omYJFT7ooooo`OoJf][
1olU9BD7obl_;`Oo00001_lS8b<5ooooo`OoDU9B1ola<C47o`820POo3@d=1onZZZX6ooooo`OoEEEE
1_mBDU86ooooo`OoVIVI1ombLW86obDU9@Oo820P1ol30`<7o`T92@Oo:BTY1_oNg]h5ooooo`OoCdm?
1oo>c/h7ooOgm`OoDU9B1ol00007oe5AD@Oof=SH1_l];Bd5ooooo`Oo8R8R1ol@4107o`X:2POo8b<S
1oodm?@7oaDE5@Ko20P81_l51@D6ooooo`Oo=SHf1omJFUX7obPX:0KoUiNG1oolo?`7odI6APOo8B4Q
1_l30`<?ooooo`003Oooool7o`0000Oo<30`1olD51@7ojBTY0Koa<C41om=CDd7ohj>SPKo_;bl1_oo
ool6odA4A0Oooooo1oli>CT7o`h>3POo820P1ol<30`7o`410@Ko=CDe1Oooool7oaLG5`OoJFUY1ooo
ool7of][J`Oo9BDU1ol_;bl7o`0000Ko8b<S1Oooool7oe9BDPOo<C4a1ol20P87o`d=3@OoZZZZ1_oo
ool7oeEEE@KoDU9B1_ooool7oiVIV@OoLW9b1_lU9BD7ob0P80Oo0`<31ol92@T7obTY:@Kog]kN1Ooo
ool7odm?C`Ooc/k>1oogmoL7oe9BDPOo00001omADE47omSHf0Ko;Bd]1Oooool7ob8R8POo410@1ol:
2PX7ob<S8`Oom?Cd1olE5AD6o`P820Ko1@D51_ooool7ocHf=POoFUYJ1olX:2P6oiNGU`Ooo?cl1om6
ATH7ob4Q8@Ko0`<33oooool000gooooo1ol51@D7oa<C4`Oo?clo1on<S8`6ojf][@Oo=3@d1on][Jd6
oh:2PPKooooo1_mFEUH7ooCdm0Oo?Shn1olT92@7ob<S8`Oo410@1ol92@T6ocLg=`Gooooo1olY:BT7
oeQHF0OooOgm1omVIVH7obTY:@Oo:b/[1ol=3@d6ob8R8PGooooo1omjNWX7obPX:0Oo6ATI1omGEeL7
ogemO@Ko^k^k1ola<C46on?Sh`Kooooo1onMWId7ogemO@Ko:RXZ1olN7Qh7o`L71`Oo3@d=1olP8206
on7Qh@Gooooo1omhN7P7ono_k`OoaLG51olf=SH7oa@D50OoBd];1ooBd]86obl_;`Gooooo1olG5aL7
o`l?3`Oo61PH1olW9bL7oo7al@Oo61PH1_lA4A46o`l?3`Kooooo1olk>c/7ofEUI@Oo=3@d1_nVYZH7
ooShn0OoCDe=1olW9bL6o`820Poooooo000=ooooo`Oo1@D51olC4a<7oclo?`OoS8b<1_n][Jd7oc@d
=0Oo[Jf]1_n2PX86ooooo`KoEUIF1oodm?@7ochn?POo92@T1olS8b<7oa0@40Oo2@T91_lg=cL5oooo
o`Oo:BTY1omHF5P7oogmo@OoIVIV1olY:BT7ob/[:`Oo3@d=1_lR8R85ooooo`OoNWYj1olX:2P7oaTI
6@OoEeMG1ommOGd6ok^k^`Oo<C4a1_oShn<6ooooo`OoWIfM1ommOGd6obXZ:POo7QhN1ol71`L7o`d=
3@Oo820P1_oQhN45ooooo`OoN7Qh1oo_knl7olG5a@Oo=SHf1olD51@7od];B`Ood];B1_l_;bl5oooo
o`Oo5aLG1ol?3`l7oaPH60Oo9bLW1ooalO47oaPH60Ko4A4A1_l?3`l6ooooo`Oo>c/k1omUIFD7oc@d
=0KoYZJV1oohn?P7ode=C@Oo9bLW1_l20P8?ooooo`003Oooool7o`D51@Oo4a<C1olo?cl7ohb<S0Ko
[Jf]1old=3@7ojf][@KoPX:21_ooool6oeIFEPOom?Cd1oln?Sh7ob@T90Oo8b<S1ol@4107o`T92@Ko
=cLg1Oooool7obTY:@OoF5QH1oomoOd7ofIVIPOo:BTY1ol[:b/7o`d=3@Ko8R8R1Oooool7ogYjNPOo
:2PX1olI6AT7oeMGE`OoOGem1_nk^k/7oc4a<@Kohn?S1_ooool7oifMW@OoOGem1_lZ:RX7oahN7POo
1`L71ol=3@d7ob0P80KohN7Q1Oooool7ogQhN0Ookno_1oo5aLD7ocHf=POo51@D1om;Bd/7om;BdPKo
;bl_1Oooool7oaLG5`Oo3`l?1olH61P7obLW9`OolO7a1olH61P6oa4A4@Ko3`l?1_ooool7oc/k>`Oo
IFEU1old=3@6ojJVYPOon?Sh1om=CDd7obLW9`Ko0P823oooool000gooooo1ol51@D7oa<C4`Oo?clo
1on<S8`6ojf][@Oo=3@d1on][Jd6oh:2PPKooooo1_mFEUH7ooCdm0Oo?Shn1olT92@7ob<S8`Oo410@
1ol92@T6ocLg=`Gooooo1olY:BT7oeQHF0OooOgm1omVIVH7obTY:@Oo:b/[1ol=3@d6ob8R8PGooooo
1omjNWX7obPX:0Oo6ATI1omGEeL7ogemO@Ko^k^k1ola<C46on?Sh`Kooooo1onMWId7ogemO@Ko:RXZ
1olN7Qh7o`L71`Oo3@d=1olP8206on7Qh@Gooooo1omhN7P7ono_k`OoaLG51olf=SH7oa@D50OoBd];
1ooBd]86obl_;`Gooooo1olG5aL7o`l?3`Oo61PH1olW9bL7oo7al@Oo61PH1_lA4A46o`l?3`Kooooo
1olk>c/7ofEUI@Oo=3@d1_nVYZH7ooShn0OoCDe=1olW9bL6o`820Poooooo000=ooooo`Oo1@D51olC
4a<7oclo?`OoS8b<1_n][Jd7oc@d=0Oo[Jf]1_n2PX86ooooo`KoEUIF1oodm?@7ochn?POo92@T1olS
8b<7oa0@40Oo2@T91_lg=cL5ooooo`Oo:BTY1omHF5P7oogmo@OoIVIV1olY:BT7ob/[:`Oo3@d=1_lR
8R85ooooo`OoNWYj1olX:2P7oaTI6@OoEeMG1ommOGd6ok^k^`Oo<C4a1_oShn<6ooooo`OoWIfM1omm
OGd6obXZ:POo7QhN1ol71`L7o`d=3@Oo820P1_oQhN45ooooo`OoN7Qh1oo_knl7olG5a@Oo=SHf1olD
51@7od];B`Ood];B1_l_;bl5ooooo`Oo5aLG1ol?3`l7oaPH60Oo9bLW1ooalO47oaPH60Ko4A4A1_l?
3`l6ooooo`Oo>c/k1omUIFD7oc@d=0KoYZJV1oohn?P7ode=C@Oo9bLW1_l20P8?ooooo`003Oooool7
o`D51@Oo4a<C1olo?cl7ohb<S0Ko[Jf]1old=3@7ojf][@KoPX:21_ooool6oeIFEPOom?Cd1oln?Sh7
ob@T90Oo8b<S1ol@4107o`T92@Ko=cLg1Oooool7obTY:@OoF5QH1oomoOd7ofIVIPOo:BTY1ol[:b/7
o`d=3@Ko8R8R1Oooool7ogYjNPOo:2PX1olI6AT7oeMGE`OoOGem1_nk^k/7oc4a<@Kohn?S1_ooool7
oifMW@OoOGem1_lZ:RX7oahN7POo1`L71ol=3@d7ob0P80KohN7Q1Oooool7ogQhN0Ookno_1oo5aLD7
ocHf=POo51@D1om;Bd/7om;BdPKo;bl_1Oooool7oaLG5`Oo3`l?1olH61P7obLW9`OolO7a1olH61P6
oa4A4@Ko3`l?1_ooool7oc/k>`OoIFEU1old=3@6ojJVYPOon?Sh1om=CDd7obLW9`Ko0P823oooool0
00gooooo1ol51@D7oa<C4`Oo?clo1on<S8`6ojf][@Oo=3@d1on][Jd6oh:2PPKooooo1_mFEUH7ooCd
m0Oo?Shn1olT92@7ob<S8`Oo410@1ol92@T6ocLg=`Gooooo1olY:BT7oeQHF0OooOgm1omVIVH7obTY
:@Oo:b/[1ol=3@d6ob8R8PGooooo1omjNWX7obPX:0Oo6ATI1omGEeL7ogemO@Ko^k^k1ola<C46on?S
h`Kooooo1onMWId7ogemO@Ko:RXZ1olN7Qh7o`L71`Oo3@d=1olP8206on7Qh@Gooooo1omhN7P7ono_
k`OoaLG51olf=SH7oa@D50OoBd];1ooBd]86obl_;`Gooooo1olG5aL7o`l?3`Oo61PH1olW9bL7oo7a
l@Oo61PH1_lA4A46o`l?3`Kooooo1olk>c/7ofEUI@Oo=3@d1_nVYZH7ooShn0OoCDe=1olW9bL6o`82
0Poooooo000=ooooo`Oo0@411olX:2P7obLW9`Oo];Bd1_ooool7oe5AD@OoUIFE1_o7alL6ooooo`Ko
De=C1ookno/7oc4a<@Oo3Ph>1olX:2P7o`X:2POo30`<1_l/;2`5ooooo`Oo6ATI1om/K6`7ooooo`Oo
GUiN1olO7al7ocDe=@Oo1@D51_lN7Qh5ooooo`Oo?Shn1olU9BD7o`410@Oo;Rh^1oo9bLT6onCTi0Oo
;Rh^1_mCDe<6ooooo`OoWYjN1om`L706obPX:0Oo8B4Q1ol00007oa8B4POo:2PX1_oinOT5ooooo`Oo
Ng]k1ooYjNT7om3@d0Oo9RHV1ol71`L7ogQhN0OokNg]1_lc<c<5ooooo`Oo6ATI1ol61PH7o``<30Oo
=cLg1ooWinL7oa<C4`Ko2@T91_l71`L6ooooo`Oo?clo1omOGel7obd];@KoZJVY1ooNg]h7oc<c<`Oo
7QhN1_l0000?ooooo`003Oooool7o`410@Oo:2PX1olW9bL7okBd]0Kooooo1omADE47oiFEU@KoalO7
1_ooool6oe=CD`Oono_k1ola<C47o`h>3POo:2PX1ol:2PX7o``<30Ko;2`/1Oooool7oaTI6@OoK6a/
1oooool7oeiNGPOo7alO1ole=CD7o`D51@Ko7QhN1Oooool7ochn?POo9BDU1ol10@47obh^;POobLW9
1_oTi>@7obh^;PKoDe=C1_ooool7oijNWPOoL71`1_lX:2P7ob4Q8@Oo00001olB4Q87obPX:0KonOWi
1Oooool7og]kN`OojNWY1oo@d=07obHV9POo1`L71omhN7P7ong]k@Ko<c<c1Oooool7oaTI6@Oo1PH6
1ol<30`7ocLg=`OoinOW1olC4a<6o`T92@Ko1`L71_ooool7oclo?`OoGemO1ol];Bd6ojVYZ@Oog]kN
1olc<c<7oahN7PKo00003oooool000gooooo1ol10@47obPX:0Oo9bLW1ond];@6ooooo`OoDE5A1onE
UID6olO7a`Kooooo1_mCDe<7oo_kn`Oo<C4a1ol>3Ph7obPX:0Oo2PX:1ol<30`6ob`/;0Gooooo1olI
6AT7ofa/K0Oooooo1omNGUh7oalO7`Oo=CDe1ol51@D6oahN7PGooooo1oln?Sh7obDU9@Oo0@411ol^
;Rh7olW9b@Koi>CT1ol^;Rh6oe=CD`Kooooo1onNWYh7og1`L0Ko:2PX1olQ8B47o`0000Oo4Q8B1olX
:2P6ooWin@Gooooo1omkNg/7onWYj@Ood=3@1olV9RH7o`L71`OoN7Qh1oo]kNd6oc<c<`Gooooo1olI
6AT7o`H61POo30`<1olg=cL7onOWi`Oo4a<C1_l92@T6o`L71`Kooooo1olo?cl7oemOG`Oo;Bd]1_nY
ZJT7omkNgPOo<c<c1olN7Qh6o`0000oooooo000=ooooo`Oo0@411olX:2P7obLW9`Oo];Bd1_ooool7
oe5AD@OoUIFE1_o7alL6ooooo`KoDe=C1ookno/7oc4a<@Oo3Ph>1olX:2P7o`X:2POo30`<1_l/;2`5
ooooo`Oo6ATI1om/K6`7ooooo`OoGUiN1olO7al7ocDe=@Oo1@D51_lN7Qh5ooooo`Oo?Shn1olU9BD7
o`410@Oo;Rh^1oo9bLT6onCTi0Oo;Rh^1_mCDe<6ooooo`OoWYjN1om`L706obPX:0Oo8B4Q1ol00007
oa8B4POo:2PX1_oinOT5ooooo`OoNg]k1ooYjNT7om3@d0Oo9RHV1ol71`L7ogQhN0OokNg]1_lc<c<5
ooooo`Oo6ATI1ol61PH7o``<30Oo=cLg1ooWinL7oa<C4`Ko2@T91_l71`L6ooooo`Oo?clo1omOGel7
obd];@KoZJVY1ooNg]h7oc<c<`Oo7QhN1_l0000?ooooo`003Oooool7o`410@Oo:2PX1olW9bL7okBd
]0Kooooo1omADE47oiFEU@KoalO71_ooool6oe=CD`Oono_k1ola<C47o`h>3POo:2PX1ol:2PX7o``<
30Ko;2`/1Oooool7oaTI6@OoK6a/1oooool7oeiNGPOo7alO1ole=CD7o`D51@Ko7QhN1Oooool7ochn
?POo9BDU1ol10@47obh^;POobLW91_oTi>@7obh^;PKoDe=C1_ooool7oijNWPOoL71`1_lX:2P7ob4Q
8@Oo00001olB4Q87obPX:0KonOWi1Oooool7og]kN`OojNWY1oo@d=07obHV9POo1`L71omhN7P7ong]
k@Ko<c<c1Oooool7oaTI6@Oo1PH61ol<30`7ocLg=`OoinOW1olC4a<6o`T92@Ko1`L71_ooool7oclo
?`OoGemO1ol];Bd6ojVYZ@Oog]kN1olc<c<7oahN7PKo00003oooool000gooooo1ol10@47obPX:0Oo
9bLW1ond];@6ooooo`OoDE5A1onEUID6olO7a`Kooooo1_mCDe<7oo_kn`Oo<C4a1ol>3Ph7obPX:0Oo
2PX:1ol<30`6ob`/;0Gooooo1olI6AT7ofa/K0Oooooo1omNGUh7oalO7`Oo=CDe1ol51@D6oahN7PGo
oooo1oln?Sh7obDU9@Oo0@411ol^;Rh7olW9b@Koi>CT1ol^;Rh6oe=CD`Kooooo1onNWYh7og1`L0Ko
:2PX1olQ8B47o`0000Oo4Q8B1olX:2P6ooWin@Gooooo1omkNg/7onWYj@Ood=3@1olV9RH7o`L71`Oo
N7Qh1oo]kNd6oc<c<`Gooooo1olI6AT7o`H61POo30`<1olg=cL7onOWi`Oo4a<C1_l92@T6o`L71`Ko
oooo1olo?cl7oemOG`Oo;Bd]1_nYZJT7omkNgPOo<c<c1olN7Qh6o`0000oooooo000=ooooo`Oo:BTY
1olP8207odA4A0OoT92@1_oclo<7of5QH@Ooclo?1_nGUiL6ooooo`KoI6AT1ooMgMd7oc@d=0Oo:BTY
1olS8b<7oa@D50Oo5aLG1_lj>SX5ooooo`Oo=3@d1omTI6@7onc/k0OoHV9R1olU9BD7oc4a<@Oo9BDU
1_lW9bL5ooooo`OoI6AT1olF5QH7oc4a<@OoI6AT1on7QhL6oiFEU@Oo;2`/1_oNg]h6ooooo`OoTY:B
1omfMWH6ocHf=POo7alO1olA4A47o`l?3`Oo:BTY2oooool7oiBDU0Oom?Cd1onHV9P7oaPH60Oo<30`
1om_Kfl7om?Cd`Ko@T921Oooool7oadM7@Oo3@d=1olN7Qh7od=3@`Ooa/K61olC4a<6oaDE5@Ko51@D
1_ooool7oclo?`OoIVIV1oll?3`6ok2`/0Ooclo?1oll?3`7obPX:0Ko20P83oooool000gooooo1olY
:BT7ob0P80OoA4A41on@T906oo?cl`OoHF5Q1oo?cll6oiNGU`Kooooo1_mTI6@7omgMg@Oo=3@d1olY
:BT7ob<S8`Oo51@D1olG5aL6ocXj>PGooooo1old=3@7ofATI0Ook>c/1omRHV87obDU9@Oo<C4a1olU
9BD6obLW9`Gooooo1omTI6@7oaHF5POo<C4a1omTI6@7ohN7Q`KoUIFE1ol/;2`6omkNgPKooooo1onB
TY87ogIfMPKo=SHf1olO7al7oa4A4@Oo3`l?1olY:BT;ooooo`OoU9BD1oodm?@7oiRHV0Oo61PH1ol`
<307ofm_K`Oodm?C1_m2@T85ooooo`Oo7AdM1ol=3@d7oahN7POo@d=31oo6a/H7oa<C4`Ko5ADE1_lD
51@6ooooo`Oo?clo1omVIVH7oc`l?0Ko/;2`1oo?cll7oc`l?0Oo:2PX1_l820P?ooooo`003Oooool7
obTY:@Oo820P1om4A4@7oi2@T0Kolo?c1omQHF47olo?c`KoUiNG1_ooool6ofATI0OogMgM1old=3@7
obTY:@Oo8b<S1olD51@7oaLG5`Ko>SXj1Oooool7oc@d=0OoI6AT1oo/k>`7of9RHPOo9BDU1ola<C47
obDU9@Ko9bLW1Oooool7ofATI0Oo5QHF1ola<C47ofATI0OoQhN71_nEUID7ob`/;0Kog]kN1_ooool7
oi:BTPOoMWIf1_lf=SH7oalO7`Oo4A4A1ol?3`l7obTY:@_ooooo1onDU9@7ooCdm0OoV9RH1olH61P7
oc0`<0OoKfm_1ooCdm<6od92@PGooooo1olM7Ad7o`d=3@Oo7QhN1om3@d<7olK6aPOo4a<C1_lE5AD6
oa@D50Kooooo1olo?cl7ofIVIPOo?3`l1_n`/;07olo?c`Oo?3`l1olX:2P6o`P820oooooo000=oooo
o`Oo:BTY1olP8207odA4A0OoT92@1_oclo<7of5QH@Ooclo?1_nGUiL6ooooo`KoI6AT1ooMgMd7oc@d
=0Oo:BTY1olS8b<7oa@D50Oo5aLG1_lj>SX5ooooo`Oo=3@d1omTI6@7onc/k0OoHV9R1olU9BD7oc4a
<@Oo9BDU1_lW9bL5ooooo`OoI6AT1olF5QH7oc4a<@OoI6AT1on7QhL6oiFEU@Oo;2`/1_oNg]h6oooo
o`OoTY:B1omfMWH6ocHf=POo7alO1olA4A47o`l?3`Oo:BTY2oooool7oiBDU0Oom?Cd1onHV9P7oaPH
60Oo<30`1om_Kfl7om?Cd`Ko@T921Oooool7oadM7@Oo3@d=1olN7Qh7od=3@`Ooa/K61olC4a<6oaDE
5@Ko51@D1_ooool7oclo?`OoIVIV1oll?3`6ok2`/0Ooclo?1oll?3`7obPX:0Ko20P83oooool000go
oooo1olY:BT7ob0P80OoA4A41on@T906oo?cl`OoHF5Q1oo?cll6oiNGU`Kooooo1_mTI6@7omgMg@Oo
=3@d1olY:BT7ob<S8`Oo51@D1olG5aL6ocXj>PGooooo1old=3@7ofATI0Ook>c/1omRHV87obDU9@Oo
<C4a1olU9BD6obLW9`Gooooo1omTI6@7oaHF5POo<C4a1omTI6@7ohN7Q`KoUIFE1ol/;2`6omkNgPKo
oooo1onBTY87ogIfMPKo=SHf1olO7al7oa4A4@Oo3`l?1olY:BT;ooooo`OoU9BD1oodm?@7oiRHV0Oo
61PH1ol`<307ofm_K`Oodm?C1_m2@T85ooooo`Oo7AdM1ol=3@d7oahN7POo@d=31oo6a/H7oa<C4`Ko
5ADE1_lD51@6ooooo`Oo?clo1omVIVH7oc`l?0Ko/;2`1oo?cll7oc`l?0Oo:2PX1_l820P?ooooo`00
3Oooool7obTY:@Oo820P1om4A4@7oi2@T0Kolo?c1omQHF47olo?c`KoUiNG1_ooool6ofATI0OogMgM
1old=3@7obTY:@Oo8b<S1olD51@7oaLG5`Ko>SXj1Oooool7oc@d=0OoI6AT1oo/k>`7of9RHPOo9BDU
1ola<C47obDU9@Ko9bLW1Oooool7ofATI0Oo5QHF1ola<C47ofATI0OoQhN71_nEUID7ob`/;0Kog]kN
1_ooool7oi:BTPOoMWIf1_lf=SH7oalO7`Oo4A4A1ol?3`l7obTY:@_ooooo1onDU9@7ooCdm0OoV9RH
1olH61P7oc0`<0OoKfm_1ooCdm<6od92@PGooooo1olM7Ad7o`d=3@Oo7QhN1om3@d<7olK6aPOo4a<C
1_lE5AD6oa@D50Kooooo1olo?cl7ofIVIPOo?3`l1_n`/;07olo?c`Oo?3`l1olX:2P6o`P820oooooo
000=ooooo`Oo:BTY1olP8207odA4A0OoT92@1_oclo<7of5QH@Ooclo?1_nGUiL6ooooo`KoI6AT1ooM
gMd7oc@d=0Oo:BTY1olS8b<7oa@D50Oo5aLG1_lj>SX5ooooo`Oo=3@d1omTI6@7onc/k0OoHV9R1olU
9BD7oc4a<@Oo9BDU1_lW9bL5ooooo`OoI6AT1olF5QH7oc4a<@OoI6AT1on7QhL6oiFEU@Oo;2`/1_oN
g]h6ooooo`OoTY:B1omfMWH6ocHf=POo7alO1olA4A47o`l?3`Oo:BTY2oooool7oiBDU0Oom?Cd1onH
V9P7oaPH60Oo<30`1om_Kfl7om?Cd`Ko@T921Oooool7oadM7@Oo3@d=1olN7Qh7od=3@`Ooa/K61olC
4a<6oaDE5@Ko51@D1_ooool7oclo?`OoIVIV1oll?3`6ok2`/0Ooclo?1oll?3`7obPX:0Ko20P83ooo
ool000gooooo1olE5AD7odI6APOo@T921ond];@6olW9b@OoOGem1onXZ:P6oo?cl`Kooooo1_mFEUH7
om?Cd`Oo:BTY1ol@4107obHV9POo4A4A1olE5AD6obTY:@Gooooo1olU9BD7ofQXJ0OocLg=1om;Bd/7
oa/K6`Oo=cLg1ol?3`l6obd];@Gooooo1olR8R87oahN7POo0`<31oll?3`7olg=c@Ko^[Zj1olR8R86
ocXj>PKooooo1on9RHT7ofm_K`Ko9bLW1ol];Bd7oa@D50Oo9bLW1olX:2P6ono_k`Gooooo1on>SXh7
omKFePOoY:BT1olM7Ad7ob<S8`OoUYJF1ooTi>@6oeIFEPGooooo1olD51@7o`0000Oo4a<C1olg=cL7
ojj^[POo410@1_l92@T6o`D51@Kooooo1oll?3`7oeEEE@Oo;bl_1_nQXJ47ok2`/0Oo9BDU1olE5AD6
o`<30`oooooo000=ooooo`Oo5ADE1om6ATH7od92@POo];Bd1_o9bLT7ogemO@OoZ:RX1_oclo<6oooo
o`KoEUIF1ooCdm<7obTY:@Oo410@1olV9RH7oa4A4@Oo5ADE1_lY:BT5ooooo`Oo9BDU1omXJ6P7olg=
c@OoBd];1olK6a/7ocLg=`Oo3`l?1_l];Bd5ooooo`Oo8R8R1olN7Qh7o`<30`Oo?3`l1oo=cLd6okZj
^POo8R8R1_lj>SX6ooooo`OoRHV91om_Kfl6obLW9`Oo;Bd]1olD51@7obLW9`Oo:2PX1_o_knl5oooo
o`OoSXj>1ooFe]H7ojBTY0Oo7AdM1olS8b<7oiJFUPOoi>CT1_mFEUH5ooooo`Oo51@D1ol00007oa<C
4`Oo=cLg1on^[Zh7oa0@40Ko2@T91_l51@D6ooooo`Oo?3`l1omEEED7obl_;`KoXJ6Q1on`/;07obDU
9@Oo5ADE1_l30`<?ooooo`003Oooool7oaDE5@OoATI61om2@T87okBd]0KobLW91ommOGd7ojRXZ0Ko
lo?c1_ooool6oeIFEPOodm?C1olY:BT7oa0@40Oo9RHV1olA4A47oaDE5@Ko:BTY1Oooool7obDU9@Oo
J6QX1oo=cLd7od];B`Oo6a/K1olg=cL7o`l?3`Ko;Bd]1Oooool7ob8R8POo7QhN1ol30`<7oc`l?0Oo
cLg=1_nj^[X7ob8R8PKo>SXj1_ooool7ohV9R@OoKfm_1_lW9bL7obd];@Oo51@D1olW9bL7obPX:0Ko
kno_1Oooool7ohj>SPOoe]KF1onTY:@7oadM7@Oo8b<S1onFUYH7onCTi0KoEUIF1Oooool7oa@D50Oo
00001olC4a<7ocLg=`Oo[Zj^1ol@4106o`T92@Ko1@D51_ooool7oc`l?0OoEEEE1ol_;bl6oj6QX@Oo
/;2`1olU9BD7oaDE5@Ko0`<33oooool000gooooo1olE5AD7odI6APOo@T921ond];@6olW9b@OoOGem
1onXZ:P6oo?cl`Kooooo1_mFEUH7om?Cd`Oo:BTY1ol@4107obHV9POo4A4A1olE5AD6obTY:@Gooooo
1olU9BD7ofQXJ0OocLg=1om;Bd/7oa/K6`Oo=cLg1ol?3`l6obd];@Gooooo1olR8R87oahN7POo0`<3
1oll?3`7olg=c@Ko^[Zj1olR8R86ocXj>PKooooo1on9RHT7ofm_K`Ko9bLW1ol];Bd7oa@D50Oo9bLW
1olX:2P6ono_k`Gooooo1on>SXh7omKFePOoY:BT1olM7Ad7ob<S8`OoUYJF1ooTi>@6oeIFEPGooooo
1olD51@7o`0000Oo4a<C1olg=cL7ojj^[POo410@1_l92@T6o`D51@Kooooo1oll?3`7oeEEE@Oo;bl_
1_nQXJ47ok2`/0Oo9BDU1olE5AD6o`<30`oooooo000=ooooo`Oo5ADE1om6ATH7od92@POo];Bd1_o9
bLT7ogemO@OoZ:RX1_oclo<6ooooo`KoEUIF1ooCdm<7obTY:@Oo410@1olV9RH7oa4A4@Oo5ADE1_lY
:BT5ooooo`Oo9BDU1omXJ6P7olg=c@OoBd];1olK6a/7ocLg=`Oo3`l?1_l];Bd5ooooo`Oo8R8R1olN
7Qh7o`<30`Oo?3`l1oo=cLd6okZj^POo8R8R1_lj>SX6ooooo`OoRHV91om_Kfl6obLW9`Oo;Bd]1olD
51@7obLW9`Oo:2PX1_o_knl5ooooo`OoSXj>1ooFe]H7ojBTY0Oo7AdM1olS8b<7oiJFUPOoi>CT1_mF
EUH5ooooo`Oo51@D1ol00007oa<C4`Oo=cLg1on^[Zh7oa0@40Ko2@T91_l51@D6ooooo`Oo?3`l1omE
EED7obl_;`KoXJ6Q1on`/;07obDU9@Oo5ADE1_l30`<?ooooo`003Oooool7oaDE5@OoATI61om2@T87
okBd]0KobLW91ommOGd7ojRXZ0Kolo?c1_ooool6oeIFEPOodm?C1olY:BT7oa0@40Oo9RHV1olA4A47
oaDE5@Ko:BTY1Oooool7obDU9@OoJ6QX1oo=cLd7od];B`Oo6a/K1olg=cL7o`l?3`Ko;Bd]1Oooool7
ob8R8POo7QhN1ol30`<7oc`l?0OocLg=1_nj^[X7ob8R8PKo>SXj1_ooool7ohV9R@OoKfm_1_lW9bL7
obd];@Oo51@D1olW9bL7obPX:0Kokno_1Oooool7ohj>SPOoe]KF1onTY:@7oadM7@Oo8b<S1onFUYH7
onCTi0KoEUIF1Oooool7oa@D50Oo00001olC4a<7ocLg=`Oo[Zj^1ol@4106o`T92@Ko1@D51_ooool7
oc`l?0OoEEEE1ol_;bl6oj6QX@Oo/;2`1olU9BD7oaDE5@Ko0`<33oooool000gooooo1olE5AD7odI6
APOo@T921ond];@6olW9b@OoOGem1onXZ:P6oo?cl`Kooooo1_mFEUH7om?Cd`Oo:BTY1ol@4107obHV
9POo4A4A1olE5AD6obTY:@Gooooo1olU9BD7ofQXJ0OocLg=1om;Bd/7oa/K6`Oo=cLg1ol?3`l6obd]
;@Gooooo1olR8R87oahN7POo0`<31oll?3`7olg=c@Ko^[Zj1olR8R86ocXj>PKooooo1on9RHT7ofm_
K`Ko9bLW1ol];Bd7oa@D50Oo9bLW1olX:2P6ono_k`Gooooo1on>SXh7omKFePOoY:BT1olM7Ad7ob<S
8`OoUYJF1ooTi>@6oeIFEPGooooo1olD51@7o`0000Oo4a<C1olg=cL7ojj^[POo410@1_l92@T6o`D5
1@Kooooo1oll?3`7oeEEE@Oo;bl_1_nQXJ47ok2`/0Oo9BDU1olE5AD6o`<30`oooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-1.97241, \
-0.428616, 0.147467, 0.147467}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-10.7743, -0.428616, 0.147467, 0.147467}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-19.5537, -0.423519, 0.147297, 0.147297}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-28.3874, -0.428616, 0.147467, 0.147467}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-37.1894, -0.428616, 0.147467, 0.147467}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-45.9384, -0.423519, 0.147297, \
0.147297}, {{371.625, 425.875}, {116.812, 62.5}} -> {-54.8024, -0.428616, \
0.147467, 0.147467}, {{431.312, 485.562}, {116.812, 62.5}} -> {-63.6044, \
-0.428616, 0.147467, 0.147467}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-1.97241, -9.23055, 0.147467, 0.147467}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-10.7743, -9.23055, 0.147467, 0.147467}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-19.5537, -9.21532, 0.147297, 0.147297}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-28.3874, -9.23055, 0.147467, 0.147467}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-37.1894, -9.23055, 0.147467, \
0.147467}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-45.9384, -9.21532, \
0.147297, 0.147297}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-54.8024, \
-9.23055, 0.147467, 0.147467}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-63.6044, -9.23055, 0.147467, 0.147467}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F7FBD7379513030
0091D48B805D4717
2AA7D7A2A15F324C
0E77AF986C64541E
2EB8E7C6BB853F3A
219DB8B487C77931
48B1E5FF999C6770
1461D642432E1D04
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A178BAF0E5A253C
52339AD91B4B2525
692673FF10593A21
602F66DE1F442E2C
883036C00B4F482F
6D45287F12533444
883B0C8200484A3B
53356979174A3844
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
110D04000804093E
040D060306040617
070808010802121A
080E020005080517
021609000A060619
0F1C0505070C0421
0D1810060A05131E
39221C12181B19FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7C2E045702473233
A04D0647125F3261
8B960E440D683F4D
9ABE0044187C6D69
72FF0555317B866F
57D4104C2E6BB949
35CB063B5353AE45
4B531F4A254D5A26
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F1F31AAEFC6AA8A
03011F8CEFC5BA72
12110A74D3D8B894
1300236CBDDABA95
1F1611538AB7B79D
1F0E09529B93AA7E
211C23488D897974
25335CD3FFF5F298
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
831331077F290964
C6144B0E89411861
D20F4C20979E132F
FF0D451C9DC61A5B
BB115B3078FE0C4E
9A09453A58E70F72
65145A3A1DD4006A
3708322E3C431383
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C39245256103EFF
08352B386D144EDA
0631312D6A1440AB
093726185D0D4276
002C221048093E4E
0533110531012C41
0040180D2B00303F
133A174B38132A84
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0549122812102F77
0A3E1D45201329B3
0847293C2A192CFF
0027353D4B1E39FF
00353F2E582435F9
06243B285B2248D4
041F36115A1D349C
04361F1A29132130
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C2C1123173B3A87
33030F001B1B3575
1C1B071610463C84
290B1707231C3572
301E171E20343D98
37041A10240B3777
2E10130F201F3D87
A6737A6A968DA8FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
111F3607210F294E
262C5500120D244B
394C930D28163E65
4792EB434521434C
4E6AF96A4C3F4D56
425AFF826B4C3D41
384CB0625A4F3E60
1E393830472A325E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6F3C17180C111BD2
7749130E0B0523D7
814D2B2A09071CFF
7D4510120F0516CC
713D1C1A050021F3
6E3B1E11060019C7
63542522142328E6
AB5C482D2B2348B0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
60F434433B537359
51FF28443A4D9342
27B7213854418E3C
0B6F1A2E4B388E1E
183B0C2746166B20
172F00341D0B4444
2E36053A27173E74
7E933E401F553F35
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
161D2A241E192832
0B090E15010D0B26
0F121814130E1017
000C081307080821
040C06130A151018
000F0B0C0E030931
17121A0F1D161626
C0F4DCFFEFEAECB6
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8D19673160FF1C6A
7509454461EF1C7D
54155A2E2DAC1192
2A00572F176E0E64
32006739044E0668
2F0F87450A471848
420F80690E5C143C
8A216B407791253E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
322FE42C461F59D5
1B16B620432B28FF
21085D0F4F1319BF
36013904461911DB
5B0E300E80210079
9D29381B87441850
A821512799642141
6955DD30713C6C85
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
064300243013431A
083B06181A0D3B1F
0F3507261405322C
1B3B0C370B0B1E63
1C3F0B3A1E0F2DB2
183A1A3D301022D4
1B3F2F42410F31FF
173B12293825474F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool7o`l?3`OoOgmo1onm
_Kd7og=cL`KoNGUi1omADE4=oc0`<0Kooooo1_mJFUX7oaLG5`OoRh^;1on_[jl7o`h>3POoFUYJ1olU
9BD6oc`l?0Gooooo1olA4A47o`d=3@Oo10@41ol00007o`P820Oo10@41ol92@T6ochn?PGooooo1oml
O7`7obh^;POo10@41omGEeL7o`820PKoAdM71olb<S86oc<c<`Kooooo3_lO7al6oc4a<@OoZZZZ1oo_
knl7olK6aPOoZZZZ1_n:RXX5ooooo`OoPh>31olC4a<7oc4a<@Oo1`L71omoOgl7obTY:@Oo2@T91_mT
I6@5ooooo`Oo30`<1oli>CT7ob@T90OoDU9B1omFEUH7oa0@40Ko?Shn3?ooool7o`D51@OoBDU91olB
4Q86obPX:0Oo4Q8B1ol@4107obl_;`KoMgMg3oooool000gooooo1ol?3`l7ogmoO`Oo_Kfm1omcLg<6
ogUiN@OoDE5A3Ol`<306ooooo`KoFUYJ1olG5aL7oh^;R`Oo[jn_1ol>3Ph7oeYJFPOo9BDU1_ll?3`5
ooooo`Oo4A4A1ol=3@d7o`@410Oo00001ol820P7o`@410Oo2@T91_ln?Sh5ooooo`OoO7al1ol^;Rh7
o`@410OoEeMG1ol20P86odM7A`Oo<S8b1_lc<c<6ooooo`ko7alO1_la<C47ojZZZPOokno_1oo6a/H7
ojZZZPKoRXZ:1Oooool7oh>3P`Oo4a<C1ola<C47o`L71`OoOgmo1olY:BT7o`T92@KoI6AT1Oooool7
o``<30Oo>CTi1olT92@7oe9BDPOoEUIF1ol@4106ochn?Pcooooo1ol51@D7odU9B@Oo4Q8B1_lX:2P7
oa8B4POo410@1ol_;bl6ogMgM`oooooo000=ooooo`Oo3`l?1omoOgl7okfm_@OoLg=c1_miNGT7oe5A
D@go<30`1_ooool6oeYJFPOo5aLG1on;Rh/7ojn_[`Oo3Ph>1omJFUX7obDU9@Ko?3`l1Oooool7oa4A
4@Oo3@d=1ol410@7o`0000Oo20P81ol410@7o`T92@Ko?Shn1Oooool7ogalO0Oo;Rh^1ol410@7oeMG
E`Oo0P821_m7AdL7oc8b<PKo<c<c1_ooool>oalO7`Ko<C4a1onZZZX7ono_k`Ooa/K61onZZZX6ohZ:
RPGooooo1on3Ph<7oa<C4`Oo<C4a1ol71`L7ogmoO`Oo:BTY1ol92@T6ofATI0Gooooo1ol<30`7ocTi
>@Oo92@T1omBDU87oeIFEPOo410@1_ln?Sh<ooooo`Oo1@D51om9BDT7oa8B4PKo:2PX1olB4Q87oa0@
40Oo;bl_1_mgMgL?ooooo`003Oooool7o`l?3`OoOgmo1onm_Kd7og=cL`KoNGUi1omADE4=oc0`<0Ko
oooo1_mJFUX7oaLG5`OoRh^;1on_[jl7o`h>3POoFUYJ1olU9BD6oc`l?0Gooooo1olA4A47o`d=3@Oo
10@41ol00007o`P820Oo10@41ol92@T6ochn?PGooooo1omlO7`7obh^;POo10@41omGEeL7o`820PKo
AdM71olb<S86oc<c<`Kooooo3_lO7al6oc4a<@OoZZZZ1oo_knl7olK6aPOoZZZZ1_n:RXX5ooooo`Oo
Ph>31olC4a<7oc4a<@Oo1`L71omoOgl7obTY:@Oo2@T91_mTI6@5ooooo`Oo30`<1oli>CT7ob@T90Oo
DU9B1omFEUH7oa0@40Ko?Shn3?ooool7o`D51@OoBDU91olB4Q86obPX:0Oo4Q8B1ol@4107obl_;`Ko
MgMg3oooool000gooooo1ol?3`l7ogmoO`Oo_Kfm1omcLg<6ogUiN@OoDE5A3Ol`<306ooooo`KoFUYJ
1olG5aL7oh^;R`Oo[jn_1ol>3Ph7oeYJFPOo9BDU1_ll?3`5ooooo`Oo4A4A1ol=3@d7o`@410Oo0000
1ol820P7o`@410Oo2@T91_ln?Sh5ooooo`OoO7al1ol^;Rh7o`@410OoEeMG1ol20P86odM7A`Oo<S8b
1_lc<c<6ooooo`ko7alO1_la<C47ojZZZPOokno_1oo6a/H7ojZZZPKoRXZ:1Oooool7oh>3P`Oo4a<C
1ola<C47o`L71`OoOgmo1olY:BT7o`T92@KoI6AT1Oooool7o``<30Oo>CTi1olT92@7oe9BDPOoEUIF
1ol@4106ochn?Pcooooo1ol51@D7odU9B@Oo4Q8B1_lX:2P7oa8B4POo410@1ol_;bl6ogMgM`oooooo
000=ooooo`Oo3`l?1omoOgl7okfm_@OoLg=c1_miNGT7oe5AD@go<30`1_ooool6oeYJFPOo5aLG1on;
Rh/7ojn_[`Oo3Ph>1omJFUX7obDU9@Ko?3`l1Oooool7oa4A4@Oo3@d=1ol410@7o`0000Oo20P81ol4
10@7o`T92@Ko?Shn1Oooool7ogalO0Oo;Rh^1ol410@7oeMGE`Oo0P821_m7AdL7oc8b<PKo<c<c1_oo
ool>oalO7`Ko<C4a1onZZZX7ono_k`Ooa/K61onZZZX6ohZ:RPGooooo1on3Ph<7oa<C4`Oo<C4a1ol7
1`L7ogmoO`Oo:BTY1ol92@T6ofATI0Gooooo1ol<30`7ocTi>@Oo92@T1omBDU87oeIFEPOo410@1_ln
?Sh<ooooo`Oo1@D51om9BDT7oa8B4PKo:2PX1olB4Q87oa0@40Oo;bl_1_mgMgL?ooooo`003Oooool7
o`0000OoTI6A1ooDe=@7oh^;R`KoP8201omMGEd7odM7A`Ko5aLG1_ooool6oe9BDPOo<c<c1onJVYX7
omWIf@Oo6a/K1om;Bd/=obDU9@Gooooo1ol410@7o`d=3@Oo1PH61ol30`<7o`H61POo10@41ol61PH6
oaLG5`Gooooo1onPX:07ode=C@Oo1PH61om7AdL7oa8B4PKoGemO1olb<S86of5QH@Kooooo1ol30`<7
o`410@Ko7alO1on<S8`7ono_k`OoaLG51onj^[X6og9bLPGooooo1oo6a/H7oa@D50OoBd];1ol>3Ph7
ohV9R@Oo@D511olH61P6of5QH@Gooooo1ol820P7ocDe=@Oo:b/[1olh>3P7ofe]K@Oo51@D1_m>CTh6
om[JfPKooooo1ol:2PX7ochn?POo7AdM1_m5ADD7ob0P80Oo4a<C1olY:BT6ok>c/`oooooo000=oooo
o`Oo00001onATI47omCDe0OoRh^;1_n0P807oeeMG@OoAdM71_lG5aL6ooooo`KoDU9B1olc<c<7oiZJ
VPOofMWI1olK6a/7od];B`go9BDU1Oooool7o`@410Oo3@d=1ol61PH7o`<30`Oo1PH61ol410@7o`H6
1PKo5aLG1Oooool7oj2PX0OoCDe=1ol61PH7odM7A`Oo4Q8B1_mOGel7oc8b<PKoHF5Q1_ooool7o`<3
0`Oo0@411_lO7al7ohb<S0Ookno_1oo5aLD7okZj^PKoLW9b1Oooool7olK6aPOo51@D1om;Bd/7o`h>
3POoRHV91om1@D47oaPH60KoHF5Q1Oooool7o`P820Oo=CDe1ol[:b/7ocPh>0OoKFe]1olD51@6odi>
CPKof][J1_ooool7o`X:2POo?Shn1olM7Ad6odE5A@Oo820P1olC4a<7obTY:@Ko/k>c3oooool000go
oooo1ol00007oi6AT@Ooe=CD1on;Rh/6oh20P0OoGEeM1om7AdL6oaLG5`Kooooo1_mBDU87oc<c<`Oo
VYZJ1ooIfMT7oa/K6`OoBd];3OlU9BD5ooooo`Oo10@41ol=3@d7o`H61POo0`<31ol61PH7o`@410Oo
1PH61_lG5aL5ooooo`OoX:2P1om=CDd7o`H61POoAdM71olB4Q86oemOG`Oo<S8b1_mQHF46ooooo`Oo
0`<31ol10@46oalO7`OoS8b<1oo_knl7olG5a@Oo^[Zj1_mbLW85ooooo`Ooa/K61olD51@7od];B`Oo
3Ph>1on9RHT7od51@@Oo61PH1_mQHF45ooooo`Oo20P81ole=CD7ob/[:`Oo>3Ph1om]KFd7oa@D50Ko
CTi>1_oJf]X6ooooo`Oo2PX:1oln?Sh7oadM7@KoADE51olP8207oa<C4`Oo:BTY1_nc/k<?ooooo`00
3Oooool7o`0000OoTI6A1ooDe=@7oh^;R`KoP8201omMGEd7odM7A`Ko5aLG1_ooool6oe9BDPOo<c<c
1onJVYX7omWIf@Oo6a/K1om;Bd/=obDU9@Gooooo1ol410@7o`d=3@Oo1PH61ol30`<7o`H61POo10@4
1ol61PH6oaLG5`Gooooo1onPX:07ode=C@Oo1PH61om7AdL7oa8B4PKoGemO1olb<S86of5QH@Kooooo
1ol30`<7o`410@Ko7alO1on<S8`7ono_k`OoaLG51onj^[X6og9bLPGooooo1oo6a/H7oa@D50OoBd];
1ol>3Ph7ohV9R@Oo@D511olH61P6of5QH@Gooooo1ol820P7ocDe=@Oo:b/[1olh>3P7ofe]K@Oo51@D
1_m>CTh6om[JfPKooooo1ol:2PX7ochn?POo7AdM1_m5ADD7ob0P80Oo4a<C1olY:BT6ok>c/`oooooo
000=ooooo`Oo00001onATI47omCDe0OoRh^;1_n0P807oeeMG@OoAdM71_lG5aL6ooooo`KoDU9B1olc
<c<7oiZJVPOofMWI1olK6a/7od];B`go9BDU1Oooool7o`@410Oo3@d=1ol61PH7o`<30`Oo1PH61ol4
10@7o`H61PKo5aLG1Oooool7oj2PX0OoCDe=1ol61PH7odM7A`Oo4Q8B1_mOGel7oc8b<PKoHF5Q1_oo
ool7o`<30`Oo0@411_lO7al7ohb<S0Ookno_1oo5aLD7okZj^PKoLW9b1Oooool7olK6aPOo51@D1om;
Bd/7o`h>3POoRHV91om1@D47oaPH60KoHF5Q1Oooool7o`P820Oo=CDe1ol[:b/7ocPh>0OoKFe]1olD
51@6odi>CPKof][J1_ooool7o`X:2POo?Shn1olM7Ad6odE5A@Oo820P1olC4a<7obTY:@Ko/k>c3ooo
ool000gooooo1ol00007oi6AT@Ooe=CD1on;Rh/6oh20P0OoGEeM1om7AdL6oaLG5`Kooooo1_mBDU87
oc<c<`OoVYZJ1ooIfMT7oa/K6`OoBd];3OlU9BD5ooooo`Oo10@41ol=3@d7o`H61POo0`<31ol61PH7
o`@410Oo1PH61_lG5aL5ooooo`OoX:2P1om=CDd7o`H61POoAdM71olB4Q86oemOG`Oo<S8b1_mQHF46
ooooo`Oo0`<31ol10@46oalO7`OoS8b<1oo_knl7olG5a@Oo^[Zj1_mbLW85ooooo`Ooa/K61olD51@7
od];B`Oo3Ph>1on9RHT7od51@@Oo61PH1_mQHF45ooooo`Oo20P81ole=CD7ob/[:`Oo>3Ph1om]KFd7
oa@D50KoCTi>1_oJf]X6ooooo`Oo2PX:1oln?Sh7oadM7@KoADE51olP8207oa<C4`Oo:BTY1_nc/k<?
ooooo`003Oooool7o`0000OoTI6A1ooDe=@7oh^;R`KoP8201omMGEd7odM7A`Ko5aLG1_ooool6oe9B
DPOo<c<c1onJVYX7omWIf@Oo6a/K1om;Bd/=obDU9@Gooooo1ol410@7o`d=3@Oo1PH61ol30`<7o`H6
1POo10@41ol61PH6oaLG5`Gooooo1onPX:07ode=C@Oo1PH61om7AdL7oa8B4PKoGemO1olb<S86of5Q
H@Kooooo1ol30`<7o`410@Ko7alO1on<S8`7ono_k`OoaLG51onj^[X6og9bLPGooooo1oo6a/H7oa@D
50OoBd];1ol>3Ph7ohV9R@Oo@D511olH61P6of5QH@Gooooo1ol820P7ocDe=@Oo:b/[1olh>3P7ofe]
K@Oo51@D1_m>CTh6om[JfPKooooo1ol:2PX7ochn?POo7AdM1_m5ADD7ob0P80Oo4a<C1olY:BT6ok>c
/`oooooo000=ooooo`Oo:RXZ1onWYjL7omOGe`OoXZ:R1_nQXJ47oemOG`Oo<S8b1_m<C4`6ooooo`Ko
JFUY1olV9RH7og=cL`Oooooo1ol@4107oeUIF@Oo>SXj1_lQ8B45ooooo`Oo1`L73_l820P7o`410@Oo
20P81ol20P87oa8B4PKo6QXJ1Oooool7oh^;R`OoUYJF1ol>3Ph7odA4A0Oo3@d=1_mXJ6P7oclo?`Ko
CDe=1_ooool7oa8B4POo4A4A1_l:2PX7ogAdM0Oodm?C1ooHf=P7okRh^0KoU9BD1Oooool7om;BdPOo
3`l?1om<C4`7ob0P80OoUiNG1onNWYh7oa<C4`Ko;bl_1Oooool7o`H61Pko<C4a1ol];Bd7ofYZJPOo
51@D1_m0@406oj^[Z`Kooooo1ol820P7odM7A`Oo:BTY1_ll?3`7obXZ:POo6ATI1ol/;2`Eooooo`00
3Oooool7obXZ:POoYjNW1ooGemL7oj:RXPKoXJ6Q1omOGel7oc8b<PKoC4a<1_ooool6ofUYJ@Oo9RHV
1omcLg<7ooooo`Oo410@1omIFET7ocXj>PKo8B4Q1Oooool7o`L71`ko20P81ol10@47o`P820Oo0P82
1olB4Q86oaXJ6PGooooo1on;Rh/7oiJFUPOo3Ph>1om4A4@7o`d=3@KoJ6QX1olo?cl6ode=C@Kooooo
1olB4Q87oa4A4@Ko2PX:1omdM7@7om?Cd`Oof=SH1onh^;P6oiBDU0Gooooo1ooBd]87o`l?3`OoC4a<
1olP8207oiNGU`OoWYjN1olC4a<6obl_;`Gooooo1ol61PH>oc4a<@Oo;Bd]1omZJVX7oa@D50Ko@410
1_n[Zj/6ooooo`Oo20P81om7AdL7obTY:@Ko?3`l1olZ:RX7oaTI6@Oo;2`/5Oooool000gooooo1olZ
:RX7ojNWY`OoemOG1onRXZ86oj6QX@OoGemO1olb<S86oda<C0Kooooo1_mYJFT7obHV9POoLg=c1ooo
ool7oa0@40OoFEUI1olj>SX6ob4Q8@Gooooo1ol71`L>o`P820Oo0@411ol820P7o`820POo4Q8B1_lJ
6QX5ooooo`OoRh^;1onFUYH7o`h>3POoA4A41ol=3@d6ofQXJ0Oo?clo1_m=CDd6ooooo`Oo4Q8B1olA
4A46o`X:2POoM7Ad1ooCdm<7omSHf0Oo^;Rh1_nDU9@5ooooo`Ood];B1ol?3`l7oda<C0Oo820P1onG
UiL7oijNWPOo4a<C1_l_;bl5ooooo`Oo1PH63_la<C47obd];@OoJVYZ1olD51@6od10@0KoZj^[1_oo
ool7o`P820OoAdM71olY:BT6oc`l?0Oo:RXZ1olI6AT7ob`/;1Gooooo000=ooooo`Oo:RXZ1onWYjL7
omOGe`OoXZ:R1_nQXJ47oemOG`Oo<S8b1_m<C4`6ooooo`KoJFUY1olV9RH7og=cL`Oooooo1ol@4107
oeUIF@Oo>SXj1_lQ8B45ooooo`Oo1`L73_l820P7o`410@Oo20P81ol20P87oa8B4PKo6QXJ1Oooool7
oh^;R`OoUYJF1ol>3Ph7odA4A0Oo3@d=1_mXJ6P7oclo?`KoCDe=1_ooool7oa8B4POo4A4A1_l:2PX7
ogAdM0Oodm?C1ooHf=P7okRh^0KoU9BD1Oooool7om;BdPOo3`l?1om<C4`7ob0P80OoUiNG1onNWYh7
oa<C4`Ko;bl_1Oooool7o`H61Pko<C4a1ol];Bd7ofYZJPOo51@D1_m0@406oj^[Z`Kooooo1ol820P7
odM7A`Oo:BTY1_ll?3`7obXZ:POo6ATI1ol/;2`Eooooo`003Oooool7obXZ:POoYjNW1ooGemL7oj:R
XPKoXJ6Q1omOGel7oc8b<PKoC4a<1_ooool6ofUYJ@Oo9RHV1omcLg<7ooooo`Oo410@1omIFET7ocXj
>PKo8B4Q1Oooool7o`L71`ko20P81ol10@47o`P820Oo0P821olB4Q86oaXJ6PGooooo1on;Rh/7oiJF
UPOo3Ph>1om4A4@7o`d=3@KoJ6QX1olo?cl6ode=C@Kooooo1olB4Q87oa4A4@Ko2PX:1omdM7@7om?C
d`Oof=SH1onh^;P6oiBDU0Gooooo1ooBd]87o`l?3`OoC4a<1olP8207oiNGU`OoWYjN1olC4a<6obl_
;`Gooooo1ol61PH>oc4a<@Oo;Bd]1omZJVX7oa@D50Ko@4101_n[Zj/6ooooo`Oo20P81om7AdL7obTY
:@Ko?3`l1olZ:RX7oaTI6@Oo;2`/5Oooool000gooooo1olZ:RX7ojNWY`OoemOG1onRXZ86oj6QX@Oo
GemO1olb<S86oda<C0Kooooo1_mYJFT7obHV9POoLg=c1oooool7oa0@40OoFEUI1olj>SX6ob4Q8@Go
oooo1ol71`L>o`P820Oo0@411ol820P7o`820POo4Q8B1_lJ6QX5ooooo`OoRh^;1onFUYH7o`h>3POo
A4A41ol=3@d6ofQXJ0Oo?clo1_m=CDd6ooooo`Oo4Q8B1olA4A46o`X:2POoM7Ad1ooCdm<7omSHf0Oo
^;Rh1_nDU9@5ooooo`Ood];B1ol?3`l7oda<C0Oo820P1onGUiL7oijNWPOo4a<C1_l_;bl5ooooo`Oo
1PH63_la<C47obd];@OoJVYZ1olD51@6od10@0KoZj^[1_ooool7o`P820OoAdM71olY:BT6oc`l?0Oo
:RXZ1olI6AT7ob`/;1Gooooo000=ooooo`Oo:RXZ1onWYjL7omOGe`OoXZ:R1_nQXJ47oemOG`Oo<S8b
1_m<C4`6ooooo`KoJFUY1olV9RH7og=cL`Oooooo1ol@4107oeUIF@Oo>SXj1_lQ8B45ooooo`Oo1`L7
3_l820P7o`410@Oo20P81ol20P87oa8B4PKo6QXJ1Oooool7oh^;R`OoUYJF1ol>3Ph7odA4A0Oo3@d=
1_mXJ6P7oclo?`KoCDe=1_ooool7oa8B4POo4A4A1_l:2PX7ogAdM0Oodm?C1ooHf=P7okRh^0KoU9BD
1Oooool7om;BdPOo3`l?1om<C4`7ob0P80OoUiNG1onNWYh7oa<C4`Ko;bl_1Oooool7o`H61Pko<C4a
1ol];Bd7ofYZJPOo51@D1_m0@406oj^[Z`Kooooo1ol820P7odM7A`Oo:BTY1_ll?3`7obXZ:POo6ATI
1ol/;2`Eooooo`003Oooool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_oo
ool6of1PH0Oo;bl_1omVIVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol2
0P87o`0000Oo1@D51ol820P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_ml
O7`7ofe]K@KoJFUY1_ooool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?oo
ool7o`d=3@OoADE51olL71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH
61P7oeeMG@Oo3@d=1_m2@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli
>CTEooooo`003Oooool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_ooool6
of1PH0Oo;bl_1omVIVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol20P87
o`0000Oo1@D51ol820P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_mlO7`7
ofe]K@KoJFUY1_ooool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?ooool7
o`d=3@OoADE51olL71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH61P7
oeeMG@Oo3@d=1_m2@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli>CTE
ooooo`003Oooool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_ooool6of1P
H0Oo;bl_1omVIVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol20P87o`00
00Oo1@D51ol820P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_mlO7`7ofe]
K@KoJFUY1_ooool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?ooool7o`d=
3@OoADE51olL71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH61P7oeeM
G@Oo3@d=1_m2@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli>CTEoooo
o`003Oooool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_ooool6of1PH0Oo
;bl_1omVIVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol20P87o`0000Oo
1@D51ol820P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_mlO7`7ofe]K@Ko
JFUY1_ooool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?ooool7o`d=3@Oo
ADE51olL71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH61P7oeeMG@Oo
3@d=1_m2@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli>CTEooooo`00
3Oooool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_ooool6of1PH0Oo;bl_
1omVIVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol20P87o`0000Oo1@D5
1ol820P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_mlO7`7ofe]K@KoJFUY
1_ooool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?ooool7o`d=3@OoADE5
1olL71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH61P7oeeMG@Oo3@d=
1_m2@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli>CTEooooo`003Ooo
ool7o`h>3POoMgMg1on_[jl7oiRHV0KoK6a/1omTI6@7oeADE0Ko7QhN1_ooool6of1PH0Oo;bl_1omV
IVH7omkNgPOo7alO1om4A4@7obh^;PKo;2`/1Oooool7o`P820Oo3Ph>1ol20P87o`0000Oo1@D51ol8
20P7o`D51@Ko5aLG1Oooool7oiZJVPOo_[jn1ol00007odA4A0Oo61PH1_mlO7`7ofe]K@KoJFUY1_oo
ool7oa<C4`Oo00001_lS8b<7ofa/K0Oo_Kfm1ooJf]X7okZj^PKoUIFE3?ooool7o`d=3@OoADE51olL
71`7oifMW@Ooa/K61olJ6QX6oe]KF`Gooooo1ol92@T7ocLg=`Oo9RHV1olH61P7oeeMG@Oo3@d=1_m2
@T86ogIfMPKooooo1ol00007obLW9`Oo=CDe1_lm?Cd7od];B`Oo7QhN1oli>CTEooooo`003Oooool7
obh^;POo^;Rh1ooWinL7olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7
ol30`0Oo2`/;1om?Cdl7odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6
oaTI6@Gooooo1ombLW87ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7
oaHF5PKo4A4A1omCDe<7ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7
ooknoPOo30`<1_m>CTh5ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6
ooooo`Oo00001ole=CD7oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^
;POo^;Rh1ooWinL7olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30
`0Oo2`/;1om?Cdl7odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI
6@Gooooo1ombLW87ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF
5PKo4A4A1omCDe<7ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ookn
oPOo30`<1_m>CTh5ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6oooo
o`Oo00001ole=CD7oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^;POo
^;Rh1ooWinL7olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30`0Oo
2`/;1om?Cdl7odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI6@Go
oooo1ombLW87ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF5PKo
4A4A1omCDe<7ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ooknoPOo
30`<1_m>CTh5ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6ooooo`Oo
00001ole=CD7oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^;POo^;Rh
1ooWinL7olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30`0Oo2`/;
1om?Cdl7odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI6@Gooooo
1ombLW87ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF5PKo4A4A
1omCDe<7ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ooknoPOo30`<
1_m>CTh5ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6ooooo`Oo0000
1ole=CD7oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^;POo^;Rh1ooW
inL7olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30`0Oo2`/;1om?
Cdl7odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI6@Gooooo1omb
LW87ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF5PKo4A4A1omC
De<7ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ooknoPOo30`<1_m>
CTh5ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6ooooo`Oo00001ole
=CD7oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^;POo^;Rh1ooWinL7
olK6aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30`0Oo2`/;1om?Cdl7
odQ8B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI6@Gooooo1ombLW87
ooooo`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF5PKo4A4A1omCDe<7
ohZ:RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ooknoPOo30`<1_m>CTh5
ooooo`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6ooooo`Oo00001ole=CD7
oclo?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7obh^;POo^;Rh1ooWinL7olK6
aPKo^k^k1on5QHD7oclo?`Ko>SXj1_ooool6ohR8R0Oo<30`1olf=SH7ol30`0Oo2`/;1om?Cdl7odQ8
B0Ko;bl_1Oooool7o`820POo5QHF1ol92@T7o`0000Oo2PX:3_l61PH6oaTI6@Gooooo1ombLW87oooo
o`Oo1@D51omEEED7oc4a<@KoNg]k1on6QXH6ofm_K`Kooooo1olO7al7oaHF5PKo4A4A1omCDe<7ohZ:
RPko]kNg1_nMWId5ooooo`Oo^k^k1olA4A47oe]KF`Oo<30`1omhN7P7ooknoPOo30`<1_m>CTh5oooo
o`Oo00001ol/;2`7ob8R8POo410@1om8B4P7o`T92@Ko?Shn1_m>CTh6ooooo`Oo00001ole=CD7oclo
?`Ko;Rh^1omHF5P7ob@T90Oo=CDe1_oinOT?ooooo`003Oooool7ob4Q8@OoWIfM1onh^;P7okBd]0Ko
QhN71oo7alL7ogUiN@Ko<C4a1_ooool6ofe]K@OoADE51olX:2P7ogmoO`Oo4Q8B1omCDe<7oc@d=0Ko
A4A41Oooool7o`l?3`Oo71`L3_l51@D7o`L71`Oo30`<1ol410@6ob4Q8@Gooooo1omGEeL7omCDe0Oo
410@1om<C4`7obh^;PKoJf][1oni^KT6odU9B@Kooooo1olO7al7o`h>3PKo2@T91omBDU87oi^KV`Oo
Ti>C1onZZZX6oginOPGooooo1onJVYX7o`T92@OoADE51olj>SX7oeQHF0OoinOW1ol?3`l6og9bLPGo
oooo1ol51@D7oc<c<`Oo4A4A1ol51@D7oc4a<@Oo0@411_l/;2`6od51@@Kooooo1ol61PH7ob@T90Oo
>c/k1_lX:2P7oe]KF`Oo8R8R1om8B4P6omCDe0oooooo000=ooooo`Oo8B4Q1onMWId7okRh^0Oo];Bd
1_n7QhL7olO7a`OoNGUi1_la<C46ooooo`KoKFe]1om5ADD7obPX:0OoOgmo1olB4Q87oe=CD`Oo=3@d
1_m4A4@5ooooo`Oo3`l?1olL71`>o`D51@Oo1`L71ol<30`7o`@410Ko8B4Q1Oooool7oeMGE`Ooe=CD
1ol@4107oda<C0Oo;Rh^1_m[Jf/7okVi^@KoBDU91_ooool7oalO7`Oo3Ph>1_l92@T7oe9BDPOoVi^K
1onCTi<7ojZZZPKoOWin1Oooool7oiZJVPOo2@T91om5ADD7ocXj>POoF5QH1ooWinL7o`l?3`KoLW9b
1Oooool7o`D51@Oo<c<c1olA4A47o`D51@Oo<C4a1ol10@46ob`/;0Ko@D511_ooool7o`H61POo92@T
1olk>c/6obPX:0OoFe]K1olR8R87odQ8B0Koe=CD3oooool000gooooo1olQ8B47oifMW@Oo^;Rh1ond
];@6ohN7Q`OoalO71omiNGT6oc4a<@Kooooo1_m]KFd7odE5A@Oo:2PX1omoOgl7oa8B4POoDe=C1old
=3@6odA4A0Gooooo1ol?3`l7oa`L70ko1@D51ol71`L7o``<30Oo10@41_lQ8B45ooooo`OoEeMG1ooD
e=@7oa0@40OoC4a<1ol^;Rh6of][J`Oo^KVi1_m9BDT6ooooo`Oo7alO1ol>3Ph6o`T92@OoDU9B1onK
Vi/7oi>CT`OoZZZZ1_mnOWh5ooooo`OoVYZJ1ol92@T7odE5A@Oo>SXj1omHF5P7onOWi`Oo3`l?1_mb
LW85ooooo`Oo1@D51olc<c<7oa4A4@Oo1@D51ola<C47o`410@Ko;2`/1_m1@D46ooooo`Oo1PH61olT
92@7oc/k>`Ko:2PX1omKFe/7ob8R8POoB4Q81_oDe=@?ooooo`003Oooool7ob4Q8@OoWIfM1onh^;P7
okBd]0KoQhN71oo7alL7ogUiN@Ko<C4a1_ooool6ofe]K@OoADE51olX:2P7ogmoO`Oo4Q8B1omCDe<7
oc@d=0KoA4A41Oooool7o`l?3`Oo71`L3_l51@D7o`L71`Oo30`<1ol410@6ob4Q8@Gooooo1omGEeL7
omCDe0Oo410@1om<C4`7obh^;PKoJf][1oni^KT6odU9B@Kooooo1olO7al7o`h>3PKo2@T91omBDU87
oi^KV`OoTi>C1onZZZX6oginOPGooooo1onJVYX7o`T92@OoADE51olj>SX7oeQHF0OoinOW1ol?3`l6
og9bLPGooooo1ol51@D7oc<c<`Oo4A4A1ol51@D7oc4a<@Oo0@411_l/;2`6od51@@Kooooo1ol61PH7
ob@T90Oo>c/k1_lX:2P7oe]KF`Oo8R8R1om8B4P6omCDe0oooooo000=ooooo`Oo8B4Q1onMWId7okRh
^0Oo];Bd1_n7QhL7olO7a`OoNGUi1_la<C46ooooo`KoKFe]1om5ADD7obPX:0OoOgmo1olB4Q87oe=C
D`Oo=3@d1_m4A4@5ooooo`Oo3`l?1olL71`>o`D51@Oo1`L71ol<30`7o`@410Ko8B4Q1Oooool7oeMG
E`Ooe=CD1ol@4107oda<C0Oo;Rh^1_m[Jf/7okVi^@KoBDU91_ooool7oalO7`Oo3Ph>1_l92@T7oe9B
DPOoVi^K1onCTi<7ojZZZPKoOWin1Oooool7oiZJVPOo2@T91om5ADD7ocXj>POoF5QH1ooWinL7o`l?
3`KoLW9b1Oooool7o`D51@Oo<c<c1olA4A47o`D51@Oo<C4a1ol10@46ob`/;0Ko@D511_ooool7o`H6
1POo92@T1olk>c/6obPX:0OoFe]K1olR8R87odQ8B0Koe=CD3oooool000gooooo1olQ8B47oifMW@Oo
^;Rh1ond];@6ohN7Q`OoalO71omiNGT6oc4a<@Kooooo1_m]KFd7odE5A@Oo:2PX1omoOgl7oa8B4POo
De=C1old=3@6odA4A0Gooooo1ol?3`l7oa`L70ko1@D51ol71`L7o``<30Oo10@41_lQ8B45ooooo`Oo
EeMG1ooDe=@7oa0@40OoC4a<1ol^;Rh6of][J`Oo^KVi1_m9BDT6ooooo`Oo7alO1ol>3Ph6o`T92@Oo
DU9B1onKVi/7oi>CT`OoZZZZ1_mnOWh5ooooo`OoVYZJ1ol92@T7odE5A@Oo>SXj1omHF5P7onOWi`Oo
3`l?1_mbLW85ooooo`Oo1@D51olc<c<7oa4A4@Oo1@D51ola<C47o`410@Ko;2`/1_m1@D46ooooo`Oo
1PH61olT92@7oc/k>`Ko:2PX1omKFe/7ob8R8POoB4Q81_oDe=@?ooooo`003Oooool7ob4Q8@OoWIfM
1onh^;P7okBd]0KoQhN71oo7alL7ogUiN@Ko<C4a1_ooool6ofe]K@OoADE51olX:2P7ogmoO`Oo4Q8B
1omCDe<7oc@d=0KoA4A41Oooool7o`l?3`Oo71`L3_l51@D7o`L71`Oo30`<1ol410@6ob4Q8@Gooooo
1omGEeL7omCDe0Oo410@1om<C4`7obh^;PKoJf][1oni^KT6odU9B@Kooooo1olO7al7o`h>3PKo2@T9
1omBDU87oi^KV`OoTi>C1onZZZX6oginOPGooooo1onJVYX7o`T92@OoADE51olj>SX7oeQHF0OoinOW
1ol?3`l6og9bLPGooooo1ol51@D7oc<c<`Oo4A4A1ol51@D7oc4a<@Oo0@411_l/;2`6od51@@Kooooo
1ol61PH7ob@T90Oo>c/k1_lX:2P7oe]KF`Oo8R8R1om8B4P6omCDe0oooooo000=ooooo`OoB4Q81ona
/K47onGUi@Oooooo1_nIVIT7oibLW0OoIfMW1_m`L706ooooo`KoR8R81olk>c/7o``<30OoPX:21ol0
0007odQ8B0OoBTY:1_lk>c/5ooooo`Oo3@d=1olH61P7oa0@40Oo1PH61ol:2PX7o`D51@Oo4a<C1_lN
7Qh5ooooo`Oo=CDe1oo;bl/7o`H61POo>c/k3OmCDe<7ojj^[PKoADE51_ooool7ob4Q8@Oo71`L1_lS
8b<7odQ8B0OoSHf=1on9RHT7ogUiN@KoM7Ad1Oooool7ofEUI@Oo51@D1omJFUX7ocXj>POo7AdM1ooD
e=@7o`0000KoJVYZ1Oooool7o`0000Oo@4101olH61P7o`d=3@Oo:b/[1ol00006oc0`<0Ko?clo1_oo
ool7o`@410Oo7alO1olf=SH6oa4A4@OoFUYJ1olM7Ad7oc@d=0KoW9bL3oooool000gooooo1om8B4P7
ok6a/@OoiNGU1oooool6oiVIV@OoW9bL1omWIfL6og1`L0Kooooo1_n8R8P7oc/k>`Oo30`<1on2PX87
o`0000OoB4Q81om:BTX6oc/k>`Gooooo1ol=3@d7oaPH60Oo410@1ol61PH7o`X:2POo1@D51olC4a<6
oahN7PGooooo1ole=CD7ol_;b`Oo1PH61olk>c/=oe=CD`Oo[Zj^1_m5ADD6ooooo`Oo8B4Q1olL71`6
ob<S8`OoB4Q81on=SHd7ohV9R@OoNGUi1_mdM7@5ooooo`OoIFEU1olD51@7oeYJFPOo>SXj1olM7Ad7
omCDe0Oo00001_mZJVX5ooooo`Oo00001om0@407oaPH60Oo3@d=1ol[:b/7o`0000Ko<30`1_lo?cl6
ooooo`Oo10@41olO7al7ocHf=PKo4A4A1omJFUX7oadM7@Oo=3@d1_nLW9`?ooooo`003Oooool7odQ8
B0Oo/K6a1ooUiND7ooooo`KoVIVI1onLW9`7ofMWI`KoL71`1_ooool6ohR8R0Oo>c/k1ol<30`7oh:2
PPOo00001om8B4P7odY:BPKo>c/k1Oooool7o`d=3@Oo61PH1ol@4107o`H61POo2PX:1ol51@D7oa<C
4`Ko7QhN1Oooool7ocDe=@Oobl_;1ol61PH7oc/k>`goDe=C1on^[Zh6odE5A@Kooooo1olQ8B47oa`L
70Ko8b<S1om8B4P7ohf=S@OoRHV91omiNGT6ogAdM0Gooooo1omUIFD7oa@D50OoFUYJ1olj>SX7oadM
7@Ooe=CD1ol00006ofYZJPGooooo1ol00007od10@0Oo61PH1ol=3@d7ob/[:`Oo00001_l`<306oclo
?`Kooooo1ol410@7oalO7`Oo=SHf1_lA4A47oeYJFPOo7AdM1old=3@6oibLW0oooooo000=ooooo`Oo
B4Q81ona/K47onGUi@Oooooo1_nIVIT7oibLW0OoIfMW1_m`L706ooooo`KoR8R81olk>c/7o``<30Oo
PX:21ol00007odQ8B0OoBTY:1_lk>c/5ooooo`Oo3@d=1olH61P7oa0@40Oo1PH61ol:2PX7o`D51@Oo
4a<C1_lN7Qh5ooooo`Oo=CDe1oo;bl/7o`H61POo>c/k3OmCDe<7ojj^[PKoADE51_ooool7ob4Q8@Oo
71`L1_lS8b<7odQ8B0OoSHf=1on9RHT7ogUiN@KoM7Ad1Oooool7ofEUI@Oo51@D1omJFUX7ocXj>POo
7AdM1ooDe=@7o`0000KoJVYZ1Oooool7o`0000Oo@4101olH61P7o`d=3@Oo:b/[1ol00006oc0`<0Ko
?clo1_ooool7o`@410Oo7alO1olf=SH6oa4A4@OoFUYJ1olM7Ad7oc@d=0KoW9bL3oooool000gooooo
1om8B4P7ok6a/@OoiNGU1oooool6oiVIV@OoW9bL1omWIfL6og1`L0Kooooo1_n8R8P7oc/k>`Oo30`<
1on2PX87o`0000OoB4Q81om:BTX6oc/k>`Gooooo1ol=3@d7oaPH60Oo410@1ol61PH7o`X:2POo1@D5
1olC4a<6oahN7PGooooo1ole=CD7ol_;b`Oo1PH61olk>c/=oe=CD`Oo[Zj^1_m5ADD6ooooo`Oo8B4Q
1olL71`6ob<S8`OoB4Q81on=SHd7ohV9R@OoNGUi1_mdM7@5ooooo`OoIFEU1olD51@7oeYJFPOo>SXj
1olM7Ad7omCDe0Oo00001_mZJVX5ooooo`Oo00001om0@407oaPH60Oo3@d=1ol[:b/7o`0000Ko<30`
1_lo?cl6ooooo`Oo10@41olO7al7ocHf=PKo4A4A1omJFUX7oadM7@Oo=3@d1_nLW9`?ooooo`003Ooo
ool7odQ8B0Oo/K6a1ooUiND7ooooo`KoVIVI1onLW9`7ofMWI`KoL71`1_ooool6ohR8R0Oo>c/k1ol<
30`7oh:2PPOo00001om8B4P7odY:BPKo>c/k1Oooool7o`d=3@Oo61PH1ol@4107o`H61POo2PX:1ol5
1@D7oa<C4`Ko7QhN1Oooool7ocDe=@Oobl_;1ol61PH7oc/k>`goDe=C1on^[Zh6odE5A@Kooooo1olQ
8B47oa`L70Ko8b<S1om8B4P7ohf=S@OoRHV91omiNGT6ogAdM0Gooooo1omUIFD7oa@D50OoFUYJ1olj
>SX7oadM7@Ooe=CD1ol00006ofYZJPGooooo1ol00007od10@0Oo61PH1ol=3@d7ob/[:`Oo00001_l`
<306oclo?`Kooooo1ol410@7oalO7`Oo=SHf1_lA4A47oeYJFPOo7AdM1old=3@6oibLW0oooooo000=
ooooo`Oo51@D1omQHF47omKFePOo@T921_m3@d<7obh^;POo7AdM1_l410@6ooooo`KoDe=C1ole=CD7
ofUYJ@OoNGUi1olG5aL7odY:BPOo>3Ph1_m4A4@5ooooo`Oo>CTi1olR8R87oa`L70Oo4Q8B1olH61P7
oa/K6`Oo6ATI2oooool7od];B`OoDe=C1olO7al7odY:BPOo9BDU1_m=CDd7oeYJFPKo9RHV1_ooool7
obDU9@Oo<c<c1_mLG5`7om?Cd`Oooooo1ooemOD7oo;blPKoV9RH1Oooool7ocLg=`Oo20P81olb<S87
obh^;POo?3`l1om3@d<7oa<C4`KoPh>31Oooool7oa<C4`Oo>SXj1olG5aL7od];B`Oo>3Ph1olC4a<6
obXZ:PKoQ8B41_ooool7o`@410Oo=SHf1olO7al6oaXJ6POo:BTY1olC4a<7ob4Q8@Ko<30`3oooool0
00gooooo1olD51@7of5QH@Ooe]KF1om2@T86od=3@`Oo;Rh^1olM7Ad6o`@410Kooooo1_mCDe<7ocDe
=@OoJFUY1omiNGT7oaLG5`OoBTY:1olh>3P6odA4A0Gooooo1oli>CT7ob8R8POo71`L1olB4Q87oaPH
60Oo6a/K1olI6AT;ooooo`OoBd];1omCDe<7oalO7`OoBTY:1olU9BD6ode=C@OoFUYJ1_lV9RH6oooo
o`Oo9BDU1olc<c<6oeaLG0Oodm?C1oooool7ooGem@Ool_;b1_nHV9P5ooooo`Oo=cLg1ol820P7oc8b
<POo;Rh^1oll?3`7od=3@`Oo4a<C1_n3Ph<5ooooo`Oo4a<C1olj>SX7oaLG5`OoBd];1olh>3P7oa<C
4`Ko:RXZ1_n4Q8@6ooooo`Oo10@41olf=SH7oalO7`Ko6QXJ1olY:BT7oa<C4`Oo8B4Q1_l`<30?oooo
o`003Oooool7oa@D50OoHF5Q1ooFe]H7od92@PKo@d=31ol^;Rh7oadM7@Ko10@41_ooool6oe=CD`Oo
=CDe1omYJFT7ogUiN@Oo5aLG1om:BTX7ocPh>0KoA4A41Oooool7ocTi>@Oo8R8R1olL71`7oa8B4POo
61PH1olK6a/7oaTI6@_ooooo1om;Bd/7oe=CD`Oo7alO1om:BTX7obDU9@KoCDe=1omJFUX6obHV9PKo
oooo1olU9BD7oc<c<`KoG5aL1ooCdm<7ooooo`OomOGe1oobl_86oiRHV0Gooooo1olg=cL7o`P820Oo
<S8b1ol^;Rh7oc`l?0Oo@d=31olC4a<6oh>3P`Gooooo1olC4a<7ocXj>POo5aLG1om;Bd/7ocPh>0Oo
4a<C1_lZ:RX6ohB4Q0Kooooo1ol410@7ocHf=POo7alO1_lJ6QX7obTY:@Oo4a<C1olQ8B46oc0`<0oo
oooo000=ooooo`Oo51@D1omQHF47omKFePOo@T921_m3@d<7obh^;POo7AdM1_l410@6ooooo`KoDe=C
1ole=CD7ofUYJ@OoNGUi1olG5aL7odY:BPOo>3Ph1_m4A4@5ooooo`Oo>CTi1olR8R87oa`L70Oo4Q8B
1olH61P7oa/K6`Oo6ATI2oooool7od];B`OoDe=C1olO7al7odY:BPOo9BDU1_m=CDd7oeYJFPKo9RHV
1_ooool7obDU9@Oo<c<c1_mLG5`7om?Cd`Oooooo1ooemOD7oo;blPKoV9RH1Oooool7ocLg=`Oo20P8
1olb<S87obh^;POo?3`l1om3@d<7oa<C4`KoPh>31Oooool7oa<C4`Oo>SXj1olG5aL7od];B`Oo>3Ph
1olC4a<6obXZ:PKoQ8B41_ooool7o`@410Oo=SHf1olO7al6oaXJ6POo:BTY1olC4a<7ob4Q8@Ko<30`
3oooool000gooooo1olD51@7of5QH@Ooe]KF1om2@T86od=3@`Oo;Rh^1olM7Ad6o`@410Kooooo1_mC
De<7ocDe=@OoJFUY1omiNGT7oaLG5`OoBTY:1olh>3P6odA4A0Gooooo1oli>CT7ob8R8POo71`L1olB
4Q87oaPH60Oo6a/K1olI6AT;ooooo`OoBd];1omCDe<7oalO7`OoBTY:1olU9BD6ode=C@OoFUYJ1_lV
9RH6ooooo`Oo9BDU1olc<c<6oeaLG0Oodm?C1oooool7ooGem@Ool_;b1_nHV9P5ooooo`Oo=cLg1ol8
20P7oc8b<POo;Rh^1oll?3`7od=3@`Oo4a<C1_n3Ph<5ooooo`Oo4a<C1olj>SX7oaLG5`OoBd];1olh
>3P7oa<C4`Ko:RXZ1_n4Q8@6ooooo`Oo10@41olf=SH7oalO7`Ko6QXJ1olY:BT7oa<C4`Oo8B4Q1_l`
<30?ooooo`003Oooool7oa@D50OoHF5Q1ooFe]H7od92@PKo@d=31ol^;Rh7oadM7@Ko10@41_ooool6
oe=CD`Oo=CDe1omYJFT7ogUiN@Oo5aLG1om:BTX7ocPh>0KoA4A41Oooool7ocTi>@Oo8R8R1olL71`7
oa8B4POo61PH1olK6a/7oaTI6@_ooooo1om;Bd/7oe=CD`Oo7alO1om:BTX7obDU9@KoCDe=1omJFUX6
obHV9PKooooo1olU9BD7oc<c<`KoG5aL1ooCdm<7ooooo`OomOGe1oobl_86oiRHV0Gooooo1olg=cL7
o`P820Oo<S8b1ol^;Rh7oc`l?0Oo@d=31olC4a<6oh>3P`Gooooo1olC4a<7ocXj>POo5aLG1om;Bd/7
ocPh>0Oo4a<C1_lZ:RX6ohB4Q0Kooooo1ol410@7ocHf=POo7alO1_lJ6QX7obTY:@Oo4a<C1olQ8B46
oc0`<0oooooo000=ooooo`Oo51@D1omQHF47omKFePOo@T921_m3@d<7obh^;POo7AdM1_l410@6oooo
o`KoDe=C1ole=CD7ofUYJ@OoNGUi1olG5aL7odY:BPOo>3Ph1_m4A4@5ooooo`Oo>CTi1olR8R87oa`L
70Oo4Q8B1olH61P7oa/K6`Oo6ATI2oooool7od];B`OoDe=C1olO7al7odY:BPOo9BDU1_m=CDd7oeYJ
FPKo9RHV1_ooool7obDU9@Oo<c<c1_mLG5`7om?Cd`Oooooo1ooemOD7oo;blPKoV9RH1Oooool7ocLg
=`Oo20P81olb<S87obh^;POo?3`l1om3@d<7oa<C4`KoPh>31Oooool7oa<C4`Oo>SXj1olG5aL7od];
B`Oo>3Ph1olC4a<6obXZ:PKoQ8B41_ooool7o`@410Oo=SHf1olO7al6oaXJ6POo:BTY1olC4a<7ob4Q
8@Ko<30`3oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool000gooooo3_l/;2`7oa4A4@Oo8b<S1_lG5aL7oc/k>`Oo>SXj
1_n7QhL6ooooo`Ko4A4A1olO7al7ocHf=POo1`L71olQ8B47o`l?3`Oo:BTY1_m>CTh5ooooo`OoKfm_
1oll?3`7oaLG5`Oo61PH1ol<30`7oa4A4@Oo6a/K1_oBd]85ooooo`OoH61P1oodm?@7oc@d=0Oo@d=3
1olk>c/6oe=CD`OoLg=c1_mIFET6ooooo`Oo5QHF1olM7Ad6obXZ:POo92@T1olN7Qh7oaTI6@Oo:2PX
1_lb<S85ooooo`OoSHf=1olI6AT7ofMWI`Oo<C4a1omPH607ooooo`Oo71`L1_mZJVX5ooooo`Oo<S8b
1ol_;bl7onCTi0Oo;2`/1om6ATH7oalO7`KoFEUI1_oEeMD6ooooo`Oo1PH61om3@d<7o`0000Ko92@T
1ol`<307oa<C4`Oo@d=31_lJ6QX?ooooo`003Oooool>ob`/;0Oo4A4A1olS8b<6oaLG5`Oo>c/k1olj
>SX6ohN7Q`Kooooo1_lA4A47oalO7`Oo=SHf1ol71`L7ob4Q8@Oo3`l?1olY:BT6odi>CPGooooo1om_
Kfl7oc`l?0Oo5aLG1olH61P7o``<30Oo4A4A1olK6a/6om;BdPGooooo1omPH607ooCdm0Oo=3@d1om3
@d<7oc/k>`KoDe=C1omcLg<6oeUIF@Kooooo1olF5QH7oadM7@Ko:RXZ1olT92@7oahN7POo6ATI1olX
:2P6oc8b<PGooooo1on=SHd7oaTI6@OoIfMW1ola<C47of1PH0Oooooo1olL71`6ofYZJPGooooo1olb
<S87obl_;`Ooi>CT1ol/;2`7odI6APOo7alO1_mIFET6omGEe@Kooooo1ol61PH7od=3@`Oo00001_lT
92@7oc0`<0Oo4a<C1om3@d<6oaXJ6Poooooo000=ooooo`ko;2`/1olA4A47ob<S8`Ko5aLG1olk>c/7
ocXj>PKoQhN71_ooool6oa4A4@Oo7alO1olf=SH7o`L71`Oo8B4Q1ol?3`l7obTY:@KoCTi>1Oooool7
ofm_K`Oo?3`l1olG5aL7oaPH60Oo30`<1olA4A47oa/K6`Kod];B1Oooool7of1PH0Oom?Cd1old=3@7
od=3@`Oo>c/k1_mCDe<7og=cL`KoFEUI1_ooool7oaHF5POo7AdM1_lZ:RX7ob@T90Oo7QhN1olI6AT7
obPX:0Ko<S8b1Oooool7ohf=S@Oo6ATI1omWIfL7oc4a<@OoH61P1oooool7oa`L70KoJVYZ1Oooool7
oc8b<POo;bl_1ooTi>@7ob`/;0OoATI61olO7al6oeUIF@KoeMGE1_ooool7o`H61POo@d=31ol00006
ob@T90Oo<30`1olC4a<7od=3@`Ko6QXJ3oooool000gooooo3_l/;2`7oa4A4@Oo8b<S1_lG5aL7oc/k
>`Oo>SXj1_n7QhL6ooooo`Ko4A4A1olO7al7ocHf=POo1`L71olQ8B47o`l?3`Oo:BTY1_m>CTh5oooo
o`OoKfm_1oll?3`7oaLG5`Oo61PH1ol<30`7oa4A4@Oo6a/K1_oBd]85ooooo`OoH61P1oodm?@7oc@d
=0Oo@d=31olk>c/6oe=CD`OoLg=c1_mIFET6ooooo`Oo5QHF1olM7Ad6obXZ:POo92@T1olN7Qh7oaTI
6@Oo:2PX1_lb<S85ooooo`OoSHf=1olI6AT7ofMWI`Oo<C4a1omPH607ooooo`Oo71`L1_mZJVX5oooo
o`Oo<S8b1ol_;bl7onCTi0Oo;2`/1om6ATH7oalO7`KoFEUI1_oEeMD6ooooo`Oo1PH61om3@d<7o`00
00Ko92@T1ol`<307oa<C4`Oo@d=31_lJ6QX?ooooo`003Oooool>ob`/;0Oo4A4A1olS8b<6oaLG5`Oo
>c/k1olj>SX6ohN7Q`Kooooo1_lA4A47oalO7`Oo=SHf1ol71`L7ob4Q8@Oo3`l?1olY:BT6odi>CPGo
oooo1om_Kfl7oc`l?0Oo5aLG1olH61P7o``<30Oo4A4A1olK6a/6om;BdPGooooo1omPH607ooCdm0Oo
=3@d1om3@d<7oc/k>`KoDe=C1omcLg<6oeUIF@Kooooo1olF5QH7oadM7@Ko:RXZ1olT92@7oahN7POo
6ATI1olX:2P6oc8b<PGooooo1on=SHd7oaTI6@OoIfMW1ola<C47of1PH0Oooooo1olL71`6ofYZJPGo
oooo1olb<S87obl_;`Ooi>CT1ol/;2`7odI6APOo7alO1_mIFET6omGEe@Kooooo1ol61PH7od=3@`Oo
00001_lT92@7oc0`<0Oo4a<C1om3@d<6oaXJ6Poooooo000=ooooo`ko;2`/1olA4A47ob<S8`Ko5aLG
1olk>c/7ocXj>PKoQhN71_ooool6oa4A4@Oo7alO1olf=SH7o`L71`Oo8B4Q1ol?3`l7obTY:@KoCTi>
1Oooool7ofm_K`Oo?3`l1olG5aL7oaPH60Oo30`<1olA4A47oa/K6`Kod];B1Oooool7of1PH0Oom?Cd
1old=3@7od=3@`Oo>c/k1_mCDe<7og=cL`KoFEUI1_ooool7oaHF5POo7AdM1_lZ:RX7ob@T90Oo7QhN
1olI6AT7obPX:0Ko<S8b1Oooool7ohf=S@Oo6ATI1omWIfL7oc4a<@OoH61P1oooool7oa`L70KoJVYZ
1Oooool7oc8b<POo;bl_1ooTi>@7ob`/;0OoATI61olO7al6oeUIF@KoeMGE1_ooool7o`H61POo@d=3
1ol00006ob@T90Oo<30`1olC4a<7od=3@`Ko6QXJ3oooool000gooooo3_l/;2`7oa4A4@Oo8b<S1_lG
5aL7oc/k>`Oo>SXj1_n7QhL6ooooo`Ko4A4A1olO7al7ocHf=POo1`L71olQ8B47o`l?3`Oo:BTY1_m>
CTh5ooooo`OoKfm_1oll?3`7oaLG5`Oo61PH1ol<30`7oa4A4@Oo6a/K1_oBd]85ooooo`OoH61P1ood
m?@7oc@d=0Oo@d=31olk>c/6oe=CD`OoLg=c1_mIFET6ooooo`Oo5QHF1olM7Ad6obXZ:POo92@T1olN
7Qh7oaTI6@Oo:2PX1_lb<S85ooooo`OoSHf=1olI6AT7ofMWI`Oo<C4a1omPH607ooooo`Oo71`L1_mZ
JVX5ooooo`Oo<S8b1ol_;bl7onCTi0Oo;2`/1om6ATH7oalO7`KoFEUI1_oEeMD6ooooo`Oo1PH61om3
@d<7o`0000Ko92@T1ol`<307oa<C4`Oo@d=31_lJ6QX?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7
o`0000go6a/K1ole=CD6ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6
od];B`Gooooo1omgMgL7odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47
ooooo`Oo:2PX1om4A4@7ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7
o`410@Oo3@d=1ol;2`/6obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6
ogemO@Gooooo1olK6a/7oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7
o`H61PKo61PH1olJ6QX7o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`00
00go6a/K1ole=CD6ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];
B`Gooooo1omgMgL7odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47oooo
o`Oo:2PX1om4A4@7ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`41
0@Oo3@d=1ol;2`/6obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogem
O@Gooooo1olK6a/7oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H6
1PKo61PH1olJ6QX7o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`0000go
6a/K1ole=CD6ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];B`Go
oooo1omgMgL7odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47ooooo`Oo
:2PX1om4A4@7ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`410@Oo
3@d=1ol;2`/6obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogemO@Go
oooo1olK6a/7oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H61PKo
61PH1olJ6QX7o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`0000go6a/K
1ole=CD6ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];B`Gooooo
1omgMgL7odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47ooooo`Oo:2PX
1om4A4@7ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`410@Oo3@d=
1ol;2`/6obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogemO@Gooooo
1olK6a/7oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H61PKo61PH
1olJ6QX7o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`0000go6a/K1ole
=CD6ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];B`Gooooo1omg
MgL7odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47ooooo`Oo:2PX1om4
A4@7ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`410@Oo3@d=1ol;
2`/6obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogemO@Gooooo1olK
6a/7oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H61PKo61PH1olJ
6QX7o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`0000go6a/K1ole=CD6
ogEeM@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];B`Gooooo1omgMgL7
odU9B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47ooooo`Oo:2PX1om4A4@7
ocXj>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`410@Oo3@d=1ol;2`/6
obHV9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogemO@Gooooo1olK6a/7
oaHF5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H61PKo61PH1olJ6QX7
o`d=3@Oo>c/k1_lO7al?ooooo`003Oooool7oc<c<`Oo0`<31ol?3`l7o`0000go6a/K1ole=CD6ogEe
M@Kooooo1_lV9RH7ob`/;0OoEEEE1ol00007oa8B4POo3@d=1olT92@6od];B`Gooooo1omgMgL7odU9
B@Oo4a<C1ol>3Ph7o`/;2`Oo1@D51olS8b<6omOGe`Gooooo1omADE47ooooo`Oo:2PX1om4A4@7ocXj
>PKoCDe=1onCTi<6od92@PKooooo1ol;2`/7o`T92@Ko3Ph>1olE5AD7o`410@Oo3@d=1ol;2`/6obHV
9PGooooo1omeMGD7o`T92@OoADE51om4A4@7of5QH@Ookno_1olL71`6ogemO@Gooooo1olK6a/7oaHF
5POo][Jf1olP8207od=3@`Oo:b/[1_lX:2P<ooooo`Oo20P81olk>c/7o`H61PKo61PH1olJ6QX7o`d=
3@Oo>c/k1_lO7al?ooooo`003Oooool7oa`L70Oo6a/K1ol71`L7oaHF5PKo410@1om6ATH7oc`l?0Ko
Q8B41_ooool6ocTi>@OoC4a<1onCTi<7o`d=3@Oo:2PX1olF5QH7ochn?PKoIFEU1Oooool7oh61P@Oo
CDe=1ol[:b/7obXZ:POo2@T91ol71`L7oa`L70_ooooo1olW9bL7okNg]`Oo8B4Q1olh>3P7oeADE0Ko
@D511on>SXh6oc`l?0Kooooo1ol?3`l7oa8B4PKo61PH1olD51@7oa<C4`Oo3Ph>1ol@4106oaLG5`Go
oooo1omDE5@7oaDE5@OoFUYJ1ol^;Rh7obd];@Oo[:b/1olA4A46oi:BTPGooooo1olQ8B47o`P820Oo
GEeM1ol?3`l7odm?C`Oo4a<C1_lI6AT6okno_`Kooooo1ol?3`l7ocDe=@Oo1`L71_lV9RH7oa@D50Oo
1@D51olb<S86ob`/;0oooooo000=ooooo`Oo71`L1olK6a/7o`L71`Oo5QHF1_l@4107odI6APOo?3`l
1_n4Q8@6ooooo`Ko>CTi1om<C4`7oi>CT`Oo3@d=1olX:2P7oaHF5POo?Shn1_mUIFD5ooooo`OoPH61
1om=CDd7ob/[:`Oo:RXZ1ol92@T7o`L71`Oo71`L2oooool7obLW9`Oo]kNg1olQ8B47ocPh>0OoE5AD
1_m1@D47ohj>SPKo?3`l1_ooool7o`l?3`Oo4Q8B1_lH61P7oa@D50Oo4a<C1ol>3Ph7oa0@40Ko5aLG
1Oooool7oeADE0Oo5ADE1omJFUX7obh^;POo;Bd]1on/[:`7oa4A4@KoTY:B1Oooool7ob4Q8@Oo20P8
1omMGEd7o`l?3`OoCdm?1olC4a<6oaTI6@Ko_kno1_ooool7o`l?3`Oo=CDe1ol71`L6obHV9POo51@D
1ol51@D7oc8b<PKo;2`/3oooool000gooooo1olL71`7oa/K6`Oo1`L71olF5QH6oa0@40OoATI61oll
?3`6ohB4Q0Kooooo1_li>CT7oda<C0OoTi>C1ol=3@d7obPX:0Oo5QHF1oln?Sh6ofEUI@Gooooo1on1
PH47ode=C@Oo:b/[1olZ:RX7o`T92@Oo1`L71olL71`;ooooo`Oo9bLW1ong]kL7ob4Q8@Oo>3Ph1omD
E5@6od51@@OoSXj>1_ll?3`6ooooo`Oo3`l?1olB4Q86oaPH60Oo51@D1olC4a<7o`h>3POo410@1_lG
5aL5ooooo`OoE5AD1olE5AD7oeYJFPOo;Rh^1ol];Bd7ojb/[0Oo4A4A1_nBTY85ooooo`Oo8B4Q1ol8
20P7oeeMG@Oo3`l?1om?Cdl7oa<C4`Ko6ATI1_no_kl6ooooo`Oo3`l?1ole=CD7o`L71`Ko9RHV1olD
51@7o`D51@Oo<S8b1_l/;2`?ooooo`003Oooool7oa`L70Oo6a/K1ol71`L7oaHF5PKo410@1om6ATH7
oc`l?0KoQ8B41_ooool6ocTi>@OoC4a<1onCTi<7o`d=3@Oo:2PX1olF5QH7ochn?PKoIFEU1Oooool7
oh61P@OoCDe=1ol[:b/7obXZ:POo2@T91ol71`L7oa`L70_ooooo1olW9bL7okNg]`Oo8B4Q1olh>3P7
oeADE0Ko@D511on>SXh6oc`l?0Kooooo1ol?3`l7oa8B4PKo61PH1olD51@7oa<C4`Oo3Ph>1ol@4106
oaLG5`Gooooo1omDE5@7oaDE5@OoFUYJ1ol^;Rh7obd];@Oo[:b/1olA4A46oi:BTPGooooo1olQ8B47
o`P820OoGEeM1ol?3`l7odm?C`Oo4a<C1_lI6AT6okno_`Kooooo1ol?3`l7ocDe=@Oo1`L71_lV9RH7
oa@D50Oo1@D51olb<S86ob`/;0oooooo000=ooooo`Oo71`L1olK6a/7o`L71`Oo5QHF1_l@4107odI6
APOo?3`l1_n4Q8@6ooooo`Ko>CTi1om<C4`7oi>CT`Oo3@d=1olX:2P7oaHF5POo?Shn1_mUIFD5oooo
o`OoPH611om=CDd7ob/[:`Oo:RXZ1ol92@T7o`L71`Oo71`L2oooool7obLW9`Oo]kNg1olQ8B47ocPh
>0OoE5AD1_m1@D47ohj>SPKo?3`l1_ooool7o`l?3`Oo4Q8B1_lH61P7oa@D50Oo4a<C1ol>3Ph7oa0@
40Ko5aLG1Oooool7oeADE0Oo5ADE1omJFUX7obh^;POo;Bd]1on/[:`7oa4A4@KoTY:B1Oooool7ob4Q
8@Oo20P81omMGEd7o`l?3`OoCdm?1olC4a<6oaTI6@Ko_kno1_ooool7o`l?3`Oo=CDe1ol71`L6obHV
9POo51@D1ol51@D7oc8b<PKo;2`/3oooool000gooooo1olL71`7oa/K6`Oo1`L71olF5QH6oa0@40Oo
ATI61oll?3`6ohB4Q0Kooooo1_li>CT7oda<C0OoTi>C1ol=3@d7obPX:0Oo5QHF1oln?Sh6ofEUI@Go
oooo1on1PH47ode=C@Oo:b/[1olZ:RX7o`T92@Oo1`L71olL71`;ooooo`Oo9bLW1ong]kL7ob4Q8@Oo
>3Ph1omDE5@6od51@@OoSXj>1_ll?3`6ooooo`Oo3`l?1olB4Q86oaPH60Oo51@D1olC4a<7o`h>3POo
410@1_lG5aL5ooooo`OoE5AD1olE5AD7oeYJFPOo;Rh^1ol];Bd7ojb/[0Oo4A4A1_nBTY85ooooo`Oo
8B4Q1ol820P7oeeMG@Oo3`l?1om?Cdl7oa<C4`Ko6ATI1_no_kl6ooooo`Oo3`l?1ole=CD7o`L71`Ko
9RHV1olD51@7o`D51@Oo<S8b1_l/;2`?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S
1olL71`7ocDe=@KoLW9b1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<
1Oooool7ogemO@OoADE51ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_
1olJ6QX7obh^;POoBd];1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L7
3_l820P6ob4Q8@Gooooo1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo
1olf=SH7o`410@Oo>CTi1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<
1_lg=cL>o`/;2`Oo7QhN1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL
71`7ocDe=@KoLW9b1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Ooo
ool7ogemO@OoADE51ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ
6QX7obh^;POoBd];1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l8
20P6ob4Q8@Gooooo1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf
=SH7o`410@Oo>CTi1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg
=cL>o`/;2`Oo7QhN1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL71`7
ocDe=@KoLW9b1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Oooool7
ogemO@OoADE51ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ6QX7
obh^;POoBd];1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l820P6
ob4Q8@Gooooo1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf=SH7
o`410@Oo>CTi1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg=cL>
o`/;2`Oo7QhN1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL71`7ocDe
=@KoLW9b1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Oooool7ogem
O@OoADE51ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ6QX7obh^
;POoBd];1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l820P6ob4Q
8@Gooooo1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf=SH7o`41
0@Oo>CTi1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg=cL>o`/;
2`Oo7QhN1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL71`7ocDe=@Ko
LW9b1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Oooool7ogemO@Oo
ADE51ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ6QX7obh^;POo
Bd];1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l820P6ob4Q8@Go
oooo1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf=SH7o`410@Oo
>CTi1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg=cL>o`/;2`Oo
7QhN1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL71`7ocDe=@KoLW9b
1_ooool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Oooool7ogemO@OoADE5
1ol@4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ6QX7obh^;POoBd];
1_lh>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l820P6ob4Q8@Gooooo
1olZ:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf=SH7o`410@Oo>CTi
1ol410@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg=cL>o`/;2`Oo7QhN
1_mSHf<?ooooo`003Oooool7obTY:@Oo2`/;1olG5aL7o`L71`Ko8b<S1olL71`7ocDe=@KoLW9b1_oo
ool6odM7A`OoTY:B1oo[jn/7od=3@`OoADE51olQ8B47od=3@`KoC4a<1Oooool7ogemO@OoADE51ol@
4107oa8B4POo3`l?1ol51@D7oaHF5PKoc<c<1Oooool7o`/;2`OoKfm_1olJ6QX7obh^;POoBd];1_lh
>3P7ohj>SPKo7QhN1_ooool7o`0000Oo30`<1_l820P7oa<C4`Oo1`L73_l820P6ob4Q8@Gooooo1olZ
:RX7o`0000OoEeMG1ol_;bl7oaLG5`OoKVi^1ol>3Ph6ofATI0Gooooo1olf=SH7o`410@Oo>CTi1ol4
10@7odI6APOo6ATI1_lA4A46om_Kf`Kooooo1olK6a/7oc/k>`Oo30`<1_lg=cL>o`/;2`Oo7QhN1_mS
Hf<?ooooo`003Oooool7oc0`<0Oo7QhN1olG5aL7oahN7PKo820P1old=3@7ocdm?@KoV9RH1_ooool6
odi>CPOoJVYZ1ooinOT7ofYZJPOoC4a<1olo?cl7ode=C@KoEUIF1Oooool7og5aL@Oo?Cdm1olL71`7
oaXJ6POo1@D51ol00007ob4Q8@Kolo?c1Oooool7oaPH60Oo>c/k1ol<30`7obLW9`OoATI61_lF5QH7
of][J`Ko820P1_ooool7o`@410Oo30`<1_l61PH7oa<C4`Oo2PX:1olE5AD7oa0@40Ko61PH1Oooool7
oc8b<POo00001omWIfL7ocTi>@Oo10@41om>CTh7o`H61PKoJ6QX1Oooool7oe]KF`Oo3Ph>1ol`<307
o`h>3POoP8201olQ8B46o`0000KoNGUi1_ooool7oa`L70Oo?clo1ol;2`/6ocXj>POo7QhN1ol?3`l7
obd];@Ko/[:b3oooool000gooooo1ol`<307oahN7POo5aLG1olN7Qh6ob0P80Oo=3@d1olm?Cd6oiRH
V0Kooooo1_m>CTh7ofYZJPOonOWi1omZJVX7oda<C0Oo?clo1om=CDd6oeIFEPGooooo1omaLG47ocdm
?@Oo71`L1olJ6QX7o`D51@Oo00001olQ8B46oo?cl`Gooooo1olH61P7oc/k>`Oo30`<1olW9bL7odI6
APKo5QHF1om[Jf/6ob0P80Kooooo1ol410@7o``<30Ko1PH61olC4a<7o`X:2POo5ADE1ol@4106oaPH
60Gooooo1olb<S87o`0000OoIfMW1oli>CT7o`@410OoCTi>1ol61PH6ofQXJ0Gooooo1omKFe/7o`h>
3POo<30`1ol>3Ph7oh20P0Oo8B4Q1_l00006ogUiN@Kooooo1olL71`7oclo?`Oo2`/;1_lj>SX7oahN
7POo3`l?1ol];Bd6ok:b/Poooooo000=ooooo`Oo<30`1olN7Qh7oaLG5`Oo7QhN1_lP8207oc@d=0Oo
?Cdm1_nHV9P6ooooo`KoCTi>1omZJVX7ooWin@OoJVYZ1om<C4`7oclo?`OoCDe=1_mFEUH5ooooo`Oo
LG5a1olm?Cd7oa`L70Oo6QXJ1ol51@D7o`0000Oo8B4Q1_oclo<5ooooo`Oo61PH1olk>c/7o``<30Oo
9bLW1om6ATH6oaHF5POoJf][1_lP8206ooooo`Oo10@41ol<30`6o`H61POo4a<C1ol:2PX7oaDE5@Oo
410@1_lH61P5ooooo`Oo<S8b1ol00007ofMWI`Oo>CTi1ol410@7odi>CPOo1PH61_mXJ6P5ooooo`Oo
Fe]K1ol>3Ph7oc0`<0Oo3Ph>1on0P807ob4Q8@Ko00001_miNGT6ooooo`Oo71`L1olo?cl7o`/;2`Ko
>SXj1olN7Qh7o`l?3`Oo;Bd]1_nb/[8?ooooo`003Oooool7oc0`<0Oo7QhN1olG5aL7oahN7PKo820P
1old=3@7ocdm?@KoV9RH1_ooool6odi>CPOoJVYZ1ooinOT7ofYZJPOoC4a<1olo?cl7ode=C@KoEUIF
1Oooool7og5aL@Oo?Cdm1olL71`7oaXJ6POo1@D51ol00007ob4Q8@Kolo?c1Oooool7oaPH60Oo>c/k
1ol<30`7obLW9`OoATI61_lF5QH7of][J`Ko820P1_ooool7o`@410Oo30`<1_l61PH7oa<C4`Oo2PX:
1olE5AD7oa0@40Ko61PH1Oooool7oc8b<POo00001omWIfL7ocTi>@Oo10@41om>CTh7o`H61PKoJ6QX
1Oooool7oe]KF`Oo3Ph>1ol`<307o`h>3POoP8201olQ8B46o`0000KoNGUi1_ooool7oa`L70Oo?clo
1ol;2`/6ocXj>POo7QhN1ol?3`l7obd];@Ko/[:b3oooool000gooooo1ol`<307oahN7POo5aLG1olN
7Qh6ob0P80Oo=3@d1olm?Cd6oiRHV0Kooooo1_m>CTh7ofYZJPOonOWi1omZJVX7oda<C0Oo?clo1om=
CDd6oeIFEPGooooo1omaLG47ocdm?@Oo71`L1olJ6QX7o`D51@Oo00001olQ8B46oo?cl`Gooooo1olH
61P7oc/k>`Oo30`<1olW9bL7odI6APKo5QHF1om[Jf/6ob0P80Kooooo1ol410@7o``<30Ko1PH61olC
4a<7o`X:2POo5ADE1ol@4106oaPH60Gooooo1olb<S87o`0000OoIfMW1oli>CT7o`@410OoCTi>1ol6
1PH6ofQXJ0Gooooo1omKFe/7o`h>3POo<30`1ol>3Ph7oh20P0Oo8B4Q1_l00006ogUiN@Kooooo1olL
71`7oclo?`Oo2`/;1_lj>SX7oahN7POo3`l?1ol];Bd6ok:b/Poooooo000=ooooo`Oo<30`1olN7Qh7
oaLG5`Oo7QhN1_lP8207oc@d=0Oo?Cdm1_nHV9P6ooooo`KoCTi>1omZJVX7ooWin@OoJVYZ1om<C4`7
oclo?`OoCDe=1_mFEUH5ooooo`OoLG5a1olm?Cd7oa`L70Oo6QXJ1ol51@D7o`0000Oo8B4Q1_oclo<5
ooooo`Oo61PH1olk>c/7o``<30Oo9bLW1om6ATH6oaHF5POoJf][1_lP8206ooooo`Oo10@41ol<30`6
o`H61POo4a<C1ol:2PX7oaDE5@Oo410@1_lH61P5ooooo`Oo<S8b1ol00007ofMWI`Oo>CTi1ol410@7
odi>CPOo1PH61_mXJ6P5ooooo`OoFe]K1ol>3Ph7oc0`<0Oo3Ph>1on0P807ob4Q8@Ko00001_miNGT6
ooooo`Oo71`L1olo?cl7o`/;2`Ko>SXj1olN7Qh7o`l?3`Oo;Bd]1_nb/[8?ooooo`003Oooool7oc0`
<0Oo7QhN1olG5aL7oahN7PKo820P1old=3@7ocdm?@KoV9RH1_ooool6odi>CPOoJVYZ1ooinOT7ofYZ
JPOoC4a<1olo?cl7ode=C@KoEUIF1Oooool7og5aL@Oo?Cdm1olL71`7oaXJ6POo1@D51ol00007ob4Q
8@Kolo?c1Oooool7oaPH60Oo>c/k1ol<30`7obLW9`OoATI61_lF5QH7of][J`Ko820P1_ooool7o`@4
10Oo30`<1_l61PH7oa<C4`Oo2PX:1olE5AD7oa0@40Ko61PH1Oooool7oc8b<POo00001omWIfL7ocTi
>@Oo10@41om>CTh7o`H61PKoJ6QX1Oooool7oe]KF`Oo3Ph>1ol`<307o`h>3POoP8201olQ8B46o`00
00KoNGUi1_ooool7oa`L70Oo?clo1ol;2`/6ocXj>POo7QhN1ol?3`l7obd];@Ko/[:b3oooool000go
oooo1olg=cL7o`@410Oo6QXJ1ol@4106ob@T90Oo2`/;1olg=cL6ogMgM`Kooooo1_m2@T87oeYJFPOo
oooo1on2PX87of][J`OoC4a<1olm?Cd6od51@@Gooooo1om^KVh7oc/k>`Oo7QhN1olA4A47o`H61POo
00001olI6AT6olO7a`Gooooo1olG5aL7obl_;`Oo00001old=3@7oadM7@Ko2`/;3Om4A4@6ooooo`Oo
00001ol?3`l6o`/;2`Oo30`<1ol>3Ph7o`<30`Oo2@T91_la<C45ooooo`Oo;bl_1ol?3`l7ohN7Q`Oo
ADE51ol:2PX7odM7A`Oo61PH1_m8B4P5ooooo`OoWIfM1olY:BT7ocPh>0Oo6a/K1on7QhL7odA4A0Ko
61PH1_m@D506ooooo`Oo61PH1olj>SX7oaXJ6PKo?Cdm1ol`<307oa0@40Oo8R8R1_oDe=@?ooooo`00
3Oooool7ocLg=`Oo10@41olJ6QX7oa0@40Ko92@T1ol;2`/7ocLg=`KoMgMg1_ooool6od92@POoFUYJ
1oooool7oh:2PPOoJf][1om<C4`7ocdm?@Ko@D511Oooool7ofi^KPOo>c/k1olN7Qh7oa4A4@Oo1PH6
1ol00007oaTI6@KoalO71Oooool7oaLG5`Oo;bl_1ol00007oc@d=0Oo7AdM1_l;2`/=odA4A0Kooooo
1ol00007o`l?3`Ko2`/;1ol<30`7o`h>3POo0`<31ol92@T6oc4a<@Gooooo1ol_;bl7o`l?3`OoQhN7
1om5ADD7o`X:2POoAdM71olH61P6odQ8B0Gooooo1onMWId7obTY:@Oo>3Ph1olK6a/7ohN7Q`OoA4A4
1_lH61P6oe1@D0Kooooo1olH61P7ocXj>POo6QXJ1_lm?Cd7oc0`<0Oo410@1olR8R86omCDe0oooooo
000=ooooo`Oo=cLg1ol410@7oaXJ6POo410@1_lT92@7o`/;2`Oo=cLg1_mgMgL6ooooo`Ko@T921omJ
FUX7ooooo`OoPX:21om[Jf/7oda<C0Oo?Cdm1_m1@D45ooooo`OoKVi^1olk>c/7oahN7POo4A4A1ol6
1PH7o`0000Oo6ATI1_o7alL5ooooo`Oo5aLG1ol_;bl7o`0000Oo=3@d1olM7Ad6o`/;2`goA4A41_oo
ool7o`0000Oo3`l?1_l;2`/7o``<30Oo3Ph>1ol30`<7o`T92@Ko<C4a1Oooool7obl_;`Oo3`l?1on7
QhL7odE5A@Oo2PX:1om7AdL7oaPH60KoB4Q81Oooool7oifMW@Oo:BTY1olh>3P7oa/K6`OoQhN71om4
A4@6oaPH60KoD51@1_ooool7oaPH60Oo>SXj1olJ6QX6ocdm?@Oo<30`1ol@4107ob8R8PKoe=CD3ooo
ool000gooooo1olg=cL7o`@410Oo6QXJ1ol@4106ob@T90Oo2`/;1olg=cL6ogMgM`Kooooo1_m2@T87
oeYJFPOooooo1on2PX87of][J`OoC4a<1olm?Cd6od51@@Gooooo1om^KVh7oc/k>`Oo7QhN1olA4A47
o`H61POo00001olI6AT6olO7a`Gooooo1olG5aL7obl_;`Oo00001old=3@7oadM7@Ko2`/;3Om4A4@6
ooooo`Oo00001ol?3`l6o`/;2`Oo30`<1ol>3Ph7o`<30`Oo2@T91_la<C45ooooo`Oo;bl_1ol?3`l7
ohN7Q`OoADE51ol:2PX7odM7A`Oo61PH1_m8B4P5ooooo`OoWIfM1olY:BT7ocPh>0Oo6a/K1on7QhL7
odA4A0Ko61PH1_m@D506ooooo`Oo61PH1olj>SX7oaXJ6PKo?Cdm1ol`<307oa0@40Oo8R8R1_oDe=@?
ooooo`003Oooool7ocLg=`Oo10@41olJ6QX7oa0@40Ko92@T1ol;2`/7ocLg=`KoMgMg1_ooool6od92
@POoFUYJ1oooool7oh:2PPOoJf][1om<C4`7ocdm?@Ko@D511Oooool7ofi^KPOo>c/k1olN7Qh7oa4A
4@Oo1PH61ol00007oaTI6@KoalO71Oooool7oaLG5`Oo;bl_1ol00007oc@d=0Oo7AdM1_l;2`/=odA4
A0Kooooo1ol00007o`l?3`Ko2`/;1ol<30`7o`h>3POo0`<31ol92@T6oc4a<@Gooooo1ol_;bl7o`l?
3`OoQhN71om5ADD7o`X:2POoAdM71olH61P6odQ8B0Gooooo1onMWId7obTY:@Oo>3Ph1olK6a/7ohN7
Q`OoA4A41_lH61P6oe1@D0Kooooo1olH61P7ocXj>POo6QXJ1_lm?Cd7oc0`<0Oo410@1olR8R86omCD
e0oooooo000=ooooo`Oo=cLg1ol410@7oaXJ6POo410@1_lT92@7o`/;2`Oo=cLg1_mgMgL6ooooo`Ko
@T921omJFUX7ooooo`OoPX:21om[Jf/7oda<C0Oo?Cdm1_m1@D45ooooo`OoKVi^1olk>c/7oahN7POo
4A4A1ol61PH7o`0000Oo6ATI1_o7alL5ooooo`Oo5aLG1ol_;bl7o`0000Oo=3@d1olM7Ad6o`/;2`go
A4A41_ooool7o`0000Oo3`l?1_l;2`/7o``<30Oo3Ph>1ol30`<7o`T92@Ko<C4a1Oooool7obl_;`Oo
3`l?1on7QhL7odE5A@Oo2PX:1om7AdL7oaPH60KoB4Q81Oooool7oifMW@Oo:BTY1olh>3P7oa/K6`Oo
QhN71om4A4@6oaPH60KoD51@1_ooool7oaPH60Oo>SXj1olJ6QX6ocdm?@Oo<30`1ol@4107ob8R8PKo
e=CD3oooool000gooooo1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo
1_lh>3P7oda<C0Oo/;2`1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU
1olR8R87oa@D50Oo8b<S1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG
1oln?Sh6ogAdM0Kooooo1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T92
1ol?3`l7oh20P0OoJFUY1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW
1onIVIT7ofATI0Ko8B4Q1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a
5Oooool000gooooo1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh
>3P7oda<C0Oo/;2`1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR
8R87oa@D50Oo8b<S1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln
?Sh6ogAdM0Kooooo1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?
3`l7oh20P0OoJFUY1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onI
VIT7ofATI0Ko8B4Q1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Ooo
ool000gooooo1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh>3P7
oda<C0Oo/;2`1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR8R87
oa@D50Oo8b<S1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln?Sh6
ogAdM0Kooooo1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?3`l7
oh20P0OoJFUY1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onIVIT7
ofATI0Ko8B4Q1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Oooool0
00gooooo1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh>3P7oda<
C0Oo/;2`1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR8R87oa@D
50Oo8b<S1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln?Sh6ogAd
M0Kooooo1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?3`l7oh20
P0OoJFUY1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onIVIT7ofAT
I0Ko8B4Q1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Oooool000go
oooo1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh>3P7oda<C0Oo
/;2`1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR8R87oa@D50Oo
8b<S1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln?Sh6ogAdM0Ko
oooo1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?3`l7oh20P0Oo
JFUY1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onIVIT7ofATI0Ko
8B4Q1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Oooool000gooooo
1ol^;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh>3P7oda<C0Oo/;2`
1omRHV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR8R87oa@D50Oo8b<S
1olX:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln?Sh6ogAdM0Kooooo
1olG5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?3`l7oh20P0OoJFUY
1ol>3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onIVIT7ofATI0Ko8B4Q
1_m1@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Oooool000gooooo1ol^
;Rh7oa0@40Oo4a<C1ol?3`l6ob0P80Oo7alO1olm?Cd6ohN7Q`Kooooo1_lh>3P7oda<C0Oo/;2`1omR
HV87oeYJFPOoCdm?1oln?Sh6of1PH0Gooooo1omSHf<7oeADE0Oo9BDU1olR8R87oa@D50Oo8b<S1olX
:2P6onKViPGooooo1ol^;Rh7ocHf=POo1@D51olj>SX7obLW9`Ko5aLG1oln?Sh6ogAdM0Kooooo1olG
5aL7oa8B4PKo6QXJ1ol?3`l7oadM7@ko5QHF1_lV9RH5ooooo`Oo@T921ol?3`l7oh20P0OoJFUY1ol>
3Ph7oeaLG0Oo51@D1_ll?3`5ooooo`OoZ:RX1olQ8B47oe5AD@Oo9bLW1onIVIT7ofATI0Ko8B4Q1_m1
@D46ooooo`Oo6a/K1olo?cl7obl_;`Ko@T921om1@D47o`l?3`Oo<C4a5Oooool000gooooo1onVYZH7
og=cL`OoNWYj1omZJVX6oiJFUPOoSHf=1onXZ:P<ooooo`Ko7QhN1oli>CT7ocPh>0Oo<30`1om7AdL7
obXZ:POo<S8b1_mNGUh5ooooo`OoZj^[1omLG5`7odQ8B0Oo;Bd]1ol[:b/7ob<S8`OoB4Q81_n`/;05
ooooo`OoOWin1onCTi<7ochn?POo@4101olO7al6oeEEE@Oo?clo1_le=CD6ooooo`Oo`<301oodm?@6
omcLg0Oooooo1oo_knl7on[ZjPOok>c/1_nf][H5ooooo`OoRXZ:1olQ8B47of][J`Oo@4101omgMgL7
oi6AT@Oo9BDU1_ln?Sh5ooooo`OoJFUY1omEEED7omgMg@Oo<30`1omaLG47oc`l?0KoK6a/1_n5QHD6
ooooo`Oo5aLG1olk>c/7oa8B4PKo:BTY1olh>3P7obDU9@OoAdM71_m?Cdl?ooooo`003Oooool7ojJV
YPOoLg=c1omjNWX7ofYZJPKoUYJF1on=SHd7ojRXZ0cooooo1_lN7Qh7ocTi>@Oo>3Ph1ol`<307odM7
A`Oo:RXZ1olb<S86oeiNGPGooooo1on[Zj/7oeaLG0OoB4Q81ol];Bd7ob/[:`Oo8b<S1om8B4P6ok2`
/0Gooooo1omnOWh7oi>CT`Oo?Shn1om0@407oalO7`KoEEEE1olo?cl6ocDe=@Kooooo1oo0`<07ooCd
m0Kog=cL1oooool7ono_k`Ooj^[Z1oo/k>`6okJf]PGooooo1on:RXX7ob4Q8@OoJf][1om0@407ogMg
M`OoTI6A1olU9BD6ochn?PGooooo1omYJFT7oeEEE@OogMgM1ol`<307og5aL@Oo?3`l1_m/K6`6ohF5
Q@Kooooo1olG5aL7oc/k>`Oo4Q8B1_lY:BT7ocPh>0Oo9BDU1om7AdL6odm?C`oooooo000=ooooo`Oo
YZJV1omcLg<7ogYjNPOoJVYZ1_nFUYH7ohf=S@OoZ:RX3?ooool6oahN7POo>CTi1olh>3P7oc0`<0Oo
AdM71olZ:RX7oc8b<PKoGUiN1Oooool7oj^[Z`OoG5aL1om8B4P7obd];@Oo:b/[1olS8b<7odQ8B0Ko
/;2`1Oooool7oginOPOoTi>C1oln?Sh7od10@0Oo7alO1_mEEED7oclo?`Ko=CDe1_ooool7ol30`0Oo
m?Cd1_oLg=`7ooooo`Ookno_1ooZj^X7onc/k0Ko][Jf1Oooool7ohZ:RPOo8B4Q1om[Jf/7od10@0Oo
MgMg1onATI47obDU9@Ko?Shn1Oooool7ofUYJ@OoEEEE1ooMgMd7oc0`<0OoLG5a1oll?3`6ofa/K0Ko
QHF51_ooool7oaLG5`Oo>c/k1olB4Q86obTY:@Oo>3Ph1olU9BD7odM7A`KoCdm?3oooool000gooooo
1onVYZH7og=cL`OoNWYj1omZJVX6oiJFUPOoSHf=1onXZ:P<ooooo`Ko7QhN1oli>CT7ocPh>0Oo<30`
1om7AdL7obXZ:POo<S8b1_mNGUh5ooooo`OoZj^[1omLG5`7odQ8B0Oo;Bd]1ol[:b/7ob<S8`OoB4Q8
1_n`/;05ooooo`OoOWin1onCTi<7ochn?POo@4101olO7al6oeEEE@Oo?clo1_le=CD6ooooo`Oo`<30
1oodm?@6omcLg0Oooooo1oo_knl7on[ZjPOok>c/1_nf][H5ooooo`OoRXZ:1olQ8B47of][J`Oo@410
1omgMgL7oi6AT@Oo9BDU1_ln?Sh5ooooo`OoJFUY1omEEED7omgMg@Oo<30`1omaLG47oc`l?0KoK6a/
1_n5QHD6ooooo`Oo5aLG1olk>c/7oa8B4PKo:BTY1olh>3P7obDU9@OoAdM71_m?Cdl?ooooo`003Ooo
ool7ojJVYPOoLg=c1omjNWX7ofYZJPKoUYJF1on=SHd7ojRXZ0cooooo1_lN7Qh7ocTi>@Oo>3Ph1ol`
<307odM7A`Oo:RXZ1olb<S86oeiNGPGooooo1on[Zj/7oeaLG0OoB4Q81ol];Bd7ob/[:`Oo8b<S1om8
B4P6ok2`/0Gooooo1omnOWh7oi>CT`Oo?Shn1om0@407oalO7`KoEEEE1olo?cl6ocDe=@Kooooo1oo0
`<07ooCdm0Kog=cL1oooool7ono_k`Ooj^[Z1oo/k>`6okJf]PGooooo1on:RXX7ob4Q8@OoJf][1om0
@407ogMgM`OoTI6A1olU9BD6ochn?PGooooo1omYJFT7oeEEE@OogMgM1ol`<307og5aL@Oo?3`l1_m/
K6`6ohF5Q@Kooooo1olG5aL7oc/k>`Oo4Q8B1_lY:BT7ocPh>0Oo9BDU1om7AdL6odm?C`oooooo000=
ooooo`OoYZJV1omcLg<7ogYjNPOoJVYZ1_nFUYH7ohf=S@OoZ:RX3?ooool6oahN7POo>CTi1olh>3P7
oc0`<0OoAdM71olZ:RX7oc8b<PKoGUiN1Oooool7oj^[Z`OoG5aL1om8B4P7obd];@Oo:b/[1olS8b<7
odQ8B0Ko/;2`1Oooool7oginOPOoTi>C1oln?Sh7od10@0Oo7alO1_mEEED7oclo?`Ko=CDe1_ooool7
ol30`0Oom?Cd1_oLg=`7ooooo`Ookno_1ooZj^X7onc/k0Ko][Jf1Oooool7ohZ:RPOo8B4Q1om[Jf/7
od10@0OoMgMg1onATI47obDU9@Ko?Shn1Oooool7ofUYJ@OoEEEE1ooMgMd7oc0`<0OoLG5a1oll?3`6
ofa/K0KoQHF51_ooool7oaLG5`Oo>c/k1olB4Q86obTY:@Oo>3Ph1olU9BD7odM7A`KoCdm?3oooool0
00gooooo1onVYZH7og=cL`OoNWYj1omZJVX6oiJFUPOoSHf=1onXZ:P<ooooo`Ko7QhN1oli>CT7ocPh
>0Oo<30`1om7AdL7obXZ:POo<S8b1_mNGUh5ooooo`OoZj^[1omLG5`7odQ8B0Oo;Bd]1ol[:b/7ob<S
8`OoB4Q81_n`/;05ooooo`OoOWin1onCTi<7ochn?POo@4101olO7al6oeEEE@Oo?clo1_le=CD6oooo
o`Oo`<301oodm?@6omcLg0Oooooo1oo_knl7on[ZjPOok>c/1_nf][H5ooooo`OoRXZ:1olQ8B47of][
J`Oo@4101omgMgL7oi6AT@Oo9BDU1_ln?Sh5ooooo`OoJFUY1omEEED7omgMg@Oo<30`1omaLG47oc`l
?0KoK6a/1_n5QHD6ooooo`Oo5aLG1olk>c/7oa8B4PKo:BTY1olh>3P7obDU9@OoAdM71_m?Cdl?oooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-1.97241, \
-0.428616, 0.147467, 0.147467}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-10.7743, -0.428616, 0.147467, 0.147467}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-19.5537, -0.423519, 0.147297, 0.147297}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-28.3874, -0.428616, 0.147467, 0.147467}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-37.1894, -0.428616, 0.147467, 0.147467}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-45.9384, -0.423519, 0.147297, \
0.147297}, {{371.625, 425.875}, {116.812, 62.5}} -> {-54.8024, -0.428616, \
0.147467, 0.147467}, {{431.312, 485.562}, {116.812, 62.5}} -> {-63.6044, \
-0.428616, 0.147467, 0.147467}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-1.97241, -9.23055, 0.147467, 0.147467}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-10.7743, -9.23055, 0.147467, 0.147467}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-19.5537, -9.21532, 0.147297, 0.147297}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-28.3874, -9.23055, 0.147467, 0.147467}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-37.1894, -9.23055, 0.147467, \
0.147467}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-45.9384, -9.21532, \
0.147297, 0.147297}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-54.8024, \
-9.23055, 0.147467, 0.147467}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-63.6044, -9.23055, 0.147467, 0.147467}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
647E5B23
2A555329
00344115
FFE28D2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0900121D
2A3B2926
A8FFBA4E
414D391E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2CBBC1FF
005573EF
23205F9A
82953F79
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A224C08
112B3712
2C180C00
5D50FF4A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D311844
0E4B42AA
025471FF
22120017
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2BBFFF4A
00241C0C
060C1216
123E1908
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
050E1730
00121805
20292915
193447FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D000002
0B130907
0B121710
FF1B1710
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C004228
494C3B37
745A7379
3A3FD0FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B241A23
FF7B150E
5A2B000E
29241227
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
031A50B2
12002B4B
2F131B24
0C477DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000221F
14040024
09071215
162FFF09
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
87160C1D
C43F110B
FF862C2A
2400163E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00121E06
1A64FF5E
160B3918
10150512
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF661400
2C1D0D12
1216301C
42312A39
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D390204
100F0C01
07000C0B
49FF2722
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>ofATI0koOWin3OmK
Fe/=ob<S8`Kooooo3Ol92@T>o`0000ko4Q8B3OlM7Ad5ooooo`ko;2`/3_nk^k/>ol71`A;ooooo3_lZ
:RX>ob8R8PgoC4a<3Ol820P6ooooo`ko7AdM3Ola<C4>oaPH60goA4A41Oooool>ob/[:`ko_kno3_oo
ool=odY:BPGooooo3_l51@D>o`h>3Pko5aLG3?l`<306ooooo`ko;Bd]6ol0000=o`820Poooooo000=
ooooo`koI6AT3_mnOWh=oe]KF`go8b<S1_ooool=o`T92@ko00003_lB4Q8=oadM7@Gooooo3_l/;2`>
ok^k^`ko`L714_ooool>obXZ:Pko8R8R3Om<C4`=o`P820Kooooo3_lM7Ad=oc4a<@ko61PH3Om4A4@5
ooooo`ko:b/[3_no_kl>ooooo`goBTY:1Oooool>o`D51@ko3Ph>3_lG5aL<oc0`<0Kooooo3_l];BdK
o`0000go0P823oooool000gooooo3_mTI6@>oginOPgoFe]K3OlS8b<6ooooo`go2@T93_l0000>oa8B
4Pgo7AdM1Oooool>ob`/;0ko^k^k3_o1`L4Booooo`ko:RXZ3_lR8R8=oda<C0go20P81_ooool>oadM
7@go<C4a3_lH61P=odA4A0Gooooo3_l[:b/>okno_`kooooo3Om:BTX5ooooo`ko1@D53_l>3Ph>oaLG
5`co<30`1_ooool>obd];A_o00003Ol20P8?ooooo`003Oooool>ofATI0koOWin3OmKFe/=ob<S8`Ko
oooo3Ol92@T>o`0000ko4Q8B3OlM7Ad5ooooo`ko;2`/3_nk^k/>ol71`A;ooooo3_lZ:RX>ob8R8Pgo
C4a<3Ol820P6ooooo`ko7AdM3Ola<C4>oaPH60goA4A41Oooool>ob/[:`ko_kno3_ooool=odY:BPGo
oooo3_l51@D>o`h>3Pko5aLG3?l`<306ooooo`ko;Bd]6ol0000=o`820Poooooo000=ooooo`koI6AT
3_mnOWh=oe]KF`go8b<S1_ooool=o`T92@ko00003_lB4Q8=oadM7@Gooooo3_l/;2`>ok^k^`ko`L71
4_ooool>obXZ:Pko8R8R3Om<C4`=o`P820Kooooo3_lM7Ad=oc4a<@ko61PH3Om4A4@5ooooo`ko:b/[
3_no_kl>ooooo`goBTY:1Oooool>o`D51@ko3Ph>3_lG5aL<oc0`<0Kooooo3_l];BdKo`0000go0P82
3oooool000gooooo3_mTI6@>oginOPgoFe]K3OlS8b<6ooooo`go2@T93_l0000>oa8B4Pgo7AdM1Ooo
ool>ob`/;0ko^k^k3_o1`L4Booooo`ko:RXZ3_lR8R8=oda<C0go20P81_ooool>oadM7@go<C4a3_lH
61P=odA4A0Gooooo3_l[:b/>okno_`kooooo3Om:BTX5ooooo`ko1@D53_l>3Ph>oaLG5`co<30`1_oo
ool>obd];A_o00003Ol20P8?ooooo`003Oooool>ofATI0koOWin3OmKFe/=ob<S8`Kooooo3Ol92@T>
o`0000ko4Q8B3OlM7Ad5ooooo`ko;2`/3_nk^k/>ol71`A;ooooo3_lZ:RX>ob8R8PgoC4a<3Ol820P6
ooooo`ko7AdM3Ola<C4>oaPH60goA4A41Oooool>ob/[:`ko_kno3_ooool=odY:BPGooooo3_l51@D>
o`h>3Pko5aLG3?l`<306ooooo`ko;Bd]6ol0000=o`820Poooooo000=ooooo`koI6AT3_mnOWh=oe]K
F`go8b<S1_ooool=o`T92@ko00003_lB4Q8=oadM7@Gooooo3_l/;2`>ok^k^`ko`L714_ooool>obXZ
:Pko8R8R3Om<C4`=o`P820Kooooo3_lM7Ad=oc4a<@ko61PH3Om4A4@5ooooo`ko:b/[3_no_kl>oooo
o`goBTY:1Oooool>o`D51@ko3Ph>3_lG5aL<oc0`<0Kooooo3_l];BdKo`0000go0P823oooool000go
oooo3_mTI6@>oginOPgoFe]K3OlS8b<6ooooo`go2@T93_l0000>oa8B4Pgo7AdM1Oooool>ob`/;0ko
^k^k3_o1`L4Booooo`ko:RXZ3_lR8R8=oda<C0go20P81_ooool>oadM7@go<C4a3_lH61P=odA4A0Go
oooo3_l[:b/>okno_`kooooo3Om:BTX5ooooo`ko1@D53_l>3Ph>oaLG5`co<30`1_ooool>obd];A_o
00003Ol20P8?ooooo`003Oooool>ofATI0koOWin3OmKFe/=ob<S8`Kooooo3Ol92@T>o`0000ko4Q8B
3OlM7Ad5ooooo`ko;2`/3_nk^k/>ol71`A;ooooo3_lZ:RX>ob8R8PgoC4a<3Ol820P6ooooo`ko7AdM
3Ola<C4>oaPH60goA4A41Oooool>ob/[:`ko_kno3_ooool=odY:BPGooooo3_l51@D>o`h>3Pko5aLG
3?l`<306ooooo`ko;Bd]6ol0000=o`820Poooooo000=ooooo`koI6AT3_mnOWh=oe]KF`go8b<S1_oo
ool=o`T92@ko00003_lB4Q8=oadM7@Gooooo3_l/;2`>ok^k^`ko`L714_ooool>obXZ:Pko8R8R3Om<
C4`=o`P820Kooooo3_lM7Ad=oc4a<@ko61PH3Om4A4@5ooooo`ko:b/[3_no_kl>ooooo`goBTY:1Ooo
ool>o`D51@ko3Ph>3_lG5aL<oc0`<0Kooooo3_l];BdKo`0000go0P823oooool000gooooo3_mTI6@>
oginOPgoFe]K3OlS8b<6ooooo`go2@T93_l0000>oa8B4Pgo7AdM1Oooool>ob`/;0ko^k^k3_o1`L4B
ooooo`ko:RXZ3_lR8R8=oda<C0go20P81_ooool>oadM7@go<C4a3_lH61P=odA4A0Gooooo3_l[:b/>
okno_`kooooo3Om:BTX5ooooo`ko1@D53_l>3Ph>oaLG5`co<30`1_ooool>obd];A_o00003Ol20P8?
ooooo`003Oooool>ofATI0koOWin3OmKFe/=ob<S8`Kooooo3Ol92@T>o`0000ko4Q8B3OlM7Ad5oooo
o`ko;2`/3_nk^k/>ol71`A;ooooo3_lZ:RX>ob8R8PgoC4a<3Ol820P6ooooo`ko7AdM3Ola<C4>oaPH
60goA4A41Oooool>ob/[:`ko_kno3_ooool=odY:BPGooooo3_l51@D>o`h>3Pko5aLG3?l`<306oooo
o`ko;Bd]6ol0000=o`820Poooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko
>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go
4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko
00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ
3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c
3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo
3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C
3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY
:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_oo
ool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB
4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=
oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5
ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>
ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=
o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV
9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>
3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH
60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go
:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko
4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko
71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oo
oooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo
3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];
3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D5
1_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_oo
ool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[
:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<
30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=
ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>
oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=
ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>
o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ
:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg
=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5oooo
o`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko
:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@ko
Lg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGo
oooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go
4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mEEED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k
3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B
1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0000>ob@T90ko71`L3Ol<30`5ooooo`ko0000
3_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l92@T=o`L71`oooooo000=ooooo`ko:RXZ3_mE
EED=oe=CD`go:BTY1_ooool=obXZ:Pko>c/k3_lY:BT=obHV9PGooooo3_l0000>oeEEE@koLg=c3Oo_
knl5ooooo`ko4A4A3_l[:b/=ocLg=`go4Q8B1_ooool>o`h>3PgoBd];3_m2@T8=ojZZZPGooooo3_l0
000>ob@T90ko71`L3Ol<30`5ooooo`ko00003_lB4Q8>oaPH60co1@D51_ooool>o`/;2`go4a<C3_l9
2@T=o`L71`oooooo000=ooooo`ko00003_ld=3@=od51@@go5ADE1_ooool=ojRXZ0kooooo3_nj^[X=
odi>CPGooooo3_lS8b<>ob0P80koGemO3OnJVYX5ooooo`ko;2`/3_lH61P=o``<30go00001_ooool>
o`820PgoE5AD3_maLG4Booooo`ko1PH63_l<30`>oa8B4Pgo5QHF1Oooool>ob0P81co:BTY3?lE5AD6
ooooo`ko2`/;3OlB4Q8>oaLG5`go410@3oooool000gooooo3_l0000>oc@d=0go@D513OlE5AD6oooo
o`goZ:RX3_ooool>okZj^PgoCTi>1Oooool>ob<S8`ko820P3_mOGel=oiZJVPGooooo3_l/;2`>oaPH
60go30`<3Ol00006ooooo`ko0P823OmDE5@>og5aLA;ooooo3_l61PH>o``<30ko4Q8B3OlF5QH5oooo
o`ko820P7?lY:BT<oaDE5@Kooooo3_l;2`/=oa8B4Pko5aLG3Ol@410?ooooo`003Oooool>o`0000ko
=3@d3Om1@D4=oaDE5@Kooooo3OnXZ:P>ooooo`ko^[Zj3Om>CTh5ooooo`ko8b<S3_lP820>oemOG`go
VYZJ1Oooool>ob`/;0ko61PH3Ol<30`=o`0000Kooooo3_l20P8=oeADE0koLG5a4_ooool>o`H61Pko
30`<3_lB4Q8=oaHF5PGooooo3_lP820LobTY:@co5ADE1_ooool>o`/;2`go4Q8B3_lG5aL=oa0@40oo
oooo000=ooooo`ko00003_ld=3@=od51@@go5ADE1_ooool=ojRXZ0kooooo3_nj^[X=odi>CPGooooo
3_lS8b<>ob0P80koGemO3OnJVYX5ooooo`ko;2`/3_lH61P=o``<30go00001_ooool>o`820PgoE5AD
3_maLG4Booooo`ko1PH63_l<30`>oa8B4Pgo5QHF1Oooool>ob0P81co:BTY3?lE5AD6ooooo`ko2`/;
3OlB4Q8>oaLG5`go410@3oooool000gooooo3_l0000>oc@d=0go@D513OlE5AD6ooooo`goZ:RX3_oo
ool>okZj^PgoCTi>1Oooool>ob<S8`ko820P3_mOGel=oiZJVPGooooo3_l/;2`>oaPH60go30`<3Ol0
0006ooooo`ko0P823OmDE5@>og5aLA;ooooo3_l61PH>o``<30ko4Q8B3OlF5QH5ooooo`ko820P7?lY
:BT<oaDE5@Kooooo3_l;2`/=oa8B4Pko5aLG3Ol@410?ooooo`003Oooool>o`0000ko=3@d3Om1@D4=
oaDE5@Kooooo3OnXZ:P>ooooo`ko^[Zj3Om>CTh5ooooo`ko8b<S3_lP820>oemOG`goVYZJ1Oooool>
ob`/;0ko61PH3Ol<30`=o`0000Kooooo3_l20P8=oeADE0koLG5a4_ooool>o`H61Pko30`<3_lB4Q8=
oaHF5PGooooo3_lP820LobTY:@co5ADE1_ooool>o`/;2`go4Q8B3_lG5aL=oa0@40oooooo000=oooo
o`ko00003_ld=3@=od51@@go5ADE1_ooool=ojRXZ0kooooo3_nj^[X=odi>CPGooooo3_lS8b<>ob0P
80koGemO3OnJVYX5ooooo`ko;2`/3_lH61P=o``<30go00001_ooool>o`820PgoE5AD3_maLG4Boooo
o`ko1PH63_l<30`>oa8B4Pgo5QHF1Oooool>ob0P81co:BTY3?lE5AD6ooooo`ko2`/;3OlB4Q8>oaLG
5`go410@3oooool000gooooo3_l0000>oc@d=0go@D513OlE5AD6ooooo`goZ:RX3_ooool>okZj^Pgo
CTi>1Oooool>ob<S8`ko820P3_mOGel=oiZJVPGooooo3_l/;2`>oaPH60go30`<3Ol00006ooooo`ko
0P823OmDE5@>og5aLA;ooooo3_l61PH>o``<30ko4Q8B3OlF5QH5ooooo`ko820P7?lY:BT<oaDE5@Ko
oooo3_l;2`/=oa8B4Pko5aLG3Ol@410?ooooo`003Oooool>o`0000ko=3@d3Om1@D4=oaDE5@Kooooo
3OnXZ:P>ooooo`ko^[Zj3Om>CTh5ooooo`ko8b<S3_lP820>oemOG`goVYZJ1Oooool>ob`/;0ko61PH
3Ol<30`=o`0000Kooooo3_l20P8=oeADE0koLG5a4_ooool>o`H61Pko30`<3_lB4Q8=oaHF5PGooooo
3_lP820LobTY:@co5ADE1_ooool>o`/;2`go4Q8B3_lG5aL=oa0@40oooooo000=ooooo`ko00003_ld
=3@=od51@@go5ADE1_ooool=ojRXZ0kooooo3_nj^[X=odi>CPGooooo3_lS8b<>ob0P80koGemO3OnJ
VYX5ooooo`ko;2`/3_lH61P=o``<30go00001_ooool>o`820PgoE5AD3_maLG4Booooo`ko1PH63_l<
30`>oa8B4Pgo5QHF1Oooool>ob0P81co:BTY3?lE5AD6ooooo`ko2`/;3OlB4Q8>oaLG5`go410@3ooo
ool000gooooo3_l0000>oc@d=0go@D513OlE5AD6ooooo`goZ:RX3_ooool>okZj^PgoCTi>1Oooool>
ob<S8`ko820P3_mOGel=oiZJVPGooooo3_l/;2`>oaPH60go30`<3Ol00006ooooo`ko0P823OmDE5@>
og5aLA;ooooo3_l61PH>o``<30ko4Q8B3OlF5QH5ooooo`ko820P7?lY:BT<oaDE5@Kooooo3_l;2`/=
oa8B4Pko5aLG3Ol@410?ooooo`003Oooool>o`0000ko=3@d3Om1@D4=oaDE5@Kooooo3OnXZ:P>oooo
o`ko^[Zj3Om>CTh5ooooo`ko8b<S3_lP820>oemOG`goVYZJ1Oooool>ob`/;0ko61PH3Ol<30`=o`00
00Kooooo3_l20P8=oeADE0koLG5a4_ooool>o`H61Pko30`<3_lB4Q8=oaHF5PGooooo3_lP820LobTY
:@co5ADE1_ooool>o`/;2`go4Q8B3_lG5aL=oa0@40oooooo000=ooooo`ko00003_ld=3@=od51@@go
5ADE1_ooool=ojRXZ0kooooo3_nj^[X=odi>CPGooooo3_lS8b<>ob0P80koGemO3OnJVYX5ooooo`ko
;2`/3_lH61P=o``<30go00001_ooool>o`820PgoE5AD3_maLG4Booooo`ko1PH63_l<30`>oa8B4Pgo
5QHF1Oooool>ob0P81co:BTY3?lE5AD6ooooo`ko2`/;3OlB4Q8>oaLG5`go410@3oooool000gooooo
3_l0000>oc@d=0go@D513OlE5AD6ooooo`goZ:RX3_ooool>okZj^PgoCTi>1Oooool>ob<S8`ko820P
3_mOGel=oiZJVPGooooo3_l/;2`>oaPH60go30`<3Ol00006ooooo`ko0P823OmDE5@>og5aLA;ooooo
3_l61PH>o``<30ko4Q8B3OlF5QH5ooooo`ko820P7?lY:BT<oaDE5@Kooooo3_l;2`/=oa8B4Pko5aLG
3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Ooo
ool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB
4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?oo
ool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>
ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6
ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>
oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6oooo
o`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@
D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P8
20Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgo
SHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Go
oooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko
?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`00
6oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE
3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG
1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG
3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Ooo
ool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB
4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?oo
ool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>
ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6
ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>
oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6oooo
o`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@
D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P8
20Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgo
SHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Go
oooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko
?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`00
6oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE
3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG
1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG
3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>ocTi>@go7QhN1Ooo
ool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6ooooo`ko8R8R3OlB
4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>oc@d=0koAdM78?oo
ool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6ooooo`go@D513_m=CDd>
ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@D0gooooo3Om:BTX6
ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P820Gooooo3_lI6AT>
oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`006oooool>on;RhPgoSHf=3Ol];Bd6oooo
o`go@D513_m=CDd>ocTi>@go7QhN1Oooool>oh:2PPkoUIFE3_lo?cl=ogUiN@Gooooo3_mMGEd>oe1@
D0gooooo3Om:BTX6ooooo`ko8R8R3OlB4Q8>o`0000go5aLG1Oooool>oa8B4Pko?Shn3_lI6AT=o`P8
20Gooooo3_lI6AT>oc@d=0koAdM78?ooool=oa/K6`ko5aLG3Ol@410?ooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00
3Oooool>o``<30ko00003Om2@T8=obPX:0Kooooo3Ol[:b/>ob@T90ko6QXJ3OlS8b<5ooooo`ko0`<3
3_lJ6QX>oe1@D0go/[:b1OoooolLo`0000go8R8R3OlO7al6ooooo`koQhN73OlF5QH>o``<30go7AdM
1Oooool>o`0000ko4Q8B3_lN7Qh=o`H61Q?ooooo3_mVIVH>oa@D50co00001_ooool>o`d=3@go>CTi
3_l20P8=o`@410oooooo000=ooooo`ko30`<3_l0000=od92@Pgo:2PX1_ooool=ob/[:`ko92@T3_lJ
6QX=ob<S8`Gooooo3_l30`<>oaXJ6PkoD51@3Onb/[85oooooaco00003OlR8R8=oalO7`Kooooo3_n7
QhL=oaHF5Pko30`<3OlM7Ad5ooooo`ko00003_lB4Q8>oahN7Pgo1PH64oooool>ofIVIPko51@D3?l0
0006ooooo`ko3@d=3Oli>CT>o`820Pgo10@43oooool000gooooo3_l<30`>o`0000go@T923OlX:2P6
ooooo`go:b/[3_lT92@>oaXJ6Pgo8b<S1Oooool>o`<30`ko6QXJ3_m@D50=ok:b/PGooooo7?l0000=
ob8R8Pgo7alO1_ooool>ohN7Q`go5QHF3_l<30`=oadM7@Gooooo3_l0000>oa8B4Pko7QhN3Ol61PHC
ooooo`koIVIV3_lD51@<o`0000Kooooo3_l=3@d=ocTi>@ko0P823Ol410@?ooooo`003Oooool>o``<
30ko00003Om2@T8=obPX:0Kooooo3Ol[:b/>ob@T90ko6QXJ3OlS8b<5ooooo`ko0`<33_lJ6QX>oe1@
D0go/[:b1OoooolLo`0000go8R8R3OlO7al6ooooo`koQhN73OlF5QH>o``<30go7AdM1Oooool>o`00
00ko4Q8B3_lN7Qh=o`H61Q?ooooo3_mVIVH>oa@D50co00001_ooool>o`d=3@go>CTi3_l20P8=o`@4
10oooooo000=ooooo`ko30`<3_l0000=od92@Pgo:2PX1_ooool=ob/[:`ko92@T3_lJ6QX=ob<S8`Go
oooo3_l30`<>oaXJ6PkoD51@3Onb/[85oooooaco00003OlR8R8=oalO7`Kooooo3_n7QhL=oaHF5Pko
30`<3OlM7Ad5ooooo`ko00003_lB4Q8>oahN7Pgo1PH64oooool>ofIVIPko51@D3?l00006ooooo`ko
3@d=3Oli>CT>o`820Pgo10@43oooool000gooooo3_l<30`>o`0000go@T923OlX:2P6ooooo`go:b/[
3_lT92@>oaXJ6Pgo8b<S1Oooool>o`<30`ko6QXJ3_m@D50=ok:b/PGooooo7?l0000=ob8R8Pgo7alO
1_ooool>ohN7Q`go5QHF3_l<30`=oadM7@Gooooo3_l0000>oa8B4Pko7QhN3Ol61PHCooooo`koIVIV
3_lD51@<o`0000Kooooo3_l=3@d=ocTi>@ko0P823Ol410@?ooooo`003Oooool>o``<30ko00003Om2
@T8=obPX:0Kooooo3Ol[:b/>ob@T90ko6QXJ3OlS8b<5ooooo`ko0`<33_lJ6QX>oe1@D0go/[:b1Ooo
oolLo`0000go8R8R3OlO7al6ooooo`koQhN73OlF5QH>o``<30go7AdM1Oooool>o`0000ko4Q8B3_lN
7Qh=o`H61Q?ooooo3_mVIVH>oa@D50co00001_ooool>o`d=3@go>CTi3_l20P8=o`@410oooooo000=
ooooo`ko30`<3_l0000=od92@Pgo:2PX1_ooool=ob/[:`ko92@T3_lJ6QX=ob<S8`Gooooo3_l30`<>
oaXJ6PkoD51@3Onb/[85oooooaco00003OlR8R8=oalO7`Kooooo3_n7QhL=oaHF5Pko30`<3OlM7Ad5
ooooo`ko00003_lB4Q8>oahN7Pgo1PH64oooool>ofIVIPko51@D3?l00006ooooo`ko3@d=3Oli>CT>
o`820Pgo10@43oooool000gooooo3_l<30`>o`0000go@T923OlX:2P6ooooo`go:b/[3_lT92@>oaXJ
6Pgo8b<S1Oooool>o`<30`ko6QXJ3_m@D50=ok:b/PGooooo7?l0000=ob8R8Pgo7alO1_ooool>ohN7
Q`go5QHF3_l<30`=oadM7@Gooooo3_l0000>oa8B4Pko7QhN3Ol61PHCooooo`koIVIV3_lD51@<o`00
00Kooooo3_l=3@d=ocTi>@ko0P823Ol410@?ooooo`003Oooool>o``<30ko00003Om2@T8=obPX:0Ko
oooo3Ol[:b/>ob@T90ko6QXJ3OlS8b<5ooooo`ko0`<33_lJ6QX>oe1@D0go/[:b1OoooolLo`0000go
8R8R3OlO7al6ooooo`koQhN73OlF5QH>o``<30go7AdM1Oooool>o`0000ko4Q8B3_lN7Qh=o`H61Q?o
oooo3_mVIVH>oa@D50co00001_ooool>o`d=3@go>CTi3_l20P8=o`@410oooooo000=ooooo`ko30`<
3_l0000=od92@Pgo:2PX1_ooool=ob/[:`ko92@T3_lJ6QX=ob<S8`Gooooo3_l30`<>oaXJ6PkoD51@
3Onb/[85oooooaco00003OlR8R8=oalO7`Kooooo3_n7QhL=oaHF5Pko30`<3OlM7Ad5ooooo`ko0000
3_lB4Q8>oahN7Pgo1PH64oooool>ofIVIPko51@D3?l00006ooooo`ko3@d=3Oli>CT>o`820Pgo10@4
3oooool000gooooo3_l<30`>o`0000go@T923OlX:2P6ooooo`go:b/[3_lT92@>oaXJ6Pgo8b<S1Ooo
ool>o`<30`ko6QXJ3_m@D50=ok:b/PGooooo7?l0000=ob8R8Pgo7alO1_ooool>ohN7Q`go5QHF3_l<
30`=oadM7@Gooooo3_l0000>oa8B4Pko7QhN3Ol61PHCooooo`koIVIV3_lD51@<o`0000Kooooo3_l=
3@d=ocTi>@ko0P823Ol410@?ooooo`003Oooool>o``<30ko00003Om2@T8=obPX:0Kooooo3Ol[:b/>
ob@T90ko6QXJ3OlS8b<5ooooo`ko0`<33_lJ6QX>oe1@D0go/[:b1OoooolLo`0000go8R8R3OlO7al6
ooooo`koQhN73OlF5QH>o``<30go7AdM1Oooool>o`0000ko4Q8B3_lN7Qh=o`H61Q?ooooo3_mVIVH>
oa@D50co00001_ooool>o`d=3@go>CTi3_l20P8=o`@410oooooo000=ooooo`ko30`<3_l0000=od92
@Pgo:2PX1_ooool=ob/[:`ko92@T3_lJ6QX=ob<S8`Gooooo3_l30`<>oaXJ6PkoD51@3Onb/[85oooo
oaco00003OlR8R8=oalO7`Kooooo3_n7QhL=oaHF5Pko30`<3OlM7Ad5ooooo`ko00003_lB4Q8>oahN
7Pgo1PH64oooool>ofIVIPko51@D3?l00006ooooo`ko3@d=3Oli>CT>o`820Pgo10@43oooool000go
oooo3_m9BDT>oda<C0go>c/k3Olg=cLCooooo`koNg]k3_lE5AD=o`h>3PGooooo3_lB4Q8>o`0000ko
:b/[3Om;Bd/5ooooo`ko51@D3_l410@=o`0000go92@T1_ooool>olC4a0go?clo3_lA4A4=o`/;2`Go
oooo3_lJ6QX>ofATI0kooooo3OmNGUh5ooooo`ko;2`/3_lM7Ad>o`d=3@co4Q8B1_ooool>oa0@40go
3`l?3_l<30`=o`410@oooooo000=ooooo`koBDU93_m<C4`=oc/k>`go=cLg4oooool>og]kN`ko5ADE
3Ol>3Ph5ooooo`ko4Q8B3_l0000>ob/[:`goBd];1Oooool>oa@D50ko10@43Ol0000=ob@T90Kooooo
3_o4a<@=oclo?`ko4A4A3Ol;2`/5ooooo`ko6QXJ3_mTI6@>ooooo`goGUiN1Oooool>ob`/;0ko7AdM
3_l=3@d<oa8B4PKooooo3_l@410=o`l?3`ko30`<3Ol10@4?ooooo`003Oooool>odU9B@koC4a<3Olk
>c/=ocLg=a?ooooo3_mkNg/>oaDE5@go3Ph>1Oooool>oa8B4Pko00003_l[:b/=od];B`Gooooo3_lD
51@>o`@410go00003OlT92@6ooooo`koa<C43Olo?cl>oa4A4@go2`/;1Oooool>oaXJ6PkoI6AT3_oo
ool=oeiNGPGooooo3_l/;2`>oadM7@ko3@d=3?lB4Q86ooooo`ko410@3Ol?3`l>o``<30go0@413ooo
ool000gooooo3_m9BDT>oda<C0go>c/k3Olg=cLCooooo`koNg]k3_lE5AD=o`h>3PGooooo3_lB4Q8>
o`0000ko:b/[3Om;Bd/5ooooo`ko51@D3_l410@=o`0000go92@T1_ooool>olC4a0go?clo3_lA4A4=
o`/;2`Gooooo3_lJ6QX>ofATI0kooooo3OmNGUh5ooooo`ko;2`/3_lM7Ad>o`d=3@co4Q8B1_ooool>
oa0@40go3`l?3_l<30`=o`410@oooooo000=ooooo`koBDU93_m<C4`=oc/k>`go=cLg4oooool>og]k
N`ko5ADE3Ol>3Ph5ooooo`ko4Q8B3_l0000>ob/[:`goBd];1Oooool>oa@D50ko10@43Ol0000=ob@T
90Kooooo3_o4a<@=oclo?`ko4A4A3Ol;2`/5ooooo`ko6QXJ3_mTI6@>ooooo`goGUiN1Oooool>ob`/
;0ko7AdM3_l=3@d<oa8B4PKooooo3_l@410=o`l?3`ko30`<3Ol10@4?ooooo`003Oooool>odU9B@ko
C4a<3Olk>c/=ocLg=a?ooooo3_mkNg/>oaDE5@go3Ph>1Oooool>oa8B4Pko00003_l[:b/=od];B`Go
oooo3_lD51@>o`@410go00003OlT92@6ooooo`koa<C43Olo?cl>oa4A4@go2`/;1Oooool>oaXJ6Pko
I6AT3_ooool=oeiNGPGooooo3_l/;2`>oadM7@ko3@d=3?lB4Q86ooooo`ko410@3Ol?3`l>o``<30go
0@413oooool000gooooo3_m9BDT>oda<C0go>c/k3Olg=cLCooooo`koNg]k3_lE5AD=o`h>3PGooooo
3_lB4Q8>o`0000ko:b/[3Om;Bd/5ooooo`ko51@D3_l410@=o`0000go92@T1_ooool>olC4a0go?clo
3_lA4A4=o`/;2`Gooooo3_lJ6QX>ofATI0kooooo3OmNGUh5ooooo`ko;2`/3_lM7Ad>o`d=3@co4Q8B
1_ooool>oa0@40go3`l?3_l<30`=o`410@oooooo000=ooooo`koBDU93_m<C4`=oc/k>`go=cLg4ooo
ool>og]kN`ko5ADE3Ol>3Ph5ooooo`ko4Q8B3_l0000>ob/[:`goBd];1Oooool>oa@D50ko10@43Ol0
000=ob@T90Kooooo3_o4a<@=oclo?`ko4A4A3Ol;2`/5ooooo`ko6QXJ3_mTI6@>ooooo`goGUiN1Ooo
ool>ob`/;0ko7AdM3_l=3@d<oa8B4PKooooo3_l@410=o`l?3`ko30`<3Ol10@4?ooooo`003Oooool>
odU9B@koC4a<3Olk>c/=ocLg=a?ooooo3_mkNg/>oaDE5@go3Ph>1Oooool>oa8B4Pko00003_l[:b/=
od];B`Gooooo3_lD51@>o`@410go00003OlT92@6ooooo`koa<C43Olo?cl>oa4A4@go2`/;1Oooool>
oaXJ6PkoI6AT3_ooool=oeiNGPGooooo3_l/;2`>oadM7@ko3@d=3?lB4Q86ooooo`ko410@3Ol?3`l>
o``<30go0@413oooool000gooooo3_m9BDT>oda<C0go>c/k3Olg=cLCooooo`koNg]k3_lE5AD=o`h>
3PGooooo3_lB4Q8>o`0000ko:b/[3Om;Bd/5ooooo`ko51@D3_l410@=o`0000go92@T1_ooool>olC4
a0go?clo3_lA4A4=o`/;2`Gooooo3_lJ6QX>ofATI0kooooo3OmNGUh5ooooo`ko;2`/3_lM7Ad>o`d=
3@co4Q8B1_ooool>oa0@40go3`l?3_l<30`=o`410@oooooo000=ooooo`koBDU93_m<C4`=oc/k>`go
=cLg4oooool>og]kN`ko5ADE3Ol>3Ph5ooooo`ko4Q8B3_l0000>ob/[:`goBd];1Oooool>oa@D50ko
10@43Ol0000=ob@T90Kooooo3_o4a<@=oclo?`ko4A4A3Ol;2`/5ooooo`ko6QXJ3_mTI6@>ooooo`go
GUiN1Oooool>ob`/;0ko7AdM3_l=3@d<oa8B4PKooooo3_l@410=o`l?3`ko30`<3Ol10@4?ooooo`00
3Oooool>odU9B@koC4a<3Olk>c/=ocLg=a?ooooo3_mkNg/>oaDE5@go3Ph>1Oooool>oa8B4Pko0000
3_l[:b/=od];B`Gooooo3_lD51@>o`@410go00003OlT92@6ooooo`koa<C43Olo?cl>oa4A4@go2`/;
1Oooool>oaXJ6PkoI6AT3_ooool=oeiNGPGooooo3_l/;2`>oadM7@ko3@d=3?lB4Q86ooooo`ko410@
3Ol?3`l>o``<30go0@413oooool000gooooo3_m9BDT>oda<C0go>c/k3Olg=cLCooooo`koNg]k3_lE
5AD=o`h>3PGooooo3_lB4Q8>o`0000ko:b/[3Om;Bd/5ooooo`ko51@D3_l410@=o`0000go92@T1_oo
ool>olC4a0go?clo3_lA4A4=o`/;2`Gooooo3_lJ6QX>ofATI0kooooo3OmNGUh5ooooo`ko;2`/3_lM
7Ad>o`d=3@co4Q8B1_ooool>oa0@40go3`l?3_l<30`=o`410@oooooo000=ooooo`koM7Ad3_mJFUX=
og=cL`goNGUi1_ooool=oeYJFPko:b/[3_l0000=o`h>3PGooooo3_l_;bl>oa<C4`ko6a/K3OlT92@5
ooooo`ko2@T93_l71`L=oa8B4Pgo5ADE5?ooool=ohJ6QPko;2`/3OlZ:RX5ooooo`ko5QHF3_l;2`/>
ocTi>@go61PH1Oooool>oa8B4Pko5QHF3_l`<30<oa`L70Kooooo3_l71`L=o`0000ko30`<3Ol;2`/?
ooooo`003Oooool>ogAdM0koFUYJ3OmcLg<=ogUiN@Kooooo3OmJFUX>ob/[:`ko00003Ol>3Ph5oooo
o`ko;bl_3_lC4a<>oa/K6`go92@T1Oooool>o`T92@ko1`L73OlB4Q8=oaDE5ACooooo3On6QXH>ob`/
;0go:RXZ1Oooool>oaHF5Pko2`/;3_li>CT=oaPH60Gooooo3_lB4Q8>oaHF5Pko<30`3?lL71`6oooo
o`ko1`L73Ol0000>o``<30go2`/;3oooool000gooooo3_mdM7@>oeYJFPgoLg=c3OmiNGT6ooooo`go
FUYJ3_l[:b/>o`0000go3Ph>1Oooool>obl_;`ko4a<C3_lK6a/=ob@T90Gooooo3_l92@T>o`L71`go
4Q8B3OlE5ADDooooo`goQXJ63_l/;2`=obXZ:PGooooo3_lF5QH>o`/;2`ko>CTi3OlH61P5ooooo`ko
4Q8B3_lF5QH>oc0`<0co71`L1_ooool>o`L71`go00003_l<30`=o`/;2`oooooo000=ooooo`koM7Ad
3_mJFUX=og=cL`goNGUi1_ooool=oeYJFPko:b/[3_l0000=o`h>3PGooooo3_l_;bl>oa<C4`ko6a/K
3OlT92@5ooooo`ko2@T93_l71`L=oa8B4Pgo5ADE5?ooool=ohJ6QPko;2`/3OlZ:RX5ooooo`ko5QHF
3_l;2`/>ocTi>@go61PH1Oooool>oa8B4Pko5QHF3_l`<30<oa`L70Kooooo3_l71`L=o`0000ko30`<
3Ol;2`/?ooooo`003Oooool>ogAdM0koFUYJ3OmcLg<=ogUiN@Kooooo3OmJFUX>ob/[:`ko00003Ol>
3Ph5ooooo`ko;bl_3_lC4a<>oa/K6`go92@T1Oooool>o`T92@ko1`L73OlB4Q8=oaDE5ACooooo3On6
QXH>ob`/;0go:RXZ1Oooool>oaHF5Pko2`/;3_li>CT=oaPH60Gooooo3_lB4Q8>oaHF5Pko<30`3?lL
71`6ooooo`ko1`L73Ol0000>o``<30go2`/;3oooool000gooooo3_mdM7@>oeYJFPgoLg=c3OmiNGT6
ooooo`goFUYJ3_l[:b/>o`0000go3Ph>1Oooool>obl_;`ko4a<C3_lK6a/=ob@T90Gooooo3_l92@T>
o`L71`go4Q8B3OlE5ADDooooo`goQXJ63_l/;2`=obXZ:PGooooo3_lF5QH>o`/;2`ko>CTi3OlH61P5
ooooo`ko4Q8B3_lF5QH>oc0`<0co71`L1_ooool>o`L71`go00003_l<30`=o`/;2`oooooo000=oooo
o`koM7Ad3_mJFUX=og=cL`goNGUi1_ooool=oeYJFPko:b/[3_l0000=o`h>3PGooooo3_l_;bl>oa<C
4`ko6a/K3OlT92@5ooooo`ko2@T93_l71`L=oa8B4Pgo5ADE5?ooool=ohJ6QPko;2`/3OlZ:RX5oooo
o`ko5QHF3_l;2`/>ocTi>@go61PH1Oooool>oa8B4Pko5QHF3_l`<30<oa`L70Kooooo3_l71`L=o`00
00ko30`<3Ol;2`/?ooooo`003Oooool>ogAdM0koFUYJ3OmcLg<=ogUiN@Kooooo3OmJFUX>ob/[:`ko
00003Ol>3Ph5ooooo`ko;bl_3_lC4a<>oa/K6`go92@T1Oooool>o`T92@ko1`L73OlB4Q8=oaDE5ACo
oooo3On6QXH>ob`/;0go:RXZ1Oooool>oaHF5Pko2`/;3_li>CT=oaPH60Gooooo3_lB4Q8>oaHF5Pko
<30`3?lL71`6ooooo`ko1`L73Ol0000>o``<30go2`/;3oooool000gooooo3_mdM7@>oeYJFPgoLg=c
3OmiNGT6ooooo`goFUYJ3_l[:b/>o`0000go3Ph>1Oooool>obl_;`ko4a<C3_lK6a/=ob@T90Gooooo
3_l92@T>o`L71`go4Q8B3OlE5ADDooooo`goQXJ63_l/;2`=obXZ:PGooooo3_lF5QH>o`/;2`ko>CTi
3OlH61P5ooooo`ko4Q8B3_lF5QH>oc0`<0co71`L1_ooool>o`L71`go00003_l<30`=o`/;2`oooooo
000=ooooo`koM7Ad3_mJFUX=og=cL`goNGUi1_ooool=oeYJFPko:b/[3_l0000=o`h>3PGooooo3_l_
;bl>oa<C4`ko6a/K3OlT92@5ooooo`ko2@T93_l71`L=oa8B4Pgo5ADE5?ooool=ohJ6QPko;2`/3OlZ
:RX5ooooo`ko5QHF3_l;2`/>ocTi>@go61PH1Oooool>oa8B4Pko5QHF3_l`<30<oa`L70Kooooo3_l7
1`L=o`0000ko30`<3Ol;2`/?ooooo`003Oooool>ogAdM0koFUYJ3OmcLg<=ogUiN@Kooooo3OmJFUX>
ob/[:`ko00003Ol>3Ph5ooooo`ko;bl_3_lC4a<>oa/K6`go92@T1Oooool>o`T92@ko1`L73OlB4Q8=
oaDE5ACooooo3On6QXH>ob`/;0go:RXZ1Oooool>oaHF5Pko2`/;3_li>CT=oaPH60Gooooo3_lB4Q8>
oaHF5Pko<30`3?lL71`6ooooo`ko1`L73Ol0000>o``<30go2`/;3oooool000gooooo3_mdM7@>oeYJ
FPgoLg=c3OmiNGT6ooooo`goFUYJ3_l[:b/>o`0000go3Ph>1Oooool>obl_;`ko4a<C3_lK6a/=ob@T
90Gooooo3_l92@T>o`L71`go4Q8B3OlE5ADDooooo`goQXJ63_l/;2`=obXZ:PGooooo3_lF5QH>o`/;
2`ko>CTi3OlH61P5ooooo`ko4Q8B3_lF5QH>oc0`<0co71`L1_ooool>o`L71`go00003_l<30`=o`/;
2`oooooo000=ooooo`koM7Ad3_mJFUX=og=cL`goNGUi1_ooool=oeYJFPko:b/[3_l0000=o`h>3PGo
oooo3_l_;bl>oa<C4`ko6a/K3OlT92@5ooooo`ko2@T93_l71`L=oa8B4Pgo5ADE5?ooool=ohJ6QPko
;2`/3OlZ:RX5ooooo`ko5QHF3_l;2`/>ocTi>@go61PH1Oooool>oa8B4Pko5QHF3_l`<30<oa`L70Ko
oooo3_l71`L=o`0000ko30`<3Ol;2`/?ooooo`003Oooool>ocXj>Pko?clo3Oo@d=0Cooooo`go:BTY
3_lT92@>oa8B4Pgo9bLW1Oooool>o``<30koAdM73_mmOGdBooooo`ko5QHF3_l_;bl=ooooo`go2@T9
1_ooool>ob@T90go00003_lF5QH=ochn?PGooooo3_l@410>oaDE5@ko1@D53OlB4Q85ooooo`ko@T92
3_la<C4>obXZ:Pco>CTi1_ooool>odU9B@gooooo3_lW9bL=ob8R8Poooooo000=ooooo`ko>SXj3_lo
?cl=om3@d1?ooooo3OlY:BT>ob@T90ko4Q8B3OlW9bL5ooooo`ko30`<3_m7AdL>ogemOA;ooooo3_lF
5QH>obl_;`gooooo3Ol92@T6ooooo`ko92@T3Ol0000>oaHF5Pgo?Shn1Oooool>oa0@40ko5ADE3_l5
1@D=oa8B4PGooooo3_m2@T8>oc4a<@ko:RXZ3?li>CT6ooooo`koBDU93Oooool>obLW9`go8R8R3ooo
ool000gooooo3_lj>SX>oclo?`god=3@4oooool=obTY:@ko92@T3_lB4Q8=obLW9`Gooooo3_l<30`>
odM7A`koOGem4_ooool>oaHF5Pko;bl_3Oooool=o`T92@Kooooo3_lT92@=o`0000ko5QHF3Oln?Sh5
ooooo`ko410@3_lE5AD>o`D51@go4Q8B1Oooool>od92@Pko<C4a3_lZ:RX<ocTi>@Kooooo3_m9BDT=
ooooo`ko9bLW3OlR8R8?ooooo`003Oooool>ocXj>Pko?clo3Oo@d=0Cooooo`go:BTY3_lT92@>oa8B
4Pgo9bLW1Oooool>o``<30koAdM73_mmOGdBooooo`ko5QHF3_l_;bl=ooooo`go2@T91_ooool>ob@T
90go00003_lF5QH=ochn?PGooooo3_l@410>oaDE5@ko1@D53OlB4Q85ooooo`ko@T923_la<C4>obXZ
:Pco>CTi1_ooool>odU9B@gooooo3_lW9bL=ob8R8Poooooo000=ooooo`ko>SXj3_lo?cl=om3@d1?o
oooo3OlY:BT>ob@T90ko4Q8B3OlW9bL5ooooo`ko30`<3_m7AdL>ogemOA;ooooo3_lF5QH>obl_;`go
oooo3Ol92@T6ooooo`ko92@T3Ol0000>oaHF5Pgo?Shn1Oooool>oa0@40ko5ADE3_l51@D=oa8B4PGo
oooo3_m2@T8>oc4a<@ko:RXZ3?li>CT6ooooo`koBDU93Oooool>obLW9`go8R8R3oooool000gooooo
3_lj>SX>oclo?`god=3@4oooool=obTY:@ko92@T3_lB4Q8=obLW9`Gooooo3_l<30`>odM7A`koOGem
4_ooool>oaHF5Pko;bl_3Oooool=o`T92@Kooooo3_lT92@=o`0000ko5QHF3Oln?Sh5ooooo`ko410@
3_lE5AD>o`D51@go4Q8B1Oooool>od92@Pko<C4a3_lZ:RX<ocTi>@Kooooo3_m9BDT=ooooo`ko9bLW
3OlR8R8?ooooo`003Oooool>ocXj>Pko?clo3Oo@d=0Cooooo`go:BTY3_lT92@>oa8B4Pgo9bLW1Ooo
ool>o``<30koAdM73_mmOGdBooooo`ko5QHF3_l_;bl=ooooo`go2@T91_ooool>ob@T90go00003_lF
5QH=ochn?PGooooo3_l@410>oaDE5@ko1@D53OlB4Q85ooooo`ko@T923_la<C4>obXZ:Pco>CTi1_oo
ool>odU9B@gooooo3_lW9bL=ob8R8Poooooo000=ooooo`ko>SXj3_lo?cl=om3@d1?ooooo3OlY:BT>
ob@T90ko4Q8B3OlW9bL5ooooo`ko30`<3_m7AdL>ogemOA;ooooo3_lF5QH>obl_;`gooooo3Ol92@T6
ooooo`ko92@T3Ol0000>oaHF5Pgo?Shn1Oooool>oa0@40ko5ADE3_l51@D=oa8B4PGooooo3_m2@T8>
oc4a<@ko:RXZ3?li>CT6ooooo`koBDU93Oooool>obLW9`go8R8R3oooool000gooooo3_lj>SX>oclo
?`god=3@4oooool=obTY:@ko92@T3_lB4Q8=obLW9`Gooooo3_l<30`>odM7A`koOGem4_ooool>oaHF
5Pko;bl_3Oooool=o`T92@Kooooo3_lT92@=o`0000ko5QHF3Oln?Sh5ooooo`ko410@3_lE5AD>o`D5
1@go4Q8B1Oooool>od92@Pko<C4a3_lZ:RX<ocTi>@Kooooo3_m9BDT=ooooo`ko9bLW3OlR8R8?oooo
o`003Oooool>ocXj>Pko?clo3Oo@d=0Cooooo`go:BTY3_lT92@>oa8B4Pgo9bLW1Oooool>o``<30ko
AdM73_mmOGdBooooo`ko5QHF3_l_;bl=ooooo`go2@T91_ooool>ob@T90go00003_lF5QH=ochn?PGo
oooo3_l@410>oaDE5@ko1@D53OlB4Q85ooooo`ko@T923_la<C4>obXZ:Pco>CTi1_ooool>odU9B@go
oooo3_lW9bL=ob8R8Poooooo000=ooooo`ko>SXj3_lo?cl=om3@d1?ooooo3OlY:BT>ob@T90ko4Q8B
3OlW9bL5ooooo`ko30`<3_m7AdL>ogemOA;ooooo3_lF5QH>obl_;`gooooo3Ol92@T6ooooo`ko92@T
3Ol0000>oaHF5Pgo?Shn1Oooool>oa0@40ko5ADE3_l51@D=oa8B4PGooooo3_m2@T8>oc4a<@ko:RXZ
3?li>CT6ooooo`koBDU93Oooool>obLW9`go8R8R3oooool000gooooo3_lj>SX>oclo?`god=3@4ooo
ool=obTY:@ko92@T3_lB4Q8=obLW9`Gooooo3_l<30`>odM7A`koOGem4_ooool>oaHF5Pko;bl_3Ooo
ool=o`T92@Kooooo3_lT92@=o`0000ko5QHF3Oln?Sh5ooooo`ko410@3_lE5AD>o`D51@go4Q8B1Ooo
ool>od92@Pko<C4a3_lZ:RX<ocTi>@Kooooo3_m9BDT=ooooo`ko9bLW3OlR8R8?ooooo`003Oooool>
ocXj>Pko?clo3Oo@d=0Cooooo`go:BTY3_lT92@>oa8B4Pgo9bLW1Oooool>o``<30koAdM73_mmOGdB
ooooo`ko5QHF3_l_;bl=ooooo`go2@T91_ooool>ob@T90go00003_lF5QH=ochn?PGooooo3_l@410>
oaDE5@ko1@D53OlB4Q85ooooo`ko@T923_la<C4>obXZ:Pco>CTi1_ooool>odU9B@gooooo3_lW9bL=
ob8R8Poooooo000=ooooo`ko>SXj3_lo?cl=om3@d1?ooooo3OlY:BT>ob@T90ko4Q8B3OlW9bL5oooo
o`ko30`<3_m7AdL>ogemOA;ooooo3_lF5QH>obl_;`gooooo3Ol92@T6ooooo`ko92@T3Ol0000>oaHF
5Pgo?Shn1Oooool>oa0@40ko5ADE3_l51@D=oa8B4PGooooo3_m2@T8>oc4a<@ko:RXZ3?li>CT6oooo
o`koBDU93Oooool>obLW9`go8R8R3oooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-0.986205, \
-0.214308, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-5.38717, -0.214308, 0.0737335, 0.0737335}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-9.77687, -0.21176, 0.0736486, 0.0736486}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-14.1937, -0.214308, 0.0737335, 0.0737335}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-18.5947, -0.214308, 0.0737335, 0.0737335}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-22.9692, -0.21176, 0.0736486, \
0.0736486}, {{371.625, 425.875}, {116.812, 62.5}} -> {-27.4012, -0.214308, \
0.0737335, 0.0737335}, {{431.312, 485.562}, {116.812, 62.5}} -> {-31.8022, \
-0.214308, 0.0737335, 0.0737335}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-0.986205, -4.61527, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-5.38717, -4.61527, 0.0737335, 0.0737335}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-9.77687, -4.60766, 0.0736486, 0.0736486}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-14.1937, -4.61527, 0.0737335, 0.0737335}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-18.5947, -4.61527, 0.0737335, \
0.0737335}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-22.9692, -4.60766, \
0.0736486, 0.0736486}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-27.4012, \
-4.61527, 0.0737335, 0.0737335}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-31.8022, -4.61527, 0.0737335, 0.0737335}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
160B0AE3
0E1006F9
0D0609FF
0D0400E7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
230B12FF
120A1836
09171726
0E000D1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
88123539
51005C55
270AD47B
2011FF81
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C4BE8219
EADF8200
E4FF8311
B3CF700D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
153E5F64
00685A59
00D3484C
10FF2852
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6E2700BF
5C2304FF
401C13DF
351706A3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A4361031
DA36083B
FF31033B
BA1B0041
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
003E9315
0756DA1C
0C6FFF2E
134DCF34
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BA528CFF
580031BF
8C1B58C0
56323DD4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
161A1354
23000DFF
14061C53
10140D32
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A32EC3F
0836FF2D
0042F221
1435E01E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0DEB4504
11FF420E
0EB71E0B
00890B17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36FF2B35
46F90E1E
67C00011
6C8B1017
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
200E1C36
1E171742
350F05FF
17000EB1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EB322716
FF0F2511
F0003124
D5163429
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000FFF54
060EE851
0B03A23F
1402682B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>oaHF5Pko2`/;3Ol:
2PX=on?Sh`Kooooo3OlS8b<>o`/;2`ko4Q8B4_ooool>ohR8R0ko4Q8B3_le=CD=ocTi>@Gooooo3_o4
a<@>okjn_PgoPX:23OlI6AT6ooooo`ko5ADE3Oln?Sh>oemOG`goI6AT1Oooool>ofi^KPko9bLW3_l0
000=okno_`Gooooo3_nTY:@>ocHf=Pko410@3?la<C46ooooo`ko00003Oln?Sh>oi>CT`go5ADE3ooo
ool000gooooo3_lF5QH>o`/;2`go2PX:3OoShn<6ooooo`go8b<S3_l;2`/>oa8B4Q;ooooo3_n8R8P>
oa8B4Pko=CDe3Oli>CT5ooooo`koa<C43_nn_[h=oh:2PPgo6ATI1_ooool>oaDE5@go?Shn3_mOGel=
ofATI0Gooooo3_m^KVh>obLW9`ko00003Ono_kl5ooooo`koY:BT3_lf=SH>oa0@40co<C4a1_ooool>
o`0000go?Shn3_nCTi<=oaDE5@oooooo000=ooooo`ko5QHF3_l;2`/=o`X:2Pgohn?S1_ooool=ob<S
8`ko2`/;3_lB4Q8Booooo`koR8R83_lB4Q8>ocDe=@go>CTi1Oooool>olC4a0ko_[jn3On2PX8=oaTI
6@Kooooo3_lE5AD=ochn?PkoGemO3OmTI6@5ooooo`koKVi^3_lW9bL>o`0000go_kno1Oooool>ojBT
Y0ko=SHf3_l@410<oc4a<@Kooooo3_l0000=ochn?PkoTi>C3OlE5AD?ooooo`003Oooool>oaHF5Pko
2`/;3Ol:2PX=on?Sh`Kooooo3OlS8b<>o`/;2`ko4Q8B4_ooool>ohR8R0ko4Q8B3_le=CD=ocTi>@Go
oooo3_o4a<@>okjn_PgoPX:23OlI6AT6ooooo`ko5ADE3Oln?Sh>oemOG`goI6AT1Oooool>ofi^KPko
9bLW3_l0000=okno_`Gooooo3_nTY:@>ocHf=Pko410@3?la<C46ooooo`ko00003Oln?Sh>oi>CT`go
5ADE3oooool000gooooo3_lF5QH>o`/;2`go2PX:3OoShn<6ooooo`go8b<S3_l;2`/>oa8B4Q;ooooo
3_n8R8P>oa8B4Pko=CDe3Oli>CT5ooooo`koa<C43_nn_[h=oh:2PPgo6ATI1_ooool>oaDE5@go?Shn
3_mOGel=ofATI0Gooooo3_m^KVh>obLW9`ko00003Ono_kl5ooooo`koY:BT3_lf=SH>oa0@40co<C4a
1_ooool>o`0000go?Shn3_nCTi<=oaDE5@oooooo000=ooooo`ko5QHF3_l;2`/=o`X:2Pgohn?S1_oo
ool=ob<S8`ko2`/;3_lB4Q8Booooo`koR8R83_lB4Q8>ocDe=@go>CTi1Oooool>olC4a0ko_[jn3On2
PX8=oaTI6@Kooooo3_lE5AD=ochn?PkoGemO3OmTI6@5ooooo`koKVi^3_lW9bL>o`0000go_kno1Ooo
ool>ojBTY0ko=SHf3_l@410<oc4a<@Kooooo3_l0000=ochn?PkoTi>C3OlE5AD?ooooo`003Oooool>
oaHF5Pko2`/;3Ol:2PX=on?Sh`Kooooo3OlS8b<>o`/;2`ko4Q8B4_ooool>ohR8R0ko4Q8B3_le=CD=
ocTi>@Gooooo3_o4a<@>okjn_PgoPX:23OlI6AT6ooooo`ko5ADE3Oln?Sh>oemOG`goI6AT1Oooool>
ofi^KPko9bLW3_l0000=okno_`Gooooo3_nTY:@>ocHf=Pko410@3?la<C46ooooo`ko00003Oln?Sh>
oi>CT`go5ADE3oooool000gooooo3_lF5QH>o`/;2`go2PX:3OoShn<6ooooo`go8b<S3_l;2`/>oa8B
4Q;ooooo3_n8R8P>oa8B4Pko=CDe3Oli>CT5ooooo`koa<C43_nn_[h=oh:2PPgo6ATI1_ooool>oaDE
5@go?Shn3_mOGel=ofATI0Gooooo3_m^KVh>obLW9`ko00003Ono_kl5ooooo`koY:BT3_lf=SH>oa0@
40co<C4a1_ooool>o`0000go?Shn3_nCTi<=oaDE5@oooooo000=ooooo`ko5QHF3_l;2`/=o`X:2Pgo
hn?S1_ooool=ob<S8`ko2`/;3_lB4Q8Booooo`koR8R83_lB4Q8>ocDe=@go>CTi1Oooool>olC4a0ko
_[jn3On2PX8=oaTI6@Kooooo3_lE5AD=ochn?PkoGemO3OmTI6@5ooooo`koKVi^3_lW9bL>o`0000go
_kno1Oooool>ojBTY0ko=SHf3_l@410<oc4a<@Kooooo3_l0000=ochn?PkoTi>C3OlE5AD?ooooo`00
3Oooool>oaHF5Pko2`/;3Ol:2PX=on?Sh`Kooooo3OlS8b<>o`/;2`ko4Q8B4_ooool>ohR8R0ko4Q8B
3_le=CD=ocTi>@Gooooo3_o4a<@>okjn_PgoPX:23OlI6AT6ooooo`ko5ADE3Oln?Sh>oemOG`goI6AT
1Oooool>ofi^KPko9bLW3_l0000=okno_`Gooooo3_nTY:@>ocHf=Pko410@3?la<C46ooooo`ko0000
3Oln?Sh>oi>CT`go5ADE3oooool000gooooo3_lF5QH>o`/;2`go2PX:3OoShn<6ooooo`go8b<S3_l;
2`/>oa8B4Q;ooooo3_n8R8P>oa8B4Pko=CDe3Oli>CT5ooooo`koa<C43_nn_[h=oh:2PPgo6ATI1_oo
ool>oaDE5@go?Shn3_mOGel=ofATI0Gooooo3_m^KVh>obLW9`ko00003Ono_kl5ooooo`koY:BT3_lf
=SH>oa0@40co<C4a1_ooool>o`0000go?Shn3_nCTi<=oaDE5@oooooo000=ooooo`ko5QHF3_l;2`/=
o`X:2Pgohn?S1_ooool=ob<S8`ko2`/;3_lB4Q8Booooo`koR8R83_lB4Q8>ocDe=@go>CTi1Oooool>
olC4a0ko_[jn3On2PX8=oaTI6@Kooooo3_lE5AD=ochn?PkoGemO3OmTI6@5ooooo`koKVi^3_lW9bL>
o`0000go_kno1Oooool>ojBTY0ko=SHf3_l@410<oc4a<@Kooooo3_l0000=ochn?PkoTi>C3OlE5AD?
ooooo`003Oooool>oaHF5Pko2`/;3Ol:2PX=on?Sh`Kooooo3OlS8b<>o`/;2`ko4Q8B4_ooool>ohR8
R0ko4Q8B3_le=CD=ocTi>@Gooooo3_o4a<@>okjn_PgoPX:23OlI6AT6ooooo`ko5ADE3Oln?Sh>oemO
G`goI6AT1Oooool>ofi^KPko9bLW3_l0000=okno_`Gooooo3_nTY:@>ocHf=Pko410@3?la<C46oooo
o`ko00003Oln?Sh>oi>CT`go5ADE3oooool000gooooo3_l>3Ph>oa0@40go1PH63OoinOT6ooooo`go
4Q8B3_l:2PX>oaPH60go=SHf1Oooool>oe5AD@ko00003_mLG5`=oeEEE@Gooooo3_oZj^X>omoOg`go
PX:23Ol00006ooooo`ko00003OmXJ6P>oeYJFPgoFEUI1Oooool>oeaLG0ko8b<S3_l410@Booooo`ko
f][J3_lf=SH>o`P820co>c/k1_ooool>o`L71`goEUIF3_oJf]X=oa`L70oooooo000=ooooo`ko3Ph>
3_l@410=o`H61PgonOWi1_ooool=oa8B4Pko2PX:3_lH61P=ocHf=PGooooo3_mADE4>o`0000koG5aL
3OmEEED5ooooo`koj^[Z3_oOgml=oh:2PPgo00001_ooool>o`0000goJ6QX3_mJFUX=oeUIF@Gooooo
3_mLG5`>ob<S8`ko10@44_ooool>om[JfPko=SHf3_l820P<oc/k>`Kooooo3_l71`L=oeIFEPkof][J
3OlL71`?ooooo`003Oooool>o`h>3Pko410@3Ol61PH=ooWin@Kooooo3OlB4Q8>o`X:2Pko61PH3Olf
=SH5ooooo`koDE5A3_l0000>oeaLG0goEEEE1Oooool>on[ZjPkogmoO3On2PX8=o`0000Kooooo3_l0
000=ofQXJ0koFUYJ3OmIFET5ooooo`koG5aL3_lS8b<>o`@411;ooooo3_oJf]X>ocHf=Pko20P83?lk
>c/6ooooo`ko1`L73OmFEUH>om[JfPgo71`L3oooool000gooooo3_l>3Ph>oa0@40go1PH63OoinOT6
ooooo`go4Q8B3_l:2PX>oaPH60go=SHf1Oooool>oe5AD@ko00003_mLG5`=oeEEE@Gooooo3_oZj^X>
omoOg`goPX:23Ol00006ooooo`ko00003OmXJ6P>oeYJFPgoFEUI1Oooool>oeaLG0ko8b<S3_l410@B
ooooo`kof][J3_lf=SH>o`P820co>c/k1_ooool>o`L71`goEUIF3_oJf]X=oa`L70oooooo000=oooo
o`ko3Ph>3_l@410=o`H61PgonOWi1_ooool=oa8B4Pko2PX:3_lH61P=ocHf=PGooooo3_mADE4>o`00
00koG5aL3OmEEED5ooooo`koj^[Z3_oOgml=oh:2PPgo00001_ooool>o`0000goJ6QX3_mJFUX=oeUI
F@Gooooo3_mLG5`>ob<S8`ko10@44_ooool>om[JfPko=SHf3_l820P<oc/k>`Kooooo3_l71`L=oeIF
EPkof][J3OlL71`?ooooo`003Oooool>o`h>3Pko410@3Ol61PH=ooWin@Kooooo3OlB4Q8>o`X:2Pko
61PH3Olf=SH5ooooo`koDE5A3_l0000>oeaLG0goEEEE1Oooool>on[ZjPkogmoO3On2PX8=o`0000Ko
oooo3_l0000=ofQXJ0koFUYJ3OmIFET5ooooo`koG5aL3_lS8b<>o`@411;ooooo3_oJf]X>ocHf=Pko
20P83?lk>c/6ooooo`ko1`L73OmFEUH>om[JfPgo71`L3oooool000gooooo3_l>3Ph>oa0@40go1PH6
3OoinOT6ooooo`go4Q8B3_l:2PX>oaPH60go=SHf1Oooool>oe5AD@ko00003_mLG5`=oeEEE@Gooooo
3_oZj^X>omoOg`goPX:23Ol00006ooooo`ko00003OmXJ6P>oeYJFPgoFEUI1Oooool>oeaLG0ko8b<S
3_l410@Booooo`kof][J3_lf=SH>o`P820co>c/k1_ooool>o`L71`goEUIF3_oJf]X=oa`L70oooooo
000=ooooo`ko3Ph>3_l@410=o`H61PgonOWi1_ooool=oa8B4Pko2PX:3_lH61P=ocHf=PGooooo3_mA
DE4>o`0000koG5aL3OmEEED5ooooo`koj^[Z3_oOgml=oh:2PPgo00001_ooool>o`0000goJ6QX3_mJ
FUX=oeUIF@Gooooo3_mLG5`>ob<S8`ko10@44_ooool>om[JfPko=SHf3_l820P<oc/k>`Kooooo3_l7
1`L=oeIFEPkof][J3OlL71`?ooooo`003Oooool>o`h>3Pko410@3Ol61PH=ooWin@Kooooo3OlB4Q8>
o`X:2Pko61PH3Olf=SH5ooooo`koDE5A3_l0000>oeaLG0goEEEE1Oooool>on[ZjPkogmoO3On2PX8=
o`0000Kooooo3_l0000=ofQXJ0koFUYJ3OmIFET5ooooo`koG5aL3_lS8b<>o`@411;ooooo3_oJf]X>
ocHf=Pko20P83?lk>c/6ooooo`ko1`L73OmFEUH>om[JfPgo71`L3oooool000gooooo3_l>3Ph>oa0@
40go1PH63OoinOT6ooooo`go4Q8B3_l:2PX>oaPH60go=SHf1Oooool>oe5AD@ko00003_mLG5`=oeEE
E@Gooooo3_oZj^X>omoOg`goPX:23Ol00006ooooo`ko00003OmXJ6P>oeYJFPgoFEUI1Oooool>oeaL
G0ko8b<S3_l410@Booooo`kof][J3_lf=SH>o`P820co>c/k1_ooool>o`L71`goEUIF3_oJf]X=oa`L
70oooooo000=ooooo`ko3Ph>3_l@410=o`H61PgonOWi1_ooool=oa8B4Pko2PX:3_lH61P=ocHf=PGo
oooo3_mADE4>o`0000koG5aL3OmEEED5ooooo`koj^[Z3_oOgml=oh:2PPgo00001_ooool>o`0000go
J6QX3_mJFUX=oeUIF@Gooooo3_mLG5`>ob<S8`ko10@44_ooool>om[JfPko=SHf3_l820P<oc/k>`Ko
oooo3_l71`L=oeIFEPkof][J3OlL71`?ooooo`003Oooool>o`h>3Pko410@3Ol61PH=ooWin@Kooooo
3OlB4Q8>o`X:2Pko61PH3Olf=SH5ooooo`koDE5A3_l0000>oeaLG0goEEEE1Oooool>on[ZjPkogmoO
3On2PX8=o`0000Kooooo3_l0000=ofQXJ0koFUYJ3OmIFET5ooooo`koG5aL3_lS8b<>o`@411;ooooo
3_oJf]X>ocHf=Pko20P83?lk>c/6ooooo`ko1`L73OmFEUH>om[JfPgo71`L3oooool000gooooo3_l>
3Ph>oa0@40go1PH63OoinOT6ooooo`go4Q8B3_l:2PX>oaPH60go=SHf1Oooool>oe5AD@ko00003_mL
G5`=oeEEE@Gooooo3_oZj^X>omoOg`goPX:23Ol00006ooooo`ko00003OmXJ6P>oeYJFPgoFEUI1Ooo
ool>oeaLG0ko8b<S3_l410@Booooo`kof][J3_lf=SH>o`P820co>c/k1_ooool>o`L71`goEUIF3_oJ
f]X=oa`L70oooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>
obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>
odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>
o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG
5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46oooo
o`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<3
0`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?o
oooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`go
Ph>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?o
oooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=
3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo
3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L
3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo
000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oD
e=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Ooo
ool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_oo
ool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>
obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>
odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>
o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG
5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46oooo
o`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<3
0`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?o
oooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`go
Ph>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?o
oooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=
3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo
3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L
3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo
000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oD
e=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Ooo
ool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_oo
ool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>
obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>
odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>
o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?ooooo3Ol92@TLoaLG
5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`goPh>33OlA4A46oooo
o`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?ooooo3_la<C4>o`<3
0`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=3_l61PH=o`T92A?o
oooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo3_oTi>@>ooooo`go
Ph>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L3_lC4a<=omoOga?o
oooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo000=ooooo`ko3@d=
3_l61PH=o`T92A?ooooo3Ol92@TLoaLG5`go9RHV1Oooool>obLW9`ko2PX:3_oDe=@=og]kN`Gooooo
3_oTi>@>ooooo`goPh>33OlA4A46ooooo`ko00003OoCdm<>odQ8B0goC4a<1Oooool>od10@0ko71`L
3_lC4a<=omoOga?ooooo3_la<C4>o`<30`co>c/k1_ooool>o``<30goKfm_3_ooool=obh^;Poooooo
000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP
820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX
:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_oo
ool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=
o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=
og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5
ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=oooo
o`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A
4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9B
DPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C
4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko
00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go
3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko
^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=
3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo
3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo
3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=
3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=
3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_oo
ool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK
6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=
o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45
ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>
oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=
oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM
7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@
40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`00
00co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000go
inOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko
/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko
1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oo
oooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo
3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo
3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D51
1_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_oo
ool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?
cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnS
Xj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=
ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>3Pko00003_l=3@d=oadM7@Gooooo3_lP820>
oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=
oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5ooooo`ko^[Zj3_lK6a/>o`0000co@D511_ooool>
oa<C4`goCDe=3_o?cll=oc@d=0oooooo000=ooooo`ko3@d=3_l410@=o`0000goinOW1_ooool=o`h>
3Pko00003_l=3@d=oadM7@Gooooo3_lP820>oa4A4@kooooo3On1PH45ooooo`ko/k>c3_o?cll=og1`
L0go3@d=1_ooool>oa0@40gooooo3_lX:2P=oe9BDPGooooo3_le=CD>oaLG5`ko1PH63OnSXj<5oooo
o`ko^[Zj3_lK6a/>o`0000co@D511_ooool>oa<C4`goCDe=3_o?cll=oc@d=0oooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo000=ooooo`ko^[Zj3_mBDU8=ohb<S1?ooooo3OlF5QH>oaXJ6Pko4a<C3OmDE5@5ooooo`ko6QXJ
3_lb<S8>onc/k0go?clo1Oooool>o`d=3@kojn_[3Om5ADD=o`@410Kooooo3_lf=SH=ooooo`ko:b/[
3Ole=CD5ooooo`ko820P3_l>3Ph>oa`L70go=SHf1Oooool>on_[j`ko<S8b3_lW9bL<oaHF5PKooooo
3_l0000=o`l?3`kooooo3OmDE5@?ooooo`003Oooool>okZj^PkoDU9B3On<S8`Cooooo`go5QHF3_lJ
6QX>oa<C4`goE5AD1Oooool>oaXJ6Pko<S8b3_o/k>`=oclo?`Gooooo3_l=3@d>on_[j`goADE53Ol4
10@6ooooo`ko=SHf3Oooool>ob/[:`go=CDe1Oooool>ob0P80ko3Ph>3_lL71`=ocHf=PGooooo3_o[
jn/>oc8b<Pko9bLW3?lF5QH6ooooo`ko00003Ol?3`l>ooooo`goE5AD3oooool000gooooo3_nj^[X>
oe9BDPgoS8b<4oooool=oaHF5Pko6QXJ3_lC4a<=oeADE0Gooooo3_lJ6QX>oc8b<Pkok>c/3Olo?cl5
ooooo`ko3@d=3_o[jn/=odE5A@go10@41_ooool>ocHf=Pgooooo3_l[:b/=ocDe=@Gooooo3_lP820>
o`h>3Pko71`L3Olf=SH5ooooo`kojn_[3_lb<S8>obLW9`co5QHF1_ooool>o`0000go3`l?3_ooool=
oeADE0oooooo000=ooooo`ko^[Zj3_mBDU8=ohb<S1?ooooo3OlF5QH>oaXJ6Pko4a<C3OmDE5@5oooo
o`ko6QXJ3_lb<S8>onc/k0go?clo1Oooool>o`d=3@kojn_[3Om5ADD=o`@410Kooooo3_lf=SH=oooo
o`ko:b/[3Ole=CD5ooooo`ko820P3_l>3Ph>oa`L70go=SHf1Oooool>on_[j`ko<S8b3_lW9bL<oaHF
5PKooooo3_l0000=o`l?3`kooooo3OmDE5@?ooooo`003Oooool>okZj^PkoDU9B3On<S8`Cooooo`go
5QHF3_lJ6QX>oa<C4`goE5AD1Oooool>oaXJ6Pko<S8b3_o/k>`=oclo?`Gooooo3_l=3@d>on_[j`go
ADE53Ol410@6ooooo`ko=SHf3Oooool>ob/[:`go=CDe1Oooool>ob0P80ko3Ph>3_lL71`=ocHf=PGo
oooo3_o[jn/>oc8b<Pko9bLW3?lF5QH6ooooo`ko00003Ol?3`l>ooooo`goE5AD3oooool000gooooo
3_nj^[X>oe9BDPgoS8b<4oooool=oaHF5Pko6QXJ3_lC4a<=oeADE0Gooooo3_lJ6QX>oc8b<Pkok>c/
3Olo?cl5ooooo`ko3@d=3_o[jn/=odE5A@go10@41_ooool>ocHf=Pgooooo3_l[:b/=ocDe=@Gooooo
3_lP820>o`h>3Pko71`L3Olf=SH5ooooo`kojn_[3_lb<S8>obLW9`co5QHF1_ooool>o`0000go3`l?
3_ooool=oeADE0oooooo000=ooooo`ko^[Zj3_mBDU8=ohb<S1?ooooo3OlF5QH>oaXJ6Pko4a<C3OmD
E5@5ooooo`ko6QXJ3_lb<S8>onc/k0go?clo1Oooool>o`d=3@kojn_[3Om5ADD=o`@410Kooooo3_lf
=SH=ooooo`ko:b/[3Ole=CD5ooooo`ko820P3_l>3Ph>oa`L70go=SHf1Oooool>on_[j`ko<S8b3_lW
9bL<oaHF5PKooooo3_l0000=o`l?3`kooooo3OmDE5@?ooooo`003Oooool>okZj^PkoDU9B3On<S8`C
ooooo`go5QHF3_lJ6QX>oa<C4`goE5AD1Oooool>oaXJ6Pko<S8b3_o/k>`=oclo?`Gooooo3_l=3@d>
on_[j`goADE53Ol410@6ooooo`ko=SHf3Oooool>ob/[:`go=CDe1Oooool>ob0P80ko3Ph>3_lL71`=
ocHf=PGooooo3_o[jn/>oc8b<Pko9bLW3?lF5QH6ooooo`ko00003Ol?3`l>ooooo`goE5AD3oooool0
00gooooo3_nj^[X>oe9BDPgoS8b<4oooool=oaHF5Pko6QXJ3_lC4a<=oeADE0Gooooo3_lJ6QX>oc8b
<Pkok>c/3Olo?cl5ooooo`ko3@d=3_o[jn/=odE5A@go10@41_ooool>ocHf=Pgooooo3_l[:b/=ocDe
=@Gooooo3_lP820>o`h>3Pko71`L3Olf=SH5ooooo`kojn_[3_lb<S8>obLW9`co5QHF1_ooool>o`00
00go3`l?3_ooool=oeADE0oooooo000=ooooo`ko^[Zj3_mBDU8=ohb<S1?ooooo3OlF5QH>oaXJ6Pko
4a<C3OmDE5@5ooooo`ko6QXJ3_lb<S8>onc/k0go?clo1Oooool>o`d=3@kojn_[3Om5ADD=o`@410Ko
oooo3_lf=SH=ooooo`ko:b/[3Ole=CD5ooooo`ko820P3_l>3Ph>oa`L70go=SHf1Oooool>on_[j`ko
<S8b3_lW9bL<oaHF5PKooooo3_l0000=o`l?3`kooooo3OmDE5@?ooooo`003Oooool>okZj^PkoDU9B
3On<S8`Cooooo`go5QHF3_lJ6QX>oa<C4`goE5AD1Oooool>oaXJ6Pko<S8b3_o/k>`=oclo?`Gooooo
3_l=3@d>on_[j`goADE53Ol410@6ooooo`ko=SHf3Oooool>ob/[:`go=CDe1Oooool>ob0P80ko3Ph>
3_lL71`=ocHf=PGooooo3_o[jn/>oc8b<Pko9bLW3?lF5QH6ooooo`ko00003Ol?3`l>ooooo`goE5AD
3oooool000gooooo3_nj^[X>oe9BDPgoS8b<4oooool=oaHF5Pko6QXJ3_lC4a<=oeADE0Gooooo3_lJ
6QX>oc8b<Pkok>c/3Olo?cl5ooooo`ko3@d=3_o[jn/=odE5A@go10@41_ooool>ocHf=Pgooooo3_l[
:b/=ocDe=@Gooooo3_lP820>o`h>3Pko71`L3Olf=SH5ooooo`kojn_[3_lb<S8>obLW9`co5QHF1_oo
ool>o`0000go3`l?3_ooool=oeADE0oooooo000=ooooo`ko^[Zj3_mBDU8=ohb<S1?ooooo3OlF5QH>
oaXJ6Pko4a<C3OmDE5@5ooooo`ko6QXJ3_lb<S8>onc/k0go?clo1Oooool>o`d=3@kojn_[3Om5ADD=
o`@410Kooooo3_lf=SH=ooooo`ko:b/[3Ole=CD5ooooo`ko820P3_l>3Ph>oa`L70go=SHf1Oooool>
on_[j`ko<S8b3_lW9bL<oaHF5PKooooo3_l0000=o`l?3`kooooo3OmDE5@?ooooo`003Oooool>okZj
^PkoDU9B3On<S8`Cooooo`go5QHF3_lJ6QX>oa<C4`goE5AD1Oooool>oaXJ6Pko<S8b3_o/k>`=oclo
?`Gooooo3_l=3@d>on_[j`goADE53Ol410@6ooooo`ko=SHf3Oooool>ob/[:`go=CDe1Oooool>ob0P
80ko3Ph>3_lL71`=ocHf=PGooooo3_o[jn/>oc8b<Pko9bLW3?lF5QH6ooooo`ko00003Ol?3`l>oooo
o`goE5AD3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;o
oooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgo
nOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko
1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S
3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>
1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU
3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono
_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_oo
ool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924ooo
ool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>
o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5
ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhL
oaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool0
00gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf
=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN
7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSX
j0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;o
oooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgo
nOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko
1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S
3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>
1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU
3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono
_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_oo
ool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924ooo
ool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>
o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5
ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhL
oaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool0
00gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf
=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN
7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSX
j0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S3_l0000>o`d=3A;o
oooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>1_ooool>odI6APgo
nOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU3?lA4A46ooooo`ko
1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono_kl6ooooo`go8b<S
3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_ooool=od92@Pgo3Ph>
1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924oooool>o`l?3`ko9BDU
3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_mHF5P>o`0000go<C4a3Ono
_kl6ooooo`go8b<S3_l0000>o`d=3A;ooooo3_l820P>ocHf=Pkooooo3Ol];Bd5ooooo`ko4A4A3_oo
ool=od92@Pgo3Ph>1_ooool>odI6APgonOWi3_l>3Ph=oahN7PGooooo3_lN7QhLoaLG5`go@T924ooo
ool>o`l?3`ko9BDU3?lA4A46ooooo`ko1PH63Ol>3Ph>onSXj0goDE5A3oooool000gooooo3_n<S8`>
oa/K6`goF5QH3Oo0`<06ooooo`go51@D3_l61PH>oa`L70goDe=C1Oooool>o`0000ko@T923_obl_8=
ob4Q8@Gooooo3_l>3Ph>okNg]`go7QhN3Ol;2`/6ooooo`koIfMW3Oo0`<0>o`0000go4A4A1Oooool>
ocDe=@ko3`l?3_l51@DBooooo`kol?3`3_l0000>oc4a<@co92@T1_ooool>o`/;2`go0`<33_nRXZ8=
oclo?`oooooo000=ooooo`koS8b<3_lK6a/=oeQHF0go`<301_ooool=oa@D50ko1PH63_lL71`=oe=C
D`Gooooo3_l0000>od92@Pkol_;b3OlQ8B45ooooo`ko3Ph>3_ng]kL=oahN7Pgo2`/;1_ooool>ofMW
I`go`<303_l0000=oa4A4@Gooooo3_le=CD>o`l?3`ko1@D54_ooool>oo3`l0ko00003_la<C4<ob@T
90Kooooo3_l;2`/=o`<30`koXZ:R3Olo?cl?ooooo`003Oooool>ohb<S0ko6a/K3OmHF5P=ol30`0Ko
oooo3OlD51@>o`H61Pko71`L3OmCDe<5ooooo`ko00003_m2@T8>oo;blPgo8B4Q1Oooool>o`h>3Pko
]kNg3OlN7Qh=o`/;2`Kooooo3_mWIfL=ol30`0ko00003OlA4A45ooooo`ko=CDe3_l?3`l>o`D51A;o
oooo3_o`l?0>o`0000ko<C4a3?lT92@6ooooo`ko2`/;3Ol30`<>oj:RXPgo?clo3oooool000gooooo
3_n<S8`>oa/K6`goF5QH3Oo0`<06ooooo`go51@D3_l61PH>oa`L70goDe=C1Oooool>o`0000ko@T92
3_obl_8=ob4Q8@Gooooo3_l>3Ph>okNg]`go7QhN3Ol;2`/6ooooo`koIfMW3Oo0`<0>o`0000go4A4A
1Oooool>ocDe=@ko3`l?3_l51@DBooooo`kol?3`3_l0000>oc4a<@co92@T1_ooool>o`/;2`go0`<3
3_nRXZ8=oclo?`oooooo000=ooooo`koS8b<3_lK6a/=oeQHF0go`<301_ooool=oa@D50ko1PH63_lL
71`=oe=CD`Gooooo3_l0000>od92@Pkol_;b3OlQ8B45ooooo`ko3Ph>3_ng]kL=oahN7Pgo2`/;1_oo
ool>ofMWI`go`<303_l0000=oa4A4@Gooooo3_le=CD>o`l?3`ko1@D54_ooool>oo3`l0ko00003_la
<C4<ob@T90Kooooo3_l;2`/=o`<30`koXZ:R3Olo?cl?ooooo`003Oooool>ohb<S0ko6a/K3OmHF5P=
ol30`0Kooooo3OlD51@>o`H61Pko71`L3OmCDe<5ooooo`ko00003_m2@T8>oo;blPgo8B4Q1Oooool>
o`h>3Pko]kNg3OlN7Qh=o`/;2`Kooooo3_mWIfL=ol30`0ko00003OlA4A45ooooo`ko=CDe3_l?3`l>
o`D51A;ooooo3_o`l?0>o`0000ko<C4a3?lT92@6ooooo`ko2`/;3Ol30`<>oj:RXPgo?clo3oooool0
00gooooo3_n<S8`>oa/K6`goF5QH3Oo0`<06ooooo`go51@D3_l61PH>oa`L70goDe=C1Oooool>o`00
00ko@T923_obl_8=ob4Q8@Gooooo3_l>3Ph>okNg]`go7QhN3Ol;2`/6ooooo`koIfMW3Oo0`<0>o`00
00go4A4A1Oooool>ocDe=@ko3`l?3_l51@DBooooo`kol?3`3_l0000>oc4a<@co92@T1_ooool>o`/;
2`go0`<33_nRXZ8=oclo?`oooooo000=ooooo`koS8b<3_lK6a/=oeQHF0go`<301_ooool=oa@D50ko
1PH63_lL71`=oe=CD`Gooooo3_l0000>od92@Pkol_;b3OlQ8B45ooooo`ko3Ph>3_ng]kL=oahN7Pgo
2`/;1_ooool>ofMWI`go`<303_l0000=oa4A4@Gooooo3_le=CD>o`l?3`ko1@D54_ooool>oo3`l0ko
00003_la<C4<ob@T90Kooooo3_l;2`/=o`<30`koXZ:R3Olo?cl?ooooo`003Oooool>ohb<S0ko6a/K
3OmHF5P=ol30`0Kooooo3OlD51@>o`H61Pko71`L3OmCDe<5ooooo`ko00003_m2@T8>oo;blPgo8B4Q
1Oooool>o`h>3Pko]kNg3OlN7Qh=o`/;2`Kooooo3_mWIfL=ol30`0ko00003OlA4A45ooooo`ko=CDe
3_l?3`l>o`D51A;ooooo3_o`l?0>o`0000ko<C4a3?lT92@6ooooo`ko2`/;3Ol30`<>oj:RXPgo?clo
3oooool000gooooo3_n<S8`>oa/K6`goF5QH3Oo0`<06ooooo`go51@D3_l61PH>oa`L70goDe=C1Ooo
ool>o`0000ko@T923_obl_8=ob4Q8@Gooooo3_l>3Ph>okNg]`go7QhN3Ol;2`/6ooooo`koIfMW3Oo0
`<0>o`0000go4A4A1Oooool>ocDe=@ko3`l?3_l51@DBooooo`kol?3`3_l0000>oc4a<@co92@T1_oo
ool>o`/;2`go0`<33_nRXZ8=oclo?`oooooo000=ooooo`koS8b<3_lK6a/=oeQHF0go`<301_ooool=
oa@D50ko1PH63_lL71`=oe=CD`Gooooo3_l0000>od92@Pkol_;b3OlQ8B45ooooo`ko3Ph>3_ng]kL=
oahN7Pgo2`/;1_ooool>ofMWI`go`<303_l0000=oa4A4@Gooooo3_le=CD>o`l?3`ko1@D54_ooool>
oo3`l0ko00003_la<C4<ob@T90Kooooo3_l;2`/=o`<30`koXZ:R3Olo?cl?ooooo`003Oooool>ohb<
S0ko6a/K3OmHF5P=ol30`0Kooooo3OlD51@>o`H61Pko71`L3OmCDe<5ooooo`ko00003_m2@T8>oo;b
lPgo8B4Q1Oooool>o`h>3Pko]kNg3OlN7Qh=o`/;2`Kooooo3_mWIfL=ol30`0ko00003OlA4A45oooo
o`ko=CDe3_l?3`l>o`D51A;ooooo3_o`l?0>o`0000ko<C4a3?lT92@6ooooo`ko2`/;3Ol30`<>oj:R
XPgo?clo3oooool000gooooo3_n<S8`>oa/K6`goF5QH3Oo0`<06ooooo`go51@D3_l61PH>oa`L70go
De=C1Oooool>o`0000ko@T923_obl_8=ob4Q8@Gooooo3_l>3Ph>okNg]`go7QhN3Ol;2`/6ooooo`ko
IfMW3Oo0`<0>o`0000go4A4A1Oooool>ocDe=@ko3`l?3_l51@DBooooo`kol?3`3_l0000>oc4a<@co
92@T1_ooool>o`/;2`go0`<33_nRXZ8=oclo?`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD
1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko0000
3_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>
3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo
000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD
51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@
410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_oo
ool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=
oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=
o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45
ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=oooo
o`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe
=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG
5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D
50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko
51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go
5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`ko
eMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF
3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P
3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo
3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P82
3_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=
3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_oo
ool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF
5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=
ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5
ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>
o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=
ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b
<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/
K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d
=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@go
e=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko
00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko
3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oo
oooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo
3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;
3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY
1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_oo
ool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9
RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona
/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo000=
ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>
ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=
oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45ooooo`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>
oa@D50go0P823_mXJ6P=ob/[:`oooooo000=ooooo`koEUIF3_lb<S8=ocdm?@goe=CD1_ooool=oa0@
40ko51@D3_l=3@d=oc8b<PGooooo3_lD51@>ocDe=@koh>3P3OlN7Qh5ooooo`ko00003_n9RHT=o`/;
2`go5aLG1_ooool>ofa/K0goRh^;3_l@410=oaLG5`Gooooo3_lG5aL>o`0000ko3Ph>3Ona/K45oooo
o`koeMGE3_lF5QH>oc@d=0co:BTY1_ooool>oa@D50go0P823_mXJ6P=ob/[:`oooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-0.986205, \
-0.214308, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-5.38717, -0.214308, 0.0737335, 0.0737335}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-9.77687, -0.21176, 0.0736486, 0.0736486}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-14.1937, -0.214308, 0.0737335, 0.0737335}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-18.5947, -0.214308, 0.0737335, 0.0737335}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-22.9692, -0.21176, 0.0736486, \
0.0736486}, {{371.625, 425.875}, {116.812, 62.5}} -> {-27.4012, -0.214308, \
0.0737335, 0.0737335}, {{431.312, 485.562}, {116.812, 62.5}} -> {-31.8022, \
-0.214308, 0.0737335, 0.0737335}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-0.986205, -4.61527, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-5.38717, -4.61527, 0.0737335, 0.0737335}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-9.77687, -4.60766, 0.0736486, 0.0736486}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-14.1937, -4.61527, 0.0737335, 0.0737335}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-18.5947, -4.61527, 0.0737335, \
0.0737335}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-22.9692, -4.60766, \
0.0736486, 0.0736486}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-27.4012, \
-4.61527, 0.0737335, 0.0737335}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-31.8022, -4.61527, 0.0737335, 0.0737335}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24138 
%%ImageSize: 500 120.69 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.00574713 0.119048 [
[ 0 0 0 0 ]
[ 1 .24138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24138 L
0 .24138 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00574713 0.133279 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BC8EAEA0
BDA7C4B1
94939B88
FF00FAA4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.00574713 0.253695 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9B052052
FF6C0025
DEC11D0B
4804515F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.00574713 0.374111 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B4ED7B7
5D08FF85
7A00A440
05626C74
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.00574713 0.494527 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
48C96A1F
08FFCF48
005FC962
68792013
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.00574713 0.614943 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A1207FF
1D1F0572
1205002C
1B110E2F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.00574713 0.735359 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0613142E
1A140230
0408001C
2F1C1EFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.00574713 0.855774 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
169B5B1F
00224C39
1D10394C
49FF571B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.00574713 0.97619 0.115216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFC70D1B
AFED5300
53CC7515
B448043B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.126163 0.133279 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D2B106E
1E17003B
997063AD
C09EB9FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.126163 0.253695 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
001F322C
4302104F
FF39014D
01482A26
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.126163 0.374111 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00160211
0F0C2D9D
1A0349FF
261B0102
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.126163 0.494527 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
362E000A
1264221B
0BFF8D4D
2F371818
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.126163 0.614943 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
152D0B00
1326020E
121F1414
32FF323D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.126163 0.735359 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
25052E2A
1C000F01
08080908
101B12FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.126163 0.855774 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E035C1A
1E00040E
2F0E0410
0817FF1A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.126163 0.97619 0.235632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5C250C00
14180012
0E180F22
FF32061F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 120.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000N2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003Oooool>okbl_0koSXj>3On^
[Zh=oj2PX0Kooooo3OnKVi/>o`D51@ko820P3OmBDU85ooooo`ko6a/K3_m>CTh>omOGe`go]kNg1Ooo
ool>odQ8B0kobLW93OmZJVX=oalO7`Kooooo3_lj>SX=oa8B4Pko1`L74_ooool>o`H61Pko4a<C3_lD
51@=obh^;PGooooo3_lF5QH>oi^KV`koFe]K3?lO7alDooooo`goalO73_l=3@d=oa/K6`oooooo000=
ooooo`ko_;bl3_n>SXh=ojj^[PgoX:2P1_ooool=oi^KV`ko1@D53_lP820=oe9BDPGooooo3_lK6a/>
odi>CPkoemOG3Ong]kL5ooooo`koB4Q83_o9bLT=ofYZJPgo7alO1_ooool>ocXj>Pgo4Q8B3_l71`LB
ooooo`ko1PH63_lC4a<>oa@D50go;Rh^1Oooool>oaHF5PkoVi^K3_mKFe/<oalO7aCooooo3Oo7alL>
o`d=3@go6a/K3oooool000gooooo3_nl_;`>ohj>SPgo[Zj^3OnPX:06ooooo`goVi^K3_l51@D>ob0P
80goDU9B1Oooool>oa/K6`koCTi>3_oGemL=okNg]`Gooooo3_m8B4P>olW9b@goJVYZ3OlO7al6oooo
o`ko>SXj3OlB4Q8>o`L71a;ooooo3_l61PH>oa<C4`ko51@D3Ol^;Rh5ooooo`ko5QHF3_nKVi/>oe]K
F`co7alO5?ooool=olO7a`ko3@d=3OlK6a/?ooooo`003Oooool>okbl_0koSXj>3On^[Zh=oj2PX0Ko
oooo3OnKVi/>o`D51@ko820P3OmBDU85ooooo`ko6a/K3_m>CTh>omOGe`go]kNg1Oooool>odQ8B0ko
bLW93OmZJVX=oalO7`Kooooo3_lj>SX=oa8B4Pko1`L74_ooool>o`H61Pko4a<C3_lD51@=obh^;PGo
oooo3_lF5QH>oi^KV`koFe]K3?lO7alDooooo`goalO73_l=3@d=oa/K6`oooooo000=ooooo`ko_;bl
3_n>SXh=ojj^[PgoX:2P1_ooool=oi^KV`ko1@D53_lP820=oe9BDPGooooo3_lK6a/>odi>CPkoemOG
3Ong]kL5ooooo`koB4Q83_o9bLT=ofYZJPgo7alO1_ooool>ocXj>Pgo4Q8B3_l71`LBooooo`ko1PH6
3_lC4a<>oa@D50go;Rh^1Oooool>oaHF5PkoVi^K3_mKFe/<oalO7aCooooo3Oo7alL>o`d=3@go6a/K
3oooool000gooooo3_nl_;`>ohj>SPgo[Zj^3OnPX:06ooooo`goVi^K3_l51@D>ob0P80goDU9B1Ooo
ool>oa/K6`koCTi>3_oGemL=okNg]`Gooooo3_m8B4P>olW9b@goJVYZ3OlO7al6ooooo`ko>SXj3OlB
4Q8>o`L71a;ooooo3_l61PH>oa<C4`ko51@D3Ol^;Rh5ooooo`ko5QHF3_nKVi/>oe]KF`co7alO5?oo
ool=olO7a`ko3@d=3OlK6a/?ooooo`003Oooool>okbl_0koSXj>3On^[Zh=oj2PX0Kooooo3OnKVi/>
o`D51@ko820P3OmBDU85ooooo`ko6a/K3_m>CTh>omOGe`go]kNg1Oooool>odQ8B0kobLW93OmZJVX=
oalO7`Kooooo3_lj>SX=oa8B4Pko1`L74_ooool>o`H61Pko4a<C3_lD51@=obh^;PGooooo3_lF5QH>
oi^KV`koFe]K3?lO7alDooooo`goalO73_l=3@d=oa/K6`oooooo000=ooooo`ko_;bl3_n>SXh=ojj^
[PgoX:2P1_ooool=oi^KV`ko1@D53_lP820=oe9BDPGooooo3_lK6a/>odi>CPkoemOG3Ong]kL5oooo
o`koB4Q83_o9bLT=ofYZJPgo7alO1_ooool>ocXj>Pgo4Q8B3_l71`LBooooo`ko1PH63_lC4a<>oa@D
50go;Rh^1Oooool>oaHF5PkoVi^K3_mKFe/<oalO7aCooooo3Oo7alL>o`d=3@go6a/K3oooool000go
oooo3_nl_;`>ohj>SPgo[Zj^3OnPX:06ooooo`goVi^K3_l51@D>ob0P80goDU9B1Oooool>oa/K6`ko
CTi>3_oGemL=okNg]`Gooooo3_m8B4P>olW9b@goJVYZ3OlO7al6ooooo`ko>SXj3OlB4Q8>o`L71a;o
oooo3_l61PH>oa<C4`ko51@D3Ol^;Rh5ooooo`ko5QHF3_nKVi/>oe]KF`co7alO5?ooool=olO7a`ko
3@d=3OlK6a/?ooooo`003Oooool>okbl_0koSXj>3On^[Zh=oj2PX0Kooooo3OnKVi/>o`D51@ko820P
3OmBDU85ooooo`ko6a/K3_m>CTh>omOGe`go]kNg1Oooool>odQ8B0kobLW93OmZJVX=oalO7`Kooooo
3_lj>SX=oa8B4Pko1`L74_ooool>o`H61Pko4a<C3_lD51@=obh^;PGooooo3_lF5QH>oi^KV`koFe]K
3?lO7alDooooo`goalO73_l=3@d=oa/K6`oooooo000=ooooo`ko_;bl3_n>SXh=ojj^[PgoX:2P1_oo
ool=oi^KV`ko1@D53_lP820=oe9BDPGooooo3_lK6a/>odi>CPkoemOG3Ong]kL5ooooo`koB4Q83_o9
bLT=ofYZJPgo7alO1_ooool>ocXj>Pgo4Q8B3_l71`LBooooo`ko1PH63_lC4a<>oa@D50go;Rh^1Ooo
ool>oaHF5PkoVi^K3_mKFe/<oalO7aCooooo3Oo7alL>o`d=3@go6a/K3oooool000gooooo3_nl_;`>
ohj>SPgo[Zj^3OnPX:06ooooo`goVi^K3_l51@D>ob0P80goDU9B1Oooool>oa/K6`koCTi>3_oGemL=
okNg]`Gooooo3_m8B4P>olW9b@goJVYZ3OlO7al6ooooo`ko>SXj3OlB4Q8>o`L71a;ooooo3_l61PH>
oa<C4`ko51@D3Ol^;Rh5ooooo`ko5QHF3_nKVi/>oe]KF`co7alO5?ooool=olO7a`ko3@d=3OlK6a/?
ooooo`003Oooool>okbl_0koSXj>3On^[Zh=oj2PX0Kooooo3OnKVi/>o`D51@ko820P3OmBDU85oooo
o`ko6a/K3_m>CTh>omOGe`go]kNg1Oooool>odQ8B0kobLW93OmZJVX=oalO7`Kooooo3_lj>SX=oa8B
4Pko1`L74_ooool>o`H61Pko4a<C3_lD51@=obh^;PGooooo3_lF5QH>oi^KV`koFe]K3?lO7alDoooo
o`goalO73_l=3@d=oa/K6`oooooo000=ooooo`ko_Kfm3_nWYjL=olC4a0go/K6a4oooool>ofa/K0ko
00003OlU9BD5ooooo`koGEeM3_l820P>ooooo`goQHF51Oooool>o`P820kooooo3Oo?cll=odQ8B0Ko
oooo3_lM7Ad=oalO7`ko1@D53OmbLW85ooooo`ko6QXJ3_lD51@>o`820Pgo<30`1Oooool>o`0000ko
8R8R3_m<C4`<ocTi>@Kooooo3_n_[jl=ong]k@koDe=C3Ol0000?ooooo`003Oooool>okfm_@koYjNW
3Oo4a<@=ok6a/A?ooooo3_m/K6`>o`0000go9BDU1Oooool>oeeMG@ko20P83_ooool=ohF5Q@Gooooo
3_l820P>ooooo`goclo?3Om8B4P6ooooo`ko7AdM3OlO7al>o`D51@goLW9b1Oooool>oaXJ6Pko51@D
3_l20P8=oc0`<0Gooooo3_l0000>ob8R8PkoC4a<3?li>CT6ooooo`ko[jn_3Oo]kNd>oe=CD`go0000
3oooool000gooooo3_nm_Kd>ojNWY`goa<C43Ona/K4Cooooo`koK6a/3_l0000=obDU9@Gooooo3_mM
GEd>o`P820kooooo3On5QHD5ooooo`ko20P83_ooool=olo?c`goB4Q81_ooool>oadM7@go7alO3_l5
1@D=og9bLPGooooo3_lJ6QX>oa@D50ko0P823Ol`<305ooooo`ko00003_lR8R8>oda<C0co>CTi1_oo
ool>ojn_[`gokNg]3_mCDe<=o`0000oooooo000=ooooo`ko_Kfm3_nWYjL=olC4a0go/K6a4oooool>
ofa/K0ko00003OlU9BD5ooooo`koGEeM3_l820P>ooooo`goQHF51Oooool>o`P820kooooo3Oo?cll=
odQ8B0Kooooo3_lM7Ad=oalO7`ko1@D53OmbLW85ooooo`ko6QXJ3_lD51@>o`820Pgo<30`1Oooool>
o`0000ko8R8R3_m<C4`<ocTi>@Kooooo3_n_[jl=ong]k@koDe=C3Ol0000?ooooo`003Oooool>okfm
_@koYjNW3Oo4a<@=ok6a/A?ooooo3_m/K6`>o`0000go9BDU1Oooool>oeeMG@ko20P83_ooool=ohF5
Q@Gooooo3_l820P>ooooo`goclo?3Om8B4P6ooooo`ko7AdM3OlO7al>o`D51@goLW9b1Oooool>oaXJ
6Pko51@D3_l20P8=oc0`<0Gooooo3_l0000>ob8R8PkoC4a<3?li>CT6ooooo`ko[jn_3Oo]kNd>oe=C
D`go00003oooool000gooooo3_nm_Kd>ojNWY`goa<C43Ona/K4Cooooo`koK6a/3_l0000=obDU9@Go
oooo3_mMGEd>o`P820kooooo3On5QHD5ooooo`ko20P83_ooool=olo?c`goB4Q81_ooool>oadM7@go
7alO3_l51@D=og9bLPGooooo3_lJ6QX>oa@D50ko0P823Ol`<305ooooo`ko00003_lR8R8>oda<C0co
>CTi1_ooool>ojn_[`gokNg]3_mCDe<=o`0000oooooo000=ooooo`ko_Kfm3_nWYjL=olC4a0go/K6a
4oooool>ofa/K0ko00003OlU9BD5ooooo`koGEeM3_l820P>ooooo`goQHF51Oooool>o`P820kooooo
3Oo?cll=odQ8B0Kooooo3_lM7Ad=oalO7`ko1@D53OmbLW85ooooo`ko6QXJ3_lD51@>o`820Pgo<30`
1Oooool>o`0000ko8R8R3_m<C4`<ocTi>@Kooooo3_n_[jl=ong]k@koDe=C3Ol0000?ooooo`003Ooo
ool>okfm_@koYjNW3Oo4a<@=ok6a/A?ooooo3_m/K6`>o`0000go9BDU1Oooool>oeeMG@ko20P83_oo
ool=ohF5Q@Gooooo3_l820P>ooooo`goclo?3Om8B4P6ooooo`ko7AdM3OlO7al>o`D51@goLW9b1Ooo
ool>oaXJ6Pko51@D3_l20P8=oc0`<0Gooooo3_l0000>ob8R8PkoC4a<3?li>CT6ooooo`ko[jn_3Oo]
kNd>oe=CD`go00003oooool000gooooo3_nm_Kd>ojNWY`goa<C43Ona/K4Cooooo`koK6a/3_l0000=
obDU9@Gooooo3_mMGEd>o`P820kooooo3On5QHD5ooooo`ko20P83_ooool=olo?c`goB4Q81_ooool>
oadM7@go7alO3_l51@D=og9bLPGooooo3_lJ6QX>oa@D50ko0P823Ol`<305ooooo`ko00003_lR8R8>
oda<C0co>CTi1_ooool>ojn_[`gokNg]3_mCDe<=o`0000oooooo000=ooooo`ko_Kfm3_nWYjL=olC4
a0go/K6a4oooool>ofa/K0ko00003OlU9BD5ooooo`koGEeM3_l820P>ooooo`goQHF51Oooool>o`P8
20kooooo3Oo?cll=odQ8B0Kooooo3_lM7Ad=oalO7`ko1@D53OmbLW85ooooo`ko6QXJ3_lD51@>o`82
0Pgo<30`1Oooool>o`0000ko8R8R3_m<C4`<ocTi>@Kooooo3_n_[jl=ong]k@koDe=C3Ol0000?oooo
o`003Oooool>okfm_@koYjNW3Oo4a<@=ok6a/A?ooooo3_m/K6`>o`0000go9BDU1Oooool>oeeMG@ko
20P83_ooool=ohF5Q@Gooooo3_l820P>ooooo`goclo?3Om8B4P6ooooo`ko7AdM3OlO7al>o`D51@go
LW9b1Oooool>oaXJ6Pko51@D3_l20P8=oc0`<0Gooooo3_l0000>ob8R8PkoC4a<3?li>CT6ooooo`ko
[jn_3Oo]kNd>oe=CD`go00003oooool000gooooo3_nm_Kd>ojNWY`goa<C43Ona/K4Cooooo`koK6a/
3_l0000=obDU9@Gooooo3_mMGEd>o`P820kooooo3On5QHD5ooooo`ko20P83_ooool=olo?c`goB4Q8
1_ooool>oadM7@go7alO3_l51@D=og9bLPGooooo3_lJ6QX>oa@D50ko0P823Ol`<305ooooo`ko0000
3_lR8R8>oda<C0co>CTi1_ooool>ojn_[`gokNg]3_mCDe<=o`0000oooooo000=ooooo`ko_Kfm3_nW
YjL=olC4a0go/K6a4oooool>ofa/K0ko00003OlU9BD5ooooo`koGEeM3_l820P>ooooo`goQHF51Ooo
ool>o`P820kooooo3Oo?cll=odQ8B0Kooooo3_lM7Ad=oalO7`ko1@D53OmbLW85ooooo`ko6QXJ3_lD
51@>o`820Pgo<30`1Oooool>o`0000ko8R8R3_m<C4`<ocTi>@Kooooo3_n_[jl=ong]k@koDe=C3Ol0
000?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5
ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=
o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<
oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8
R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`00
00koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`00
00go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?oooo
o`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`ko
NWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko
00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Ko
oooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo
3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO
3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L
1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Ooo
ool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0
000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/
;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mC
De<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>
ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=
of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>
oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBD
U0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBT
Y0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5oooo
o`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<
c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko
7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKo
oooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko
410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C
3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@410
1Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@4
3_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe
3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;
2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB
4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li
>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=
ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>
o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>
o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?
ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5oooo
o`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D5
1@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<
C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`003Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Ko
oooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj3_l0000>ojBTY0go@4101Oooool>o`0000ko
GemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko00003Ol/;2`5ooooo`ko10@43_l820P>o`0000go
71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`00
3Oooool>oiBDU0koTi>C3OnKVi/=ohR8R0Kooooo3OoNg]h>ol71`@ko7AdM3Ol;2`/5ooooo`koNWYj
3_l0000>ojBTY0go@4101Oooool>o`0000koGemO3Oo9bLT=of9RHPKooooo3_lB4Q8=o`D51@ko0000
3Ol/;2`5ooooo`ko10@43_l820P>o`0000go71`L1Oooool>oadM7@ko410@3_li>CT<oda<C0Kooooo
3_mCDe<=olc<c0koMGEe3OlE5AD?ooooo`006oooool>o`0000gon_[j3OnTY:@6ooooo`goB4Q83_l4
10@>oe5AD@goGemO1Oooool>o`D51@koHV9R3_m/K6`=ogAdM0Gooooo3_mXJ6P>ogUiN@go820P3OlC
4a<6ooooo`ko6a/K3OlA4A4>o`h>3Pgo;bl_1Oooool>obl_;`ko71`L3_lN7QhBooooo`koBDU93_oo
ool>oeMGE`co6a/K1_ooool>okBd]0goB4Q83_l410@=oc/k>`oooooo000Kooooo`ko00003Oojn_X=
ojBTY0Kooooo3Om8B4P>o`@410koDE5A3OmOGel5ooooo`ko1@D53_mRHV8>ofa/K0goM7Ad1Oooool>
ofQXJ0koNGUi3OlP820=oa<C4`Kooooo3_lK6a/=oa4A4@ko3Ph>3Ol_;bl5ooooo`ko;bl_3_lL71`>
oahN7Q;ooooo3_m9BDT>ooooo`koEeMG3?lK6a/6ooooo`ko];Bd3Om8B4P>o`@410go>c/k3oooool0
01_ooooo3_l0000=oo[jnPgoY:BT1_ooool=odQ8B0ko10@43_mADE4=oemOG`Gooooo3_l51@D>of9R
HPkoK6a/3OmdM7@5ooooo`koJ6QX3_miNGT=ob0P80go4a<C1_ooool>oa/K6`go4A4A3_l>3Ph=obl_
;`Gooooo3_l_;bl>oa`L70ko7QhN4_ooool>odU9B@kooooo3_mGEeL<oa/K6`Kooooo3_nd];@=odQ8
B0ko10@43Olk>c/?ooooo`006oooool>o`0000gon_[j3OnTY:@6ooooo`goB4Q83_l410@>oe5AD@go
GemO1Oooool>o`D51@koHV9R3_m/K6`=ogAdM0Gooooo3_mXJ6P>ogUiN@go820P3OlC4a<6ooooo`ko
6a/K3OlA4A4>o`h>3Pgo;bl_1Oooool>obl_;`ko71`L3_lN7QhBooooo`koBDU93_ooool>oeMGE`co
6a/K1_ooool>okBd]0goB4Q83_l410@=oc/k>`oooooo000Kooooo`ko00003Oojn_X=ojBTY0Kooooo
3Om8B4P>o`@410koDE5A3OmOGel5ooooo`ko1@D53_mRHV8>ofa/K0goM7Ad1Oooool>ofQXJ0koNGUi
3OlP820=oa<C4`Kooooo3_lK6a/=oa4A4@ko3Ph>3Ol_;bl5ooooo`ko;bl_3_lL71`>oahN7Q;ooooo
3_m9BDT>ooooo`koEeMG3?lK6a/6ooooo`ko];Bd3Om8B4P>o`@410go>c/k3oooool001_ooooo3_l0
000=oo[jnPgoY:BT1_ooool=odQ8B0ko10@43_mADE4=oemOG`Gooooo3_l51@D>of9RHPkoK6a/3Omd
M7@5ooooo`koJ6QX3_miNGT=ob0P80go4a<C1_ooool>oa/K6`go4A4A3_l>3Ph=obl_;`Gooooo3_l_
;bl>oa`L70ko7QhN4_ooool>odU9B@kooooo3_mGEeL<oa/K6`Kooooo3_nd];@=odQ8B0ko10@43Olk
>c/?ooooo`006oooool>o`0000gon_[j3OnTY:@6ooooo`goB4Q83_l410@>oe5AD@goGemO1Oooool>
o`D51@koHV9R3_m/K6`=ogAdM0Gooooo3_mXJ6P>ogUiN@go820P3OlC4a<6ooooo`ko6a/K3OlA4A4>
o`h>3Pgo;bl_1Oooool>obl_;`ko71`L3_lN7QhBooooo`koBDU93_ooool>oeMGE`co6a/K1_ooool>
okBd]0goB4Q83_l410@=oc/k>`oooooo000Kooooo`ko00003Oojn_X=ojBTY0Kooooo3Om8B4P>o`@4
10koDE5A3OmOGel5ooooo`ko1@D53_mRHV8>ofa/K0goM7Ad1Oooool>ofQXJ0koNGUi3OlP820=oa<C
4`Kooooo3_lK6a/=oa4A4@ko3Ph>3Ol_;bl5ooooo`ko;bl_3_lL71`>oahN7Q;ooooo3_m9BDT>oooo
o`koEeMG3?lK6a/6ooooo`ko];Bd3Om8B4P>o`@410go>c/k3oooool001_ooooo3_l0000=oo[jnPgo
Y:BT1_ooool=odQ8B0ko10@43_mADE4=oemOG`Gooooo3_l51@D>of9RHPkoK6a/3OmdM7@5ooooo`ko
J6QX3_miNGT=ob0P80go4a<C1_ooool>oa/K6`go4A4A3_l>3Ph=obl_;`Gooooo3_l_;bl>oa`L70ko
7QhN4_ooool>odU9B@kooooo3_mGEeL<oa/K6`Kooooo3_nd];@=odQ8B0ko10@43Olk>c/?ooooo`00
6oooool>o`0000gon_[j3OnTY:@6ooooo`goB4Q83_l410@>oe5AD@goGemO1Oooool>o`D51@koHV9R
3_m/K6`=ogAdM0Gooooo3_mXJ6P>ogUiN@go820P3OlC4a<6ooooo`ko6a/K3OlA4A4>o`h>3Pgo;bl_
1Oooool>obl_;`ko71`L3_lN7QhBooooo`koBDU93_ooool>oeMGE`co6a/K1_ooool>okBd]0goB4Q8
3_l410@=oc/k>`oooooo000Kooooo`ko00003Oojn_X=ojBTY0Kooooo3Om8B4P>o`@410koDE5A3OmO
Gel5ooooo`ko1@D53_mRHV8>ofa/K0goM7Ad1Oooool>ofQXJ0koNGUi3OlP820=oa<C4`Kooooo3_lK
6a/=oa4A4@ko3Ph>3Ol_;bl5ooooo`ko;bl_3_lL71`>oahN7Q;ooooo3_m9BDT>ooooo`koEeMG3?lK
6a/6ooooo`ko];Bd3Om8B4P>o`@410go>c/k3oooool001_ooooo3_l0000=oo[jnPgoY:BT1_ooool=
odQ8B0ko10@43_mADE4=oemOG`Gooooo3_l51@D>of9RHPkoK6a/3OmdM7@5ooooo`koJ6QX3_miNGT=
ob0P80go4a<C1_ooool>oa/K6`go4A4A3_l>3Ph=obl_;`Gooooo3_l_;bl>oa`L70ko7QhN4_ooool>
odU9B@kooooo3_mGEeL<oa/K6`Kooooo3_nd];@=odQ8B0ko10@43Olk>c/?ooooo`006oooool>o`00
00gon_[j3OnTY:@6ooooo`goB4Q83_l410@>oe5AD@goGemO1Oooool>o`D51@koHV9R3_m/K6`=ogAd
M0Gooooo3_mXJ6P>ogUiN@go820P3OlC4a<6ooooo`ko6a/K3OlA4A4>o`h>3Pgo;bl_1Oooool>obl_
;`ko71`L3_lN7QhBooooo`koBDU93_ooool>oeMGE`co6a/K1_ooool>okBd]0goB4Q83_l410@=oc/k
>`oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO
3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:
1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>
3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[
:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA
4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU
9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<
30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=
ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>
oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>
oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@
40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45oooo
o`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D5
1@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`00
00oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Go
oooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go
;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co
6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^
1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf
3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^
3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo
000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0
000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;
2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_oo
ool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=
o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=
o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5
ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=oooo
o`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF
5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`00
00Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaL
G0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko
7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go
2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko
3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM
3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P82
3OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo
3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU
3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb
<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_oo
ool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l3
0`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7AdM3_l[:b/=
oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45
ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>
o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaLG0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=
o`0000oooooo000=ooooo`ko7AdM3_l[:b/=oa0@40goKVi^1_ooool=o`0000ko7alO3_lb<S8=ob`/
;0Gooooo3_l0000>oaHF5Pko0P823OlA4A45ooooo`ko=SHf3_l^;Rh=o`0000go2PX:1_ooool>oaDE
5@go;Bd]3_l;2`/=o`0000Gooooo3_lU9BD>o`D51@ko;Rh^3OlZ:RX5ooooo`ko3Ph>3_l30`<>oeaL
G0co6QXJ1_ooool>oeaLG0go9BDU3_l<30`=o`0000oooooo000=ooooo`ko7QhN3_lG5aL=o`0000go
>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko
4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko
3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poo
oooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo
3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV
3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>
1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_oo
ool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mT
I6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol1
0@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=
ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>
o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=
o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>
oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3
@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R
8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45oooo
o`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko
7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko
;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGo
oooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go
61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P82
3_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K
1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN
3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG
5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnM
WId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL
71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0
000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=
odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>
oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>
o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`00
00go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5oooo
o`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`00
00ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B
4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Go
oooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go
9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co
3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k
1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B
3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l20P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?
3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_ooool>oa@D50go61PH3_l0000=oa8B4Poooooo
000=ooooo`ko7QhN3_lG5aL=o`0000go>c/k1_ooool=od=3@`ko0P823_l@410=odm?C`Gooooo3_l?
3`l>o``<30ko;Bd]3OnMWId5ooooo`ko4Q8B3_mTI6@=ob8R8Pgo6a/K1_ooool>oa<C4`go9RHV3_l2
0P8=o`h>3PGooooo3_lL71`>o`0000ko3`l?3Ol10@45ooooo`ko7QhN3_l0000>o`@410co3Ph>1_oo
ool>oa@D50go61PH3_l0000=oa8B4Poooooo000=ooooo`koVIVI3_m`L70=of=SH`go[Jf]4oooool>
ocTi>@ko0@413Om=CDd5ooooo`ko6QXJ3_l30`<>odU9BA;ooooo3_l;2`/>ooooo`goSHf=3Om=CDd6
ooooo`ko4Q8B3OlO7alKoa@D50Gooooo7?l820P>o`T92@go20P81Oooool>obl_;`ko3Ph>3_l410@<
oa0@40Kooooo3_l>3Ph=oaPH60ko3`l?3OlR8R8?ooooo`003Oooool>oiVIV@koL71`3OmSHf<=ojf]
[A?ooooo3_li>CT>o`410@goCDe=1Oooool>oaXJ6Pko0`<33_m9BDTBooooo`ko2`/;3_ooool=ohf=
S@goCDe=1_ooool>oa8B4Pgo7alO6olD51@5oooooaco20P83_l92@T=o`P820Gooooo3_l_;bl>o`h>
3Pko10@43?l@4106ooooo`ko3Ph>3OlH61P>o`l?3`go8R8R3oooool000gooooo3_nIVIT>og1`L0go
Hf=S3On][JdCooooo`ko>CTi3_l10@4=ode=C@Gooooo3_lJ6QX>o`<30`koBDU94_ooool>o`/;2`ko
oooo3On=SHd=ode=C@Kooooo3_lB4Q8=oalO7a_o51@D1OoooolLo`P820ko2@T93Ol820P5ooooo`ko
;bl_3_l>3Ph>o`@410co410@1_ooool>o`h>3Pgo61PH3_l?3`l=ob8R8Poooooo000=ooooo`koVIVI
3_m`L70=of=SH`go[Jf]4oooool>ocTi>@ko0@413Om=CDd5ooooo`ko6QXJ3_l30`<>odU9BA;ooooo
3_l;2`/>ooooo`goSHf=3Om=CDd6ooooo`ko4Q8B3OlO7alKoa@D50Gooooo7?l820P>o`T92@go20P8
1Oooool>obl_;`ko3Ph>3_l410@<oa0@40Kooooo3_l>3Ph=oaPH60ko3`l?3OlR8R8?ooooo`003Ooo
ool>oiVIV@koL71`3OmSHf<=ojf][A?ooooo3_li>CT>o`410@goCDe=1Oooool>oaXJ6Pko0`<33_m9
BDTBooooo`ko2`/;3_ooool=ohf=S@goCDe=1_ooool>oa8B4Pgo7alO6olD51@5oooooaco20P83_l9
2@T=o`P820Gooooo3_l_;bl>o`h>3Pko10@43?l@4106ooooo`ko3Ph>3OlH61P>o`l?3`go8R8R3ooo
ool000gooooo3_nIVIT>og1`L0goHf=S3On][JdCooooo`ko>CTi3_l10@4=ode=C@Gooooo3_lJ6QX>
o`<30`koBDU94_ooool>o`/;2`kooooo3On=SHd=ode=C@Kooooo3_lB4Q8=oalO7a_o51@D1OoooolL
o`P820ko2@T93Ol820P5ooooo`ko;bl_3_l>3Ph>o`@410co410@1_ooool>o`h>3Pgo61PH3_l?3`l=
ob8R8Poooooo000=ooooo`koVIVI3_m`L70=of=SH`go[Jf]4oooool>ocTi>@ko0@413Om=CDd5oooo
o`ko6QXJ3_l30`<>odU9BA;ooooo3_l;2`/>ooooo`goSHf=3Om=CDd6ooooo`ko4Q8B3OlO7alKoa@D
50Gooooo7?l820P>o`T92@go20P81Oooool>obl_;`ko3Ph>3_l410@<oa0@40Kooooo3_l>3Ph=oaPH
60ko3`l?3OlR8R8?ooooo`003Oooool>oiVIV@koL71`3OmSHf<=ojf][A?ooooo3_li>CT>o`410@go
CDe=1Oooool>oaXJ6Pko0`<33_m9BDTBooooo`ko2`/;3_ooool=ohf=S@goCDe=1_ooool>oa8B4Pgo
7alO6olD51@5oooooaco20P83_l92@T=o`P820Gooooo3_l_;bl>o`h>3Pko10@43?l@4106ooooo`ko
3Ph>3OlH61P>o`l?3`go8R8R3oooool000gooooo3_nIVIT>og1`L0goHf=S3On][JdCooooo`ko>CTi
3_l10@4=ode=C@Gooooo3_lJ6QX>o`<30`koBDU94_ooool>o`/;2`kooooo3On=SHd=ode=C@Kooooo
3_lB4Q8=oalO7a_o51@D1OoooolLo`P820ko2@T93Ol820P5ooooo`ko;bl_3_l>3Ph>o`@410co410@
1_ooool>o`h>3Pgo61PH3_l?3`l=ob8R8Poooooo000=ooooo`koVIVI3_m`L70=of=SH`go[Jf]4ooo
ool>ocTi>@ko0@413Om=CDd5ooooo`ko6QXJ3_l30`<>odU9BA;ooooo3_l;2`/>ooooo`goSHf=3Om=
CDd6ooooo`ko4Q8B3OlO7alKoa@D50Gooooo7?l820P>o`T92@go20P81Oooool>obl_;`ko3Ph>3_l4
10@<oa0@40Kooooo3_l>3Ph=oaPH60ko3`l?3OlR8R8?ooooo`003Oooool>oiVIV@koL71`3OmSHf<=
ojf][A?ooooo3_li>CT>o`410@goCDe=1Oooool>oaXJ6Pko0`<33_m9BDTBooooo`ko2`/;3_ooool=
ohf=S@goCDe=1_ooool>oa8B4Pgo7alO6olD51@5oooooaco20P83_l92@T=o`P820Gooooo3_l_;bl>
o`h>3Pko10@43?l@4106ooooo`ko3Ph>3OlH61P>o`l?3`go8R8R3oooool000gooooo3_nIVIT>og1`
L0goHf=S3On][JdCooooo`ko>CTi3_l10@4=ode=C@Gooooo3_lJ6QX>o`<30`koBDU94_ooool>o`/;
2`kooooo3On=SHd=ode=C@Kooooo3_lB4Q8=oalO7a_o51@D1OoooolLo`P820ko2@T93Ol820P5oooo
o`ko;bl_3_l>3Ph>o`@410co410@1_ooool>o`h>3Pgo61PH3_l?3`l=ob8R8Poooooo000=ooooo`ko
VIVI3_m`L70=of=SH`go[Jf]4oooool>ocTi>@ko0@413Om=CDd5ooooo`ko6QXJ3_l30`<>odU9BA;o
oooo3_l;2`/>ooooo`goSHf=3Om=CDd6ooooo`ko4Q8B3OlO7alKoa@D50Gooooo7?l820P>o`T92@go
20P81Oooool>obl_;`ko3Ph>3_l410@<oa0@40Kooooo3_l>3Ph=oaPH60ko3`l?3OlR8R8?ooooo`00
3Oooool>ol30`0koWYjN3Oni^KTCooooo`go0@413_m8B4P>obXZ:Pgo9RHV1Oooool>obHV9Pko6a/K
3_l10@4=o`820PGooooo3_l_;bl>ocLg=a[o61PH1_ooool>oc8b<Pgooooo3_lb<S8=ocdm?@Gooooo
3_l@410>oa/K6`ko4Q8B4_ooool>o`P820ko5aLG3_ooool<oaXJ6QCooooo3Olb<S8>o`H61Pgo7alO
3oooool000gooooo3_o0`<0>oijNWPgo^KVi4oooool=o`410@koB4Q83_lZ:RX=obHV9PGooooo3_lV
9RH>oa/K6`ko0@413Ol20P85ooooo`ko;bl_3_lg=cLJoaPH60Kooooo3_lb<S8=ooooo`ko<S8b3Olm
?Cd5ooooo`ko410@3_lK6a/>oa8B4Q;ooooo3_l820P>oaLG5`kooooo3?lJ6QXDooooo`go<S8b3_l6
1PH=oalO7`oooooo000=ooooo`ko`<303_nNWYh=okVi^A?ooooo3Ol10@4>odQ8B0ko:RXZ3OlV9RH5
ooooo`ko9RHV3_lK6a/>o`410@go0P821Oooool>obl_;`ko=cLg6_lH61P6ooooo`ko<S8b3Oooool>
oc8b<Pgo?Cdm1Oooool>oa0@40ko6a/K3_lB4Q8Booooo`ko20P83_lG5aL>ooooo`co6QXJ5?ooool=
oc8b<Pko1PH63OlO7al?ooooo`003Oooool>ol30`0koWYjN3Oni^KTCooooo`go0@413_m8B4P>obXZ
:Pgo9RHV1Oooool>obHV9Pko6a/K3_l10@4=o`820PGooooo3_l_;bl>ocLg=a[o61PH1_ooool>oc8b
<Pgooooo3_lb<S8=ocdm?@Gooooo3_l@410>oa/K6`ko4Q8B4_ooool>o`P820ko5aLG3_ooool<oaXJ
6QCooooo3Olb<S8>o`H61Pgo7alO3oooool000gooooo3_o0`<0>oijNWPgo^KVi4oooool=o`410@ko
B4Q83_lZ:RX=obHV9PGooooo3_lV9RH>oa/K6`ko0@413Ol20P85ooooo`ko;bl_3_lg=cLJoaPH60Ko
oooo3_lb<S8=ooooo`ko<S8b3Olm?Cd5ooooo`ko410@3_lK6a/>oa8B4Q;ooooo3_l820P>oaLG5`ko
oooo3?lJ6QXDooooo`go<S8b3_l61PH=oalO7`oooooo000=ooooo`ko`<303_nNWYh=okVi^A?ooooo
3Ol10@4>odQ8B0ko:RXZ3OlV9RH5ooooo`ko9RHV3_lK6a/>o`410@go0P821Oooool>obl_;`ko=cLg
6_lH61P6ooooo`ko<S8b3Oooool>oc8b<Pgo?Cdm1Oooool>oa0@40ko6a/K3_lB4Q8Booooo`ko20P8
3_lG5aL>ooooo`co6QXJ5?ooool=oc8b<Pko1PH63OlO7al?ooooo`003Oooool>ol30`0koWYjN3Oni
^KTCooooo`go0@413_m8B4P>obXZ:Pgo9RHV1Oooool>obHV9Pko6a/K3_l10@4=o`820PGooooo3_l_
;bl>ocLg=a[o61PH1_ooool>oc8b<Pgooooo3_lb<S8=ocdm?@Gooooo3_l@410>oa/K6`ko4Q8B4_oo
ool>o`P820ko5aLG3_ooool<oaXJ6QCooooo3Olb<S8>o`H61Pgo7alO3oooool000gooooo3_o0`<0>
oijNWPgo^KVi4oooool=o`410@koB4Q83_lZ:RX=obHV9PGooooo3_lV9RH>oa/K6`ko0@413Ol20P85
ooooo`ko;bl_3_lg=cLJoaPH60Kooooo3_lb<S8=ooooo`ko<S8b3Olm?Cd5ooooo`ko410@3_lK6a/>
oa8B4Q;ooooo3_l820P>oaLG5`kooooo3?lJ6QXDooooo`go<S8b3_l61PH=oalO7`oooooo000=oooo
o`ko`<303_nNWYh=okVi^A?ooooo3Ol10@4>odQ8B0ko:RXZ3OlV9RH5ooooo`ko9RHV3_lK6a/>o`41
0@go0P821Oooool>obl_;`ko=cLg6_lH61P6ooooo`ko<S8b3Oooool>oc8b<Pgo?Cdm1Oooool>oa0@
40ko6a/K3_lB4Q8Booooo`ko20P83_lG5aL>ooooo`co6QXJ5?ooool=oc8b<Pko1PH63OlO7al?oooo
o`003Oooool>ol30`0koWYjN3Oni^KTCooooo`go0@413_m8B4P>obXZ:Pgo9RHV1Oooool>obHV9Pko
6a/K3_l10@4=o`820PGooooo3_l_;bl>ocLg=a[o61PH1_ooool>oc8b<Pgooooo3_lb<S8=ocdm?@Go
oooo3_l@410>oa/K6`ko4Q8B4_ooool>o`P820ko5aLG3_ooool<oaXJ6QCooooo3Olb<S8>o`H61Pgo
7alO3oooool000gooooo3_o0`<0>oijNWPgo^KVi4oooool=o`410@koB4Q83_lZ:RX=obHV9PGooooo
3_lV9RH>oa/K6`ko0@413Ol20P85ooooo`ko;bl_3_lg=cLJoaPH60Kooooo3_lb<S8=ooooo`ko<S8b
3Olm?Cd5ooooo`ko410@3_lK6a/>oa8B4Q;ooooo3_l820P>oaLG5`kooooo3?lJ6QXDooooo`go<S8b
3_l61PH=oalO7`oooooo000=ooooo`ko`<303_nNWYh=okVi^A?ooooo3Ol10@4>odQ8B0ko:RXZ3OlV
9RH5ooooo`ko9RHV3_lK6a/>o`410@go0P821Oooool>obl_;`ko=cLg6_lH61P6ooooo`ko<S8b3Ooo
ool>oc8b<Pgo?Cdm1Oooool>oa0@40ko6a/K3_lB4Q8Booooo`ko20P83_lG5aL>ooooo`co6QXJ5?oo
ool=oc8b<Pko1PH63OlO7al?ooooo`003Oooool>ol30`0koWYjN3Oni^KTCooooo`go0@413_m8B4P>
obXZ:Pgo9RHV1Oooool>obHV9Pko6a/K3_l10@4=o`820PGooooo3_l_;bl>ocLg=a[o61PH1_ooool>
oc8b<Pgooooo3_lb<S8=ocdm?@Gooooo3_l@410>oa/K6`ko4Q8B4_ooool>o`P820ko5aLG3_ooool<
oaXJ6QCooooo3Olb<S8>o`H61Pgo7alO3oooool000gooooo3_o0`<0>oijNWPgo^KVi4oooool=o`41
0@koB4Q83_lZ:RX=obHV9PGooooo3_lV9RH>oa/K6`ko0@413Ol20P85ooooo`ko;bl_3_lg=cLJoaPH
60Kooooo3_lb<S8=ooooo`ko<S8b3Olm?Cd5ooooo`ko410@3_lK6a/>oa8B4Q;ooooo3_l820P>oaLG
5`kooooo3?lJ6QXDooooo`go<S8b3_l61PH=oalO7`oooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {119.688, 0}} -> {-0.22675, -0.0482859, \
0.0169408, 0.0169408}, {{13.375, 67.625}, {116.812, 62.5}} -> {-0.986205, \
-0.214308, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {116.812, 62.5}} -> \
{-5.38717, -0.214308, 0.0737335, 0.0737335}, {{132.75, 187.062}, {116.812, \
62.5}} -> {-9.77687, -0.21176, 0.0736486, 0.0736486}, {{192.5, 246.75}, \
{116.812, 62.5}} -> {-14.1937, -0.214308, 0.0737335, 0.0737335}, {{252.188, \
306.438}, {116.812, 62.5}} -> {-18.5947, -0.214308, 0.0737335, 0.0737335}, \
{{311.875, 366.188}, {116.812, 62.5}} -> {-22.9692, -0.21176, 0.0736486, \
0.0736486}, {{371.625, 425.875}, {116.812, 62.5}} -> {-27.4012, -0.214308, \
0.0737335, 0.0737335}, {{431.312, 485.562}, {116.812, 62.5}} -> {-31.8022, \
-0.214308, 0.0737335, 0.0737335}, {{13.375, 67.625}, {57.125, 2.8125}} -> \
{-0.986205, -4.61527, 0.0737335, 0.0737335}, {{73.0625, 127.312}, {57.125, \
2.8125}} -> {-5.38717, -4.61527, 0.0737335, 0.0737335}, {{132.75, 187.062}, \
{57.125, 2.8125}} -> {-9.77687, -4.60766, 0.0736486, 0.0736486}, {{192.5, \
246.75}, {57.125, 2.8125}} -> {-14.1937, -4.61527, 0.0737335, 0.0737335}, \
{{252.188, 306.438}, {57.125, 2.8125}} -> {-18.5947, -4.61527, 0.0737335, \
0.0737335}, {{311.875, 366.188}, {57.125, 2.8125}} -> {-22.9692, -4.60766, \
0.0736486, 0.0736486}, {{371.625, 425.875}, {57.125, 2.8125}} -> {-27.4012, \
-4.61527, 0.0737335, 0.0737335}, {{431.312, 485.562}, {57.125, 2.8125}} -> \
{-31.8022, -4.61527, 0.0737335, 0.0737335}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 1.16373 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13109 -18 -4.5 ]
[-0.0125 .13109 0 4.5 ]
[-0.0125 .24746 -18 -4.5 ]
[-0.0125 .24746 0 4.5 ]
[-0.0125 .36383 -18 -4.5 ]
[-0.0125 .36383 0 4.5 ]
[-0.0125 .48021 -18 -4.5 ]
[-0.0125 .48021 0 4.5 ]
[-0.0125 .59658 -18 -4.5 ]
[-0.0125 .59658 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13109 m
.00625 .13109 L
s
[(0.1)] -0.0125 .13109 1 0 Mshowa
0 .24746 m
.00625 .24746 L
s
[(0.2)] -0.0125 .24746 1 0 Mshowa
0 .36383 m
.00625 .36383 L
s
[(0.3)] -0.0125 .36383 1 0 Mshowa
0 .48021 m
.00625 .48021 L
s
[(0.4)] -0.0125 .48021 1 0 Mshowa
0 .59658 m
.00625 .59658 L
s
[(0.5)] -0.0125 .59658 1 0 Mshowa
.125 Mabswid
0 .03799 m
.00375 .03799 L
s
0 .06126 m
.00375 .06126 L
s
0 .08454 m
.00375 .08454 L
s
0 .10781 m
.00375 .10781 L
s
0 .15436 m
.00375 .15436 L
s
0 .17764 m
.00375 .17764 L
s
0 .20091 m
.00375 .20091 L
s
0 .22419 m
.00375 .22419 L
s
0 .27074 m
.00375 .27074 L
s
0 .29401 m
.00375 .29401 L
s
0 .31728 m
.00375 .31728 L
s
0 .34056 m
.00375 .34056 L
s
0 .38711 m
.00375 .38711 L
s
0 .41038 m
.00375 .41038 L
s
0 .43366 m
.00375 .43366 L
s
0 .45693 m
.00375 .45693 L
s
0 .50348 m
.00375 .50348 L
s
0 .52676 m
.00375 .52676 L
s
0 .55003 m
.00375 .55003 L
s
0 .5733 m
.00375 .5733 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13109 m
1 .13109 L
s
.99375 .24746 m
1 .24746 L
s
.99375 .36383 m
1 .36383 L
s
.99375 .48021 m
1 .48021 L
s
.99375 .59658 m
1 .59658 L
s
.125 Mabswid
.99625 .03799 m
1 .03799 L
s
.99625 .06126 m
1 .06126 L
s
.99625 .08454 m
1 .08454 L
s
.99625 .10781 m
1 .10781 L
s
.99625 .15436 m
1 .15436 L
s
.99625 .17764 m
1 .17764 L
s
.99625 .20091 m
1 .20091 L
s
.99625 .22419 m
1 .22419 L
s
.99625 .27074 m
1 .27074 L
s
.99625 .29401 m
1 .29401 L
s
.99625 .31728 m
1 .31728 L
s
.99625 .34056 m
1 .34056 L
s
.99625 .38711 m
1 .38711 L
s
.99625 .41038 m
1 .41038 L
s
.99625 .43366 m
1 .43366 L
s
.99625 .45693 m
1 .45693 L
s
.99625 .50348 m
1 .50348 L
s
.99625 .52676 m
1 .52676 L
s
.99625 .55003 m
1 .55003 L
s
.99625 .5733 m
1 .5733 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .01839 L
.08642 .01839 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .01839 L
.08642 .01839 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .15727 L
.14815 .15727 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .15727 L
.14815 .15727 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .18627 L
.20988 .18627 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .18627 L
.20988 .18627 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .02084 L
.2716 .02084 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .02084 L
.2716 .02084 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .01512 L
.33333 .01512 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .01512 L
.33333 .01512 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .16136 L
.39506 .16136 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .16136 L
.39506 .16136 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .15523 L
.45679 .15523 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .15523 L
.45679 .15523 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .01921 L
.51852 .01921 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .01921 L
.51852 .01921 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .09028 L
.58025 .09028 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .09028 L
.58025 .09028 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .07149 L
.64198 .07149 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .07149 L
.64198 .07149 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .13521 L
.7037 .13521 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .13521 L
.7037 .13521 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .01921 L
.76543 .01921 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .01921 L
.76543 .01921 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .15645 L
.88889 .15645 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .15645 L
.88889 .15645 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .1634 L
.95062 .1634 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .1634 L
.95062 .1634 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .48772 L
.03704 .48772 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .48772 L
.03704 .48772 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .02207 L
.09877 .02207 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .02207 L
.09877 .02207 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .02411 L
.16049 .02411 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .02411 L
.16049 .02411 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .02574 L
.22222 .02574 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .02574 L
.22222 .02574 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .33046 L
.28395 .33046 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .33046 L
.28395 .33046 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .01798 L
.34568 .01798 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .01798 L
.34568 .01798 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .01921 L
.40741 .01921 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .01921 L
.40741 .01921 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .01553 L
.46914 .01553 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .01553 L
.46914 .01553 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .32229 L
.53086 .32229 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .32229 L
.53086 .32229 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .01921 L
.59259 .01921 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .01921 L
.59259 .01921 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .02329 L
.65432 .02329 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .02329 L
.65432 .02329 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .01512 L
.71605 .01512 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .01512 L
.71605 .01512 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .02901 L
.77778 .02901 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .02901 L
.77778 .02901 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .01635 L
.83951 .01635 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .01635 L
.83951 .01635 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .01594 L
.90123 .01594 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .01594 L
.90123 .01594 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01512 L
.96296 .01512 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01512 L
.96296 .01512 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .60332 L
.04938 .60332 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .60332 L
.04938 .60332 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .01717 L
.11111 .01717 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .01717 L
.11111 .01717 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .01553 L
.17284 .01553 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .01553 L
.17284 .01553 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .01512 L
.23457 .01512 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .01512 L
.23457 .01512 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .29615 L
.2963 .29615 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .29615 L
.2963 .29615 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .01472 L
.35802 .01472 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .01472 L
.35802 .01472 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .30391 L
.54321 .30391 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .30391 L
.54321 .30391 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .01512 L
.66667 .01512 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .01512 L
.66667 .01512 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .01512 L
.79012 .01512 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .01512 L
.79012 .01512 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .01594 L
.06173 .01594 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .01594 L
.06173 .01594 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .16871 L
.12346 .16871 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .16871 L
.12346 .16871 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .05066 L
.18519 .05066 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .05066 L
.18519 .05066 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .07762 L
.24691 .07762 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .07762 L
.24691 .07762 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .05515 L
.30864 .05515 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .05515 L
.30864 .05515 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .16626 L
.37037 .16626 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .16626 L
.37037 .16626 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .038 L
.4321 .038 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .038 L
.4321 .038 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .05229 L
.49383 .05229 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .05229 L
.49383 .05229 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .0572 L
.55556 .0572 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .0572 L
.55556 .0572 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .14093 L
.61728 .14093 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .14093 L
.61728 .14093 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .15359 L
.67901 .15359 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .15359 L
.67901 .15359 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .03065 L
.74074 .03065 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .03065 L
.74074 .03065 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .17606 L
.80247 .17606 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .17606 L
.80247 .17606 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .15114 L
.8642 .15114 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .15114 L
.8642 .15114 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .03024 L
.92593 .03024 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .03024 L
.92593 .03024 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .03473 L
.98765 .03473 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .03473 L
.98765 .03473 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oo
oooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`00<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001[ooooo000coooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001gooooo000booooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool003?ooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00006_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035
o`0000gooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00o`[ooooo1Ooo0006o`3o00Go003o1oooO`05ooooo`Goo`001ol0
o`04ooooo`Ooogl01?ooool6ool000Ko0?l01Oooool7oomo00Cooooo1_oo0005o`3o00Ko003o1_oo
O`0;ooooo`Ko0?l01Oooool6oomo00Gooooo1Ooo0007o`3o00Gooooo1_ooO`05ooooo`Koo`002_oo
ool7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Koo`001ol0o`04ooooo`Ooogl01?oo
ool6ool000Ko0?l01Oooool6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool5ool000Oo0?l01Ooo
ool6oomo00[ooooo1ol0o`04ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_oo
ool7oomo00Cooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l?ooooo`Oo0?l01?ooool7oomo00Gooooo1Ooo
0007o`3o00Cooooo1oooO`04ooooo`Koo`001_l0o`05ooooo`Ooogl01?ooool6ool000Go0?l01_l0
0?l6oomo01Kooooo1_ooO`05ooooo`Goo`001ol0o`05ooooo`Koogl01Oooool6ool000[ooooo1ooo
O`05ooooo`Goo`001_l0o`05o`00o`Ooogl01?ooool6ool000Oo0?l01?ooool7oomo00Cooooo1_oo
0006o`3o00Gooooo1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo0007o`3o00Gooooo1_oo
O`0Eooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo00?o
0000ooooooooool02oooool001[ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00o`oooooo1ol0o`04ooooo`Ooogl01Oooool5ool000Oo0?l01?ooool7oomo00Cooooo1_oo0006
o`3o00Gooooo1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl05_ooool6oomo00Gooooo1_oo000;
ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:
ooooo`Ooogl01?ooool6ool000Ko0?l01Oooool6oomo00Gooooo1ooo000:ooooo`Koogl02_ooool7
o`3o00Gooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7
oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o6_ooool7oomo00Gooooo1Ooo0007o`3o00Cooooo1oooO`04ooooo`Koo`001_l0o`05oooo
o`Ooogl02_ooool5o`3o00Ko003o1_ooO`0Fooooo`Koogl01Oooool6ool000_ooooo1_ooO`05oooo
o`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04oooo
o`Koo`001_l0o`05ooooo`Koogl01Oooool7ool000[ooooo1_ooO`0:ooooo`Oo0?l01Oooool6oomo
01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Oo
ogl01Oooool6ool000[ooooo1oooO`04ooooo`Koo`001_l0o`05ooooo`Ooogl02_ooool5o`3o00Ko
003o1_ooO`0Fooooo`Koogl01Oooool6ool000_ooooo1_ooO`05ooooo`Koo`002_ooool7oomo00[o
oooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Go
oooo1ooo000:ooooo`Koogl02_ooool7o`3o00Gooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[o
oooo1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl0
1?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`00
2oooool6oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`00
2_ooool7oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`0:ooooo`Oo0?l0
1Oooool6oomo01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl0
1?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?lJooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0
o`06o`00o`Koogl05_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_oo
O`05ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[ooooo1ooo
O`04ooooo`Ooo`002_ooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7
ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`002oooool6
oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6
ool001Gooooo1ooo000:ooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool000[ooooo1oooO`04oooo
o`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl05_ooool6oomo00Gooooo1_oo000;oooo
o`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05oooo
o`Koo`005Oooool7ool000[ooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
00002?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[o
oooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`002oooool6oomo00Go
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Co
oooo1ooo000:ooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Go
oooo1ooo000Dooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l0
1_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`005_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l0
1Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`00
9_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo
000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_oo
O`05ooooo`Koo`005_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo
000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1ooo
O`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7
ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`005_ooool6
ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7
ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7
ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:oooo
o`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`005_ooool6ool000[ooooo1oooO`0:oooo
o`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05oooo
o`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Go
oooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Ko
oooo1_ooO`05ooooo`Koo`005_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Co
oooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Go
oooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl0
1?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo01Kooooo1_ooO`05ooooo`Koo`00
5_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl0
1?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`00
5Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`002_ooool7oomo00[ooooo1Ol0
o`06o`00o`Koogl05_ooool6oomo00Gooooo1_oo000Fooooo`Koo`002_ooool7oomo00[ooooo1_l0
o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo
000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6
ool001Gooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`0Fooooo`Koogl01Oooool6
ool001Kooooo1_oo000Kooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7
ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7
ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`07o`00
oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool0
00[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo
00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000:ooooo`Oo
ogl02_ooool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko
003o2_ooool7ool000[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo000Vooooo`Ko
ogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0000Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool000[ooooo
1oooO`0:ooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l0
1_l00?l:ooooo`Ooo`002_ooool7oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7ool002Kooooo
1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000Dooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`002_oo
ool7oomo00[ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0
o`06o`00o`[ooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_oo
ool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000E
ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6
ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05
ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo
00Gooooo1_oo000Eooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`07o`00oa_ooooo1_ooO`05oooo
o`Koo`005_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000:ooooo`Ooogl01?ooool7ool0
00[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool0
01Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`07o`00oa_o
oooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000:ooooo`Oo
ogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Ko
o`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`002_ooool7oomo00[ooooo
1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo
1ooo000:ooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo
1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000:ooooo`Ooogl02_oo
ool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o2_oo
ool7ool000[ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Ooo
ool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool000[ooooo1oooO`0:
ooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?l:
ooooo`Ooo`002_ooool7oomo01Gooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05
ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o
00Oo003o6oooool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o2_ooool7ool0
00[ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool0
01Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_o
oooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000:ooooo`Oo
ogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Oo
o`005Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07o`00oa[ooooo
1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`00
5_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000:ooooo`Ooogl05Oooool6oomo00Gooooo
1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005?ooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Ooo
ool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0
o`06o`00o`[ooooo1ooo000:ooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Ooo
ool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000K
ooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?l:
ooooo`Ooo`002_ooool7oomo01Gooooo1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05
ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o
00Oo003o6oooool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o2_ooool7ool0
00[ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool0
01Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_o
oooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Ko
ogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000Eooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo
1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`00
5_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo
1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Ooo
ool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0
o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Ooo
ool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07
o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo1oooO`0E
ooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000E
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05oooo
o`Koo`005_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool0
02Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Ko
o`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_o
oooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Oo
ogl01Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo
1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo
1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo
1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003o6_oo
ool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo
000Fooooo`Koo`006oooool6o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`05ooooo`Ooo`009_oo
ool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Cooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000K
ooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?lK
ooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000E
ooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lKoooo
o`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo
00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Oo
ogl01Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Ko
oooo1_oo000Kooooo`Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Ko
ogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo
1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l0
1_l00?lKooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo
1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol0
0?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?lKooooo`Ooogl05Ooo
ool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Ooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJ
ooooo`Ooogl01Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6
ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo00Gooooo1ooo000V
ooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool0
01Gooooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Koooo
o`Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo
00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6oooool6oomo00Go
oooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`05ooooo`Oo
o`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_o
oooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00oa_o
oooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Go
oooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01_ooool4o`0000Oooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Ko
o`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_o
oooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Kooooo1_ooO`0Eooooo`Oo
ogl01Oooool6ool001Gooooo1ooo000Booooo`Co00003Oooool000gooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[o
oooo1oooO`05ooooo`Koo`005Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Ko
o`005_ooool6ool001_ooooo1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl01Oooool7ool002Ko
oooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000Kooooo`Go
0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?lKooooo`Oo
ogl05Oooool6oomo00Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Oo
o`005Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`;o
00002?ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Go
oooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko
0?l01_l00?lKooooo`Ooogl05Oooool6oomo03;ooooo1_ooO`0Eooooo`Ooogl01Oooool6ool001Go
oooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`00
5Oooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo
1_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl0<_ooool6oomo01Gooooo1oooO`05ooooo`Koo`00
5Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6ooo
ool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o6oooool7oomo01Gooooo1_oo
O`0booooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6
ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo1_oo000K
ooooo`Ko0?l01_l00?lgooooo`Koogl0<_ooool6oomo01Gooooo1oooO`05ooooo`Koo`005Oooool7
ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6oooool6oomo
00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o=oooool6oomo03;ooooo1_ooO`0Eoooo
o`Ooogl01Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`005Oooool7ool001_o
oooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00ocOo
oooo1_ooO`0booooo`Koogl05Oooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl0
1Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lKooooo`Koogl01Oooool6ool001Kooooo
1_oo000Kooooo`Ko0?l01_l00?lgooooo`Koogl0<_ooool6oomo01Gooooo1oooO`05ooooo`Koo`00
5Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6ooo
ool6oomo00Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Ko003o=oooool6oomo03;ooooo1_oo
O`0Qooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo0ol00008
ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool001Gooooo1ooo000Kooooo`Go0?l01ol00?lK
ooooo`Koogl01Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?m_ooooo`Koogl08Oooool6
ool001Gooooo1ooo000Dooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o6_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`006oooool5o`3o00Oo003o6oooool6oomo
00Gooooo1_oo000gooooo`Ko0?l01_l00?m_ooooo`Koogl08Oooool6ool001Gooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[o
oooo1oooO`0Pooooo`Ooo`006oooool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo000gooooo`Ko
0?l01_l00?m_ooooo`Koogl0??ooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo023ooooo1ooo000Kooooo`Go0?l0
1ol00?lKooooo`Koogl01Oooool6ool003Oooooo1_l0o`06o`00ofoooooo1_ooO`0looooo`Ooo`00
5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?lJooooo`Ooogl08?ooool7ool001_ooooo1Ol0o`07o`00oa_ooooo1_ooO`12ooooo`Ko0?l01_l0
0?m_ooooo`Koogl0??ooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo023ooooo1ooo000Kooooo`Go0?l01ol00?lK
ooooo`Koogl0@_ooool6o`3o00Ko003oKoooool6oomo05Sooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo023ooooo1ooo000Koooo
o`Go0?l01ol00?mSooooo`Ko0?l01_l00?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?m1ooooo`Ooo`006oooool5o`3o00Oo
003oHoooool6o`3o00Ko003oKoooool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003o@Oooool7ool001_ooooo1Ol0o`07o`00of?ooooo
1_l0o`06o`00ofoooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00od7ooooo1ooo000Kooooo`Go0?l01ol00?mSooooo`Ko0?l01_l0
0?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00od7ooooo1ooo000Kooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?m_ooooo`Koogl0Eoooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00od7ooooo1ooo000Koooo
o`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00od7ooooo1ooo000Kooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00od7ooooo1ooo000Kooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00od7ooooo1ooo
000Kooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHooo
ool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o
00Ko003oc?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?o
oooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHooo
ool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o
00Ko003oc?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?o
oooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool0
2oooool000kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go
0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool4o`0000Oooooo1_l0o`07o`00of?o
oooo1Ol0o`07o`00of?ooooo1_l0o`06o`00ol[ooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo
00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?o
oooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003o
Hoooool5o`3o00Oo003oHoooool6o`3o00Ko003oc?ooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5
o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?o
oooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oHoooool5o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko
0?l01_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00of?ooooo1Ol0o`07o`00of?ooooo1_l0o`06o`00olgooooo00?o0000ooooooooool0
2oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?mSooooo`Go0?l01ol00?mSooooo`Ko0?l01_l0
0?o<ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool5
o`3o00Oo003oHoooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko0?l0JOooool6o`3o00Ko003ocOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko
0?l0JOooool6o`3o00Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko0?l0JOooool6o`3o00Ko003ocOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko0?l0JOoo
ool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003oHoooool6o`3o06Wooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1_l0o`1Yooooo`Oo0?l0d_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko
0?l0JOooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003oHoooool6o`3o06Wooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00002?ooool6o`3o00Oo003oHoooool6o`3o06Wooooo1ol0o`3Aooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHoooool6o`3o06Wooooo1ol0o`3B
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
of?ooooo1_l0o`1Yooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?mSooooo`Ko0?l0oooooom3ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00of?ooooo1_l0o`3ooooood?ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oHooo
ool6o`3o0?oooooo@oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mSooooo`Ko0?l0oooooom3ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07o`00ooooooooZoooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojco
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
oooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Cooooo1?l00007ooooo`Ko0?l01ol00?ooooooojWo
oooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o00001oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o
00001oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oo
ooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo0ol0
0008ooooo`Ko0?l01ol00?oooooooj_ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oooooo
ojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0
o`07o`00ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojco
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
oooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooo
oon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003ooooooon[
ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooo
oooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00007ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00007ooooo`Co00001oooool6o`3o00Oo003ooooooonYooooo`Co00003Oooool000gooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00009ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojco
oooo00?o0000ooooooooool02oooool000kooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`?o00003_ooool7o`00ooooooooZoooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000
ooooooooool02oooool002?ooooo0ol0000>ooooo`Oo003ooooooon[ooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000
ooooooooool02oooool002?ooooo0ol0000>ooooo`Oo003ooooooon[ooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`008oooool3o`0000kooooo1ol00?oooooooj_ooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
0ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00kooooo1ol00?ooooooojcooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`Co00003Oooool7o`00ooooooooZOoo
ool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo00kooooo1ol0
0?ooooooojcooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o
0000ooooooooool02oooool000kooooo0_l00008ooooo`Go00001_ooool00ol0003oooooooooo`3o
oooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool00?oooooomOooool003;ooooo0ol0000Hooooo`Go00006?ooool3o`0001Wooooo0ol0
000Hooooo`?o00006Oooool3o`0001[ooooo00?o0000ooooooooool06?ooool3o`0001Wooooo0_l0
000Gooooo`?o00001?ooool2o`0001;ooooo0ol00003ooooo`?o00004oooool3o`0000;ooooo1Ol0
000Booooo`?o00000oooool3o`0001?ooooo0ol00004ooooo`?o00004_ooool3o`0000?ooooo0ol0
000Cooooo`?o00000oooool3o`0001[ooooo000cooooo`03o`000?oooooooooo01Sooooo00Co0000
oooooooooooo00005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5_ooool01Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Ioooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0Gooooo`00<oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05?ooool5o`0001_ooooo00?o0000ooooooooool05Oooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooo
oooo000001_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00Co0000oooooooooooooooo1Ol0000Cooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool05oooool003?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`;o
00005oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01Gooooo1?l0000Koooo
o`03o`000?oooooooooo01Oooooo0ol0000Iooooo`Co00005_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`;o00005?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo
1?l0000Jooooo`00<oooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool00000
6oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000001Sooooo1?l0000Hooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001Oo
oooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000005?oo
ool01?l0003oooooooooooooool4o`0001Cooooo00Go0000ooooooooooooooooo`00000Mooooo`00
<_ooool2o`0001Wooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oooooooooooooo
ool000006?ooool2o`0001Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo000001Oooooo00Go
0000ooooooooooooooooo`00000Eooooo`;o00001?ooool01?l0003oooooooooool0000Aooooo`;o
00001?ooool2o`0001Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000004_ooool2o`00
00?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00001Oooool2o`0001?ooooo0_l00003
ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo000coooo
o`03o`000?oooooooooo01Sooooo0ol0000Iooooo`?o00006_ooool00ol0003oooooooooo`0Foooo
o`Go00006Oooool2o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Oooooo00?o0000oooo
ooooool00oooool2o`0001?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00;ooooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo0ol0000Doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool01?l0003oooooooooooooool5
o`0001?ooooo00?o0000ooooooooool00oooool2o`0001[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.584672, -0.0405374, \
0.0359213, 0.0019054}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 1.68198 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09881 -24 -4.5 ]
[-0.0125 .09881 0 4.5 ]
[-0.0125 .18291 -18 -4.5 ]
[-0.0125 .18291 0 4.5 ]
[-0.0125 .26701 -24 -4.5 ]
[-0.0125 .26701 0 4.5 ]
[-0.0125 .35111 -18 -4.5 ]
[-0.0125 .35111 0 4.5 ]
[-0.0125 .43521 -24 -4.5 ]
[-0.0125 .43521 0 4.5 ]
[-0.0125 .51931 -18 -4.5 ]
[-0.0125 .51931 0 4.5 ]
[-0.0125 .60341 -24 -4.5 ]
[-0.0125 .60341 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09881 m
.00625 .09881 L
s
[(0.05)] -0.0125 .09881 1 0 Mshowa
0 .18291 m
.00625 .18291 L
s
[(0.1)] -0.0125 .18291 1 0 Mshowa
0 .26701 m
.00625 .26701 L
s
[(0.15)] -0.0125 .26701 1 0 Mshowa
0 .35111 m
.00625 .35111 L
s
[(0.2)] -0.0125 .35111 1 0 Mshowa
0 .43521 m
.00625 .43521 L
s
[(0.25)] -0.0125 .43521 1 0 Mshowa
0 .51931 m
.00625 .51931 L
s
[(0.3)] -0.0125 .51931 1 0 Mshowa
0 .60341 m
.00625 .60341 L
s
[(0.35)] -0.0125 .60341 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08199 m
.00375 .08199 L
s
0 .11563 m
.00375 .11563 L
s
0 .13245 m
.00375 .13245 L
s
0 .14927 m
.00375 .14927 L
s
0 .16609 m
.00375 .16609 L
s
0 .19973 m
.00375 .19973 L
s
0 .21655 m
.00375 .21655 L
s
0 .23337 m
.00375 .23337 L
s
0 .25019 m
.00375 .25019 L
s
0 .28383 m
.00375 .28383 L
s
0 .30065 m
.00375 .30065 L
s
0 .31747 m
.00375 .31747 L
s
0 .33429 m
.00375 .33429 L
s
0 .36793 m
.00375 .36793 L
s
0 .38475 m
.00375 .38475 L
s
0 .40157 m
.00375 .40157 L
s
0 .41839 m
.00375 .41839 L
s
0 .45203 m
.00375 .45203 L
s
0 .46885 m
.00375 .46885 L
s
0 .48567 m
.00375 .48567 L
s
0 .50249 m
.00375 .50249 L
s
0 .53613 m
.00375 .53613 L
s
0 .55295 m
.00375 .55295 L
s
0 .56977 m
.00375 .56977 L
s
0 .58659 m
.00375 .58659 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09881 m
1 .09881 L
s
.99375 .18291 m
1 .18291 L
s
.99375 .26701 m
1 .26701 L
s
.99375 .35111 m
1 .35111 L
s
.99375 .43521 m
1 .43521 L
s
.99375 .51931 m
1 .51931 L
s
.99375 .60341 m
1 .60341 L
s
.125 Mabswid
.99625 .03153 m
1 .03153 L
s
.99625 .04835 m
1 .04835 L
s
.99625 .06517 m
1 .06517 L
s
.99625 .08199 m
1 .08199 L
s
.99625 .11563 m
1 .11563 L
s
.99625 .13245 m
1 .13245 L
s
.99625 .14927 m
1 .14927 L
s
.99625 .16609 m
1 .16609 L
s
.99625 .19973 m
1 .19973 L
s
.99625 .21655 m
1 .21655 L
s
.99625 .23337 m
1 .23337 L
s
.99625 .25019 m
1 .25019 L
s
.99625 .28383 m
1 .28383 L
s
.99625 .30065 m
1 .30065 L
s
.99625 .31747 m
1 .31747 L
s
.99625 .33429 m
1 .33429 L
s
.99625 .36793 m
1 .36793 L
s
.99625 .38475 m
1 .38475 L
s
.99625 .40157 m
1 .40157 L
s
.99625 .41839 m
1 .41839 L
s
.99625 .45203 m
1 .45203 L
s
.99625 .46885 m
1 .46885 L
s
.99625 .48567 m
1 .48567 L
s
.99625 .50249 m
1 .50249 L
s
.99625 .53613 m
1 .53613 L
s
.99625 .55295 m
1 .55295 L
s
.99625 .56977 m
1 .56977 L
s
.99625 .58659 m
1 .58659 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .04837 L
.08642 .04837 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .04837 L
.08642 .04837 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .07375 L
.14815 .07375 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .07375 L
.14815 .07375 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .26858 L
.20988 .26858 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .26858 L
.20988 .26858 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .01826 L
.2716 .01826 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .01826 L
.2716 .01826 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .36599 L
.33333 .36599 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .36599 L
.33333 .36599 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .07611 L
.39506 .07611 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .07611 L
.39506 .07611 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .01472 L
.45679 .01472 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .01472 L
.45679 .01472 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .03066 L
.51852 .03066 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .03066 L
.51852 .03066 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .26917 L
.58025 .26917 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .26917 L
.58025 .26917 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .31463 L
.64198 .31463 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .31463 L
.64198 .31463 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .05899 L
.7037 .05899 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .05899 L
.7037 .05899 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .03479 L
.76543 .03479 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .03479 L
.76543 .03479 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .03243 L
.82716 .03243 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .03243 L
.82716 .03243 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .28156 L
.88889 .28156 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .28156 L
.88889 .28156 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .01472 L
.95062 .01472 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .01472 L
.95062 .01472 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .06431 L
.09877 .06431 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .06431 L
.09877 .06431 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .24024 L
.16049 .24024 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .24024 L
.16049 .24024 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .04305 L
.22222 .04305 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .04305 L
.22222 .04305 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .19714 L
.28395 .19714 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .19714 L
.28395 .19714 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .06135 L
.34568 .06135 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .06135 L
.34568 .06135 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .16054 L
.40741 .16054 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .16054 L
.40741 .16054 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .0218 L
.46914 .0218 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .0218 L
.46914 .0218 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .19183 L
.53086 .19183 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .19183 L
.53086 .19183 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .07257 L
.59259 .07257 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .07257 L
.59259 .07257 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .07434 L
.65432 .07434 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .07434 L
.65432 .07434 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .0342 L
.71605 .0342 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .0342 L
.71605 .0342 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .08556 L
.77778 .08556 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .08556 L
.77778 .08556 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .02121 L
.83951 .02121 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .02121 L
.83951 .02121 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .02829 L
.90123 .02829 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .02829 L
.90123 .02829 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01767 L
.96296 .01767 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01767 L
.96296 .01767 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .0218 L
.04938 .0218 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .0218 L
.04938 .0218 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .16998 L
.11111 .16998 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .16998 L
.11111 .16998 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .07729 L
.17284 .07729 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .07729 L
.17284 .07729 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .14106 L
.23457 .14106 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .14106 L
.23457 .14106 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .03066 L
.2963 .03066 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .03066 L
.2963 .03066 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .12984 L
.35802 .12984 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .12984 L
.35802 .12984 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .10799 L
.41975 .10799 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .10799 L
.41975 .10799 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .17294 L
.48148 .17294 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .17294 L
.48148 .17294 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .07434 L
.54321 .07434 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .07434 L
.54321 .07434 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .18002 L
.60494 .18002 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .18002 L
.60494 .18002 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .157 L
.66667 .157 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .157 L
.66667 .157 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .20009 L
.7284 .20009 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .20009 L
.7284 .20009 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .09264 L
.79012 .09264 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .09264 L
.79012 .09264 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .17471 L
.85185 .17471 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .17471 L
.85185 .17471 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .07434 L
.91358 .07434 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .07434 L
.91358 .07434 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .11272 L
.97531 .11272 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .11272 L
.97531 .11272 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .19006 L
.06173 .19006 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .19006 L
.06173 .19006 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .03656 L
.12346 .03656 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .03656 L
.12346 .03656 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .19714 L
.18519 .19714 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .19714 L
.18519 .19714 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .03715 L
.24691 .03715 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .03715 L
.24691 .03715 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .48347 L
.30864 .48347 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .48347 L
.30864 .48347 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .02888 L
.37037 .02888 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .02888 L
.37037 .02888 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .10681 L
.4321 .10681 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .10681 L
.4321 .10681 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .01472 L
.49383 .01472 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .01472 L
.49383 .01472 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .36067 L
.55556 .36067 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .36067 L
.55556 .36067 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .0342 L
.61728 .0342 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .0342 L
.61728 .0342 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .06431 L
.67901 .06431 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .06431 L
.67901 .06431 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .02003 L
.74074 .02003 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .02003 L
.74074 .02003 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .27507 L
.80247 .27507 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .27507 L
.80247 .27507 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .0159 L
.8642 .0159 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .0159 L
.8642 .0159 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .03774 L
.92593 .03774 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .03774 L
.92593 .03774 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .01472 L
.98765 .01472 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .01472 L
.98765 .01472 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00=Oooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00005oooool003Kooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Co
oooo000fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Dooooo`00=_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001Oooooo000foooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001[ooooo000eooooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool05oooool003Kooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00005oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002Koooooool00035
o`0000[ooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Mooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02?ooool001cooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02?ooool001cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02?oo
ool001cooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000:ooooo`007?ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`06o`00o`Koogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Gooooo1Ooo
0006o`3o00Go003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Ooogl01?ooool6ool000Go0?l01_l0
0?l6oomo00Gooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl02_oo
ool6o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0006o`3o00Go003o1ooo
O`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01_l00?l6oomo00Gooooo1Ooo
0006o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`_ooooo1Ooo0006o`3o00Go003o1ooo
O`0:ooooo`Ko0?l01_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0
o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1ooo
O`0:ooooo`Go0?l01_l00?l6oomo00Gooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0
o`06o`00o`Koogl02_ooool6o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo
0006o`3o00Go003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01_l0
0?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`_ooooo1Ooo
0006o`3o00Go003o1oooO`0@ooooo`Ko003o2_ooool00ol0003oooooooooo`08ooooo`007Oooool2
o`0000Oooooo00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`05
o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1oooO`0:
ooooo`Go0?l01_l00?l6oomo00Gooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`06
o`00o`Koogl02_ooool6o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0006
o`3o00Go003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01ol00?l:
ooooo`Goo`001_l0o`06o`00o`Koogl01Oooool5ool000Ko0?l01_l00?l;ooooo`Goo`001_l0o`05
o`00o`Ooogl04?ooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool02?ooool7o`3o00Gooooo1_ooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Oooool5ool0
00Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1oooO`0:ooooo`Go0?l01_l00?l6oomo
00Gooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00
o`_ooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Koo`001_l0o`05o`00o`Ooogl01?ooool6ool0
00Go0?l01_l00?l6oomo00Gooooo1_oo0005o`3o00Oo003o2_ooool5ool000Ko0?l01_l00?l6oomo
00Gooooo1_oo0005ooooo`Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo013ooooo1_l00?l:oooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Ko
ogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ko
o`001Ol0o`06o`00o`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Koo`001Ol0o`06o`00o`Ko
ogl01Oooool5ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Goo`001_l0o`05o`00o`Oo
ogl01?ooool6ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Ko
o`001Ol0o`07o`00o`[ooooo1Ooo0006o`3o00Ko003o1_ooO`05ooooo`Koo`001Oooool6o`00o`_o
oooo1Ooo0006o`3o00Go003o1oooO`0@ooooo`Ko003o2_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo00Gooooo1Ooo0006o`3o00Go003o
1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01?ooool6ool000Go0?l01_l00?l7oomo00[ooooo
1Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o
1_ooO`0@ooooo`Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0006o`3o00Go003o
1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01ol00?l:ooooo`Goo`00
1_l0o`06o`00o`Koogl01Oooool6ool000Gooooo1_l00?l;ooooo`Goo`001_l0o`05o`00o`Ooogl0
4?ooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l01Ooo
ool6oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01?oo
ool6ool000Go0?l01_l00?l7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01ol0
0?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00o`_ooooo1Ooo0006o`3o00Go003o1ooo
O`04ooooo`Koo`001_l0o`05o`00o`Ooogl01?ooool6ool000Go0?l01_l00?l6oomo00Gooooo1_oo
0005o`3o00Oo003o2_ooool5ool000Ko0?l01_l00?l6oomo00Gooooo1_oo0005ooooo`Ko003o2ooo
ool6ool000Gooooo1Ol00?l7oomo013ooooo1_l00?l9ooooo`;o00002_ooool002Kooooo00?o0000
ooooooooool02?ooool7o`3o00Gooooo1_ooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Oooool5
ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1oooO`0:ooooo`Ko0?l01Oooool6
oomo00Gooooo1_oo0005o`3o00Oo003o2_ooool5ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l@
ooooo`Ko0?l01Ol00?l7oomo00Cooooo1_oo0006o`3o00Go003o1oooO`04ooooo`Koo`001Ol0o`06
o`00o`Koogl01Oooool6ool000Go0?l01ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl01Oooool6
ool000Gooooo1_l00?l;ooooo`Koo`001Oooool5o`00o`Ooogl04?ooool6o`00o`[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`05oooo
o`Goo`001_l0o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o
00Ko003o1oooO`0:ooooo`Ko0?l01Oooool6oomo00Gooooo1_oo0005o`3o00Oo003o2_ooool5ool0
00Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo1_oo0006o`3o
00Go003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01ol00?l:oooo
o`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00o`_ooooo1_oo0005ooooo`Go003o1oooO`0@oooo
o`Ko003o2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo
0?l01Oooool6oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Oo
ogl01?ooool6ool000Go0?l01_l00?l7oomo00[ooooo1_l0o`05ooooo`Koogl01Oooool6ool000Go
0?l01ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Oo
ogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool7ool000Co
oooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool5o`00o`Oo
ogl04?ooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o00Gooooo1_ooO`05ooooo`Goo`001_l0o`06o`00o`_ooooo1Ooo0006o`3o00Go003o
1oooO`04ooooo`Koo`001Ol0o`07o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool6ool000Go0?l0
1ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Ooogl0
1?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool7ool000Cooooo
1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKooooo
1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`05ooooo`Koogl01Oooool5ool000Ko0?l01_l00?l;ooooo`Goo`001_l0o`05o`00o`Ooogl01?oo
ool6ool000Go0?l01ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1_oo0005o`3o00Oo003o2_oo
ool5ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo1_oo
0006o`3o00Ko003o2_ooool6ool000Go0?l01_l00?l6oomo00Gooooo1ooo0004ooooo`Oo003o3ooo
ool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o2oooool6ool000Gooooo1_l00?lFooooo`Ko003o2_oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6
oomo00Gooooo1Ooo0006o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005
o`3o00Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Koo`001Ol0o`07o`00o`[ooooo1Ooo0006
o`3o00Ko003o1_ooO`0@ooooo`Ko003o4?ooool6o`3o00Go003o1oooO`04ooooo`Koo`001_l0o`06
o`00o`[ooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Ooo`001?ooool7o`00o`oooooo1_l0o`06
o`00o`Koogl04?ooool6o`00o`_ooooo1_oo0005ooooo`Ko003o5_ooool6o`00o`[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`05oooo
o`Goo`001_l0o`06o`00o`_ooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?ooool7o`00
oa3ooooo1_l0o`05ooooo`Koogl01Oooool6ool000Go0?l01ol00?l:ooooo`Goo`001_l0o`06o`00
o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Ooogl01?ooool6ool000Ko0?l01_l00?l:oooo
o`Koo`001Ol0o`06o`00o`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo
013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKooooo1_l00?l:ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`?o00002?ooool7o`3o00Gooooo1_ooO`05ooooo`Goo`001_l0o`06o`00o`_o
oooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Ko
ogl01Oooool6ool000Go0?l01ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3o
oooo1_l0o`05o`00o`Ooogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`06o`00o`Ko
ogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Ko
o`001Oooool6o`00oaKooooo1_l00?l9ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o00Gooooo1_ooO`0:ooooo`Ko0?l01_l00?l;ooooo`Goo`001_l0o`05o`00o`Ooogl0
1?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1_oo0005o`3o00Oo003o
2_ooool5ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo
1_oo0006o`3o00Ko003o2_ooool6ool000Go0?l01_l00?l6oomo00Gooooo1ooo0004ooooo`Oo003o
3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o2oooool6ool000Gooooo1_l00?lFooooo`Ko003o
2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Ooo
ool6oomo00[ooooo1_l0o`06o`00o`_ooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?oo
ool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool6ool000Go0?l01ol00?l:ooooo`Goo`001_l0
o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Ooogl01?ooool6ool000Ko0?l01_l0
0?l:ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko0?l01_l0
0?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKooooo1_l00?l:ooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl02_ooool6
o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1ooo0004ooooo`Oo003o4?ooool6
o`3o00Gooooo1_ooO`05ooooo`Koo`001Ol0o`07o`00o`[ooooo1Ooo0006o`3o00Ko003o1_ooO`0@
ooooo`Ko003o4?ooool6o`3o00Go003o1oooO`04ooooo`Koo`001_l0o`06o`00o`[ooooo1_oo0005
o`3o00Ko003o1_ooO`05ooooo`Ooo`001?ooool7o`00o`oooooo1_l0o`06o`00o`Koogl04?ooool6
o`00o`_ooooo1_oo0005ooooo`Ko003o5_ooool6o`00o`[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0:ooooo`Ko0?l01_l00?l;oooo
o`Goo`001_l0o`05o`00o`Ooogl01?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo
00Gooooo1_oo0005o`3o00Oo003o2_ooool5ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l@oooo
o`Ko0?l01Ol00?l7oomo00Cooooo1_oo0006o`3o00Ko003o2_ooool6ool000Go0?l01_l00?l6oomo
00Gooooo1ooo0004ooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o2oooool6ool0
00Gooooo1_l00?lFooooo`Ko003o2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l01Oooool6oomo00[ooooo1_l0o`06o`00o`_ooooo1Ooo0006o`3o00Go
003o1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool6ool000Go
0?l01ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Oo
ogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool7ool000Co
oooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKo
oooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo
1ol0o`05ooooo`Koogl02_ooool6o`3o00Ko003o2oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo
1ooo0004ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Koo`001Ol0o`07o`00o`[ooooo
1Ooo0006o`3o00Ko003o1_ooO`0@ooooo`Ko003o4?ooool6o`3o00Go003o1oooO`04ooooo`Koo`00
1_l0o`06o`00o`[ooooo1_oo0005o`3o00Ko003o1_ooO`0@ooooo`Oo003o3oooool6o`3o00Ko003o
1_ooO`0@ooooo`Ko003o2oooool6ool000Gooooo1_l00?lFooooo`Ko003o2_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo00[ooooo1_l0
o`06o`00o`_ooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0
o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?oo
ool6o`00oa3ooooo1_l0o`05o`00o`Ooogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0
o`06o`00o`Koogl04?ooool7o`00o`oooooo1_l0o`06o`00o`Koogl04?ooool6o`00o`_ooooo1_oo
0005ooooo`Ko003o5_ooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00008
ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l;ooooo`Goo`001_l0o`05o`00o`Ooogl01?ooool7
ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o2_ooool5
ool000Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo1_oo0006
o`3o00Ko003o2_ooool6ool000Go0?l01ol00?lEooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@
ooooo`Ko003o2oooool6ool000Gooooo1_l00?lFooooo`Ko003o2Oooool2o`0000[ooooo000Voooo
o`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00o`_ooooo1Ooo0006o`3o
00Go003o1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool0
00Cooooo1ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00
o`Ooogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`07o`00oaGooooo1ol00?l?oooo
o`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKooooo1_l00?l:oooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Ko
ogl04?ooool6o`00o`_ooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?ooool7o`00oa3o
oooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l:ooooo`Goo`001_l0o`06o`00o`Ko
ogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Ooogl01?ooool6ool000Ko0?l01_l00?l:ooooo`Ko
o`001Ol0o`07o`00oaGooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;ooooo`Ko
o`001Oooool6o`00oaKooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00o`_ooooo1Ooo0006o`3o00Go003o
1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo
1ol00?l:ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1_l0o`05o`00o`Ooogl0
1?ooool6ool000Ko0?l01_l00?l:ooooo`Koo`001Ol0o`07o`00oaGooooo1ol00?l?ooooo`Ko0?l0
1_l00?l6oomo013ooooo1_l00?l;ooooo`Koo`001Oooool6o`00oaKooooo1_l00?l:ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?oo
ool6o`00oa3ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Ooo
ool6oomo00Gooooo1ooo0004ooooo`Oo003o2_ooool5ool000Ko0?l01_l00?l6oomo013ooooo1_l0
0?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool6ool000Go0?l01ol0
0?lEooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o2oooool6ool000Gooooo1_l0
0?lFooooo`Ko003o2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08
ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo0004
ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`001?ooool7o`00o`oooooo1_l0o`06
o`00o`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:
ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l;
ooooo`Koo`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04oooo
o`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?oooo
o`Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005oooo
o`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@oooo
o`Ko003o2oooool6ool0027ooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o
00002?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Oo
o`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko
0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko
003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko
003o2oooool6ool0027ooooo1_l00?l9ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`00
1?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko0?l0
1_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o
2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o
2oooool6ool0027ooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?oo
ool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o3ooo
ool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Ooo
ool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00o`oooooo1_l0o`06o`00o`Koogl04?oo
ool6o`00o`_ooooo1_oo000Qooooo`Ko003o2_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7
oomo00Cooooo1ooo0004ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`001?ooool7
o`00o`oooooo1_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7
ool000Gooooo1_l00?l:ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?lEooooo`Ko003o1_ooO`0@
ooooo`Ko003o2oooool6ool0027ooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04oooo
o`Ooogl01?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004oooo
o`Oo003o3oooool6o`3o00Ko003o1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04oooo
o`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oaGooooo1_l00?l6oomo
013ooooo1_l00?l;ooooo`Koo`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool000_o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001oooool00ol0003o
ooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Co
oooo1ooo0004ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`001?ooool7o`00o`oo
oooo1_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Go
oooo1_l00?l:ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?lEooooo`Ko003o1_ooO`0@ooooo`Ko
003o2oooool6ool0027ooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7
o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7
ool000Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7
oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6
oomo013ooooo1_l00?l;ooooo`Koo`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool0
00[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?oo
ool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Ooo
ool7ool000Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?oo
ool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6ooo
ool6oomo013ooooo1_l00?l;ooooo`Koo`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?oo
ool000[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00Cooooo1?l00007ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Oo0?l0
1?ooool7oomo00Cooooo1ooo0004ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`00
1?ooool7o`00o`oooooo1_l0o`06o`00o`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl0
1?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?lKooooo`Koogl0
4?ooool6o`00o`_ooooo1_oo000Qooooo`Ko003o1oooool4o`0000[ooooo000:ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Oooooo00?o0000oooooooo
ool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Oo
o`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko
0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko
003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Ko
o`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000[ooooo00?o0000ooooooooool02?ooool7
o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7
o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6
oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7
ool000Cooooo1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`008Oooool6
o`00o`[ooooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:ooooo`;o00000_ooool5o`00
00Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o
00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool0
00Cooooo1ol00?l?ooooo`Ko0?l01_l00?l6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo
00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6oomo
013ooooo1_l00?l;ooooo`Koo`008Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Co
oooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Co
oooo1ol00?l?ooooo`Ko0?l01ol00?lEooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Oo
o`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@ooooo`Ko
003o2oooool6ool0027ooooo1_l00?l:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl0
1?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o
3oooool7o`3o01_ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o
2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00
8Oooool6o`00o`[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?oo
ool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?oo
ool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?ooooo`Oo0?l06ooo
ool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`001?oo
ool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo1_oo000Qooooo`Ko003o2_oo
ool00ol0003oooooooooo`08ooooo`009_ooool3o`0000Sooooo1ol0o`05ooooo`Koogl04?ooool6
o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6
oomo00Gooooo1ooo0004ooooo`Oo003o3oooool7o`3o01_ooooo1_l00?l@ooooo`Oo0?l01?ooool7
oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6
oomo013ooooo1_l00?l;ooooo`Koo`00<?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool0
00Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o3oooool7o`3o
01_ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool0
00Cooooo1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo013o
oooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0004ooooo`Oo003o4?ooool6o`3o00Go
oooo1_ooO`05ooooo`Ooo`001?ooool7o`00o`oooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Co
oooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_o
oooo1_ooO`0@ooooo`Ko003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo
1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo
1ol00?l?ooooo`Oo0?l06oooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo
1_l00?l:ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo
1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Cooooo1ol0
0?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o3oooool7o`3o01_ooooo1_l0
0?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol0
0?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@
ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0004ooooo`Oo003o4?ooool6o`3o00Gooooo1_ooO`05
ooooo`Ooo`001?ooool7o`00o`oooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04
ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@
ooooo`Ko003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04oooo
o`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool000Cooooo1ol00?l?oooo
o`Oo0?l06oooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:oooo
o`Ooo`001?ooool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo1_oo000aoooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Ko
ogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Cooooo1ol00?l@ooooo`Ko
0?l01Oooool6oomo00Gooooo1ooo0004ooooo`Oo003o3oooool7o`3o01_ooooo1_l00?l@ooooo`Oo
0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo
003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`00
9_ooool3o`0000Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl0
1?ooool7ool000Cooooo1ol00?l@ooooo`Ko0?l01Oooool6oomo00Gooooo1ooo000Jooooo`Oo0?l0
6oooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`00
1?ooool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo1_oo000`ooooo`;o0000
2_ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?oo
ool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Ooo
ool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Ooo
ool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@ooooo`Ko003o2ooo
ool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7
o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7
o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7
o`3o00Cooooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7
o`00oa_ooooo1_ooO`0@ooooo`Ko003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o
00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3ooooo1_l0o`05ooooo`Koogl01Oooool7ool0
01[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Oooool6o`00
o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@ooooo`Ko003o2oooool6ool0
037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Go
oooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa3o
oooo1_l0o`05ooooo`Koogl01Oooool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Co
oooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_o
oooo1_ooO`0@ooooo`Ko003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo
1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`006_ooool7o`3o01_ooooo
1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo
1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l0
0?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo
000Jooooo`Oo0?l06oooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l0
0?l:ooooo`Ooo`001?ooool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo1_oo
000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7o`3o00Gooooo1_ooO`0@
ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05
ooooo`Ooo`006_ooool7o`3o01_ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo1ooo0005
ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo003o6oooool6oomo013ooooo1_l00?l;
ooooo`Koo`00<?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05oooo
o`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool001_ooooo1_l0o`05oooo
o`Koogl01Oooool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04oooo
o`Ooo`001Oooool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@oooo
o`Ko003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool02?ooool7o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Oo
o`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`006_ooool7o`3o01_ooooo1_l00?l@ooooo`Oo
0?l01?ooool7oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool000Cooooo1ol00?lEooooo`Oo
003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Oo0?l0
1?ooool7oomo00Cooooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo000Jooooo`Oo0?l0
6oooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`00
1?ooool7o`00oaGooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo1_oo000aooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl04?oo
ool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool001_ooooo1_l0o`05ooooo`Koogl01Ooo
ool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Ooo
ool6o`00o`[ooooo1ooo0004ooooo`Oo003o5Oooool7o`00oa_ooooo1_ooO`0@ooooo`Ko003o2ooo
ool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7
o`3o00Gooooo1_ooO`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6
o`3o00Gooooo1_ooO`05ooooo`Ooo`006_ooool7o`3o01_ooooo1_l00?l@ooooo`Oo0?l01?ooool7
oomo00Cooooo1ooo0005ooooo`Ko003o2_ooool7ool0023ooooo1ol00?lKooooo`Koogl04?ooool6
o`00o`_ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00Sooooo1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool0
01_ooooo1_l0o`05ooooo`Koogl01Oooool7ool001[ooooo1ol0o`0Kooooo`Ko003o4?ooool7o`3o
00Cooooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo000Pooooo`Oo003o6oooool6oomo
013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l01Oooool6oomo013ooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Co
oooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo000looooo`Ko003o4?ooool7o`3o00Co
oooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo000Pooooo`Oo003o6oooool6oomo013o
oooo1_l00?l;ooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000Sooooo
1ol0o`05ooooo`Koogl04?ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool001_ooooo
1_l0o`05ooooo`Koogl01Oooool7ool003cooooo1_l00?l@ooooo`Oo0?l01?ooool7oomo00Cooooo
1ooo0005ooooo`Ko003o2_ooool7ool0023ooooo1ol00?lKooooo`Koogl04?ooool6o`00o`_ooooo
1_oo000`ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_oo
O`0@ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_oo
O`05ooooo`Ooo`00??ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l0
0?l:ooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0@ooooo`Ko003o2oooool6ool0037ooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0@
ooooo`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05
ooooo`Ooo`00??ooool6o`00oa3ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:
ooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0@ooooo`Ko003o2oooool6ool0037ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0Voooo
o`Oo0?l01?ooool7oomo00Cooooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo000loooo
o`Ko003o4?ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo000Poooo
o`Oo003o6oooool6oomo013ooooo1_l00?l;ooooo`Koo`00<Oooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo02Kooooo1ol0o`04ooooo`Oo
ogl01?ooool7ool001_ooooo1_l0o`05ooooo`Koogl01Oooool7ool005;ooooo1ol0o`04ooooo`Oo
ogl01?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0@ooooo`Ko
003o2oooool6ool0037ooooo00?o0000ooooooooool02?ooool0017ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl0
9_ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`00
D_ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`001Oooool6o`00o`[ooooo1ooo000Pooooo`Oo003o
6oooool6oomo027ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Oo0?l0
1Oooool6oomo02Kooooo1ol0o`04ooooo`Ooogl01?ooool7ool001_ooooo1_l0o`05ooooo`Koogl0
1Oooool7ool005;ooooo1ol0o`04ooooo`Ooogl01?ooool7ool000Gooooo1_l00?l:ooooo`Ooo`00
8?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`004?oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool7o`3o00Gooooo1_ooO`0Vooooo`Oo0?l01?ooool7oomo00Cooooo1ooo000Kooooo`Ko0?l0
1Oooool6oomo00Gooooo1ooo001Booooo`Oo0?l01?ooool7oomo00Cooooo1ooo000Eooooo`Ooo`00
8?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`004?oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l00007ooooo`Oo0?l0
1Oooool6oomo02Kooooo1ol0o`04ooooo`Ooogl01?ooool7ool001_ooooo1_l0o`05ooooo`Koogl0
1Oooool7ool005;ooooo1ol0o`04ooooo`Ooogl01?ooool7ool001Gooooo1ooo000Pooooo`Oo003o
6oooool6oomo027ooooo1_oo000^ooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol0o`05ooooo`Koogl0
9_ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`00
D_ooool7o`3o00Cooooo1oooO`04ooooo`Ooo`005Oooool7ool0023ooooo1ol00?lKooooo`Koogl0
8Oooool6ool0037ooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo0000
2?ooool2o`0000Sooooo00?o0000ooooooooool02?ooool7o`3o00Gooooo1_ooO`0Vooooo`Oo0?l0
1?ooool7oomo00Cooooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo001Booooo`Oo0?l0
1?ooool7oomo00Cooooo1ooo000Eooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00
<Oooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo0?l01Oooool6oomo02Kooooo1ol0o`04ooooo`Ooogl01?oo
ool7ool001_ooooo1_l0o`05ooooo`Koogl01Oooool7ool005;ooooo1ol0o`04ooooo`Ooogl01?oo
ool7ool001Gooooo1ooo000Pooooo`Oo003o6oooool6oomo027ooooo1_oo000aooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`0aooooo`Oo0?l01?ooool7
oomo00Cooooo1ooo000Kooooo`Ko0?l01Oooool6oomo00Gooooo1ooo001Booooo`Oo0?l01?ooool7
oomo00Cooooo1ooo000Eooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00<Oooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0<Oooool7o`3o
00Cooooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`00GOooool7oomo
00Cooooo1ooo000Eooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0<Oooool7o`3o00Co
oooo1oooO`04ooooo`Ooo`006oooool6o`3o00Gooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Co
oooo1ooo000Eooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003o
ooooooooo`08ooooo`009_ooool3o`0000Sooooo1ol0o`0aooooo`Oo0?l03oooool7ool002Kooooo
1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`008?ooool7o`00oa_ooooo
1_ooO`0Qooooo`Koo`00<?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`0aooooo`Oo0?l03oooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo
000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00Sooooo1ol0o`0aooooo`Oo0?l03oooool7ool002Kooooo1_ooO`05
ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000a
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`0aoooo
o`Oo0?l03oooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eoooo
o`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00Sooooo1ol0o`0aooooo`Oo0?l03oooool7ool002Kooooo1_ooO`05ooooo`Oo
o`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`0aooooo`Oo0?l0
3oooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00
@_ooool6oomo027ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00Sooooo1ol0o`0aooooo`Oo0?l03oooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOoo
ool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`0aooooo`Oo0?l03oooool7
ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6
oomo027ooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7o`3o
037ooooo1ol0o`0?ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool0
01Gooooo1ooo0012ooooo`Koogl08Oooool6ool0033ooooo0_l0000:ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l0<Oooool7o`3o00oooooo1ooo000Vooooo`Koogl01Oooool7ool005go
oooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0<Oooool7o`3o00oooooo
1ooo000Vooooo`Koogl01Oooool7ool005gooooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo
1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`08ooooo`Oo0?l0<Oooool7o`3o00oooooo1ooo000Vooooo`Koogl01Oooool7ool005gooooo1ooo
O`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0<Oooool7o`3o00oooooo1ooo000V
ooooo`Koogl01Oooool7ool005gooooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Q
ooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08oooo
o`Oo0?l0<Oooool7o`3o00oooooo1ooo000Vooooo`Koogl01Oooool7ool005gooooo1oooO`04oooo
o`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0<Oooool7o`3o00oooooo1ooo000Vooooo`Ko
ogl01Oooool7ool005gooooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Ko
o`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000Sooooo1ol0o`0aooooo`Oo0?l0
3oooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00
@_ooool6oomo027ooooo1_oo000`ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool02?oo
ool7o`3o037ooooo1ol0o`0?ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?oo
ool7ool001Gooooo1ooo0012ooooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o037ooooo1ol0o`0?ooooo`Ooo`009_ooool6
oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool001Gooooo1ooo0012ooooo`Koogl08Oooool6
ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o
037ooooo1ol0o`0?ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool0
01Gooooo1ooo0012ooooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool02?ooool7o`3o04Oooooo1ooo000Vooooo`Koogl01Oooool7ool005go
oooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0Aoooool7ool002Kooooo
1_ooO`05ooooo`Ooo`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo
1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`17ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool001Gooooo1ooo
0012ooooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool02?ooool7o`3o04Oooooo1ooo000Vooooo`Koogl01Oooool7ool005gooooo1oooO`04
ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08
ooooo`009_ooool3o`0000Sooooo1ol0o`17ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Moooo
o`Ooogl01?ooool7ool001Gooooo1ooo0012ooooo`Koogl08Oooool6ool0033ooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0Aoooool7ool002Kooooo1_ooO`05ooooo`Oo
o`00GOooool7oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`17ooooo`Ooo`00
9_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool001Gooooo1ooo0012ooooo`Koogl0
8Oooool6ool0037ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?oo
ool7o`3o04Oooooo1ooo000Vooooo`Koogl01Oooool7ool005gooooo1oooO`04ooooo`Ooo`005Ooo
ool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`08ooooo`Oo0?l0Aoooool7ool002Kooooo1_ooO`05ooooo`Ooo`00GOooool7
oomo00Cooooo1ooo000Eooooo`Ooo`00@_ooool6oomo027ooooo1_oo000aooooo`03o`000?oooooo
oooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`00
00Oooooo00?o0000ooooooooool02?ooool7o`3o04Oooooo1ooo000Vooooo`Koogl01Oooool7ool0
05gooooo1oooO`04ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0
003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1ol0o`17
ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?ooool7ool001Gooooo1ooo0012
ooooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool7o`3o04Oooooo1ooo000Vooooo`Koogl01Oooool7ool005gooooo1oooO`04
ooooo`Ooo`005Oooool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08
ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool4o`0000Oooooo1ol0o`17ooooo`Ooo`009_ooool6oomo00Gooooo1ooo001M
ooooo`Ooogl01?ooool7ool001Gooooo1ooo0012ooooo`Koogl08Oooool6ool002kooooo1?l0000:
ooooo`002_ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooooooo`Co00001ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl01?oo
ool7ool001Gooooo1ooo0012ooooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02?oo
ool000[ooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl08?oo
ool7ool004;ooooo1_ooO`0Qooooo`Koo`00<Oooool00ol0003oooooooooo`08ooooo`002oooool2
o`0000[ooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`0Pooooo`Ooo`00@_ooool6oomo027ooooo1_oo
000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1d
ooooo`Koogl01Oooool7ool005gooooo1oooO`0Pooooo`Ooo`00JOooool6ool0037ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`05oooo
o`Ooo`00GOooool7oomo023ooooo1ooo001Yooooo`Koo`00<Oooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Oo
ogl08?ooool7ool006Wooooo1_oo000aooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o0000
2?ooool7o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo023ooooo1ooo002Oooooo`;o0000
2_ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOoo
ool7oomo023ooooo1ooo002Pooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`0Pooooo`Ooo`00X?ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo
00Gooooo1ooo001Mooooo`Ooogl08?ooool7ool00:3ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo023o
oooo1ooo002Pooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo
1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`0Pooooo`Ooo`00X?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo
001Mooooo`Ooogl08?ooool7ool00:3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool02?ooool7o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo023ooooo1ooo002P
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7o`3o07Cooooo1_ooO`05oooo
o`Ooo`00GOooool7oomo023ooooo1ooo002Oooooo`;o00002_ooool002Kooooo00?o0000oooooooo
ool02?ooool7o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo023ooooo1ooo002Pooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
1Oooool7ool005gooooo1oooO`0Pooooo`Ooo`00X?ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl08?oo
ool7ool00:3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7
o`3o07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo023ooooo1ooo002Pooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool0
05gooooo1oooO`0Pooooo`Ooo`00X?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl08?ooool7ool00:3o
oooo00?o0000ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l0M?ooool6oomo00Gooooo
1ooo001Mooooo`Ooogl0a_ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`37
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1doooo
o`Koogl01Oooool7ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`37ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
1Oooool7ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`37ooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7
ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7o`3o
07Cooooo1_ooO`05ooooo`Ooo`00GOooool7oomo0<Kooooo0_l0000:ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl0aoooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo
1ooo001Mooooo`Ooogl0aoooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl0aoooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001M
ooooo`Ooogl0aoooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7
ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?oo
ool6oomo00Gooooo1ooo001Mooooo`Ooogl0aoooool00ol0003oooooooooo`08ooooo`004?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l00007ooooo`Oo0?l0M?oo
ool6oomo00Gooooo1ooo001Mooooo`Ooogl0a?ooool4o`0000[ooooo000@ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`Oo0?l0M?oo
ool6oomo00Gooooo1ooo001Mooooo`Ooogl0aoooool00ol0003oooooooooo`08ooooo`004?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Ooogl0aoooool00ol0003ooooo
ooooo`08ooooo`004?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo001Mooooo`Oo
ogl0aoooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool005gooooo1oooO`37ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl01Ooo
ool7ool005gooooo1oooO`37ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00Sooooo1ol0o`1dooooo`Koogl01Oooool7ool00?oooooo;?ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo00Gooooo1ooo003ooooo
obcooooo00?o0000ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l0M?ooool6oomo0?oo
oooo=oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7
o`3o07Cooooo1_ooO`3oooooocOooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`08oooo
o`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo0?oooooo>?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6
oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08oooo
o`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000So
oooo1ol0o`1dooooo`Koogl0oooooolgooooo`;o00002_ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3ooooo
ocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Co
oooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?oo
ool002Kooooo0ol00008ooooo`Oo0?l0M?ooool6oomo0?oooooo=oooool2o`0000[ooooo000Voooo
o`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool0
1?l0003oooooooooooooool5o`0000;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo1?l00007ooooo`Oo0?l0M?ooool6oomo0?oooooo=Oooool4o`0000[o
oooo000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03
o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000oooooooo
ooooooooo`000?ooool4o`0000Oooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3o
ooooocSooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool0
1ol0003ooooooooooooooooo0000ooooool000002_ooool00ol0003oooooooooo`08ooooo`Oo0?l0
M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo0ol0
0002ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6oomo0?oooooo>?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0M?ooool6
oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08oooo
o`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`08ooooo`Oo0?l0M?ooool6oomo0?oooooo>?ooool00ol0003oooooooooo`08ooooo`00
9_ooool3o`0000Sooooo1ol0o`1dooooo`Koogl0oooooolgooooo`;o00002_ooool002Kooooo00?o
0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3ooooo
ocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Co
oooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
2?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o07Cooooo1_ooO`3oooooocSooooo00?o0000
ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l0M?ooool6oomo0?oooooo=oooool2o`00
00[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0
oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0
o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`1dooooo`Koogl0oooooolhooooo`03
o`000?oooooooooo00Sooooo000Vooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000[ooooo
000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000
ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00002_ooool002Ko
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08
ooooo`004Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000oooo
ooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool01?ooool4o`0000Oooooo1ol0o`3oooooojoooooo1?l0000:
ooooo`004?ooool01?l0003oooooooooool00009ooooo`;o00001oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02?ooool0017ooooo0_l00009ooooo`?o00001oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00002?oo
ool7o`3o0?oooooo/Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo
0?l0oooooonaooooo`;o00002_ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00008ooooo`Oo0?l0oooo
oonaooooo`;o00002_ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000Sooooo1ol0o`3ooooook7o
oooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00000oooool3o`0000Oooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003o
ooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooooooooooo
ool0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool7
o`3o0?oooooo/_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool4o`0000Oooooo1ol0o`3o
ooooojoooooo1?l0000:ooooo`002_ooool01?l0003oooooooooool00009ooooo`;o00001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`08
ooooo`002_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o00001oooool0
0ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00009ooooo`?o00000_oo
ool5o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool002Koooooool00035o`0000[ooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo000eooooo`?o00006?ooool5o`0001Sooooo0ol0000Iooooo`?o00006?ooool3
o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Sooooo0ol0000Iooooo`;o00005oooool3
o`0000Cooooo0_l0000Booooo`?o00000oooool3o`0001?ooooo0ol00002ooooo`Go00004_ooool3
o`0000?ooooo0ol0000Cooooo`?o00001?ooool3o`0001;ooooo0ol00003ooooo`?o00004oooool3
o`0000?ooooo0ol0000Gooooo`00=_ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0001Oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo01Kooooo00Go
0000ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000006Oooool00ol0003o
ooooooooo`0Gooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000Cooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool05?ooool003Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Cooooo1Ol0000Kooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooo
ooooooooo`00000Jooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000K
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Co
oooo000fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool2o`0001Oooooo
00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Eooooo`Co00006oooool00ol0003o
ooooooooo`0Gooooo`?o00006Oooool4o`0001Kooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool2o`00
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooooooo`Co00005ooo
ool003Kooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001_ooooo00?o
0000ooooooooool05Oooool00ol0003oooooo`00000Hooooo`Co00006?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Cooooo00Co0000
oooooooooooooooo1?l0000Dooooo`05o`000?ooooooooooooooool000006_ooool003Gooooo0_l0
000Iooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo000001So
oooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oooooo
ooooooooool000005Oooool2o`0000Cooooo00Co0000oooooooooooo00004Oooool2o`0000Cooooo
0_l0000Dooooo`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000004_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool00ol0
003oooooooooo`0Dooooo`;o00001?ooool00ol0003oooooooooo`0Gooooo`00=_ooool00ol0003o
ooooooooo`0Hooooo`?o00006Oooool3o`0001[ooooo00?o0000ooooooooool05_ooool5o`0001Wo
oooo0_l0000Hooooo`Go00006?ooool3o`0001Wooooo0ol0000Gooooo`03o`000?oooooooooo00?o
oooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`?o00005?ooool00ol0003oooooooooo`02ooooo`?o00005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo1Ol0000Coooo
o`03o`000?oooooooooo00?ooooo0_l0000Gooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.692436, -0.0280471, \
0.0359213, 0.00131831}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 1.42718 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15743 -18 -4.5 ]
[-0.0125 .15743 0 4.5 ]
[-0.0125 .30015 -18 -4.5 ]
[-0.0125 .30015 0 4.5 ]
[-0.0125 .44287 -18 -4.5 ]
[-0.0125 .44287 0 4.5 ]
[-0.0125 .58559 -18 -4.5 ]
[-0.0125 .58559 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15743 m
.00625 .15743 L
s
[(0.1)] -0.0125 .15743 1 0 Mshowa
0 .30015 m
.00625 .30015 L
s
[(0.2)] -0.0125 .30015 1 0 Mshowa
0 .44287 m
.00625 .44287 L
s
[(0.3)] -0.0125 .44287 1 0 Mshowa
0 .58559 m
.00625 .58559 L
s
[(0.4)] -0.0125 .58559 1 0 Mshowa
.125 Mabswid
0 .04326 m
.00375 .04326 L
s
0 .0718 m
.00375 .0718 L
s
0 .10035 m
.00375 .10035 L
s
0 .12889 m
.00375 .12889 L
s
0 .18598 m
.00375 .18598 L
s
0 .21452 m
.00375 .21452 L
s
0 .24306 m
.00375 .24306 L
s
0 .27161 m
.00375 .27161 L
s
0 .32869 m
.00375 .32869 L
s
0 .35724 m
.00375 .35724 L
s
0 .38578 m
.00375 .38578 L
s
0 .41432 m
.00375 .41432 L
s
0 .47141 m
.00375 .47141 L
s
0 .49996 m
.00375 .49996 L
s
0 .5285 m
.00375 .5285 L
s
0 .55704 m
.00375 .55704 L
s
0 .61413 m
.00375 .61413 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15743 m
1 .15743 L
s
.99375 .30015 m
1 .30015 L
s
.99375 .44287 m
1 .44287 L
s
.99375 .58559 m
1 .58559 L
s
.125 Mabswid
.99625 .04326 m
1 .04326 L
s
.99625 .0718 m
1 .0718 L
s
.99625 .10035 m
1 .10035 L
s
.99625 .12889 m
1 .12889 L
s
.99625 .18598 m
1 .18598 L
s
.99625 .21452 m
1 .21452 L
s
.99625 .24306 m
1 .24306 L
s
.99625 .27161 m
1 .27161 L
s
.99625 .32869 m
1 .32869 L
s
.99625 .35724 m
1 .35724 L
s
.99625 .38578 m
1 .38578 L
s
.99625 .41432 m
1 .41432 L
s
.99625 .47141 m
1 .47141 L
s
.99625 .49996 m
1 .49996 L
s
.99625 .5285 m
1 .5285 L
s
.99625 .55704 m
1 .55704 L
s
.99625 .61413 m
1 .61413 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .12392 L
.08642 .12392 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .12392 L
.08642 .12392 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .02073 L
.14815 .02073 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .02073 L
.14815 .02073 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .13093 L
.20988 .13093 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .13093 L
.20988 .13093 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .01572 L
.2716 .01572 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .01572 L
.2716 .01572 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .15047 L
.33333 .15047 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .15047 L
.33333 .15047 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .13344 L
.39506 .13344 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .13344 L
.39506 .13344 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .1665 L
.45679 .1665 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .1665 L
.45679 .1665 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .02073 L
.51852 .02073 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .02073 L
.51852 .02073 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .19004 L
.58025 .19004 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .19004 L
.58025 .19004 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .04978 L
.64198 .04978 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .04978 L
.64198 .04978 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .15197 L
.7037 .15197 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .15197 L
.7037 .15197 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .03776 L
.76543 .03776 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .03776 L
.76543 .03776 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .15097 L
.82716 .15097 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .15097 L
.82716 .15097 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .15448 L
.88889 .15448 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .15448 L
.88889 .15448 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .15047 L
.95062 .15047 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .15047 L
.95062 .15047 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .57827 L
.03704 .57827 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .57827 L
.03704 .57827 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .03075 L
.09877 .03075 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .03075 L
.09877 .03075 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .21509 L
.16049 .21509 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .21509 L
.16049 .21509 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .01822 L
.22222 .01822 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .01822 L
.22222 .01822 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .11891 L
.28395 .11891 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .11891 L
.28395 .11891 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .01722 L
.34568 .01722 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .01722 L
.34568 .01722 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .01822 L
.40741 .01822 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .01822 L
.40741 .01822 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .01672 L
.46914 .01672 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .01672 L
.46914 .01672 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .44402 L
.53086 .44402 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .44402 L
.53086 .44402 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .02273 L
.59259 .02273 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .02273 L
.59259 .02273 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .02924 L
.65432 .02924 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .02924 L
.65432 .02924 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .01572 L
.71605 .01572 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .01572 L
.71605 .01572 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .09236 L
.77778 .09236 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .09236 L
.77778 .09236 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .01572 L
.83951 .01572 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .01572 L
.83951 .01572 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .01472 L
.90123 .01472 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .01472 L
.90123 .01472 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .60332 L
.04938 .60332 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .60332 L
.04938 .60332 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .01572 L
.11111 .01572 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .01572 L
.11111 .01572 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .13745 L
.17284 .13745 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .13745 L
.17284 .13745 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .01472 L
.23457 .01472 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .01472 L
.23457 .01472 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .46756 L
.2963 .46756 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .46756 L
.2963 .46756 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .01522 L
.35802 .01522 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .01522 L
.35802 .01522 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .23413 L
.54321 .23413 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .23413 L
.54321 .23413 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .03676 L
.66667 .03676 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .03676 L
.66667 .03676 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .03475 L
.79012 .03475 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .03475 L
.79012 .03475 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .03425 L
.06173 .03425 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .03425 L
.06173 .03425 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .17251 L
.12346 .17251 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .17251 L
.12346 .17251 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .20908 L
.18519 .20908 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .20908 L
.18519 .20908 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .09837 L
.24691 .09837 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .09837 L
.24691 .09837 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .09787 L
.30864 .09787 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .09787 L
.30864 .09787 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .0623 L
.37037 .0623 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .0623 L
.37037 .0623 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .08936 L
.4321 .08936 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .08936 L
.4321 .08936 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .06781 L
.49383 .06781 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .06781 L
.49383 .06781 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .12642 L
.55556 .12642 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .12642 L
.55556 .12642 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .07783 L
.61728 .07783 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .07783 L
.61728 .07783 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .19906 L
.67901 .19906 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .19906 L
.67901 .19906 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .0588 L
.74074 .0588 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .0588 L
.74074 .0588 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .26218 L
.80247 .26218 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .26218 L
.80247 .26218 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .05028 L
.8642 .05028 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .05028 L
.8642 .05028 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .03225 L
.92593 .03225 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .03225 L
.92593 .03225 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .02423 L
.98765 .02423 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .02423 L
.98765 .02423 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oo
oooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`00<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001[ooooo000coooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001gooooo000booooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool003?ooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00006_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035
o`0000gooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`06o`00o`Koogl01Oooool5ool000Oo0?l01?ooool7oomo00Gooooo1Ooo
0006o`3o00Go003o1oooO`04ooooo`Koo`001_l0o`05ooooo`Ooogl02_ooool5o`3o00Ko003o1_oo
O`05ooooo`Koo`001_l0o`05ooooo`Koogl01Oooool5ool000Oo0?l01Oooool6oomo00Gooooo1Ooo
0007o`3o00Cooooo1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01?ooool6ool000Oo0?l01?oo
ool7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo
0006o`3o00Ko003o1_ooO`05ooooo`Koo`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?oo
ool7ool000[ooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001ol0
o`04ooooo`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_oo
ool5o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Ooo
ool6ool000[ooooo1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01?ooool6ool000Oo0?l01?oo
ool7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo
0006o`3o00Ko003o1_ooO`05ooooo`Koo`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?oo
ool7ool000[ooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01_l00?l6oomo00Gooooo1Ooo0007o`3o00Cooooo1oooO`0:
ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05
ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:
ooooo`Ko0?l01Ol00?l7oomo00Cooooo1_oo0007o`3o00Cooooo1oooO`04ooooo`Koo`001Ol0o`06
o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl01Oooool6
ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01_l00?l6oomo
00Gooooo1Ooo0007o`3o00Cooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;oooo
o`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl01?ooool6ool000Go0?l01_l00?l6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool5ool0
00Ko0?l01_l00?l6oomo00Gooooo1_oo000:ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04oooo
o`Ooo`002_ooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001ol0o`04ooooo`Ooogl02_ooool6o`3o00Go
003o1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool000[o
oooo1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go
003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`05ooooo`Oo
o`002_ooool6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`05ooooo`Koo`002_ooool7oomo00Go
oooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001ol0o`04ooooo`Ooogl0
2_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl0
1Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo1_oo000:ooooo`Ooogl0
2_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo1_oo0005o`3o00Ko003o
1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`05ooooo`Koo`00
2_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05ooooo`Goo`001ol0
o`04ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0
o`06o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo1_oo
000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo1ooo
0004ooooo`Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo0006o`3o00Ko003o1_oo
O`05ooooo`Koo`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Ko003o1_ooO`05
ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:
ooooo`Go0?l01_l00?l6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool6ool000_ooooo1_ooO`05
ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04
ooooo`Ooo`001?ooool6o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Goo`001_l0o`06
o`00o`Koogl01Oooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000E
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`06o`00
o`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;oooo
o`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool5ool0
00Ko0?l01_l00?l6oomo00Gooooo1_oo000:ooooo`Ooogl01Oooool6ool001Gooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[o
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00[o
oooo1Ol0o`06o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Go
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Co
oooo1ooo0004ooooo`Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1Ooo0007o`3o00Go
oooo1_ooO`05ooooo`Koo`002_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`00
2_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l0
1_l00?l6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool6ool000_ooooo1_ooO`05ooooo`Koo`00
2_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04ooooo`Ooo`00
2_ooool6oomo00Gooooo1ooo000:ooooo`Koogl02_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`00
2_ooool7oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0
o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo00Gooooo1ooo
000:ooooo`Koogl01Oooool6ool000_ooooo1_ooO`05ooooo`Koo`002_ooool7oomo00[ooooo1_l0
o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo
000:ooooo`Koogl02_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`002_ooool7oomo00Gooooo1_oo
000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6
oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`0:ooooo`Oo0?l01Oooool6
oomo00Gooooo1_oo000:ooooo`Ooogl01Oooool6ool001Gooooo1ooo000Dooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:oooo
o`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05oooo
o`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:oooo
o`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05oooo
o`Ooo`002_ooool6oomo00[ooooo1ol0o`05ooooo`Koogl01Oooool6ool000[ooooo1oooO`05oooo
o`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Co
oooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Go
oooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Co
oooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`002_ooool6oomo00[o
oooo1ol0o`05ooooo`Koogl01Oooool6ool000[ooooo1oooO`05ooooo`Koo`005Oooool7ool001Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl0
2_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl0
1Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl0
1?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`002_ooool6oomo00[ooooo1ol0o`05ooooo`Koogl0
1Oooool6ool000[ooooo1oooO`05ooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_oo
O`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl05Oooool6oomo00Gooooo1ooo
000:ooooo`Koogl02_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo
000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6
oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo01Gooooo1_ooO`05ooooo`Ooo`002_ooool6oomo00[ooooo1ol0o`05ooooo`Koogl01Oooool6
ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00
o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo00Gooooo1ooo000:oooo
o`Koogl01Oooool6ool000_ooooo1_ooO`05ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00
o`Ooogl01?ooool7ool000[ooooo1oooO`0Eooooo`Koogl01Oooool7ool000[ooooo1_ooO`0:oooo
o`Oo0?l01Oooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[o
oooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko
003o1_ooO`05ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[o
oooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl05Oooool6oomo00Go
oooo1ooo000:ooooo`Koogl02_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`005_ooool6ool001Go
oooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`00
2_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`00
2oooool6oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`00
2_ooool7oomo01Gooooo1_ooO`05ooooo`Ooo`006_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`00
5_ooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1ooo
O`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool001Gooooo1_oo
000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo
000:ooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Jooooo`Oo0?l01Oooool6oomo00Gooooo1_oo
000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7
oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`005Oooool6
ool000_ooooo1_ooO`05ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7
ool000[ooooo1oooO`0Eooooo`Koogl01Oooool7ool001[ooooo1ol0o`05ooooo`Koogl01Oooool6
ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00
o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo00Gooooo1ooo000Eoooo
o`Koo`002oooool6oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04oooo
o`Ooo`002_ooool7oomo01Gooooo1_ooO`05ooooo`Ooo`006_ooool7o`3o00Gooooo1_ooO`05oooo
o`Koo`005_ooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go
003o1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool001Go
oooo1_oo000;ooooo`Koogl01Oooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[o
oooo1oooO`0Eooooo`Koogl01Oooool7ool001[ooooo1ol0o`05ooooo`Koogl01Oooool6ool001Ko
oooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo
1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`00
2_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool001Gooooo1_oo000;ooooo`Koogl0
1Oooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0Eooooo`Koogl0
1Oooool7ool001[ooooo1ol0o`05ooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`00
5?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo
000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0
o`06o`00o`Koogl01Oooool7ool001Gooooo1_oo000;ooooo`Koogl01Oooool6ool001_ooooo1_l0
o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0Eooooo`Koogl01Oooool7ool001[ooooo1ol0
o`05ooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7
oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6
oomo00Gooooo1ooo000Eooooo`Koo`002oooool6oomo00Gooooo1_oo000Kooooo`Ko0?l01Ol00?l7
oomo00Cooooo1ooo000:ooooo`Ooogl05Oooool6oomo00Gooooo1ooo000Jooooo`Oo0?l01Oooool6
oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:oooo
o`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05oooo
o`Ooo`005Oooool6ool000_ooooo1_ooO`05ooooo`Koo`006oooool6o`3o00Go003o1oooO`04oooo
o`Ooo`009_ooool6oomo00Gooooo1ooo000Jooooo`Oo0?l01Oooool6oomo00Gooooo1_oo000Foooo
o`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Co
oooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`005Oooool6ool000_o
oooo1_ooO`05ooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Go
oooo1ooo000Jooooo`Oo0?l01Oooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl0
2_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`005Oooool6ool000_ooooo1_ooO`05ooooo`Koo`00
6oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Jooooo`Oo0?l0
1Oooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_oo
O`05ooooo`Ooo`005Oooool6ool000_ooooo1_ooO`05ooooo`Koo`006oooool6o`3o00Go003o1ooo
O`04ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Jooooo`Oo0?l01Oooool6oomo00Gooooo1_oo
000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7
oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`005Oooool6
ool000_ooooo1_ooO`05ooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6
oomo00Gooooo1ooo000Jooooo`Oo0?l01Oooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7
ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl02_ooool5o`3o00Ko003o1_ooO`05ooooo`Ooo`005Oooool6ool001Kooooo1_oo000Koooo
o`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Vooooo`Koogl01Oooool7ool001[ooooo1ol0o`05oooo
o`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[o
oooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo00Go
oooo1ooo000Eooooo`Koo`005_ooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool002Ko
oooo1_ooO`05ooooo`Ooo`006_ooool7o`3o00Gooooo1_ooO`05ooooo`Koo`005_ooool6ool001Go
oooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`00
2_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Oooool7ool001Gooooo1_oo000Fooooo`Koo`00
6oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl0
1Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0
o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01_l00?l6oomo00Gooooo1ooo
000Eooooo`Koo`005_ooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool002Kooooo1_oo
O`05ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o
0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7
oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01ol00?l:
ooooo`Ooo`005Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000V
ooooo`Koogl01Oooool7ool002Kooooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo000D
ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool0
00[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Kooooo`Go0?l01ol00?l:oooo
o`Ooo`005Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Voooo
o`Koogl01Oooool7ool002Kooooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[o
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`006oooool5o`3o00Oo
003o2_ooool7ool001Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Oo
o`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Oo
o`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool001_ooooo
1Ol0o`07o`00o`[ooooo1ooo000Eooooo`Koo`005_ooool6ool001_ooooo1_l0o`05o`00o`Ooogl0
1?ooool7ool002Kooooo1_ooO`05ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000Fooooo`Koo`00
5Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo
000Kooooo`Go0?l01ol00?l:ooooo`Ooo`005Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01Ol0
0?l7oomo00Cooooo1ooo000Vooooo`Koogl01Oooool7ool002Kooooo1_ooO`05ooooo`Koo`005_oo
ool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04
ooooo`Ooo`006oooool5o`3o00Oo003o2_ooool7ool001Gooooo1_oo000Fooooo`Koo`006oooool6
o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6
ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00
o`Ooogl01?ooool7ool001_ooooo1Ol0o`07o`00o`[ooooo1ooo000Eooooo`Koo`005_ooool6ool0
01_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool002Kooooo1_ooO`05ooooo`Ooo`009_ooool6oomo
00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`0:ooooo`Ko
0?l01Ol00?l7oomo00Cooooo1ooo000Kooooo`Go0?l01ol00?l:ooooo`Ooo`005Oooool6ool001Ko
oooo1_oo000Kooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Vooooo`Koogl01Oooool7ool002Ko
oooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl0
2_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`006oooool5o`3o00Oo003o2_ooool7ool001Gooooo
1_oo000Fooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Gooooo
1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_oo
ool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool001_ooooo1Ol0o`07o`00o`[ooooo1ooo
000Eooooo`Koo`005_ooool6ool001_ooooo1_l0o`05o`00o`Ooogl01?ooool7ool002Kooooo1_oo
O`05ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000Fooooo`Koo`005Oooool7ool001Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6
ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Pooooo`Oo003o2_ooool7
ool001Gooooo1_oo000Fooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6
oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:oooo
o`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?ooool7ool0023ooooo1ol00?l:oooo
o`Ooo`005Oooool6ool001Kooooo1_oo000Kooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Voooo
o`Koogl01Oooool7ool002Kooooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[o
oooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Pooooo`Oo003o2_ooool7ool001Go
oooo1_oo000Fooooo`Koo`006oooool6o`3o00Go003o1oooO`04ooooo`Ooo`009_ooool6oomo00Go
oooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003o
ooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07o`00oa[ooooo1oooO`0:ooooo`Ko0?l0
1Ol00?l7oomo00Cooooo1ooo000Pooooo`Oo003o2_ooool7ool001Gooooo1_oo000Fooooo`Koo`00
6oooool6o`3o00Ko003o2_ooool7ool002Kooooo1_ooO`05ooooo`Ooo`009_ooool6oomo00Gooooo
1_oo000Fooooo`Koo`005Oooool7ool001Cooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`008?oo
ool7o`00o`[ooooo1ooo000Eooooo`Koo`005_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo
000Vooooo`Koogl01Oooool7ool002Kooooo1_ooO`05ooooo`Koo`005_ooool6ool001Gooooo1ooo
000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oa[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo02_ooooo1ol00?l:ooooo`Ooo`005Oooool6
ool001Kooooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000V
ooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool6o`3o
00Go003o1oooO`0[ooooo`Oo003o2_ooool7ool0037ooooo1_oo000Kooooo`Ko0?l01_l00?l:oooo
o`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eoooo
o`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?lJooooo`Ooogl02_ooool6o`3o00Go003o1oooO`0[ooooo`Oo003o2_ooool7ool0037o
oooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Ko
ogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool7o`3o00Cooooo
1oooO`0[ooooo`Oo003o2_ooool7ool0037ooooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`00
9_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`00
5Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?lJooooo`Ooogl02_ooool7o`3o00Cooooo1oooO`0[ooooo`Oo003o2_ooool7ool0037ooooo1_oo
000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Ooo
ool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool7o`3o00Cooooo1oooO`0[
ooooo`Oo003o2_ooool7ool0037ooooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6
oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJoooo
o`Ooogl02_ooool7o`3o00Cooooo1oooO`0[ooooo`Oo003o2_ooool7ool0037ooooo1_oo000Koooo
o`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool0
01Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool7o`3o00Cooooo1oooO`0[ooooo`Oo
003o2_ooool7ool0037ooooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo00Go
oooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo1_oo000Eooooo`Ooo`005Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl0
2_ooool7o`3o00Cooooo1oooO`0[ooooo`Oo003o2_ooool7ool0037ooooo1_oo000Kooooo`Ko0?l0
1_l00?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl01Oooool6ool001Kooooo
1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_oo
ool7oomo00[ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00od;ooooo1_oo000Kooooo`Ko0?l01_l0
0?l:ooooo`Ooo`009_ooool6oomo00Gooooo1ooo000Vooooo`Koogl08Oooool6ool0037ooooo00?o
0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`0:ooooo`Oo0?l01?oo
ool7oomo02_ooooo1ol00?m2ooooo`Koo`006oooool6o`3o00Ko003o2_ooool7ool002Kooooo1_oo
O`0booooo`Koogl08Oooool6ool0037ooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00001oooool6o`3o00Oo003o6_oo
ool7oomo00[ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00od;ooooo1_oo000Kooooo`Ko0?l01_l0
0?l:ooooo`Ooo`009_ooool6oomo03;ooooo1_ooO`1Eooooo`Co00003Oooool000gooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00oa[ooooo1oooO`0:ooooo`Oo0?l01?ooool7oomo02_ooooo1ol00?m2ooooo`Koo`006ooo
ool6o`3o00Ko003o2_ooool7ool002Kooooo1_ooO`0booooo`Koogl0F?ooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00[ooooo1ol0o`04ooooo`Ooogl0:ooo
ool7o`00od;ooooo1_oo000Kooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo03;ooooo1_oo
O`1Hooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
0008ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`0:ooooo`Oo0?l01?oo
ool7oomo02_ooooo1ol00?m2ooooo`Koo`006oooool6o`3o00Ko003o2_ooool7ool002Kooooo1_oo
O`0booooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl02_ooool7
o`3o00Cooooo1oooO`0[ooooo`Oo003o@_ooool6ool001_ooooo1_l0o`06o`00o`[ooooo1ooo000V
ooooo`Koogl0<_ooool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o6_ooool7oomo00[ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00
of?ooooo1_l0o`06o`00o`[ooooo1ooo000Vooooo`Koogl0<_ooool6oomo05Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00[o
oooo1ol0o`04ooooo`Ooogl0:oooool7o`00of?ooooo1_l0o`06o`00o`[ooooo1ooo000Vooooo`Ko
ogl0<_ooool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003o6_ooool7oomo00[ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00of?ooooo
1_l0o`06o`00o`[ooooo1ooo000Vooooo`Koogl0<_ooool6oomo05Sooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o:oooool7o`3o00Cooooo1ooo
O`0[ooooo`Oo003oHoooool6o`3o00Ko003o2_ooool7ool002Kooooo1_ooO`0booooo`Koogl0F?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l[
ooooo`Oo0?l01?ooool7oomo02_ooooo1ol00?mSooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6
oomo03;ooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ob_ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00of?ooooo1_l0o`06o`00
o`[ooooo1ooo000Vooooo`Koogl0<_ooool6oomo05Sooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003o:oooool7o`3o00Cooooo1oooO`0[ooooo`Oo
003oHoooool6o`3o00Ko003o2_ooool7ool002Kooooo1_ooO`0booooo`Koogl0F?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l[ooooo`Oo0?l0
1?ooool7oomo02_ooooo1ol00?mSooooo`Ko0?l01_l00?l:ooooo`Ooo`009_ooool6oomo03;ooooo
1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003o:ooo
ool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003o2_ooool7ool002Kooooo1_oo
O`0booooo`Koogl0Eoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ob_ooooo1ol0o`04ooooo`Ooogl0:oooool7o`00of?ooooo1_l0o`06o`00o`[ooooo1ooo000V
ooooo`Koogl0<_ooool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o:oooool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o
00Ko003o2_ooool7ool002Kooooo1_ooO`0booooo`Koogl0F?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l[ooooo`Oo0?l01?ooool7oomo02_o
oooo1ol00?mSooooo`Ko0?l01_l00?lgooooo`Koogl0<_ooool6oomo05Sooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o:oooool7o`3o00Cooooo
1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003o=oooool6oomo03;ooooo1_ooO`1Hooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ob_ooooo1ol0
o`04ooooo`Ooogl0:oooool7o`00of?ooooo1_l0o`06o`00ocOooooo1_ooO`0booooo`Koogl0F?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l[
ooooo`Oo0?l01?ooool7oomo02_ooooo1ol00?mSooooo`Ko0?l01_l00?lgooooo`Koogl0<_ooool6
oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o:oooool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo
05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003o:oooool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo05So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
:oooool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo05Sooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o:ooo
ool7o`3o00Cooooo1oooO`0[ooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo05Sooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o:oooool7
o`3o03Kooooo1ol00?mSooooo`Ko0?l01_l00?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l[ooooo`Oo0?l0=_ooool7o`00
of?ooooo1_l0o`06o`00ofoooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
00002?ooool6o`3o00Oo003o:oooool7o`3o03Kooooo1ol00?mSooooo`Ko0?l01_l00?m_ooooo`Ko
ogl0Eoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo
1ol00?mSooooo`Ko0?l01_l00?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool6o`3o00Ko003oKooo
ool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003oJ?ooool7o`00of?ooooo1_l0o`06o`00ofoooooo1_ooO`1Hooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSoooo
o`Ko0?l01_l00?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo05So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00of?ooooo1_l0o`06o`00ofoooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Ko0?l01_l0
0?m_ooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool6o`3o00Ko003oKoooool6oomo05Sooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00
of?ooooo1_l0o`06o`00ofoooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0M?ooool6oomo05So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00of?ooooo1ol0o`1dooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o07Cooooo1_oo
O`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003oJ?ooool7
o`00of?ooooo1ol0o`1dooooo`Koogl0Eoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0M?ooool6oomo05Sooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?o
oooo1ol0o`1dooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o07Cooooo1_ooO`1Hooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mSooooo`Oo0?l0M?ooool6oomo05Sooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`1dooooo`Koogl0F?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXoooo
o`Oo003oHoooool7o`3o07Cooooo1_ooO`1Hooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0M?ooool6oomo05So
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00of?ooooo1ol0o`1dooooo`Koogl0F?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7
o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;o
oooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?mXooooo`Oo003o
Hoooool7o`3o0=7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSoooo
o`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Boooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo
00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`Co00001oooool6o`3o
00Oo003oJ?ooool7o`00of?ooooo1ol0o`3?ooooo`Co00003Oooool000gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003ooooooooo
o`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?o
oooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7
o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?oo
ool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Aooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSoooo
o`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Boooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0
o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=7o
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003o
Hoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXoooo
o`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0
d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSoooo
o`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00ofSooooo1ol00?mSooooo`Oo0?l0dOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7
o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003o
Hoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXoooo
o`Oo003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00002?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0o`3Aooooo`;o0000
3Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1ol0
o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?o
oooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7
o`00of?ooooo1ol0o`3Booooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool7o`3o0=;o
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo0?l0
d_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo
003oHoooool7o`3o0=;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mSooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00009ooooo`;o00001oooool4o`0000Oooooo1_l0o`07o`00ofSooooo1ol00?mSooooo`Oo
0?l0coooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003ooooooolmooooo`03
o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?oooooo
ocgooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003ooooooolmooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?ooooooocgooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?oo
ool7o`00oooooooo?Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003ooooooolmooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?ooooooocgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00oooo
oooo?Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?mXooooo`Oo003ooooooolmooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?ooooooocgooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00oooooooo?Oooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oooooo
ojcooooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?oooooooj_o
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooo
oon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojco
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
oooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooo
oon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko
0?l01ol00?oooooooj_ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3
o`0000Sooooo1_l0o`07o`00ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooo
oooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00Cooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool03_ooool7o`00
oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Go00001_ooool4o`00
00gooooo1ol00?ooooooojWooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o00001oooool00ol0003oooooooooo`0>
ooooo`Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`Oo003ooooooon/ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo1ol00?ooooooojcooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool7o`00oooooooo[?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02ooo
ool002?ooooo0ol0000>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool002?o
ooooool00035o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000booooo`?o00006?ooool5
o`0001Sooooo0ol0000Iooooo`?o00006?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooo
oooo01Sooooo0ol0000Iooooo`;o00005oooool3o`0000Cooooo0_l0000Booooo`?o00000oooool3
o`0001?ooooo0ol00002ooooo`Go00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00001?ooool3
o`0001;ooooo0ol00003ooooo`?o00004oooool3o`0000?ooooo0ol0000Jooooo`00<oooool00ol0
003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001Oooooo00Go0000ooooooooooooooooo`00
000Iooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`00
0?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Gooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Cooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool05oooool003?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo1Ol0000Kooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo
01Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooooooo`Go0000
4oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo01Oooooo000cooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool2o`0001Oooooo00Co0000oooooooooooo00007?ooool00ol0003o
ooooooooo`0Eooooo`Co00006oooool00ol0003oooooooooo`0Gooooo`?o00006Oooool4o`0001Ko
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00oooool2o`0001Cooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooooooo`Co00006_ooool003?ooooo00?o0000ooooooooool05oooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00
000Hooooo`Co00006?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00Go
0000ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000001Cooooo00Co0000oooooooooooooooo1?l0000Dooooo`05o`000?oo
ooooooooooooool000007Oooool003;ooooo0_l0000Iooooo`05o`000?ooooooooooooooool00000
5oooool01Ol0003ooooooooooooooooo000001Sooooo0_l0000Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001Oooooo00Go0000oooo
ooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000005Oooool2o`0000Cooooo00Co
0000oooooooooooo00004Oooool2o`0000Cooooo0_l0000Dooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000004_ooool2o`00
00Gooooo0_l0000Cooooo`;o00000oooool00ol0003oooooooooo`0Dooooo`;o00001?ooool00ol0
003oooooooooo`0Jooooo`00<oooool00ol0003oooooooooo`0Hooooo`?o00006Oooool3o`0001[o
oooo00?o0000ooooooooool05_ooool5o`0001Wooooo0_l0000Hooooo`Go00006?ooool3o`0001Wo
oooo0ol0000Gooooo`03o`000?oooooooooo00?ooooo0_l0000Cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`?o00005?ooool00ol0003o
ooooooooo`02ooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;o
oooo00Co0000oooooooooooooooo1Ol0000Cooooo`03o`000?oooooooooo00?ooooo0_l0000Joooo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.584672, -0.0330544, \
0.0359213, 0.00155367}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 0.831399 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09786 -18 -4.5 ]
[-0.0125 .09786 0 4.5 ]
[-0.0125 .18099 -18 -4.5 ]
[-0.0125 .18099 0 4.5 ]
[-0.0125 .26413 -18 -4.5 ]
[-0.0125 .26413 0 4.5 ]
[-0.0125 .34727 -18 -4.5 ]
[-0.0125 .34727 0 4.5 ]
[-0.0125 .43041 -18 -4.5 ]
[-0.0125 .43041 0 4.5 ]
[-0.0125 .51355 -18 -4.5 ]
[-0.0125 .51355 0 4.5 ]
[-0.0125 .59669 -18 -4.5 ]
[-0.0125 .59669 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09786 m
.00625 .09786 L
s
[(0.1)] -0.0125 .09786 1 0 Mshowa
0 .18099 m
.00625 .18099 L
s
[(0.2)] -0.0125 .18099 1 0 Mshowa
0 .26413 m
.00625 .26413 L
s
[(0.3)] -0.0125 .26413 1 0 Mshowa
0 .34727 m
.00625 .34727 L
s
[(0.4)] -0.0125 .34727 1 0 Mshowa
0 .43041 m
.00625 .43041 L
s
[(0.5)] -0.0125 .43041 1 0 Mshowa
0 .51355 m
.00625 .51355 L
s
[(0.6)] -0.0125 .51355 1 0 Mshowa
0 .59669 m
.00625 .59669 L
s
[(0.7)] -0.0125 .59669 1 0 Mshowa
.125 Mabswid
0 .03134 m
.00375 .03134 L
s
0 .04797 m
.00375 .04797 L
s
0 .0646 m
.00375 .0646 L
s
0 .08123 m
.00375 .08123 L
s
0 .11448 m
.00375 .11448 L
s
0 .13111 m
.00375 .13111 L
s
0 .14774 m
.00375 .14774 L
s
0 .16437 m
.00375 .16437 L
s
0 .19762 m
.00375 .19762 L
s
0 .21425 m
.00375 .21425 L
s
0 .23088 m
.00375 .23088 L
s
0 .24751 m
.00375 .24751 L
s
0 .28076 m
.00375 .28076 L
s
0 .29739 m
.00375 .29739 L
s
0 .31402 m
.00375 .31402 L
s
0 .33065 m
.00375 .33065 L
s
0 .3639 m
.00375 .3639 L
s
0 .38053 m
.00375 .38053 L
s
0 .39716 m
.00375 .39716 L
s
0 .41379 m
.00375 .41379 L
s
0 .44704 m
.00375 .44704 L
s
0 .46367 m
.00375 .46367 L
s
0 .4803 m
.00375 .4803 L
s
0 .49693 m
.00375 .49693 L
s
0 .53018 m
.00375 .53018 L
s
0 .54681 m
.00375 .54681 L
s
0 .56344 m
.00375 .56344 L
s
0 .58007 m
.00375 .58007 L
s
0 .61332 m
.00375 .61332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09786 m
1 .09786 L
s
.99375 .18099 m
1 .18099 L
s
.99375 .26413 m
1 .26413 L
s
.99375 .34727 m
1 .34727 L
s
.99375 .43041 m
1 .43041 L
s
.99375 .51355 m
1 .51355 L
s
.99375 .59669 m
1 .59669 L
s
.125 Mabswid
.99625 .03134 m
1 .03134 L
s
.99625 .04797 m
1 .04797 L
s
.99625 .0646 m
1 .0646 L
s
.99625 .08123 m
1 .08123 L
s
.99625 .11448 m
1 .11448 L
s
.99625 .13111 m
1 .13111 L
s
.99625 .14774 m
1 .14774 L
s
.99625 .16437 m
1 .16437 L
s
.99625 .19762 m
1 .19762 L
s
.99625 .21425 m
1 .21425 L
s
.99625 .23088 m
1 .23088 L
s
.99625 .24751 m
1 .24751 L
s
.99625 .28076 m
1 .28076 L
s
.99625 .29739 m
1 .29739 L
s
.99625 .31402 m
1 .31402 L
s
.99625 .33065 m
1 .33065 L
s
.99625 .3639 m
1 .3639 L
s
.99625 .38053 m
1 .38053 L
s
.99625 .39716 m
1 .39716 L
s
.99625 .41379 m
1 .41379 L
s
.99625 .44704 m
1 .44704 L
s
.99625 .46367 m
1 .46367 L
s
.99625 .4803 m
1 .4803 L
s
.99625 .49693 m
1 .49693 L
s
.99625 .53018 m
1 .53018 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .56344 m
1 .56344 L
s
.99625 .58007 m
1 .58007 L
s
.99625 .61332 m
1 .61332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .07629 L
.02469 .07629 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .07629 L
.02469 .07629 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .01472 L
.08642 .01472 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .01472 L
.08642 .01472 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .19039 L
.14815 .19039 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .19039 L
.14815 .19039 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .01472 L
.20988 .01472 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .01472 L
.20988 .01472 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .1971 L
.2716 .1971 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .1971 L
.2716 .1971 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .01472 L
.33333 .01472 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .01472 L
.33333 .01472 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .01472 L
.39506 .01472 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .01472 L
.39506 .01472 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .01472 L
.45679 .01472 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .01472 L
.45679 .01472 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .1545 L
.51852 .1545 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .1545 L
.51852 .1545 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .01472 L
.58025 .01472 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .01472 L
.58025 .01472 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .06257 L
.64198 .06257 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .06257 L
.64198 .06257 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .01472 L
.7037 .01472 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .01472 L
.7037 .01472 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .23883 L
.76543 .23883 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .23883 L
.76543 .23883 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .01472 L
.88889 .01472 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .01472 L
.88889 .01472 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .01472 L
.95062 .01472 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .01472 L
.95062 .01472 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .01472 L
.09877 .01472 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .01472 L
.09877 .01472 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .04448 L
.16049 .04448 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .04448 L
.16049 .04448 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .01472 L
.22222 .01472 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .01472 L
.22222 .01472 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .06491 L
.28395 .06491 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .06491 L
.28395 .06491 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .01472 L
.34568 .01472 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .01472 L
.34568 .01472 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .01501 L
.40741 .01501 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .01501 L
.40741 .01501 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .01472 L
.46914 .01472 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .01472 L
.46914 .01472 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .15683 L
.53086 .15683 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .15683 L
.53086 .15683 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .01472 L
.59259 .01472 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .01472 L
.59259 .01472 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .01559 L
.65432 .01559 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .01559 L
.65432 .01559 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .03427 L
.77778 .03427 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .03427 L
.77778 .03427 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .01472 L
.83951 .01472 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .01472 L
.83951 .01472 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .01472 L
.90123 .01472 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .01472 L
.90123 .01472 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .39758 L
.04938 .39758 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .39758 L
.04938 .39758 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .01472 L
.11111 .01472 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .01472 L
.11111 .01472 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .08358 L
.17284 .08358 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .08358 L
.17284 .08358 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .01472 L
.23457 .01472 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .01472 L
.23457 .01472 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .11218 L
.2963 .11218 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .11218 L
.2963 .11218 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .01472 L
.35802 .01472 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .01472 L
.35802 .01472 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .01472 L
.41975 .01472 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .01472 L
.48148 .01472 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .24876 L
.54321 .24876 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .24876 L
.54321 .24876 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .01472 L
.60494 .01472 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .01617 L
.66667 .01617 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .01617 L
.66667 .01617 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .01472 L
.7284 .01472 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .06141 L
.79012 .06141 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .06141 L
.79012 .06141 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .01472 L
.91358 .01472 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .01472 L
.97531 .01472 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .01472 L
.06173 .01472 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .01472 L
.06173 .01472 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .09467 L
.12346 .09467 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .09467 L
.12346 .09467 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .02318 L
.18519 .02318 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .02318 L
.18519 .02318 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .09876 L
.24691 .09876 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .09876 L
.24691 .09876 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .0258 L
.30864 .0258 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .0258 L
.30864 .0258 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .09467 L
.37037 .09467 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .09467 L
.37037 .09467 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .08592 L
.4321 .08592 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .08592 L
.4321 .08592 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .09234 L
.49383 .09234 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .09234 L
.49383 .09234 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .01647 L
.55556 .01647 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .01647 L
.55556 .01647 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .08709 L
.61728 .08709 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .08709 L
.61728 .08709 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .0903 L
.67901 .0903 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .0903 L
.67901 .0903 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .0652 L
.74074 .0652 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .0652 L
.74074 .0652 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .02084 L
.80247 .02084 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .02084 L
.80247 .02084 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .06841 L
.8642 .06841 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .06841 L
.8642 .06841 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .08855 L
.92593 .08855 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .08855 L
.92593 .08855 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .09993 L
.98765 .09993 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .09993 L
.98765 .09993 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oo
oooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`00<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001[ooooo000coooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001gooooo000booooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool003?ooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00006_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035
o`0000gooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Go003o1ooo
O`0Eooooo`Ooogl01?ooool6ool000Go0?l01_l00?l6oomo01Kooooo1_ooO`0Fooooo`Koogl05Ooo
ool7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0Eooooo`Ooogl01?ooool7ool000[ooooo1_oo
O`0Fooooo`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo01Gooooo1oooO`0Eooooo`Ooogl05Ooo
ool7oomo00Cooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Goo`001_l0
o`05o`00o`Ooogl05Oooool7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0Fooooo`Koogl05_oo
ool6oomo01Gooooo1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`002_oo
ool6oomo01Kooooo1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl05Oooool7oomo01Gooooo1ooo
O`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000
ooooooooool00oooool5ool000Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01Ol00?l7
oomo01Gooooo1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl05_ooool6oomo01Kooooo1_ooO`0E
ooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0F
ooooo`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo01Gooooo1oooO`0Eooooo`Ooogl05Oooool7
oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool5ool0
00Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo01Gooooo1oooO`04oooo
o`Koo`001Ol0o`06o`00o`Koogl05_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool0
00Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Fooooo`Koogl01Oooool5ool0
00Ko0?l01ol00?lJooooo`Ooogl05Oooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Go
oooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0Fooooo`Ko
ogl05_ooool6oomo01Gooooo1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Oo
o`002_ooool6oomo01Kooooo1_ooO`05ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`0Eooooo`Oo
ogl05Oooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
0oooool5ool000Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl0
1?ooool6ool000Go0?l01ol00?lKooooo`Koogl05_ooool6oomo01Gooooo1oooO`05ooooo`Goo`00
1_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`05ooooo`Goo`00
1_l0o`07o`00oa[ooooo1oooO`0Eooooo`Ooogl05Oooool7oomo00Cooooo00?o0000ooooooooool0
2oooool002?ooooo0ol00003ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Goo`001_l0
o`06o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`0Fooooo`Koogl05Ooo
ool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl05_oo
ool6oomo00Gooooo1Ooo0006o`3o00Oo003o6_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl00ooo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7
oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6
oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7
ool000[ooooo1_ooO`0Fooooo`Koogl01Oooool5ool000Ko0?l01ol00?lJooooo`Ooogl05Oooool7
oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo
00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool0
00Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Fooooo`Koogl01Oooool5ool0
00Ko0?l01ol00?lJooooo`Ooogl05Oooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Go
oooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo01Ko
oooo1_ooO`0Eooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[o
oooo1_ooO`0Fooooo`Koogl01Oooool6ool000Gooooo1ol00?lJooooo`Ooogl05Oooool7oomo01Go
oooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo
1_oo0005o`3o00Oo003o6oooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool000Ko0?l0
1_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Fooooo`Koogl01Oooool6ool000Gooooo
1ol00?lJooooo`Ooogl05Oooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo
0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo01Kooooo1_oo
O`0Eooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_oo
O`0Fooooo`Koogl01Oooool6ool000Gooooo1ol00?lJooooo`Ooogl05Oooool7oomo01Gooooo1ooo
O`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006
o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005
o`3o00Oo003o6oooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lK
ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Fooooo`Koogl01Oooool6ool000Gooooo1ol00?lJ
ooooo`Ooogl05Oooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1_oo0005oooo
o`Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo01Kooooo1_ooO`0Eoooo
o`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Foooo
o`Koogl01Oooool6ool000Gooooo1ol00?lJooooo`Ooogl05Oooool7oomo01Gooooo1oooO`04oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool5ool000Ko0?l01ol00?lJooooo`Oo
ogl01Oooool6ool000Gooooo1_l00?lKooooo`Ooogl01?ooool6ool000Go0?l01ol00?lKooooo`Ko
ogl05_ooool6oomo01Gooooo1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Oo
o`002_ooool6oomo01Kooooo1_ooO`05ooooo`Koo`001Oooool7o`00oa[ooooo1oooO`0Eooooo`Oo
ogl05Oooool7oomo00?ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`00
1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Koo`00
1Ol0o`07o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o
6oooool7oomo00Cooooo1ooo000:ooooo`Koogl05_ooool6oomo00Gooooo1_oo0005ooooo`Oo003o
6_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`001Ooo
ool6o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`0Fooooo`Koogl05Ooo
ool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl05_oo
ool6oomo00Gooooo1_oo0005ooooo`Oo003o6_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07
o`00oa[ooooo1oooO`05ooooo`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07
o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7
oomo00Cooooo1ooo000:ooooo`Koogl05_ooool6oomo00Gooooo1_oo0005ooooo`Oo003o6_ooool7
oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`001Oooool6o`00
oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo
00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl05_ooool6oomo
00Gooooo1_oo0005ooooo`Oo003o6_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[o
oooo1oooO`05ooooo`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_o
oooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Co
oooo1ooo000:ooooo`Koogl05_ooool6oomo00Gooooo1_oo0005ooooo`Oo003o6_ooool7oomo01Go
oooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`001Oooool6o`00oa_ooooo
1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo
1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl05_ooool6oomo00Gooooo
1_oo0005ooooo`Oo003o6_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0000?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1_oo
0005ooooo`Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo01Kooooo1_oo
O`0Eooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo01Kooooo1_oo
O`05ooooo`Koo`009_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl00oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1_oo0005
ooooo`Ko003o6oooool7oomo00Cooooo1ooo0004ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0E
ooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo01Kooooo1_ooO`05
ooooo`Koo`009_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05oooo
o`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa_ooooo1_ooO`0Foooo
o`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`0Qoooo
o`Koo`009_ooool7oomo01Gooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05ooooo`Ko
o`001Oooool6o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa_ooooo1_ooO`0Fooooo`Ko
ogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`0Qooooo`Ko
o`00@_ooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o6_ooool7oomo00Gooooo1_oo0005ooooo`Ko003o
6oooool7oomo00Cooooo1ooo0004ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl0
1Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl05Oooool6oomo027ooooo1_oo0012ooooo`Ooogl0
5Oooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo
ool5ool000Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool000Gooooo1_l00?lKooooo`Ooogl01?oo
ool7ool000Cooooo1ol00?lKooooo`Koogl05_ooool6oomo01Gooooo1oooO`05ooooo`Goo`001_l0
o`06o`00oa_ooooo1oooO`0Eooooo`Koogl08Oooool6ool004;ooooo1oooO`0Eooooo`Ooogl01?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07
o`00oa[ooooo1oooO`05ooooo`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool7
o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7
oomo01Gooooo1_ooO`0Qooooo`Koo`00@_ooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05oooo
o`Koo`001Oooool6o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool7o`00oa_ooooo1_ooO`0Foooo
o`Koogl05Oooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`0Qoooo
o`Koo`00@_ooool7oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o
00002?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo0005ooooo`Ko003o6oooool7oomo00Co
oooo1ooo0004ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool5ool000Ko
0?l01_l00?lKooooo`Ooogl05Oooool6oomo027ooooo1_oo0012ooooo`Ooogl05Oooool7oomo00?o
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl0
1Oooool6ool000Gooooo1_l00?lKooooo`Ooogl01?ooool7ool000Cooooo1ol00?lKooooo`Koogl0
5_ooool6oomo01Gooooo1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`0Eooooo`Koogl0
8Oooool6ool004;ooooo1oooO`0Eooooo`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool6ool002Kooooo1ooo
O`04ooooo`Ooo`001?ooool7o`00oa_ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1Ooo
0006o`3o00Ko003o6oooool7oomo01Gooooo1_ooO`0Qooooo`Koo`00@_ooool7oomo01Gooooo1ooo
O`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oa[ooooo1oooO`05ooooo`Koo`009_ooool7oomo00Cooooo1ooo0004ooooo`Oo003o6oooool6
oomo037ooooo1oooO`05ooooo`Goo`001_l0o`06o`00ocOooooo1_ooO`0Qooooo`Koo`00@_ooool7
oomo01Gooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Koo`009_ooool7oomo00Cooooo1ooo0004oooo
o`Oo003o6oooool6oomo037ooooo1oooO`05ooooo`Goo`001_l0o`06o`00ocOooooo1_ooO`0Qoooo
o`Koo`00G_ooool7oomo00Cooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[o
oooo1oooO`05ooooo`Koo`009_ooool7oomo00Cooooo1ooo0004ooooo`Oo003o6oooool6oomo037o
oooo1oooO`05ooooo`Goo`001_l0o`06o`00oekooooo1_oo001Nooooo`Ooogl01?ooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1_oo000Vooooo`Oo
ogl01?ooool7ool000Cooooo1ol00?lKooooo`Koogl0?Oooool5ool000Ko0?l01_l00?mNooooo`Ko
o`00G_ooool7oomo00Cooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`06ooooo`Co00001oooool6o`3o00Oo003o9_ooool6ool002Ko
oooo1oooO`04ooooo`Ooo`001?ooool7o`00oekooooo1Ooo0006o`3o00Ko003oG_ooool6ool005ko
oooo1oooO`000ooooooo0000o`000002o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Ko
o`009_ooool7oomo00Cooooo1ooo0004ooooo`Oo003oG_ooool5ool000Ko0?l01_l00?mNooooo`Ko
o`00G_ooool7oomo00Cooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKo
oooo1_oo000aooooo`Ooo`001?ooool7o`00oekooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Wo
oooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool2o`0000So
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003o9_ooool6ool0037ooooo1ooo0004ooooo`Oo
003oG_ooool5ool000Ko0?l01_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?lVooooo`Koo`00<Oooool7ool000Cooooo1ol00?mNooooo`Goo`001_l0o`06o`00oekooooo
1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00obKooooo1_oo000aooooo`Ooo`001?ooool7o`00oekooooo1Ooo0006o`3o00Ko003oG_oo
ool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003o9_ooool6ool0037ooooo1ooo0004ooooo`Oo003oG_ooool5ool000Ko0?l01_l00?mN
ooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool000Cooooo1ol00?mNooooo`Goo`001_l0o`06o`00
oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo
003o9_ooool6ool0037ooooo1ooo001Yooooo`Goo`001_l0o`06o`00oekooooo1_oo001Xooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o9_ooool6ool0037ooooo
1ooo001Yooooo`Goo`001_l0o`06o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00JOoo
ool5ool000Ko0?l01_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006
o`3o00Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o9_ooool6ool0037ooooo1ooo001Yooooo`Goo`001_l0o`06o`00
oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00JOooool5ool000Ko0?l01_l00?mNooooo`Ko
o`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Wooooo
00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?lVooooo`Koo`00<Ooo
ool7ool006Wooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Sooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006
o`3o00Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o9_ooool6ool0037ooooo1ooo001Yooooo`Goo`001_l0o`06o`00
oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00JOooool5ool000Ko0?l01_l00?mNooooo`Ko
o`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Wooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o9_oo
ool6ool0037ooooo1ooo001Yooooo`Goo`001_l0o`06o`00oekooooo1_oo001Yooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000a
ooooo`Ooo`00JOooool5ool000Ko0?l01_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool0
06Wooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool002?o
oooo0ol00008ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006o`3o00Ko
003oG_ooool6ool006Sooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?lVooooo`Koo`00<Oooool7ool006Wooooo1Ooo0006o`3o00Ko003oG_ooool6ool006Wooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o9_oo
ool6ool0037ooooo1ooo001Yooooo`Goo`001_l0o`06o`00oekooooo1_oo001Yooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000a
ooooo`Ooo`00JOooool5ool000Ko0?l01_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool0
06kooooo1_l0o`06o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00M?ooool6o`00oeko
oooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00M?ooool6o`00oekooooo1_oo001Yooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003o9_ooool6ool0037ooooo1ooo
001dooooo`Ko003oG_ooool6ool006Sooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool007Cooooo1_l00?mNooooo`Koo`00JOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVoooo
o`Koo`00<Oooool7ool007Cooooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool007Co
oooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool007Cooooo1_l00?mNooooo`Koo`00
JOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00006ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00
M?ooool6o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?lVooooo`Koo`00<Oooool7ool007Cooooo1_l00?mNooooo`Koo`00JOooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003o9_ooool6ool0037ooooo1ooo001dooooo`Ko
003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`05ooooo`Co00001oooool6o`3o00Oo003o9_ooool6ool0037o
oooo1ooo001dooooo`Ko003oG_ooool6ool006Kooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?lVooooo`Koo`00<Oooool7ool007Cooooo1_l00?mNooooo`Koo`00JOooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lVooooo`Koo`00<Oooool7
ool007Cooooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`00
00Wooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000aoooo
o`Ooo`00M?ooool6o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00obKooooo1_oo000aooooo`Ooo`00M?ooool6o`00oeko
oooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00oegooooo1ooo001dooooo`Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oGOooool7ool007Cooooo1_l0
0?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00oegooooo1ooo001dooooo`Ko003oG_ooool6ool006Sooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?oHooooo`Ko003oG_ooool6ool006Wooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003of?ooool6o`00oeko
oooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00omSooooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oHooooo`Ko003oG_ooool6ool006Wooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003of?ooool6
o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00omSooooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oHooooo`Ko003oG_ooool6ool006Wo
oooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?oHooooo`Ko003o
G_ooool6ool006Sooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?oHooooo`Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003of?ooool6o`00oekooooo1_oo001Yooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00omSooooo1_l00?mNoooo
o`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?oHooooo`Ko003oG_ooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003of?ooool6o`00oekooooo1_oo001Yooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00omSooooo1_l0
0?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00omSooooo1_l00?mNooooo`Koo`00J?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00omSooooo1_l00?mNooooo`Koo`00JOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oHooooo`Ko003oG_ooool6ool006Wo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
f?ooool6o`00oekooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00omSooooo1_l00?mNooooo`Koo`00JOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oHooooo`Ko003ocOooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?oHoooo
o`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?oHooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo
1_l0o`07o`00omSooooo1_l00?o<ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003ooooo
ooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool4o`0000Oooooo1_l0o`07o`00oooo
ooooZOooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wo
oooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooo
oon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07o`00
ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooo
oooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00002?ooool6o`3o00Oo003ooooooon[ooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo
[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o
00Oo003ooooooon[ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000oooooooo
ool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?oooooooj_ooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojco
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol00006ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`Ko0?l01ol00?ooooooojWo
oooo1?l0000=ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooo
oon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko
0?l01ol00?oooooooj_ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o
0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?oooooooj_ooooo0_l0000=
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?ooooooojcooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003ooooooon/ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oooooooo
[?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?ooooooojcooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003ooooooon/ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00oooooooo[?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000So
oooo1_l0o`07o`00ooooooooZoooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo0ol00008
ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?oo
ool4o`0000Oooooo1ol0o`3oooooojoooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002?ooool5
o`0000Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0000=ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool000kooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooo
ok;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`Co00001ooo
ool7o`3o0?oooooo[oooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000>
ooooo`;o00002_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000go
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool000gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`05ooooo`Co00001oooool7o`3o0?oooooo[oooool4o`0000go
oooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooo
ok;ooooo00?o0000ooooooooool02oooool000kooooo0_l00008ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Ooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool002?ooooo0ol0000>ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00cooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?oooooool00035o`0000gooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo000booooo`?o00006?ooool5o`0001Sooooo0ol0000Iooooo`?o00006?ooool3o`00
01Wooooo0ol0000Jooooo`03o`000?oooooooooo01Sooooo0ol0000Iooooo`;o00005oooool3o`00
00Cooooo0_l0000Booooo`?o00000oooool3o`0001?ooooo0ol00002ooooo`Go00004_ooool3o`00
00?ooooo0ol0000Cooooo`?o00001?ooool3o`0001;ooooo0ol00003ooooo`?o00004oooool3o`00
00?ooooo0ol0000Jooooo`00<oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
01Oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo01Kooooo00Go0000
ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`0Gooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000C
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool05oooool003?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Cooooo1Ol0000Kooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000Jooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo
000cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool2o`0001Oooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`0Eooooo`Co00006oooool00ol0003ooooo
ooooo`0Gooooo`?o00006Oooool4o`0001Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool2o`0001Co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooooooo`Co00006_ooool0
03?ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooo`00000Hooooo`Co00006?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Cooooo00Co0000oooo
oooooooooooo1?l0000Dooooo`05o`000?ooooooooooooooool000007Oooool003;ooooo0_l0000I
ooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo000001Sooooo
0_l0000Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oooooooooo
ooooool000005Oooool2o`0000Cooooo00Co0000oooooooooooo00004Oooool2o`0000Cooooo0_l0
000Dooooo`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000004_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool00ol0003o
ooooooooo`0Dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`00<oooool00ol0003ooooo
ooooo`0Hooooo`?o00006Oooool3o`0001[ooooo00?o0000ooooooooool05_ooool5o`0001Wooooo
0_l0000Hooooo`Go00006?ooool3o`0001Wooooo0ol0000Gooooo`03o`000?oooooooooo00?ooooo
0_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`?o00005?ooool00ol0003oooooooooo`02ooooo`?o00005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo1Ol0000Cooooo`03
o`000?oooooooooo00?ooooo0_l0000Jooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.584672, -0.0567412, \
0.0359213, 0.00266703}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 1.20296 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13501 -18 -4.5 ]
[-0.0125 .13501 0 4.5 ]
[-0.0125 .25531 -18 -4.5 ]
[-0.0125 .25531 0 4.5 ]
[-0.0125 .3756 -18 -4.5 ]
[-0.0125 .3756 0 4.5 ]
[-0.0125 .4959 -18 -4.5 ]
[-0.0125 .4959 0 4.5 ]
[-0.0125 .6162 -18 -4.5 ]
[-0.0125 .6162 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13501 m
.00625 .13501 L
s
[(0.1)] -0.0125 .13501 1 0 Mshowa
0 .25531 m
.00625 .25531 L
s
[(0.2)] -0.0125 .25531 1 0 Mshowa
0 .3756 m
.00625 .3756 L
s
[(0.3)] -0.0125 .3756 1 0 Mshowa
0 .4959 m
.00625 .4959 L
s
[(0.4)] -0.0125 .4959 1 0 Mshowa
0 .6162 m
.00625 .6162 L
s
[(0.5)] -0.0125 .6162 1 0 Mshowa
.125 Mabswid
0 .03877 m
.00375 .03877 L
s
0 .06283 m
.00375 .06283 L
s
0 .08689 m
.00375 .08689 L
s
0 .11095 m
.00375 .11095 L
s
0 .15907 m
.00375 .15907 L
s
0 .18313 m
.00375 .18313 L
s
0 .20719 m
.00375 .20719 L
s
0 .23125 m
.00375 .23125 L
s
0 .27937 m
.00375 .27937 L
s
0 .30343 m
.00375 .30343 L
s
0 .32749 m
.00375 .32749 L
s
0 .35155 m
.00375 .35155 L
s
0 .39966 m
.00375 .39966 L
s
0 .42372 m
.00375 .42372 L
s
0 .44778 m
.00375 .44778 L
s
0 .47184 m
.00375 .47184 L
s
0 .51996 m
.00375 .51996 L
s
0 .54402 m
.00375 .54402 L
s
0 .56808 m
.00375 .56808 L
s
0 .59214 m
.00375 .59214 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13501 m
1 .13501 L
s
.99375 .25531 m
1 .25531 L
s
.99375 .3756 m
1 .3756 L
s
.99375 .4959 m
1 .4959 L
s
.99375 .6162 m
1 .6162 L
s
.125 Mabswid
.99625 .03877 m
1 .03877 L
s
.99625 .06283 m
1 .06283 L
s
.99625 .08689 m
1 .08689 L
s
.99625 .11095 m
1 .11095 L
s
.99625 .15907 m
1 .15907 L
s
.99625 .18313 m
1 .18313 L
s
.99625 .20719 m
1 .20719 L
s
.99625 .23125 m
1 .23125 L
s
.99625 .27937 m
1 .27937 L
s
.99625 .30343 m
1 .30343 L
s
.99625 .32749 m
1 .32749 L
s
.99625 .35155 m
1 .35155 L
s
.99625 .39966 m
1 .39966 L
s
.99625 .42372 m
1 .42372 L
s
.99625 .44778 m
1 .44778 L
s
.99625 .47184 m
1 .47184 L
s
.99625 .51996 m
1 .51996 L
s
.99625 .54402 m
1 .54402 L
s
.99625 .56808 m
1 .56808 L
s
.99625 .59214 m
1 .59214 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .05483 L
.02469 .05483 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .05483 L
.02469 .05483 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .01852 L
.08642 .01852 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .01852 L
.08642 .01852 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .18614 L
.14815 .18614 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .18614 L
.14815 .18614 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .02949 L
.20988 .02949 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .02949 L
.20988 .02949 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .24737 L
.2716 .24737 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .24737 L
.2716 .24737 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .01936 L
.33333 .01936 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .01936 L
.33333 .01936 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .28917 L
.39506 .28917 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .28917 L
.39506 .28917 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .04469 L
.45679 .04469 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .04469 L
.45679 .04469 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .12872 L
.51852 .12872 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .12872 L
.51852 .12872 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .0164 L
.58025 .0164 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .0164 L
.58025 .0164 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .14561 L
.64198 .14561 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .14561 L
.64198 .14561 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .01472 L
.7037 .01472 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .01472 L
.7037 .01472 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .17854 L
.76543 .17854 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .17854 L
.76543 .17854 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .01472 L
.82716 .01472 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .03498 L
.88889 .03498 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .03498 L
.88889 .03498 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .01514 L
.95062 .01514 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .01514 L
.95062 .01514 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .0202 L
.09877 .0202 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .0202 L
.09877 .0202 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .16672 L
.16049 .16672 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .16672 L
.16049 .16672 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .02147 L
.22222 .02147 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .02147 L
.22222 .02147 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .12703 L
.28395 .12703 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .12703 L
.28395 .12703 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .0202 L
.34568 .0202 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .0202 L
.34568 .0202 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .11901 L
.40741 .11901 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .11901 L
.40741 .11901 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .02738 L
.46914 .02738 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .02738 L
.46914 .02738 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .19248 L
.53086 .19248 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .19248 L
.53086 .19248 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .01514 L
.59259 .01514 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .01514 L
.59259 .01514 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .01978 L
.65432 .01978 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .01978 L
.65432 .01978 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .03498 L
.77778 .03498 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .03498 L
.77778 .03498 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .01472 L
.83951 .01472 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .01472 L
.83951 .01472 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .02654 L
.90123 .02654 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .02654 L
.90123 .02654 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .09283 L
.04938 .09283 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .09283 L
.04938 .09283 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .04216 L
.11111 .04216 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .04216 L
.11111 .04216 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .12365 L
.17284 .12365 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .12365 L
.17284 .12365 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .09367 L
.23457 .09367 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .09367 L
.23457 .09367 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .12956 L
.2963 .12956 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .12956 L
.2963 .12956 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .05905 L
.35802 .05905 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .05905 L
.35802 .05905 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .12534 L
.41975 .12534 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .12534 L
.41975 .12534 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .10127 L
.48148 .10127 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .10127 L
.48148 .10127 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .1093 L
.54321 .1093 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .1093 L
.54321 .1093 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .0354 L
.60494 .0354 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .0354 L
.60494 .0354 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .08143 L
.66667 .08143 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .08143 L
.66667 .08143 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .07763 L
.7284 .07763 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .07763 L
.7284 .07763 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .09959 L
.79012 .09959 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .09959 L
.79012 .09959 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .06792 L
.85185 .06792 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .06792 L
.85185 .06792 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .10845 L
.91358 .10845 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .10845 L
.91358 .10845 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .09114 L
.97531 .09114 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .09114 L
.97531 .09114 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .0202 L
.06173 .0202 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .0202 L
.06173 .0202 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .14434 L
.12346 .14434 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .14434 L
.12346 .14434 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .04892 L
.18519 .04892 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .04892 L
.18519 .04892 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .11394 L
.24691 .11394 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .11394 L
.24691 .11394 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .06074 L
.30864 .06074 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .06074 L
.30864 .06074 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .15194 L
.37037 .15194 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .15194 L
.37037 .15194 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .05229 L
.4321 .05229 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .05229 L
.4321 .05229 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .09747 L
.49383 .09747 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .09747 L
.49383 .09747 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .06454 L
.55556 .06454 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .06454 L
.55556 .06454 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .15701 L
.61728 .15701 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .15701 L
.61728 .15701 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .12534 L
.67901 .12534 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .12534 L
.67901 .12534 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .0354 L
.74074 .0354 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .0354 L
.74074 .0354 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .10634 L
.80247 .10634 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .10634 L
.80247 .10634 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .07425 L
.8642 .07425 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .07425 L
.8642 .07425 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .13083 L
.92593 .13083 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .13083 L
.92593 .13083 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .05483 L
.98765 .05483 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .05483 L
.98765 .05483 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oo
oooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`00<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001[ooooo000coooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001gooooo000booooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool003?ooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00006_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035
o`0000gooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00?ooooo1Ooo0006o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Ooo
ool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1oooO`04ooooo`Koo`001Ol0
o`06o`00o`Koogl01Oooool6ool000Go0?l01_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_oo
O`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1ooo
0005ooooo`Go003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Ooo
ool5ool000Ko0?l01_l00?l6oomo013ooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1ooo
O`0@ooooo`Go003o1oooO`04ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool00oooool5ool000Ko0?l01_l00?l6oomo00[ooooo1_l0
o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1ooo
O`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Oooool6ool000Go0?l01_l00?l6oomo00Gooooo1Ooo
0006o`3o00Ko003o1_ooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol0
0?l7oomo013ooooo1Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0@ooooo`Ko003o1_oo
O`05ooooo`Goo`001_l0o`06o`00o`Koogl04?ooool5o`00o`Ooogl01Oooool5ool000Ko0?l01Ol0
0?l7oomo013ooooo1Ol00?l7oomo00Cooooo00?o0000ooooooooool02oooool001[ooooo0_l00007
ooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5
ool000Ko0?l01Ol00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1oooO`04ooooo`Koo`001Ol0o`06
o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo00Gooooo1Ooo0006
o`3o00Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool7
ool000Cooooo1_l00?l6oomo013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`0@
ooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00
oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`001?ooool6o`00
o`Ooogl01?ooool6ool000Go0?l01_l00?l6oomo013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o
00Ko003o1_ooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo
013ooooo1Ol00?l7oomo00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@ooooo`Ko003o1_ooO`05oooo
o`Goo`001_l0o`06o`00o`Koogl04?ooool5o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo
013ooooo1Ol00?l7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool5ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Oo
ogl01?ooool7ool000Cooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0@ooooo`Ko
003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Go
oooo1Ooo0006o`3o00Go003o1oooO`0@ooooo`Go003o1oooO`04ooooo`Ooo`001?ooool6o`00o`Ko
ogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo013ooooo1Ol00?l7oomo00Go
oooo1Ooo0006o`3o00Go003o1oooO`0@ooooo`Go003o1oooO`04ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl0
1Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1ooo0004ooooo`Ko003o1oooO`04ooooo`Koo`00
1Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo00Gooooo
1_oo0005ooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl04?ooool5o`00o`Ooogl0
1?ooool7ool000Cooooo1_l00?l6oomo013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o
1_ooO`0@ooooo`Go003o1oooO`05ooooo`Koo`001Oooool5o`00o`Ooogl04?ooool5o`00o`Ooogl0
1?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0
o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0?ooooo`Ko003o1ooo
O`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l0
0?l6oomo00Gooooo1_oo0005ooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl04?oo
ool5o`00o`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo013ooooo1_l00?l6oomo00Gooooo1Ooo
0006o`3o00Ko003o1_ooO`0@ooooo`Go003o1oooO`05ooooo`Koo`001Oooool5o`00o`Ooogl04?oo
ool5o`00o`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03
ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0?
ooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5
ool000Ko0?l01_l00?l6oomo00Gooooo1_oo0005ooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05
o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo013ooooo1_l00?l6
oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`0@ooooo`Go003o1oooO`05ooooo`Koo`001Oooool5
o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o
00Go003o1oooO`0?ooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00
o`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo00Gooooo1_oo0005ooooo`Go003o1oooO`05oooo
o`Goo`001_l0o`05o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo
013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`0@ooooo`Go003o1oooO`05oooo
o`Koo`001Oooool5o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Go
oooo1Ooo0006o`3o00Go003o1oooO`0?ooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Ko
ogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l00?l6oomo00Gooooo1_oo0005ooooo`Go
003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl05Oooool7oomo00Cooooo1ooo0004ooooo`Ko
003o1_ooO`0@ooooo`Oo003o2_ooool6ool000Gooooo1_l00?l6oomo013ooooo1Ol00?l7oomo013o
oooo1Ol00?l7oomo013ooooo1Ol00?l7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo
0ol00003ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o
1oooO`0?ooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl0
1Oooool5ool000Ko0?l01_l00?l6oomo00Gooooo1_oo0005ooooo`Go003o1oooO`05ooooo`Goo`00
1_l0o`05o`00o`Ooogl05Oooool7oomo00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@ooooo`Oo003o
2_ooool6ool000Gooooo1_l00?l6oomo013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo013ooooo
1Ol00?l7oomo00?ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0
o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0?ooooo`Ko003o1ooo
O`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5ool000Ko0?l01_l0
0?l6oomo00Gooooo1_oo0005ooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl05Ooo
ool7oomo00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@ooooo`Oo003o2_ooool6ool000Gooooo1_l0
0?l6oomo013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo00Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool5ool000Ko0?l01ol00?lJ
ooooo`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00oooooo1_l00?l7oomo00Cooooo1_oo0005
o`3o00Ko003o1_ooO`0@ooooo`Ko003o1_ooO`05ooooo`Goo`001_l0o`06o`00o`Koogl01Oooool6
ool000Gooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0Eooooo`Ooogl01?ooool7
ool000Cooooo1_l00?l6oomo013ooooo1ol00?l:ooooo`Koo`001Oooool6o`00o`Koogl04?ooool5
o`00o`Ooogl04?ooool5o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07o`00oa[ooooo1oooO`05oooo
o`Goo`001_l0o`05o`00o`Ooogl03oooool6o`00o`Ooogl01?ooool6ool000Go0?l01_l00?l6oomo
013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`0@ooooo`Go003o1oooO`05oooo
o`Goo`001_l0o`05o`00o`Ooogl05Oooool7oomo00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@oooo
o`Oo003o2_ooool6ool000Gooooo1_l00?l6oomo013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo
013ooooo1Ol00?l7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool5ool000Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00oo
oooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0@ooooo`Ko003o1_ooO`05ooooo`Go
o`001_l0o`06o`00o`Koogl04?ooool5o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo01Go
oooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo1_oo0005ooooo`Ko
003o1_ooO`0@ooooo`Go003o1oooO`0@ooooo`Go003o1oooO`0@ooooo`Go003o1oooO`04ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1Ooo0006o`3o00Oo003o
6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go0?l0
1_l00?l6oomo013ooooo1_l00?l6oomo00Gooooo1Ooo0006o`3o00Ko003o1_ooO`0@ooooo`Go003o
1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl05Oooool7oomo00Cooooo1ooo0004ooooo`Ko003o
1_ooO`0@ooooo`Oo003o2_ooool6ool000Gooooo1_l00?l6oomo013ooooo1Ol00?l7oomo013ooooo
1Ol00?l7oomo013ooooo1Ol00?l7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool5ool000Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01_l0
0?lEooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Ooo
ool5ool000Ko0?l01_l00?l6oomo013ooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go003o1ooo
O`0Eooooo`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo013ooooo1ol00?l:ooooo`Koo`001Ooo
ool6o`00o`Koogl04?ooool5o`00o`Ooogl04?ooool5o`00o`Ooogl04?ooool5o`00o`Ooogl01?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Goo`001_l0o`07
o`00oa[ooooo1oooO`05ooooo`Goo`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005
o`3o00Ko003o1_ooO`0@ooooo`Ko003o1_ooO`05ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7
oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`0Eooooo`Ooogl01?ooool7ool000Cooooo1_l00?l6
oomo013ooooo1ol00?l:ooooo`Koo`001Oooool6o`00o`Koogl04?ooool5o`00o`Ooogl04?ooool5
o`00o`Ooogl04?ooool5o`00o`Ooogl01?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lEoooo
o`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl04?ooool6o`00o`Koogl01Oooool5ool0
00Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`001_l0o`05o`00o`Ooogl05Oooool7oomo
00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@ooooo`Oo003o2_ooool6ool000Gooooo1_l00?l6oomo
013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo013ooooo1_l00?l:ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Go
o`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_ooO`0@ooooo`Ko
003o1_ooO`05ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Go
003o1oooO`0Eooooo`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo013ooooo1ol00?l:ooooo`Ko
o`001Oooool6o`00o`Koogl04?ooool5o`00o`Ooogl04?ooool5o`00o`Ooogl04?ooool6o`00o`[o
oooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Ko0?l01ol00?lJooooo`Ooogl0
1Oooool5ool000Ko0?l01_l00?lEooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl0
5_ooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool000Ko0?l0
1Ol00?l7oomo01Gooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo
1_oo0005ooooo`Ko003o1_ooO`0@ooooo`Go003o1oooO`0@ooooo`Go003o1oooO`0@ooooo`Ko003o
2Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1ooo
O`05ooooo`Goo`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Oo003o6ooo
ool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool000Ko0?l01Ol0
0?l7oomo01Gooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo1_oo
0005ooooo`Ko003o1_ooO`0@ooooo`Go003o1oooO`0@ooooo`Go003o1oooO`0@ooooo`Ko003o2_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJ
ooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lEooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`07
o`00oa_ooooo1_ooO`05ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006
o`3o00Ko003o6oooool7oomo00Cooooo1ooo0004ooooo`Ko003o1_ooO`0@ooooo`Oo003o2_ooool6
ool000Gooooo1_l00?l6oomo013ooooo1Ol00?l7oomo013ooooo1Ol00?l7oomo013ooooo1_l00?l:
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
oa[ooooo1oooO`05ooooo`Goo`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005o`3o
00Oo003o6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool0
00Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000Cooooo1_l00?l6oomo013ooooo1ol00?l:oooo
o`Koo`001Oooool6o`00o`Koogl04?ooool5o`00o`Ooogl04?ooool5o`00o`Ooogl04?ooool6o`00
o`[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo
003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go
0?l01ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Go
o`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[o
oooo1_oo0005ooooo`Ko003o1_ooO`0Eooooo`Ooogl04?ooool5o`00o`Ooogl04?ooool6o`00o`[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go0?l0
1ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`00
1_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo
1_oo0005ooooo`Ko003o1_ooO`0Eooooo`Ooogl04?ooool5o`00o`Ooogl04?ooool6o`00o`[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_oo
ool7oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go0?l01ol0
0?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`001_l0
o`06o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo1_oo
0005ooooo`Ko003o1_ooO`0Eooooo`Ooogl04?ooool5o`00o`Ooogl04?ooool6o`00o`[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7
oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go0?l01ol00?lK
ooooo`Koogl01Oooool5ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`001_l0o`06
o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Koogl04?ooool7o`00o`[ooooo1_oo0005
ooooo`Ko003o1_ooO`0/ooooo`Go003o1oooO`0@ooooo`Ko003o2_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool0
00Ko0?l01_l00?lEooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05oooo
o`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo
00Cooooo1ooo0004ooooo`Ko003o1_ooO`0Qooooo`Koo`001Oooool6o`00o`Koogl0;?ooool5o`00
o`Ooogl04?ooool6o`00o`[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o5Oooool6o`00o`Oo
ogl01?ooool6ool000Go0?l01ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lEooooo`Go
003o1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`001?ooool6o`00o`Ko
ogl08Oooool6ool000Gooooo1_l00?l6oomo02cooooo1Ol00?l7oomo013ooooo1_l00?l:ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo
1oooO`05ooooo`Goo`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Oo003o
6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool000Ko0?l0
1_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`001Oooool6o`00o`Koogl0
;?ooool5o`00o`Ooogl04?ooool6o`00o`[ooooo00?o0000ooooooooool02oooool002?ooooo0ol0
0008ooooo`Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lEooooo`Ko003o1ooo
O`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Goo`001_l0o`07o`00oaGooooo1Ol0
0?l7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl08Ooo
ool6ool000Gooooo1_l00?l6oomo02cooooo1Ol00?l7oomo013ooooo1_l00?l9ooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o6_ooool7oomo00Gooooo1Ooo0006
o`3o00Ko003o5Oooool6o`00o`Ooogl01?ooool6ool000Go0?l01ol00?lKooooo`Koogl01Oooool5
ool000Ko0?l01ol00?lEooooo`Go003o1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04
ooooo`Ooo`002_ooool6oomo027ooooo1_oo0005ooooo`Ko003o1_ooO`0/ooooo`Go003o1oooO`0@
ooooo`Ko003o2_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?lJooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lEooooo`Ko003o1oooO`04oooo
o`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Goo`001_l0o`07o`00oaGooooo1Ol00?l7oomo
00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl08Oooool6ool0
00Gooooo1_l00?l6oomo02cooooo1Ol00?l7oomo013ooooo1_l00?l:ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00oa[ooooo1oooO`05ooooo`Go
o`001_l0o`06o`00oaGooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo00Go
oooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Oo
ogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`001Oooool6o`00o`Koogl0;?ooool5o`00o`Oo
ogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
8?ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o
6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Oooool5ool000Ko0?l0
1_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`001Oooool6o`00o`Koogl0
;?ooool5o`00o`Ooogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1_oo
0005o`3o00Oo003o6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool5o`00o`Ooogl01Ooo
ool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`001Ooo
ool6o`00o`Koogl0;?ooool5o`00o`Ooogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o6oooool7
oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o5Oooool6
o`00o`_ooooo1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl08Oooool6
ool000Gooooo1_l00?l6oomo02cooooo1Ol00?l7oomo023ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001_l0o`06o`00
oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Goo`001_l0o`07o`00
oaGooooo1_l00?l;ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Ooo`002_ooool6oomo
027ooooo1_oo000;ooooo`Koogl0;?ooool5o`00o`Ooogl08?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0006o`3o00Ko
003o6oooool7oomo00Cooooo1_oo0005o`3o00Oo003o6oooool6oomo00Gooooo1Ooo0006o`3o00Oo
003o9_ooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Ko
o`002oooool6oomo02cooooo1Ol00?l7oomo023ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001_l0o`06o`00oa_ooooo
1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Goo`001_l0o`07o`00obKooooo
1Ooo0006o`3o00Ko003o6oooool7oomo00Cooooo1ooo000:ooooo`Koogl08Oooool6ool000_ooooo
1_ooO`0/ooooo`Go003o1oooO`0Pooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`0Pooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?oo
ool6ool000Go0?l01ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lVooooo`Goo`001_l0
o`06o`00oa_ooooo1oooO`04ooooo`Ooo`002_ooool6oomo027ooooo1_oo000mooooo`Go003o1ooo
O`0Pooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o023ooooo1oooO`05
ooooo`Goo`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05
ooooo`Goo`001_l0o`07o`00obKooooo1Ooo0007o`3o023ooooo1oooO`04ooooo`Ooo`002_ooool6
oomo027ooooo1_oo0012ooooo`Ooogl07oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`0Pooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lKooooo`Ooogl01?ooool6ool0
00Go0?l01ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lVooooo`Goo`001ol0o`0Poooo
o`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`00@_ooool7oomo023ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Go
o`001_l0o`06o`00oa_ooooo1oooO`04ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Go
o`001_l0o`07o`00obKooooo1Ooo0007o`3o023ooooo1oooO`04ooooo`Ooo`002_ooool6oomo027o
oooo1_oo0012ooooo`Ooogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o9_ooool6ool000Go0?l0
1ol00?lKooooo`Koogl01Oooool5ool000Ko0?l01ol00?lVooooo`Goo`001ol0o`0Pooooo`Ooogl0
1?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`00@_ooool7oomo023ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001_l0
o`06o`00obKooooo1_oo0005o`3o00Oo003o6oooool6oomo00Gooooo1Ooo0006o`3o00Oo003o9_oo
ool5ool000Oo0?l08?ooool7oomo00Cooooo1ooo000:ooooo`Koogl08Oooool6ool004;ooooo1ooo
O`0Pooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`0P
ooooo`Ooogl01Oooool5ool000Ko0?l01_l00?lVooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05
ooooo`Koo`001Oooool7o`00obKooooo1Ooo0007o`3o023ooooo1oooO`04ooooo`Ooo`002_ooool6
oomo027ooooo1_oo0012ooooo`Ooogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0006o`3o00Ko003o9_ooool6ool0
00Go0?l01ol00?lKooooo`Koogl01Oooool6ool000Gooooo1ol00?lVooooo`Goo`001ol0o`0Poooo
o`Ooogl01?ooool7ool000[ooooo1_ooO`0Qooooo`Koo`00@_ooool7oomo023ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Go
o`001ol0o`0[ooooo`Koo`001Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`001Oooool7o`00obKo
oooo1Ooo0007o`3o023ooooo1oooO`04ooooo`Ooo`002_ooool6oomo027ooooo1_oo0012ooooo`Oo
ogl08?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
8?ooool7oomo00Gooooo1Ooo0007o`3o02_ooooo1ooo0004ooooo`Oo003o6oooool6oomo00Gooooo
1_oo000booooo`Goo`001ol0o`0Pooooo`Ooogl01?ooool7ool0037ooooo1_oo0012ooooo`Ooogl0
8?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Oooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001ol0
o`0[ooooo`Ooo`001?ooool7o`00oa_ooooo1_ooO`05ooooo`Koo`00=oooool7o`3o023ooooo1ooo
O`04ooooo`Ooo`00<Oooool6ool004;ooooo1oooO`0Pooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo0007o`3o02_ooooo1ooo000Vooooo`Koogl01Ooo
ool6ool003Oooooo1ol0o`0Pooooo`Ooogl01?ooool7ool0037ooooo1_oo001Yooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_oo
ool4o`0000Oooooo1ol0o`0Pooooo`Ooogl01Oooool5ool000Oo0?l0:oooool7ool002Kooooo1_oo
O`05ooooo`Koo`00=oooool7o`3o023ooooo1oooO`04ooooo`Ooo`00<Oooool6ool006Kooooo1?l0
000=ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001ol0o`0[ooooo`Ooo`009_oo
ool6oomo00Gooooo1_oo000gooooo`Oo0?l08?ooool7oomo00Cooooo1ooo000aooooo`Koo`00JOoo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool7o`3o023ooooo1oooO`05ooooo`Goo`001ol0
o`0[ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000gooooo`Oo0?l08?ooool7oomo00Cooooo1ooo
000aooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0008ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`Oo0?l08?ooool7oomo00Gooooo1Ooo
0007o`3o02_ooooo1ooo000Vooooo`Koogl01Oooool6ool003Oooooo1ol0o`0Pooooo`Ooogl01?oo
ool7ool0037ooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol0o`0Pooooo`Ooogl01Oooool5
ool000Oo0?l0:oooool7ool002Kooooo1_ooO`05ooooo`Koo`00=oooool7o`3o023ooooo1oooO`04
ooooo`Ooo`00<Oooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool7o`3o02cooooo1Ooo0007o`3o02_ooooo1ooo000Vooooo`Koogl01Oooool6ool0
03Oooooo1ol0o`0Pooooo`Ooogl01?ooool7ool0037ooooo1_oo001Yooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`0/ooooo`Goo`001ol0o`0[ooooo`Oo
o`009_ooool6oomo00Gooooo1_oo000gooooo`Oo0?l08?ooool7oomo03cooooo1_oo001Yooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`0/ooooo`Goo`00
1ol0o`0[ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000gooooo`Oo0?l08?ooool7oomo03cooooo
1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`0/ooooo`Goo`001ol0o`0[ooooo`Ooo`009_ooool6oomo00Gooooo1_oo000gooooo`Oo0?l08?oo
ool7oomo03cooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`0/ooooo`Goo`001ol0o`0[ooooo`Ooo`00<Oooool6ool003Oooooo1ol0o`0P
ooooo`Ooogl0??ooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool7o`3o02cooooo1Ooo0007o`3o02_ooooo1ooo000aooooo`Koo`00=oooool7o`3o
023ooooo1oooO`0looooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000So
oooo1ol0o`0/ooooo`Goo`001ol0o`0[ooooo`Ooo`00<Oooool6ool003Oooooo1ol0o`1Sooooo`Ko
o`00J?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`0/ooooo`Goo`00
1ol0o`0[ooooo`Ooo`00<Oooool6ool003Oooooo1ol0o`1Sooooo`Koo`00JOooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0;?ooool5ool000Oo0?l0:ooo
ool7ool0037ooooo1_oo000gooooo`Oo0?l0Hoooool6ool006Wooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o02cooooo1Ooo0007o`3o02_ooooo1ooo000a
ooooo`Koo`00=oooool7o`3o06?ooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`0/ooooo`Koo`00<Oooool7ool0037ooooo1_oo000goooo
o`Oo0?l0Hoooool6ool006Wooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o02cooooo1_oo000aooooo`Ooo`00<Oooool6ool003Oooooo1ol0o`1Sooooo`Ko
o`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
;?ooool6ool0037ooooo1ooo000aooooo`Koo`00=oooool7o`3o06?ooooo1_oo001Yooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`0/ooooo`Koo`00<Ooo
ool7ool0037ooooo1_oo000gooooo`Oo0?l0Hoooool6ool006Wooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o02cooooo1_oo000aooooo`Ooo`00<Oooool6
ool003Oooooo1ol0o`1Sooooo`Koo`00JOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0;?ooool6ool0037ooooo1ooo000aooooo`Koo`00=oooool7o`3o
06?ooooo1_oo001Yooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`0/ooooo`Koo`00<Oooool7ool0037ooooo1_oo000gooooo`Oo0?l0d_ooool00ol0003o
ooooooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`0/ooooo`Koo`00<Oooool7ool0037ooooo
1_oo000gooooo`Oo0?l0dOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`0/ooooo`Koo`00<Oooool7ool0037ooooo1_oo000gooooo`Oo0?l0d_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo000g
ooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0Hoooool7ool0037ooooo1_oo000gooooo`Oo0?l0d_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo000gooooo`Oo
0?l0d_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
Hoooool7ool0037ooooo1_oo003ooooooa7ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00oooooolAooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`1Sooooo`Ooo`00<Oooool6
ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0Hoooool7ool0037ooooo1_oo003ooooooa7ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00oooooolAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`1Sooooo`Ooo`00
<Oooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1ol0
o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4?ooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo003ooooo
oa7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o06?o
oooo1ooo000aooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1ol0o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo
003ooooooa7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o06?ooooo1ooo000aooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037o
oooo1_oo003ooooooa7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00002?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00ooooool@ooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00oooooolA
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`1Soooo
o`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo003ooooooa7ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o06?ooooo1ooo000aooooo`Koo`00
oooooolAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0Hoooool7ool0037ooooo1_oo003ooooooa7ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o06?ooooo1ooo000aoooo
o`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`1Sooooo`Ooo`00<Oooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00So
oooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08oooo
o`Oo0?l0Voooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l00007ooooo`Oo0?l0Voooool6ool0
0?oooooo3_ooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Oooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Oooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Ooo
ool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooo
oooo00Sooooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`2Kooooo`Koo`00
oooooolAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`2Kooooo`Koo`00oooooolAooooo`03o`000?oooooooooo
00_ooooo000Sooooo`?o00002?ooool7o`3o09_ooooo1_oo003ooooooa3ooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Ooo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0Voooool6
ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0Voooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0Voooool6ool00?oooooo4Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0000=ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`00
0?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool7o`3o0?oo
oooo/_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o
00001oooool4o`0000Oooooo1ol0o`3oooooojoooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool7o`3o0?oo
oooo/_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0000Sooooo1ol0o`3ooooook7ooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000>
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00006
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
00gooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`Co00001ooo
ool7o`3o0?oooooo[oooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool000kooooo0_l0000;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo
/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo
/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo0ol00008ooooo`Oo0?l0oooo
oonaooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`3o
oooook7ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo
/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooo
oonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool0
2oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`Co00003Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0:ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`04oooooooo0000aOl0000=ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co0000
oooooooIooooo`003Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooo
f_ooool000kooooo0_l00008ooooo`Go0000oooooooHooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Ooo
ool3o`0001Sooooo0ol0000Iooooo`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Ooo
ool2o`0001Oooooo0ol00004ooooo`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_oo
ool5o`0001;ooooo0ol00003ooooo`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000ooo
ool3o`0001?ooooo0ol00003ooooo`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool0
1?l0003oooooooooool0000Gooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`0Fooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo0000
01Wooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00004oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Oooooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eoooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooooooool5o`0001?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Gooooo`00<oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01So
oooo0_l0000Gooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`00
01_ooooo00?o0000ooooooooool05oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo0_l0000Dooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool01?l0003ooooooooo
ooooool4o`0001[ooooo000cooooo`03o`000?oooooooooo01Oooooo00Go0000oooooooooooooooo
o`00000Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00005oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
000Dooooo`04o`000?ooooooooooooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001go
oooo000booooo`;o00006Oooool01Ol0003ooooooooooooooooo000001Oooooo00Go0000oooooooo
ooooooooo`00000Hooooo`;o00006?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000005ooo
ool01Ol0003ooooooooooooooooo000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017o
oooo0_l00004ooooo`;o00005?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Boooo
o`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2
o`0000?ooooo00?o0000ooooooooool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool0
03?ooooo00?o0000ooooooooool06?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo
01Kooooo1Ol0000Iooooo`;o00006?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0
003oooooooooo`03ooooo`;o00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`00
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`04o`000?oooooooooo
ooooo`Go00004oooool00ol0003oooooooooo`03ooooo`;o00006_ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.584672, -0.0392154, \
0.0359213, 0.00184326}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0432099 0.0617284 0.0147151 0.709062 [
[.03704 -0.0125 -3 -9 ]
[.03704 -0.0125 3 0 ]
[.09877 -0.0125 -3 -9 ]
[.09877 -0.0125 3 0 ]
[.16049 -0.0125 -3 -9 ]
[.16049 -0.0125 3 0 ]
[.22222 -0.0125 -3 -9 ]
[.22222 -0.0125 3 0 ]
[.28395 -0.0125 -3 -9 ]
[.28395 -0.0125 3 0 ]
[.34568 -0.0125 -3 -9 ]
[.34568 -0.0125 3 0 ]
[.40741 -0.0125 -3 -9 ]
[.40741 -0.0125 3 0 ]
[.46914 -0.0125 -3 -9 ]
[.46914 -0.0125 3 0 ]
[.53086 -0.0125 -3 -9 ]
[.53086 -0.0125 3 0 ]
[.59259 -0.0125 -6 -9 ]
[.59259 -0.0125 6 0 ]
[.65432 -0.0125 -6 -9 ]
[.65432 -0.0125 6 0 ]
[.71605 -0.0125 -6 -9 ]
[.71605 -0.0125 6 0 ]
[.77778 -0.0125 -6 -9 ]
[.77778 -0.0125 6 0 ]
[.83951 -0.0125 -6 -9 ]
[.83951 -0.0125 6 0 ]
[.90123 -0.0125 -6 -9 ]
[.90123 -0.0125 6 0 ]
[.96296 -0.0125 -6 -9 ]
[.96296 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15653 -18 -4.5 ]
[-0.0125 .15653 0 4.5 ]
[-0.0125 .29834 -18 -4.5 ]
[-0.0125 .29834 0 4.5 ]
[-0.0125 .44015 -18 -4.5 ]
[-0.0125 .44015 0 4.5 ]
[-0.0125 .58196 -18 -4.5 ]
[-0.0125 .58196 0 4.5 ]
[ 0 0 -0.125 0 ]
[.03704 .63053 -3 0 ]
[.03704 .63053 3 9 ]
[.09877 .63053 -3 0 ]
[.09877 .63053 3 9 ]
[.16049 .63053 -3 0 ]
[.16049 .63053 3 9 ]
[.22222 .63053 -3 0 ]
[.22222 .63053 3 9 ]
[.28395 .63053 -3 0 ]
[.28395 .63053 3 9 ]
[.34568 .63053 -3 0 ]
[.34568 .63053 3 9 ]
[.40741 .63053 -3 0 ]
[.40741 .63053 3 9 ]
[.46914 .63053 -3 0 ]
[.46914 .63053 3 9 ]
[.53086 .63053 -3 0 ]
[.53086 .63053 3 9 ]
[.59259 .63053 -6 0 ]
[.59259 .63053 6 9 ]
[.65432 .63053 -6 0 ]
[.65432 .63053 6 9 ]
[.71605 .63053 -6 0 ]
[.71605 .63053 6 9 ]
[.77778 .63053 -6 0 ]
[.77778 .63053 6 9 ]
[.83951 .63053 -6 0 ]
[.83951 .63053 6 9 ]
[.90123 .63053 -6 0 ]
[.90123 .63053 6 9 ]
[.96296 .63053 -6 0 ]
[.96296 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03704 0 m
.03704 .00625 L
s
[(1)] .03704 -0.0125 0 1 Mshowa
.09877 0 m
.09877 .00625 L
s
[(2)] .09877 -0.0125 0 1 Mshowa
.16049 0 m
.16049 .00625 L
s
[(3)] .16049 -0.0125 0 1 Mshowa
.22222 0 m
.22222 .00625 L
s
[(4)] .22222 -0.0125 0 1 Mshowa
.28395 0 m
.28395 .00625 L
s
[(5)] .28395 -0.0125 0 1 Mshowa
.34568 0 m
.34568 .00625 L
s
[(6)] .34568 -0.0125 0 1 Mshowa
.40741 0 m
.40741 .00625 L
s
[(7)] .40741 -0.0125 0 1 Mshowa
.46914 0 m
.46914 .00625 L
s
[(8)] .46914 -0.0125 0 1 Mshowa
.53086 0 m
.53086 .00625 L
s
[(9)] .53086 -0.0125 0 1 Mshowa
.59259 0 m
.59259 .00625 L
s
[(10)] .59259 -0.0125 0 1 Mshowa
.65432 0 m
.65432 .00625 L
s
[(11)] .65432 -0.0125 0 1 Mshowa
.71605 0 m
.71605 .00625 L
s
[(12)] .71605 -0.0125 0 1 Mshowa
.77778 0 m
.77778 .00625 L
s
[(13)] .77778 -0.0125 0 1 Mshowa
.83951 0 m
.83951 .00625 L
s
[(14)] .83951 -0.0125 0 1 Mshowa
.90123 0 m
.90123 .00625 L
s
[(15)] .90123 -0.0125 0 1 Mshowa
.96296 0 m
.96296 .00625 L
s
[(16)] .96296 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15653 m
.00625 .15653 L
s
[(0.2)] -0.0125 .15653 1 0 Mshowa
0 .29834 m
.00625 .29834 L
s
[(0.4)] -0.0125 .29834 1 0 Mshowa
0 .44015 m
.00625 .44015 L
s
[(0.6)] -0.0125 .44015 1 0 Mshowa
0 .58196 m
.00625 .58196 L
s
[(0.8)] -0.0125 .58196 1 0 Mshowa
.125 Mabswid
0 .05017 m
.00375 .05017 L
s
0 .08562 m
.00375 .08562 L
s
0 .12107 m
.00375 .12107 L
s
0 .19198 m
.00375 .19198 L
s
0 .22743 m
.00375 .22743 L
s
0 .26289 m
.00375 .26289 L
s
0 .33379 m
.00375 .33379 L
s
0 .36925 m
.00375 .36925 L
s
0 .4047 m
.00375 .4047 L
s
0 .47561 m
.00375 .47561 L
s
0 .51106 m
.00375 .51106 L
s
0 .54651 m
.00375 .54651 L
s
0 .61742 m
.00375 .61742 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03704 .61178 m
.03704 .61803 L
s
[(1)] .03704 .63053 0 -1 Mshowa
.09877 .61178 m
.09877 .61803 L
s
[(2)] .09877 .63053 0 -1 Mshowa
.16049 .61178 m
.16049 .61803 L
s
[(3)] .16049 .63053 0 -1 Mshowa
.22222 .61178 m
.22222 .61803 L
s
[(4)] .22222 .63053 0 -1 Mshowa
.28395 .61178 m
.28395 .61803 L
s
[(5)] .28395 .63053 0 -1 Mshowa
.34568 .61178 m
.34568 .61803 L
s
[(6)] .34568 .63053 0 -1 Mshowa
.40741 .61178 m
.40741 .61803 L
s
[(7)] .40741 .63053 0 -1 Mshowa
.46914 .61178 m
.46914 .61803 L
s
[(8)] .46914 .63053 0 -1 Mshowa
.53086 .61178 m
.53086 .61803 L
s
[(9)] .53086 .63053 0 -1 Mshowa
.59259 .61178 m
.59259 .61803 L
s
[(10)] .59259 .63053 0 -1 Mshowa
.65432 .61178 m
.65432 .61803 L
s
[(11)] .65432 .63053 0 -1 Mshowa
.71605 .61178 m
.71605 .61803 L
s
[(12)] .71605 .63053 0 -1 Mshowa
.77778 .61178 m
.77778 .61803 L
s
[(13)] .77778 .63053 0 -1 Mshowa
.83951 .61178 m
.83951 .61803 L
s
[(14)] .83951 .63053 0 -1 Mshowa
.90123 .61178 m
.90123 .61803 L
s
[(15)] .90123 .63053 0 -1 Mshowa
.96296 .61178 m
.96296 .61803 L
s
[(16)] .96296 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15653 m
1 .15653 L
s
.99375 .29834 m
1 .29834 L
s
.99375 .44015 m
1 .44015 L
s
.99375 .58196 m
1 .58196 L
s
.125 Mabswid
.99625 .05017 m
1 .05017 L
s
.99625 .08562 m
1 .08562 L
s
.99625 .12107 m
1 .12107 L
s
.99625 .19198 m
1 .19198 L
s
.99625 .22743 m
1 .22743 L
s
.99625 .26289 m
1 .26289 L
s
.99625 .33379 m
1 .33379 L
s
.99625 .36925 m
1 .36925 L
s
.99625 .4047 m
1 .4047 L
s
.99625 .47561 m
1 .47561 L
s
.99625 .51106 m
1 .51106 L
s
.99625 .54651 m
1 .54651 L
s
.99625 .61742 m
1 .61742 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
F
.5 Mabswid
.01235 .01472 m
.01235 .01472 L
.02469 .01472 L
.02469 .01472 L
.01235 .01472 L
s
.07407 .01472 m
.07407 .0732 L
.08642 .0732 L
.08642 .01472 L
F
.07407 .01472 m
.07407 .0732 L
.08642 .0732 L
.08642 .01472 L
.07407 .01472 L
s
.1358 .01472 m
.1358 .06225 L
.14815 .06225 L
.14815 .01472 L
F
.1358 .01472 m
.1358 .06225 L
.14815 .06225 L
.14815 .01472 L
.1358 .01472 L
s
.19753 .01472 m
.19753 .07196 L
.20988 .07196 L
.20988 .01472 L
F
.19753 .01472 m
.19753 .07196 L
.20988 .07196 L
.20988 .01472 L
.19753 .01472 L
s
.25926 .01472 m
.25926 .0187 L
.2716 .0187 L
.2716 .01472 L
F
.25926 .01472 m
.25926 .0187 L
.2716 .0187 L
.2716 .01472 L
.25926 .01472 L
s
.32099 .01472 m
.32099 .0396 L
.33333 .0396 L
.33333 .01472 L
F
.32099 .01472 m
.32099 .0396 L
.33333 .0396 L
.33333 .01472 L
.32099 .01472 L
s
.38272 .01472 m
.38272 .06847 L
.39506 .06847 L
.39506 .01472 L
F
.38272 .01472 m
.38272 .06847 L
.39506 .06847 L
.39506 .01472 L
.38272 .01472 L
s
.44444 .01472 m
.44444 .05379 L
.45679 .05379 L
.45679 .01472 L
F
.44444 .01472 m
.44444 .05379 L
.45679 .05379 L
.45679 .01472 L
.44444 .01472 L
s
.50617 .01472 m
.50617 .02293 L
.51852 .02293 L
.51852 .01472 L
F
.50617 .01472 m
.50617 .02293 L
.51852 .02293 L
.51852 .01472 L
.50617 .01472 L
s
.5679 .01472 m
.5679 .1287 L
.58025 .1287 L
.58025 .01472 L
F
.5679 .01472 m
.5679 .1287 L
.58025 .1287 L
.58025 .01472 L
.5679 .01472 L
s
.62963 .01472 m
.62963 .08017 L
.64198 .08017 L
.64198 .01472 L
F
.62963 .01472 m
.62963 .08017 L
.64198 .08017 L
.64198 .01472 L
.62963 .01472 L
s
.69136 .01472 m
.69136 .08266 L
.7037 .08266 L
.7037 .01472 L
F
.69136 .01472 m
.69136 .08266 L
.7037 .08266 L
.7037 .01472 L
.69136 .01472 L
s
.75309 .01472 m
.75309 .02641 L
.76543 .02641 L
.76543 .01472 L
F
.75309 .01472 m
.75309 .02641 L
.76543 .02641 L
.76543 .01472 L
.75309 .01472 L
s
.81481 .01472 m
.81481 .01795 L
.82716 .01795 L
.82716 .01472 L
F
.81481 .01472 m
.81481 .01795 L
.82716 .01795 L
.82716 .01472 L
.81481 .01472 L
s
.87654 .01472 m
.87654 .08216 L
.88889 .08216 L
.88889 .01472 L
F
.87654 .01472 m
.87654 .08216 L
.88889 .08216 L
.88889 .01472 L
.87654 .01472 L
s
.93827 .01472 m
.93827 .10083 L
.95062 .10083 L
.95062 .01472 L
F
.93827 .01472 m
.93827 .10083 L
.95062 .10083 L
.95062 .01472 L
.93827 .01472 L
s
0 1 0 r
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
F
.02469 .01472 m
.02469 .60332 L
.03704 .60332 L
.03704 .01472 L
.02469 .01472 L
s
.08642 .01472 m
.08642 .01496 L
.09877 .01496 L
.09877 .01472 L
F
.08642 .01472 m
.08642 .01496 L
.09877 .01496 L
.09877 .01472 L
.08642 .01472 L
s
.14815 .01472 m
.14815 .01472 L
.16049 .01472 L
.16049 .01472 L
F
.14815 .01472 m
.14815 .01472 L
.16049 .01472 L
.16049 .01472 L
.14815 .01472 L
s
.20988 .01472 m
.20988 .01546 L
.22222 .01546 L
.22222 .01472 L
F
.20988 .01472 m
.20988 .01546 L
.22222 .01546 L
.22222 .01472 L
.20988 .01472 L
s
.2716 .01472 m
.2716 .05354 L
.28395 .05354 L
.28395 .01472 L
F
.2716 .01472 m
.2716 .05354 L
.28395 .05354 L
.28395 .01472 L
.2716 .01472 L
s
.33333 .01472 m
.33333 .01571 L
.34568 .01571 L
.34568 .01472 L
F
.33333 .01472 m
.33333 .01571 L
.34568 .01571 L
.34568 .01472 L
.33333 .01472 L
s
.39506 .01472 m
.39506 .01496 L
.40741 .01496 L
.40741 .01472 L
F
.39506 .01472 m
.39506 .01496 L
.40741 .01496 L
.40741 .01472 L
.39506 .01472 L
s
.45679 .01472 m
.45679 .01496 L
.46914 .01496 L
.46914 .01472 L
F
.45679 .01472 m
.45679 .01496 L
.46914 .01496 L
.46914 .01472 L
.45679 .01472 L
s
.51852 .01472 m
.51852 .09286 L
.53086 .09286 L
.53086 .01472 L
F
.51852 .01472 m
.51852 .09286 L
.53086 .09286 L
.53086 .01472 L
.51852 .01472 L
s
.58025 .01472 m
.58025 .01496 L
.59259 .01496 L
.59259 .01472 L
F
.58025 .01472 m
.58025 .01496 L
.59259 .01496 L
.59259 .01472 L
.58025 .01472 L
s
.64198 .01472 m
.64198 .01472 L
.65432 .01472 L
.65432 .01472 L
F
.64198 .01472 m
.64198 .01472 L
.65432 .01472 L
.65432 .01472 L
.64198 .01472 L
s
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
F
.7037 .01472 m
.7037 .01472 L
.71605 .01472 L
.71605 .01472 L
.7037 .01472 L
s
.76543 .01472 m
.76543 .01496 L
.77778 .01496 L
.77778 .01472 L
F
.76543 .01472 m
.76543 .01496 L
.77778 .01496 L
.77778 .01472 L
.76543 .01472 L
s
.82716 .01472 m
.82716 .01496 L
.83951 .01496 L
.83951 .01472 L
F
.82716 .01472 m
.82716 .01496 L
.83951 .01496 L
.83951 .01472 L
.82716 .01472 L
s
.88889 .01472 m
.88889 .01496 L
.90123 .01496 L
.90123 .01472 L
F
.88889 .01472 m
.88889 .01496 L
.90123 .01496 L
.90123 .01472 L
.88889 .01472 L
s
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
F
.95062 .01472 m
.95062 .01472 L
.96296 .01472 L
.96296 .01472 L
.95062 .01472 L
s
0 0 1 r
.03704 .01472 m
.03704 .19739 L
.04938 .19739 L
.04938 .01472 L
F
.03704 .01472 m
.03704 .19739 L
.04938 .19739 L
.04938 .01472 L
.03704 .01472 L
s
.09877 .01472 m
.09877 .01671 L
.11111 .01671 L
.11111 .01472 L
F
.09877 .01472 m
.09877 .01671 L
.11111 .01671 L
.11111 .01472 L
.09877 .01472 L
s
.16049 .01472 m
.16049 .01571 L
.17284 .01571 L
.17284 .01472 L
F
.16049 .01472 m
.16049 .01571 L
.17284 .01571 L
.17284 .01472 L
.16049 .01472 L
s
.22222 .01472 m
.22222 .0187 L
.23457 .0187 L
.23457 .01472 L
F
.22222 .01472 m
.22222 .0187 L
.23457 .0187 L
.23457 .01472 L
.22222 .01472 L
s
.28395 .01472 m
.28395 .2066 L
.2963 .2066 L
.2963 .01472 L
F
.28395 .01472 m
.28395 .2066 L
.2963 .2066 L
.2963 .01472 L
.28395 .01472 L
s
.34568 .01472 m
.34568 .03463 L
.35802 .03463 L
.35802 .01472 L
F
.34568 .01472 m
.34568 .03463 L
.35802 .03463 L
.35802 .01472 L
.34568 .01472 L
s
.40741 .01472 m
.40741 .0182 L
.41975 .0182 L
.41975 .01472 L
F
.40741 .01472 m
.40741 .0182 L
.41975 .0182 L
.41975 .01472 L
.40741 .01472 L
s
.46914 .01472 m
.46914 .01696 L
.48148 .01696 L
.48148 .01472 L
F
.46914 .01472 m
.46914 .01696 L
.48148 .01696 L
.48148 .01472 L
.46914 .01472 L
s
.53086 .01472 m
.53086 .31088 L
.54321 .31088 L
.54321 .01472 L
F
.53086 .01472 m
.53086 .31088 L
.54321 .31088 L
.54321 .01472 L
.53086 .01472 L
s
.59259 .01472 m
.59259 .01646 L
.60494 .01646 L
.60494 .01472 L
F
.59259 .01472 m
.59259 .01646 L
.60494 .01646 L
.60494 .01472 L
.59259 .01472 L
s
.65432 .01472 m
.65432 .01496 L
.66667 .01496 L
.66667 .01472 L
F
.65432 .01472 m
.65432 .01496 L
.66667 .01496 L
.66667 .01472 L
.65432 .01472 L
s
.71605 .01472 m
.71605 .01521 L
.7284 .01521 L
.7284 .01472 L
F
.71605 .01472 m
.71605 .01521 L
.7284 .01521 L
.7284 .01472 L
.71605 .01472 L
s
.77778 .01472 m
.77778 .01696 L
.79012 .01696 L
.79012 .01472 L
F
.77778 .01472 m
.77778 .01696 L
.79012 .01696 L
.79012 .01472 L
.77778 .01472 L
s
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
F
.83951 .01472 m
.83951 .01472 L
.85185 .01472 L
.85185 .01472 L
.83951 .01472 L
s
.90123 .01472 m
.90123 .01521 L
.91358 .01521 L
.91358 .01472 L
F
.90123 .01472 m
.90123 .01521 L
.91358 .01521 L
.91358 .01472 L
.90123 .01472 L
s
.96296 .01472 m
.96296 .01521 L
.97531 .01521 L
.97531 .01472 L
F
.96296 .01472 m
.96296 .01521 L
.97531 .01521 L
.97531 .01472 L
.96296 .01472 L
s
1 .5 0 r
.04938 .01472 m
.04938 .01496 L
.06173 .01496 L
.06173 .01472 L
F
.04938 .01472 m
.04938 .01496 L
.06173 .01496 L
.06173 .01472 L
.04938 .01472 L
s
.11111 .01472 m
.11111 .06175 L
.12346 .06175 L
.12346 .01472 L
F
.11111 .01472 m
.11111 .06175 L
.12346 .06175 L
.12346 .01472 L
.11111 .01472 L
s
.17284 .01472 m
.17284 .08166 L
.18519 .08166 L
.18519 .01472 L
F
.17284 .01472 m
.17284 .08166 L
.18519 .08166 L
.18519 .01472 L
.17284 .01472 L
s
.23457 .01472 m
.23457 .062 L
.24691 .062 L
.24691 .01472 L
F
.23457 .01472 m
.23457 .062 L
.24691 .062 L
.24691 .01472 L
.23457 .01472 L
s
.2963 .01472 m
.2963 .03089 L
.30864 .03089 L
.30864 .01472 L
F
.2963 .01472 m
.2963 .03089 L
.30864 .03089 L
.30864 .01472 L
.2963 .01472 L
s
.35802 .01472 m
.35802 .08764 L
.37037 .08764 L
.37037 .01472 L
F
.35802 .01472 m
.35802 .08764 L
.37037 .08764 L
.37037 .01472 L
.35802 .01472 L
s
.41975 .01472 m
.41975 .08166 L
.4321 .08166 L
.4321 .01472 L
F
.41975 .01472 m
.41975 .08166 L
.4321 .08166 L
.4321 .01472 L
.41975 .01472 L
s
.48148 .01472 m
.48148 .07345 L
.49383 .07345 L
.49383 .01472 L
F
.48148 .01472 m
.48148 .07345 L
.49383 .07345 L
.49383 .01472 L
.48148 .01472 L
s
.54321 .01472 m
.54321 .05255 L
.55556 .05255 L
.55556 .01472 L
F
.54321 .01472 m
.54321 .05255 L
.55556 .05255 L
.55556 .01472 L
.54321 .01472 L
s
.60494 .01472 m
.60494 .04383 L
.61728 .04383 L
.61728 .01472 L
F
.60494 .01472 m
.60494 .04383 L
.61728 .04383 L
.61728 .01472 L
.60494 .01472 L
s
.66667 .01472 m
.66667 .05205 L
.67901 .05205 L
.67901 .01472 L
F
.66667 .01472 m
.66667 .05205 L
.67901 .05205 L
.67901 .01472 L
.66667 .01472 L
s
.7284 .01472 m
.7284 .04831 L
.74074 .04831 L
.74074 .01472 L
F
.7284 .01472 m
.7284 .04831 L
.74074 .04831 L
.74074 .01472 L
.7284 .01472 L
s
.79012 .01472 m
.79012 .08614 L
.80247 .08614 L
.80247 .01472 L
F
.79012 .01472 m
.79012 .08614 L
.80247 .08614 L
.80247 .01472 L
.79012 .01472 L
s
.85185 .01472 m
.85185 .06922 L
.8642 .06922 L
.8642 .01472 L
F
.85185 .01472 m
.85185 .06922 L
.8642 .06922 L
.8642 .01472 L
.85185 .01472 L
s
.91358 .01472 m
.91358 .06474 L
.92593 .06474 L
.92593 .01472 L
F
.91358 .01472 m
.91358 .06474 L
.92593 .06474 L
.92593 .01472 L
.91358 .01472 L
s
.97531 .01472 m
.97531 .03363 L
.98765 .03363 L
.98765 .01472 L
F
.97531 .01472 m
.97531 .03363 L
.98765 .03363 L
.98765 .01472 L
.97531 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00<_ooool3o`0001Sooooo1Ol0000Hooooo`?o00006Oooool3o`0001Sooooo0ol0000Ioooo
o`?o00006_ooool00ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0001Oooooo0ol00004oooo
o`;o00004_ooool3o`0000?ooooo0ol0000Cooooo`?o00000_ooool5o`0001;ooooo0ol00003oooo
o`?o00004oooool3o`0000Cooooo0ol0000Booooo`?o00000oooool3o`0001?ooooo0ol00003oooo
o`?o00006_ooool003?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Goooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000005oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oo
oooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`Go00006oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooooooool5o`0001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Gooooo`00<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool05Oooool4o`0001_ooooo00?o0000ooooooooool0
5oooool3o`0001Wooooo1?l0000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool4o`0001[ooooo000coooo
o`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool000006?ooool4o`0001Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Dooooo`04o`000?oooooooooo
ooooo`Co00005?ooool01Ol0003ooooooooooooooooo000001gooooo000booooo`;o00006Oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Gooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo
000001Gooooo0_l00004ooooo`04o`000?ooooooooooo`00017ooooo0_l00004ooooo`;o00005?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool05?ooool2o`0000Cooooo00?o0000ooooooooool06_ooool003?ooooo00?o0000ooooooooool0
6?ooool3o`0001Wooooo0ol0000Jooooo`03o`000?oooooooooo01Kooooo1Ol0000Iooooo`;o0000
6?ooool5o`0001Sooooo0ol0000Iooooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003o
ooooooooo`03ooooo`;o00006_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool002?oooooool00035
o`0000gooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00001oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02oooool001Wooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00001_ooool6o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001Ol0
o`06o`00o`Ooogl01?l00006ool000Go0?l01_l00?l6oomo00Go00001_oo0005o`3o00Ko003o1_oo
O`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol00005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo
0006o`3o00Go003o1oooO`04o`0000Koo`001_l0o`05o`00o`Ooogl01?l00006ool000Go0?l01_l0
0?l6oomo00Go00001_oo0005o`3o00Ko003o1_ooO`05o`0000Goo`001_l0o`06o`00o`Koogl01Ol0
0005ool000Ko0?l01Ol00?l7oomo00Go00001Ooo0006o`3o00Go003o1oooO`04o`0000Koo`001_l0
o`05o`00o`Ooogl01Ol0000=ooooo`006Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo0005ooooo`Go003o1oooO`05ooooo`Koo`002_oo
ool7oomo00Cooooo1ooo0004ooooo`Ko003o1oooO`04ooooo`Koo`001Ol0o`06o`00o`Koogl01Ooo
ool7ool000Cooooo1_l00?l6oomo00Gooooo1_oo0005ooooo`Ko003o1_ooO`05ooooo`Koo`001Ooo
ool5o`00o`Ooogl01Oooool5ool000Ko0?l01Ol00?l7oomo00Cooooo1ooo0005ooooo`Go003o1ooo
O`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo000:ooooo`Koogl01Oooool6ool000Gooooo1_l0
0?l6oomo00Gooooo1_oo000:ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_oo
ool7oomo00Cooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00Gooooo1_oo
000:ooooo`Ooogl01?ooool7ool000Cooooo1_l00?l7oomo00Cooooo1_oo0005o`3o00Ko003o1_oo
O`05ooooo`Ooo`001?ooool6o`00o`Koogl01Oooool6ool000_ooooo1_ooO`05ooooo`Koo`002_oo
ool7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo1ooo
000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo1ooo
O`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool00ol0003ooooooooo
o`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6
ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5
o`3o00Ko003o1_ooO`05ooooo`Ooo`001?ooool6o`00o`Koogl01Oooool6ool000_ooooo1_ooO`05
ooooo`Koo`002_ooool7oomo00Gooooo1Ooo0006o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7
oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6
oomo01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:oooo
o`Koo`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:oooo
o`Go0?l01_l00?l6oomo00Gooooo1ooo0004ooooo`Ko003o1_ooO`05ooooo`Koo`002oooool6oomo
00Gooooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo
00Cooooo1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo
01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Ko
o`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go
0?l01_l00?l6oomo00Gooooo1ooo0004ooooo`Ko003o1_ooO`05ooooo`Koo`002oooool6oomo00Go
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Co
oooo1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Go
oooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`00
2_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l0
1_l00?l6oomo00Gooooo1ooo0004ooooo`Ko003o1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo
1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo
1ooo000:ooooo`Koogl01Oooool7ool000[ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo
1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`04ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl01Ooo
ool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`06o`00o`Koogl01Ooo
ool7ool000Cooooo1_l00?l6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_oo
O`05ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[ooooo1ooo
O`04ooooo`Ooo`002_ooool7oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7
oomo00Cooooo1ooo000:ooooo`Ooogl02_ooool5o`3o00Oo003o2_ooool7ool000Cooooo1_l00?l6
oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7
oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`002_ooool6
oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7
oomo00Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o2_ooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:oooo
o`Ooogl02_ooool5o`3o00Oo003o2_ooool7ool000Cooooo1_l00?l6oomo00Gooooo1_oo000;oooo
o`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:oooo
o`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`0Eoooo
o`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`005Oooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00Go
oooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01ol00?l:ooooo`Oo
o`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1oooO`0:ooooo`Ko
0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl01?ooool7ool000[ooooo1_ooO`05ooooo`Oo
o`002_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Oo
o`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l0
1ol00?l:ooooo`Koo`002_ooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool000[ooooo
1oooO`0:ooooo`Go0?l01ol00?l:ooooo`Ooo`002_ooool6oomo00Gooooo1_oo000;ooooo`Koogl0
1Oooool6ool000[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000:ooooo`Ooogl0
1?ooool7ool000[ooooo1_ooO`05ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl0
1Oooool6ool000[ooooo1oooO`04ooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`002_ooool7oomo00Gooooo1_oo
000:ooooo`Ooogl01?ooool7ool000[ooooo1oooO`0:ooooo`Go0?l01ol00?lKooooo`Koogl01Ooo
ool6ool000_ooooo1_ooO`05ooooo`Koo`002_ooool7oomo00[ooooo1_l0o`05o`00o`Ooogl01?oo
ool7ool000[ooooo1oooO`04ooooo`Ooo`002_ooool6oomo00Gooooo1ooo000:ooooo`Koogl05_oo
ool6oomo01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000Eooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000:
ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`002_ooool7oomo00[ooooo1Ol0o`07
o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo1_oo000:ooooo`Ooogl02_ooool6
o`3o00Go003o1oooO`04ooooo`Ooo`002_ooool7oomo00Cooooo1ooo000:ooooo`Koogl01Oooool7
ool000[ooooo1_ooO`0Fooooo`Koogl05Oooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7
ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003o2_ooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:oooo
o`Ooogl02_ooool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool0
00[ooooo1oooO`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Eooooo`Ooo`002_ooool6oomo
00Gooooo1ooo000:ooooo`Koogl05_ooool6oomo01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo
00Cooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Oo
o`002_ooool7oomo00[ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Go
oooo1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`005Oooool7ool000[o
oooo1_ooO`05ooooo`Ooo`002_ooool6oomo01Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool000[o
oooo1oooO`04ooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo
1_l0o`07o`00o`[ooooo1_oo000:ooooo`Ooogl01Oooool6ool000[ooooo1oooO`04ooooo`Ooo`00
2_ooool7oomo00[ooooo1Ol0o`07o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo00Gooooo
1_oo000:ooooo`Ooogl02_ooool6o`3o00Go003o1oooO`04ooooo`Ooo`005Oooool7ool000[ooooo
1_ooO`05ooooo`Ooo`009_ooool6oomo01Gooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo
1ooo000Dooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_oo
ool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl02_oo
ool5o`3o00Oo003o6oooool6oomo00Gooooo1_oo000;ooooo`Koogl01Oooool6ool000[ooooo1ooo
O`0:ooooo`Ko0?l01Ol00?l7oomo00Cooooo1ooo000Eooooo`Ooo`002_ooool6oomo00Gooooo1ooo
000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6
ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl03oooool7
o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo1oooO`0:ooooo`Ko0?l01_l00?l:
ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000:
ooooo`Ooogl01?ooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo
00Cooooo1ooo000:ooooo`Ooogl03oooool7o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo
01Gooooo1oooO`0:ooooo`Ko0?l01_l00?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Voooo
o`Koogl05Oooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool000[o
oooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo1ooo000:ooooo`Ooogl03oooool7o`00oa_o
oooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo1oooO`0:ooooo`Ko0?l01_l00?l:ooooo`Oo
o`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl05Oooool7oomo00Gooooo1_oo000:ooooo`Oo
ogl01?ooool7ool001Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool6o`3o00Oo003o2_ooool6ool000[ooooo1oooO`05ooooo`Koo`002_ooool7oomo00Cooooo
1ooo000:ooooo`Ooogl03oooool7o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo
1oooO`0:ooooo`Ko0?l01_l00?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl0
5Oooool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool002Kooooo1ooo
O`04ooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo1ooo
O`0:ooooo`Ko0?l01_l00?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl05Ooo
ool7oomo00Gooooo1_oo000:ooooo`Ooogl01?ooool7ool001Gooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o2_ooool6ool002Kooooo1oooO`04
ooooo`Ooo`008?ooool7o`00oa_ooooo1_ooO`05ooooo`Koo`002oooool6oomo01Gooooo1oooO`0:
ooooo`Ko0?l01_l00?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl05Oooool7
oomo00Gooooo1_oo000Eooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?l:ooooo`Koo`009_ooool7oomo00Cooooo1ooo000Poooo
o`Oo003o6oooool6oomo00Gooooo1_oo000;ooooo`Koogl05Oooool7oomo00[ooooo1_l0o`06o`00
o`[ooooo1ooo000Eooooo`Ooo`005Oooool7ool002Kooooo1_ooO`0Eooooo`Ooogl01Oooool6ool0
01Gooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1_l0o`07o`00o`[ooooo1_oo000Vooooo`Ooogl01?ooool7ool0023ooooo1ol00?lKooooo`Ko
ogl05_ooool6oomo01Gooooo1oooO`0:ooooo`Ko0?l01_l00?l:ooooo`Ooo`005Oooool7ool001Go
oooo1ooo000Vooooo`Koogl08Oooool6ool001Gooooo1ooo000Eooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00o`[ooooo1_oo000Vooooo`Ooogl0
1?ooool7ool0023ooooo1ol00?lKooooo`Koogl05_ooool6oomo01Gooooo1oooO`0:ooooo`Ko0?l0
1_l00?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl08Oooool6ool001Gooooo
1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0
o`07o`00ocKooooo1oooO`0[ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Vooooo`Ko0?l01_l0
0?l:ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl08Oooool6ool001Gooooo1ooo
000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ocKooooo1oooO`0[ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Vooooo`Ko0?l01_l00?l:
ooooo`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl08Oooool6ool001Gooooo1ooo000E
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00
ocKooooo1oooO`0[ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Vooooo`Ko0?l01_l00?l:oooo
o`Ooo`005Oooool7ool001Gooooo1ooo000Vooooo`Koogl08Oooool6ool001Gooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ocKo
oooo1oooO`0[ooooo`Oo003o6oooool6oomo01Kooooo1_ooO`0Vooooo`Ko0?l01_l00?l:ooooo`Oo
o`00<Oooool7ool002Kooooo1_ooO`0Qooooo`Koo`005Oooool7ool001Gooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00oa_ooooo
1_ooO`12ooooo`Ko0?l01_l00?l:ooooo`Ooo`00G_ooool6oomo03cooooo1ooo000Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00002?ooool6o`3o00Oo003oJ?ooool7o`00oa_ooooo1_oo
O`12ooooo`Ko0?l01_l00?l:ooooo`Ooo`00G_ooool6oomo03cooooo1ooo000Dooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00oa_ooooo1_ooO`12
ooooo`Ko0?l01_l00?l:ooooo`Ooo`00X?ooool7ool001Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00of?ooooo1_l0o`06o`00
o`[ooooo1ooo002Pooooo`Ooo`005Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oHoooool6o`3o00Ko003o2_ooool7ool00:3o
oooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7ool00:3ooooo1ooo000Eooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mYooooo`Ko003o2_ooool7ool00:3ooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7
ool00:3ooooo1ooo000Eooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7ool00:3ooooo1ooo000Eoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mYooooo`Ko003o2_ooool7ool00;cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?l:ooooo`Ooo`00
_?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mXooooo`Oo003oJOooool6o`00o`[ooooo1ooo002looooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7
ool00;cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oJ?ooool7o`00ofWooooo1_l00?l:ooooo`Ooo`00_?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00o`[o
oooo1ooo002looooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7ool00;cooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l0
0?l:ooooo`Ooo`00_?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07
o`00ofSooooo1ol00?mYooooo`Ko003o2_ooool7ool00;_ooooo0_l0000=ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00o`[ooooo1ooo002loooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mYooooo`Ko003o2_ooool7ool00;cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?l:ooooo`Ooo`00
_?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol0
0?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?o=ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYoooo
o`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko
0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?o=ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?o=oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo
00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSo
oooo1ol00?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oJ?ooool7o`00ofWooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`Co00001oooool6o`3o
00Oo003oJ?ooool7o`00ofWooooo1_l00?o:ooooo`Co00003Oooool000gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool6
o`3o00Oo003oJ?ooool7o`00ofWooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003ooooooooo
o`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1_l0o`07
o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7o`00ofWo
oooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003oJ?ooool7
o`00ofWooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgo
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o00Oo003o
J?ooool7o`00ofWooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6
o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool6o`3o
00Oo003oJ?ooool7o`00ofWooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003ocOooool00ol0003o
ooooooooo`0;ooooo`008oooool3o`0000Sooooo1_l0o`07o`00ofSooooo1ol00?mYooooo`Ko003o
c?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1_l0o`07o`00ofSooooo1ol0
0?mYooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Ko0?l01ol00?mXooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o06kooooo1ol00?mYooooo`Ko003ocOooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0K_ooool7o`00ofWo
oooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`1^ooooo`Oo003oJOooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o06kooooo1ol00?mYooooo`Ko003ocOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko
003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003ooooo
ooooo`0;ooooo`008oooool3o`0000Sooooo1ol0o`3Nooooo`Ko003oc?ooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_oo
ool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko
003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7
o`3o0=kooooo1_l00?o<ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003o
cOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0g_oo
ool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000ooooooooool02oooool000kooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00Sooooo
1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool7o`3o0=kooooo
1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
1Ol00006ooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003ooooo
ooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo1?l00007ooooo`Oo0?l0g_ooool6o`00ol[ooooo1?l0000=ooooo`003Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool02?ooool7o`3o0=ko
oooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003o
ooooooooo`0;ooooo`003_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0g_ooool6o`00olgooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0=kooooo1_l00?o=ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3Nooooo`Ko003ocOooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oooooo/Oooool2o`00
00gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooo
ok;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oo
oooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00002?ooool7o`3o0?oo
oooo/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooo
ok;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oo
oooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0
oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
2?ooool7o`3o0?oooooo/Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0
o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7
o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08oooo
o`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00So
oooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
2?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000>oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`08oooo
o`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001ooo
ool4o`0000Oooooo1ol0o`3oooooojoooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooooooo
o`0;ooooo`003_ooool2o`0000[ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`3o
oooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o
0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo
0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo
1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo00?o0000ooooooooool02?oo
ool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08
ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool002?ooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool002?ooooo00?o0000
ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02oooool002?ooooo0ol00008ooooo`Oo0?l0oooooonaooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonboooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;o
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo0ol00007ooooo`Co00001oooool7o`3o0?oooooo[oooool4o`00
00gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000ooooooooool02oooool0
00gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0003oooooooooo`0;ooooo`003_ooool2
o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonbooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooook;ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool02?ooool7o`3o0?oooooo/_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`08ooooo`Oo0?l0oooooonb
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00Sooooo1ol0o`3ooooo
ok;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool002?oooooool00035o`0000gooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo000booooo`?o00006?ooool5o`0001Sooooo0ol0000Iooooo`?o00006?ooool3o`00
01Wooooo0ol0000Jooooo`03o`000?oooooooooo01Sooooo0ol0000Iooooo`;o00005oooool3o`00
00Cooooo0_l0000Booooo`?o00000oooool3o`0001?ooooo0ol00002ooooo`Go00004_ooool3o`00
00?ooooo0ol0000Cooooo`?o00001?ooool3o`0001;ooooo0ol00003ooooo`?o00004oooool3o`00
00?ooooo0ol0000Jooooo`00<oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
01Oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo01Kooooo00Go0000
ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`0Gooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000C
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool05oooool003?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Cooooo1Ol0000Kooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000Jooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooooooo`Go00004oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo
000cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool2o`0001Oooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`0Eooooo`Co00006oooool00ol0003ooooo
ooooo`0Gooooo`?o00006Oooool4o`0001Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool2o`0001Co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooooooo`Co00006_ooool0
03?ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooo`00000Hooooo`Co00006?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Cooooo00Co0000oooo
oooooooooooo1?l0000Dooooo`05o`000?ooooooooooooooool000007Oooool003;ooooo0_l0000I
ooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo000001Sooooo
0_l0000Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000001Oooooo00Go0000ooooooooooooooooo`00000Gooooo`05o`000?oooooooooo
ooooool000005Oooool2o`0000Cooooo00Co0000oooooooooooo00004Oooool2o`0000Cooooo0_l0
000Dooooo`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000004_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool00ol0003o
ooooooooo`0Dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`00<oooool00ol0003ooooo
ooooo`0Hooooo`?o00006Oooool3o`0001[ooooo00?o0000ooooooooool05_ooool5o`0001Wooooo
0_l0000Hooooo`Go00006?ooool3o`0001Wooooo0ol0000Gooooo`03o`000?oooooooooo00?ooooo
0_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`?o00005?ooool00ol0003oooooooooo`02ooooo`?o00005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo1Ol0000Cooooo`03
o`000?oooooooooo00?ooooo0_l0000Jooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-0.584672, -0.066531, 0.0359213, \
0.00312718}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(263.783197`8.872792121011857\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .46848 L
.2381 .46848 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .46848 L
.2381 .46848 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01939 L
.71429 .01939 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01939 L
.71429 .01939 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .14204 L
.95238 .14204 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .14204 L
.95238 .14204 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF00000000FFFF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF8000FF8000FF80000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF80000000FFFF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF00000000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF80000000FFFF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF00000000FF0000FF
FF80000000FFFF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF80000000FF
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FFFF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF00000000FFFF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .45638 L
.47619 .45638 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .45638 L
.47619 .45638 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .15644 L
.71429 .15644 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .15644 L
.71429 .15644 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF80000000FFFF8000FF80000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF00FF00
0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF800000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FFFF0000FF0000
FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FFFF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF800000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FFFF80000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01627 L
.2381 .01627 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01627 L
.2381 .01627 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .16269 L
.47619 .16269 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .16269 L
.47619 .16269 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .418 L
.71429 .418 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .418 L
.71429 .418 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04484 L
.95238 .04484 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04484 L
.95238 .04484 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF80000000FFFF800000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000
0000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF000000FF00FF00
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FFFF0000FF0000
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF00FF0000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF0000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF00FF0000FF000000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF0000FF8000FF80000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF0000FF0000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FFFF8000
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FFFF80000000FFFF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF8000
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
00FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FFFF80000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FFFF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF8000
0000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FFFF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF800000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF00
FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .24154 L
.2381 .24154 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .24154 L
.2381 .24154 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .06695 L
.71429 .06695 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .06695 L
.71429 .06695 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .3208 L
.95238 .3208 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .3208 L
.95238 .3208 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF80000000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000
FF0000FF00000000FF00FF000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF0000FF8000FF0000
FF8000FF80000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF80000000FFFF0000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FFFF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000
FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF80000000FFFF80000000FFFF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF80000000FFFF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF80000000FFFF8000FF80000000FF0000FFFF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FFFF0000FF8000FF0000FF0000
FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF0000FF8000
FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
0000FFFF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF80000000FFFF8000FF0000FF8000FF80000000FF0000FFFF80000000FF
FF8000FF80000000FF0000FF0000FF
FF8000FF0000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF0000FF8000
FF80000000FF0000FFFF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF80000000FFFF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FFFF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF80000000FFFF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF0000
FF0000FF0000FF0000FF8000FF0000
0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF80000000FFFF0000FF0000FF80000000FF0000FFFF8000FF0000
FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF00000000FF0000FFFF0000
FF0000FF8000FF8000FF8000FF8000
0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF00000000FF
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000
0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF
FF80000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
0000FFFF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF00000000FFFF80000000FF0000FF0000FF00FF00
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF80000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FFFF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF80000000FF0000FF
FF80000000FFFF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
0000FF0000FF0000FFFF8000FF0000FF8000FF0000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF00000000FF
FF8000FF8000FF0000FF0000FF80000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF80000000FFFF0000FF0000FF0000FF80000000FF0000FF0000FFFF0000FF0000
FF0000FF80000000FFFF80000000FFFF0000FF0000FF8000FF8000FF8000FF80000000FF
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FF
FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF80000000FF0000FF0000FFFF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF80000000FFFF80000000FFFF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF80000000FFFF8000
FF0000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF80000000FFFF8000FF80000000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF80000000FFFF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF80000000FFFF80000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF80000000FFFF8000FF8000
0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF80000000FF0000FFFF80000000FFFF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000
FF80000000FFFF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .49101 L
.2381 .49101 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .49101 L
.2381 .49101 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .07425 L
.47619 .07425 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .07425 L
.47619 .07425 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .03483 L
.71429 .03483 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .03483 L
.71429 .03483 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04171 L
.95238 .04171 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04171 L
.95238 .04171 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF8000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF8000FF8000
FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF8000FF00000000FFFF8000FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FF
FF0000FF8000FF8000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF8000FF80000000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF800000FF000000FFFF0000
FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF80000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF8000FF80000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000FF000000FF00
FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF000000FF00
FF0000FF0000FF0000FF00000000FFFF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000
FF8000FF8000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF80000000FFFF0000FF0000FF8000FF80000000FFFF0000
FF0000FF8000FF00000000FFFF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF
FF0000FF800000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF800000FF00FF000000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF800000FF00FF0000FF0000
FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF00000000FFFF8000FF8000FF8000FF000000FF000000FF
FF8000FF800000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF00000000FFFF8000FF8000FF8000FF000000FF000000FF
FF8000FF8000FF8000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF000000FF000000FF
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF00000000FF
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF00000000FFFF8000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF00000000FFFF0000FF0000FF8000FF0000FF000000FF0000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF00000000FFFF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF000000FF0000FF00FF0000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF0000FF00000000FFFF0000FF80000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF00000000FFFF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF000000FF00FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF8000FF0000FF0000FF000000FF00FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .2065 L
.2381 .2065 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .2065 L
.2381 .2065 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .36356 L
.47619 .36356 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .36356 L
.47619 .36356 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02503 L
.71429 .02503 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02503 L
.71429 .02503 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04672 L
.95238 .04672 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04672 L
.95238 .04672 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
0000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000
FF8000FF8000FF8000FF8000FF8000
FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF00000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF000000FF0000FF000000FFFF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF000000FF0000FF000000FFFF8000FF80000000FFFF0000
0000FFFF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000
00FF0000FF00FF00000000FFFF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000
0000FFFF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF00000000FF00FF00FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000
FF8000FF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00000000FFFF8000
FF8000FF8000FF0000FF8000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000
00FF00FF00000000FFFF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
00FF00FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000
00FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF8000FF000000FF0000FF00FF0000FF00000000FFFF8000FF8000FF800000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF00000000FF
FF8000FF000000FF0000FF00FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF8000
FF8000FF000000FF0000FF00FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF800000FF0000FF00FF00000000FFFF0000FF8000
FF8000FF000000FF0000FF00FF000000FF000000FFFF8000FF8000FF800000FF0000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF000000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF800000FF00FF000000FF0000FF0000FF000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF00FF000000FF0000FF0000FF000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF00FF000000FF0000FF0000FF000000FFFF8000FF8000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF8000FF8000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00
FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF000000FF00FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF000000FF00FF0000FF0000FF00000000FFFF0000FF800000FF00FF0000FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF80000000FFFF0000FF00000000FFFF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF80000000FFFF0000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF80000000FFFF8000FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FF0000FFFF8000FF8000FF8000FF0000FF000000FF00FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF8000FF8000FF0000FF000000FF00FF000000FF00FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .2891 L
.2381 .2891 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .2891 L
.2381 .2891 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0997 L
.47619 .0997 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0997 L
.47619 .0997 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .08844 L
.71429 .08844 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .08844 L
.71429 .08844 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .16457 L
.95238 .16457 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .16457 L
.95238 .16457 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000
FF00000000FFFF0000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF8000FF8000FF800000FF0000FF00FF0000FF0000
FF00000000FFFF8000FF8000FF80000000FFFF80000000FFFF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF00000000FFFF80000000FFFF8000FF8000FF800000FF00FF000000FF00FF0000
FF00000000FFFF8000FF8000FF80000000FFFF80000000FFFF80000000FFFF8000FF0000
0000FF0000FFFF8000FF8000FF8000
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF8000FF0000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF00000000FFFF80000000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
FF8000FF8000FF8000FF0000FF800000FF00FF00000000FFFF8000FF0000FF8000FF0000
0000FFFF80000000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF8000FF00000000FF0000FFFF8000FF8000FF80000000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF00000000FFFF8000
FF8000FF8000FF000000FF00FF0000FF00000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF00000000FFFF8000FF8000FF8000FF80000000FFFF0000FF0000FF00000000FF
FF8000FF8000FF8000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000
0000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF00000000FFFF8000
FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF80000000FF
FF8000FF8000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
0000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF000000FF000000FFFF8000FF8000FF8000FF8000FF80000000FF
FF0000FF00000000FFFF8000FF8000
FF8000FF800000FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF80000000FF
FF8000FF8000FF800000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF0000
FF00000000FFFF8000FF800000FF000000FFFF8000FF80000000FFFF8000FF8000FF8000
FF0000FF00000000FFFF80000000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FFFF8000FF8000FF8000FF0000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF800000FF00FF0000FF00000000FFFF8000FF8000FF800000FF0000FF0000FF00
FF00000000FFFF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000
FF0000FF00000000FFFF80000000FF
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF00000000FFFF8000FF0000FF0000FF00000000FFFF8000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
0000FFFF8000FF8000FF8000FF0000FF00000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF00000000FFFF00000000FFFF8000FF8000FF8000FF0000FF000000FF00
FF00000000FFFF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF00000000FFFF8000FF8000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF000000FF00
FF000000FF000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FFFF8000
FF8000FF8000FF8000FF800000FF00FF00000000FFFF80000000FFFF8000FF8000FF0000
FF000000FF0000FF000000FFFF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00000000FFFF8000FF0000FF8000
00FF0000FF000000FFFF8000FF8000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF80000000FFFF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF800000FF00
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF00000000FFFF8000FF8000FF8000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF00FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF800000FF00FF0000
00FF00FF0000FF0000FF0000FF0000
FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF000000FF000000FFFF0000FF8000FF8000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000
FF8000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF00000000FFFF0000
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF000000FF00FF00000000FFFF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF00000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF0000
FF000000FF00FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF
FF0000FF0000FF8000FF0000FF00000000FFFF0000FF00000000FFFF80000000FFFF8000
0000FFFF8000FF8000FF8000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF800000FF00FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000
00FF0000FF00FF00000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF00000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000
0000FFFF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF00000000FFFF8000
0000FFFF8000FF8000FF8000FF000000FF00FF000000FF00FF0000FF0000FF00000000FF
FF0000FF0000FF8000FF800000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
00FF00FF0000FF00000000FFFF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
0000FFFF8000FF8000FF8000FF0000FF80000000FFFF0000FF8000FF80000000FFFF0000
FF000000FF00FF0000FF00000000FF
FF0000FF000000FF0000FF0000FF00FF00000000FFFF8000FF0000FF800000FF000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF800000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
00FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF800000FF00FF000000FF00FF000000FF00FF00000000FFFF0000
FF8000FF8000FF0000FF00000000FF
FF0000FF000000FF0000FF00FF000000FF000000FFFF0000FF0000FF800000FF000000FF
FF8000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF0000FFFF8000FF800000FF00FF000000FF000000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000
0000FFFF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00FF00000000FFFF8000
FF8000FF80000000FF0000FF0000FF
FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF8000
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF800000FF00FF000000FF000000FF0000FF0000FFFF8000FF8000
FF00000000FFFF8000FF8000FF0000FF0000FF00000000FFFF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF0000FF0000FF000000FF0000FF00FF00000000FFFF8000
FF80000000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF000000FFFF00000000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF00000000FFFF8000FF000000FF00FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF00000000FFFF8000FF80000000FFFF0000FF00000000FFFF8000FF80000000FFFF8000
0000FFFF8000FF800000FF00FF0000FF0000FF800000FF00FF0000FF0000FF0000FF8000
FF00000000FF0000FF0000FFFF8000
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF8000
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF00000000FFFF00000000FFFF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF
FF8000FF8000FF8000FF000000FF00FF0000FF00000000FFFF80000000FFFF8000FF8000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF80000000FF0000FF0000FFFF8000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF8000
FF8000FF8000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FFFF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF80000000FF
00FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF8000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF00FF0000FF0000FF0000FF8000FF0000FF000000FF00FF000000FF00
FF000000FF000000FFFF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF800000FF00FF000000FF0000FF00FF000000FF00FF00000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FFFF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00
FF0000FF00000000FFFF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF00000000FFFF0000FF000000FF0000FF0000FF00FF0000FF0000FF00000000FFFF8000
FF80000000FFFF0000FF800000FF00FF000000FF00FF0000FF0000FF0000FF00000000FF
FF8000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF00000000FF0000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF8000
0000FFFF8000FF80000000FF0000FF
00FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF000000FF000000FF
FF8000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF80000000FF
0000FFFF8000FF80000000FFFF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF000000FF000000FF0000FF0000FFFF8000
0000FFFF8000FF80000000FF0000FF
FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF8000FF000000FF0000FF00FF0000FF000000FF0000FF000000FFFF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF00000000FF
FF8000FF8000FF0000FF000000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000
FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF80000000FFFF8000
FF0000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF8000FF000000FF0000FF00FF0000FF000000FF0000FF000000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00000000FF
FF80000000FFFF8000FF800000FF00FF0000FF0000FF0000FF00000000FFFF80000000FF
FF8000FF8000FF00000000FF0000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF00FF00000000FFFF8000FF8000FF8000FF0000FF000000FF00FF00000000FF
FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF800000FF00FF00000000FFFF000000FF000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF000000FF00FF0000FF0000
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF000000FF0000FF00FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000
FF000000FF000000FFFF0000FF000000FF00FF0000FF0000FF00000000FFFF80000000FF
0000FF0000FFFF8000FF800000FF00FF00000000FFFF8000FF80000000FFFF8000FF0000
FF8000FF8000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF00000000FF
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF800000FF0000FF00FF0000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF000000FF000000FFFF0000FF000000FF00FF0000FF0000FF00000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF00000000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
0000FFFF8000FF8000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000
FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF80000000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00FF00000000FF
FF8000FF8000FF80000000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000FF00000000FF0000FFFF0000FF8000FF8000FF0000
FF8000FF8000FF800000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF80000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF000000FF000000FF
FF8000FF8000FF80000000FF0000FF
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00
FF00000000FFFF0000FF0000FF8000FF0000FF8000FF8000FF8000FF00000000FF0000FF
FF8000FF8000FF0000FF000000FF0000FF00FF0000FF000000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF000000FF000000FF
FF8000FF8000FF80000000FF0000FF
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FFFF8000FF80000000FFFF8000
FF8000FF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF00000000FF0000FF
FF8000FF8000FF0000FF000000FF0000FF00FF0000FF000000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF00000000FF0000FF
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF80000000FFFF8000
FF8000FF8000FF800000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF00000000FFFF0000FF8000FF800000FF00FF00000000FF0000FF
FF8000FF800000FF00FF000000FF0000FF00FF0000FF000000FF00FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF00000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .18084 L
.2381 .18084 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .18084 L
.2381 .18084 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .06737 L
.47619 .06737 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .06737 L
.47619 .06737 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .07238 L
.71429 .07238 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .07238 L
.71429 .07238 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .32122 L
.95238 .32122 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .32122 L
.95238 .32122 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF800000FF0000FF00FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF8000FF0000FF8000FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF0000FF0000FF0000FF80000000FFFF0000
FF8000FF0000FF0000FF8000FF000000FF0000FF00FF00000000FFFF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF800000FF00FF0000FF0000FF8000FF800000FF00FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF8000FF8000FF0000FF0000FF8000FF0000FF00000000FFFF8000FF0000FF8000FF8000
00FF00FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF80000000FFFF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FF
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF000000FF00FF800000FF00FF0000FF80000000FFFF8000
FF0000FF0000FF0000FF8000FF0000FF000000FF00FF8000FF8000FF0000FF000000FF00
FF8000FF8000FF0000FF000000FF0000FF00FF8000FF0000FF0000FF8000FF8000FF0000
00FF00FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF800000FF000000FFFF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF000000FF0000FF00FF0000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF0000FF000000FF0000FF00FF8000FF0000FF0000FF8000FF8000
00FF00FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF00000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF000000FFFF8000FF8000FF8000FF0000FF800000FF00FF0000
FF8000FF8000FF8000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF8000FF8000FF8000
FF00000000FFFF0000FF000000FF0000FF0000FF00FF80000000FFFF8000FF8000FF8000
00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF000000FF000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF80000000FFFF8000FF8000FF800000FF0000FF00FF0000FF00000000FF
FF8000FF8000FF8000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000
0000FFFF8000FF0000FF8000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF00FF80000000FFFF8000FF8000FF8000
00FF000000FFFF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
00FF00FF0000FF0000FF000000FF00
FF800000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF80000000FF
FF8000FF8000FF8000FF000000FF00FF000000FF00FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF00000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000
00FF000000FFFF0000FF0000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF8000FF8000FF0000
FF000000FF0000FF00FF00000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000
00FF0000FF00FF0000FF0000FF0000FF800000FF00FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF800000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
00FF00FF0000FF8000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF00000000FFFF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF00000000FFFF0000FF8000
FF80000000FFFF8000FF8000FF0000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000FF8000
FF80000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF800000FF0000FF00FF8000FF0000
FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000
FF80000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF000000FF00FF8000FF0000FF0000FF8000FF0000
00FF00FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF800000FF00FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
FF00000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
00FF00FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00
00FF00FF0000FF0000FF0000FF8000FF800000FF00FF00000000FFFF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF0000FF800000FF00FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF
FF0000FF80000000FFFF8000FF8000FF800000FF000000FFFF0000FF0000FF8000FF8000
FF8000FF8000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF000000FF0000FF00
FF00000000FFFF0000FF8000FF800000FF0000FF00FF00000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF00000000FF
0000FFFF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF80000000FF
FF0000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000FF000000FF0000FF0000FF00
FF00000000FFFF8000FF8000FF8000FF8000FF00000000FFFF80000000FFFF8000FF8000
00FF00FF0000FF00000000FF0000FFFF8000FF800000FF00FF0000FF0000FF0000FF8000
0000FFFF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF800000FF00FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
FF0000FF8000FF800000FF0000FF0000FF00FF8000FF0000FF8000FF80000000FFFF8000
FF8000FF800000FF0000FF000000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00
FF8000FF0000FF8000FF8000FF8000FF800000FF000000FFFF80000000FFFF8000FF8000
FF8000FF0000FF00000000FF0000FFFF8000FF800000FF00FF0000FF0000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
0000FFFF8000FF800000FF0000FF00FF00000000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF80000000FF
FF0000FF8000FF8000FF800000FF00FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF000000FFFF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF0000FF0000FF8000FF0000FF8000FF00000000FFFF00000000FF0000FFFF8000
FF8000FF00000000FF0000FF0000FFFF8000FF800000FF000000FFFF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FFFF80000000FFFF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF000000FF00
0000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF800000FF0000FF0000FF000000FFFF8000FF8000FF800000FF00FF0000FF000000FF00
FF8000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF00000000FF0000FFFF8000
FF8000FF00000000FF0000FFFF8000FF8000FF800000FF00FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF000000FF0000FF0000FF00
0000FFFF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF00FF00000000FFFF8000FF8000FF800000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF8000FF8000FF8000FF800000FF000000FF0000FFFF8000FF8000
FF800000FF00FF00000000FFFF8000FF8000FF8000FF8000FF800000FF00FF00000000FF
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF000000FF0000FF00
00FF00FF8000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF800000FF000000FFFF8000FF8000FF800000FF000000FFFF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF00000000FFFF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF0000
FF800000FF00FF0000FF8000FF0000FF8000FF800000FF00FF0000FF8000FF80000000FF
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF800000FF00FF0000FF0000FF8000
FF800000FF000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
00FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00
00FF00FF0000FF8000FF8000FF8000
00FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF800000FF00FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF800000FF000000FFFF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF00000000FFFF0000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF000000FFFF8000FF8000FF8000
00FF00FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF800000FF00FF00000000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF00000000FFFF8000FF8000FF8000FF00000000FFFF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF800000FF00FF00000000FFFF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF000000FF00FF8000FF8000FF8000FF0000
00FF000000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF00000000FF
FF8000FF0000FF00000000FF0000FFFF0000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF800000FF0000FF00FF0000FF000000FF0000FF00FF0000FF8000FF0000
FF80000000FFFF8000FF0000FF8000
FF0000FF0000FF0000FF80000000FFFF8000FF8000FF800000FF0000FF000000FFFF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF00000000FFFF8000FF800000FF000000FF
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF000000FF00
FF8000FF0000FF0000FF00000000FFFF80000000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF800000FF00FF8000FF000000FF0000FF00FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF00000000FFFF8000
FF8000FF800000FF00FF0000FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF00000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF00000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
FF800000FF00FF0000FF0000FF8000FF800000FF0000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF800000FF00FF000000FF0000FF00FF000000FF0000FF00FF8000FF0000FF0000FF8000
FF8000FF800000FF00FF0000FF8000FF8000FF8000FF00000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF80000000FFFF0000FF0000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF800000FF000000FFFF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF80000000FF0000FFFF8000
FF8000FF800000FF00FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF800000FF0000FF00FF0000FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF000000FF0000FF00FF0000FF0000FF8000FF8000FF8000
FF00000000FFFF8000FF000000FF0000FF00FF8000FF8000FF80000000FFFF8000FF0000
FF8000FF8000FF0000FF800000FF00FF00000000FF0000FFFF8000FF8000FF0000FF0000
FF0000FF00000000FFFF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FF
00FF00FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF0000FF0000FF000000FF000000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF00000000FFFF8000FF80000000FFFF8000FF8000
FF8000FF800000FF00FF800000FF00FF0000FF80000000FFFF8000FF8000FF0000FF0000
0000FFFF8000FF80000000FFFF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000
FF0000FF00000000FF0000FFFF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF80000000FFFF8000FF8000FF80000000FF
FF8000FF000000FF00FF0000FF0000FF0000FF80000000FFFF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF800000FF0000FF000000FF0000FFFF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF00000000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF
FF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF800000FF00FF00000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF800000FF00FF0000FF8000FF8000FF00000000FFFF8000
FF8000FF8000FF0000FF8000FF00000000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF800000FF0000FF00FF0000FF0000FF8000FF8000FF80000000FFFF0000FF8000FF8000
FF0000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF00000000FFFF80000000FFFF80000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF0000FF800000FF00FF0000FF8000FF8000FF00000000FFFF8000
FF8000FF800000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF00000000FFFF0000FF8000FF8000FF80000000FFFF8000FF8000
FF800000FF0000FF0000FF000000FFFF0000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF00000000FFFF8000FF80000000FF0000FFFF8000
FF8000FF800000FF00FF8000FF0000FF8000FF80000000FFFF8000FF00000000FFFF8000
FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF8000FF00000000FFFF8000FF8000FF800000FF000000FFFF8000FF8000
FF800000FF0000FF0000FF000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF00000000FF0000FFFF8000
FF8000FF800000FF00FF8000FF0000FF8000FF0000FF0000FF8000FF80000000FFFF8000
FF8000FF80000000FFFF0000FF8000
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF00000000FFFF8000FF8000
FF800000FF0000FF00FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000
FF800000FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF80000000FFFF8000
FF0000FF80000000FFFF8000FF8000
FF0000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF00000000FFFF8000FF8000
FF8000FF800000FF0000FF000000FFFF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF000000FF00FF8000FF0000FF0000FF00000000FF
FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000FF800000FF00
0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF800000FF00FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .44783 L
.2381 .44783 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .44783 L
.2381 .44783 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .02482 L
.47619 .02482 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .02482 L
.47619 .02482 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .07509 L
.71429 .07509 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .07509 L
.71429 .07509 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09407 L
.95238 .09407 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09407 L
.95238 .09407 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF80000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
00FF00FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000
FF8000FF00000000FFFF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
0000FFFF0000FF8000FF0000FF0000FF0000FF8000FF00000000FFFF80000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF80000000FF0000FF
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF00000000FF
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000
0000FFFF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000
0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF8000FF8000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF00000000FFFF8000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FFFF8000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF00000000FFFF8000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF80000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF0000
0000FFFF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF80000000FFFF0000FF0000FF8000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF80000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF00000000FFFF0000
FF0000FF8000FF8000FF8000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF000000FF00
FF0000FF8000FF8000FF80000000FF
00FF0000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FF
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
0000FFFF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FF0000FF0000FFFF0000FF8000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF80000000FFFF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF80000000FFFF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF80000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF80000000FF0000FF0000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FF00FF00FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF00000000FF
00FF00FF0000FF00000000FF0000FFFF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
00FF0000FF00FF0000FF8000FF80000000FFFF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF00000000FFFF0000FF0000FF80000000FFFF0000FF00000000FFFF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF8000FF80000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FF0000FFFF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF8000FF8000FF0000
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF80000000FF0000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF8000FF0000
0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF00000000FF0000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF00FF000000FF00
FF0000FF00000000FFFF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000
FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
00FF0000FF00FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF00000000FFFF00000000FF00FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF00000000FF0000FF00FF00FF0000
00FF000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF80000000FF0000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF00000000FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .107 L
.2381 .107 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .107 L
.2381 .107 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .37921 L
.47619 .37921 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .37921 L
.47619 .37921 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .13954 L
.71429 .13954 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .13954 L
.71429 .13954 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01606 L
.95238 .01606 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01606 L
.95238 .01606 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF00000000FF00FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF80000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF
FF00000000FFFF00000000FFFF0000FF000000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FFFF0000FF000000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF00FF000000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF00000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
FF000000FF00FF000000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF00000000FF0000FFFF0000FF000000FF00
0000FFFF000000FF0000FF00FF0000
0000FFFF0000FF00000000FF0000FFFF000000FF0000FF000000FF0000FF00FF000000FF
0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FFFF00000000FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF00000000FF0000FFFF00000000FF
0000FF0000FF0000FF00FF0000FF00
0000FF00FF00FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FFFF80000000FFFF0000FF000000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FFFF00000000FFFF000000FF000000FFFF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
00FF000000FF0000FF0000FF00FF00FF000000FF0000FF00FF000000FF0000FF0000FF00
0000FFFF000000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF00000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FF0000FF00FF0000FF00FF0000FF00000000FFFF00000000FF0000FFFF000000FF00
0000FFFF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FFFF0000FF000000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF00000000FF0000FF
0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF000000FFFF000000FF000000FF0000FF0000FF0000FFFF0000
0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF00000000FFFF0000FF0000FF0000FF8000FF8000FF80000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FFFF00000000FF0000FF0000FFFF0000FF8000FF8000FF8000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FFFF0000FF00000000FF
FF0000FF000000FF00FF000000FF00
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF
0000FF0000FF00FF0000FF0000FF000000FFFF00000000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF00FF0000FF80000000FFFF00000000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00000000FF
FF8000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF
FF00000000FF00FF0000FF0000FF00FF0000FF00000000FFFF00000000FFFF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF000000FF00FF00FF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF00FF00000000FF
0000FFFF000000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FFFF0000FF0000FF0000
0000FF0000FFFF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF000000FF00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF00000000FF00FF0000FF0000FF00FF00000000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FF0000FF00FF000000FF00FF00FF0000FF0000
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF00FF0000FF0000FF00FF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FF0000FF00FF0000FF0000FF00FF0000FF00000000FF0000FFFF000000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FFFF00000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF000000FF000000FF0000FF
FF0000FF000000FF000000FF0000FF00FF00FF00000000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF00000000FFFF000000FF0000FF0000FF0000FF000000FF00FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF000000FF0000FF00
00FF0000FF000000FFFF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FFFF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF00FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF0000FF0000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FF0000FF00FF0000FF0000FF00FF00000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF00000000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00000000FF0000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF
0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FFFF000000FF0000FF0000FF000000FF0000FFFF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF000000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00FF00000000FFFF0000FF000000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF00000000FF0000FFFF000000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF00FF0000FF00000000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF00FF000000FF0000FF0000FF0000FF00FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF00000000FF0000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF000000FFFF00000000FF00FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF0000FF000000FF0000FF00FF000000FF00FF000000FF000000FF0000FFFF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF000000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FFFF00000000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FFFF000000FF0000FF00FF0000
FF0000FF0000FF0000FF8000FF8000FF00000000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF00FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF00FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF80000000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF00000000FF0000FF0000FF00FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF000000FF
0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF
FF00000000FF0000FF0000FFFF00000000FF0000FFFF00000000FF00FF00FF000000FF00
0000FF0000FF0000FF00FF00FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
0000FF0000FF0000FF00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .13328 L
.2381 .13328 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .13328 L
.2381 .13328 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .33373 L
.47619 .33373 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .33373 L
.47619 .33373 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .16228 L
.71429 .16228 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .16228 L
.71429 .16228 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01251 L
.95238 .01251 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01251 L
.95238 .01251 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FFFF0000FF00000000FF0000FFFF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000FF0000FF000000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF000000FF00FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000FF00000000FFFF000000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF00FF00000000FF0000FF0000FFFF0000FF000000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FFFF0000FF00000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF
0000FFFF000000FF0000FF00FF0000FF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FFFF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF000000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF000000FF0000FF00FF0000FF00
FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF0000FF00FF00000000FFFF0000
FF0000FF000000FF000000FFFF000000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FFFF000000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF0000FF00FF00
00FF0000FF00FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF00000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF00FF000000FF0000FF00FF0000FF00000000FFFF0000
FF000000FF000000FF0000FFFF000000FF0000FF00FF000000FF0000FF00FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
00FF000000FFFF00000000FF0000FF0000FF0000FF00FF000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FF00FF00
00FF00FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF000000FF0000FF00FF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
0000FF0000FFFF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000
FF000000FF00FF00000000FF00FF00FF0000FF00000000FFFF00000000FFFF0000FF0000
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF00000000FF0000FFFF00000000FF0000FF00FF00FF0000
FF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FF0000FF00FF0000FF0000FF00FF00000000FFFF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF000000FF00
00FF0000FF000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FFFF000000FF0000FF0000FF00FF000000FF000000FF0000FFFF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FF00FF0000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF00FF00000000FFFF00000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FFFF000000FF00FF0000FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FFFF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FFFF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00000000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF00FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF000000FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF0000FF00000000FFFF00000000FF00FF00
00FF00FF000000FF000000FF0000FF00FF0000FF00FF00000000FFFF0000FF00000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF00000000FFFF0000
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF0000FF00000000FFFF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FFFF000000FF0000FF00FF000000FF0000FF0000FF000000FFFF00000000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FFFF0000FF00000000FFFF00000000FF00FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF
FF0000FF00000000FFFF00000000FF
0000FFFF00000000FFFF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000
0000FFFF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF0000FF000000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF00
00FF0000FF00FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF0000
0000FFFF0000FF00000000FF0000FFFF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF00000000FF00FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF00FF0000FF00FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF000000FF0000FFFF0000FF0000FF00000000FF00FF000000FF0000FF0000FF
FF00000000FFFF00000000FFFF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000
0000FFFF0000FF00000000FF0000FF0000FF00FF0000FF00FF0000FF00000000FFFF0000
FF00000000FFFF00000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
FF00000000FF0000FF0000FF00FF0000FF00FF000000FF000000FF0000FF00FF00FF0000
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FFFF000000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FFFF0000FF0000FF0000FF000000FF00
FF00000000FFFF00000000FF0000FF
0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000
FF00000000FFFF00000000FF0000FF0000FF00FF00FF0000FF0000FF0000FF0000FF0000
FF80000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF0000FF00000000FFFF000000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF00000000FFFF00000000FF0000FF0000FF
0000FF00FF00FF00000000FFFF00000000FF0000FFFF00000000FF0000FFFF000000FF00
00FF0000FF0000FF000000FF0000FF
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF00000000FFFF0000FF00000000FF0000FF00FF0000FF00FF0000FF00000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FFFF000000FF00FF0000FF0000FF00000000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF00FF00000000FFFF0000FF00000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF00000000FFFF0000FF0000FF00000000FF00FF00FF0000FF0000FF00000000FFFF0000
FF80000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF00000000FF0000FFFF00000000FF0000FFFF00000000FF00FF00
00FF0000FF0000FF00FF00000000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF00000000FFFF000000FF0000FF0000FF0000FF00FF00000000FFFF0000
FF80000000FF0000FFFF000000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FFFF0000FF00000000FF0000FF
0000FF00FF00FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF0000FFFF00000000FF
0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF0000FF0000FF00FF000000FFFF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF00
00FF0000FF00FF0000FF00000000FF0000FFFF000000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
0000FFFF00000000FF00FF0000FF0000FF00FF000000FF00FF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF00FF000000FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FFFF0000
0000FF0000FFFF000000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF0000FF0000
FF00000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00000000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF000000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FFFF0000FF00000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FFFF000000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
FF000000FF0000FF0000FF00FF00000000FF0000FF0000FF00FF0000FF000000FF0000FF
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FFFF000000FF0000FF0000FF00FF00000000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00FF000000FF000000FF00FF0000FF000000FF00FF00
00FF00FF00000000FF0000FF0000FF
00FF000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF00FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF00FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
FF00000000FF00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF00000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF00000000FF0000FF
FF000000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF00FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FFFF00000000FF00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF000000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FFFF000000FF00FF00000000FF0000FF0000FF00FF000000FFFF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FFFF0000
00FF000000FFFF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF00FF0000FF00FF0000FF0000
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF000000FF0000FF
FF0000FF00000000FF0000FF00FF0000FF0000FF0000FF00FF000000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000
0000FF00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF000000FFFF0000
0000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF00FF0000
0000FF0000FF00FF0000FF0000FF0000FF00FF000000FF000000FF0000FF0000FFFF0000
FF00000000FF0000FFFF00000000FF0000FFFF000000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FF0000FF00FF0000FF0000FF00FF00000000FF
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF00FF000000FF00FF000000FF000000FFFF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF000000FF0000FF0000FF000000FF00FF00
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF00
00FF0000FF0000FF0000FF000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .03733 L
.2381 .03733 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .03733 L
.2381 .03733 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01439 L
.71429 .01439 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01439 L
.71429 .01439 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .5782 L
.95238 .5782 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .5782 L
.95238 .5782 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF
0000FFFF8000FF00000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .55254 L
.2381 .55254 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .55254 L
.2381 .55254 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01376 L
.47619 .01376 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01376 L
.47619 .01376 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .06341 L
.95238 .06341 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .06341 L
.95238 .06341 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF000000FF00FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF800000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02836 L
.2381 .02836 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02836 L
.2381 .02836 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .24112 L
.47619 .24112 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .24112 L
.47619 .24112 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .29077 L
.71429 .29077 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .29077 L
.71429 .29077 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .08155 L
.95238 .08155 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .08155 L
.95238 .08155 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00FF8000FF8000FF0000FF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF00FF8000FF80000000FF
FF800000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF
00FF0000FF0000FF00FF8000FF800000FF00FF0000FF8000FF800000FF0000FF0000FF00
0000FF0000FFFF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF
00FF000000FF0000FF0000FFFF8000
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF00FF8000FF8000FF8000FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF00FF8000FF8000FF0000FF0000FF0000FF80000000FF00FF000000FF0000FF
00FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00
00FF000000FF00FF0000FF00FF8000FF00000000FF00FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF0000FF0000FF800000FF0000FF000000FF00FF00
00FF0000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
FF0000FF0000FF00000000FF0000FF00FF00FF000000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF000000FF00FF0000FF8000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF80000000FF00FF000000FF00FF00FF800000FF0000FF0000FF0000FF000000FFFF8000
FF800000FF0000FF000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
00FF000000FF00FF00FF80000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FFFF800000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FFFF8000FF800000FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FFFF800000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
FF80000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00FF800000FF00FF000000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00FF8000
00FF0000FF0000FF0000FF000000FF00FF0000FF00FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF800000FF00FF80000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF000000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF00FF8000FF800000FF0000FF000000FFFF8000FF800000FF00
FF00000000FF00FF00FF800000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FFFF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF00
00FF00FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF0000FF80000000FFFF800000FF00
0000FFFF80000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF00FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000
FF0000FF000000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00FF800000FF0000FF00
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF000000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF
FF800000FF000000FF0000FFFF80000000FF00FF000000FF0000FFFF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF800000FF00FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF000000FF0000FF00FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF800000FF0000FF0000FF000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF
FF800000FF0000FF00FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FFFF8000
FF800000FF00FF800000FF0000FF0000FF000000FFFF80000000FF00FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF800000FF000000FF00FF00FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF0000FF800000FF000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
00FF00FF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
FF80000000FF00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF8000
0000FFFF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF8000FF800000FF00FF8000FF8000FF80000000FFFF0000FF800000FF0000FF000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000
0000FF00FF00FF800000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FF
0000FFFF8000FF8000FF8000FF0000FF00000000FFFF8000FF800000FF0000FF000000FF
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FFFF8000
0000FFFF800000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF000000FF0000FFFF000000FF00
00FF0000FF000000FFFF8000FF8000FF000000FF000000FF0000FF0000FF00FF000000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF000000FF0000FF0000FF000000FF0000FF0000FF
FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FFFF800000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF80000000FFFF8000FF8000
0000FFFF80000000FFFF000000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000FF80000000FF
0000FF0000FF00FF000000FF0000FF0000FFFF8000FF8000FF8000FF800000FF000000FF
0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF800000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF00FF00FF8000FF8000FF800000FF00
0000FF00FF0000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF0000FF00
00FF00FF800000FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF000000FF0000FF00FF8000
FF8000FF0000FF800000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000FF0000FF8000
0000FFFF8000FF0000FF8000FF0000FF8000FF80000000FF0000FF0000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00FF800000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF80000000FF0000FF
0000FFFF8000FF0000FF0000FF8000FF8000FF8000FF000000FF0000FF000000FF0000FF
0000FF0000FF00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF000000FF0000FF0000FF
0000FFFF8000FF8000FF800000FF0000FF00FF8000FF80000000FF00FF000000FF0000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF
00FF00FF80000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF800000FF00FF000000FF00FF800000FF0000FF0000FF000000FF0000FF
FF80000000FF0000FF0000FF0000FF00FF000000FFFF80000000FFFF000000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FFFF800000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF00
0000FF0000FFFF8000FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF00FF800000FF00FF800000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF800000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF00FF8000FF800000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF0000FF00FF80000000FF00FF00FF800000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF00000000FF00FF00
0000FFFF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF80000000FFFF0000FF800000FF0000FF00FF80000000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF00FF800000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000
00FF0000FF000000FF0000FFFF8000FF8000FF0000FF000000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF0000FFFF80000000FF00FF00FF800000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FFFF800000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00
00FF00FF800000FF0000FF0000FF00FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01209 L
.2381 .01209 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01209 L
.2381 .01209 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .09803 L
.47619 .09803 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .09803 L
.47619 .09803 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .50123 L
.71429 .50123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .50123 L
.71429 .50123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03045 L
.95238 .03045 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03045 L
.95238 .03045 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF800000FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF800000FF0000FF000000FF0000FFFF8000
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF800000FF0000FF000000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF0000FF000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FFFF8000FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FFFF8000FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF800000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF00FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FFFF80000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00
FF800000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF00FF000000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF000000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF000000FF0000FF0000FF0000FFFF8000
00FF00FF8000FF80000000FFFF800000FF0000FF000000FF0000FFFF80000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF000000FFFF80000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FFFF800000FF0000FF000000FF00FF000000FFFF8000
00FF000000FF0000FF0000FFFF8000
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF00FF000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF00FF80000000FFFF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF00FF0000FF000000FF0000FF0000FFFF80000000FF
00FF000000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF800000FF0000FF000000FFFF800000FF0000FF0000FF000000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF000000FF00FF000000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF000000FFFF8000FF8000FF800000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF0000FF00FF800000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF80000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .14475 L
.2381 .14475 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .14475 L
.2381 .14475 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .17625 L
.47619 .17625 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .17625 L
.47619 .17625 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .07905 L
.71429 .07905 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .07905 L
.71429 .07905 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .24175 L
.95238 .24175 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .24175 L
.95238 .24175 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF0000FF00FF8000FF8000FF0000FF8000FF00000000FF0000FFFF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF000000FF00FF0000FF00FF8000FF80000000FF
00FF00FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF800000FF0000FF00FF800000FF0000FF00FF80000000FF0000FF
FF8000FF8000FF0000FF800000FF0000FF00FF80000000FFFF800000FF0000FF00FF8000
00FF00FF8000FF0000FF8000FF800000FF00FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF800000FF0000FF00
FF000000FF0000FF000000FFFF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
00FF00FF800000FF00FF800000FF0000FF000000FFFF8000FF0000FF800000FF00FF8000
FF8000FF0000FF000000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF0000FF
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF800000FF0000FF00
00FF0000FF0000FF000000FFFF8000FF8000FF0000FF8000FF0000FF000000FF00FF0000
FF0000FF8000FF0000FF000000FF0000FF000000FF0000FF00FF00FF8000FF800000FF00
FF8000FF800000FF00FF0000FF000000FF00FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF800000FF000000FF0000FF0000FF0000FF0000FF00FF00
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF00000000FF
00FF00FF000000FF000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF80000000FFFF8000FF800000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF00FF80000000FFFF8000FF8000FF800000FF00
00FF00FF8000FF0000FF000000FF0000FF00FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
FF8000FF000000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF0000FF800000FF000000FF00FF0000FF00FF800000FF00FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF8000
FF800000FF0000FF000000FF0000FF0000FFFF80000000FFFF0000FF800000FF0000FF00
00FF00FF8000FF0000FF0000FF00000000FFFF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF800000FF00
FF8000FF0000FF800000FF00FF0000FF8000FF8000FF0000FF0000FF800000FF00FF8000
FF8000FF000000FF0000FF0000FF0000FF000000FF0000FFFF80000000FF0000FFFF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF8000
0000FFFF80000000FF0000FFFF800000FF0000FF0000FF00FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00
FF0000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF800000FF00FF800000FF00
FF8000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FFFF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF800000FF00FF8000FF0000FF0000FF0000FF8000FF8000
FF000000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF000000FF00FF0000FF0000
00FF0000FF0000FF000000FFFF8000
FF8000FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF8000FF000000FF0000FF00FF8000FF80000000FF00FF000000FFFF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF800000FF0000FF0000FF000000FF0000FF00FF000000FFFF8000
00FF00FF800000FF0000FF0000FF00
FF8000FF0000FF0000FF8000FF000000FF000000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF000000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000
FF800000FF0000FF0000FF000000FFFF800000FF00FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF000000FF0000FF00FF80000000FFFF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF80000000FF00FF0000FF000000FF0000FF0000FFFF8000
FF0000FF8000FF000000FF00FF0000
FF8000FF8000FF0000FF0000FF0000FF800000FF0000FF000000FF0000FFFF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF0000
FF000000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF0000FF8000
FF8000FF8000FF8000FF800000FF0000FF000000FF00FF00FF0000FF0000FF0000FF0000
FF800000FF0000FF00FF8000FF8000FF000000FF000000FFFF8000FF000000FF0000FF00
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF000000FF0000FF0000FF000000FF0000FFFF8000FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF0000FF8000FF0000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF800000FF000000FF0000FF0000FFFF0000FF0000FF0000
00FF0000FF000000FFFF800000FF0000FF00FF80000000FFFF8000FF8000FF800000FF00
FF000000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF0000FF0000FFFF8000
00FF0000FF0000FF00FF8000FF8000
0000FFFF8000FF8000FF8000FF0000FF800000FF0000FF0000FF000000FFFF8000FF8000
0000FFFF8000FF8000FF800000FF0000FF000000FFFF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF000000FF00FF8000
FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF0000
FF8000FF8000FF8000FF8000FF8000FF000000FF0000FF0000FF0000FF000000FFFF8000
FF80000000FF0000FFFF8000FF8000
00FF00FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF00000000FF
FF8000FF000000FF0000FF00FF800000FF00FF0000FF0000FF000000FF0000FF000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF0000FF0000
FF800000FF00FF0000FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF0000FF000000FF00FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF800000FF000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF800000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF000000FF0000FF0000FF00FF8000FF0000FF800000FF0000FF0000FF00
0000FF00FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF0000FF0000FF8000FF00000000FFFF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF000000FF0000FF00FF8000FF8000
FF0000FF800000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF0000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF800000FF00FF8000
00FF00FF8000FF000000FF00FF8000
FF8000FF8000FF8000FF0000FF00000000FF00FF00FF8000FF8000FF8000FF0000FF0000
FF000000FF0000FF00FF8000FF8000FF8000FF000000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF800000FF00FF0000FF0000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF0000
FF800000FF00FF8000FF8000FF000000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF80000000FF0000FFFF8000FF8000FF000000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF8000FF0000FF0000
FF800000FF0000FF000000FF00FF0000FF00FF8000FF0000FF8000FF800000FF00FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF00000000FFFF80000000FF00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000
0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
FF8000FF8000FF00000000FF0000FF
FF8000FF8000FF0000FF800000FF000000FFFF800000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF000000FF00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF000000FF00FF800000FF000000FF
0000FF0000FFFF8000FF00000000FF00FF00FF800000FF00FF8000FF800000FF00FF0000
FF80000000FFFF80000000FF0000FFFF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF800000FF00FF80000000FF0000FF0000FFFF800000FF0000FF0000FF00FF8000
FF800000FF00FF000000FF0000FF00
0000FFFF8000FF8000FF000000FF00FF8000FF8000FF0000FF0000FF000000FF000000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF00FF8000FF8000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF0000FF8000FF00000000FFFF8000FF8000FF0000FF8000FF0000
FF800000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF000000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF8000
0000FF0000FF0000FF00FF00FF800000FF00FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF800000FF000000FF00FF0000FF0000FF00FF8000FF8000FF0000FF000000FF00
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF000000FF00FF800000FF00FF8000
FF8000FF8000FF0000FF8000FF800000FF0000FF000000FF0000FF00FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF80000000FFFF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF800000FF0000FF000000FF0000FFFF8000FF000000FF0000FF00
0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF00FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00
00FF00FF8000FF0000FF0000FF8000FF00000000FFFF0000FF800000FF00FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF000000FF00FF800000FF0000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF000000FFFF8000FF0000
FF8000FF00000000FF00FF000000FF0000FF0000FF0000FFFF80000000FF00FF0000FF00
0000FF0000FFFF8000FF0000FF0000
00FF0000FF000000FFFF80000000FFFF800000FF000000FFFF8000FF0000FF8000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF80000000FF0000FFFF8000FF800000FF0000FF00FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF8000FF8000
00FF000000FF0000FFFF80000000FF0000FF00FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF800000FF000000FF00FF0000FF000000FF00FF00
00FF0000FF00FF8000FF8000FF0000
FF800000FF0000FF00FF8000FF8000FF800000FF000000FF0000FFFF8000FF0000FF8000
FF000000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000
00FF00FF800000FF00FF800000FF000000FF0000FFFF800000FF00FF800000FF0000FF00
0000FFFF8000FF0000FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF0000FF0000FFFF800000FF00
FF8000FF8000FF0000FF0000FF8000
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF000000FFFF8000FF0000FF8000
FF0000FF8000FF8000FF800000FF000000FFFF8000FF8000FF000000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF800000FF00
0000FF0000FF0000FF0000FFFF8000FF0000FF000000FF0000FF00FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF0000FF00FF0000FF00FF8000
FF8000FF8000FF0000FF0000FF8000
FF0000FF000000FF00FF8000FF8000FF0000FF800000FF000000FFFF8000FF8000FF0000
FF00000000FFFF8000FF800000FF0000FF000000FFFF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF000000FF00FF8000FF8000FF000000FF0000FF000000FFFF8000FF8000FF0000
FF800000FF0000FF00FF800000FF0000FF000000FFFF8000FF8000FF800000FF00FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF0000FF0000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF000000FF00FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000
FF0000FF000000FF00FF8000FF8000FF8000FF800000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF00FF800000FF0000FF000000FFFF8000FF800000FF00FF0000FF8000
00FF00FF000000FF000000FFFF80000000FF00FF00FF80000000FF00FF0000FF00FF8000
FF8000FF0000FF800000FF000000FF0000FFFF8000FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF000000FF0000FF0000FF00FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF0000FF8000
00FF00FF8000FF8000FF000000FF00
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF0000FF000000FF0000FF
FF80000000FF00FF00FF8000FF800000FF0000FF000000FFFF80000000FFFF8000FF8000
FF800000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF800000FF000000FFFF8000FF8000FF80000000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF800000FF00FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF000000FF0000FF00FF0000FF8000FF0000
FF000000FF00FF8000FF800000FF00
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF00FF00
0000FF00FF00FF8000FF8000FF0000FF800000FF000000FFFF800000FF00FF8000FF8000
FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF800000FF000000FF00FF00FF8000FF8000
0000FFFF0000FF8000FF8000FF800000FF0000FF00FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF0000
00FF00FF8000FF800000FF00FF8000
00FF00FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF80000000FF00FF000000FF0000FF0000FFFF8000FF8000
FF800000FF0000FF000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000
FF000000FF0000FF00FF0000FF8000FF8000FF800000FF0000FF000000FFFF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF000000FF0000FF0000FFFF8000FF800000FF000000FF0000FF0000FFFF8000FF8000
FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FF
FF0000FF0000FF8000FF0000FF8000FF8000FF000000FF0000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF800000FF0000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
00FF0000FF00FF80000000FF00FF00
FF8000FF000000FF00FF8000FF800000FF0000FF000000FF00FF00FF800000FF0000FF00
00FF000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF800000FF00FF00000000FF00FF000000FF0000FFFF800000FF00FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF800000FF0000FF00FF0000FF8000FF8000FF0000FF8000FF800000FF0000FF00
00FF000000FFFF800000FF00FF8000
00FF0000FF0000FF000000FF0000FF0000FFFF800000FF0000FF00FF0000FF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00FF8000FF0000
FF8000FF0000FF0000FF00000000FF00FF000000FF0000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF00000000FF00FF0000FF00FF8000FF0000FF0000FF0000FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000
FF000000FF000000FF0000FF0000FF0000FF00FF00FF8000FF8000FF8000FF800000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FFFF8000FF0000
FF0000FF0000FF0000FF000000FF0000FF000000FF00FF00FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF800000FF00
00FF0000FF0000FF000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF800000FF00FF8000FF0000FF0000
FF800000FF000000FF0000FFFF80000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FFFF8000FF8000
FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF800000FF00FF8000
FF8000FF0000FF0000FF000000FF00FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF0000FF0000
00FF0000FF00FF0000FF8000FF0000
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF00FF800000FF00FF8000FF80000000FFFF8000
FF8000FF8000FF0000FF800000FF00FF8000FF000000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF8000FF0000FF0000FF800000FF0000FF00
00FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF0000
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000
0000FFFF000000FF000000FF0000FF0000FFFF8000FF800000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000FF0000
FF800000FF00FF0000FF0000FF800000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF8000FF8000FF000000FF000000FF0000FF0000FFFF8000FF8000FF0000FF00000000FF
0000FFFF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF0000
00FF00FF8000FF8000FF000000FF00FF8000FF800000FF0000FF00FF8000FF8000FF0000
FF800000FF00FF8000FF8000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .50269 L
.2381 .50269 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .50269 L
.2381 .50269 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .03525 L
.47619 .03525 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .03525 L
.47619 .03525 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .08197 L
.71429 .08197 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .08197 L
.71429 .08197 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0219 L
.95238 .0219 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0219 L
.95238 .0219 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF000000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF00000000FF0000FF0000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF000000FF00
FF0000FF000000FF0000FF00FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF000000FF00FF8000FF8000
FF000000FF00FF0000FF0000FF0000FF0000FF80000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF000000FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF00000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF800000FF00FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF000000FF00
FF0000FF8000FF0000FF0000FF0000
0000FF00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF8000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF8000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000
FF000000FF00FF0000FF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF000000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF00000000FF
FF0000FF0000FF00000000FFFF0000
0000FF00FF00FF0000FF000000FF00FF0000FF8000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000
0000FF00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF00FF000000FF
00FF00FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF00FF000000FF
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF00FF000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF00FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF8000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF00FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF00FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF000000FF00FF00000000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF00FF00FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF00FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .10137 L
.2381 .10137 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .10137 L
.2381 .10137 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .30912 L
.47619 .30912 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .30912 L
.47619 .30912 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .06758 L
.71429 .06758 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .06758 L
.71429 .06758 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .16374 L
.95238 .16374 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .16374 L
.95238 .16374 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF000000FFFF0000
0000FFFF800000FF00FF800000FF0000FF00FF000000FF00FF0000FF0000FF00000000FF
FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00000000FFFF800000FF00
00FF00FF800000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF00000000FFFF800000FF00
00FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FFFF0000
0000FFFF800000FF00FF800000FF0000FF00FF0000FF800000FF00FF0000FF0000FF8000
FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00000000FFFF800000FF00
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF800000FF0000FF00FF800000FF00
0000FFFF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF8000
FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00000000FFFF800000FF00
00FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF800000FF0000FF00FF800000FF00
0000FFFF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF0000FF8000FF80000000FF
0000FF0000FFFF8000FF800000FF00FF0000FF800000FF000000FFFF0000FF0000FF8000
FF800000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00000000FFFF800000FF00
00FF00FF8000FF00000000FFFF8000FF8000FF800000FF00FF8000FF0000FF000000FF00
FF000000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF00000000FF0000FF
0000FF0000FFFF8000FF800000FF00FF0000FF800000FF000000FFFF00000000FFFF8000
0000FF00FF00FF0000FF000000FF00FF0000FF000000FF00FF00000000FFFF800000FF00
00FF00FF8000FF00000000FFFF8000FF8000FF800000FF00FF0000FF00000000FFFF8000
FF000000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF00FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF000000FF000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF00000000FF0000FFFF00000000FFFF8000
0000FF00FF00FF0000FF000000FF00FF0000FF000000FF00FF00000000FFFF8000FF8000
00FF00FF0000FF00000000FFFF8000FF800000FF0000FF00FF0000FF00000000FFFF8000
FF800000FF0000FF00FF800000FF00
FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF00FF0000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF80000000FFFF00000000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF00000000FF0000FFFF00000000FFFF8000
0000FF00FF00FF00000000FF00FF00FF000000FF0000FF00FF00000000FFFF8000FF8000
00FF00FF0000FF00000000FFFF8000FF800000FF0000FF00FF800000FF00FF8000FF8000
FF800000FF0000FF00FF8000FF8000
FF000000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF0000FF8000FF8000FF0000FF000000FF00FF0000FF800000FF00FF0000FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF000000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF80000000FF0000FFFF00000000FFFF8000
0000FF0000FFFF00000000FF00FF00FF000000FF0000FF00FF00000000FFFF8000FF8000
00FF00FF0000FF00000000FFFF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF00FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF00FF0000FF800000FF00FF000000FF0000FF00FF0000FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF80000000FFFF00000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF800000FF000000FFFF00000000FFFF0000
0000FF0000FF0000FFFF000000FF00FF000000FF0000FF00FF0000FF0000FF8000FF8000
00FF00FF8000FF00000000FFFF8000FF800000FF00FF8000FF800000FF00FF000000FF00
00FF0000FF00FF0000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF00FF8000FF800000FF00FF800000FF0000FF00FF0000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF000000FF
0000FFFF8000FF8000FF8000FF00000000FFFF800000FF000000FFFF00000000FFFF0000
0000FF00FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF000000FF00
0000FF00FF00FF0000FF000000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF000000FF
0000FFFF8000FF8000FF8000FF00000000FFFF800000FF000000FFFF0000FF0000FF0000
FF0000FF000000FF00FF0000FF8000FF000000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF0000FF000000FF00
0000FF0000FF0000FFFF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF
0000FFFF8000FF8000FF8000FF00000000FF0000FF00FF000000FFFF0000FF0000FF0000
FF00000000FFFF8000FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF0000FF0000FF0000
0000FFFF00000000FFFF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF000000FF
0000FF00FF00FF8000FF8000FF00000000FF0000FF0000FF0000FFFF000000FF00FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF0000FF0000FF0000
0000FFFF00000000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF00FF8000FF800000FF000000FF0000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FF00FF00FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00FF0000FF0000
0000FFFF00000000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF00FF0000FF800000FF000000FF0000FF0000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FF00FF0000FF00FF8000FF800000FF0000FF00FF800000FF00
FF800000FF00FF00000000FFFF800000FF0000FF0000FF00FF8000FF8000FF0000FF0000
0000FFFF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF80000000FF0000FF0000FF
0000FFFF0000FF0000FF80000000FF0000FF0000FF0000FFFF000000FF000000FFFF0000
FF0000FF0000FF0000FF000000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00
FF8000FF8000FF00000000FFFF800000FF0000FF0000FF00FF8000FF8000FF0000FF0000
0000FFFF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF80000000FF0000FF0000FF
FF0000FF0000FF000000FF00FF00000000FF0000FFFF0000FF000000FF00FF0000FF0000
0000FF0000FFFF0000FF000000FF0000FF00FF0000FF8000FF00000000FFFF800000FF00
FF8000FF0000FF00000000FFFF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF000000FFFF0000
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FF00FF000000FFFF000000FF0000FF00FF0000FF8000FF0000FF000000FF00FF8000
FF8000FF0000FF00000000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF000000FF00FF8000FF8000FF00000000FF
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000
0000FF00FF000000FFFF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00
FF800000FF0000FF000000FFFF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF000000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF80000000FFFF00000000FF
0000FFFF8000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FF00FF000000FFFF0000FF8000FF000000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF0000FF00FF0000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF00000000FFFF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF00000000FFFF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF80000000FF0000FF0000FF
FF0000FF8000FF8000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF8000
0000FF00FF000000FFFF0000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF0000FF00FF0000FF8000FF800000FF0000FF0000FF00FF800000FF00FF0000
FF0000FF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF00000000FFFF800000FF00FF800000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF0000FF800000FF00FF80000000FF0000FF0000FF
FF0000FF8000FF800000FF00FF00000000FFFF00000000FFFF0000FF00000000FFFF8000
0000FF0000FF0000FFFF0000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF00FF0000FF8000FF800000FF0000FF00FF800000FF00FF0000FF0000
0000FFFF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF8000FF00000000FFFF800000FF00FF800000FF0000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF800000FF00FF80000000FF0000FF0000FF
FF00000000FF0000FF00FF00FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
0000FFFF00000000FFFF0000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF0000FF0000
0000FFFF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF0000FF800000FF00FF800000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF0000FF00000000FF
FF80000000FFFF800000FF0000FF00FF00000000FF0000FF0000FF0000FFFF000000FF00
FF0000FF00000000FFFF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF0000
FF000000FF00FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00FF8000
00FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF80000000FFFF00000000FF
FF0000FF8000FF8000FF800000FF00FF00000000FF0000FF0000FF0000FFFF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF0000FF0000FF0000
FF0000FF000000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF80000000FFFF00000000FF
FF0000FF8000FF800000FF0000FF00FF0000FF0000FF00000000FFFF8000FF000000FF00
00FF0000FF00FF000000FF0000FF00FF0000FF800000FF0000FF0000FF00FF800000FF00
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF000000FF0000FF00
FF0000FF000000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF00000000FF0000FF0000FF
FF0000FF8000FF800000FF0000FF00FF0000FF0000FF00000000FFFF800000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF0000FF000000FF0000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF00FF800000FF00FF800000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF800000FF00FF000000FF0000FF000000FF00FF000000FF0000FF
0000FFFF80000000FF00FF000000FF0000FF0000FF0000FFFF0000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF0000FF0000FF00000000FFFF8000FF800000FF00
FF800000FF0000FF00FF0000FF8000FF8000FF8000FF000000FF0000FF00FF0000FF0000
FF0000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF00FF0000FF800000FF000000FF00FF000000FF0000FF
0000FFFF80000000FF00FF0000FF000000FF0000FF0000FFFF0000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF00000000FFFF0000FF00000000FFFF8000FF800000FF00
FF800000FF0000FF00FF00000000FFFF8000FF800000FF0000FF00FF0000FF0000FF0000
00FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF0000FF800000FF00FF800000FF000000FF0000FF
0000FFFF8000FF800000FF0000FF00FF00000000FFFF0000FF0000FF0000FF8000FF8000
FF800000FF00FF0000FF000000FF000000FFFF8000FF000000FF00FF8000FF800000FF00
FF800000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF0000
00FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF0000FF800000FF00FF800000FF00FF0000FF0000
0000FFFF8000FF8000FF800000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
FF800000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF000000FFFF800000FF00FF800000FF00FF0000FF0000
0000FFFF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF000000FF0000FF00
FF000000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF800000FF00FF0000FF0000
0000FFFF8000FF800000FF000000FFFF800000FF00FF800000FF00FF000000FF0000FF00
FF000000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF000000FFFF0000
0000FFFF8000FF0000FF00000000FFFF800000FF00FF800000FF00FF000000FF0000FF00
FF000000FF00FF0000FF000000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF000000FFFF0000
0000FFFF8000FF0000FF00000000FFFF800000FF00FF000000FF00FF000000FF00FF0000
FF000000FF00FF0000FF000000FF0000FF00FF8000FF00000000FFFF800000FF0000FF00
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF00000000FF0000FF
0000FF0000FFFF0000FF00000000FFFF000000FF00FF000000FF00FF0000FF0000FF0000
0000FF00FF00FF0000FF000000FF00FF8000FF0000FF00000000FFFF800000FF0000FF00
00FF00FF000000FF0000FF00FF000000FF0000FF00FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF00000000FF0000FF
FF00000000FFFF0000FF00000000FFFF000000FF00FF000000FF000000FFFF00000000FF
0000FF00FF00FF000000FF00FF0000FF0000FF0000FF00000000FFFF8000FF800000FF00
FF8000FF000000FF00FF8000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .23069 L
.2381 .23069 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .23069 L
.2381 .23069 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .12014 L
.47619 .12014 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .12014 L
.47619 .12014 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .18981 L
.71429 .18981 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .18981 L
.71429 .18981 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .10116 L
.95238 .10116 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .10116 L
.95238 .10116 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF800000FF00FF800000FF00FF8000FF000000FF00FF0000FF8000
00FF00FF000000FF0000FF000000FF0000FFFF0000FF000000FF00FF8000FF8000FF8000
00FF000000FFFF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF000000FF
FF0000FF00000000FFFF8000FF00000000FF00FF00FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF0000FFFF8000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF800000FF0000FF00FF800000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00FF800000FF00FF0000FF000000FF00FF0000FF8000
00FF00FF000000FF0000FF00FF00000000FFFF0000FF000000FF00FF8000FF8000FF8000
00FF000000FFFF000000FF00FF800000FF00FF0000FF000000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF00000000FFFF00000000FF0000FFFF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF0000FF00000000FFFF800000FF00FF80000000FF00FF000000FFFF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
00FF00FF000000FF00FF00000000FF0000FF0000FFFF000000FF000000FFFF8000FF8000
00FF0000FF00FF0000FF8000FF800000FF0000FF00FF800000FF00FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF8000FF000000FF00
FF00000000FF00FF0000FF00FF000000FF00FF80000000FF0000FF0000FFFF0000FF8000
FF0000FF000000FF00FF8000FF0000
FF0000FF800000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
00FF00FF000000FF00FF00000000FF0000FFFF00000000FFFF00000000FFFF0000FF8000
00FF00FF0000FF0000FF8000FF800000FF0000FF00FF000000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FFFF0000FF00000000FFFF8000FF8000FF000000FF00
FF00000000FF00FF000000FFFF0000FF8000FF800000FF000000FFFF00000000FF00FF00
FF0000FF000000FF00FF800000FF00
FF8000FF800000FF00FF8000FF8000FF800000FF000000FF00FF00FF0000FF000000FF00
00FF0000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF00FF0000FF0000FF8000FF800000FF00FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FF0000FF0000FF
0000FF0000FF00FF000000FFFF0000FF0000FF00000000FFFF8000FF000000FF0000FF00
FF00000000FF0000FFFF0000FF0000FF8000FF800000FF000000FFFF0000FF000000FF00
FF0000FF00000000FFFF8000FF0000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF000000FF0000FF00
FF0000FF8000FF8000FF00000000FFFF00000000FF0000FF0000FFFF0000FF000000FF00
FF0000FF0000FF0000FF8000FF800000FF00FF0000FF0000FF8000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF00000000FF00FF000000FF0000FF0000FFFF00000000FFFF8000FF000000FF0000FF00
FF0000FF00000000FFFF0000FF8000FF8000FF800000FF0000FF00FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF000000FF00FF0000
FF000000FF00FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
FF0000FF00000000FFFF8000FF800000FF0000FF00FF00000000FF00FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
0000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF8000FF8000FF800000FF0000FF0000FF00FF8000
00FF00FF0000FF0000FF0000FF0000
FF8000FF000000FF0000FF0000FF00FF8000FF800000FF0000FF00FF000000FF0000FF00
FF000000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF8000
00FF00FF00000000FFFF8000FF800000FF0000FF00FF00000000FF00FF000000FF0000FF
0000FF0000FFFF0000FF000000FF00FF0000FF800000FF00FF8000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF000000FF00FF8000FF8000FF8000FF800000FF00FF00000000FFFF8000
00FF000000FF0000FFFF0000FF0000
FF8000FF000000FF0000FF0000FF00FF800000FF0000FF00FF0000FF800000FF0000FF00
00FF0000FF00FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000
FF0000FF00000000FFFF8000FF800000FF0000FF00FF0000FF000000FF00FF00000000FF
0000FF0000FFFF0000FF000000FF00FF0000FF800000FF00FF8000FF8000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF000000FF0000FF00FF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000
0000FF0000FF0000FF0000FF00FF00
FF0000FF000000FF0000FF00FF0000FF800000FF0000FF00FF0000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF8000
FF000000FF00FF8000FF8000FF800000FF0000FF00FF0000FF800000FF000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF800000FF00FF8000FF80000000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF8000FF00000000FF00FF00
FF0000FF000000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF00000000FFFF0000
0000FFFF00000000FF0000FFFF0000
FF000000FF0000FF00FF0000FF0000FF800000FF0000FF00FF000000FF0000FF00FF8000
FF800000FF00FF800000FF000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF8000FF800000FF0000FF00FF0000FF00000000FF00FF000000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF800000FF00FF0000FF80000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FFFF00000000FFFF800000FF000000FF00FF00
FF0000FF000000FF0000FF0000FF00FF8000FF800000FF00FF8000FF0000FF0000FF0000
0000FFFF00000000FF0000FF0000FF
FF0000FF8000FF8000FF000000FF00FF800000FF0000FF00FF000000FF0000FF00FF8000
FF800000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF800000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF000000FF0000FF00FF0000FF00000000FFFF0000
0000FFFF000000FF000000FF0000FF0000FF0000FF0000FFFF800000FF00FF0000FF0000
FF0000FF0000FF800000FF0000FF00FF0000FF800000FF00FF800000FF000000FF00FF00
0000FFFF00000000FFFF80000000FF
FF0000FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000
FF800000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF8000
0000FFFF00000000FFFF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FF00FF00FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000FF8000
FF000000FF00FF8000FF000000FF00FF8000FF800000FF00FF8000FF80000000FF00FF00
0000FFFF00000000FFFF80000000FF
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF00FF0000FF800000FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000
0000FFFF00000000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FF00FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000
FF000000FF00FF8000FF000000FF00FF8000FF800000FF00FF8000FF80000000FFFF0000
0000FFFF0000FF0000FF00000000FF
00FF00FF0000FF800000FF0000FF0000FF00FF8000FF000000FF00FF8000FF800000FF00
FF800000FF0000FF00FF800000FF00FF00000000FFFF0000FF0000FF00000000FFFF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF00000000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF8000FF8000FF800000FF00FF8000FF80000000FFFF0000
0000FFFF0000FF000000FF00FF0000
00FF00FF0000FF800000FF00FF800000FF00FF8000FF00000000FFFF800000FF0000FF00
FF000000FF0000FF00FF000000FF00FF0000FF0000FF80000000FFFF00000000FFFF0000
0000FFFF8000FF0000FF0000FF0000FF800000FF0000FF00FF8000FF0000FF00000000FF
FF00000000FF0000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF
FF0000FF0000FF8000FF00000000FFFF8000FF800000FF0000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
00FF00FF0000FF800000FF00FF000000FF00FF0000FF00000000FFFF000000FF00FF8000
FF8000FF0000FF0000FF000000FF00FF0000FF000000FF000000FF00FF000000FFFF0000
FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF800000FF00FF8000FF00000000FFFF8000FF800000FF0000FF00FF0000FF0000FF8000
FF0000FF0000FF0000FF00000000FF
00FF0000FF00FF800000FF00FF000000FF000000FFFF00000000FFFF000000FF0000FF00
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF00000000FFFF0000FF8000FF800000FF0000FF00FF800000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF8000FF800000FF00
0000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF800000FF00FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF000000FF000000FFFF00000000FF
0000FF00FF00FF800000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF0000FF000000FF00FF8000FF000000FF00FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF000000FF00
FF800000FF00FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000FF00000000FF
00FF0000FF00FF000000FF00FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF00000000FF
0000FF00FF00FF8000FF800000FF0000FF000000FF00FF0000FF00FF0000FF800000FF00
FF8000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF000000FF00FF8000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF000000FF00FF0000FF0000FF00000000FF0000FF0000FFFF0000FF800000FF000000FF
00FF0000FF00FF00000000FF0000FF0000FFFF0000FF000000FF000000FF0000FFFF0000
0000FF00FF00FF0000FF000000FF00
FF000000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF0000FF800000FF00
00FF00FF8000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FF
FF0000FF00000000FF0000FF00FF00FF000000FF0000FF00FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF00000000FFFF0000FF000000FF00
FF0000FF80000000FF00FF000000FF0000FF0000FF0000FFFF000000FF0000FF00FF8000
00FF0000FF000000FF0000FF0000FFFF0000FF8000FF800000FF000000FF0000FF0000FF
0000FFFF0000FF0000FF00000000FF
00FF00FF000000FF00FF800000FF0000FF00FF800000FF0000FF00FF0000FF800000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF8000FF8000FF00000000FFFF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF0000FF00FF0000
00FF0000FF00FF000000FF000000FFFF0000FF0000FF8000FF80000000FF0000FF0000FF
0000FFFF00000000FFFF00000000FF
FF0000FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF8000FF8000FF800000FF00FF000000FF0000FF0000FF00FF800000FF000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF000000FF00FF0000FF0000
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF8000FF80000000FF0000FF0000FF
0000FFFF00000000FFFF00000000FF
00FF00FF0000FF0000FF800000FF0000FF00FF8000FF800000FF00FF000000FF00FF0000
FF0000FF8000FF8000FF8000FF00000000FFFF00000000FFFF0000FF0000FF000000FF00
00FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF800000FF0000FF00FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF00000000FF0000FF
FF0000FF00000000FF00FF000000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000
00FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF000000FF0000FF0000FF
0000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF800000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
FF0000FF8000FF8000FF800000FF000000FFFF000000FF00FF0000FF0000FF00000000FF
00FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF800000FF0000FF00FF0000
FF00000000FFFF80000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF00000000FF00FF000000FFFF00000000FFFF00000000FFFF0000
00FF0000FF00FF00000000FF0000FFFF0000FF000000FF00FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF
FF0000FF00000000FFFF8000FF00000000FFFF8000FF8000FF0000FF000000FF0000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF000000FF00FF0000FF0000FF80000000FF
00FF00FF000000FF00FF8000FF8000FF0000FF00000000FFFF800000FF0000FF00FF0000
FF00000000FFFF8000FF000000FF000000FF00FF000000FFFF00000000FF0000FFFF0000
0000FFFF000000FF00FF00000000FF00FF000000FFFF00000000FFFF000000FF00FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF00000000FF
FF0000FF000000FF00FF8000FF00000000FFFF8000FF8000FF000000FF0000FF0000FF00
00FF00FF800000FF00FF800000FF0000FF00FF00000000FF00FF000000FFFF800000FF00
00FF00FF0000FF000000FF00FF8000FF0000FF00000000FFFF800000FF0000FF00FF0000
FF00000000FFFF8000FF8000FF80000000FF00FF000000FFFF00000000FF0000FF0000FF
0000FFFF000000FF00FF0000FF000000FF000000FFFF00000000FFFF800000FF0000FF00
00FF0000FF00FF8000FF00000000FF0000FF0000FF00FF000000FF0000FFFF00000000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF000000FF00FF8000FF000000FF00FF8000FF8000FF800000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF00000000FF0000FFFF0000FF800000FF00
FF0000FF0000FF00000000FFFF8000FF0000FF00000000FFFF800000FF0000FF00FF0000
FF0000FF00000000FFFF8000FF00000000FF00FF000000FFFF00000000FF0000FF0000FF
0000FF0000FF00FF00FF0000FF0000FF0000FF00000000FFFF8000FF0000FF800000FF00
00FF0000FF00FF8000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF8000FF800000FF0000FF00FF800000FF00FF800000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF00000000FFFF8000FF0000FF0000FF0000FF000000FF0000FF00FF0000
0000FFFF00000000FFFF8000FF00000000FF00FF000000FFFF00000000FF0000FF0000FF
0000FF0000FF00FF000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF8000
00FF0000FF00FF800000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF8000FF000000FF0000FF00FF800000FF00FF8000FF8000FF0000FF8000
00FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF00FF00FF0000FF000000FF00FF80000000FF
0000FF0000FF0000FF0000FFFF000000FF0000FF000000FF00FF00FF00000000FF0000FF
0000FF0000FF00FF000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF8000
FF800000FF00FF800000FF00FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
FF8000FF0000FF8000FF000000FF0000FF00FF800000FF00FF8000FF00000000FFFF8000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF00FF00FF0000FF000000FF00FF80000000FF
0000FF0000FF0000FF0000FFFF000000FF0000FF00FF0000FF000000FF000000FF0000FF
0000FF0000FF00FF00FF00000000FFFF00000000FFFF00000000FFFF00000000FFFF8000
FF800000FF00FF80000000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF00000000FF0000FF
FF0000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FF0000FF0000FF0000FFFF000000FF00FF0000FF800000FF00FF80000000FF
0000FF0000FF0000FF0000FFFF0000FF000000FF00FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF00000000FF0000FF0000FFFF00000000FFFF00000000FFFF8000
FF800000FF00FF80000000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF8000FF000000FF00FF8000FF8000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF800000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF000000FF00FF0000FF0000FF0000FF00000000FF
FF8000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FFFF00000000FFFF8000
FF800000FF00FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF8000FF0000FF8000FF800000FF00FF0000FF00000000FFFF8000
FF00000000FFFF00000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF800000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF00000000FF0000FF0000FF0000FF
FF8000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF8000FF00000000FFFF800000FF00FF00000000FF0000FF0000FF
FF000000FF00FF80000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF800000FF00FF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF000000FF000000FF0000FF0000FF0000FF
0000FFFF8000FF000000FF000000FF0000FF0000FF0000FFFF0000FF00000000FFFF8000
FF8000FF800000FF00FF8000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF8000FF00000000FFFF800000FF00FF00000000FF0000FF0000FF
FF0000FF8000FF8000FF8000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF0000FF0000FF800000FF00FF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF00FF000000FF0000FF0000FF0000FFFF0000FF00000000FFFF8000
FF8000FF800000FF00FF8000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF0000FF00000000FFFF800000FF00FF00000000FF0000FF0000FF
FF0000FF8000FF8000FF8000FF00000000FF0000FF00FF000000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FFFF8000FF0000FF0000FF0000FF800000FF00FF00000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
FF8000FF00000000FF00FF000000FF0000FF0000FF0000FF0000FFFF00000000FFFF8000
FF8000FF800000FF000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .03212 L
.2381 .03212 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .03212 L
.2381 .03212 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .19273 L
.47619 .19273 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .19273 L
.47619 .19273 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01543 L
.71429 .01543 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01543 L
.71429 .01543 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .40153 L
.95238 .40153 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .40153 L
.95238 .40153 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF0000FF000000FF0000FF00FF8000FF8000FF8000FF00000000FFFF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF000000FF00FF0000FF8000
FF0000FF8000FF800000FF0000FF00
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF000000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000
0000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF000000FF00
00FF00FF8000FF8000FF000000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
0000FFFF800000FF00FF8000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000
00FF00FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FFFF8000
00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
00FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF0000
FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF00FF8000
00FF00FF8000FF000000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF00FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF800000FF00FF0000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF800000FF00FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF0000FF8000FF8000FF800000FF00FF0000FF000000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF00FF000000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF000000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF0000FF800000FF00FF800000FF00FF0000FF0000FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000
FF800000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF800000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF00FF0000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF00000000FFFF800000FF00
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF00FF0000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF800000FF00
FF8000FF800000FF0000FF00FF0000FF000000FF00FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF0000FF0000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF00000000FFFF800000FF00
FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF0000
FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF000000FF00
FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF000000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF000000FF00
00FF00FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF000000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF000000FF00
FF8000FF80000000FF00FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF000000FF00
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF800000FF00FF8000FF8000
FF800000FF000000FF00FF00FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF0000FF00000000FFFF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF000000FF00
FF8000FF8000FF000000FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF000000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000FF800000FF00
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF000000FF00FF8000
FF8000FF800000FF00FF800000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .55171 L
.2381 .55171 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .55171 L
.2381 .55171 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .06591 L
.95238 .06591 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .06591 L
.95238 .06591 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF800000FF00
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02753 L
.2381 .02753 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02753 L
.2381 .02753 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .35334 L
.47619 .35334 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .35334 L
.47619 .35334 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .22923 L
.71429 .22923 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .22923 L
.71429 .22923 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0317 L
.95238 .0317 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF0000FF000000FF0000FF00
0000FF00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF00FF0000FF0000FF000000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF800000FF00
FF800000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF00FF8000FF8000FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF00FF8000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF000000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF800000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF0000
FF800000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF000000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF00FF000000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF00FF8000FF8000FF0000FF0000FF8000
FF0000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF0000
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF800000FF00FF8000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF800000FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF0000
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF800000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF8000
FF000000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .30286 L
.47619 .30286 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .30286 L
.47619 .30286 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .30745 L
.71429 .30745 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .30745 L
.71429 .30745 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01919 L
.95238 .01919 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01919 L
.95238 .01919 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF0000FF800000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF800000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF8000
FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00FF800000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF800000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .11201 L
.2381 .11201 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .11201 L
.2381 .11201 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .07154 L
.47619 .07154 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .07154 L
.47619 .07154 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .44575 L
.95238 .44575 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .44575 L
.95238 .44575 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF8000FF8000FF0000
FF8000FF0000FF8000FF800000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF0000FF800000FF00FF8000FF8000FF0000FF0000FF000000FF00
FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000
FF8000FF800000FF0000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF800000FF00FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF000000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF000000FF00FF000000FF00FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00FF0000
FF8000FF8000FF8000FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF800000FF0000FF0000FF000000FF00FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
FF0000FF800000FF00FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF000000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF000000FF00FF800000FF00FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF000000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF000000FF00FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00
00FF00FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF800000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF800000FF00
FF0000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF800000FF00FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF0000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF800000FF00
00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
00FF0000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
00FF0000FF00FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000
FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000
FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF000000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF8000FF0000FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF000000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF0000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF00FF8000FF000000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF00FF0000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF000000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF000000FF00
00FF000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF000000FF00FF8000FF8000FF0000FF800000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l0
0?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool003[o
001o5oooO`04o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o00Go
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o00Go
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool003[o
001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0h
o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05
o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`00
0?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
K_l007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`1^o`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1^o`00O`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;oooooL_l0000Wooooog7o00009ooooomao`0002OoooooL_l0000Soooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool20?l00080oh002P3o00020?n0
00@0o`000P3oP0000`3o0000oh000?n000020?n000T0o`000P3oP00@0?l00080oh002@3o00000`3o
P000o`000?l000040?l000030?n0003o0000o`0000T0o`00103oP0090?l000<0oh003@3o00020?n0
01<0o`00103oP00>ooooob000?l02@000?l=003o00<0003o2000o`000`000?l00?l0003o0009003o
00D0003o2000o`0<0000o`L00?l05P000?l3003o0080003o0P00o`0>ooooo`80003o2@00o`0@0000
o`800?l000<0003o003o0000o`001000o`0M0000o`030?n000000?l0003o00@0003o0`00o`0?0000
o`030?n000000?l0003o0080003o0P3oP00Y0000o`kooooo1@3o00020?n00080o`001`3oP0020?l0
00@0oh000`3o00050?n00080003o3@3oP0050?l00080oh000P000?l30?l00080oh000P000?l20?n0
00T0o`002@3oP0000`3o0000003o0000o`020?n000D0o`00203oP0050?l00080oh001@3o00040?n0
00030?l0003oP000oh0000H0o`001@3oP0020?l00080oh001@3o000Hooooo`005_ooool20?l00080
oh002P3o00020?n000@0o`000P3oP0000`3o0000oh000?n000020?n000T0o`000P3oP00@0?l00080
oh002@3o00000`3oP000o`000?l000040?l000030?n0003o0000o`0000T0o`00103oP0090?l000<0
oh003@3o00020?n001<0o`00103oP00>ooooob000?l02@000?l=003o00<0003o2000o`000`000?l0
0?l0003o0009003o00D0003o2000o`0<0000o`L00?l05P000?l3003o0080003o0P00o`0>ooooo`80
003o2@00o`0@0000o`800?l000<0003o003o0000o`001000o`0M0000o`030?n000000?l0003o00@0
003o0`00o`0?0000o`030?n000000?l0003o0080003o0P3oP00Y0000o`kooooo1@3o00020?n00080
o`001`3oP0020?l000@0oh000`3o00050?n00080003o3@3oP0050?l00080oh000P000?l30?l00080
oh000P000?l20?n000T0o`002@3oP0000`3o0000003o0000o`020?n000D0o`00203oP0050?l00080
oh001@3o00040?n000030?l0003oP000oh0000H0o`001@3oP0020?l00080oh001@3o000Hooooo`00
5_oooolI0?l00080oh000P3o00000`3oP000o`000?l000040?l00080oh001@3o00040?n000L0o`00
0P3oP00L0?l00080oh003P3o00020?n00080o`00103oP0070?l000030?n0003o0000o`000080o`00
0P3oP00<0?l00080oh000P3o000>ooooo`800?l00P000?lL003o0080003o0P3oP0020000o`<0oh00
0P000?l;003o00L0003o1000o`000`000?l00?l0003o000=003o00030000o`00o`000?l000@00?l0
30000?l2003o0080003o2@00o`0I0000o`kooooo2`00o`070000o`80oh000P000?l00`3oP000003o
0000o`020000o`L00?l05P000?l5003o01@0003o1`00o`0@0000o`80oh000`000?l20?n00180003o
0P3oP0030000o`80oh000P000?l>ooooo`80oh000P3o00050?n00080o`001@3oP0020?l000@0oh00
00<0o`000?n0003oP0000P3oP0020000o`<0oh000P000?l40?n000<0o`001P3oP0000`3o0000oh00
0?n0000=0?n00080o`0000<0oh000?l0003o0000103o00000`3oP000o`000?l000020?n000L0o`00
0P3oP0050?l00080oh00103o00090?n000X0o`000P3oP0060?l000D0oh00103o00000`3oP000o`00
0?l000020?n001Sooooo000FoooooaT0o`000P3oP0020?l000030?n0003o0000o`0000@0o`000P3o
P0050?l000@0oh001`3o00020?n001`0o`000P3oP00>0?l00080oh000P3o00040?n000L0o`0000<0
oh000?l0003o00000P3o00020?n000`0o`000P3oP0020?l000kooooo0P00o`020000oa`00?l00P00
0?l20?n00080003o0`3oP0020000o`/00?l01`000?l4003o00030000o`00o`000?l000d00?l000<0
003o003o0000o`001000o`0<0000o`800?l00P000?l9003o01T0003o3_ooool;003o00L0003o0P3o
P0020000o`030?n000000?l0003o0080003o1`00o`0F0000o`D00?l050000?l7003o0100003o0P3o
P0030000o`80oh004P000?l20?n000<0003o0P3oP0020000o`kooooo0P3oP0020?l000D0oh000P3o
00050?n00080o`00103oP0000`3o0000oh000?n000020?n00080003o0`3oP0020000o`@0oh000`3o
00060?n000030?l0003oP000oh0000d0oh000P3o00000`3oP000o`000?l000040?l000030?n0003o
0000o`000080oh001`3o00020?n000D0o`000P3oP0040?l000T0oh002P3o00020?n000H0o`001@3o
P0040?l000030?n0003o0000o`000080oh006?ooool001Kooooo0P3oP00Y0?l00080oh000`3o0002
0?n00080o`001@3oP00@0?l00080oh002@3o00020?n00180o`000P3oP0050?l000D0oh000P3o0002
0?n000h0o`00103oP00>ooooo`@0003o3P00o`020000oa000?l00`000?l?003o00L0003o1000o`05
0000oa800?l040000?l7003o00L0003o0P00o`050000o`80oh002`000?l>ooooo`T00?l03@000?l0
0`3oP000003o0000o`020000o`D00?l040000?l60?n000<0003o0P00o`0D0000o`80oh002@000?l5
003o00T0003o0P3oP0030000o`80oh002`000?l70?l000T0003o3_ooool40?l000D0003o1`3o000=
0?n000<0o`000P3oP0020000o`<0oh0010000?l;0?n00080o`001@3oP0040?l000<0oh000P3o0007
0?n00080o`001@3oP0020000o`D0o`00203oP0000`3o0000oh000?n000060?n000030?l0003oP000
oh000080oh000P3o00050?n00080o`000`3oP0040?l00080oh000P3o00050?n001Sooooo000Foooo
o`@0oh0000<0o`000?n0003oP0000P3oP00I0?l00080oh001`3o00040?n000030?l0003oP000oh00
0080o`000P3oP0030?l00080oh00103o00030?n000L0o`000P3oP00M0?l00080oh000P3o00000`3o
P000o`000?l000040?n000030000o`3oP000oh000080o`001@3oP0090?l00080003o0P3oP00>oooo
o`@0003o3P00o`020000o`h00?l010000?l@003o00L0003o6`00o`050000o`800?l00P000?l2003o
00030000o`00o`000?l00080003o1`00o`090000o`80oh000P000?l30?n000T0003o0P00o`0>oooo
o`80oh001`00o`070000o`H0o`0000<0oh000000o`000?l00P3oP003003o00H0003o0P3oP00B0000
o`T00?l01@000?l20?n000T0003o00<0oh000000o`000?l010000?l5003o0100003o0P3oP0020000
o`<0oh000P000?l20?n00080o`001`3oP0040000o`03003o00000?l0003o0080003o3_ooool40?l0
00030000o`00o`000?l00080003o0P3oP0070?l000@0oh0000<0o`000?n0003oP0000P3oP0020000
o`D0oh001@3o00020?n000H0o`000`3oP0060?l000<0oh0010000?lB0?n000030000o`3oP000oh00
00@0oh000P3o00030?n00080o`00103oP0030?l00080oh000P3o00070?n00080003o1`3o00090?n0
0080o`001@3oP00Hooooo`005_ooool40?n000030?l0003oP000oh000080oh006@3o00020?n000L0
o`00103oP0000`3o0000oh000?n000020?l00080oh000`3o00020?n000@0o`000`3oP0070?l00080
oh007@3o00020?n00080o`0000<0oh000?l0003o0000103oP0000`000?l0oh000?n000020?l000D0
oh002@3o00020000o`80oh003_ooool40000o`h00?l00P000?l>003o00@0003o4000o`070000oa/0
0?l01@000?l2003o0080003o0P00o`000`000?l00?l0003o00020000o`L00?l02@000?l20?n00080
003o0`3oP0090000o`800?l03_ooool20?n000L00?l01`000?l60?l000030?n000000?l0003o0080
oh000`00o`060000o`80oh004P000?l9003o00D0003o0P3oP0090000o`030?n000000?l0003o00@0
003o1@00o`0@0000o`80oh000P000?l30?n00080003o0P3oP0020?l000L0oh0010000?l00`00o`00
003o0000o`020000o`kooooo103o00000`000?l00?l0003o00020000o`80oh001`3o00040?n00003
0?l0003oP000oh000080oh000P000?l50?n000D0o`000P3oP0060?l000<0oh001P3o00030?n000@0
003o4P3oP0000`000?l0oh000?n000040?n00080o`000`3oP0020?l000@0oh000`3o00020?n00080
o`001`3oP0020000o`L0o`002@3oP0020?l000D0oh006?ooool001Kooooo0P3o00020?n000<0o`00
103oP00R0?l00080oh001@3o00020?n000<0o`000P3oP0070?l00080oh000P3o00020?n000<0o`00
0P3oP00G0?l00080oh002@3o00040?n000030?l0003oP000oh0000T0oh001`3o00020000o`80oh00
3_ooool20000o`80oh00:@00o`020000oaL00?l00P000?l<003o0080003o4P00o`070000o`800?l0
0`000?l2003o00l0003o1@00o`0>ooooo`80003o2`00o`0A0000o`800?l00P3oP0040000o`<0oh00
2@000?l20?n000D0003o1000o`020000o`800?l00`000?l70?n00080003o0P3oP0030000o`80oh00
1`000?l2003o00d0003o0P00o`0>0000o`L0oh002@000?l>ooooo`80o`000`3oP0040?l000D0oh00
103o00020?n00080o`0000<0oh000000o`000?l00P3oP0020000o`X0oh000P3o00040?n00080o`00
1@3oP0020?l000<0oh001P3o00030?n000L0o`000P3oP0020000o`/0oh000P3o00030?n00080o`00
103oP0000`3o0000oh000?n000020?l000L0oh000P000?l30?n000T0o`00203oP0000`3o0000oh00
0?n000020?n001Sooooo000Fooooo`80o`000P3oP0030?l000@0oh008P3o00020?n000D0o`000P3o
P0030?l00080oh001`3o00020?n00080o`000P3oP0030?l00080oh005`3o00020?n000T0o`00103o
P0000`3o0000oh000?n000090?n000L0o`000P000?l20?n000kooooo0P000?l20?n002T00?l00P00
0?lG003o0080003o3000o`020000oa800?l01`000?l2003o00<0003o0P00o`0?0000o`D00?l03_oo
ool20000o`/00?l04@000?l2003o0080oh0010000?l30?n000T0003o0P3oP0050000o`@00?l00P00
0?l2003o00<0003o1`3oP0020000o`80oh000`000?l20?n000L0003o0P00o`0=0000o`800?l03P00
0?l70?n000T0003o3_ooool20?l000<0oh00103o00050?n000@0o`000P3oP0020?l000030?n00000
0?l0003o0080oh000P000?l:0?n00080o`00103oP0020?l000D0oh000P3o00030?n000H0o`000`3o
P0070?l00080oh000P000?l;0?n00080o`000`3oP0020?l000@0oh0000<0o`000?n0003oP0000P3o
00070?n00080003o0`3oP0090?l000P0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool7
0?l00080oh001@3o00060?n000h0o`000P3oP0070?l00080oh002@3o00020?n001<0o`00103oP003
0?l000@0oh006@3o00020?n000D0o`00103oP0020000o`L0o`001@3oP0020000o`koooooAP00o`02
0000o``00?l010000?l2003o00030000o`00o`000?l000H00?l01`000?l2003o00030000o`00o`00
0?l000L00?l01`000?l20?n000T0003o0P00o`0>ooooo`80003o2@00o`0;0000o`030?n000000?l0
003o00h0003o0P3oP00@0000o`P00?l01@000?l20?n000<0003o0P3oP0020?l000D0oh0050000?l2
003o0080003o00<0oh000000o`000?l01`000?l2003o00D0003o103oP0090000o`kooooo0P3o0002
0?n000D0o`00103oP0030?l000@0oh000P3o00000`3oP000o`000?l000050?n000@0o`000P3oP003
0?l00080oh000P3o00020?n00080o`001@3oP00;0?l000<0oh001P3o00030?n000/0o`001`3oP004
0?l000<0oh000P000?l20?l00080oh000P3o00030?n00080003o0P3o00000`3oP000o`000?l00006
0?l000<0oh000P3o00020?n000L0o`006?ooool001Kooooo1`3o00020?n000D0o`001P3oP00>0?l0
0080oh001`3o00020?n000T0o`000P3oP00C0?l000@0oh000`3o00040?n001T0o`000P3oP0050?l0
00@0oh000P000?l70?l000D0oh000P000?l>ooooodH00?l00P000?l<003o00@0003o0P00o`000`00
0?l00?l0003o0006003o00L0003o0P00o`000`000?l00?l0003o0007003o00L0003o0P3oP0090000
o`800?l03_ooool20000o`T00?l02`000?l00`3oP000003o0000o`0>0000o`80oh0040000?l8003o
00D0003o0P3oP0030000o`80oh000P3o00050?n001@0003o0P00o`020000o`030?n000000?l0003o
00L0003o0P00o`050000o`@0oh002@000?l>ooooo`80o`000P3oP0050?l000@0oh000`3o00040?n0
0080o`0000<0oh000?l0003o00001@3oP0040?l00080oh000`3o00020?n00080o`000P3oP0020?l0
00D0oh002`3o00030?n000H0o`000`3oP00;0?l000L0oh00103o00030?n00080003o0P3o00020?n0
0080o`000`3oP0020000o`80o`0000<0oh000?l0003o00001P3o00030?n00080o`000P3oP0070?l0
01Sooooo000Fooooo`80oh003P3o00020?n000L0o`001@3oP0020?l000@0oh000`3o00080?n000L0
o`000P3oP00L0?l000@0oh000P3o00050?n00280o`000P3oP0020000o`<0oh000P3o000>oooood40
0?l000<0003o003o0000o`000P00o`020000oaT00?l00`000?l8003o00030000o`00o`000?l000T0
0?l01@000?l20?n000800?l01`000?l2003o00kooooo2`00o`090000o`<0oh00=0000?l20?n00080
o`001@3oP00H0000o`030?n000000?l0003o00@0003o2@00o`0:0000o`@00?l03_ooool90?l000D0
oh000P3o00040?n000D0o`000P3oP0020000o`D0o`000P3oP0070?l000T0oh002@3o00020?n000X0
o`000P3oP0070?l00080oh000P3o00070?n000@0o`000`3oP0020000o`@0oh000P3o00030?n00080
003o0P3o00000`3oP000o`000?l000070?n00080003o103o00020?n000D0o`006?ooool001Kooooo
403o00020?n000L0o`000P3oP0050?l00080oh002`3o00020?n000<0o`000P3oP0020?l000<0oh00
603o00000`000?l0o`000?l000040?l00080oh00:`3o00000`000?l0o`000?l000020?l000kooooo
?@00o`050000o`/00?l00P000?l7003o0080003o4000o`040000o`03003o00000?l0003o00T00?l0
10000?l5003o0080003o0P00o`030000o`800?l03_ooool20000o`L00?l01`000?l6003o01<0003o
0P3oP0040000o`030?n00000o`000?l001L0003o103oP0020?l000D0oh000P000?l20?n00380003o
3_ooool20?l00080oh000`3o000?0?n000030?l000000?l0003o0080oh000P000?l50?l00080oh00
1`3o00070?n00080003o0P3oP0070?l000@0oh001`3o00030?n000@0o`000P3oP0000`3o0000oh00
0?n000070?n000H0o`001`3oP0020000o`L0oh000`3o00040?n00080o`000`3oP0020000o`80oh00
0P3o00050?n00080o`006?ooool001Kooooo403o00020?n000L0o`000P3oP0050?l00080oh002`3o
00020?n000<0o`000P3oP0020?l000<0oh00603o00000`000?l0o`000?l000040?l00080oh00:`3o
00000`000?l0o`000?l000020?l000kooooo?@00o`050000o`/00?l00P000?l7003o0080003o4000
o`040000o`03003o00000?l0003o00T00?l010000?l5003o0080003o0P00o`030000o`800?l03_oo
ool20000o`L00?l01`000?l6003o01<0003o0P3oP0040000o`030?n00000o`000?l001L0003o103o
P0020?l000D0oh000P000?l20?n00380003o3_ooool20?l00080oh000`3o000?0?n000030?l00000
0?l0003o0080oh000P000?l50?l00080oh001`3o00070?n00080003o0P3oP0070?l000@0oh001`3o
00030?n000@0o`000P3oP0000`3o0000oh000?n000070?n000H0o`001`3oP0020000o`L0oh000`3o
00040?n00080o`000`3oP0020000o`80oh000P3o00050?n00080o`006?ooool001Kooooo1@3o0004
0?n00100o`000P3oP0070?l00080oh001@3o00020?n000T0o`001@3oP00_0?l000@0oh00303o0002
0?n000/0o`0000<0oh000?l0003o00000P3o000>oooooc/00?l010000?l2003o00030000o`00o`00
0?l000L00?l01`000?l2003o00@0003o:@00o`070000o`800?l03_ooool2003o01L0003o0P00o`0;
0000o`030?n000000?l0003o0080oh0010000?l00`3oP000003o0000o`090000o`80oh0040000?l2
0?n00080o`000`3oP0020000o`80oh007P000?l2003o0180003o3_ooool20?l00080oh0000<0o`00
0?n0003oP0000P3o00090?n000@0o`0000<0oh000000o`000?l00P3oP0020000o`030?n0003o0000
o`0000@0oh001@3o00040?n000<0o`000P3oP0020000o`80o`000P3oP0030?l000@0oh000`3o0002
0?n00080o`002`3oP0000`3o0000oh000?n000060?n000030000o`3o0000o`000080o`00103oP000
0`000?l0oh000?n000060?l000L0oh0000<0o`000?n0003oP0000P3oP0020?l000L0003o103oP000
0`3o0000oh000?n000020?n001Sooooo000Fooooo`D0o`00103oP00@0?l00080oh001`3o00020?n0
00D0o`000P3oP0090?l000D0oh00;`3o00040?n000`0o`000P3oP00;0?l000030?n0003o0000o`00
0080o`003_oooolk003o00@0003o0P00o`000`000?l00?l0003o0007003o00L0003o0P00o`040000
obT00?l01`000?l2003o00kooooo0P00o`0G0000o`800?l02`000?l00`3oP000003o0000o`020?n0
00@0003o00<0oh000000o`000?l02@000?l20?n00100003o0P3oP0020?l000<0oh000P000?l20?n0
01h0003o0P00o`0B0000o`kooooo0P3o00020?n000030?l0003oP000oh000080o`002@3oP0040?l0
00030?n000000?l0003o0080oh000P000?l00`3oP000o`000?l000040?n000D0o`00103oP0030?l0
0080oh000P000?l20?l00080oh000`3o00040?n000<0o`000P3oP0020?l000/0oh0000<0o`000?n0
003oP0001P3oP0000`000?l0o`000?l000020?l000@0oh0000<0003o0?n0003oP0001P3o00070?n0
00030?l0003oP000oh000080oh000P3o00070000o`@0oh0000<0o`000?n0003oP0000P3oP00Hoooo
o`005_ooool70?l000@0oh000P3o00050?n00280o`002@3oP0020?l00080oh001`3o00030?n00080
o`000P3oP0020?l000<0003o8P3o00060?n000T0o`0000<0oh000?l0003o00000P3o000>oooood40
0?l01@000?l5003o00T0003o0P00o`040000oah00?l01@000?l2003o00L0003o0P3oP002003o00ko
oooo0P000?l2003o00<0003o0P00o`070000o`@00?l01@000?l2003o00`0003o0P3oP00T0000o`80
oh000P3o00030?n00080003o0P3oP00;0000o`030?n000000?l0003o00@0oh000`000?l20?n00100
003o1P00o`050000o`kooooo0P3oP0020?l000<0oh000P000?l40?n000<0003o103o00020?n00003
0?l0003oP000oh0000D0oh000P3o00070?n00080o`00103oP0030?l000@0oh000P3o00030?n00080
o`00103oP0020?l000D0oh001`3o000=0?n000030?l0003oP000oh000080o`00103oP0000`000?l0
o`000?l000020?n000L0o`000P3oP0020000o`D0oh000P3o00020?n000`0003o0P3oP00Hooooo`00
5_ooool70?l000@0oh000P3o00050?n00280o`002@3oP0020?l00080oh001`3o00030?n00080o`00
0P3oP0020?l000<0003o8P3o00060?n000T0o`0000<0oh000?l0003o00000P3o000>oooood400?l0
1@000?l5003o00T0003o0P00o`040000oah00?l01@000?l2003o00L0003o0P3oP002003o00kooooo
0P000?l2003o00<0003o0P00o`070000o`@00?l01@000?l2003o00`0003o0P3oP00T0000o`80oh00
0P3o00030?n00080003o0P3oP00;0000o`030?n000000?l0003o00@0oh000`000?l20?n00100003o
1P00o`050000o`kooooo0P3oP0020?l000<0oh000P000?l40?n000<0003o103o00020?n000030?l0
003oP000oh0000D0oh000P3o00070?n00080o`00103oP0030?l000@0oh000P3o00030?n00080o`00
103oP0020?l000D0oh001`3o000=0?n000030?l0003oP000oh000080o`00103oP0000`000?l0o`00
0?l000020?n000L0o`000P3oP0020000o`D0oh000P3o00020?n000`0003o0P3oP00Hooooo`005_oo
ool70?l00080oh001`3o00020000o`@0oh0000<0o`000?n0003oP0000P3oP00@0?l00080oh005`3o
00020?n000D0o`000P3oP0020?l00080oh009@3o00060000o`030?n0003o0000o`000080o`001`3o
P0020?l000kooooo9P00o`000`000?l00?l0003o000B003o00L0003o2@00o`0=0000o`800?l000<0
003o003o0000o`006@00o`0D0000o`kooooo3@000?l00`00o`00003o0000o`07003o00d0003o0P00
o`070000o`80oh005@000?l20?n001L0003o0P00o`0>0000o`800?l010000?l5003o00L0003o1P00
o`050000o`kooooo1@3o00020?n000@0o`000P3oP0030000o`80oh000P3o00030?n00080003o0P3o
P0020?l000L0oh000P3o00030?n000@0o`000P3oP0000`3o0000oh000?n000040?l00080oh000`3o
00020?n00080o`000P3oP0000`000?l0oh000?n000020?n00080o`0000<0oh000?l0003o00000P3o
P0040?l000D0oh000P3o00020?n000030?l0003oP000oh000080oh0010000?l50?n000D0o`00103o
P0020000o`030?n0003o0000o`0000@0oh000`000?l20?n00080003o103oP0050000oaSooooo000F
ooooo`L0o`000P3oP0070?l00080003o103oP0000`3o0000oh000?n000020?n00100o`000P3oP00G
0?l00080oh001@3o00020?n00080o`000P3oP00U0?l000H0003o00<0oh000?l0003o00000P3o0007
0?n00080o`003_oooolV003o00030000o`00o`000?l001800?l01`000?l9003o00d0003o0P00o`00
0`000?l00?l0003o000I003o01@0003o3_ooool=0000o`03003o00000?l0003o00L00?l03@000?l2
003o00L0003o0P3oP00E0000o`80oh005`000?l2003o00h0003o0P00o`040000o`D00?l01`000?l6
003o00D0003o3_ooool50?l00080oh00103o00020?n000<0003o0P3oP0020?l000<0oh000P000?l2
0?n00080o`001`3oP0020?l000<0oh00103o00020?n000030?l0003oP000oh0000@0o`000P3oP003
0?l00080oh000P3o00020?n000030000o`3oP000oh000080oh000P3o00000`3oP000o`000?l00002
0?n000@0o`001@3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0040000o`D0oh001@3o0004
0?n00080003o00<0oh000?l0003o0000103oP0030000o`80oh000P000?l40?n000D0003o6?ooool0
01Kooooo403o00020?n00080o`000P3oP0000`3o0000oh000?n000040?l000030?n0003o0000o`00
00H0oh0000<0o`000?n0003oP0000P3o00020?n000T0o`000P3oP0070?l00080oh001@3o00020?n0
02L0o`000P3oP0070?l00080oh001`3o00020000o`<0oh00103o000>ooooo`800?l00P000?lP003o
00D0003o4P00o`070000o`T00?l03@000?l;003o00030000o`00o`000?l001800?l01`000?l2003o
00T0003o3_ooool;0000o`T00?l06@000?l20?n000X0003o2000o`030000o`@0oh003P000?l9003o
00/0003o0P00o`050000o`T00?l01`000?l4003o00D0003o3_ooool20?n00080o`000`3oP0020000
o`@0oh000`000?l20?n00080o`000`3oP0040000o`80o`001`3oP0020?l000<0oh000P3o00070?n0
0080o`000P3oP0020?l000D0oh000P3o00070?n000T0o`000P3oP0050?l000@0oh0000<0003o0?n0
003oP0000P3oP0020?l00080oh0000<0o`000?n0003oP000103oP0050?l000@0oh0000<0003o0?n0
003oP0000P3oP0020?l000D0oh001P000?l00`3o0000oh000?n000020?n001Sooooo000Fooooo`80
oh003P3o00020?n000`0o`000P3oP0020?l00080003o0P3oP0000`3o0000oh000?n000060?n00200
o`000P3oP00<0?l00080oh00403o00020?n000T0o`000P3oP0050?l00080oh000`3o00020?n00080
o`003_ooool2003o0080003o8000o`030000oaH00?l02@000?l5003o00L0003o0P00o`070000o`P0
0?l000<0003o003o0000o`002@00o`040000o`h00?l02@000?l>ooooo`D0003o0P00o`060000o`03
003o00000?l0003o01@0003o0`00o`0B0000o`T00?l010000?l20?n000h0003o2`00o`050000o`80
0?l06@000?l4003o00030000o`3o0000o`000080o`003_ooool70?l000H0oh0000<0003o0?l0003o
00001`3oP0020000o`@0oh0000<0003o0?n0003oP0000P000?l50?l000@0oh001@3o00020?n00080
o`000P3oP0050?l000L0oh00103o00020?n000L0o`000P3oP0000`3o0000oh000?n000020?l000L0
oh000P3o00040?n000030?l0003oP000oh000080oh001`3o00020?n00080o`000`3oP0020?l000@0
oh000`000?l70?l00080oh000P3o000Hooooo`005_ooool20?n000h0o`000P3oP00<0?l00080oh00
0P3o00020000o`80oh0000<0o`000?n0003oP0001P3oP00P0?l00080oh00303o00020?n00100o`00
0P3oP0090?l00080oh001@3o00020?n000<0o`000P3oP0020?l000kooooo0P00o`020000ob000?l0
0`000?lF003o00T0003o1@00o`070000o`800?l01`000?l8003o00030000o`00o`000?l000T00?l0
10000?l>003o00T0003o3_ooool50000o`800?l01P000?l00`00o`00003o0000o`0D0000o`<00?l0
4P000?l9003o00@0003o0P3oP00>0000o`/00?l01@000?l2003o01T0003o1000o`000`000?l0o`00
0?l000020?l000kooooo1`3o00060?n000030000o`3o0000o`0000L0oh000P000?l40?n000030000
o`3oP000oh000080003o1@3o00040?n000D0o`000P3oP0020?l00080oh001@3o00070?n000@0o`00
0P3oP0070?l00080oh0000<0o`000?n0003oP0000P3o00070?n00080o`00103oP0000`3o0000oh00
0?n000020?n000L0o`000P3oP0020?l000<0oh000P3o00040?n000<0003o1`3o00020?n00080o`00
6?ooool001Kooooo103oP00N0?l00080oh002@3o00030?n00080o`000P3oP0040?l000030?n0003o
0000o`0000@0o`000P3oP00I0?l000030?n0003o0000o`0000@0o`000P3oP0030?l000@0oh005`3o
00020?n00080003o1@3o000>ooooo`800?l00`000?l2003o00H0003o5`00o`030000oaP00?l00`00
0?l?003o00030000o`00o`000?l000/00?l01@000?l;003o00@0003o1@00o`050000o`800?l02`00
0?l>ooooo`D0003o1000o`0@0000o`80oh001`00o`0>0000o`80oh001`000?l8003o01<0003o0P3o
P002003o00L0003o1000o`070000o`800?l07P000?l>ooooo`80003o1@3o00070?n000@0o`000P3o
P0020?l000D0oh000P000?l50?l00080oh000P3o00030?n000L0o`000P3oP0020?l000@0oh000`3o
00040?n00080003o00<0o`000?n0003oP0000P3oP0070?l000L0oh000P3o00070?n000H0o`0000<0
oh000?l0003o00000P3o00020?n000D0o`00103oP0000`000?l0o`000?l000020?l00080oh000`00
0?l20?n000H0o`0000<0oh000?l0003o00000P3oP00Hooooo`005_ooool40?n001h0o`000P3oP009
0?l000<0oh000P3o00020?n000@0o`0000<0oh000?l0003o0000103o00020?n001T0o`0000<0oh00
0?l0003o0000103o00020?n000<0o`00103oP00G0?l00080oh000P000?l50?l000kooooo0P00o`03
0000o`800?l01P000?lG003o00<0003o6000o`030000o`l00?l000<0003o003o0000o`002`00o`05
0000o`/00?l010000?l5003o00D0003o0P00o`0;0000o`kooooo1@000?l4003o0100003o0P3oP007
003o00h0003o0P3oP0070000o`P00?l04`000?l20?n000800?l01`000?l4003o00L0003o0P00o`0N
0000o`kooooo0P000?l50?l000L0oh00103o00020?n00080o`001@3oP0020000o`D0o`000P3oP002
0?l000<0oh001`3o00020?n00080o`00103oP0030?l000@0oh000P000?l00`3o0000oh000?n00002
0?n000L0o`001`3oP0020?l000L0oh001P3o00000`3oP000o`000?l000020?l00080oh001@3o0004
0?n000030000o`3o0000o`000080o`000P3oP0030000o`80oh001P3o00000`3oP000o`000?l00002
0?n001Sooooo000Fooooo`T0o`000P3oP0020?l000030?n0003o0000o`000080o`000P3oP00@0?l0
0080oh001@3o00020?n000D0o`000P000?l50?l00080oh000P3o00020?n00080o`0000<0oh000?l0
003o00000P3oP0020?l000030?n0003o0000o`000100o`000P3oP00;0?l000@0oh0000<0o`000?n0
003oP0002`3o00020?n000T0o`0000<0oh000?l0003o00000P3o000>ooooo`L00?l00P000?l>003o
00/0003o6@00o`040000o``00?l01P000?l7003o00D0003o0P00o`070000oaL00?l02`000?l2003o
00kooooo1@000?l2003o02@0003o0P3oP0030000o`80oh002@000?l6003o0140003o103oP0070000
o`@00?l0:@000?l>ooooo`@0oh0000<0o`000?n0003oP0000P3oP0020000o`<0oh000P3o00040?n0
00<0o`00103oP0020000o`030?l0003oP000oh0000T0oh000P000?l50?l00080oh000P3o00020?n0
00D0o`001`3oP0040?l000<0oh000P3o00060?n000030?l0003oP000oh0000L0oh003@3o00040?n0
00030?l0003oP000oh0000@0oh001@3o00020?n00080o`000`000?l40?l000L0oh006?ooool001Ko
oooo2@3o00020?n00080o`0000<0oh000?l0003o00000P3o00020?n00100o`000P3oP0050?l00080
oh001@3o00020000o`D0o`000P3oP0020?l00080oh000P3o00000`3oP000o`000?l000020?n00080
o`0000<0oh000?l0003o0000403o00020?n000/0o`00103oP0000`3o0000oh000?n0000;0?l00080
oh002@3o00000`3oP000o`000?l000020?l000kooooo1`00o`020000o`h00?l02`000?lI003o00@0
003o3000o`060000o`L00?l01@000?l2003o00L0003o5`00o`0;0000o`800?l03_ooool50000o`80
0?l090000?l20?n000<0003o0P3oP0090000o`H00?l04@000?l40?n000L0003o1000o`0Y0000o`ko
oooo103oP0000`3o0000oh000?n000020?n00080003o0`3oP0020?l000@0oh000`3o00040?n00080
003o00<0o`000?n0003oP0002@3oP0020000o`D0o`000P3oP0020?l00080oh001@3o00070?n000@0
o`000`3oP0020?l000H0oh0000<0o`000?n0003oP0001`3oP00=0?l000@0oh0000<0o`000?n0003o
P000103oP0050?l00080oh000P3o00030000o`@0o`001`3oP00Hooooo`005_ooool70?l00080oh00
1`3o00040?n000D0o`000P3oP0020?l000030?n0003o0000o`000080o`000P3oP0070?l00080oh00
1`3o00020?n000D0o`000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3o00050?n000L0o`00
0P3oP00?0?l000030?n0003o0000o`000080o`000P3oP0070?l00080oh004`3o00020?n00080o`00
3_ooool9003o0080003o3000o`020000o`@00?l00`000?lH003o01X0003o2000o`030000o`800?l0
1`000?lB003o00/0003o1`00o`0>oooooaH0003o2000o`0J0000o`03003o00000?l0003o01L0003o
103oP00N0000o`T00?l03@000?l>ooooo`80003o0P3oP0000`3o0000oh000?n000070?n00080003o
103oP0020?l000D0oh001@3o00040?n00080o`000`3oP0020?l00080oh000P3o00030?n000@0o`00
0P3oP0030?l00080oh000P3o00020000o`030?n000000?l0003o00@0oh0000<0003o0?n0003oP000
1P3oP0030000o`H0oh000`000?l20?n000/0o`000P3oP0030?l000@0oh001@3o00020?n00080o`00
0`3oP0040?l000<0oh000P3o00020?n001Sooooo000Fooooo`L0o`000P3oP0070?l000@0oh001@3o
00020?n00080o`0000<0oh000?l0003o00000P3o00020?n000L0o`000P3oP0070?l00080oh001@3o
00020?n00080o`000P3oP0000`3o0000oh000?n000020?l000D0oh001`3o00020?n000l0o`0000<0
oh000?l0003o00000P3o00020?n000L0o`000P3oP00C0?l00080oh000P3o000>ooooo`T00?l00P00
0?l<003o0080003o1000o`030000oaP00?l06P000?l8003o00<0003o0P00o`070000oa800?l02`00
0?l7003o00kooooo5P000?l8003o01X0003o00<00?l00000o`000?l05`000?l40?n001h0003o2@00
o`0=0000o`kooooo0P000?l20?n000030?l0003oP000oh0000L0oh000P000?l40?n00080o`001@3o
P0050?l000@0oh000P3o00030?n00080o`000P3oP0020?l000<0oh00103o00020?n000<0o`000P3o
P0020?l00080003o00<0oh000000o`000?l0103oP0000`000?l0oh000?n000060?n000<0003o1P3o
P0030000o`80oh002`3o00020?n000<0o`00103oP0050?l00080oh000P3o00030?n000@0o`000`3o
P0020?l00080oh006?ooool001Kooooo0P3oP00N0?l000@0oh00403o00020?n000D0o`000P3oP009
0?l00080oh000`3o00040?n00080o`0000<0oh000?l0003o00003`3o00000`3oP000o`000?l00002
0?l00080oh000`3o00020?n000/0o`000P3oP0090?l000030?n0003o0000o`000080o`003_oooolK
003o00L0003o5000o`0<0000o`d00?l00`000?l6003o00`0003o0P00o`020000o`@0o`0000<0oh00
003o0000o`002@00o`050000o`d00?l03_oooolI0000o`800?l00P000?l3003o0080003o0P00o`0b
0000o`80oh000P000?l5003o00D0003o0P3oP00@0000o`800?l010000?l00`00o`00003o0000o`07
0000o`@00?l03_ooool20000o`80oh0000<0o`000?n0003oP0001`3oP0020000o`80oh001@3o0002
0?n000D0o`00503oP0020?l000@0oh0000<0o`000?n0003oP000103oP0050000o`@0oh0000<0003o
0?n0003oP0001P3o00000`3oP000o`000?l000020?l00080oh000P3o00050?n00080o`000P3oP003
0?l000@0oh000P3o00080?n00080o`001`3oP0020000o`80oh000P3o00070?n001Sooooo000Foooo
o`80oh001@3o00020?n000T0o`000P3oP0050?l00080oh001`3o00050?n000@0o`000P3oP00>0?l0
00@0oh002@3o00000`3oP000o`000?l000090?l00080oh001@3o00020?n00200o`000P3oP0040?l0
0080oh001@3o000>oooooah00?l00P000?lF003o01<0003o0P00o`0;0000o`800?l01@000?l6003o
00030000o`00o`000?l000L0003o4P00o`060000o`D00?l03_ooool70000o`@0oh000P000?l00`3o
P000003o0000o`070000o`@00?l00`000?l2003o0080003o0P00o`050000o`H0oh001`000?l20?n0
01<0003o0P3oP00=0000o`D00?l03P000?l2003o0100003o0P3oP0090000o`kooooo10000?l50?l0
00@0oh000`3o00040?n00080o`000`3oP0050?l000P0oh0000<0003o0?n0003oP0000P3oP0020?l0
00D0oh000P3o00050?n00080o`00103oP0030000o`80oh001@3o00020?n000L0o`000P000?l40?n0
00D0003o1P3oP0030?l00080oh000P3o00020?n000030?l0003oP000oh0000D0oh000P3o00020?n0
0080o`001@3oP0070000o`80oh000P000?lHooooo`005_ooool20?n000D0o`000P3oP0090?l00080
oh001@3o00020?n000L0o`001@3oP0040?l00080oh003P3o00040?n000T0o`0000<0oh000?l0003o
00002@3o00020?n000D0o`000P3oP00P0?l00080oh00103o00020?n000D0o`003_oooolN003o0080
003o5P00o`0C0000o`800?l02`000?l2003o00D0003o1P00o`000`000?l00?l0003o00070000oa80
0?l01P000?l5003o00kooooo1`000?l40?n00080003o00<0oh000000o`000?l01`000?l4003o00<0
003o0P00o`020000o`800?l01@000?l60?n000L0003o0P3oP00C0000o`80oh003@000?l5003o00h0
003o0P00o`0@0000o`80oh002@000?l>ooooo`@0003o1@3o00040?n000<0o`00103oP0020?l000<0
oh001@3o00080?n000030000o`3oP000oh000080oh000P3o00050?n00080o`001@3oP0020?l000@0
oh000`000?l20?n000D0o`000P3oP0070?l00080003o103oP0050000o`H0oh000`3o00020?n00080
o`000P3oP0000`3o0000oh000?n000050?n00080o`000P3oP0020?l000D0oh001`000?l20?n00080
003o6?ooool001Kooooo0P3o00020?n000030?l0003oP000oh0000@0oh007P3o00040?n00080o`00
00<0oh000?l0003o00000P3oP0070?l00080oh002`3o00000`3oP000o`000?l0000F0?l000<0oh00
0P3o00020?n00100o`000P3oP0070?l00080oh000P3o00030?n00080o`003_oooolf003o0080003o
00<00?l00000o`000?l02@000?lF003o00D0003o1000o`030000o`80oh0010000?l00`3oP0000?l0
003o000K003o00kooooo40000?l2003o00@0003o1@00o`050000o`80oh001`000?l20?l000@0oh00
4`000?l20?n000L0003o0P3oP0040000o`<00?l01P000?l3003o02d0003o3_ooool50000o`@0o`00
0P3oP0030?l000H0oh000P3o00050?n000<0o`00103oP0020000o`80oh000`3o00020?n000D0o`00
203oP0030?l000@0oh002@3o00050?n000@0o`0000<0oh000000o`000?l00P000?l20?n000D0003o
2@3o00020?n00080o`000P3oP0050?l000<0oh0010000?l40?n000L0003o1`3oP00Hooooo`005_oo
ool20?l00080oh0000<0o`000?n0003oP000103oP00N0?l000@0oh000P3o00000`3oP000o`000?l0
00020?n000L0o`000P3oP00;0?l000030?n0003o0000o`0001H0o`000`3oP0020?l00080oh00403o
00020?n000L0o`000P3oP0020?l000<0oh000P3o000>ooooocH00?l00P000?l00`00o`00003o0000
o`090000oaH00?l01@000?l4003o00<0003o0P3oP0040000o`030?n00000o`000?l001/00?l03_oo
ool@0000o`800?l010000?l5003o00D0003o0P3oP0070000o`80o`00103oP00C0000o`80oh001`00
0?l20?n000@0003o0`00o`060000o`<00?l0;@000?l>ooooo`D0003o103o00020?n000<0o`001P3o
P0020?l000D0oh000`3o00040?n00080003o0P3oP0030?l00080oh001@3o00080?n000<0o`00103o
P0090?l000D0oh00103o00000`3oP000003o0000o`020000o`80oh001@000?l90?l00080oh000P3o
00020?n000D0o`000`3oP0040000o`@0oh001`000?l70?n001Sooooo000Fooooo`D0o`000P3oP002
0?l00080oh000P3o00070?n001D0o`000P3oP0050?l00080oh001`3o00020?n000H0o`0000<0oh00
0?l0003o00003@3o00000`3oP000o`000?l000040?l00080oh000`3o00020?n00080o`000`3oP00F
0?l00080oh001`3o00020?n000<0o`000P3oP00>ooooocT00?l00P000?l2003o00@0003o6@00o`05
0000o`L00?l00P3oP0020000o`<0oh005000o`040000o`D00?l03_ooool9003o00L0003o1000o`03
0000o`800?l01`000?l20?n000T0003o0P3oP0030000o`80oh006@000?l20?n000d0003o1`00o`09
0000o`X00?l050000?l20?n000kooooo0P3oP0030000o`80oh000P3o00040?n000L0o`000P3oP000
0`000?l0oh000?n000020?n000<0o`000P3oP0020?l000@0oh000`3o00040?n000<0o`00103oP007
0?l000@0oh001`3o00070?n00080o`000`3oP0060?l00080oh000`000?l60?l000030?n0003o0000
o`0000@0oh001@3o00040?n000<0003o103oP0090000o`<0o`00103oP00Hooooo`005_ooool50?l0
0080oh000P3o00020?n00080o`001`3oP00E0?l00080oh001@3o00020?n000L0o`000P3oP0060?l0
00030?n0003o0000o`0000d0o`0000<0oh000?l0003o0000103o00020?n000<0o`000P3oP0020?l0
00<0oh005P3o00020?n000L0o`000P3oP0030?l00080oh003_ooooli003o0080003o0P00o`040000
oaT00?l01@000?l7003o0080oh000P000?l30?n001@00?l010000?l5003o00kooooo2@00o`070000
o`@00?l00`000?l2003o00L0003o0P3oP0090000o`80oh000`000?l20?n001T0003o0P3oP00=0000
o`L00?l02@000?l:003o01@0003o0P3oP00>ooooo`80oh000`000?l20?n00080o`00103oP0070?l0
0080oh0000<0003o0?n0003oP0000P3oP0030?l00080oh000P3o00040?n000<0o`00103oP0030?l0
00@0oh001`3o00040?n000L0o`001`3oP0020?l000<0oh001P3o00020?n000<0003o1P3o00000`3o
P000o`000?l000040?n000D0o`00103oP0030000o`@0oh002@000?l30?l000@0oh006?ooool001Ko
oooo1@3o00020?n000T0o`00103oP0050?l00080oh00403o00020?n000/0o`0000<0oh000?l0003o
00005P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`0000@0o`000P3oP00G0?l00080
oh001`3o00020?n000D0o`003_oooolf003o00D0003o0P00o`090000oa@00?l01`000?lY003o00ko
oooo0P000?lB003o00<0003o0P00o`0=0000o`030?n000000?l0003o0080oh000P3o00030?n00080
003o1P00o`0>0000o`80oh000`000?l40?l000<0oh0050000?l20?n00080003o0P00o`000`000?l0
0?l0003o00040000o`D00?l03@000?l00`00o`00003o0000o`020?n000kooooo103o00000`3oP000
o`000?l000060?n000030?l0003oP000oh000080oh001`3o00040?n000030?l0003oP000oh0000@0
oh000`3o00080?n000030?l0003oP000oh0000@0oh001@3o000B0?n00080o`000`000?l20?l000/0
oh000P3o00030?n00080o`000P3oP0040?l000030?n0003o0000o`0000@0oh000`3o00020000o`80
oh001@000?l2003o0080oh000`3o00020?n00080o`006?ooool001Kooooo0P3o00050?n000L0o`00
103oP0050?l00080oh002@3o00020?n002D0o`000P3oP00V0?l00080oh001`3o00020?n000L0o`00
0P3oP0050?l000kooooo7P00o`020000oaT00?l020000?l00`00o`00003o0000o`0D003o00L0003o
:`00o`0>ooooo`@0003o3000o`070000o`H00?l03P000?l20?n000D0003o1P00o`070000o`<00?l0
10000?l20?n000030000o`3oP000oh000080oh000P000?l20?n001T0003o0P00o`070000o`T00?l0
1@000?l20?n000L0003o3_ooool40?l000<0oh000P000?l70?n00080o`000P3oP0020?l000030?n0
003o0000o`0000@0o`001`3oP0020000o`<0o`001P3oP0000`3o0000oh000?n000060?n000030?l0
003oP000oh0000L0oh000P3o00070?n00080o`001@3oP0040?l000@0oh000`3o00020?n00080o`00
1@3oP0020?l00080oh001@3o00040?n000<0o`00103oP0030000o`80oh000P000?l90?l001Sooooo
000Fooooo`80o`001@3oP0070?l000@0oh001@3o00020?n000T0o`000P3oP00U0?l00080oh009P3o
00020?n000L0o`000P3oP0070?l00080oh001@3o000>oooooah00?l00P000?lI003o00P0003o00<0
0?l00000o`000?l05000o`070000ob/00?l03_ooool40000o``00?l01`000?l6003o00h0003o0P3o
P0050000o`H00?l01`000?l3003o00@0003o0P3oP0000`000?l0oh000?n000020?n00080003o0P3o
P00I0000o`800?l01`000?l9003o00D0003o0P3oP0070000o`kooooo103o00030?n00080003o1`3o
P0020?l00080oh000P3o00000`3oP000o`000?l000040?l000L0oh000P000?l30?l000H0oh0000<0
o`000?n0003oP0001P3oP0000`3o0000oh000?n000070?n00080o`001`3oP0020?l000D0oh00103o
00040?n000<0o`000P3oP0020?l000D0oh000P3o00020?n000D0o`00103oP0030?l000@0oh000`00
0?l20?n00080003o2@3o000Hooooo`005_ooool20?n00080o`001@3oP0050?l00080oh001`3o0004
0?n000T0o`000P3oP0050?l00080oh001@3o00020?n001h0o`000P3oP00I0?l00080oh00103o0000
0`3oP000o`000?l000040?l00080oh001`3o00020?n000D0o`003_oooolN003o00H0003o6`00o`02
0?n000<0003o5000o`050000oa/00?l02@000?l9003o00kooooo1@000?l;003o0280003o3`00o`0<
0000o`80oh000P3o00050?n000@0003o0`00o`0F0000o`<00?l010000?l2003o00D0003o0P3oP005
0000o`80oh003_ooool40?l000030?n0003o0000o`0000@0o`000P3oP0000`000?l0oh000?n00002
0?l00080oh000P3o00050?n00080o`002@3oP0000`3o0000oh000?n000040?n00080003o00<0oh00
0?l0003o00001P3oP0000`3o0000oh000?n0000=0?n000<0o`000P3oP0040?l000T0oh001`3o0003
0?n00080003o2`3oP0020?l000030?n0003o0000o`000080o`000P3oP0030000o`P0o`000`3oP002
0?l001Sooooo000Fooooo`80oh000P3o00050?n000D0o`000P3oP0070?l000@0oh002@3o00020?n0
00D0o`000P3oP0050?l00080oh007P3o00020?n001T0o`000P3oP0040?l000030?n0003o0000o`00
00@0o`000P3oP0070?l00080oh001@3o000>oooooah00?l01P000?lK003o0080oh000`000?lD003o
00D0003o6`00o`090000o`T00?l03_ooool50000o`/00?l08P000?l?003o00`0003o0P3oP0020?l0
00D0oh0010000?l3003o01H0003o0`00o`040000o`800?l01@000?l20?n000D0003o0P3oP00>oooo
o`@0o`0000<0oh000?l0003o0000103o00020?n000030000o`3oP000oh000080o`000P3oP0020?l0
00D0oh000P3o00090?n000030?l0003oP000oh0000@0oh000P000?l00`3oP000o`000?l000060?n0
00030?l0003oP000oh0000d0oh000`3o00020?n000@0o`002@3oP0070?l000<0oh000P000?l;0?n0
0080o`0000<0oh000?l0003o00000P3o00020?n000<0003o203o00030?n00080o`006?ooool001Ko
oooo103o00000`3oP000003o0000o`020?n00080o`001`3oP00>0?l00080oh001`3o00020?n000L0
o`00103oP0070?l00080oh004`3o00020?n00080o`00103oP0000`3o0000oh000?n000040?l00080
oh0000<0o`000?n0003oP0005`3o00020?n00080o`001@3oP0040?l000kooooo7P00o`060000oa80
0?l00`000?lF003o00<0003o0P00o`090000oa/00?l02`000?l7003o00kooooo2@000?l4003o00X0
003o1P00o`0B0000o`030?n000000?l0003o00@0003o2`00o`000`000?l00?l0003o000;0000o`80
oh000`000?l20?n000D0003o0P00o`0B0000o`80oh006@000?l>ooooo`@0o`000`3oP0070?l00080
oh001P3o00080?n00080o`00103oP0020000o`030?n000000?l0003o0080003o0P3oP0020000o`03
0?n0003o0000o`000080oh000P3o00030?n000@0o`00103oP0050000o`80oh0000<0o`000?n0003o
P0000P3o00040?n000L0003o0P3oP0070?l000L0oh001@3o00060?n000<0o`00103oP0020000o`03
0?n0003o0000o`0000H0o`0000<0oh000?l0003o00000P3o000Hooooo`005_ooool40?l000030?n0
00000?l0003o0080oh000P3o00070?n000h0o`000P3oP0070?l00080oh001`3o00040?n000L0o`00
0P3oP00C0?l00080oh000P3o00040?n000030?l0003oP000oh0000@0o`000P3oP0000`3o0000oh00
0?n0000G0?l00080oh000P3o00050?n000@0o`003_oooolN003o00H0003o4P00o`030000oaH00?l0
0`000?l2003o00T0003o6`00o`0;0000o`L00?l03_ooool90000o`@00?l02P000?l6003o0180003o
00<0oh000000o`000?l010000?l;003o00030000o`00o`000?l000/0003o0P3oP0030000o`80oh00
1@000?l2003o0180003o0P3oP00I0000o`kooooo103o00030?n000L0o`000P3oP0060?l000P0oh00
0P3o00040?n00080003o00<0oh000000o`000?l00P000?l20?n00080003o00<0oh000?l0003o0000
0P3oP0020?l000<0oh00103o00040?n000D0003o0P3oP0000`3o0000oh000?n000020?l000@0oh00
1`000?l20?n000L0o`001`3oP0050?l000H0oh000`3o00040?n00080003o00<0oh000?l0003o0000
1P3o00000`3oP000o`000?l000020?l001Sooooo000Fooooo`D0o`00103oP0040?l000D0oh00103o
00030?n00100o`000P3oP0040?l000030?n0003o0000o`000080oh000P3o00020?n000030?l0003o
P000oh000080oh000P000?l20?n000030?l0003oP000oh0000/0o`000P3oP00:0?l00080oh003@3o
00020?n00140o`000P3oP0020000o`L0oh000P3o000>oooood/00?l01`000?l4003o00L0003o6`00
o`050000o`d00?l03_ooool90000o`800?l030000?l6003o00`0003o0P3oP002003o00D0003o0P00
o`020000oa800?l03P000?l@003o00d0003o2P00o`020000o`@00?l00`000?l20?n00080003o3_oo
ool20?l000<0oh001P3o00030?n00080003o0P3oP0040?l000P0oh000P3o00040?n00080003o00<0
oh000?l0003o00002`3oP0070?l000H0oh001@3o00020?n000T0o`0000<0oh000?l0003o00000P3o
00040?n000L0o`000P3oP0000`3o0000oh000?n000020?n00080o`000P3oP0000`3o0000oh000?n0
00020?n000D0o`00103oP0020000o`<0o`00103oP0020?l000<0oh000P3o000Hooooo`005_ooool5
0?l000@0oh00103o00050?n000@0o`000`3oP00@0?l00080oh00103o00000`3oP000o`000?l00002
0?n00080o`000P3oP0000`3o0000oh000?n000020?n00080003o0P3oP0000`3o0000oh000?n0000;
0?l00080oh002P3o00020?n000d0o`000P3oP00A0?l00080oh000P000?l70?n00080o`003_oooom;
003o00L0003o1000o`070000oa/00?l01@000?l=003o00kooooo2@000?l2003o00`0003o1P00o`0<
0000o`80oh000P00o`050000o`800?l00P000?lB003o00h0003o4000o`0=0000o`X00?l00P000?l4
003o00<0003o0P3oP0020000o`kooooo0P3o00030?n000H0o`000`3oP0020000o`80oh00103o0008
0?n00080o`00103oP0020000o`030?n0003o0000o`0000/0oh001`3o00060?n000D0o`000P3oP009
0?l000030?n0003o0000o`000080o`00103oP0070?l00080oh0000<0o`000?n0003oP0000P3oP002
0?l00080oh0000<0o`000?n0003oP0000P3oP0050?l000@0oh000P000?l30?l000@0oh000P3o0003
0?n00080o`006?ooool001Kooooo1@3o00020?n000H0o`0000<0oh000?l0003o00001P3o00050?n0
00D0o`000P3oP00G0?l000@0003o0P3o00020?n000030?l0003oP000oh000080oh004P3o00020?n0
00h0o`000P3oP0020?l000<0oh00403o00020?n00080o`000P000?l00`3o0000oh000?n000020?l0
00kooooo6@00o`020000oa/00?l00P000?lC003o00L0003o1P00o`050000oad00?l01`000?l9003o
00kooooo1@000?l9003o00H0003o3000o`020000o`800?l00`000?l2003o0080003o1000o`070000
o`T00?l01`000?l2003o00<0003o1000o`050000o`80oh003P00o`0@0000o`H00?l00P000?l7003o
00L0003o3_ooool20?l000D0oh001P3o00050?n00080003o0`3oP0020?l00080oh001@3o00020?n0
00D0003o103oP0020000o`80oh0000<0o`000?n0003oP0000P3o00020?n000D0o`00103oP0020000
o``0o`000P3oP0020?l000030?n0003o0000o`000080o`000P3oP0070?l000L0oh000P000?l40?n0
00030?l0003oP000oh000080oh001@3o00070?n00080o`002`3oP00Hooooo`005_ooool50?l00080
oh003`3o00000`3oP000o`000?l000050?l000H0oh000`3o00020?n00180o`000P3oP0050?l000L0
oh001P3o00020?n001D0o`000P3oP0020?l00080oh000`3o00020?n000<0o`001P3oP0070?l000@0
oh001@3o000>ooooocd00?l00P000?l<003o00H0003o00<0oh00003o0000o`000P00o`070000obd0
0?l03_ooool50000o`T00?l01P000?l9003o00D0003o1`00o`090000o`d00?l030000?l2003o00/0
003o3000o`090000oa000?l02`000?l2003o00kooooo0P3oP0020000o`D0oh00103o00050?n00080
0?l00P3oP0030?l00080oh001@3o00020?n000D0003o4P3oP0020?l000H0oh001@3o00020?n000<0
o`002@3oP0020?l000@0oh001@3o00070?n00080003o0P3o00030?n00080o`000P3oP0050?l000T0
oh000P000?l40?n000030?l0003oP000oh000080oh006?ooool001Kooooo1@3o00020?n000l0o`00
00<0oh000?l0003o00001@3o00060?n000<0o`000P3oP00B0?l00080oh001@3o00070?n000H0o`00
0P3oP00E0?l00080oh000P3o00020?n000<0o`000P3oP0030?l000H0oh001`3o00040?n000D0o`00
3_oooolm003o0080003o3000o`060000o`030?n00000o`000?l000800?l01`000?l]003o00kooooo
1@000?l9003o00H0003o2@00o`050000o`L00?l02@000?l=003o00`0003o0P00o`0;0000o``00?l0
2@000?l@003o00/0003o0P00o`0>ooooo`80oh000P000?l50?n000@0o`001@3oP002003o0080oh00
0`3o00020?n000D0o`000P3oP0050000oa80oh000P3o00060?n000D0o`000P3oP0030?l000T0oh00
0P3o00040?n000D0o`001`3oP0020000o`80o`000`3oP0020?l00080oh001@3o00090?n00080003o
103oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`80oh001@3o00020?n00080o`001@3o
P00>0?l00080oh00103o00020?n000030?l0003oP000oh000080oh001@3o00020?n000L0o`000P3o
P0070?l000@0oh000`3o00020?n00080o`001@3oP0020?l000@0oh003P3o00020?n000@0o`0000<0
oh000?l0003o00000P3oP0020?l000L0oh001`3o00020?n00080003o1@3o000>oooooad00?l000<0
003o003o0000o`007@00o`020000o`L00?l00`000?l?003o00D0003o8P00o`020000o`T00?l03_oo
ool50000o`/00?l00P000?l2003o00<0003o1P00o`050000o`L00?l01`000?l=003o00h0003o0P00
o`070000o`80oh000P000?l3003o0080003o0P00o`040000o`03003o00000?l0003o01L0003o0P00
o`090000o`800?l03_ooool20?n000<0003o103oP0020?l000D0oh000P000?l50?l000@0oh001@3o
00020?n000@0003o00<0o`000?n0003oP000103o00030?n00080o`001P3oP0000`3o0000oh000?n0
00060?n000L0o`0000<0oh000?l0003o00000P3oP0020?l000D0oh000P3o00050?n00080o`001`3o
P0040?l00080oh000P3o00070?n000<0o`00103oP0050?l00080oh001@3o00040000oaSooooo000F
ooooo`80oh001@3o00020?n00080o`001@3oP00>0?l00080oh00103o00020?n000030?l0003oP000
oh000080oh001@3o00020?n000L0o`000P3oP0070?l000@0oh000`3o00020?n00080o`001@3oP002
0?l000@0oh003P3o00020?n000@0o`0000<0oh000?l0003o00000P3oP0020?l000L0oh001`3o0002
0?n00080003o1@3o000>oooooad00?l000<0003o003o0000o`007@00o`020000o`L00?l00`000?l?
003o00D0003o8P00o`020000o`T00?l03_ooool50000o`/00?l00P000?l2003o00<0003o1P00o`05
0000o`L00?l01`000?l=003o00h0003o0P00o`070000o`80oh000P000?l3003o0080003o0P00o`04
0000o`03003o00000?l0003o01L0003o0P00o`090000o`800?l03_ooool20?n000<0003o103oP002
0?l000D0oh000P000?l50?l000@0oh001@3o00020?n000@0003o00<0o`000?n0003oP000103o0003
0?n00080o`001P3oP0000`3o0000oh000?n000060?n000L0o`0000<0oh000?l0003o00000P3oP002
0?l000D0oh000P3o00050?n00080o`001`3oP0040?l00080oh000P3o00070?n000<0o`00103oP005
0?l00080oh001@3o00040000oaSooooo000Fooooo`@0o`0000<0oh000?l0003o0000103o00050?n0
01L0o`000P3oP0020?l00080oh000P3o00030?n001/0o`00103oP0050?l000@0oh006@3o00070?n0
00L0o`000P3oP0020000o`D0o`003_ooool4003o00030000o`00o`000?l001T00?l00P000?lK003o
0080003o0`00o`040000o`800?l000<0003o003o0000o`003@00o`090000o`<00?l00P000?lG003o
00H0003o1`00o`0>oooooa@00?l030000?l4003o00T0003o0P3oP0050000o`T00?l01@000?l2003o
0080003o0P00o`000`000?l00?l0003o0002003o00d0003o0`00o`0@0000o`800?l02@000?l2003o
00/0003o00<0oh000000o`000?l00P00o`0>ooooo`80oh000`3o00020?n00080o`000P3oP0020?l0
00<0oh00103o00020?n000030?l0003oP000oh000080oh001@3o00060?n000L0o`000`3oP0020?l0
00@0oh000`3o00040?n00080003o0`3oP0090?l000H0oh001@000?l20?n00080o`0000<0oh000?l0
003o0000103oP0020?l000X0oh000P3o00020?n000h0o`000P3oP0040?l000030?n0003o0000o`00
0080003o6?ooool001Kooooo103o00000`3oP000o`000?l000040?l000D0oh005`3o00020?n00080
o`000P3oP0020?l000<0oh006`3o00040?n000D0o`00103oP00I0?l000L0oh001`3o00020?n00080
003o1@3o000>ooooo`@00?l000<0003o003o0000o`006@00o`020000oa/00?l00P000?l3003o00@0
003o0P00o`000`000?l00?l0003o000=003o00T0003o0`00o`020000oaL00?l01P000?l7003o00ko
oooo5000o`0<0000o`@00?l02@000?l20?n000D0003o2@00o`050000o`800?l00P000?l2003o0003
0000o`00o`000?l000800?l03@000?l3003o0100003o0P00o`090000o`800?l02`000?l00`3oP000
003o0000o`02003o00kooooo0P3oP0030?l00080oh000P3o00020?n00080o`000`3oP0040?l00080
oh0000<0o`000?n0003oP0000P3oP0050?l000H0oh001`3o00030?n00080o`00103oP0030?l000@0
oh000P000?l30?n000T0o`001P3oP0050000o`80oh000P3o00000`3oP000o`000?l000040?n00080
o`002P3oP0020?l00080oh003P3o00020?n000@0o`0000<0oh000?l0003o00000P000?lHooooo`00
5_ooool;0?l00080oh002P3o00020?n000h0o`000P3oP0060?l000030?n0003o0000o`000080o`00
0P3oP0070?l00080oh005@3o00020?n000T0o`000P3oP0030?l00080oh003P3o00020?n000H0o`00
00<0oh000?l0003o0000103oP0020000o`030?n0003o0000o`000080o`003_ooool2003o0080003o
<P00o`020000o`03003o00000?l0003o00800?l010000?l00`00o`00003o0000o`090000o`/00?l0
1@000?lO003o00L0003o1`00o`0>ooooo`T00?l00P000?l5003o00d0003o2P00o`060000o`80oh00
00<0003o003o0000o`002`00o`020000o`D00?l01@000?l4003o00D0003o0P00o`060000o`D00?l0
0P000?l2003o00T0003o1@00o`070000o`800?l00P000?l00`00o`00003o0000o`020000o`800?l0
0`000?l4003o00kooooo103oP0030?l00080oh000P000?l20?l000<0oh001P3o00030?n00080003o
1@3o00020?n000D0003o1P3o00020?n000030000o`3oP000oh000080003o103o00070?n00080003o
00<0o`000?n0003oP0001`3o00040?n000L0o`000P3oP0030?l000H0oh000P3o00000`3oP000o`00
0?l000040?n00080003o0`3oP0020000o`<0oh001P3o00050?n00080o`000P3oP0020?l000030?n0
003o0000o`000080oh006?ooool001Kooooo2`3o00020?n000X0o`000P3oP00>0?l00080oh001P3o
00000`3oP000o`000?l000020?l00080oh001`3o00020?n001D0o`000P3oP0090?l00080oh000`3o
00020?n000h0o`000P3oP0060?l000030?n0003o0000o`0000@0oh000P000?l00`3oP000o`000?l0
00020?l000kooooo0P00o`020000oc800?l00P000?l00`00o`00003o0000o`02003o00@0003o00<0
0?l00000o`000?l02@000?l;003o00D0003o7`00o`070000o`L00?l03_ooool9003o0080003o1@00
o`0=0000o`X00?l01P000?l20?n000030000o`00o`000?l000/00?l00P000?l5003o00D0003o1000
o`050000o`800?l01P000?l5003o0080003o0P00o`090000o`D00?l01`000?l2003o0080003o00<0
0?l00000o`000?l00P000?l2003o00<0003o1000o`0>ooooo`@0oh000`3o00020?n00080003o0P3o
00030?n000H0o`000`3oP0020000o`D0o`000P3oP0050000o`H0o`000P3oP0000`000?l0oh000?n0
00020000o`@0o`001`3oP0020000o`030?l0003oP000oh0000L0o`00103oP0070?l00080oh000`3o
00060?n00080o`0000<0oh000?l0003o0000103oP0020000o`<0oh000P000?l30?n000H0o`001@3o
P0020?l00080oh000P3o00000`3oP000o`000?l000020?n001Sooooo000Fooooo`/0o`000P3oP007
0?l00080oh0000<0o`000?n0003oP0001@3o00020?n001d0o`000P3oP00>0?l00080oh001`3o0002
0?n000T0o`000P3oP0000`3o0000oh000?n000020?n000/0o`000`3oP0070?l000@0003o0P3oP002
0000o`030?n0003o0000o`000080o`003_ooool2003o00<0003o=000o`060000o`<00?l02`000?l=
003o00D0003o6@00o`0;0000o`L00?l03_oooolF003o00D0003o3P00o`040000o`80oh002@00o`03
0000o`800?l010000?l3003o0080003o0P00o`000`000?l00?l0003o0004003o00/0003o1@00o`05
0000o`/00?l02@000?l2003o0080003o00<00?l00000o`000?l01`000?l2003o0080003o3_ooool2
0?n00080o`001@3oP0020000o`<0oh00103o00020?n000<0o`00103oP0030?l000@0oh000P000?l5
0?n000@0o`000P3oP0050000o`80oh000P3o00050?n000@0o`000`3oP0070?l000@0oh001@3o0002
0?n000D0o`001P3oP0020?l000D0oh002@3o00030?n000d0o`001@3oP0040?l001Sooooo000Foooo
o`80o`000`3oP0060?l00080oh00303o00020?n00080o`001@3oP0040?l000<0oh005P3o00020?n0
00030?l0003oP000oh0000@0oh001@3o00040?n002h0o`000P000?l50?l00080oh000P000?l>oooo
o`@0003o>`00o`020000o`03003o00000?l0003o00L0003o3`00o`050000oaT00?l02`000?l7003o
00kooooo1@000?l2003o00H0003o2@00o`070000o``00?l01`000?l4003o00/0003o1@00o`020000
o`800?l00`000?l4003o00/0003o0`00o`070000o`@00?l010000?l5003o01D0003o1000o`0>oooo
o`80oh000P3o00050?n00080o`000P3oP00:0?l000H0oh0000<0o`000?n0003oP0000P3oP0020000
o`<0o`000P3oP0020?l000D0oh00103o00020?n00080o`0000<0oh000?l0003o00001P3o00000`3o
P000003o0000o`040?n000030?l0003oP000oh0000@0oh000P3o00050?n000D0o`00103oP0020000
o`80oh0000<0003o0?n0003oP0001P3o00000`3oP000o`000?l000040?n000030?l0003oP000oh00
0080o`00103oP0050?l000D0oh000P000?l20?n001Sooooo000Fooooo`80o`000`3oP0060?l00080
oh00303o00020?n00080o`001@3oP0040?l000<0oh005P3o00020?n000030?l0003oP000oh0000@0
oh001@3o00040?n002h0o`000P000?l50?l00080oh000P000?l>ooooo`@0003o>`00o`020000o`03
003o00000?l0003o00L0003o3`00o`050000oaT00?l02`000?l7003o00kooooo1@000?l2003o00H0
003o2@00o`070000o``00?l01`000?l4003o00/0003o1@00o`020000o`800?l00`000?l4003o00/0
003o0`00o`070000o`@00?l010000?l5003o01D0003o1000o`0>ooooo`80oh000P3o00050?n00080
o`000P3oP00:0?l000H0oh0000<0o`000?n0003oP0000P3oP0020000o`<0o`000P3oP0020?l000D0
oh00103o00020?n00080o`0000<0oh000?l0003o00001P3o00000`3oP000003o0000o`040?n00003
0?l0003oP000oh0000@0oh000P3o00050?n000D0o`00103oP0020000o`80oh0000<0003o0?n0003o
P0001P3o00000`3oP000o`000?l000040?n000030?l0003oP000oh000080o`00103oP0050?l000D0
oh000P000?l20?n001Sooooo000Fooooo`80o`000`3oP0040?l000@0oh002P3o00020?n000D0o`00
0P000?l20?n000D0o`00103oP0040?l000030?n0003o0000o`0000L0o`00103oP0050?l00080oh00
0P3o00020?n000030?l0003oP000oh0000H0oh001@3o00020?n001D0o`000P3oP0040?l000D0oh00
1`3o00020?n000T0o`003_ooool50000ocH00?l01P000?l00`00o`00003o0000o`090000o`/00?l0
2@000?lE003o00d0003o0`00o`020000o`800?l03_ooool50000o`800?l01P000?l<003o00D0003o
2`00o`060000o`D00?l06@000?l2003o00D0003o0P3oP0050000o`800?l09P000?l3003o0080003o
0P00o`0>ooooo`80o`001`3oP0020000o`80oh0000<0o`000?n0003oP0001`3o00060?n000030000
o`3oP000oh000080oh000P000?l50?l00080oh002@3o00050?n000P0o`000`3oP0070?l000L0oh00
0P3o00040?n00080o`000`3oP0060?l000030?n0003o0000o`000080oh000P3o00030?n000@0o`00
1@3oP0040?l000<0oh000P3o000;0?n001Sooooo000Fooooo`80o`000`3oP0040?l000@0oh002P3o
00020?n000D0o`000P000?l20?n000D0o`00103oP0040?l000030?n0003o0000o`0000L0o`00103o
P0050?l00080oh000P3o00020?n000030?l0003oP000oh0000H0oh001@3o00020?n001D0o`000P3o
P0040?l000D0oh001`3o00020?n000T0o`003_ooool50000ocH00?l01P000?l00`00o`00003o0000
o`090000o`/00?l02@000?lE003o00d0003o0`00o`020000o`800?l03_ooool50000o`800?l01P00
0?l<003o00D0003o2`00o`060000o`D00?l06@000?l2003o00D0003o0P3oP0050000o`800?l09P00
0?l3003o0080003o0P00o`0>ooooo`80o`001`3oP0020000o`80oh0000<0o`000?n0003oP0001`3o
00060?n000030000o`3oP000oh000080oh000P000?l50?l00080oh002@3o00050?n000P0o`000`3o
P0070?l000L0oh000P3o00040?n00080o`000`3oP0060?l000030?n0003o0000o`000080oh000P3o
00030?n000@0o`001@3oP0040?l000<0oh000P3o000;0?n001Sooooo000Fooooo`80o`000P3oP000
0`3o0000oh000?n000020?l000D0oh001P3o00020?n000L0o`0000<0oh000?l0003o00000P3o0002
0?n00080o`001@3oP0020?l000<0oh001P3o00030?n000P0o`0000<0oh000?l0003o0000103o0000
0`3oP000o`000?l000040?n00080o`0000<0oh000?l0003o00000P3o00020?n000h0o`00103oP009
0?l000D0oh001`3o00040?n000L0o`003_ooool50000ocX00?l02@000?l<003o00/0003o0P3oP00I
003o0080003o00<00?l00000o`000?l00P00o`020000o`L00?l03_ooool50000o`800?l01P000?l>
003o00<0003o2`00o`070000o`800?l02`000?l2003o00<0003o0P00o`0F0000o`<00?l03`000?l3
003o00T0003o0P00o`020000o`03003o00000?l0003o00T0003o0P00o`0>ooooo`T0oh000P3o0003
0?n00080o`00103oP0020?l000<0oh000P000?l90?n00080003o0`3oP0040?l00080oh000`3o0007
0?n000H0o`000`3oP0020000o`@0o`0000<0oh000?l0003o0000103oP0030?l000d0oh001@3o0004
0?n00080o`000`3oP0020?l000L0oh000P3o00020?n00080o`0000<0oh000?l0003o00002`3oP00H
ooooo`005_ooool20?l00080oh0000<0o`000?n0003oP0000P3o00050?n000H0o`000P3oP0070?l0
00030?n0003o0000o`000080o`000P3oP0020?l000D0oh000P3o00030?n000H0o`000`3oP0080?l0
00030?n0003o0000o`0000@0o`0000<0oh000?l0003o0000103oP0020?l000030?n0003o0000o`00
0080o`000P3oP00>0?l000@0oh002@3o00050?n000L0o`00103oP0070?l000kooooo1@000?lj003o
00T0003o3000o`0;0000o`80oh006@00o`020000o`03003o00000?l0003o00800?l00P000?l7003o
00kooooo1@000?l2003o00H0003o3P00o`030000o`/00?l01`000?l2003o00/0003o0P00o`030000
o`800?l05P000?l3003o00l0003o0`00o`090000o`800?l00P000?l00`00o`00003o0000o`090000
o`800?l03_ooool90?n00080o`000`3oP0020?l000@0oh000P3o00030?n00080003o2@3oP0020000
o`<0oh00103o00020?n000<0o`001`3oP0060?l000<0oh000P000?l40?l000030?n0003o0000o`00
00@0oh000`3o000=0?n000D0o`00103oP0020?l000<0oh000P3o00070?n00080o`000P3oP0020?l0
00030?n0003o0000o`0000/0oh006?ooool001Kooooo2@3o00020?n00280o`000`3oP0040?l000T0
oh003P3o00020?n000L0o`001P3oP0030?l00080oh003P3o00040?n00080o`001@3oP0020000o`D0
o`00103oP0050?l00080oh003_ooool50000ocX00?l02@000?l<003o00l0003o6P00o`060000o`L0
0?l03_ooool50000o`@00?l010000?l>003o00D0003o2@00o`0F0000o`<00?l02@000?l20?n000/0
003o1`00o`0;0000o`<00?l02`000?l5003o00/0003o0P00o`0>ooooo`@0oh0000<0003o0?n0003o
P0001P3oP0050?l00080oh000P3o00050?n00080003o00<0oh000000o`000?l00P000?l20?n00080
o`001@3oP0040?l000030?n0003o0000o`0000@0oh000P3o00050?n00080o`000`3oP0040?l00080
oh0000<0o`000?n0003oP0000P3oP0050?l00080oh000P3o00050?n00080003o0P3oP0040?l000T0
oh0000<0o`000?n0003oP0000P000?l20?n000030000o`3oP000oh0000@0oh000P3o00000`3oP000
o`000?l000060?n000030000o`3oP000oh000080oh006?ooool001Kooooo403o00020?n001/0o`00
0P3oP0050?l000T0oh001@3o00020?n00100o`000P3oP0020?l00080oh0000<0o`000?n0003oP000
103oP00;0?l000030?n0003o0000o`000080o`000P000?l00`3oP000o`000?l000040?l00080oh00
00<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000020?n000kooooo?@00o`090000o`80oh00
1`000?l5003o00H0003o00<0oh000000o`000?l010000?lI003o0080003o3P00o`0>ooooo`L0003o
0P00o`0=0000o`D00?l01`000?l7003o00T0003o0P00o`0;0000o`800?l000<0003o003o0000o`00
2@000?lB003o00/0003o5@00o`070000o`@00?l03_ooool40000o`030?n000000?l0003o0080oh00
0P000?l30?n000@0o`001@3oP0020?l000/0003o0P3oP0000`3o0000oh000?n000020?n00080o`00
0P3oP0000`3o0000oh000?n000060?n000D0o`000P3oP0050?l000T0oh001@3o00020?n00080o`00
103oP0000`000?l0oh000?n000020?n00080o`001`3oP0020?l000<0oh000P000?l20?n000<0003o
503oP0020?l001Sooooo000Foooooa00o`000P3oP00K0?l00080oh001@3o00090?n000D0o`000P3o
P00@0?l00080oh000P3o00020?n000030?l0003oP000oh0000@0oh002`3o00000`3oP000o`000?l0
00020?l00080003o00<0oh000?l0003o0000103o00020?n000030?l0003oP000oh0000H0oh0000<0
o`000?n0003oP0000P3oP00>ooooocd00?l02@000?l20?n000L0003o1@00o`060000o`030?n00000
0?l0003o00@0003o6@00o`020000o`h00?l03_ooool70000o`800?l03@000?l5003o00L0003o1`00
o`090000o`800?l02`000?l2003o00030000o`00o`000?l000T0003o4P00o`0;0000oaD00?l01`00
0?l4003o00kooooo10000?l00`3oP000003o0000o`020?n00080003o0`3oP0040?l000D0oh000P3o
000;0000o`80oh0000<0o`000?n0003oP0000P3oP0020?l00080oh0000<0o`000?n0003oP0001P3o
P0050?l00080oh001@3o00090?n000D0o`000P3oP0020?l000@0oh0000<0003o0?n0003oP0000P3o
P0020?l000L0oh000P3o00030?n00080003o0P3oP0030000oa@0oh000P3o000Hooooo`005_oooolN
0?l00080oh005P3o00020000o`X0o`000P3oP00@0?l00080oh001@3o00020?n000L0o`000P3oP00=
0?l000030?n0003o0000o`0000H0o`0000<0oh000?l0003o0000103o00020?n000030?l0003oP000
oh000080oh003_oooolm003o00D0003o0P3oP0040000o``00?l02@000?l]003o00kooooo0P3oP002
0?l001h0003o1`00o`0@0000o`@00?l04P000?l2003o00030000o`00o`000?l000L00?l00P000?l4
003o00/0003o0`00o`070000o`T00?l02@000?l2003o00kooooo103oP0030000o`80oh000P000?l2
0?l000030?n0003o0000o`0000@0oh001@3o00020?n00080o`0000<0oh000?l0003o0000103o0002
0?n000D0o`003@3oP0050?l00080oh000`3o00020?n00080o`000`3oP0040?l00080oh000P3o0000
0`3oP000o`000?l000060?n000030?l0003oP000oh0000@0oh000P3o00030?n000@0003o0`3oP002
0000o`80oh001@3o00060?n000030000o`3o0000o`0000H0oh001@3o000Hooooo`005_oooolN0?l0
0080oh005P3o00020000o`X0o`000P3oP00@0?l00080oh001@3o00020?n000L0o`000P3oP00=0?l0
00030?n0003o0000o`0000H0o`0000<0oh000?l0003o0000103o00020?n000030?l0003oP000oh00
0080oh003_oooolm003o00D0003o0P3oP0040000o``00?l02@000?l]003o00kooooo0P3oP0020?l0
01h0003o1`00o`0@0000o`@00?l04P000?l2003o00030000o`00o`000?l000L00?l00P000?l4003o
00/0003o0`00o`070000o`T00?l02@000?l2003o00kooooo103oP0030000o`80oh000P000?l20?l0
00030?n0003o0000o`0000@0oh001@3o00020?n00080o`0000<0oh000?l0003o0000103o00020?n0
00D0o`003@3oP0050?l00080oh000`3o00020?n00080o`000`3oP0040?l00080oh000P3o00000`3o
P000o`000?l000060?n000030?l0003oP000oh0000@0oh000P3o00030?n000@0003o0`3oP0020000
o`80oh001@3o00060?n000030000o`3o0000o`0000H0oh001@3o000Hooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool002;oooooL_l0000Wooooog7o00009ooooomao`0002OoooooLOl0000Tooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Go
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo
5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_oo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool000Gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5
oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo
003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`0PoooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l08?oooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaKoo`001Ol007lFo`3o03[o001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOoo`00>_l007lFoomo00Co001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOoo`00>_l007lFoomo00Co001o00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
03[ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
7Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOoo`00
E?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`04o`00O`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009oooooma
o`0002Cooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Fooooo`@00?l00`3o0004
003o00D0o`000P00o`0G0?l000@00?l02`3o00050?n00180o`000P000?l00`3oP000o`000?l00002
0?n000@0o`0000<00?l00?l0003o00001`3o00020000o`@0o`000P00o`000`3o00000?l0003o000;
0?l00080003o0`3o00020000o`@0o`0000<0003o0?n0003oP0000P3oP00>ooooo`@0oh002@00o`0:
0?l000H00?l01`3o00020000o`D0oh004P00o`050?l000T00?l01P3o0005003o0080o`003P00o`02
0?l000D00?l01P3o0005003o0080o`000P00o`050?l00080003o1`3oP00>ooooo`@00?l02@3o0000
0`3oP000o`000?l000020?l000800?l00`3o00020000o`@0o`0000<0oh000?l0003o00000P3o0002
0000o`D0oh00103o0002003o00<0o`001`00o`080?l000030?n000000?l0003o00@0o`0000<00?l0
0?l0003o00004P3o00020000o`D0oh001000o`050?l00080003o1@3oP0020000o`80oh000P000?l2
0?n000030000o`3oP000oh0000@0oh000P000?l50?n000kooooo0P3oP0090?l000<0oh000P3o0002
0?n00080o`001@3oP0020?l00080oh0000<0o`000?n0003oP0001000o`020?n000D0o`000P3oP003
0?l00080oh000P000?l50?n00080o`00103oP0020?l000030?n0003o0000o`0000@0o`0000<0oh00
0?l0003o00000P3o00020000o`80oh0000<0o`000?n0003oP0000P3oP004003o00030?n00000o`00
0?l000800?l00P3oP0050?l00080oh000P000?l20?l000030?n0003o0000o`000080o`000P3oP000
0`3o00000?l0003o0002003o0080o`000P000?l30?n000@0o`001`3oP00Hooooo`005_ooool4003o
00<0o`001000o`050?l000800?l05`3o0004003o00/0o`001@3oP00B0?l00080003o00<0oh000?l0
003o00000P3oP0040?l00003003o003o0000o`0000L0o`000P000?l40?l000800?l000<0o`00003o
0000o`002`3o00020000o`<0o`000P000?l40?l000030000o`3oP000oh000080oh003_ooool40?n0
00T00?l02P3o0006003o00L0o`000P000?l50?n001800?l01@3o0009003o00H0o`001@00o`020?l0
00h00?l00P3o0005003o00H0o`001@00o`020?l000800?l01@3o00020000o`L0oh003_ooool4003o
00T0o`0000<0oh000?l0003o00000P3o0002003o00<0o`000P000?l40?l000030?n0003o0000o`00
0080o`000P000?l50?n000@0o`000P00o`030?l000L00?l0203o00000`3oP000003o0000o`040?l0
0003003o003o0000o`000180o`000P000?l50?n000@00?l01@3o00020000o`D0oh000P000?l20?n0
0080003o0P3oP0000`000?l0oh000?n000040?n00080003o1@3oP00>ooooo`80oh002@3o00030?n0
0080o`000P3oP0020?l000D0oh000P3o00020?n000030?l0003oP000oh0000@00?l00P3oP0050?l0
0080oh000`3o00020?n00080003o1@3oP0020?l000@0oh000P3o00000`3oP000o`000?l000040?l0
00030?n0003o0000o`000080o`000P000?l20?n000030?l0003oP000oh000080oh001000o`000`3o
P0000?l0003o0002003o0080oh001@3o00020?n00080003o0P3o00000`3oP000o`000?l000020?l0
0080oh0000<0o`00003o0000o`000P00o`020?l00080003o0`3oP0040?l000L0oh006?ooool001Ko
oooo0P3o0002003o00<0o`000P00o`070?l000800?l01`3o00020?n000h0o`001000o`0;0?l000D0
oh004P3o00020000o`D0oh002`3o0002003o00L0o`001@00o`0;0?l00080003o0`3o00020000o`80
oh000P3o00000`000?l0oh000?n000020?n000kooooo103oP007003o00L0o`000P00o`030?l000T0
0?l0103o00020000o`D0oh004P00o`050?l00080oh000P3o0005003o00L0o`001000o`020?l00200
0?l02@3o00020000o`80oh0000<0o`000?n0003oP0000P3oP00>ooooo`@00?l02@3o00000`3oP000
o`000?l000020?l000800?l02@3o00000`00o`00o`000?l000020?l00080003o1@3oP0070?l000/0
0?l03@3o0003003o00H0o`000`3oP0060?l000030000o`3oP000oh000080003o1@3oP002003o0080
o`000P00o`030?l00080003o1@3oP0020000o`80oh000P000?l20?n000030000o`3oP000oh000080
o`0010000?l50?n000kooooo103oP0000`00o`00oh000?n000040?l000<0oh000P3o00020?n00080
o`001@3oP002003o00<0o`00103oP002003o0080o`002@3oP0000`3o0000oh000?n000060?l00003
0?n0003o0000o`0000@0o`000P00o`030?n000@0o`0000<0oh000?l0003o00000P3o00020000o`80
oh0000<0o`000?n0003oP0000P3oP002003o0080o`0000<0oh000?l0003o00000P3o00020?n00080
o`0000<0oh000?l0003o00000P3oP0020000o`<0o`000P3oP0020?l000D0oh00103o00030?n00080
o`000P000?l70?n00080o`006?ooool001Kooooo0P3o0002003o00<0o`000P00o`070?l000800?l0
1`3o00020?n000h0o`001000o`0;0?l000D0oh004P3o00020000o`D0oh002`3o0002003o00L0o`00
1@00o`0;0?l00080003o0`3o00020000o`80oh000P3o00000`000?l0oh000?n000020?n000kooooo
103oP007003o00L0o`000P00o`030?l000T00?l0103o00020000o`D0oh004P00o`050?l00080oh00
0P3o0005003o00L0o`001000o`020?l002000?l02@3o00020000o`80oh0000<0o`000?n0003oP000
0P3oP00>ooooo`@00?l02@3o00000`3oP000o`000?l000020?l000800?l02@3o00000`00o`00o`00
0?l000020?l00080003o1@3oP0070?l000/00?l03@3o0003003o00H0o`000`3oP0060?l000030000
o`3oP000oh000080003o1@3oP002003o0080o`000P00o`030?l00080003o1@3oP0020000o`80oh00
0P000?l20?n000030000o`3oP000oh000080o`0010000?l50?n000kooooo103oP0000`00o`00oh00
0?n000040?l000<0oh000P3o00020?n00080o`001@3oP002003o00<0o`00103oP002003o0080o`00
2@3oP0000`3o0000oh000?n000060?l000030?n0003o0000o`0000@0o`000P00o`030?n000@0o`00
00<0oh000?l0003o00000P3o00020000o`80oh0000<0o`000?n0003oP0000P3oP002003o0080o`00
00<0oh000?l0003o00000P3o00020?n00080o`0000<0oh000?l0003o00000P3oP0020000o`<0o`00
0P3oP0020?l000D0oh00103o00030?n00080o`000P000?l70?n00080o`006?ooool001Kooooo1000
o`0E0?l00080oh000P00o`030?l00080oh002@3o0002003o00T0o`000P000?l50?n00180o`000P00
0?l50?n000L0o`000P00o`0;0?l000800?l000<0o`00003o0000o`002@3o00020?n00080003o0`3o
00020000o`80o`000`3oP0040?l000kooooo103oP007003o00L0o`000P00o`030?l000d00?l00P00
0?l50?n001800?l01@3o000;003o00D0o`009P00o`050?l00080003o0P3o00090?n000kooooo1@00
o`020?l000800?l01@3o0002003o0080o`001000o`0<0?l00080003o1@3oP0060?l000030?n0003o
0000o`0000L0o`000P00o`060?l000030?n0003o0000o`000080o`000P00o`030?l000H0003o1@3o
P0040?l000030000o`3oP000oh000080003o1@3oP0060?l00080003o1@3oP0020?l000030?n00000
o`000?l00080o`000P000?l20?n000030?l0003oP000oh000080o`000P000?l20?n000030000o`3o
P000oh000080oh003_ooool50?n000H0o`001`3oP0040?l000D0oh000`3o0002003o0080oh000P00
o`020?l000030?n000000?l0003o0080oh001@3o00020?n000@0o`000P00o`030?n000@0o`000P00
o`030?n000@0o`000`00o`020?n000@0o`000`3oP0020?l000800?l00P3o00000`3oP000o`000?l0
00020?l000D0oh000P3o00040?n00080o`000`3oP0020?l00080oh0000<0o`000?n0003oP0000P3o
P0070000o`/0oh006?ooool001Kooooo0P3o0003003o01@0o`000P3oP002003o00h0o`000P00o`09
0?l00080003o1@3oP00<0?l00080003o103oP0020000o`<0oh005P3o0002003o00X0o`00103oP009
0?l00080oh0000<00?l00000o`000?l00P3o000>ooooo`80o`000P3oP007003o00D0o`000P00o`05
0?l000L00?l0103o0002003o0080003o1@3oP00B003o00D0o`000P00o`040?l000D00?l01@3o0002
003o00H0o`004000o`030?l000T00?l00P3o00020000o`D0oh000P3o00070?n00080o`003_ooool9
003o00@0o`0000<0003o003o0000o`001P3o00000`00o`00o`000?l000040?l000030?n0003o0000
o`0000@0003o1@3oP0020000o`80o`000`3oP0090?l000800?l00P3o00020000o`D0oh000P3o0002
003o00<0o`000P000?l20?n00080003o1`3oP0020?l000030000o`3oP000oh0000H0oh0000<0003o
0?l0003o0000103o00020000o`D0oh000P3o00000`00o`00o`000?l000040?l000800?l01@3o0002
0000o`L0oh003_ooool50?n00080003o0P3o00050?n00080o`000P3oP0040?l000030?n0003o0000
o`000080oh001@3o00020?n000800?l00P000?l00`3oP000o`000?l000020?n00080o`000P3oP000
0`3o0000oh000?n000020?l000@00?l000<0o`000?n0003oP0000P3o00070?n00080003o0`3o0004
003o0080oh000`3o00040?n000800?l00P3o00000`3oP000o`000?l000070?n000@0o`001`3oP004
0?l000030000o`3oP000oh000080oh000P000?l@0?n001Sooooo000Fooooo`80o`000`00o`0D0?l0
0080oh000P00o`0>0?l000800?l02@3o00020000o`D0oh00303o00020000o`@0oh000P000?l30?n0
01H0o`000P00o`0:0?l000@0oh002@3o00020?n00003003o00000?l0003o0080o`003_ooool20?l0
0080oh001`00o`050?l000800?l01@3o0007003o00@0o`000P00o`020000o`D0oh004P00o`050?l0
00800?l0103o0005003o00D0o`000P00o`060?l001000?l00`3o0009003o0080o`000P000?l50?n0
0080o`001`3oP0020?l000kooooo2@00o`040?l000030000o`00o`000?l000H0o`0000<00?l00?l0
003o0000103o00000`3oP000o`000?l000040000o`D0oh000P000?l20?l000<0oh002@3o0002003o
0080o`000P000?l50?n00080o`000P00o`030?l00080003o0P3oP0020000o`L0oh000P3o00000`00
0?l0oh000?n000060?n000030000o`3o0000o`0000@0o`000P000?l50?n00080o`0000<00?l00?l0
003o0000103o0002003o00D0o`000P000?l70?n000kooooo1@3oP0020000o`80o`001@3oP0020?l0
0080oh00103o00000`3oP000o`000?l000020?n000D0o`000P3oP002003o0080003o00<0oh000?l0
003o00000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3o0004003o00030?l0003oP000oh00
0080o`001`3oP0020000o`<0o`001000o`020?n000<0o`00103oP002003o0080o`0000<0oh000?l0
003o00001`3oP0040?l000L0oh00103o00000`000?l0oh000?n000020?n00080003o403oP00Hoooo
o`005_ooool20?l000D00?l01P3o00000`00o`00o`000?l000090?l000@00?l05@3o0002003o00D0
o`000P3oP0020000o``0o`000P000?l40?n00080003o1`3o00020000o`L0o`000P3oP0000`3o0000
003o0000o`040?l000800?l000<0o`00003o0000o`00103o00000`000?l0oh000?n000040?n000D0
o`000P000?l20?l00080oh001@3o000>ooooo`/00?l0303o0009003o0080o`000P00o`020000o`D0
oh004P00o`050?l000@00?l01@3o0002003o00D0o`000P00o`060?l000D00?l00P3o0002003o0003
0?l00000o`000?l00080o`000P00o`050?l000T00?l00P000?l50?n000@0o`001@3oP0020?l000ko
oooo103oP005003o00@0o`000`3oP00B0?l00080003o1@3oP0020000o`D0oh002@3o0002003o0080
o`000P000?l20?n000030?l0003oP000oh0000L0o`000P000?lB0?n00080o`000P3oP0000`000?l0
oh000?n000040?n00080003o0`3oP0040?l00003003o003o0000o`000080o`00103oP0070?l00080
oh0000<0o`000?n0003oP0000P3oP00>ooooo`80oh000P3o00000`3oP0000?l0003o00020000o`D0
oh000P3o00020?n000800?l00P3o00050?n00080o`0000<00?l00?l0003o00002`00o`020?l00080
oh0000<0o`000?n0003oP000103o00020?n000030?l000000?l0003o00H0oh0000<0o`000000o`00
0?l0103o0005003o0080oh000P000?l50?n000800?l00`3o00090?n00080o`002@3oP0020?l00080
0?l000<0003o0?n0003oP0002@3oP0020?l000L0oh000P3o000Hooooo`005_ooool20?l000D00?l0
1P3o00000`00o`00o`000?l000090?l000@00?l05@3o0002003o00D0o`000P3oP0020000o``0o`00
0P000?l40?n00080003o1`3o00020000o`L0o`000P3oP0000`3o0000003o0000o`040?l000800?l0
00<0o`00003o0000o`00103o00000`000?l0oh000?n000040?n000D0o`000P000?l20?l00080oh00
1@3o000>ooooo`/00?l0303o0009003o0080o`000P00o`020000o`D0oh004P00o`050?l000@00?l0
1@3o0002003o00D0o`000P00o`060?l000D00?l00P3o0002003o00030?l00000o`000?l00080o`00
0P00o`050?l000T00?l00P000?l50?n000@0o`001@3oP0020?l000kooooo103oP005003o00@0o`00
0`3oP00B0?l00080003o1@3oP0020000o`D0oh002@3o0002003o0080o`000P000?l20?n000030?l0
003oP000oh0000L0o`000P000?lB0?n00080o`000P3oP0000`000?l0oh000?n000040?n00080003o
0`3oP0040?l00003003o003o0000o`000080o`00103oP0070?l00080oh0000<0o`000?n0003oP000
0P3oP00>ooooo`80oh000P3o00000`3oP0000?l0003o00020000o`D0oh000P3o00020?n000800?l0
0P3o00050?n00080o`0000<00?l00?l0003o00002`00o`020?l00080oh0000<0o`000?n0003oP000
103o00020?n000030?l000000?l0003o00H0oh0000<0o`000000o`000?l0103o0005003o0080oh00
0P000?l50?n000800?l00`3o00090?n00080o`002@3oP0020?l000800?l000<0003o0?n0003oP000
2@3oP0020?l000L0oh000P3o000Hooooo`005_ooool7003o00H0o`0000<00?l00?l0003o00002@3o
0002003o01D0o`000P00o`0G0?l00080003o4P3o00060?n000030?l000000?l0003o00@0o`000P00
o`070?l000030000o`3oP000oh000080o`000P3oP0090?l00080oh001@3o000>ooooo`/00?l00`3o
0002003o00L0o`002@00o`020?l000800?l00P000?l50?n001800?l01@3o0004003o00D0o`000P00
o`050?l000800?l01P3o0003003o00@0o`000P00o`000`3o00000?l0003o0004003o00D0o`001000
o`000`3o00000?l0003o0002003o0080003o1@3oP0020?l00080003o1`3oP00>ooooo`@0oh001@00
o`040?l000<0oh001P3o00000`3oP000o`000?l00002003o00L0o`000P000?l20?l000<0oh000P00
0?l50?n000T0o`001000o`040?l000030000o`3oP000oh000080003o1@3oP0020000o`80oh000`00
0?l;0?n000H0o`001@3oP0040?l000030?n0003o0000o`0000@0o`0000<00?l00000o`000?l02@3o
P0020000o`@0o`0000<0003o0?n0003oP0000P3oP00>ooooo`80oh000P3o00000`3oP000003o0000
o`060?n000<00?l0103o00020000o`D0oh000P3o00000`00o`00o`000?l00006003o00D0o`000P00
0?l20?n000030?l0003oP000oh0000@0o`000`3oP0020000o`L0oh000P3o00050?n000@00?l00P3o
P0020000o`D0oh000P00o`020000o`030?n0003o0000o`0000L0oh000P000?l90?n00080o`002`3o
P0030?l00080oh000P00o`050?l000800?l06?ooool001Kooooo1`00o`060?l00003003o003o0000
o`0000T0o`000P00o`0E0?l000800?l05`3o00020000oa80o`001P3oP0000`3o0000003o0000o`04
0?l000800?l01`3o00000`000?l0oh000?n000020?l00080oh002@3o00020?n000D0o`003_ooool;
003o00<0o`000P00o`070?l000T00?l00P3o0002003o0080003o1@3oP00B003o00D0o`001000o`05
0?l000800?l01@3o0002003o00H0o`000`00o`040?l000800?l000<0o`00003o0000o`001000o`05
0?l000@00?l000<0o`00003o0000o`000P00o`020000o`D0oh000P3o00020000o`L0oh003_ooool4
0?n000D00?l0103o00030?n000H0o`0000<0oh000?l0003o00000P00o`070?l00080003o0P3o0003
0?n00080003o1@3oP0090?l000@00?l0103o00000`000?l0oh000?n000020000o`D0oh000P000?l2
0?n000<0003o2`3oP0060?l000D0oh00103o00000`3oP000o`000?l000040?l00003003o00000?l0
003o00T0oh000P000?l40?l000030000o`3oP000oh000080oh003_ooool20?n00080o`0000<0oh00
0000o`000?l01P3oP003003o00@0o`000P000?l50?n00080o`0000<00?l00?l0003o00001P00o`05
0?l00080003o0P3oP0000`3o0000oh000?n000040?l000<0oh000P000?l70?n00080o`001@3oP004
003o0080oh000P000?l50?n000800?l00P000?l00`3oP000o`000?l000070?n00080003o2@3oP002
0?l000/0oh000`3o00020?n000800?l01@3o0002003o01Sooooo000Fooooo`L00?l01P3o00000`00
o`00o`000?l000090?l000800?l0303o0002003o00T0o`000P00o`0@0?l00080003o0`3o00020000
oa00o`000P000?l60?n000030?l000000?l0003o00d0o`0000<0oh000?l0003o00003@3o00020?n0
00D0o`003_ooool;003o0080o`000`00o`070?l000T00?l00P3o0002003o0080003o1@3oP00;003o
0080o`001@00o`050?l000800?l00P3o00020000o`<0o`000P00o`0=0?l000<00?l00P3o0004003o
00<0o`001000o`050?l000@00?l000<0o`00003o0000o`000P00o`020000o`<0oh000P000?l20?l0
0080003o1`3oP00>ooooo`@0oh001@00o`020000o`<0o`000P3oP0060?l000030?n0003o0000o`00
00L0o`0010000?l50?n00080003o1@3oP006003o0080o`001@00o`040?l000030000o`3oP000oh00
0080003o1@3oP0020000o`80oh000`000?l90?n000@0o`000P000?l70?n000D0o`000P000?l40?n0
0003003o00000?l0003o00@0oh000P000?l50?n000@0o`0000<0003o0?n0003oP0000P000?l>oooo
o`80oh000P00o`050?l000@0oh001@3o00020?n00080003o1@3oP0020?l00003003o003o0000o`00
00800?l01@3o00020?n000@0o`000P3oP0030?l00080003o1@3oP0020000o`H0oh0000<0o`000000
o`000?l01@3oP0040?l00080oh000P000?l50?n000800?l00P000?l30?l00080oh000P3o00030?n0
0080003o1P3oP0000`3o0000oh000?n000020?n00080o`000`3oP0040?l00080oh000`3o00020?n0
0080o`000P3oP0000`3o0000oh000?n000020?l001Sooooo000Fooooo`80o`000`00o`080?l00003
003o003o0000o`0000T0o`000P00o`070?l00080003o0`3o0002003o00T0o`001000o`0C0?l00080
003o403o00020000o`@0o`000P3oP00W0?l000kooooo4000o`070?l000H00?l01@3o0002003o0080
003o1@3oP00;003o0080o`000`00o`020?l000800?l00P3o0003003o0080o`000P000?l:0?l00080
0?l01P3o000B003o00<0o`002@00o`050?l00080003o0P3o00020000o`D0oh000P3o000>ooooo`@0
oh001@00o`050?l00080oh00103o0002003o00X0o`000P3oP0020000o`D0oh000P3o00050?n000@0
o`002@00o`040?l000030000o`3oP000oh0000@0oh0000<0o`000?n0003oP0000P000?l20?n00080
003o2@3oP0000`00o`00o`000?l000020?l00080003o1@3oP006003o00030?l000000?l0003o00D0
oh000P000?l40?n00080003o1@3oP0040?l000030000o`3oP000oh000080003o3_ooool90?l000@0
oh001@3o00020?n00080o`001@3oP0070?l00080oh000P00o`030?n000@0o`000`00o`020?l00080
003o1@3oP0020000o`L0oh000P000?l50?n000H0o`000P000?l50?n00080o`000P3oP0000`3o0000
oh000?n000020?n00080o`000P3oP0000`3o0000oh000?n000040?n000<0003o3`3oP0000`3o0000
oh000?n000040?n00080003o1@3oP00Hooooo`005_ooool20?l000<00?l0203o00000`00o`00o`00
0?l000090?l000800?l01`3o00020000o`<0o`000P00o`090?l000@00?l04`3o00020000oa00o`00
0P000?l40?l00080oh009`3o000>oooooa000?l01`3o0006003o00D0o`000P00o`020000o`D0oh00
2`00o`020?l000<00?l00P3o0002003o0080o`000`00o`020?l00080003o2P3o0002003o00H0o`00
4P00o`030?l000T00?l01@3o00020000o`80o`000P000?l50?n00080o`003_ooool40?n000D00?l0
1@3o00020?n000@0o`000P00o`0:0?l00080oh000P000?l50?n00080o`001@3oP0040?l000T00?l0
103o00000`000?l0oh000?n000040?n000030?l0003oP000oh000080003o0P3oP0020000o`T0oh00
00<00?l00?l0003o00000P3o00020000o`D0oh001P00o`000`3o0000003o0000o`050?n00080003o
103oP0020000o`D0oh00103o00000`000?l0oh000?n000020000o`kooooo2@3o00040?n000D0o`00
0P3oP0020?l000D0oh001`3o00020?n000800?l00`3oP0040?l000<00?l00P3o00020000o`D0oh00
0P000?l70?n00080003o1@3oP0060?l00080003o1@3oP0020?l00080oh0000<0o`000?n0003oP000
0P3oP0020?l00080oh0000<0o`000?n0003oP000103oP0030000o`l0oh0000<0o`000?n0003oP000
103oP0020000o`D0oh006?ooool001Kooooo0P3o0003003o0140o`0000<00?l00?l0003o0000103o
00000`000?l0o`000?l000060?l000<00?l04P3o00020000o`@0o`0000<00?l00?l0003o00007@3o
0002003o00X0o`000P00o`0D0?l00080oh0000<0o`000000o`000?l00P3oP00>oooooa000?l00P3o
0002003o0080o`001`00o`050?l000800?l00P000?l50?n000/00?l00P3o0003003o00L0o`000P00
o`090?l00080003o0P00o`000`3o00000?l0003o00060?l001h00?l01@3o00020000o`80o`001`3o
P0020?l000kooooo0P3o0007003o00/0o`000P00o`030?l00080003o0P3oP0050?l00080003o0P3o
P0000`3o0000oh000?n000020?l000@0oh002P3o0004003o00@0o`0000<0003o0?n0003oP000103o
P0030?l00080003o0P3oP0020000o`T0oh0000<0o`000000o`000?l00P3o00020000o`D0oh00103o
0002003o00030?l000000?l0003o00D0oh001P3o00020000o`D0oh00103o00000`000?l0oh000?n0
00020?n000kooooo1000o`050?l00080oh000P00o`000`3oP000o`000?l000020?l000/0oh0000<0
o`000000o`000?l01P3oP0000`3o0000oh000?n000020?l00080oh002@3o00030?n00080o`000P00
0?l40?n000<0o`001`3oP0020?l000T0oh000P3o00090?n00080o`001`3oP0020000o`D0oh000P3o
00030?n00080003o103oP0000`00o`00oh000?n000040?n00080o`001@3oP00Hooooo`005_ooool2
0?l000<00?l04@3o00000`00o`00o`000?l000040?l000030000o`3o0000o`0000H0o`000`00o`0B
0?l00080003o103o00000`00o`00o`000?l0000M0?l000800?l02P3o0002003o01@0o`000P3oP000
0`3o0000003o0000o`020?n000kooooo4000o`020?l000800?l00P3o0007003o00D0o`000P00o`02
0000o`D0oh002`00o`020?l000<00?l01`3o0002003o00T0o`000P000?l2003o00030?l00000o`00
0?l000H0o`007P00o`050?l00080003o0P3o00070?n00080o`003_ooool20?l000L00?l02`3o0002
003o00<0o`000P000?l20?n000D0o`000P000?l20?n000030?l0003oP000oh000080o`00103oP00:
0?l000@00?l0103o00000`000?l0oh000?n000040?n000<0o`000P000?l20?n00080003o2@3oP000
0`3o0000003o0000o`020?l00080003o1@3oP0040?l000800?l000<0o`000000o`000?l01@3oP006
0?l00080003o1@3oP0040?l000030000o`3oP000oh000080oh003_ooool4003o00D0o`000P3oP002
003o00030?n0003o0000o`000080o`002`3oP0000`3o0000003o0000o`060?n000030?l0003oP000
oh000080o`000P3oP0090?l000<0oh000P3o00020000o`@0oh000`3o00070?n00080o`002@3oP002
0?l000T0oh000P3o00070?n00080003o1@3oP0020?l000<0oh000P000?l40?n00003003o003oP000
oh0000@0oh000P3o00050?n001Sooooo000Foooooa00o`000P000?l40?l00003003o003o0000o`00
00@0o`0000<0003o0?l0003o00001P3o00000`00o`00o`000?l0000K0?l00080003o2@3o00020?n0
00030?l000000?l0003o0080o`00103oP0070?l000800?l02P3o0002003o0100o`000P000?l40?l0
0003003o003o0000o`000080oh003_oooolT003o0080003o1@3oP00;003o0080o`0000<00?l00?l0
003o0000103o0002003o00030?l00000o`000?l000T0o`000P000?l30?l000800?l01`3o0009003o
0080o`001`00o`020?l000T00?l00P3o0002003o00030?l000000?l0003o00H0oh0000<0o`000?n0
003oP0000P3o000>ooooo`80o`002`00o`000`3o0000003o0000o`040?l000800?l000<0o`00003o
0000o`000P000?l30?l00080oh001`3o00020000o`@0o`000`3oP0090?l000@00?l00P000?l90?n0
0003003o003o0000o`000080003o0P3oP0020000o`<0oh00103o0003003o0080003o0P3o00020000
o`<0o`000P3oP00;0?l000D00?l0103o00020000o`030?n0003o0000o`000080oh001000o`000`00
0?l0oh000?n000020?n000kooooo0P00o`020?l000030?n0003o0000o`000080o`000P3oP003003o
00@0o`002`3oP0000`3o0000003o0000o`020?n00080o`000`3oP0020?l000@0oh001`3o00040?n0
0003003o003o0000o`000080003o0P3o00030?n00080003o103oP0000`3o0000oh000?n000020000
o`80oh000P000?l50?n00080o`000P3oP0000`3o0000oh000?n0000D0?n000<0o`0010000?l50?n0
0080o`00103oP0020000o`D0oh006?ooool001Kooooo403o00020000o`@0o`0000<00?l00?l0003o
0000103o00000`000?l0o`000?l000060?l00003003o003o0000o`0001/0o`000P000?l90?l00080
oh0000<0o`000000o`000?l00P3o00040?n000L0o`000P00o`0:0?l000800?l0403o00020000o`@0
o`0000<00?l00?l0003o00000P3oP00>ooooob@00?l00P000?l50?n000/00?l00P3o00000`00o`00
o`000?l000040?l000800?l000<0o`00003o0000o`002@3o00020000o`<0o`000P00o`070?l000T0
0?l00P3o0007003o0080o`002@00o`020?l000800?l000<0o`000000o`000?l01P3oP0000`3o0000
oh000?n000020?l000kooooo0P3o000;003o00030?l000000?l0003o00@0o`000P00o`000`3o0000
0?l0003o00020000o`<0o`000P3oP0070?l00080003o103o00030?n000T0o`001000o`020000o`T0
oh0000<00?l00?l0003o00000P000?l20?n00080003o0`3oP0040?l000<00?l00P000?l20?l00080
003o0`3o00020?n000/0o`001@00o`040?l00080003o00<0oh000?l0003o00000P3oP004003o0003
0000o`3oP000oh000080oh003_ooool2003o0080o`0000<0oh000?l0003o00000P3o00020?n000<0
0?l0103o000;0?n000030?l000000?l0003o0080oh000P3o00030?n00080o`00103oP0070?l000@0
oh0000<00?l00?l0003o00000P000?l20?l000<0oh000P000?l40?n000030?l0003oP000oh000080
003o0P3oP0020000o`D0oh000P3o00020?n000030?l0003oP000oh0001@0oh000`3o00040000o`D0
oh000P3o00040?n00080003o1@3oP00Hooooo`005_ooool@0?l00080003o2`3o00000`000?l0o`00
0?l000060?l00003003o003o0000o`0001/0o`000P000?l20?l000030?n000000?l0003o00@0o`00
0`3oP0020000o`@0o`000P3oP0000`3o0000003o0000o`040?l00080oh0000<00?l00?l0003o0000
0P00o`050?l000800?l02@3o00040?n000<0o`000P000?l20?l00080oh0000<00?l00?l0003o0000
0P3o000>ooooo`/00?l00P3o0007003o0080o`003P00o`020000o`D0oh004000o`040?l000800?l0
403o0005003o00D0o`002@00o`020?l000L00?l01P3o00000`00o`00o`000?l00009003o00@0o`00
0P3oP0050?l000kooooo0P3o0007003o00D0o`000P000?l40?l000800?l03P3o00030?n000H0o`00
0`3oP00=0?l00080003o0`3oP0020000o`80o`000P00o`030?l000H0003o0`3oP002003o0080o`00
1@00o`0D0?l000<00?l00P3o00020000o`D0oh000P3o00020?n000800?l01`3o000>ooooo`T0o`00
0P3oP002003o00030?n00000o`000?l000800?l00P3oP0020?l000<0oh00103o00000`3oP000003o
0000o`060?n000<0o`00103oP0070?l000D0oh000P3o00020000o`@0o`0000<0oh000000o`000?l0
103oP0000`3o0000oh000?n000040?n00080o`000`3oP0070?l001/0oh000P000?l50?n00080o`00
103oP0020000o`D0oh006?ooool001Kooooo403o00020000o`/0o`0000<0003o0?l0003o00001P3o
00000`00o`00o`000?l0000K0?l00080003o0P3o00000`3oP000003o0000o`040?l000<0oh000P00
0?l40?l00080oh0000<0o`000000o`000?l0103o00020?n00003003o003o0000o`0000800?l01@3o
0002003o00T0o`00103oP0030?l00080003o0P3o00020?n00003003o003o0000o`000080o`003_oo
ool;003o0080o`001`00o`020?l000h00?l00P000?l50?n001000?l0103o0002003o0100o`001@00
o`050?l000T00?l00P3o0007003o00H0o`0000<00?l00?l0003o00002@00o`040?l00080oh001@3o
000>ooooo`80o`001`00o`050?l00080003o103o0002003o00h0o`000`3oP0060?l000<0oh003@3o
00020000o`<0oh000P000?l20?l000800?l00`3o00060000o`<0oh000P00o`020?l000D00?l0503o
0003003o0080o`000P000?l50?n00080o`000P3oP002003o00L0o`003_ooool90?l00080oh000P00
o`000`3oP0000?l0003o0002003o0080oh000P3o00030?n000@0o`0000<0oh000000o`000?l01P3o
P0030?l000@0oh001`3o00050?n00080o`000P000?l40?l000030?n000000?l0003o00@0oh0000<0
o`000?n0003oP000103oP0020?l000<0oh001`3o000K0?n00080003o1@3oP0020?l000@0oh000P00
0?l50?n001Sooooo000Fooooo`L0o`000P00o`070?l00080003o2`3o00000`000?l0o`000?l00006
0?l00003003o003o0000o`000080o`000P000?l90?l00080003o1`3o00020?n000<0o`000P000?l9
0?l000<0oh000P000?l70?l00080003o103o00020?n00003003o003o0000o`0000800?l01@3o0002
003o0100o`000P000?l40?n00003003o003o0000o`000080o`003_oooolD003o0080o`002000o`02
0?l000@00?l00P000?l50?n001000?l0103o0007003o00T0o`000P3oP005003o00D0o`002@00o`02
0?l000L00?l02@3o0002003o0080o`001@00o`0;0?l000kooooo103o0005003o00h0o`000P00o`02
0?l000800?l00`3o00020000o`80o`000`3oP0080?l000030?n0003o0000o`0000800?l02@3o0002
0000o`80oh00303o00070?n000H0o`0000<0oh00003o0000o`000P00o`050?l000@0oh00103o0003
0?n000L0o`000P000?l50?n000800?l00P3o0002003o00L0o`003_ooool70?l00080oh000P3o0002
003o00030?n0003o0000o`000080o`000P3oP0020?l00003003o003oP000oh000080o`000`3oP00;
0?l000@0oh000`3o00080?n000<0o`003@3oP0000`000?l0oh000?n000040?n00080o`0000<0oh00
003o0000o`001P3o000@0?n00080o`0000<0oh000?l0003o00000P3o00030?n00080o`000P000?l7
0?n00080o`001`3oP0020?l001Sooooo000Fooooo`80o`000P000?l30?l000800?l0=P3o00020?n0
00<0o`000P000?l90?l00080oh002P3o00020000o`@0o`000`00o`090?l000800?l01@3o00020000
o`H0oh0000<0o`00003o0000o`000P000?l40?n00003003o003o0000o`000080o`003_ooool2003o
00<0o`001000o`040?l00003003o003o0000o`0000d00?l00`3o0004003o00D0o`000P3oP00D003o
00`0o`000P000?l50?n000@00?l01@3o000D003o00@0o`0000<00?l00?l0003o00000P00o`050?l0
00800?l00P3o0002003o0080o`0000<0003o0?l0003o00000P3o000>ooooo`80oh000`3o0002003o
00T0o`001000o`030?l000H00?l0303o0002003o00@0o`0000<0oh000?l0003o00000P3o0004003o
00D0o`000P00o`070?l000800?l000<0o`00003o0000o`000P000?l20?l000<0oh00203o00000`00
o`00o`000?l000060?l000<0oh000P3o00020000o`80o`000`3oP0040?l000<0oh000P000?l70?n0
00L0o`000P3oP0020?l000kooooo0P3o00020000o`030?l0003oP000oh0000H0oh001@3o00040?n0
0003003o003oP000oh000080o`000P00o`090?l000<0oh001000o`050?l000@0oh000P00o`000`3o
0000003o0000o`070?n00080003o103oP0000`000?l0oh000?n000040?n00080o`0000<0oh00003o
0000o`00103o00020000o`T0oh0000<0003o0?n0003oP000103oP0020?l000030000o`3oP000oh00
00D0oh000P3o00040000o``0oh0010000?lHooooo`005_ooool20?l00080003o0`3o0002003o03H0
o`000P3oP0030?l00080003o2@3o00020?n000X0o`000P000?l40?l000<00?l02@3o0002003o00D0
o`000P000?l60?n000030?l00000o`000?l00080003o103oP0000`00o`00o`000?l000020?l000ko
oooo0P00o`030?l000@00?l0103o00000`00o`00o`000?l0000=003o00<0o`001000o`050?l00080
oh005000o`0<0?l00080003o1@3oP004003o00D0o`005000o`040?l00003003o003o0000o`000080
0?l01@3o0002003o0080o`000P00o`020?l000030000o`3o0000o`000080o`003_ooool20?n000<0
o`000P00o`090?l000@00?l00`3o0006003o00`0o`000P00o`040?l000030?n0003o0000o`000080
o`001000o`050?l000800?l01`3o0002003o00030?l00000o`000?l00080003o0P3o00030?n000P0
o`0000<00?l00?l0003o00001P3o00030?n00080o`000P000?l20?l000<0oh00103o00030?n00080
003o1`3oP0070?l00080oh000P3o000>ooooo`80o`000P000?l00`3o0000oh000?n000060?n000D0
o`00103oP0000`00o`00oh000?n000020?l000800?l02@3o00030?n000@00?l01@3o00040?n00080
0?l000<0o`000000o`000?l01`3oP0020000o`@0oh0000<0003o0?n0003oP000103oP0020?l00003
0?n00000o`000?l000@0o`000P000?l90?n000030000o`3oP000oh0000@0oh000P3o00000`000?l0
oh000?n000050?n00080o`0010000?l<0?n000@0003o6?ooool001Kooooo1`3o0004003o00h0o`00
0P00o`0<0?l00080oh009P3o00030?n00140o`0000<00?l00?l0003o00000P00o`050?l000800?l0
1@3o00020000o`H0oh0000<0o`00003o0000o`000P000?l50?n000@0o`003_ooool50?l000T00?l0
0P3o0002003o00@0o`001`00o`030?l000@00?l01@3o00020?n000L00?l01P3o0003003o00L0o`00
1000o`050?l00080003o1@3oP004003o00D0o`002@00o`020?l000H00?l000<0o`00003o0000o`00
2@00o`050?l000800?l00P3o0002003o00L0o`003_ooool20?n000h0o`001000o`050?l000@00?l0
2P3o00020?n000d0o`000P00o`050?l000800?l01`3o0002003o00T0o`0000<0oh000?l0003o0000
1P3o00000`00o`00o`000?l000020?l00080003o1@3oP0020?l00080003o0P3o00030?n00080003o
1@3oP0040000o`D0oh002`3o000>ooooo`80o`000P3oP0000`000?l0oh000?n000040?n000800?l0
00<0003o0?l0003o00000P3o00070?n00080o`000P00o`030?l000@0oh000`3o0004003o0080o`00
0P000?l00`3o0000oh000?n000020?n000@00?l000<0o`000000o`000?l00P000?l50?n00080o`00
103oP0000`3o0000oh000?n000020?n000@00?l00`3o00070000o`H0oh000`000?l40?n00080o`00
0`000?l70?n00080o`000P000?l70?n00080o`000P000?l50?n00080003o6?ooool001Kooooo1`3o
0004003o00h0o`000P00o`0<0?l00080oh009P3o00030?n00140o`0000<00?l00?l0003o00000P00
o`050?l000800?l01@3o00020000o`H0oh0000<0o`00003o0000o`000P000?l50?n000@0o`003_oo
ool50?l000T00?l00P3o0002003o00@0o`001`00o`030?l000@00?l01@3o00020?n000L00?l01P3o
0003003o00L0o`001000o`050?l00080003o1@3oP004003o00D0o`002@00o`020?l000H00?l000<0
o`00003o0000o`002@00o`050?l000800?l00P3o0002003o00L0o`003_ooool20?n000h0o`001000
o`050?l000@00?l02P3o00020?n000d0o`000P00o`050?l000800?l01`3o0002003o00T0o`0000<0
oh000?l0003o00001P3o00000`00o`00o`000?l000020?l00080003o1@3oP0020?l00080003o0P3o
00030?n00080003o1@3oP0040000o`D0oh002`3o000>ooooo`80o`000P3oP0000`000?l0oh000?n0
00040?n000800?l000<0003o0?l0003o00000P3o00070?n00080o`000P00o`030?l000@0oh000`3o
0004003o0080o`000P000?l00`3o0000oh000?n000020?n000@00?l000<0o`000000o`000?l00P00
0?l50?n00080o`00103oP0000`3o0000oh000?n000020?n000@00?l00`3o00070000o`H0oh000`00
0?l40?n00080o`000`000?l70?n00080o`000P000?l70?n00080o`000P000?l50?n00080003o6?oo
ool001Kooooo0P3o0002003o01D0o`000P00o`070?l00080003o0`3o0002003o0080o`000P00o`0L
0?l000800?l0103o00030?n000H0o`000P00o`090?l00003003o003o0000o`0000800?l0303o0002
0000o`H0oh0000<0o`00003o0000o`000P000?l40?n000D0o`003_ooool2003o0080o`002P00o`06
0?l002L00?l01P3o0005003o00D0o`000P000?l50?n000@00?l01@3o000A003o00030?l00000o`00
0?l000T00?l01@3o0002003o0080o`000P00o`020?l00003003o003o0000o`000080o`003_oooolD
0?l00080003o0`3o0002003o00T0o`000P000?l00`3oP000o`000?l000060?l000<0oh00103o0005
003o00T0o`000P00o`0<0?l00080003o0P3oP0020?l000800?l000<0o`000000o`000?l00P3oP002
0000o`D0oh002@3o00020000o`D0oh0010000?l50?n000@0o`000P00o`030?l00080003o3_ooool2
0?l00080oh0000<0003o0?l0003o00001P3oP0030?l000T0oh000P00o`050?l000@0oh000P3o0005
003o0080o`000P000?l70?n00080o`0000<0003o0?n0003oP0000P000?l40?n00003003o003o0000
o`000080o`000`000?l40?n000800?l01@3o00020?n00080003o0P3oP0000`000?l0oh000?n00004
0000o`L0oh000P3o00070?n000800?l000<0oh000000o`000?l00P3oP0020000o`h0oh000P000?lH
ooooo`005_ooool20?l000800?l05@3o0002003o00L0o`000P000?l30?l000800?l00P3o0002003o
01`0o`000P00o`040?l000<0oh001P3o0002003o00T0o`0000<00?l00?l0003o00000P00o`0<0?l0
0080003o1P3oP0000`3o00000?l0003o00020000o`@0oh001@3o000>ooooo`800?l00P3o000:003o
00H0o`009`00o`060?l000D00?l01@3o00020000o`D0oh001000o`050?l001400?l000<0o`00003o
0000o`002@00o`050?l000800?l00P3o0002003o0080o`0000<00?l00?l0003o00000P3o000>oooo
oa@0o`000P000?l30?l000800?l02@3o00020000o`030?n0003o0000o`0000H0o`000`3oP0040?l0
00D00?l02@3o0002003o00`0o`000P000?l20?n00080o`000P00o`000`3o0000003o0000o`020?n0
0080003o1@3oP0090?l00080003o1@3oP0040000o`D0oh00103o0002003o00<0o`000P000?l>oooo
o`80o`000P3oP0000`000?l0o`000?l000060?n000<0o`002@3oP002003o00D0o`00103oP0020?l0
00D00?l00P3o00020000o`L0oh000P3o00000`000?l0oh000?n000020000o`@0oh0000<00?l00?l0
003o00000P3o00030000o`@0oh000P00o`050?l00080oh000P000?l20?n000030000o`3oP000oh00
00@0003o1`3oP0020?l000L0oh000P00o`000`3oP000003o0000o`020?n00080003o3P3oP0020000
oaSooooo000FoooooaT0o`000P00o`070?l00080003o0`3o0002003o0100o`000P000?lM0?l00080
0?l0303o0002003o00`0o`000P000?l20?l00080oh001@3o00020000o`D0oh00103o000>ooooo`@0
o`002P00o`090?l002l00?l01@3o00020000o`D0oh001000o`050?l000/00?l00P3o0004003o00D0
o`001`00o`090?l000800?l00P3o0005003o00kooooo403o00020?n00080o`000P000?l30?l00080
oh000`3o00020000o`@0o`000P000?l00`3oP000003o0000o`020?n00080003o1@3oP0060?l00003
003o003o0000o`0000L0o`000P3oP002003o00T0o`000`000?l40?n000@00?l000<0o`000000o`00
0?l01P3oP0000`3o0000oh000?n000060?l000030000o`3o0000o`000080003o1@3oP0020000o`L0
oh002@3o00020000o`kooooo0P3o00030?n000H00?l00P3oP0000`3o0000oh000?n000020?n00080
003o1@3oP004003o00030000o`3oP000oh0000@0oh000P3o0005003o0080oh000P3o00070?n00080
0?l000<0003o0?n0003oP0000P000?l50?n000@0o`000`000?l40?n000800?l00`3o00040?n00080
003o1@3oP0060000o`D0oh000P000?l20?n000030000o`3oP000oh000080oh000`00o`020?l00080
003o1`3oP0040000o`D0oh000P000?lHooooo`005_oooolI0?l000800?l01`3o00020000o`<0o`00
0P00o`0@0?l00080003o7@3o0002003o00`0o`000P00o`0<0?l00080003o0P3o00020?n000D0o`00
0P000?l50?n000@0o`003_ooool40?l000X00?l02@3o000_003o00D0o`000P000?l50?n000@00?l0
1@3o000;003o0080o`001000o`050?l000L00?l02@3o0002003o0080o`001@00o`0>oooooa00o`00
0P3oP0020?l00080003o0`3o00020?n000<0o`000P000?l40?l00080003o00<0oh000000o`000?l0
0P3oP0020000o`D0oh001P3o00000`00o`00o`000?l000070?l00080oh000P00o`090?l000<0003o
103oP004003o00030?l000000?l0003o00H0oh0000<0o`000?n0003oP0001P3o00000`000?l0o`00
0?l000020000o`D0oh000P000?l70?n000T0o`000P000?l>ooooo`80o`000`3oP006003o0080oh00
00<0o`000?n0003oP0000P3oP0020000o`D0oh001000o`000`000?l0oh000?n000040?n00080o`00
1@00o`020?n00080o`001`3oP002003o00030000o`3oP000oh000080003o1@3oP0040?l000<0003o
103oP002003o00<0o`00103oP0020000o`D0oh001P000?l50?n00080003o0P3oP0000`000?l0oh00
0?n000020?n000<00?l00P3o00020000o`L0oh0010000?l50?n00080003o6?ooool001Kooooo6@3o
0002003o0080o`0000<0003o0?n0003oP0001`3o0004003o00T0o`000P00o`030?l00080003o103o
00020000o`<0o`000P000?l70?l00080003o2@3o0002003o00D0o`000P00o`050?l000800?l05`3o
00020000o`80o`000`3oP0040?l000kooooo0P3o000<003o00H0o`000P00o`000`3o00000?l0003o
0004003o00D0o`007@00o`020?l000D00?l01@3o00020000o`D0oh001P00o`050?l000T00?l00P3o
0002003o00L0o`001`00o`020?l000<00?l0103o0002003o0080o`001@00o`0>ooooo`D00?l01P3o
00020000o`030?l0003oP000oh000080oh00103o00000`000?l0o`000?l000040?n000<0o`000P3o
P0020?l00080oh0000<0o`000000o`000?l00P3oP0020000o`D0oh000P3o0002003o0080o`0000<0
0?l00?l0003o0000103o00020000o`<0o`00103oP0000`00o`00o`000?l000020?l000D0003o103o
P002003o00<0o`000P000?l20?n00080o`000P3oP0000`3o0000oh000?n000060?l000030000o`3o
P000oh0000@0oh0000<0o`000?n0003oP0000P000?l20?l000<0oh000P000?l40?l000800?l00`3o
00020000o`kooooo0P3o00050?n000800?l0103o00000`000?l0oh000?n000070?n000H00?l000<0
003o0?n0003oP000103oP007003o0080oh000`3o00020?n00080o`000P3oP0020?l000030000o`3o
0000o`0000@0003o0`3oP0020?l000D0003o103oP002003o0080003o1@3oP0020000o`D0oh000P00
0?l20?n00080003o00<0oh000?l0003o00001P3o00080?n00080o`000P3oP0040?l000030?n0003o
0000o`0000800?l00P000?l50?n00080o`006?ooool001Kooooo0P00o`0D0?l00003003o003o0000
o`0000800?l00P3o00000`000?l0o`000?l000020?l00080oh000`3o0004003o0080o`000P00o`0@
0?l00080003o0`3o00020000oaT0o`000P00o`050?l000800?l01@3o0002003o00@0o`0000<0003o
0?n0003oP000103oP0090?l000<00?l0103o000>ooooo`80o`003000o`060?l000T00?l01@3o000G
003o00/0o`001000o`030?l00080003o1@3oP006003o00D0o`002@00o`0;0?l000800?l00`3o0006
003o00D0o`001`00o`020?l000kooooo103o0005003o0080o`000P000?l00`3oP000o`000?l00002
0?n000800?l00`000?l60?n000<0o`00103oP0020?l000030?n000000?l0003o00@0003o1@3oP002
0?l000D00?l0203o00000`3oP000o`000?l000040?n00003003o003o0000o`000080o`001@000?l4
0?n000800?l00`3o00020?n000l0o`0000<0003o0?n0003oP000103oP0000`00o`00o`000?l00002
003o0080o`000P00o`000`3o0000003o0000o`020?l000@0oh000`3o00020000o`kooooo2@3oP004
0?l000D0oh000P3o00030?n000H00?l000<0003o0?n0003oP000103oP002003o00<0o`000P00o`02
0?n00080o`0000<0003o0?n0003oP000103oP0020?l000030?n0003o0000o`0000@0003o0`3oP002
0?l000@0003o1@3oP002003o0080oh000`3o00070?n00080o`000P000?l50?n000H0o`001`3oP002
0?l000<0oh001000o`020?l000D00?l00P000?l30?l00080oh000P3o000Hooooo`005_ooool2003o
01@0o`0000<00?l00?l0003o00000P00o`020?l000030000o`3o0000o`000080o`000P3oP0030?l0
00@00?l00P3o0002003o0100o`000P000?l30?l00080003o6@3o0002003o00D0o`000P00o`050?l0
00800?l0103o00000`000?l0oh000?n000040?n000T0o`000`00o`040?l000kooooo0P3o000<003o
00H0o`002@00o`050?l001L00?l02`3o0004003o00<0o`000P000?l50?n000H00?l01@3o0009003o
00/0o`000P00o`030?l000H00?l01@3o0007003o0080o`003_ooool40?l000D00?l00P3o00020000
o`030?n0003o0000o`000080oh000P00o`030000o`H0oh000`3o00040?n00080o`0000<0oh000000
o`000?l010000?l50?n00080o`001@00o`080?l000030?n0003o0000o`0000@0oh0000<00?l00?l0
003o00000P3o00050000o`@0oh000P00o`030?l00080oh003`3o00000`000?l0oh000?n000040?n0
0003003o003o0000o`0000800?l00P3o0002003o00030?l000000?l0003o0080o`00103oP0030?l0
0080003o3_ooool90?n000@0o`001@3oP0020?l000<0oh001P00o`000`000?l0oh000?n000040?n0
00800?l00`3o0002003o0080oh000P3o00000`000?l0oh000?n000040?n00080o`0000<0oh000?l0
003o000010000?l30?n00080o`0010000?l50?n000800?l00P3oP0030?l000L0oh000P3o00020000
o`D0oh001P3o00070?n00080o`000`3oP004003o0080o`001@00o`020000o`<0o`000P3oP0020?l0
01Sooooo000Fooooo`800?l0503o00000`00o`00o`000?l00002003o0080o`0000<0003o0?l0003o
00000P3o0002003o00<0o`000P00o`0;0?l000800?l0:@3o0002003o00`0o`000P00o`050?l000H0
oh002@3o0002003o00D0o`003_ooool50?l000P00?l01`3o0009003o00D0o`005`00o`080?l00003
0?n0003o0000o`0000@00?l00`3o00020000o`D0oh000P00o`020?l001800?l00P3o0002003o00D0
o`000`00o`060?l000800?l01@3o0005003o0080o`000P00o`0>ooooo`@0o`000`00o`020?l00080
0?l00P000?l30?l00080oh000P00o`020000o`030?n0003o0000o`000080o`000P3oP0000`000?l0
o`000?l000020?l00080oh000`3o00060000o`D0oh000P3o0005003o00P0o`000`000?l40?n00003
003o003o0000o`0000800?l01@000?l40?n000D0o`000P3oP0070?l00080003o103o00020?n00003
0000o`3oP000oh0000@0oh000`3o0006003o00030?l000000?l0003o00H0oh001@000?l>ooooo`T0
oh000P000?l70?n000@0o`000`3oP002003o0080o`0000<0003o0?n0003oP000103oP002003o00T0
o`0000<0003o0?n0003oP0001P3oP0000`00o`00003o0000o`020000o`D0oh000P00o`020?l00080
003o2@3oP0000`00o`00o`000?l000020000o`D0oh000P3o00020000o`D0oh00103o00040?n00003
0?l0003oP000oh0000L0oh000P00o`020?n000<0o`001P00o`020?n000D0o`006?ooool001Kooooo
0P00o`0D0?l00003003o003o0000o`0000800?l00P3o00000`000?l0o`000?l000020?l000800?l0
0`3o0002003o00/0o`000P00o`0Y0?l000800?l0303o0002003o00D0o`001P3oP0090?l000800?l0
1@3o000>ooooo`D0o`002000o`070?l000T00?l01@3o000G003o00P0o`0000<0oh000?l0003o0000
1000o`030?l00080003o1@3oP002003o0080o`004P00o`020?l000800?l01@3o0003003o00H0o`00
0P00o`050?l000D00?l00P3o0002003o00kooooo103o0003003o0080o`000P00o`020000o`<0o`00
0P3oP002003o0080003o00<0oh000?l0003o00000P3o00020?n000030000o`3o0000o`000080o`00
0P3oP0030?l000H0003o1@3oP0020?l000D00?l0203o00030000o`@0oh0000<00?l00?l0003o0000
0P00o`050000o`@0oh001@3o00020?n000L0o`000P000?l40?l00080oh0000<0003o0?n0003oP000
103oP0030?l000H00?l000<0o`000000o`000?l01P3oP0050000o`kooooo2@3oP0020000o`L0oh00
103o00030?n000800?l00P3o00000`000?l0oh000?n000040?n000800?l02@3o00000`000?l0oh00
0?n000060?n00003003o00000?l0003o0080003o1@3oP002003o0080o`000P000?l90?n00003003o
003o0000o`000080003o1@3oP0020?l00080003o1@3oP0040?l000@0oh0000<0o`000?n0003oP000
1`3oP002003o0080oh000`3o0006003o0080oh001@3o000Hooooo`005_ooool2003o01L0o`000P00
o`070?l000@00?l03P3o0002003o02T0o`000P00o`0<0?l000800?l01@3o00040?n000/0o`000P00
o`050?l000kooooo1@3o0004003o00D0o`000P00o`040?l000T00?l01@3o000B003o00L0o`000P00
0?l20?l00080003o00<0oh000?l0003o00001000o`030?l00080003o1@3oP006003o00D0o`004P00
o`020?l000<00?l01P3o0002003o00D0o`002@00o`0>ooooo`@0o`0000<00?l00?l0003o00000P3o
0002003o00T0o`000P000?l00`3oP000o`000?l000090?l000800?l00`3o00020000o`80oh000P00
0?l50?n00080o`001@00o`090?l00080003o103oP0000`00o`00o`000?l00002003o00D0003o103o
P0020?l00080003o0`3oP0060?l000030000o`3oP000oh000080oh000P000?l20?n000030000o`3o
P000oh0000@0oh001@3o0004003o00030?l000000?l0003o00@0oh001@000?l20?n000kooooo0P3o
P002003o00<0o`003@3oP0030?l000@0oh000P00o`000`000?l0oh000?n000040?n000800?l000<0
003o0?l0003o00001P3oP0000`000?l0oh000?n000040?n000D0o`002@3oP0020?l00080003o2@3o
P0030?l000L0oh00103o00020000o`80oh0000<0o`000000o`000?l00P3oP0020?l00080oh000`3o
00070?n000800?l0103oP007003o00D0oh000P3o000Hooooo`005_ooool2003o01L0o`000P00o`07
0?l000@00?l03P3o0002003o02T0o`000P00o`0<0?l000800?l01@3o00040?n000/0o`000P00o`05
0?l000kooooo1@3o0004003o00D0o`000P00o`040?l000T00?l01@3o000B003o00L0o`000P000?l2
0?l00080003o00<0oh000?l0003o00001000o`030?l00080003o1@3oP006003o00D0o`004P00o`02
0?l000<00?l01P3o0002003o00D0o`002@00o`0>ooooo`@0o`0000<00?l00?l0003o00000P3o0002
003o00T0o`000P000?l00`3oP000o`000?l000090?l000800?l00`3o00020000o`80oh000P000?l5
0?n00080o`001@00o`090?l00080003o103oP0000`00o`00o`000?l00002003o00D0003o103oP002
0?l00080003o0`3oP0060?l000030000o`3oP000oh000080oh000P000?l20?n000030000o`3oP000
oh0000@0oh001@3o0004003o00030?l000000?l0003o00@0oh001@000?l20?n000kooooo0P3oP002
003o00<0o`003@3oP0030?l000@0oh000P00o`000`000?l0oh000?n000040?n000800?l000<0003o
0?l0003o00001P3oP0000`000?l0oh000?n000040?n000D0o`002@3oP0020?l00080003o2@3oP003
0?l000L0oh00103o00020000o`80oh0000<0o`000000o`000?l00P3oP0020?l00080oh000`3o0007
0?n000800?l0103oP007003o00D0oh000P3o000Hooooo`005_ooool2003o01L0o`000P00o`050?l0
00H00?l01@3o0002003o00L0o`000P00o`030?l00080003o:@3o0002003o0100o`000P3oP002003o
0100o`003_ooool50?l000@00?l01@3o0004003o0080o`002P00o`060?l000`00?l01P3o0002003o
00<0o`000P000?l20?l000<0oh000P3o0004003o00<0o`000P000?l50?n000P00?l00`3o000G003o
00H0o`000P00o`050?l000D00?l00P3o0002003o00kooooo5P3o00000`00o`00o`000?l000070?l0
00@00?l00P000?l00`3o0000003o0000o`070?n000P0o`0000<00?l00?l0003o00000P00o`050?l0
0080003o0P3oP0020?l00003003o003o0000o`000080o`001@000?l40?n00080o`000P000?l30?n0
0080003o103o00000`000?l0oh000?n000020?n00080003o0P3oP0000`000?l0oh000?n000020?n0
00800?l00`3o00020?n000800?l01@3o00020?n00080o`001@000?l20?n000kooooo0P3oP002003o
00030?l0003oP000oh000080o`00103oP0000`00o`00o`000?l000040?n00080003o00<0o`000?n0
003oP0000P3oP0020?l000030000o`3oP000oh0000@0oh000P00o`030?l000@0oh000P00o`000`00
0?l0oh000?n000040?n00080o`0000<0oh000?l0003o00000P3oP0020?l00080oh0000<0o`000?n0
003oP0000P3o000;0?n000<0o`000P000?l50?n000H0o`000P3oP0070?l00080oh0000<00?l00?n0
003oP0000P3oP0020?l000<0oh000P00o`070?n000@00?l00P3o00050?n001Sooooo000Fooooo`@0
0?l05@3o0002003o00D0o`001P00o`0S0?l000800?l04P3o0002003o00D0o`000P00o`060?l00003
003o003o0000o`0000T0o`000P00o`030?l000800?l02@3o0002003o00kooooo1@3o0004003o00@0
o`004@00o`060?l000`00?l0103o00020?n000<00?l00P3o00020000o`80o`000`3oP0020?l000@0
0?l000<0o`00003o0000o`000P000?l50?n000@00?l00P3o0002003o00030?l00000o`000?l001L0
0?l01P3o0005003o0080o`001@00o`020?l000800?l03_ooool5003o00@0o`000P00o`050?l00080
003o0P3o00020?n000<00?l01`3o0002003o0080o`000P000?l00`3o0000003o0000o`060?n000`0
o`001000o`020000o`D0oh000P3o00000`00o`00o`000?l000020?l00080003o0P3oP0000`000?l0
oh000?n000020?n00080o`000P000?l>0?l00080003o1`3oP0020?l000030000o`3oP000oh0000@0
oh001`3o00020?n000D0003o0P3oP00>ooooo`800?l00P3oP0000`3o0000oh000?n000070?n00080
o`001P3oP0000`3o0000oh000?n000020?n00080o`0000<0003o0?n0003oP0001P3oP0000`000?l0
oh000?n000040?n00080o`001`3oP0020?l000030?n0003o0000o`000080oh000P00o`030?l000@0
oh000P000?l70?n000800?l000<0003o0?n0003oP0000P3oP0040?l000030?n0003o0000o`0000@0
o`000P3oP0000`00o`00o`000?l000020000o`80o`001`3oP003003o0080oh001000o`020?n00003
003o003oP000oh0000@00?l00P000?l50?n001Sooooo000Fooooo`@00?l05@3o0002003o00D0o`00
1P00o`0S0?l000800?l04P3o0002003o00D0o`000P00o`060?l00003003o003o0000o`0000T0o`00
0P00o`030?l000800?l02@3o0002003o00kooooo1@3o0004003o00@0o`004@00o`060?l000`00?l0
103o00020?n000<00?l00P3o00020000o`80o`000`3oP0020?l000@00?l000<0o`00003o0000o`00
0P000?l50?n000@00?l00P3o0002003o00030?l00000o`000?l001L00?l01P3o0005003o0080o`00
1@00o`020?l000800?l03_ooool5003o00@0o`000P00o`050?l00080003o0P3o00020?n000<00?l0
1`3o0002003o0080o`000P000?l00`3o0000003o0000o`060?n000`0o`001000o`020000o`D0oh00
0P3o00000`00o`00o`000?l000020?l00080003o0P3oP0000`000?l0oh000?n000020?n00080o`00
0P000?l>0?l00080003o1`3oP0020?l000030000o`3oP000oh0000@0oh001`3o00020?n000D0003o
0P3oP00>ooooo`800?l00P3oP0000`3o0000oh000?n000070?n00080o`001P3oP0000`3o0000oh00
0?n000020?n00080o`0000<0003o0?n0003oP0001P3oP0000`000?l0oh000?n000040?n00080o`00
1`3oP0020?l000030?n0003o0000o`000080oh000P00o`030?l000@0oh000P000?l70?n000800?l0
00<0003o0?n0003oP0000P3oP0040?l000030?n0003o0000o`0000@0o`000P3oP0000`00o`00o`00
0?l000020000o`80o`001`3oP003003o0080oh001000o`020?n00003003o003oP000oh0000@00?l0
0P000?l50?n001Sooooo000Fooooo`@00?l01@3o0002003o00<0o`000P00o`090?l000@00?l01`3o
0002003o02<0o`000P00o`0B0?l000800?l01@3o0002003o0100o`000P3oP00@0?l000800?l03_oo
ool4003o00030?l00000o`000?l000800?l01@3o0004003o0080o`002P00o`060?l000`00?l00P00
0?l40?l000T00?l00P3o00000`3oP0000?l0003o00020?l000D00?l00P000?l50?n000@00?l01@3o
000I003o00P0o`002P00o`040?l000kooooo0P00o`020?l00003003o003o0000o`0000T0o`000P00
0?l40?l00003003o003o0000o`0000L0o`000P00o`050?l00080003o1P3oP0070?l000800?l00`3o
0004003o0080003o1@3oP0070?l00080003o1`3oP0020?l00080003o303o0002003o0080003o0`3o
P0020?l00080oh000`3o00020?n00080o`000P3oP0090?l00080oh0000<0003o0?n0003oP0000P00
0?l>ooooo`800?l00P3oP0000`3o0000003o0000o`070?n00080o`000P3oP0020?l00080oh0000<0
o`000?n0003oP0000P3oP002003o00030?l000000?l0003o00H0oh0000<0003o0?n0003oP000103o
P0020?l000030000o`3oP000oh0000@0oh000P3o00000`000?l0oh000?n000040?n00080003o1@3o
P0030?l000H0oh002`3o00000`3oP000003o0000o`040?l00080oh0000<00?l00?l0003o00000P00
0?l70?n000D00?l00P3oP0020?l000800?l01@3oP0020?l000800?l00P000?l50?n001Sooooo000F
ooooo`@00?l01@3o0002003o00<0o`000P00o`090?l000@00?l01`3o0002003o02<0o`000P00o`0B
0?l000800?l01@3o0002003o0100o`000P3oP00@0?l000800?l03_ooool4003o00030?l00000o`00
0?l000800?l01@3o0004003o0080o`002P00o`060?l000`00?l00P000?l40?l000T00?l00P3o0000
0`3oP0000?l0003o00020?l000D00?l00P000?l50?n000@00?l01@3o000I003o00P0o`002P00o`04
0?l000kooooo0P00o`020?l00003003o003o0000o`0000T0o`000P000?l40?l00003003o003o0000
o`0000L0o`000P00o`050?l00080003o1P3oP0070?l000800?l00`3o0004003o0080003o1@3oP007
0?l00080003o1`3oP0020?l00080003o303o0002003o0080003o0`3oP0020?l00080oh000`3o0002
0?n00080o`000P3oP0090?l00080oh0000<0003o0?n0003oP0000P000?l>ooooo`800?l00P3oP000
0`3o0000003o0000o`070?n00080o`000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP002
003o00030?l000000?l0003o00H0oh0000<0003o0?n0003oP000103oP0020?l000030000o`3oP000
oh0000@0oh000P3o00000`000?l0oh000?n000040?n00080003o1@3oP0030?l000H0oh002`3o0000
0`3oP000003o0000o`040?l00080oh0000<00?l00?l0003o00000P000?l70?n000D00?l00P3oP002
0?l000800?l01@3oP0020?l000800?l00P000?l50?n001Sooooo000Fooooo`T0o`000P00o`0I0?l0
00800?l0=`3o0002003o0080o`000P00o`000`3o00000?l0003o00070?l00080003o103o00000`00
0?l0o`000?l000020?n00100o`000P00o`0>ooooo`@00?l000<0o`00003o0000o`002`00o`020?l0
00T00?l01`3o000<003o0080003o103o0009003o00<0o`000P00o`020?l000D00?l00P000?l50?n0
00@00?l01@3o000I003o00P0o`002P00o`020?l000800?l03_ooool7003o0080o`000P00o`050?l0
0080oh000P3o0002003o00X0o`000P00o`070?l000H0oh000`3o0002003o0080o`002@00o`020000
o`D0oh001`3o00020000o`/0oh0000<00?l00?l0003o0000103o00020?n000<0o`000P00o`020?l0
00800?l000<0o`00003o0000o`000P000?l30?l000800?l01P3o00000`000?l0o`000?l000020?l0
0080003o0`3o00040000o`kooooo1@3o00090?n000800?l00P3oP0040?l000D0oh000`3o00020000
o`80oh001@3o00060?n00080o`0000<0003o0?n0003oP000103oP0030?l000H0oh000P000?l70?n0
00030?l0003oP000oh0000@0oh000P3o00000`3oP000o`000?l000020000o`80oh000`3o00040000
o`80o`000`3oP0020?l00080003o2@3oP003003o00@0o`001000o`000`3o0000oh000?n000020?l0
0080oh000P000?l00`3oP000o`000?l000020?n001Sooooo000Fooooo`T0o`000P00o`0I0?l00080
0?l0=`3o0002003o0080o`000P00o`000`3o00000?l0003o00070?l00080003o103o00000`000?l0
o`000?l000020?n00100o`000P00o`0>ooooo`@00?l000<0o`00003o0000o`002`00o`020?l000T0
0?l01`3o000<003o0080003o103o0009003o00<0o`000P00o`020?l000D00?l00P000?l50?n000@0
0?l01@3o000I003o00P0o`002P00o`020?l000800?l03_ooool7003o0080o`000P00o`050?l00080
oh000P3o0002003o00X0o`000P00o`070?l000H0oh000`3o0002003o0080o`002@00o`020000o`D0
oh001`3o00020000o`/0oh0000<00?l00?l0003o0000103o00020?n000<0o`000P00o`020?l00080
0?l000<0o`00003o0000o`000P000?l30?l000800?l01P3o00000`000?l0o`000?l000020?l00080
003o0`3o00040000o`kooooo1@3o00090?n000800?l00P3oP0040?l000D0oh000`3o00020000o`80
oh001@3o00060?n00080o`0000<0003o0?n0003oP000103oP0030?l000H0oh000P000?l70?n00003
0?l0003oP000oh0000@0oh000P3o00000`3oP000o`000?l000020000o`80oh000`3o00040000o`80
o`000`3oP0020?l00080003o2@3oP003003o00@0o`001000o`000`3o0000oh000?n000020?l00080
oh000P000?l00`3oP000o`000?l000020?n001Sooooo000Fooooo`T0o`000P00o`090?l000800?l0
3P3o0002003o00L0o`000P00o`0G0?l000800?l05@3o0002003o00D0o`000P00o`0=0?l000030000
o`3o0000o`0000/0o`000P00o`050?l000800?l03_ooool4003o00030?l00000o`000?l000/00?l0
0P3o0009003o00<0o`000P3oP0020?l000`00?l00P000?l40?l000T00?l00P3o0003003o0080o`00
1@00o`020000o`D0oh001000o`050?l001T00?l0203o000>003o00kooooo2`00o`050?l000800?l0
0P3o0002003o00L0o`001@00o`090?l00080oh000P000?l00`3o0000oh000?n00002003o0080o`00
0`00o`020?l000800?l00P3o00020000o`D0oh002@3o00020?n000030?l000000?l0003o00L0oh00
0P000?l60?n000<0o`001P00o`030?l00080003o0`3o0004003o00D0o`00103oP0050?l000@0003o
3_ooool50?l00080oh000P000?l50?n000@00?l00P000?l70?n000<0o`00103oP0020?l00080003o
00<0o`000?n0003oP0000P3oP0040?l000<0oh000P3o00020?n00080o`0000<0003o0?n0003oP000
0P3oP002003o0080003o00<0oh000?l0003o00002`3oP0020?l000030?n0003o0000o`0000800?l0
0P3oP0050?l00080003o0P3oP0020000o`D0oh000P000?l70?n000800?l000<0oh000?l0003o0000
1000o`030?l00080oh000P3o00020?n00080o`0000<0oh000?l0003o00000P3o000Hooooo`005_oo
ool90?l000800?l02@3o0002003o00h0o`000P00o`070?l000800?l05`3o0002003o01D0o`000P00
o`050?l000800?l03@3o00000`000?l0o`000?l0000;0?l000800?l01@3o0002003o00kooooo1000
o`000`3o00000?l0003o000;003o0080o`002@00o`030?l00080oh000P3o000<003o0080003o103o
0009003o0080o`000`00o`020?l000D00?l00P000?l50?n000@00?l01@3o000I003o00P0o`003P00
o`0>ooooo`/00?l01@3o0002003o0080o`000P00o`070?l000D00?l02@3o00020?n00080003o00<0
o`000?n0003oP0000P00o`020?l000<00?l00P3o0002003o0080o`000P000?l50?n000T0o`000P3o
P0000`3o0000003o0000o`070?n00080003o1P3oP0030?l000H00?l00`3o00020000o`<0o`001000
o`050?l000@0oh001@3o00040000o`kooooo1@3o00020?n00080003o1@3oP004003o0080003o1`3o
P0030?l000@0oh000P3o00020000o`030?l0003oP000oh000080oh00103o00030?n00080o`000P3o
P0020?l000030000o`3oP000oh000080oh000P00o`020000o`030?n0003o0000o`0000/0oh000P3o
00000`3oP000o`000?l00002003o0080oh001@3o00020000o`80oh000P000?l50?n00080003o1`3o
P002003o00030?n0003o0000o`0000@00?l00`3o00020?n00080o`000P3oP0020?l000030?n0003o
0000o`000080o`006?ooool001Kooooo903o0002003o00L0o`000P00o`000`3o00000?l0003o000?
0?l00003003o003o0000o`000200o`000P3oP00P0?l000800?l00P3o000>ooooo`d00?l000<0o`00
003o0000o`000P00o`020?l000T00?l000<0o`000?n0003oP0000P3oP0020?l000`00?l01P3o0009
003o0080o`002P00o`060?l000030?n00000o`000?l000800?l01@3o0006003o0080o`0000<00?l0
0?l0003o00001000o`020?l000`00?l02@3o0009003o00kooooo1`00o`020?l000800?l02@3o0002
003o00030?l000000?l0003o00@0o`001@00o`050?l00080003o103oP0020000o`030?l0003oP000
oh0000800?l00P3o0002003o00L0o`000P000?l50?n000<0o`001000o`050?l000H0003o0`3oP002
0000o`H0oh004@3o0004003o00D0o`00103oP0020000o`<0oh0010000?l>ooooo`80oh000`3o0002
0?n00080003o1`3oP0020?l00080003o1@3oP002003o00<0o`00103oP0020?l00080003o1@3oP002
0?l000D0oh000P3o00020?n00080o`0000<0003o0?n0003oP000103oP0050?l000@0oh0000<0o`00
0?n0003oP000103oP0020?l000030?n0003o0000o`0000@0oh001@3o00020000o`80oh000P000?l:
0?n000800?l0103o00030?n000@00?l00`3o00090?n000@0o`006?ooool001Kooooo0P00o`020?l0
0003003o003o0000o`000280o`000P00o`090?l000800?l02`3o00000`00o`00o`000?l000090?l0
0080oh005@3o0002003o01H0o`0000<0003o0?l0003o00001`3o0002003o0080o`003_oooolM003o
00L0o`003000o`060?l000<00?l00P3o0009003o0080o`000`00o`060?l000800?l000<0o`00003o
0000o`001P00o`000`3o00000?l0003o0004003o0080o`0000<00?l00?l0003o00001000o`020?l0
00`00?l03@3o0005003o00kooooo0P00o`020?l000<00?l01P3o00000`00o`00o`000?l000040?l0
00800?l02P3o0002003o00D0o`000P000?l90?n000H00?l01@3o0002003o0080003o1@3oP0030?l0
00@00?l01@3o00020?n000@0003o0`3oP0020000o`H0oh000`00o`0=0?l000<00?l00P3o0002003o
00D0003o0P3oP0020000o`<0oh0010000?l>ooooo`80oh000P00o`000`3o00000?l0003o0002003o
0080o`000`00o`020?n000@0o`001@3oP002003o0080o`001@3oP0020?l000<0003o2`3oP006003o
00<0o`00103oP0020000o`<0o`001`3oP0040?l000<0oh000P3o00040?n00080003o0`3o00020?n0
00L0003o1`3oP002003o0080003o0P3o00030?n000H0o`001@3oP0020?l00080oh000`000?l20?n0
01Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l0000R0?l000800?l02@3o0002003o00/0
o`0000<00?l00?l0003o00002@3o00020?n001D0o`000P00o`0F0?l000030000o`3o0000o`0000L0
o`000P00o`020?l000kooooo7@00o`070?l000`00?l01P3o0003003o0080o`002@00o`020?l000<0
0?l01P3o0002003o00030?l00000o`000?l000H00?l000<0o`00003o0000o`001000o`020?l00003
003o003o0000o`0000@00?l00P3o000<003o00d0o`001@00o`0>ooooo`800?l00P3o0003003o00H0
o`0000<00?l00?l0003o0000103o0002003o00X0o`000P00o`050?l00080003o2@3oP006003o00D0
o`000P00o`020000o`D0oh000`3o0004003o00D0o`000P3oP0040000o`<0oh000P000?l60?n000<0
0?l03@3o0003003o0080o`000P00o`050000o`80oh000P000?l30?n000@0003o3_ooool20?n00080
0?l000<0o`00003o0000o`000P00o`020?l000<00?l00P3oP0040?l000D0oh000P00o`020?l000D0
oh000P3o00030000o`/0oh001P00o`030?l000@0oh000P000?l30?l000L0oh00103o00030?n00080
o`00103oP0020000o`<0o`000P3oP0070000o`L0oh000P00o`020000o`80o`000`3oP0060?l000D0
oh000P3o00020?n000<0003o0P3oP00Hooooo`005_ooool2003o0080o`000`00o`0P0?l000800?l0
2`3o0002003o00/0o`0000<00?l00?l0003o00002`3o00020000o`<0o`000P3oP00D0?l000800?l0
1`3o00000`3oP000o`000?l000020000o`@0o`0000<0003o0?l0003o00001P3o0003003o0080o`00
3_oooolM003o00T0o`002P00o`060?l000<00?l00P3o000=003o00L0o`000P00o`030?l000800?l0
0P3oP009003o00D0o`004P00o`0=0?l000D00?l03_ooool20?n00080o`0000<00?l00?l0003o0000
2@3o0006003o00X0o`001000o`020000o`030?n000000?l0003o00T0oh001P00o`050?l000800?l0
0P3o00000`3oP000o`000?l00004003o00<0o`001000o`020000o`<0oh000P000?l50?n000H0o`00
0P3oP003003o00@0o`000P000?l30?n000@0o`000`00o`040?l000L0003o1@3oP0020000o`80oh00
3_ooool40?n00003003o003o0000o`000080oh000P3o00020?n000030?l0003oP000oh000080oh00
0P3o00030?n000@00?l01@3o00020?n000D0003o103oP0020?l000D0oh000P3o0004003o00<0o`00
1P3oP0000`3o0000003o0000o`020?n00080o`000`00o`060?n000030000o`3oP000oh000080o`00
103oP0000`3o0000oh000?n00002003o0080o`000`000?l40?n000L0o`000P000?l50?n000@0o`00
0P000?l50?n000@0o`001@000?lHooooo`005_ooool2003o0080o`000`00o`0P0?l000800?l02`3o
0002003o00/0o`0000<00?l00?l0003o00002`3o00020000o`<0o`000P3oP00D0?l000800?l01`3o
00000`3oP000o`000?l000020000o`@0o`0000<0003o0?l0003o00001P3o0003003o0080o`003_oo
oolM003o00T0o`002P00o`060?l000<00?l00P3o000=003o00L0o`000P00o`030?l000800?l00P3o
P009003o00D0o`004P00o`0=0?l000D00?l03_ooool20?n00080o`0000<00?l00?l0003o00002@3o
0006003o00X0o`001000o`020000o`030?n000000?l0003o00T0oh001P00o`050?l000800?l00P3o
00000`3oP000o`000?l00004003o00<0o`001000o`020000o`<0oh000P000?l50?n000H0o`000P3o
P003003o00@0o`000P000?l30?n000@0o`000`00o`040?l000L0003o1@3oP0020000o`80oh003_oo
ool40?n00003003o003o0000o`000080oh000P3o00020?n000030?l0003oP000oh000080oh000P3o
00030?n000@00?l01@3o00020?n000D0003o103oP0020?l000D0oh000P3o0004003o00<0o`001P3o
P0000`3o0000003o0000o`020?n00080o`000`00o`060?n000030000o`3oP000oh000080o`00103o
P0000`3o0000oh000?n00002003o0080o`000`000?l40?n000L0o`000P000?l50?n000@0o`000P00
0?l50?n000@0o`001@000?lHooooo`005_ooool2003o0080o`000`00o`0?0?l00003003o003o0000
o`0000h0o`000P3oP00;0?l000800?l04`3o00020?n000@0o`000P000?l30?l00080oh000P000?lE
0?l000800?l01`3o00020000o`h0o`000P00o`020?l000kooooo0P00o`030?l001@00?l00P3o0002
003o00T0o`002P00o`060?l000L00?l01@3o0002003o0080o`000P00o`050?l00080oh000P00o`05
0?l000/00?l00P3o00000`00o`00o`000?l0000B003o00D0o`000P00o`060?l00003003o003o0000
o`000080o`003_ooool20?n00080o`0000<00?l00?l0003o00002@3o0006003o00030?l00000o`00
0?l000800?l01@3o0002003o00@0o`0000<0oh000000o`000?l00P3oP0020?l000D0oh001P00o`05
0?l000800?l00P3o00000`3oP000o`000?l00004003o00<0o`001000o`020000o`D0oh000P3o0003
0?n000@0o`001000o`000`3o00000?l0003o00040?l00080003o00<0oh000000o`000?l0103oP000
0`00o`00o`000?l000060?l000030000o`3oP000oh000080003o103oP0000`3o0000003o0000o`02
0000o`kooooo0P00o`050?l00080oh000P3o00020?n000030?l0003oP000oh0000L0oh001000o`05
0?l000800?l00P000?l70?n000@0o`0000<0oh000?l0003o00000P3o0004003o00<0o`002`3oP002
0?l000030?n0003o0000o`000080003o103oP0000`000?l0oh000?n000060?n00003003o003oP000
oh0000800?l00P3o00020?n000030000o`3oP000oh000080oh00103o00000`000?l0oh000?n00002
0?n00080003o0`3oP0020?l00080oh000P000?l50?n000@0o`000`000?l20?n001Sooooo000Foooo
o`800?l00P3o0003003o00l0o`0000<00?l00?l0003o00003P3o00020?n000/0o`000P00o`0C0?l0
0080oh00103o00020000o`<0o`000P3oP0020000oaD0o`000P00o`070?l00080003o3P3o0002003o
0080o`003_ooool2003o00<0o`005000o`020?l000800?l02@3o000:003o00H0o`001`00o`050?l0
00800?l00P3o0002003o00D0o`000P3oP002003o00D0o`002`00o`020?l00003003o003o0000o`00
01800?l01@3o0002003o00H0o`0000<00?l00?l0003o00000P3o000>ooooo`80oh000P3o00000`00
o`00o`000?l000090?l000H00?l000<0o`00003o0000o`000P00o`050?l000800?l0103o00000`3o
P000003o0000o`020?n00080o`001@3oP006003o00D0o`000P00o`020?l000030?n0003o0000o`00
00@00?l00`3o0004003o0080003o1@3oP0020?l000<0oh00103o0004003o00030?l00000o`000?l0
00@0o`000P000?l00`3oP000003o0000o`040?n00003003o003o0000o`0000H0o`0000<0003o0?n0
003oP0000P000?l40?n000030?l000000?l0003o0080003o3_ooool2003o00D0o`000P3oP0020?l0
0080oh0000<0o`000?n0003oP0001`3oP004003o00D0o`000P00o`020000o`L0oh00103o00000`3o
P000o`000?l000020?l000@00?l00`3o000;0?n00080o`0000<0oh000?l0003o00000P000?l40?n0
00030000o`3oP000oh0000H0oh0000<00?l00?n0003oP0000P00o`020?l00080oh0000<0003o0?n0
003oP0000P3oP0040?l000030000o`3oP000oh000080oh000P000?l30?n00080o`000P3oP0020000
o`D0oh00103o00030000o`80oh006?ooool001Kooooo103o0003003o00l0o`0000<00?l00?l0003o
00002@3o00020000o`<0o`000P3oP00O0?l000030000o`3oP000oh000080oh002`3o0002003o01<0
o`000P00o`0@0?l00080003o0P3oP0030?l000800?l00P3o000>ooooo`800?l00P3o000I003o00T0
o`002P00o`060?l000L00?l01@3o0002003o00T0o`000P3oP002003o00D0o`001@00o`060?l00080
0?l00`3o000B003o00D0o`000P00o`0;0?l000kooooo103o00000`00o`00o`000?l000090?l00080
0?l01@3o0002003o0080o`000P000?l50?n000@0o`0000<00?l00?l0003o00000P000?l50?n000H0
0?l03P3o0004003o00L0o`000P000?l50?n000@0o`0000<0oh000?l0003o00000P3o0002003o00T0
o`001@000?l40?n00003003o003o0000o`000080003o0P3o0002003o00030000o`3oP000oh0000L0
oh0010000?l>ooooo`L0o`000P3oP0020?l00080oh0000<0003o0?n0003oP000103oP0020000o`03
0?n0003o0000o`0000800?l01@3o00020?n00080003o0`3oP0060?l00080oh001@3o0004003o00<0
o`002`3oP0030?l000P0oh0000<0003o0?l0003o00001P3oP0000`3o0000oh000?n00004003o00<0
003o103oP0020000o`80oh0000<0003o0?n0003oP0002`3oP0020000o`D0oh00103o00000`000?l0
oh000?n000020?n001Sooooo000Fooooo`@0o`000`00o`0?0?l00003003o003o0000o`0000T0o`00
0P000?l30?l00080oh007`3o00000`000?l0oh000?n000020?n000/0o`000P00o`0C0?l000800?l0
403o00020000o`80oh000`3o0002003o0080o`003_ooool2003o0080o`006@00o`090?l000X00?l0
1P3o0007003o00D0o`000P00o`090?l00080oh000P00o`050?l000D00?l01P3o0002003o00<0o`00
4P00o`050?l000800?l02`3o000>ooooo`@0o`0000<00?l00?l0003o00002@3o0002003o00D0o`00
0P00o`020?l00080003o1@3oP0040?l00003003o003o0000o`000080003o1@3oP006003o00h0o`00
1000o`070?l00080003o1@3oP0040?l000030?n0003o0000o`000080o`000P00o`090?l000D0003o
103oP0000`00o`00o`000?l000020000o`80o`000P00o`000`000?l0oh000?n000070?n000@0003o
3_ooool70?l00080oh000P3o00020?n000030000o`3oP000oh0000@0oh000P000?l00`3oP000o`00
0?l00002003o00D0o`000P3oP0020000o`<0oh001P3o00020?n000D0o`001000o`030?l000/0oh00
0`3o00080?n000030000o`3o0000o`0000H0oh0000<0o`000?n0003oP0001000o`030000o`@0oh00
0P000?l20?n000030000o`3oP000oh0000/0oh000P000?l50?n000@0o`0000<0003o0?n0003oP000
0P3oP00Hooooo`005_ooool70?l000800?l01`3o00020000o`@0o`0000<00?l00?l0003o00002@3o
00020000o`<0o`000P3oP0060?l00003003o003o0000o`0001T0o`000P3oP00;0?l000800?l01@3o
0002003o00`0o`000P00o`0K0?l000kooooo0P00o`020?l00003003o003o0000o`0001H00?l02@3o
000G003o0080003o0`3o0002003o00D0o`000P000?l20?l00080oh000P00o`030?l000L00?l02`3o
0004003o0080o`003000o`050?l000800?l02@3o00020?n000kooooo0P00o`0>0?l000800?l02@3o
00020000o`D0oh00103o00000`00o`00o`000?l000020?l000L0oh001000o`0;0?l000030?n0003o
0000o`0000@00?l01@3o00040000o`D0oh000P3o0002003o00030000o`3o0000o`000080o`000P00
o`050?l00080003o0P3oP0050000o`@0oh0000<00?l00?l0003o00000P000?l40?n000030000o`3o
P000oh000080o`001@3oP0040000o`kooooo0P3o000;0?n000030000o`3oP000oh0000@0oh000P00
0?l00`3oP0000?l0003o0002003o00D0o`000P00o`090?l000@0oh001@3o00050?n000P0o`0000<0
oh00003o0000o`000P3o00020000o`T0oh0000<0003o0?n0003oP0001P3oP0030?l00080oh000P00
o`020?l000<0oh000P3o00020000o`D0oh000P3o00020?n000030?l000000?l0003o00H0oh0000<0
o`000?n0003oP0001P3oP0000`000?l0oh000?n000020?n001Sooooo000Fooooo`L0o`000P00o`07
0?l00080003o103o00000`00o`00o`000?l000040?l000030000o`3o0000o`000080oh000P000?lI
0?l000800?l06@3o0002003o00D0o`000P00o`020?l00003003o003o0000o`0000H0o`000`00o`0>
0?l00080oh002`3o000>ooooo`@0o`0000<00?l00?l0003o00005P00o`050?l000800?l00P3o000G
003o0080003o0`3o00020?n00080003o0`3o00020000o`@0o`003000o`060?l000800?l00`3o000@
003o00L0o`000P00o`0;0?l000kooooo0P3oP00@0?l000@00?l01@3o00020000o`D0oh00103o0000
0`3oP000o`000?l000020000o`L0oh001000o`0;0?l000<0oh001000o`050?l000@0003o0`3oP004
0?l000800?l000<0003o0?l0003o00000P3o0002003o00D0o`000P000?l20?n000D0003o103oP003
0?l00080003o103oP0070?l00080oh0000<0o`000000o`000?l00P000?l>ooooo`80o`001@3oP002
0?l000L0oh000P000?l20?n00080003o00<0oh00003o0000o`000P00o`030?l000H0oh000P000?l0
0`3o0000oh000?n000020?n00080o`000P3oP0000`3o0000003o0000o`070?n00080o`00103oP007
0?l00080003o00<0oh000000o`000?l00P3oP0020000o`D0oh000P3o00040?n000<0o`000P3oP002
003o0080o`000`3oP0020?l00080003o1@3oP002003o0080oh000`3o00060?n000030?l000000?l0
003o00/0oh006?ooool001Kooooo1`3o0002003o00L0o`000P000?l40?l00003003o003o0000o`00
00@0o`0000<0003o0?l0003o00000P3oP0020000oaT0o`000P00o`0I0?l000800?l01@3o0002003o
0080o`0000<00?l00?l0003o00001P3o0003003o00h0o`000P3oP00;0?l000kooooo103o00000`00
o`00o`000?l0000F003o00D0o`000P00o`020?l001L00?l00P000?l30?l00080oh000P000?l30?l0
0080003o103o000<003o00H0o`000P00o`030?l001000?l01`3o0002003o00/0o`003_ooool20?n0
0100o`001000o`050?l00080003o1@3oP0040?l000030?n0003o0000o`000080003o1`3oP004003o
00/0o`000`3oP004003o00D0o`0010000?l30?n000@0o`000P00o`000`000?l0o`000?l000020?l0
00800?l01@3o00020000o`80oh001@000?l40?n000<0o`000P000?l40?n000L0o`000P3oP0000`3o
0000003o0000o`020000o`kooooo0P3o00050?n00080o`001`3oP0020000o`80oh000P000?l00`3o
P0000?l0003o0002003o00<0o`001P3oP0020000o`030?l0003oP000oh000080oh000P3o00020?n0
00030?l000000?l0003o00L0oh000P3o00040?n000L0o`000P000?l00`3oP000003o0000o`020?n0
0080003o1@3oP0020?l000@0oh000`3o00020?n000800?l00P3o00030?n00080o`000P000?l50?n0
00800?l00P3oP0030?l000H0oh0000<0o`000000o`000?l02`3oP00Hooooo`005_ooool70?l00080
0?l01@3o0002003o00H0o`0000<00?l00?l0003o0000103o00000`000?l0o`000?l000020?l00080
003o903o00000`000?l0o`000?l000040?n000<0o`000P000?l40?l000800?l01@3o0002003o00/0
o`000`00o`0>0?l00080oh001P3o00000`00o`00o`000?l000020?l000kooooo103o00000`00o`00
o`000?l0000I003o0080o`006`00o`020000o`<0o`000P3oP0020000o`80o`000`3oP0040?l000`0
0?l01P3o0002003o00D0o`003P00o`060?l000<00?l00P3o0002003o00L0o`003_ooool2003o00T0
o`000P00o`050?l000@00?l01@3o00020000o`<0oh001P3o00000`3oP000o`000?l000020?l00080
003o1@3oP0020?l000800?l05@3o00020?n00080003o1`3oP0020?l000800?l00`3o0004003o00L0
o`000P3oP0050000o`@0oh000`3o00060?n00003003o003o0000o`000080003o1@3oP0040000o`ko
oooo1@3oP0020?l00080003o0P3o00050?n00080003o1@3oP006003o00030000o`3o0000o`0000@0
oh000P000?l50?n00080o`000`3oP0020000o`L0oh000P000?l60?n000030?l0003oP000oh0000@0
o`001@3oP0020000o`D0oh00103o00030?n00080o`000P3oP0020?l00080003o0`3oP0040000o`D0
oh000P00o`020?n000030?l0003oP000oh000080oh000P000?l20?n000030?l000000?l0003o00H0
oh0000<0003o0?l0003o00000P3oP00Hooooo`005_ooool70?l000800?l01@3o0002003o00H0o`00
00<00?l00?l0003o0000103o00000`000?l0o`000?l000020?l00080003o903o00000`000?l0o`00
0?l000040?n000<0o`000P000?l40?l000800?l01@3o0002003o00/0o`000`00o`0>0?l00080oh00
1P3o00000`00o`00o`000?l000020?l000kooooo103o00000`00o`00o`000?l0000I003o0080o`00
6`00o`020000o`<0o`000P3oP0020000o`80o`000`3oP0040?l000`00?l01P3o0002003o00D0o`00
3P00o`060?l000<00?l00P3o0002003o00L0o`003_ooool2003o00T0o`000P00o`050?l000@00?l0
1@3o00020000o`<0oh001P3o00000`3oP000o`000?l000020?l00080003o1@3oP0020?l000800?l0
5@3o00020?n00080003o1`3oP0020?l000800?l00`3o0004003o00L0o`000P3oP0050000o`@0oh00
0`3o00060?n00003003o003o0000o`000080003o1@3oP0040000o`kooooo1@3oP0020?l00080003o
0P3o00050?n00080003o1@3oP006003o00030000o`3o0000o`0000@0oh000P000?l50?n00080o`00
0`3oP0020000o`L0oh000P000?l60?n000030?l0003oP000oh0000@0o`001@3oP0020000o`D0oh00
103o00030?n00080o`000P3oP0020?l00080003o0`3oP0040000o`D0oh000P00o`020?n000030?l0
003oP000oh000080oh000P000?l20?n000030?l000000?l0003o00H0oh0000<0003o0?l0003o0000
0P3oP00Hooooo`005_ooool2003o00D0o`000P00o`0I0?l000800?l06@3o0002003o00L0o`000P3o
P0000`000?l0o`000?l000020?n000D0o`000P00o`040?l000800?l01@3o0002003o00/0o`0000<0
0?l00?l0003o00002`3o00020000o`L0o`000P00o`050?l000kooooo103o00000`00o`00o`000?l0
000f003o0080003o0`3o00020?n00080003o1@3oP0020?l000h00?l0103o0004003o00D0o`003P00
o`060?l000T00?l01@3o000>ooooo`800?l02@3o0002003o00h0o`000P000?l00`3oP000o`000?l0
00040000o`80o`000`3oP0020?l000D0oh000P00o`020?l000800?l00P3o00000`00o`00o`000?l0
000=0?l000030?n0003o0000o`0000L0oh000P000?l60?n000<0o`001P00o`050?l00080oh000`00
0?l60?n000<0o`000P3oP0020?l00080oh0000<0o`00003o0000o`000P000?l50?n000@0003o3_oo
ool50?n00080o`000P000?l50?n000800?l00P000?l50?n000H00?l000<0003o0?n0003oP000103o
P0020?l000h0oh000P3o00020?n00003003o003o0000o`000080oh001@3o00020?n00080o`000`3o
P0020?l00080oh000P000?l50?n000@0o`001`3oP0020?l000<0oh000P3o00040000o`D0oh000P00
o`020?n000030?l0003oP000oh0000@0o`000`3oP0020000o`H0oh0000<0003o0?l0003o00000P3o
P00Hooooo`005_ooool2003o00D0o`000P00o`0I0?l000800?l06@3o0002003o00L0o`000P3oP000
0`000?l0o`000?l000020?n000D0o`000P00o`040?l000800?l01@3o0002003o00/0o`0000<00?l0
0?l0003o00002`3o00020000o`L0o`000P00o`050?l000kooooo103o00000`00o`00o`000?l0000f
003o0080003o0`3o00020?n00080003o1@3oP0020?l000h00?l0103o0004003o00D0o`003P00o`06
0?l000T00?l01@3o000>ooooo`800?l02@3o0002003o00h0o`000P000?l00`3oP000o`000?l00004
0000o`80o`000`3oP0020?l000D0oh000P00o`020?l000800?l00P3o00000`00o`00o`000?l0000=
0?l000030?n0003o0000o`0000L0oh000P000?l60?n000<0o`001P00o`050?l00080oh000`000?l6
0?n000<0o`000P3oP0020?l00080oh0000<0o`00003o0000o`000P000?l50?n000@0003o3_ooool5
0?n00080o`000P000?l50?n000800?l00P000?l50?n000H00?l000<0003o0?n0003oP000103oP002
0?l000h0oh000P3o00020?n00003003o003o0000o`000080oh001@3o00020?n00080o`000`3oP002
0?l00080oh000P000?l50?n000@0o`001`3oP0020?l000<0oh000P3o00040000o`D0oh000P00o`02
0?n000030?l0003oP000oh0000@0o`000`3oP0020000o`H0oh0000<0003o0?l0003o00000P3oP00H
ooooo`005_ooool40?l000D00?l01@3o0002003o0180o`000P00o`0I0?l000800?l01`3o00020?n0
00030000o`3o0000o`0000L0o`000P00o`0;0?l000800?l02`3o00000`00o`00o`000?l0000>0?l0
0080003o103o0002003o00D0o`003_ooool2003o0080o`0000<00?l00?l0003o00001`00o`020?l0
02/00?l01`3o00040000o`D0oh00103o0002003o00030?l00000o`000?l000H0o`0000<00?l00?l0
003o0000103o0002003o00D0o`003P00o`040?l000/00?l01@3o000>ooooo`@00?l01`3o0002003o
0100o`0000<0oh000?l0003o00000P3oP0020000o`80o`001`3oP0030?l000800?l01P3o00000`00
o`00o`000?l000040?l000800?l000<0o`000000o`000?l0103o00000`3oP000o`000?l000060?n0
00030?l000000?l0003o0080003o103oP0030?l000@00?l00`3o0002003o0080o`001@000?l40?n0
00D0o`000P3oP0020?l00080oh0000<0o`00003o0000o`000P000?l50?n000@0003o3_ooool20?l0
00<0oh000P3o00020000o`D0oh000P3o00020000o`D0oh001000o`020?l000030000o`3oP000oh00
00@0oh001@3o00060?n000<0o`000P3oP005003o00H0o`001@3oP0020000o`/0oh0000<0o`000?n0
003oP0000P3o00070?n00080003o1@3oP0040000o`D0oh001000o`030?l00080oh001P3o00000`3o
P000003o0000o`020?n00080o`000P3oP0000`000?l0oh000?n000020?n001Sooooo000Fooooo`@0
o`001@00o`050?l000800?l00P3o0005003o00/0o`000P00o`090?l000800?l08`3o0002003o00H0
o`0000<00?l00?l0003o00005`3o0002003o00d0o`000P00o`050?l000kooooo0P00o`020?l00003
003o003o0000o`0000H00?l00`3o0007003o0080o`009000o`070?l00080003o0P3o00030?n000@0
o`000P00o`000`3o00000?l0003o00060?l000T00?l01@3o000>003o0080o`003@00o`050?l000ko
oooo1000o`070?l000800?l03P3o00020?n000<0o`000P3oP0020000o`<0oh000P000?l60?n000<0
0?l01P3o00000`00o`00o`000?l000040?l000<00?l01P3o00070?n000<0o`0010000?l40?n000<0
o`001000o`030?l000800?l00P3o00050000o`@0oh00303o0002003o0080003o1@3o00040000o`ko
oooo0P3o00020?n000D00?l0103o00000`3oP000o`000?l000020000o`L0oh001000o`000`000?l0
oh000?n000040?n00080003o0`3o00060?n000<0o`000P3oP0020?l000800?l000<0oh000?l0003o
0000103o00020000o`<0oh000P000?l30?l000P0oh0000<0o`000?n0003oP0000P00o`020000o`L0
oh000P3o000<0?n000@00?l00`3o00020?n000H0o`0000<0oh000?l0003o00000P3oP0020?l000D0
oh000P3o000Hooooo`005_ooool40?l000D00?l01@3o0002003o0080o`001@00o`0;0?l000800?l0
2@3o0002003o02<0o`000P00o`060?l00003003o003o0000o`0001L0o`000P00o`0=0?l000800?l0
1@3o000>ooooo`800?l00P3o00000`00o`00o`000?l00006003o00<0o`001`00o`020?l002@00?l0
1`3o00020000o`80o`000`3oP0040?l000800?l000<0o`00003o0000o`001P3o0009003o00D0o`00
3P00o`020?l000d00?l01@3o000>ooooo`@00?l01`3o0002003o00h0o`000P3oP0030?l00080oh00
0P000?l30?n00080003o1P3oP003003o00H0o`0000<00?l00?l0003o0000103o0003003o00H0o`00
1`3oP0030?l000@0003o103oP0030?l000@00?l00`3o0002003o0080o`001@000?l40?n000`0o`00
0P00o`020000o`D0o`0010000?l>ooooo`80o`000P3oP005003o00@0o`0000<0oh000?l0003o0000
0P000?l70?n000@00?l000<0003o0?n0003oP000103oP0020000o`<0o`001P3oP0030?l00080oh00
0P3o0002003o00030?n0003o0000o`0000@0o`000P000?l30?n00080003o0`3o00080?n000030?l0
003oP000oh0000800?l00P000?l70?n00080o`00303oP004003o00<0o`000P3oP0060?l000030?n0
003o0000o`000080oh000P3o00050?n00080o`006?ooool001Kooooo103o0005003o00T0o`001@00
o`0F0?l000<00?l01P3o0002003o00<0o`000P3oP002003o01<0o`000P00o`060?l00003003o003o
0000o`0000H0o`0000<0003o0?l0003o00006`3o0004003o00D0o`003_ooool2003o0080o`002@00
o`050?l000D00?l0103o0005003o00H0o`006@00o`020?l00003003o003o0000o`0000@0o`0000<0
oh000?l0003o0000103o0002003o00030?l00000o`000?l000/0o`001000o`050?l000T00?l00P3o
000B003o00D0o`003_ooool4003o00L0o`000P00o`050?l000800?l00`3o00060?n000<0o`000P3o
P0020000o`<0oh000P000?l70?n000800?l01P3o00000`00o`00o`000?l000040?l000<00?l01P3o
00000`000?l0o`000?l000040?n000800?l000<0o`000000o`000?l00P000?l40?n00003003o003o
0000o`0000@00?l00`3o0002003o0080o`001@000?l40?n000`0o`000P00o`020000o`D0o`001000
0?l>ooooo`T00?l00P3o00020?n000030000o`3oP000oh0000@0oh000`3o00040?n00080o`0000<0
003o0?n0003oP000103oP002003o00D0o`00103oP0000`3o0000oh000?n000020?n00080o`000`3o
P0080?l000D0oh000P3o00090?n000030?l00000o`000?l000@00?l02@3o00020?n000D0o`000P3o
P007003o00<0o`000P00o`040?l000<0oh00103o00020?n000<0o`000P3oP0020?l001Sooooo000F
ooooo`@0o`001@00o`090?l000D00?l05P3o0003003o00H0o`000P00o`030?l00080oh000P00o`0C
0?l000800?l01P3o00000`00o`00o`000?l000060?l000030000o`3o0000o`0001/0o`001000o`05
0?l000kooooo0P00o`020?l000T00?l01@3o0005003o00@0o`001@00o`060?l001T00?l00P3o0000
0`00o`00o`000?l000040?l000030?n0003o0000o`0000@0o`000P00o`000`3o00000?l0003o000;
0?l000@00?l01@3o0009003o0080o`004P00o`050?l000kooooo1000o`070?l000800?l01@3o0002
003o00<0o`001P3oP0030?l00080oh000P000?l30?n00080003o1`3oP002003o00H0o`0000<00?l0
0?l0003o0000103o0003003o00H0o`0000<0003o0?l0003o0000103oP002003o00030?l000000?l0
003o0080003o103oP0000`00o`00o`000?l00004003o00<0o`000P00o`020?l000D0003o103oP00<
0?l000800?l00P000?l50?l000@0003o3_ooool9003o0080o`000P3oP0000`000?l0oh000?n00004
0?n000<0o`00103oP0020?l000030000o`3oP000oh0000@0oh000P00o`050?l000@0oh0000<0o`00
0?n0003oP0000P3oP0020?l000<0oh00203o00050?n00080o`002@3oP0000`3o00000?l0003o0004
003o00T0o`000P3oP0050?l00080oh001`00o`030?l000800?l0103o00030?n000@0o`000P3oP003
0?l00080oh000P3o000Hooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000Wooooog7o00009ooo
oomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolF
o`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolG
o`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo000OoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00o`Cooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`007ooooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00o`Cooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`007ooooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool000Cooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0
00Gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00
O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0
o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo
0004o`00OaKo0?l01Ol007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1Co`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool0
07l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo
0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03
o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo
001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o06ko001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_oo
O`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000Wooooog;o0000
8oooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool001Kooooo0P000?lP0?l000D0oh00
3@3o00020?n001T0o`000P000?l50?l00080oh001@3o00060?n000030?l000000?l0003o0080o`00
103oP0030?l000@0oh000`3o00070?n00080o`00103oP0070?l000kooooo10000?l90?l000<0003o
4000o`020000o`D0o`000P000?l;003o00@0o`0000<0oh000000o`000?l01P3o00030000o`@0o`00
1@000?l20?l000L0003o2@00o`050?l000P0003o1@00o`030?l000H0003o2@3o00070000o`kooooo
0P3o00020000o`030?l00000o`000?l001000?l00P000?lT003o00@0o`001@000?l30?l000@0003o
0P3o00020000o``00?l00P3o00020000o`L0o`001@00o`020?l000L00?l00P000?l2003o00L0o`00
1`00o`020?l000kooooo3P3oP0020?l001H0oh0000<0o`000?n0003oP0003`3oP0000`3o0000oh00
0?n0000]0?n00080o`00803oP00Hooooo`005_ooool20000ob00o`001@3oP00=0?l00080oh006@3o
00020000o`D0o`000P3oP0050?l000H0oh0000<0o`000000o`000?l00P3o00040?n000<0o`00103o
P0030?l000L0oh000P3o00040?n000L0o`003_ooool40000o`T0o`000`000?l@003o0080003o1@3o
00020000o`/00?l0103o00000`3oP000003o0000o`060?l000<0003o103o00050000o`80o`001`00
0?l9003o00D0o`0020000?l5003o00<0o`001P000?l90?l000L0003o3_ooool20?l00080003o00<0
o`00003o0000o`004000o`020000ob@00?l0103o00050000o`<0o`0010000?l20?l00080003o3000
o`020?l00080003o1`3o0005003o0080o`001`00o`020000o`800?l01`3o0007003o0080o`003_oo
ool>0?n00080o`005P3oP0000`3o0000oh000?n0000?0?n000030?l0003oP000oh0002d0oh000P3o
000P0?n001Sooooo000Fooooo`@0o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l0000=
0?l000030000o`3o0000o`0000@0o`000`3oP0020000o`/0o`001@3oP0060?l00080oh001`3o0000
0`3oP000o`000?l000060?l000<0oh002`3o00020?n000<0o`000P000?l40?l00080oh001@3o0003
0000o`@0o`001`3oP0020?l000L0oh000P3o000>ooooo`80o`000P000?l00`3o0000003o0000o`04
0?l000800?l000<0003o003o0000o`002@00o`040000o`L0o`001@000?l6003o00L0o`002@000?l5
0?l00080003o0`3o0002003o00L0003o1P00o`020000o`03003o003o0000o`0000800?l02@000?l2
003o00D0003o103o000:0000o`80o`000P000?l20?l000D0003o0P00o`0>ooooo`@0003o0`3o000@
003o00@0003o5@00o`040000o`D00?l00P3o00020000o`L0o`0010000?l30?l00080003o0P3o0009
003o00<0003o0P00o`020?l000D0003o103o0009003o00<0003o0P00o`020000o`@0o`001`000?l7
003o00koooooA03oP0050?l00440oh006?ooool001Kooooo103o00000`000?l0o`000?l000060?l0
00030?n0003o0000o`0000d0o`0000<0003o0?l0003o0000103o00030?n00080003o2`3o00050?n0
00H0o`000P3oP0070?l000030?n0003o0000o`0000H0o`000`3oP00;0?l00080oh000`3o00020000
o`@0o`000P3oP0050?l000<0003o103o00070?n00080o`001`3oP0020?l000kooooo0P3o00020000
o`030?l000000?l0003o00@0o`000P00o`000`000?l00?l0003o0009003o00@0003o1`3o00050000
o`H00?l01`3o00090000o`D0o`000P000?l30?l000800?l01`000?l6003o0080003o00<00?l00?l0
003o00000P00o`090000o`800?l01@000?l40?l000X0003o0P3o00020000o`80o`001@000?l2003o
00kooooo10000?l30?l001000?l010000?lE003o00@0003o1@00o`020?l00080003o1`3o00040000
o`<0o`000P000?l20?l000T00?l00`000?l2003o0080o`001@000?l40?l000T00?l00`000?l2003o
0080003o103o00070000o`L00?l03_oooom40?n000D0o`00@@3oP00Hooooo`005_ooool2003o0080
o`0000<0003o0?l0003o00001P3o00030?n001H0o`001@000?l90?l000L0oh00103o00030?n000H0
o`000`3oP0040?l000L0oh00103o00000`3oP000o`000?l000040?l00080oh004@3o00020000o`@0
o`001@3oP0040?l000L0oh003_ooool70000o`80o`001@000?l6003o00L0o`001@00o`090000o`80
0?l00P3o0002003o00030?l00000o`000?l000800?l00P000?l20?l000L0003o0P00o`080?l002X0
0?l00`000?l20?l000@0003o0`3o0002003o0080003o0P3o0003003o0080o`003_ooool90?l000h0
0?l010000?l5003o00@0003o3P00o`020000o`@00?l000<0o`000000o`000?l01`000?l20?l000@0
0?l00`3o00040000o`80o`003000o`040?l000D0003o0P3o000B003o0080o`002P000?l4003o00ko
oooo4P3oP0040?l00200oh000`3o000;0?n00100o`007@3oP0020?l001L0oh006?ooool001Kooooo
1`3o00020?n000D0o`000P3oP0060?l000<0oh007`3o00030?n000@0003o0P3o00000`3oP000o`00
0?l000020000o`<0o`00103oP0020?l000L0oh000P000?l20?l000030?n0003o0000o`0000@0o`00
0P3oP0000`3o0000003o0000o`020?n00080003o0P3o00000`000?l0o`000?l000050?l00080003o
1P3o00000`3oP000003o0000o`020000o`@0o`001@3oP00>ooooo`80003o0`3o00040000o`80o`00
0`00o`040000o`800?l00`000?l40?l000T00?l00P000?l9003o00<0003o0P00o`070000o`80o`00
0P000?l2003o00`0o`0010000?l00`3o00000?l0003o000F003o0080o`001@000?l3003o00H0o`00
0`000?l20?l000L0003o1000o`0>ooooo`L0o`002`00o`050?l000800?l00P000?l7003o0080003o
0`00o`080?l000D00?l00P3o00020000o`<0o`001`000?l6003o00030000o`3o0000o`0000@0003o
0P3o000:003o0080003o0P3o0005003o0080003o1P00o`000`000?l00?l0003o000@003o0080o`00
0P00o`030000o`@00?l03_oooolB0?n00080o`00J@3oP0020?l000T0oh000P3o000Hooooo`005_oo
ool70?l00080oh001@3o00020?n000H0o`000`3oP00O0?l000<0oh0010000?l20?l000030?n0003o
0000o`000080003o0`3o00040?n00080o`001`3oP0020000o`80o`0000<0oh000?l0003o0000103o
00020?n000030?l000000?l0003o0080oh000P000?l20?l000030000o`3o0000o`0000D0o`000P00
0?l60?l000030?n000000?l0003o0080003o103o00050?n000kooooo0P000?l30?l000@0003o0P3o
0003003o00@0003o0P00o`030000o`@0o`002@00o`020000o`T00?l00`000?l2003o00L0003o0P3o
00020000o`800?l0303o00040000o`030?l00000o`000?l001H00?l00P3o00050000o`<00?l01P3o
00030000o`80o`001`000?l4003o00kooooo1`3o000;003o00D0o`000P00o`020000o`L00?l00P00
0?l3003o00P0o`001@00o`020?l00080003o0`3o00070000o`H00?l000<0003o0?l0003o00001000
0?l20?l000X00?l00P000?l20?l000D00?l00P000?l6003o00030000o`00o`000?l001000?l00P3o
0002003o00<0003o1000o`0>oooooa80oh000P3o001Y0?n00080o`002@3oP0020?l001Sooooo000F
ooooo`/0o`000`000?l20?l00080oh000P3o00020000o`030?l0003oP000oh000080oh001@3o0004
0?n000`0o`000P000?lI0?l00080oh000P000?l30?l000@0oh000P000?l20?l000<0oh00103o0002
0?n000D0o`000P000?l20?l000030000o`3oP000oh000080o`000P3oP00<0?l00080003o1@3o0004
0?n000kooooo0P000?l2003o00030?l000000?l0003o0080003o3@00o`070000o`T00?l01`000?lD
003o00<0o`000P000?l20?n000030000o`3o0000o`000080o`000P00o`030000oaH00?l0103o0000
0`000?l0o`000?l000020000o`80o`0000<00?l00000o`000?l0103o00050000o`80o`001@000?l2
003o0080003o3_ooool70?l00080003o1`00o`040000o`80o`003000o`020000o`<00?l0203o0005
003o00/0o`001@000?l5003o00/0o`002`00o`020?l000<00?l00P000?lI003o0080o`002@00o`0>
oooooa80oh000P3o000P0?n00080o`00403oP0030?l00440oh006?ooool001Kooooo2`3o00030000
o`80o`000P3oP0020?l00080003o00<0o`000?n0003oP0000P3oP0050?l000@0oh00303o00020000
oaT0o`000P3oP0020000o`<0o`00103oP0020000o`80o`000`3oP0040?l00080oh001@3o00020000
o`80o`0000<0003o0?n0003oP0000P3o00020?n000`0o`000P000?l50?l000@0oh003_ooool20000
o`800?l000<0o`000000o`000?l00P000?l=003o00L0003o2@00o`070000oa@00?l00`3o00020000
o`80oh0000<0003o0?l0003o00000P3o0002003o00<0003o5P00o`040?l000030000o`3o0000o`00
0080003o0P3o00000`00o`00003o0000o`040?l000D0003o0P3o00050000o`800?l00P000?l>oooo
o`L0o`000P000?l7003o00@0003o0P3o000<003o0080003o0`00o`080?l000D00?l02`3o00050000
o`D00?l02`3o000;003o0080o`000`00o`020000oaT00?l00P3o0009003o00kooooo4P3oP0020?l0
0200oh000P3o000@0?n000<0o`00@@3oP00Hooooo`005_ooool20?l00080003o1`3o00020000o``0
o`000P000?l50?l000@0oh000P3o00000`000?l0o`000?l000020?l00080oh001@3o00020?n001T0
o`000P000?l50?l00080oh001@3o00020?n00080o`000P000?l20?n000L0o`000P000?l30?l00080
003o1@3oP00B0?l00080003o3_oooolF003o00D0003o2@00o`020?l001D00?l01P000?l00`3o0000
003o0000o`070000o`80o`001`000?lD003o0080o`000`000?l20?l000@0003o4000o`030000o`@0
0?l03_ooool40?l000L0003o1@00o`020?l00080003o1@3o0002003o0080003o00<0o`00003o0000
o`001`00o`020?l000@0003o0P3o00000`00o`00o`000?l000040?l000L0003o1000o`000`000?l0
0?l0003o0005003o00P0o`000`000?l6003o00030?l000000?l0003o0080003o3@00o`030000oa@0
0?l00P3o00000`000?l00?l0003o0002003o00kooooo4P3oP0020?l001h0oh00103o000B0?n000<0
o`002`3oP0020?l00380oh006?ooool001Kooooo0P3o00020000o`L0o`000P000?l<0?l00080003o
1@3o00040?n00080o`0000<0003o0?l0003o00000P3o00020?n000D0o`000P3oP00I0?l00080003o
1@3o00020?n000D0o`000P3oP0020?l00080003o0P3oP0070?l00080003o0`3o00020000o`D0oh00
4P3o00020000o`kooooo5P00o`050000o`T00?l00P3o000E003o00H0003o00<0o`000000o`000?l0
1`000?l20?l000L0003o5000o`020?l000<0003o0P3o00040000oa000?l00`000?l4003o00kooooo
103o00070000o`D00?l00P3o00020000o`D0o`000P00o`020000o`030?l00000o`000?l000L00?l0
0P3o00040000o`80o`0000<00?l00?l0003o0000103o00070000o`@00?l000<0003o003o0000o`00
1@00o`080?l000<0003o1P00o`000`3o0000003o0000o`020000o`d00?l00`000?lD003o0080o`00
00<0003o003o0000o`000P00o`0>oooooa80oh000P3o000N0?n000@0o`004P3oP0030?l000/0oh00
0P3o000b0?n001Sooooo000Fooooo`80o`000`000?l20?n000@0o`000P00o`070?l00080003o0`3o
00020000oa00o`00103oP0050?l000@0oh003P3o00020?n001D0o`0010000?l20?l000030?n0003o
0000o`0000@0o`000P000?l70?l000030000o`3oP000oh000080oh003P3o00020000o`80o`003_oo
oolR003o00@0o`006`00o`050000o`80o`000`000?l90?l001@00?l00P3o00020000o`03003o0000
0?l0003o00@0003o00<00?l00?l0003o00001000o`020?l000D00?l00P000?l20?l00003003o0000
0?l0003o0080003o3_ooool70000o`800?l00P3o0003003o00@0o`000P000?l30?l000800?l01000
0?l00`3o00000?l0003o0002003o0080o`000`00o`040?l000D0003o203o00070000o`<00?l01P00
0?l00`00o`00o`000?l000060?l000030000o`3o0000o`000080o`000P00o`020000o`030?l00000
0?l0003o00H0003o00<00?l00000o`000?l01`3o00020000o`@0o`0000<00?l00?l0003o00001`3o
00020000o`@00?l00`3o00040000o`koooooRP3oP00Hooooo`005_ooool20000o`D0o`000P3oP002
0?l00080003o403o00000`000?l0o`000?l000040?l000<0003o1P3o00020?n000030000o`3o0000
o`0000@0o`000P3oP00>0?l000<0oh005P3o00020000o`80o`000`3oP0040?l00080003o203o0008
0?n000D0o`00103oP0050?l000kooooo8P00o`020?l000<0003o1000o`020000o`T00?l00P000?l0
0`00o`00o`000?l000020?l000L0003o1`00o`090?l000l00?l02@3o00030000o`@00?l00`3o0002
0000o`80o`000`000?l20?l000800?l00P000?l30?l000800?l00P3o000>ooooo`T0003o0P3o0003
003o00@0o`0010000?l<003o0080o`001@00o`020?l000@0003o0`3o00060000o`030?l000000?l0
003o00@0003o0`3o0002003o0080o`000P000?l00`00o`00o`000?l000020?l00080003o0P3o0000
0`000?l0o`000?l000020?l000800?l00`000?l9003o00P0003o1`3o00000`00o`00o`000?l00009
0?l000@00?l00P3o00050000o`koooooRP3oP00Hooooo`005_ooool20000o`D0o`000P3oP0020?l0
0080003o403o00000`000?l0o`000?l000040?l000<0003o1P3o00020?n000030000o`3o0000o`00
00@0o`000P3oP00>0?l000<0oh005P3o00020000o`80o`000`3oP0040?l00080003o203o00080?n0
00D0o`00103oP0050?l000kooooo8P00o`020?l000<0003o1000o`020000o`T00?l00P000?l00`00
o`00o`000?l000020?l000L0003o1`00o`090?l000l00?l02@3o00030000o`@00?l00`3o00020000
o`80o`000`000?l20?l000800?l00P000?l30?l000800?l00P3o000>ooooo`T0003o0P3o0003003o
00@0o`0010000?l<003o0080o`001@00o`020?l000@0003o0`3o00060000o`030?l000000?l0003o
00@0003o0`3o0002003o0080o`000P000?l00`00o`00o`000?l000020?l00080003o0P3o00000`00
0?l0o`000?l000020?l000800?l00`000?l9003o00P0003o1`3o00000`00o`00o`000?l000090?l0
00@00?l00P3o00050000o`koooooRP3oP00Hooooo`005_ooool2003o00L0o`0010000?l00`3o0000
oh000?n000040?n000T0o`0000<0003o0?n0003oP0001P3o00000`00o`00o`000?l000060?l00003
0000o`3o0000o`0000T0o`000P000?l40?l000030000o`3o0000o`0000@0o`000`3oP0060?l00003
0?n0003o0000o`0000@0o`000P3oP0050?l00080003o2@3o00030000o`80o`000P000?l30?l00080
003o0P3o00040?n000L0o`000`3oP0040?l000kooooo5`00o`040000o`D00?l010000?l30?l00080
0?l010000?l9003o0080003o00<00?l00?l0003o00000P3o00050000o`H00?l03P3o000>003o00@0
003o0P3o0009003o00030000o`3o0000o`0000800?l01`000?l20?l00080003o0P3o0005003o00ko
oooo2@00o`020?l001000?l00`3o00040000o`80o`000`000?l2003o00@0o`000P000?l00`3o0000
0?l0003o000=003o00<0o`0010000?l5003o0080o`000P000?l30?l000@0003o2`00o`050?l000@0
003o0`3o00070000o`@0o`0010000?l30?l000H00?l00`000?l20?l000koooooE03oP0020?l003@0
oh006?ooool001Kooooo0P00o`070?l000@0003o00<0o`000?n0003oP000103oP0090?l000030000
o`3oP000oh0000H0o`0000<00?l00?l0003o00001P3o00000`000?l0o`000?l000090?l00080003o
103o00000`000?l0o`000?l000040?l000<0oh001P3o00000`3oP000o`000?l000040?l00080oh00
1@3o00020000o`T0o`000`000?l20?l00080003o0`3o00020000o`80o`00103oP0070?l000<0oh00
103o000>oooooaL00?l010000?l5003o00@0003o0`3o0002003o00@0003o2@00o`020000o`03003o
003o0000o`000080o`001@000?l6003o00h0o`003P00o`040000o`80o`002@00o`000`000?l0o`00
0?l00002003o00L0003o0P3o00020000o`80o`001@00o`0>ooooo`T00?l00P3o000@003o00<0o`00
10000?l20?l000<0003o0P00o`040?l00080003o00<0o`00003o0000o`003@00o`030?l000@0003o
1@00o`020?l00080003o0`3o00040000o`/00?l01@3o00040000o`<0o`001`000?l40?l000@0003o
0`3o0006003o00<0003o0P3o000>oooooe@0oh000P3o000d0?n001Sooooo000Fooooo`80003o0`3o
00020000o`T0o`00103oP0050?l00080003o0P3o00000`000?l0o`000?l000090?l00080oh00103o
00000`00o`00o`000?l0000G0?l00080oh000P000?l40?l000<0oh001P3o00000`3oP000o`000?l0
000=0?l000<0003o3@3o00030?n000H0o`000`3oP0040?l000kooooo7P00o`020?l000@0003o1`3o
00020000oa800?l00`000?l20?l00080003o1@3o00060?n000<0003o0P3o000;003o00<0o`001P00
0?l9003o00X0003o103o00050000o`@00?l03_oooolG003o00@0003o0P3o0005003o0080o`000P00
o`030000o`80o`0010000?l00`3o00000?l0003o000=003o0080o`001@000?l5003o0080003o0P3o
00070000o`L00?l00P3o00020000o`80o`0000<0003o003o0000o`002`000?l20?l00003003o003o
0000o`0000@0o`001@000?l7003o0080003o0P3o000>oooooaH0oh0000<0003o0?l0003o00000P3o
000Y0?n00080o`00303oP0060?l002L0oh00103o00070?n001Sooooo000Fooooo`80003o0`3o0002
0000o`T0o`00103oP0050?l00080003o0P3o00000`000?l0o`000?l000090?l00080oh00103o0000
0`00o`00o`000?l0000G0?l00080oh000P000?l40?l000<0oh001P3o00000`3oP000o`000?l0000=
0?l000<0003o3@3o00030?n000H0o`000`3oP0040?l000kooooo7P00o`020?l000@0003o1`3o0002
0000oa800?l00`000?l20?l00080003o1@3o00060?n000<0003o0P3o000;003o00<0o`001P000?l9
003o00X0003o103o00050000o`@00?l03_oooolG003o00@0003o0P3o0005003o0080o`000P00o`03
0000o`80o`0010000?l00`3o00000?l0003o000=003o0080o`001@000?l5003o0080003o0P3o0007
0000o`L00?l00P3o00020000o`80o`0000<0003o003o0000o`002`000?l20?l00003003o003o0000
o`0000@0o`001@000?l7003o0080003o0P3o000>oooooaH0oh0000<0003o0?l0003o00000P3o000Y
0?n00080o`00303oP0060?l002L0oh00103o00070?n001Sooooo000Fooooo`80003o2@3o00020000
o`D0o`000P3oP0090?l000030000o`3o0000o`000080o`000P3oP00>0?l00080oh007P3o00040?n0
00/0o`000P3oP00J0?l00080003o1P3o00000`3oP000003o0000o`020?l000kooooo1000o`000`00
0?l00?l0003o0007003o0080003o3P00o`020?l000@0003o1`3o000=003o00<0003o1P00o`000`00
0?l0o`000?l000050000o`80o`001P3oP0000`3o0000003o0000o`020?l000d00?l000<0o`000000
o`000?l010000?l9003o00<0003o1000o`020000o`<0o`000P000?l40?l00003003o003o0000o`00
00800?l03_ooool20000oah00?l00P000?l4003o00<0003o0P3o00050000o`l00?l00P3o00000`00
0?l00?l0003o00020000o`/00?l000<0003o003o0000o`003@00o`020?l000030000o`3o0000o`00
00@0003o0P00o`030000o`D00?l00P3o00070000o`@00?l02@000?l>oooooaH0oh001@3o000g0?n0
0080o`00=P3oP00Hooooo`005_ooool20000o`T0o`000P000?l50?l00080oh002@3o00000`000?l0
o`000?l000020?l00080oh003P3o00020?n001h0o`00103oP00;0?l00080oh006P3o00020000o`H0
o`0000<0oh000000o`000?l00P3o000>ooooo`@00?l000<0003o003o0000o`001`00o`020000o`h0
0?l00P3o00040000o`L0o`003@00o`030000o`H00?l000<0003o0?l0003o00001@000?l20?l000H0
oh0000<0o`000000o`000?l00P3o000=003o00030?l000000?l0003o00@0003o2@00o`030000o`@0
0?l00P000?l30?l00080003o103o00000`00o`00o`000?l00002003o00kooooo0P000?lN003o0080
003o1000o`030000o`80o`001@000?l?003o0080o`0000<0003o003o0000o`000P000?l;003o0003
0000o`00o`000?l000d00?l00P3o00000`000?l0o`000?l000040000o`800?l00`000?l5003o0080
o`001`000?l4003o00T0003o3_oooolF0?n000D0o`00=`3oP0020?l003H0oh006?ooool001Kooooo
103o00000`000?l0o`000?l000090?l00080oh002`3o00000`000?l0o`000?l0000;0?l00080oh00
1@3o00070?n00080o`00103oP00E0?l00080oh001@3o00020?n000@0o`000`3oP0090?l00080oh00
5`3o00020000o`80o`003_ooool20000o`800?l01@000?l5003o0080003o4P00o`070?l000H0003o
1@00o`020000o`80o`001@000?l4003o00<0003o1@00o`020?l00080oh000P000?l20?l000030000
o`3o0000o`000080o`007P00o`020?l000H00?l00`3o00020000o`80oh000`3o0004003o00kooooo
8P00o`020?l000D0003o0P3o00020000oa800?l00`000?l?003o00<0o`003@00o`030?l000P0003o
6@00o`000`000?l00?l0003o00020?l000kooooo6@3oP0020?l006l0oh006?ooool001Kooooo1@00
0?l20?l00080oh001@3o00040?n000/0o`0000<0003o0?l0003o00003`3o00000`000?l0o`000?l0
00020?l000D0oh00103o00020?n000L0o`000P3oP0070?l00080oh001@3o00020?n000/0o`0000<0
oh000000o`000?l00P3o00020?n00080o`0000<0003o0?n0003oP0000P3oP0050?l00080oh003P3o
00020000o`80o`003_oooolG003o00@0o`001`00o`050000o`80o`003`00o`030?l000H0003o00<0
o`000000o`000?l01@00o`040?l00080003o0P3o00000`000?l0o`000?l000020?l000800?l00P3o
0009003o00<0003o3@00o`030000o`@00?l01`3o00020000o`<0o`000P000?l20?l000kooooo9P00
o`030000o`80o`008000o`020?l00080003o0`3o000;003o0080003o1@00o`020000o`80o`000P00
0?l20?l000h00?l00P000?l00`3o00000?l0003o0007003o00@0003o3_oooolN0?n00080o`004P3o
P0020?l005H0oh006?ooool001Kooooo1@000?l20?l00080oh001@3o00040?n000/0o`0000<0003o
0?l0003o00003`3o00000`000?l0o`000?l000020?l000D0oh00103o00020?n000L0o`000P3oP007
0?l00080oh001@3o00020?n000/0o`0000<0oh000000o`000?l00P3o00020?n00080o`0000<0003o
0?n0003oP0000P3oP0050?l00080oh003P3o00020000o`80o`003_oooolG003o00@0o`001`00o`05
0000o`80o`003`00o`030?l000H0003o00<0o`000000o`000?l01@00o`040?l00080003o0P3o0000
0`000?l0o`000?l000020?l000800?l00P3o0009003o00<0003o3@00o`030000o`@00?l01`3o0002
0000o`<0o`000P000?l20?l000kooooo9P00o`030000o`80o`008000o`020?l00080003o0`3o000;
003o0080003o1@00o`020000o`80o`000P000?l20?l000h00?l00P000?l00`3o00000?l0003o0007
003o00@0003o3_oooolN0?n00080o`004P3oP0020?l005H0oh006?ooool001Kooooo1@000?l60?l0
0080003o0`3o00040?n00080003o1`3o00000`00o`00o`000?l0000@0?l00080003o103o00030?n0
0080003o103o00020?n000030?l000000?l0003o00/0o`000P3oP0000`000?l0o`000?l000020?n0
0080o`000P3oP0090?l000030?n000000?l0003o00@0o`000`000?l60?n000<0o`001P3oP00>0?l0
00kooooo5`00o`020?l000D00?l00P000?l2003o00@0o`000`000?l?003o00030000o`3o0000o`00
00800?l00P3o00030000o`80o`001@00o`040?l00080003o1@3o00040000o`80o`006@00o`030000
o`@00?l00P000?l50?l000@0003o00<0o`00003o0000o`000P3o000>ooooo`80003o9@00o`060000
o`80o`006P00o`090?l00080003o1`00o`040000o`@00?l000<0o`000000o`000?l01P3o000<003o
00@0003o00<0o`00003o0000o`001P00o`050000o`kooooo<P3oP0020?l00480oh000P3o000B0?n0
01Sooooo000Fooooo`D0003o1P3o00020000o`<0o`00103oP0020000o`L0o`0000<00?l00?l0003o
0000403o00020000o`@0o`000`3oP0020000o`@0o`000P3oP0000`3o0000003o0000o`0;0?l00080
oh0000<0003o0?l0003o00000P3oP0020?l00080oh002@3o00000`3oP000003o0000o`040?l000<0
003o1P3oP0030?l000H0oh003P3o000>oooooaL00?l00P3o0005003o0080003o0P00o`040?l000<0
003o3`00o`000`000?l0o`000?l00002003o0080o`000`000?l20?l000D00?l0103o00020000o`D0
o`0010000?l20?l001T00?l00`000?l4003o0080003o1@3o00040000o`030?l00000o`000?l00080
o`003_ooool20000obD00?l01P000?l20?l001X00?l02@3o00020000o`L00?l010000?l4003o0003
0?l000000?l0003o00H0o`003000o`040000o`030?l00000o`000?l000H00?l01@000?l>oooooc80
oh000P3o00120?n00080o`004P3oP00Hooooo`005_ooool20000o`800?l01`3o00020000o`<0o`00
0P000?l20?n00080003o303o00020?n00300o`000P3oP0070?l00080oh001@3o00020000o`T0o`00
103oP0000`000?l0o`000?l000020?l000@0oh0000<0o`000000o`000?l0103o00030?n000@0o`00
3_oooolD003o0080o`0000<00?l00000o`000?l01@00o`080?l001000?l01`000?l40?l000030000
o`3o0000o`000080003o1@00o`020?l00080003o1@3o00090000oa@00?l00P3o00050000o`800?l0
0P000?l00`00o`00o`000?l000020?l000L0003o0P00o`0>ooooo`80003o1`3o000=003o00030?l0
0000o`000?l000/00?l00P3o00000`000?l0o`000?l000020?l000D0003o6000o`030000o`@0o`00
0P000?l00`3o0000003o0000o`04003o0080o`0000<00?l00000o`000?l00P000?l4003o00030?l0
00000?l0003o00@0o`001@000?l9003o00T0o`000P00o`030?l00080003o0P3o000>ooooo`d0oh00
00<0o`000?n0003oP0001`3oP0020?l00280oh000P000?l20?l000D0oh000P3o00140?n001Sooooo
000Fooooo`80003o0P00o`070?l00080003o0`3o00020000o`80oh000P000?l<0?l00080oh00<03o
00020?n000L0o`000P3oP0050?l00080003o2@3o00040?n000030000o`3o0000o`000080o`00103o
P0000`3o0000003o0000o`040?l000<0oh00103o000>oooooa@00?l00P3o00000`00o`00003o0000
o`05003o00P0o`004000o`070000o`@0o`0000<0003o0?l0003o00000P000?l5003o0080o`000P00
0?l50?l000T0003o5000o`020?l000D0003o0P00o`020000o`03003o003o0000o`000080o`001`00
0?l2003o00kooooo0P000?l70?l000d00?l000<0o`00003o0000o`002`00o`020?l000030000o`3o
0000o`000080o`001@000?lH003o00<0003o103o00020000o`030?l000000?l0003o00@00?l00P3o
00000`00o`00003o0000o`020000o`@00?l000<0o`000000o`000?l0103o00050000o`T00?l02@3o
0002003o00<0o`000P000?l20?l000kooooo3@3oP0000`3o0000oh000?n000070?n00080o`008P3o
P0020000o`80o`001@3oP0020?l004@0oh006?ooool001Kooooo1000o`0<0?l00080003o0P3o0002
0000o`<0o`000P000?l70?l000@0oh00;03o00040?n001T0o`00103oP0000`000?l0o`000?l00004
0?l00080oh0000<0o`000000o`000?l0103o00050?n00080o`003_oooolD003o0080o`000`000?l5
003o0080o`0010000?l20?l001L00?l00P000?l20?l000<0003o1@00o`040?l000@0003o00<0o`00
003o0000o`001000o`050000oa800?l00P000?l20?l000030000o`00o`000?l000H00?l01@000?l4
0?l000D0003o3_ooool4003o00<0003o3`00o`000`000?l0o`000?l000020?l000/00?l000<0003o
0?l0003o00001P000?lI003o00<0003o103o00020000o`<0o`003`00o`000`3o0000003o0000o`04
0?l000<0003o0P00o`020000o`L00?l010000?l:0?l00080003o0P00o`0>ooooo`h0oh000P3o000Y
0?n000@0o`00=`3oP0060?l00100oh006?ooool001Kooooo1000o`0<0?l00080003o0P3o00020000
o`<0o`000P000?l70?l000@0oh00;03o00040?n001T0o`00103oP0000`000?l0o`000?l000040?l0
0080oh0000<0o`000000o`000?l0103o00050?n00080o`003_oooolD003o0080o`000`000?l5003o
0080o`0010000?l20?l001L00?l00P000?l20?l000<0003o1@00o`040?l000@0003o00<0o`00003o
0000o`001000o`050000oa800?l00P000?l20?l000030000o`00o`000?l000H00?l01@000?l40?l0
00D0003o3_ooool4003o00<0003o3`00o`000`000?l0o`000?l000020?l000/00?l000<0003o0?l0
003o00001P000?lI003o00<0003o103o00020000o`<0o`003`00o`000`3o0000003o0000o`040?l0
00<0003o0P00o`020000o`L00?l010000?l:0?l00080003o0P00o`0>ooooo`h0oh000P3o000Y0?n0
00@0o`00=`3oP0060?l00100oh006?ooool001Kooooo1000o`0R0?l000030000o`3o0000o`0000H0
oh008`3o00040?n000@0003o0`3oP0090?l00080oh002`3o00030000o`T0o`000P00o`020?l000D0
oh000P000?l>ooooob000?l00P000?lD003o0080003o0`3o0002003o00@0003o0`3o0002003o00<0
003o0P00o`020?l000D0003o2000o`000`3o0000003o0000o`020?l000L00?l00P000?l4003o0003
0?l00000o`000?l001000?l02`3o000>ooooo`L0003o3`00o`030000o`80o`000`00o`020?l000H0
0?l000<0003o0?l0003o00001P000?l00`00o`00003o0000o`0D003o00D0003o103o00020000o`03
0?l000000?l0003o00L00?l00P3o0009003o0080003o1`00o`040000o`D00?l0103o00050000o`@0
o`0000<0003o0?l0003o00000P000?l>oooood@0oh00103o000`0?n00080o`00403oP00Hooooo`00
5_ooool4003o00030?l0003oP000oh000080oh00503o00000`000?l0o`000?l000060?l000030000
o`3o0000o`000080o`00103oP0050?l00080oh001@3o00040?n001`0o`000P3oP0020000o`L0o`00
0P3oP0050?l00080oh000P000?l70?l000800?l02`3o00030?n00080003o3_oooolN003o0080o`00
1`000?lD003o0080o`001@000?l20?l000L00?l00P3o00040000o`030?l00000o`000?l000H00?l0
00<0003o0?l0003o00000P000?l=003o00030?l00000o`000?l000800?l00P000?l<003o0080003o
0P3o00020000o`D0o`003_ooool20000o`80o`0000<0003o0?l0003o00001P000?l7003o0080o`00
00<0003o0?l0003o00000P3o0002003o00<0o`001`00o`020000o`L0o`004@00o`000`3o00000?l0
003o0005003o0080003o0P3o00040000o`<0o`001P00o`000`3o00000?l0003o0009003o0080003o
0P3o0005003o0080o`000P000?l70?l000D0003o1P3o00000`000?l0o`000?l000020?l000kooooo
2`3oP0020?l000<0oh000P3o000W0?n00080o`00?@3oP0020000o`80o`003P3oP00Hooooo`005_oo
ool4003o00030?l0003oP000oh000080oh00503o00000`000?l0o`000?l000060?l000030000o`3o
0000o`000080o`00103oP0050?l00080oh001@3o00040?n001`0o`000P3oP0020000o`L0o`000P3o
P0050?l00080oh000P000?l70?l000800?l02`3o00030?n00080003o3_oooolN003o0080o`001`00
0?lD003o0080o`001@000?l20?l000L00?l00P3o00040000o`030?l00000o`000?l000H00?l000<0
003o0?l0003o00000P000?l=003o00030?l00000o`000?l000800?l00P000?l<003o0080003o0P3o
00020000o`D0o`003_ooool20000o`80o`0000<0003o0?l0003o00001P000?l7003o0080o`0000<0
003o0?l0003o00000P3o0002003o00<0o`001`00o`020000o`L0o`004@00o`000`3o00000?l0003o
0005003o0080003o0P3o00040000o`<0o`001P00o`000`3o00000?l0003o0009003o0080003o0P3o
0005003o0080o`000P000?l70?l000D0003o1P3o00000`000?l0o`000?l000020?l000kooooo2`3o
P0020?l000<0oh000P3o000W0?n00080o`00?@3oP0020000o`80o`003P3oP00Hooooo`005_ooool4
003o00`0o`000P3oP00D0?l00003003o003o0000o`0000H0o`0000<0003o0?l0003o00002@3o0006
0?n000D0o`000P3oP00C0?l000@0oh00103o00000`000?l0o`000?l0000R0?l00080003o3_ooool2
003o0080o`006P00o`020?l000H0003o5`00o`040000o`X00?l01P000?l7003o0080o`001@000?l;
003o00<0003o0P00o`050000o`/00?l00P000?l20?l000L0003o3_ooool40000o`X00?l010000?l2
003o0080o`0000<0003o0?l0003o00000P3o00030000o`80o`001000o`0>0?l000800?l00P3o0002
0000o`T00?l00`3o00040000o`<00?l0103o00050000oa000?l00P3o0009003o00@0003o1@3o0002
0000o`800?l01@000?l20?l00080003o00<0o`000000o`000?l00P3o000>ooooob80oh000P000?lN
0?n000@0o`00<P3oP0020?l00100oh006?ooool001Kooooo1000o`0<0?l00080oh00503o00000`00
o`00o`000?l000060?l000030000o`3o0000o`0000T0o`001P3oP0050?l00080oh004`3o00040?n0
00@0o`0000<0003o0?l0003o00008P3o00020000o`kooooo0P00o`020?l001X00?l00P3o00060000
oaL00?l010000?l:003o00H0003o1`00o`020?l000D0003o2`00o`030000o`800?l01@000?l;003o
0080003o0P3o00070000o`kooooo10000?l:003o00@0003o0P00o`020?l000030000o`3o0000o`00
0080o`000`000?l20?l000@00?l03P3o0002003o0080o`000P000?l9003o00<0o`0010000?l3003o
00@0o`001@000?l@003o0080o`002@00o`040000o`D0o`000P000?l2003o00D0003o0P3o00020000
o`030?l000000?l0003o0080o`003_oooolR0?n00080003o7P3oP0040?l00380oh000P3o000@0?n0
01Sooooo000Fooooo`@00?l03P3o00020?n00080o`0000<0003o0?n0003oP0003@3o00000`000?l0
o`000?l0000D0?l000@0oh0000<0003o0?l0003o00000P3o00050?n000@0o`000`3oP00=0?l00080
003o2@3o00020?n001h0o`003_ooool20000o`80o`00<P00o`020000o`T0o`001@000?lD003o0003
0?l000000?l0003o00@0003o1@00o`020?l000D0003o4P00o`040?l000L0003o3_ooool40000o`03
0?l00000o`000?l000H00?l01`000?l20?l000030000o`3o0000o`000080o`001@000?l4003o00<0
o`000P000?l40?l00080003o00<0o`000000o`000?l01P000?l7003o0080003o00<0o`000000o`00
0?l010000?l3003o0080o`000P00o`030000o`800?l00P3o0002003o00L0003o1000o`050000o`80
o`000P00o`050000o`800?l01@000?l70?l000800?l00P3o00020000o`030?l000000?l0003o0080
003o3_oooold0?n00080o`00D03oP0040?l001Sooooo000Fooooo`@00?l03P3o00020?n00080o`00
00<0003o0?n0003oP0003@3o00000`000?l0o`000?l0000D0?l000@0oh0000<0003o0?l0003o0000
0P3o00050?n000@0o`000`3oP00=0?l00080003o2@3o00020?n001h0o`003_ooool20000o`80o`00
<P00o`020000o`T0o`001@000?lD003o00030?l000000?l0003o00@0003o1@00o`020?l000D0003o
4P00o`040?l000L0003o3_ooool40000o`030?l00000o`000?l000H00?l01`000?l20?l000030000
o`3o0000o`000080o`001@000?l4003o00<0o`000P000?l40?l00080003o00<0o`000000o`000?l0
1P000?l7003o0080003o00<0o`000000o`000?l010000?l3003o0080o`000P00o`030000o`800?l0
0P3o0002003o00L0003o1000o`050000o`80o`000P00o`050000o`800?l01@000?l70?l000800?l0
0P3o00020000o`030?l000000?l0003o0080003o3_oooold0?n00080o`00D03oP0040?l001Sooooo
000Fooooo`@00?l00`3oP00=0?l000<0003o0P3o00050000o`80o`000P3oP0040?l000030000o`3o
0000o`0001P0o`0000<0003o0?l0003o0000103o00030?n000@0o`001@3oP0090?l00080oh001@3o
00040000o`T0o`000P3oP0050?l00080oh00403o000>ooooo`@0003o6P00o`020?l000@0003o0P3o
000C003o0080003o1P3o000<003o00L0003o1P00o`030000ob800?l00P3o00040000o`030?l00000
0?l0003o00800?l03_ooool20000o`<0o`002@00o`020000o`L0o`000P000?l20?l000D0003o0P00
o`090?l00080oh000`000?l20?l000d00?l00P000?l30?l00080003o0P3o0009003o00030?l00000
0?l0003o00L0003o1P00o`020?l000030000o`3o0000o`0000L0003o0P00o`020?l00080003o00<0
o`000000o`000?l00P000?l20?l000<0003o0P3o0007003o00@0003o3_ooool50?l000@0oh00103o
000E0?n00080o`000P000?mG0?n00080o`0010000?l20?n000030?l000000?l0003o0080003o6?oo
ool001Kooooo1000o`000`3o0000oh000?n000020?n00180o`000P000?l50?l00080003o1@3o0002
0?n001d0o`000`3oP0060?l000<0oh000P000?l;0?l00080003o5@3o00040?n000D0o`00103oP005
0?l000kooooo1@000?lI003o00H0003o3P00o`020?l000D00?l00P3o00040000o`80o`0000<0003o
003o0000o`004P00o`040000ob800?l000<0o`00003o0000o`001P000?l00`3o00000?l0003o0002
003o00kooooo1@3o000;003o0080o`000P00o`030?l00080003o103o00030000o`@00?l00`3o0002
0000o`@0o`000P000?l30?l000l00?l000<0o`000000o`000?l00P000?l20?l00003003o003o0000
o`0000@0o`000P000?l00`3o00000?l0003o000=003o0100003o0P00o`000`3o0000003o0000o`04
0?l000<0003o0P3o000;003o00koooooO`3oP0040?l000L0oh006?ooool001Kooooo1000o`000`3o
0000oh000?n000020?n00180o`000P000?l50?l00080003o1@3o00020?n001d0o`000`3oP0060?l0
00<0oh000P000?l;0?l00080003o5@3o00040?n000D0o`00103oP0050?l000kooooo1@000?lI003o
00H0003o3P00o`020?l000D00?l00P3o00040000o`80o`0000<0003o003o0000o`004P00o`040000
ob800?l000<0o`00003o0000o`001P000?l00`3o00000?l0003o0002003o00kooooo1@3o000;003o
0080o`000P00o`030?l00080003o103o00030000o`@00?l00`3o00020000o`@0o`000P000?l30?l0
00l00?l000<0o`000000o`000?l00P000?l20?l00003003o003o0000o`0000@0o`000P000?l00`3o
00000?l0003o000=003o0100003o0P00o`000`3o0000003o0000o`040?l000<0003o0P3o000;003o
00koooooO`3oP0040?l000L0oh006?ooool001Kooooo1000o`030?l00080oh000P000?l20?l000D0
oh00403o00020000o`L0o`000P3oP00;0?l000030000o`3o0000o`0000@0oh002@3o00030?n00080
003o1`3o00040000o`D0oh007@3o00020?n000D0o`001@3oP0040?l000kooooo3@00o`000`000?l0
0?l0003o000@003o00H0003o3000o`060000o`D0o`001@000?l9003o00@0o`001@000?l;003o00T0
003o0P3o000B003o00<0003o0P3o00050000o`@00?l03_ooool50000o`/00?l01P000?l00`3o0000
003o0000o`050?l00080003o0P00o`050?l00080003o0P3o00020?n000<0003o0P3o000?003o00D0
003o0P3o00000`000?l0o`000?l000020?l00080003o1`3o0005003o0080o`0010000?l20?l000<0
003o0P3o00020000o`L00?l00P3o00030000o`@0o`002@000?l7003o00koooooB03oP0000`3o0000
oh000?n0000@0?n00080o`00;@3oP00Hooooo`005_ooool4003o00<0o`000P3oP0020000o`80o`00
1@3oP00@0?l00080003o1`3o00020?n000/0o`0000<0003o0?l0003o0000103oP0090?l000<0oh00
0P000?l70?l000@0003o1@3oP00M0?l00080oh001@3o00050?n000@0o`003_ooool=003o00030000
o`00o`000?l001000?l01P000?l<003o00H0003o1@3o00050000o`T00?l0103o00050000o`/00?l0
2@000?l20?l001800?l00`000?l20?l000D0003o1000o`0>ooooo`D0003o2`00o`060000o`030?l0
00000?l0003o00D0o`000P000?l2003o00D0o`000P000?l20?l00080oh000`000?l20?l000l00?l0
1@000?l20?l000030000o`3o0000o`000080o`000P000?l70?l000D00?l00P3o00040000o`80o`00
0`000?l20?l00080003o1`00o`020?l000<0003o103o00090000o`L00?l03_oooom80?n000030?l0
003oP000oh000100oh000P3o000]0?n001Sooooo000Fooooo`800?l02@3o00020000o`030?l0003o
P000oh000080oh000P000?l20?l000030?n0003o0000o`0001d0o`000P000?l30?l000H0oh0000<0
o`000?n0003oP000403o0004003o0080o`000`3oP0040?l000<0003o103o00020000oa80o`0000<0
oh000?l0003o00001P3o00000`3oP000003o0000o`020?l000kooooo1`00o`020?l001D00?l02000
0?l@003o00D0003o0P00o`050000o`80o`001@00o`040000o`@0o`002P00o`020?l000T00?l00P00
0?l20?l001<00?l010000?l2003o00<0003o1000o`0>ooooo`80003o3P00o`090000o`80o`000P00
0?l00`3o00000?l0003o0006003o00030?l000000?l0003o0080o`000P3oP0030000o`80o`000P00
o`020000oa000?l00`000?l4003o0080003o0`3o00060000o`800?l00`3o00060000o`030?l00000
0?l0003o00@0003o2@00o`000`3o0000003o0000o`040?l000<0003o0P3o00060000o`D00?l03_oo
oon:0?n001Sooooo000Fooooo`800?l02@3o00020000o`030?l0003oP000oh000080oh000P000?l2
0?l000030?n0003o0000o`0001d0o`000P000?l30?l000H0oh0000<0o`000?n0003oP000403o0004
003o0080o`000`3oP0040?l000<0003o103o00020000oa80o`0000<0oh000?l0003o00001P3o0000
0`3oP000003o0000o`020?l000kooooo1`00o`020?l001D00?l020000?l@003o00D0003o0P00o`05
0000o`80o`001@00o`040000o`@0o`002P00o`020?l000T00?l00P000?l20?l001<00?l010000?l2
003o00<0003o1000o`0>ooooo`80003o3P00o`090000o`80o`000P000?l00`3o00000?l0003o0006
003o00030?l000000?l0003o0080o`000P3oP0030000o`80o`000P00o`020000oa000?l00`000?l4
003o0080003o0`3o00060000o`800?l00`3o00060000o`030?l000000?l0003o00@0003o2@00o`00
0`3o0000003o0000o`040?l000<0003o0P3o00060000o`D00?l03_oooon:0?n001Sooooo000Foooo
o`800?l03P3o00040000o`<0o`000P3oP0020000o`L0o`000P000?lI0?l00080oh000`000?l40?n0
00L0o`000P3oP0070?l00080003o703o00040?n000h0o`0010000?l>oooooc800?l00P3o00050000
o`T00?l00P3o0005003o0080o`000P000?l40?l000L00?l00P000?l:003o00H0003o4`00o`020000
o`800?l00P3o00030000o`80o`000P00o`0>ooooo`80003o5`00o`020000o`h00?l00P000?l20?l0
00D0003o0P00o`020000o`80o`004`00o`020?l000L0003o1P00o`030?l000@0003o0P3o00000`00
o`00003o0000o`020000o``00?l010000?l40?l000L0003o1@00o`020000o`kooooo>@3oP0040?l0
04d0oh006?ooool001Kooooo0P00o`0>0?l000@0003o0`3o00020?n00080003o1`3o00020000oaT0
o`000P3oP0030000o`@0oh001`3o00020?n000L0o`000P000?lL0?l000@0oh003P3o00040000o`ko
oooo<P00o`020?l000D0003o2@00o`020?l000D00?l00P3o00020000o`@0o`001`00o`020000o`X0
0?l01P000?lC003o0080003o0P00o`020?l000<0003o0P3o0002003o00kooooo0P000?lG003o0080
003o3P00o`020000o`80o`001@000?l2003o0080003o0P3o000C003o0080o`001`000?l6003o00<0
o`0010000?l20?l00003003o00000?l0003o0080003o3000o`040000o`@0o`001`000?l5003o0080
003o3_ooooli0?n000@0o`00C@3oP00Hooooo`005_ooool2003o0100o`000P000?l50?l000@0003o
1`3o00020000o`030?l000000?l0003o01H0o`000`000?l20?l00080oh001@000?l20?l000@0oh00
3P3o00020000o`80o`0000<0003o0?l0003o00002@3o00020000o`800?l000<0o`000?n0003oP000
0P3oP0040?l000<0oh002@3o00020000o`kooooo0P000?lo003o00<0003o1000o`030?l000@0003o
2@00o`020000o`03003o003o0000o`0000L00?l00P3o00040000oa<00?l010000?l50?l000@00?l0
3_oooolY003o0080003o0P3o00020000o`03003o00000?l0003o01800?l00P3o0009003o00<0003o
0P3o00040000o`80o`0000<0003o003o0000o`001000o`020?l00003003o003o0000o`000080o`00
10000?l<003o0080o`000P00o`030000o`/00?l03_oooolI0?n000L0o`006@3oP0020?l000/0oh00
0`3o00110?n001Sooooo000Fooooo`800?l00`3o00040000o`80o`000`3oP00=0?l000800?l04P3o
00000`3oP000o`000?l0000=0?l000D0003o0P3o00050000o`@0o`000`3oP00M0?l000@0003o00<0
o`000?n0003oP0000P3oP0050?l00080oh002`3o000>ooooocT00?l010000?l5003o0080003o1000
o`000`000?l0o`000?l0000;003o0080003o0P3o00050000o`@00?l000<0o`000000o`000?l01000
0?lG003o00L0o`000P00o`0>ooooo`80003o0P3o000[003o00<0o`001P000?lL003o0080o`001@00
0?l;003o0080o`002@00o`030000o`@00?l00P3o0002003o00<0003o1000o`070000o`kooooo403o
P0040?l000T0oh0000<0o`000?n0003oP0005P3oP0020?l000030?n0003o0000o`0000@0o`00>`3o
P0030?l000d0oh006?ooool001Kooooo0P00o`030?l000@0003o0P3o00030?n000d0o`000P00o`0B
0?l000030?n0003o0000o`0000d0o`001@000?l20?l000D0003o103o00030?n001d0o`0010000?l0
0`3o0000oh000?n000020?n000D0o`000P3oP00;0?l000kooooo>@00o`040000o`D00?l00P000?l4
003o00030000o`3o0000o`0000/00?l00P000?l20?l000D0003o1000o`000`3o0000003o0000o`04
0000oaL00?l01`3o0002003o00kooooo0P000?l20?l002/00?l00`3o00060000oa`00?l00P3o0005
0000o`/00?l00P3o0009003o00<0003o1000o`020?l000800?l00`000?l4003o00L0003o3_ooool@
0?n000@0o`002@3oP0000`3o0000oh000?n0000F0?n00080o`0000<0oh000?l0003o0000103o000k
0?n000<0o`003@3oP00Hooooo`005_ooool20000o`/0o`000`3oP0020000o`80o`000P3oP00@0?l0
00<0003o0P3o0004003o00030?l0003oP000oh000080oh000P000?l20?l000<0oh002`3o0002003o
00T0o`0000<0oh000?l0003o00000P000?l20?n000h0o`000P000?l50?l000800?l01`3o00020?n0
00L0o`00103oP0050?l00080003o3_oooom4003o0080o`000`000?l20?l000d00?l00P000?lE003o
00@0003o1`00o`030000o`@00?l00P3o00050000o`800?l03_ooool20000o`80o`007000o`020000
o`80o`009000o`000`000?l00?l0003o0007003o00@0o`001@000?l6003o0080003o0`00o`020000
o`T00?l00P000?l@003o00D0003o0P3o000>ooooodP0oh0000<0o`000?n0003oP000?`3oP00Hoooo
o`005_ooool20000o`/0o`000`3oP0020000o`80o`000P3oP00@0?l000<0003o0P3o0004003o0003
0?l0003oP000oh000080oh000P000?l20?l000<0oh002`3o0002003o00T0o`0000<0oh000?l0003o
00000P000?l20?n000h0o`000P000?l50?l000800?l01`3o00020?n000L0o`00103oP0050?l00080
003o3_oooom4003o0080o`000`000?l20?l000d00?l00P000?lE003o00@0003o1`00o`030000o`@0
0?l00P3o00050000o`800?l03_ooool20000o`80o`007000o`020000o`80o`009000o`000`000?l0
0?l0003o0007003o00@0o`001@000?l6003o0080003o0`00o`020000o`T00?l00P000?l@003o00D0
003o0P3o000>ooooodP0oh0000<0o`000?n0003oP000?`3oP00Hooooo`005_ooool20000o``0o`00
0P3oP0060?l000030?n0003o0000o`0000@0o`0000<0oh000?l0003o00002`3o00020000o`L0o`00
0P000?l30?l000@0oh000P3o00020000oa40o`0010000?l40?l000030000o`3o0000o`000080o`00
0P3oP0020000o`<0o`000P000?l50?l000@00?l03P3o00060?n000<0o`000P000?l>ooooocl00?l0
0P3o00000`000?l0o`000?l0000;0?l001000?l01@000?lI003o0080o`000P000?l20?l000D0003o
0P00o`0>ooooo`@0003o00<0o`00003o0000o`0010000?lE003o0080003o1@00o`060?l000L0003o
5000o`050?l000D00?l00P3o00070000o`H00?l00P3o00000`00o`00003o0000o`020000o`/00?l0
00<0003o0?l0003o00000P3o00050000o`d00?l03_oooom80?n000030?l0003oP000oh0003l0oh00
6?ooool001Kooooo0P000?l<0?l00080oh001P3o00000`3oP000o`000?l000040?l000030?n0003o
0000o`0000/0o`000P000?l70?l00080003o0`3o00040?n00080o`000P000?lA0?l000@0003o103o
00000`000?l0o`000?l000020?l00080oh000P000?l30?l00080003o1@3o0004003o00h0o`001P3o
P0030?l00080003o3_oooolo003o0080o`0000<0003o0?l0003o00002`3o000@003o00D0003o6@00
o`020?l00080003o0P3o00050000o`800?l03_ooool40000o`030?l00000o`000?l000@0003o5@00
o`020000o`D00?l01P3o00070000oa@00?l01@3o0005003o0080o`001`000?l6003o0080o`0000<0
0?l00000o`000?l00P000?l;003o00030000o`3o0000o`000080o`001@000?l=003o00koooooB03o
P0000`3o0000oh000?n0000o0?n001Sooooo000FoooooaL0o`0010000?l@0?l00080003o1`3o0002
0000o``0o`00103oP00<0?l00080003o1P3o00000`000?l0o`000?l000090?l000@0003o1@3o0002
003o00/0o`0000<0003o0?l0003o00000P3o00040?n000030000o`3o0000o`000080o`003_oooolh
003o00030?l00000o`000?l000800?l010000?l>0?l000`00?l00P000?l=0?l000<00?l00P000?l2
0?l00080003o1@00o`040?l000`0003o0P00o`0>ooooo`@0003o00<0o`00003o0000o`0010000?l7
003o0080003o0P00o`000`3o00000?l0003o0004003o00030?l000000?l0003o00@0003o0`00o`04
0000o`80o`001@000?lD003o00D0003o0P3o0005003o0080o`0010000?l20?l001D00?l00P000?l3
003o0080o`000P00o`020000o`<00?l00P000?l4003o0080o`001@000?l>ooooob00oh000P3o000W
0?n00080003o?`3oP00Hooooo`005_oooolG0?l000@0003o403o00020000o`L0o`000P000?l<0?l0
00@0oh00303o00020000o`H0o`0000<0003o0?l0003o00002@3o00040000o`D0o`000P00o`0;0?l0
00030000o`3o0000o`000080o`00103oP0000`000?l0o`000?l000020?l000kooooo>000o`000`3o
00000?l0003o0002003o00@0003o3P3o000<003o0080003o3@3o0003003o0080003o0P3o00020000
o`D00?l0103o000<0000o`800?l03_ooool40000o`030?l00000o`000?l000@0003o1`00o`020000
o`800?l000<0o`00003o0000o`001000o`000`3o0000003o0000o`040000o`<00?l010000?l20?l0
00D0003o5000o`050000o`80o`001@00o`020?l000@0003o0P3o000E003o0080003o0`00o`020?l0
00800?l00P000?l3003o0080003o1000o`020?l000D0003o3_oooolP0?n00080o`009`3oP0020000
ocl0oh006?ooool001Kooooo0P000?l70?l00080oh00303o00060000o`030?l0003oP000oh0000@0
o`000`3oP0060?l00080oh002@3o00000`00o`00o`000?l000090?l00080oh000`000?l20?l000H0
oh005@3o00040000o`D0o`000P000?lB0?l00080oh0000<0003o0?l0003o00000P3o000>ooooob/0
0?l00P000?l30?l000@00?l00P3o0002003o00030?l00000o`000?l000@0003o1@3o00050?n000H0
o`000`00o`020000o`L00?l00P000?l40?l000<00?l010000?l>003o00H0003o1`00o`050000o`80
0?l03_ooool2003o0080003o00<0o`00003o0000o`003`00o`000`000?l00?l0003o0004003o0003
0?l000000?l0003o00@0003o3000o`020000oaH00?l000<0003o003o0000o`000P3o000=0000o`03
0?l000000?l0003o02d00?l03_oooolf0?n000<0o`00D@3oP00Hooooo`005_ooool20000o`T0o`00
0P3oP0030?l00080003o1`3o00040000o`<0o`0010000?l20?l000<0oh000P3o00020000o`<0oh00
2@3o0002003o00d0o`0000<0003o0?l0003o00000P3o00040?n000<0003o0P3oP00=0?l000030000
o`3o0000o`0000T0o`000P000?l20?l000<0oh003`3o00000`000?l0o`000?l000020?l000kooooo
1`00o`020?l002@00?l00P000?l5003o00D0003o0P3o00090000o`L0oh00103o000;003o00030?l0
00000?l0003o00@0003o0`3o00060000o``00?l010000?l@003o00kooooo1@000?lA003o00030000
o`00o`000?l000d00?l00`000?l2003o0080o`000P000?l00`00o`00o`000?l00007003o0080o`00
5000o`020000o`L0o`003P00o`020000o`D00?l00P3o000>003o00H0o`000`000?l20?l000800?l0
3_oooon:0?n001Sooooo000Fooooo`80003o2@3o00020?n000<0o`000P000?l70?l000@0003o0`3o
00040000o`80o`000`3oP0020?l00080003o0`3oP0090?l000800?l03@3o00000`000?l0o`000?l0
00020?l000@0oh000`000?l20?n000d0o`0000<0003o0?l0003o00002@3o00020000o`80o`000`3o
P00?0?l000030000o`3o0000o`000080o`003_ooool7003o0080o`009000o`020000o`D00?l01@00
0?l20?l000T0003o1`3oP0040?l000/00?l000<0o`000000o`000?l010000?l30?l000H0003o3000
o`040000oa000?l03_ooool50000oa400?l000<0003o003o0000o`003@00o`030000o`800?l00P3o
00020000o`03003o003o0000o`0000L00?l00P3o000D003o0080003o1`3o000>003o0080003o1@00
o`020?l000h00?l01P3o00030000o`80o`000P00o`0>ooooohX0oh006?ooool001Kooooo0P00o`03
0?l00080003o1`3o00020000o`H0o`0000<0003o0?l0003o00001`3o00040000o`<0o`000P3oP002
0?l00080003o0P3o00000`3oP000o`000?l0000D0?l00080003o1@3o00020?n00080o`000`000?l4
0?n000/0o`0000<0003o003o0000o`000P00o`020?l000800?l00`3o00020000o`<0o`00103oP005
0?l00080oh002`3o000>ooooo`800?l00`3o000D003o00@0003o00<0o`000000o`000?l010000?l5
003o00L0003o103o00050000o`80o`001000o`070?l000<0oh000P3o00020000o`80o`003000o`04
0000o`800?l00`3o00060000oaL00?l0103o00030000o`800?l03_oooolP003o00@0003o0P00o`00
0`3o0000003o0000o`020000o`80o`000`00o`020?l000800?l00P3o0003003o0080o`001`00o`02
0?l000/00?l01`000?l20?l000D0003o0P00o`020?l000T00?l00`3o00020000o`80o`000P000?l0
0`00o`00o`000?l00006003o00L0o`001`000?l>ooooogX0oh000P000?l>0?n001Sooooo000Foooo
o`800?l00`3o00020000o`L0o`000P000?l60?l000030000o`3o0000o`0000L0o`0010000?l30?l0
0080oh000P3o00020000o`80o`0000<0oh000?l0003o0000503o00020000o`D0o`000P3oP0020?l0
00<0003o103oP00;0?l000030000o`00o`000?l000800?l00P3o0002003o00<0o`000P000?l30?l0
00@0oh001@3o00020?n000/0o`003_ooool2003o00<0o`005000o`040000o`030?l000000?l0003o
00@0003o1@00o`070000o`@0o`001@000?l20?l000@00?l01`3o00030?n00080o`000P000?l20?l0
00`00?l010000?l2003o00<0o`001P000?lG003o00@0o`000`000?l2003o00kooooo8000o`040000
o`800?l000<0o`000000o`000?l00P000?l20?l000<00?l00P3o0002003o0080o`000`00o`020?l0
00L00?l00P3o000;003o00L0003o0P3o00050000o`800?l00P3o0009003o00<0o`000P000?l20?l0
0080003o00<00?l00?l0003o00001P00o`070?l000L0003o3_oooomj0?n00080003o3P3oP00Hoooo
o`005_ooool50?l00080003o3`3o00000`000?l0o`000?l0000B0?l00080003o1`3o0002003o00/0
o`0000<0oh000?l0003o0000103o00000`000?l0o`000?l0000;0?l00080oh004P3o0002003o00<0
o`0010000?l<0?l00080oh002@3o000>ooooo`800?l00`3o000I003o0080003o6@00o`020?l00080
0?l00P000?l20?l000<0003o1@3o00020?n00080003o0P3o000;003o00<0o`001P000?l00`00o`00
o`000?l0000O003o00030?l00000o`000?l00080003o3_ooool40000o`030?l00000o`000?l000H0
0?l01@000?l>003o0080o`002@00o`020?l000<0003o0P3o0002003o0080o`001@000?l2003o0080
003o0P3o00000`00o`00o`000?l0000;003o00T0003o0P00o`070000o`<00?l01P000?l20?l00003
003o00000?l0003o0080o`000`00o`0=0?l00080003o0`00o`040?l000kooooo?`3oP0020?l004T0
oh006?ooool001Kooooo1@3o00020000o`l0o`0000<0003o0?l0003o00004P3o00020000o`L0o`00
0P00o`0;0?l000030?n0003o0000o`0000@0o`0000<0003o0?l0003o00002`3o00020?n00180o`00
0P00o`030?l000@0003o303o00020?n000T0o`003_ooool2003o00<0o`006@00o`020000oaT00?l0
0P3o0002003o0080003o0P3o00030000o`D0o`000P3oP0020000o`80o`002`00o`030?l000H0003o
00<00?l00?l0003o00007`00o`000`3o00000?l0003o00020000o`kooooo10000?l00`3o00000?l0
003o0006003o00D0003o3P00o`020?l000T00?l00P3o00030000o`80o`000P00o`020?l000D0003o
0P00o`020000o`80o`0000<00?l00?l0003o00002`00o`090000o`800?l01`000?l3003o00H0003o
0P3o00000`00o`00003o0000o`020?l000<00?l03@3o00020000o`<00?l0103o000>ooooocl0oh00
0P3o00190?n001Sooooo000Fooooo`@0o`000`000?l?0?l000030000o`3o0000o`0000800?l0503o
00000`000?l0o`000?l000070?l00080003o103o00020000o`030?n0003o0000o`0000/0o`000P00
0?l00`3o00000?l0003o00040?l000<0003o103o00040000o`L0o`000P000?l3003o00T0o`001000
0?l30?l000@0oh000P000?l50?l000kooooo0P000?l20?l000<0003o5P00o`050000oaL00?l00P3o
00040000o`<0o`000P000?l50?l00080003o1`3o000B003o0080o`003P00o`020000oa@00?l03_oo
ool4003o00030000o`00o`000?l001T00?l00P3o0005003o00@0003o103o00030000o`L00?l00P3o
0002003o00L0003o2`00o`020?l000<0003o0P3o00020000o`800?l01`3o0007003o0080003o0P3o
00000`000?l0o`000?l000070000o`L0o`001P000?l7003o00kooooo6@3oP0020?l00280oh00103o
000C0?n00080003o=03oP00Hooooo`005_ooool50000oa@0o`000P00o`030?l00080003o4P3o0002
0000ob@0o`000`000?l60?l00080003o00<0o`000000o`000?l00P00o`040?l00003003o003o0000
o`0000h0o`000P00o`040?l000<0003o0P00o`020?l000kooooo0P3o00050000oc@00?l01`3o0002
0000o`/0o`000P000?l00`3o00000?l0003o000=003o00<0003o103o000R003o00kooooo2`00o`03
0000oad00?l00P3o00050000o`L00?l010000?l2003o0080o`000`000?l7003o0080o`000P00o`05
0000o`@0o`000`000?l20?l000@0003o0P3o0005003o00@0o`002000o`020000o`T0o`000P000?l4
003o00D0003o3_oooolF0?n000<0o`002@3oP0040?l000030?n0003o0000o`000640oh006?ooool0
01Kooooo1@000?lD0?l000800?l00`3o00020000oa80o`000P000?lT0?l000<0003o1P3o00020000
o`030?l000000?l0003o00800?l0103o00000`00o`00o`000?l0000>0?l000800?l0103o00030000
o`800?l00P3o000>ooooo`80o`001@000?ld003o00L0o`000P000?l;0?l00080003o00<0o`00003o
0000o`003@00o`030000o`@0o`008P00o`0>ooooo`/00?l00`000?lM003o0080o`001@000?l7003o
00@0003o0P00o`020?l000<0003o1`00o`020?l000800?l01@000?l40?l000<0003o0P3o00040000
o`80o`001@00o`040?l000P00?l00P000?l90?l00080003o1000o`050000o`kooooo5P3oP0030?l0
00T0oh00103o00000`3oP000o`000?l0001Q0?n001Sooooo000Fooooo`800?l00P000?l70?l000<0
003o0P3o00020?n000@0o`0000<00?l00?l0003o00000P00o`0;0?l000030000o`3o0000o`000080
003o3P3o00020000o`@0o`000P000?l00`3o0000oh000?n000040000o`<0o`000P3oP00=0?l00003
0000o`3o0000o`000080o`0010000?l30?l00080003o1@3o00020000o`h0o`000P00o`070?l00080
003o0P3o000>ooooocT00?l0103o00040000o`030?l000000?l0003o00@0003o00<0o`000000o`00
0?l00P000?l20?l00080003o00<00?l00?l0003o00000P00o`050000o`800?l01P3o00030000o`@0
o`001`000?l2003o00030?l00000o`000?l001@00?l03_oooolK003o0080o`001@000?l5003o0080
o`000P000?l20?l000D0003o3`00o`050000o`800?l000<0o`00003o0000o`000P3o0002003o0080
003o00<0o`000000o`000?l0103o00030000o`P0o`001@00o`020000o`<00?l00P3o0002003o00/0
o`0000<0003o0?l0003o00002@00o`020000o`kooooo103oP0050?l00840oh006?ooool001Kooooo
0P00o`020000o`L0o`000`000?l20?l00080oh00103o00000`00o`00o`000?l00002003o00/0o`00
00<0003o0?l0003o00000P000?l>0?l00080003o103o00020000o`030?l0003oP000oh0000@0003o
0`3o00020?n000d0o`0000<0003o0?l0003o00000P3o00040000o`<0o`000P000?l50?l00080003o
3P3o0002003o00L0o`000P000?l20?l000kooooo>@00o`040?l000@0003o00<0o`000000o`000?l0
10000?l00`3o0000003o0000o`020000o`80o`000P000?l00`00o`00o`000?l00002003o00D0003o
0P00o`060?l000<0003o103o00070000o`800?l000<0o`00003o0000o`005000o`0>oooooa/00?l0
0P3o00050000o`D00?l00P3o00020000o`80o`001@000?l?003o00D0003o0P00o`000`3o00000?l0
003o00020?l000800?l00P000?l00`3o0000003o0000o`040?l000<0003o203o0005003o0080003o
0`00o`020?l000800?l02`3o00000`000?l0o`000?l00009003o0080003o3_ooool40?n000D0o`00
P@3oP00Hooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000Wooooog7o00009ooooomao`0002Oo
ooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`0iooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo
00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0
o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_oo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0
o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04
oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooo
oaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
1?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1Ooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaOo0?l07ooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOo
o`001?l007lGo`3o01oo001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
1?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaOo0?l07ooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5ol0o`0OoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l0
0ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol007l0
0ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1^o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03
o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooog;o00009ooooomao`0002Oo
ooooLOl0000Wooooog;o00008oooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool001Ko
oooo5P3o00000`3oP000o`000?l0000>0?l00080oh001P3o00030?n005P0o`003_ooool@003o00T0
003o1@00o`040?n00080o`000P3oP005003o00L0003o1P00o`000`3oP0000?l0003o00040?n00080
003o00<0oh00003o0000o`000P00o`020?n000T0o`000`00o`020000o`D00?l0103oP002003o0080
o`000`3oP006003o00<0003o0P3oP002003o00030?n00000o`000?l000H00?l00`3oP0020000o`80
0?l01@000?l20?n000koooooE0000?l2003o0100003o0P00o`0R0000o`kooooo0P3oP003003o00@0
oh000P3o00020?n000030?l000000?l0003o0080003o103oP003003o0080oh001@00o`020000o`@0
0?l00`3oP0020000o`800?l00`3oP004003o00@0oh000`3o00070?n00080o`00103oP003003o0080
oh001000o`000`3oP000003o0000o`020000o`@0oh0000<0o`000?n0003oP0001000o`020?n00003
0000o`3oP000oh0000@00?l00P3oP0000`00o`00oh000?n000020?l000<0oh000P00o`040?n00080
o`0000<0oh000?l0003o00000P3oP0020?l000<0oh001000o`0Hooooo`005_oooolF0?l000030?n0
003o0000o`0000h0o`000P3oP0060?l000<0oh00F03o000>oooooa000?l02@000?l5003o00@0oh00
0P3o00020?n000D00?l01`000?l6003o00030?n00000o`000?l000@0oh000P000?l00`3oP0000?l0
003o0002003o0080oh002@3o0003003o0080003o1@00o`040?n000800?l00P3o00030?n000H00?l0
0`000?l20?n000800?l000<0oh00003o0000o`001P00o`030?n00080003o0P00o`050000o`80oh00
3_oooomD0000o`800?l040000?l2003o0280003o3_ooool20?n000<00?l0103oP0020?l00080oh00
00<0o`000000o`000?l00P000?l40?n000<00?l00P3oP005003o0080003o1000o`030?n00080003o
0P00o`030?n000@00?l0103oP0030?l000L0oh000P3o00040?n000<00?l00P3oP004003o00030?n0
00000?l0003o0080003o103oP0000`3o0000oh000?n00004003o0080oh0000<0003o0?n0003oP000
1000o`020?n00003003o003oP000oh000080o`000`3oP002003o00@0oh000P3o00000`3oP000o`00
0?l000020?n00080o`000`3oP004003o01Sooooo000Fooooo`80oh002`3o00000`3oP000o`000?l0
000G0?l00080oh001`3o00020?n00080o`000P000?l30?l00080oh00<P3o00020?n001/0o`003_oo
ool2003o00<0003o2000o`090000o`D00?l00P000?l00`00o`00oh000?n000060?n000<00?l02@00
0?l;003o0080oh001@00o`040?n000D0o`000P3oP0020000o`03003o00000?l0003o0080003o1@00
o`060?n00080o`001`3oP003003o0080003o1000o`000`3oP000o`000?l000020000o`800?l01@3o
P009003o0080oh003_oooomO0000o`80oh000`000?l20?n000@00?l070000?l4003o00kooooo0P3o
0003003o0080003o1P3oP00<003o0080oh000P3o0009003o00<0oh001000o`020?n00003003o003o
P000oh0000@00?l00P000?l00`3oP000o`000?l000020?n000800?l00`3oP0040?l000D00?l00P3o
P005003o00@0003o103oP0000`3o0000oh000?n000040?l000<0oh000P00o`090?n000L0o`000P3o
P0020?l00080oh001`3o00030?n000@00?l06?ooool001Kooooo0P3oP00;0?l000030?n0003o0000
o`0001L0o`000P3oP0070?l00080oh000P3o00020000o`<0o`000P3oP00b0?l00080oh006`3o000>
ooooo`800?l00`000?l8003o00T0003o1@00o`020000o`03003o003oP000oh0000H0oh000`00o`09
0000o`/00?l00P3oP005003o00@0oh001@3o00020?n00080003o00<00?l00000o`000?l00P000?l5
003o00H0oh000P3o00070?n000<00?l00P000?l4003o00030?n0003o0000o`000080003o0P00o`05
0?n000T00?l00P3oP00>oooooel0003o0P3oP0030000o`80oh001000o`0L0000o`@00?l03_ooool2
0?l000<00?l00P000?l60?n000`00?l00P3oP0020?l000T00?l00`3oP004003o0080oh0000<00?l0
0?n0003oP0001000o`020000o`030?n0003o0000o`000080oh000P00o`030?n000@0o`001@00o`02
0?n000D00?l010000?l40?n000030?l0003oP000oh0000@0o`000`3oP002003o00T0oh001`3o0002
0?n00080o`000P3oP0070?l000<0oh001000o`0Hooooo`005_ooool`0?l00080oh000P3o00020?n0
0100o`000`3oP00_0?l00080oh00403o000>ooooo`D00?l03`000?l7003o0080003o00<00?l00000
o`000?l01P000?l00`00o`00003o0000o`0;0000o`T00?l0103oP0000`3o0000oh000?n000020?n0
00800?l000<0oh000?l0003o00000P3o00020?n000<00?l00P000?l7003o00@0oh00103o00030?n0
00T00?l01@3oP008003o00D0oh001000o`000`3oP0000?l0003o00020?n000koooooB@000?l20?n0
00@0003o0P00o`070000o`800?l030000?l40?n000D00?l00P000?l3003o01H0003o3_ooool5003o
0080003o103oP0020?l000030?n0003o0000o`000080o`000P00o`030?l00080oh00103o0003003o
00@0003o0P00o`030?n000800?l0103oP0000`00o`00o`000?l000020?l000800?l00P3oP0050?l0
00@0oh0000<0o`000?n0003oP0000P3oP0020000o`030?n00000o`000?l000T0003o0P00o`050?n0
00@0o`002`3oP00<0?l00080oh000P3o00020?n000T0o`0000<0oh000?l0003o00000P000?lHoooo
o`005_ooool;0?l00080oh008`3o00020?n00080o`000P3oP0170?l000@0oh000P3o00020?n000D0
o`003_ooool7003o00d0003o1`00o`030000o`T00?l04@000?l00`00o`00003o0000o`040000o`80
oh001@3o00030000o`800?l00P3o0009003o0080oh000`00o`020?n00080o`000P00o`020?l00003
0?n0003o0000o`0000/00?l00P3oP009003o00030?n00000o`000?l000800?l00P3oP007003o00ko
oooo4P000?l2003o0380003o0P3oP0000`000?l0oh000?n000020?n000@00?l00`000?l20?n000L0
0?l02`000?l20?n00080003o0`3oP0020000o`80oh002@000?l00`00o`00003o0000o`0;0000o`ko
oooo0P00o`020?l00003003o00000?l0003o00H0oh0000<0o`000?n0003oP000103o00020?n000D0
o`001`00o`020?n000T00?l02@3oP0020000o`<0oh000P00o`020?n000800?l00`3oP007003o0080
oh000P000?l50?n000@00?l00P3oP0030?l000@00?l00P3oP0030?l00080oh00503o00000`3oP000
o`000?l000070?l000@00?l06?ooool001Kooooo2`3o00020?n002<0o`000P3oP0020?l00080oh00
A`3o00040?n00080o`000P3oP0050?l000kooooo1`00o`0=0000o`L00?l00`000?l9003o0140003o
00<00?l00000o`000?l010000?l20?n000D0o`000`000?l2003o0080o`002@00o`020?n000<00?l0
0P3oP0020?l000800?l00P3o00000`3oP000o`000?l0000;003o0080oh002@00o`000`3oP0000?l0
003o0002003o0080oh001`00o`0>oooooa80003o0P00o`0b0000o`80oh0000<0003o0?n0003oP000
0P3oP004003o00<0003o0P3oP007003o00/0003o0P3oP0020000o`<0oh000P000?l20?n000T0003o
00<00?l00000o`000?l02`000?l>ooooo`800?l00P3o00000`00o`00003o0000o`060?n000030?l0
003oP000oh0000@0o`000P3oP0050?l000L00?l00P3oP009003o00T0oh000P000?l30?n000800?l0
0P3oP002003o00<0oh001`00o`020?n00080003o1@3oP004003o0080oh000`3o0004003o0080oh00
0`3o00020?n001@0o`0000<0oh000?l0003o00001`3o0004003o01Sooooo000Fooooo`/0o`000P3o
P0000`3o0000oh000?n000040?l00080oh006P3o00020?n000T0o`000P3oP00@0?l00080oh00=03o
00020?n000D0o`003_oooolF0000o`D00?l00`000?l6003o0080oh000`00o`0F0000o`800?l000<0
oh000000o`000?l00P00o`020000o`03003o003oP000oh0000L00?l00P000?l40?n000<00?l01P00
0?l30?n000P0003o00<00?l00000o`000?l00P00o`020?n000<0003o1000o`070000o`80oh001`00
o`0>oooooaH0003o00<00?l00000o`000?l0:`000?l20?n000<0003o103oP004003o00D0003o1`3o
P00@0000o`80oh002@000?l20?n000<0003o0P00o`040000o`D00?l00P000?l>ooooo`80oh000P3o
0005003o00@0oh000`3o00020?n000800?l01`3o00020?n00003003o00000?l0003o00@00?l00P3o
P0000`00o`00oh000?n00004003o00<0oh002000o`030?n000@0o`000`3oP004003o00D0003o0P3o
P0020000o`80o`0000<0oh00003o0000o`001000o`020?n000D0o`000P000?l20?n000<0o`00103o
P0020?l000030?n0003o0000o`000080oh000P3o00030?n000d0o`001@3oP002003o01Sooooo000F
ooooo`/0o`000P3oP0000`3o0000oh000?n000040?l00080oh006P3o00020?n000T0o`000P3oP00@
0?l00080oh00=03o00020?n000D0o`003_oooolF0000o`D00?l00`000?l6003o0080oh000`00o`0F
0000o`800?l000<0oh000000o`000?l00P00o`020000o`03003o003oP000oh0000L00?l00P000?l4
0?n000<00?l01P000?l30?n000P0003o00<00?l00000o`000?l00P00o`020?n000<0003o1000o`07
0000o`80oh001`00o`0>oooooaH0003o00<00?l00000o`000?l0:`000?l20?n000<0003o103oP004
003o00D0003o1`3oP00@0000o`80oh002@000?l20?n000<0003o0P00o`040000o`D00?l00P000?l>
ooooo`80oh000P3o0005003o00@0oh000`3o00020?n000800?l01`3o00020?n00003003o00000?l0
003o00@00?l00P3oP0000`00o`00oh000?n00004003o00<0oh002000o`030?n000@0o`000`3oP004
003o00D0003o0P3oP0020000o`80o`0000<0oh00003o0000o`001000o`020?n000D0o`000P000?l2
0?n000<0o`00103oP0020?l000030?n0003o0000o`000080oh000P3o00030?n000d0o`001@3oP002
003o01Sooooo000Foooooad0o`0000<0oh000?l0003o00000P3oP00I0?l00080oh00C@3o000>oooo
oa@0003o1`00o`030000o`80oh002@00o`0?0000o`<00?l02@000?l20?n000D0003o2@00o`020?n0
00800?l040000?l4003o00<0003o4P00o`020?n000D00?l00P000?l>ooooobH0003o00<0oh000000
o`000?l07@000?l5003o0080oh001000o`050000o`@0oh002P000?l20?n000/0003o0P00o`050000
o`L00?l01`000?l20?n00080003o3_ooool20?n00080o`0000<0oh00003o0000o`000P3o00040?n0
00<0o`000P3oP002003o00<0oh000P3o0007003o00@0003o0P3oP0030000o`H0oh0000<0o`000?n0
003oP0001P3oP0000`3o0000oh000?n000020?n00080o`000`3oP0020?l000@0oh000`00o`040?n0
00<0o`00103oP0020000o`80oh000`000?l20?n000D00?l0103oP0040?l000X0oh00403o00020?n0
00800?l06?ooool001Kooooo7@3o00000`3oP000o`000?l000020?n001T0o`000P3oP01=0?l000ko
oooo50000?l7003o00<0003o0P3oP009003o00l0003o0`00o`090000o`80oh001@000?l9003o0080
oh000P00o`0@0000o`@00?l00`000?lB003o0080oh001@00o`020000o`kooooo9P000?l00`3oP000
003o0000o`0M0000o`D00?l00P3oP004003o00D0003o103oP00:0000o`80oh002`000?l2003o00D0
003o1`00o`070000o`80oh000P000?l>ooooo`80oh000P3o00000`3oP0000?l0003o00020?l000@0
oh000`3o00020?n000800?l00`3oP0020?l000L00?l010000?l20?n000<0003o1P3oP0000`3o0000
oh000?n000060?n000030?l0003oP000oh000080oh000P3o00030?n00080o`00103oP003003o00@0
oh000`3o00040?n00080003o0P3oP0030000o`80oh001@00o`040?n000@0o`002P3oP00@0?l00080
oh000P00o`0Hooooo`005_ooool`0?l00080oh00?`3o00020?n001L0o`003_ooool20000o`D00?l0
3@000?l7003o00<0003o103oP002003o0080oh000`00o`0?0000o`03003o00000?l0003o0100003o
1000o`020000o`<00?l04P000?l4003o00T0003o00<00?l00000o`000?l00P000?l4003o00030?n0
0000o`000?l000T00?l00P000?l>oooood80003o0P00o`070000o`@0oh000`00o`0B0000o`80oh00
0P00o`0G0000o`800?l00P000?l3003o00@0003o3_ooool20?l000D0oh000P3o00020?n000<0003o
0P3oP002003o0080oh000P00o`000`3oP000o`000?l00007003o00H0003o1@3oP004003o00030?n0
0000o`000?l000/0oh000P3o00020?n000D0o`000`3oP002003o0080oh001@3o00040?n00080o`00
0`00o`040?n000D00?l0103oP0020?l00080oh0000<0o`000?n0003oP000103oP0000`3o0000oh00
0?n000020?l00080oh000P3o00000`00o`00o`000?l000020?l000D00?l00P000?l20?n001Sooooo
000Fooooo`D0o`000P3oP00Y0?l00080oh000P3o00020?n000`0o`000P3oP0160?l000kooooo0P00
0?l>003o00@0003o1`00o`030000o`80oh001`00o`0A0000o`<00?l00P000?l7003o00/0003o1@00
o`0@0000o`P00?l01@000?l9003o0080003o1@00o`020?n00080003o1@00o`0>oooooa00003o1000
o`0I0000o`L00?l02@000?l4003o00L0003o00<00?l00000o`000?l0103oP003003o00/0003o0P3o
P00P0000o`800?l01@000?l20?n000800?l03_ooool40?n000D0o`002`000?l2003o00030?n0003o
0000o`0000@00?l00`3oP0020000o`800?l00P000?l90?n000<00?l0103oP0030?l00080oh002@3o
00020?n000D00?l00P3oP00;0?l000<00?l0203oP0000`00o`00oh000?n000020?n00080o`000`3o
P0020?l000@0oh001@00o`040000o`03003o00000?l0003o0080oh000P00o`020?n000D00?l06?oo
ool001Kooooo1@3o00020?n002T0o`000P3oP0020?l00080oh00303o00020?n004H0o`003_ooool2
0000o`h00?l010000?l7003o00<0003o0P3oP007003o0140003o0`00o`020000o`L00?l02`000?l5
003o0100003o2000o`050000o`T00?l00P000?l5003o0080oh000P000?l5003o00kooooo40000?l4
003o01T0003o1`00o`090000o`@00?l01`000?l00`00o`00003o0000o`040?n000<00?l02`000?l2
0?n00200003o0P00o`050000o`80oh000P00o`0>ooooo`@0oh001@3o000;0000o`800?l000<0oh00
0?l0003o00001000o`030?n00080003o0P00o`020000o`T0oh000`00o`040?n000<0o`000P3oP009
0?l00080oh001@00o`020?n000/0o`000`00o`080?n00003003o003oP000oh000080oh000P3o0003
0?n00080o`00103oP005003o00@0003o00<00?l00000o`000?l00P3oP002003o0080oh001@00o`0H
ooooo`005_ooool20?l00080oh00;03o00020?n00080o`000P3oP00@0?l000<0oh00;@3o00020?n0
00T0o`00103oP0050?l000kooooo1`00o`040000o`D00?l02@000?l2003o0080003o00<00?l00?n0
003oP0000P00o`020?l000800?l030000?l9003o0080003o0P00o`020?n000L00?l000<0003o003o
0000o`000P00o`020?n000<00?l04@000?l7003o00T0003o2@00o`030?n000/00?l03_oooolD0000
o`80oh005@000?l2003o0080oh000`00o`0F0000o`<00?l0103oP00k0000o`kooooo0P3oP0030?l0
0080oh000P3o0002003o00L0003o103oP0030?l000@00?l01`3oP002003o00030?n0003o0000o`00
0080o`000P3oP005003o0080003o0P3oP002003o00030?n0003o0000o`000080oh00103o00000`3o
P000o`000?l000040?l000<00?l00P3oP0020000o`L0o`001@00o`060?n000<00?l00P3oP0040?l0
0080oh000`3o00020?n00080o`0000<0oh000000o`000?l01000o`050000o`80oh000P3o00020?n0
00030?l00000o`000?l00080o`006?ooool001Kooooo0P3o00020?n002`0o`000P3oP0020?l00080
oh00403o00030?n002d0o`000P3oP0090?l000@0oh001@3o000>ooooo`L00?l010000?l5003o00T0
003o0P00o`020000o`03003o003oP000oh0000800?l00P3o0002003o00`0003o2@00o`020000o`80
0?l00P3oP007003o00030000o`00o`000?l000800?l00P3oP003003o0140003o1`00o`090000o`T0
0?l00`3oP00;003o00kooooo50000?l20?n001D0003o0P00o`020?n000<00?l05P000?l3003o00@0
oh00>`000?l>ooooo`80oh000`3o00020?n00080o`000P00o`070000o`@0oh000`3o0004003o00L0
oh000P00o`000`3oP000o`000?l000020?l00080oh001@00o`020000o`80oh000P00o`000`3oP000
o`000?l000020?n000@0o`0000<0oh000?l0003o0000103o0003003o0080oh000P000?l70?l000D0
0?l01P3oP003003o0080oh00103o00020?n000<0o`000P3oP0020?l000030?n000000?l0003o00@0
0?l01@000?l20?n00080o`000P3oP0000`3o00000?l0003o00020?l001Sooooo000Fooooo`h0o`00
0P3oP0070?l00080oh00103o00000`3oP000o`000?l0000X0?l000030?n0003o0000o`000080o`00
0P3oP0070?l00080oh00:@3o00040?n000D0o`003_ooool4003o00030000o`00o`000?l000L0003o
0P00o`0=0000o`D0oh000P00o`020?n000030000o`00o`000?l000T0003o2`00o`020000o``00?l0
1P3oP0000`00o`00003o0000o`04003o00D0003o1000o`0<0000o`H00?l00`3oP004003o0080003o
0`3oP002003o0080o`000P000?l00`00o`00oh000?n00002003o00kooooo50000?l2003o01X0003o
0P00o`0_0000o`800?l09`000?l>ooooo`@0oh001@3o00020?n000<00?l010000?l50?n000L00?l0
0P3oP002003o00L0oh00103o0007003o0080oh000`00o`020?n000800?l00P3o00090?n000<00?l0
0P000?l2003o00L0o`000P3oP003003o00@0oh000P3o0002003o00030000o`3oP000oh000080o`00
1000o`000`3oP000003o0000o`0@0000o`H0oh000`3o00020?n001Sooooo000Fooooo`h0o`000P3o
P0070?l00080oh00103o00000`3oP000o`000?l0000X0?l000030?n0003o0000o`000080o`000P3o
P0070?l00080oh00:@3o00040?n000D0o`003_ooool4003o00030000o`00o`000?l000L0003o0P00
o`0=0000o`D0oh000P00o`020?n000030000o`00o`000?l000T0003o2`00o`020000o``00?l01P3o
P0000`00o`00003o0000o`04003o00D0003o1000o`0<0000o`H00?l00`3oP004003o0080003o0`3o
P002003o0080o`000P000?l00`00o`00oh000?n00002003o00kooooo50000?l2003o01X0003o0P00
o`0_0000o`800?l09`000?l>ooooo`@0oh001@3o00020?n000<00?l010000?l50?n000L00?l00P3o
P002003o00L0oh00103o0007003o0080oh000`00o`020?n000800?l00P3o00090?n000<00?l00P00
0?l2003o00L0o`000P3oP003003o00@0oh000P3o0002003o00030000o`3oP000oh000080o`001000
o`000`3oP000003o0000o`0@0000o`H0oh000`3o00020?n001Sooooo000Foooooad0o`0000<0oh00
0?l0003o00000P3oP0070?l00080oh008P3o00020?n00380o`00103oP0050?l000kooooo3@000?l3
003o00L0003o0P00o`040000o`<0oh002`00o`070000o`800?l00P000?l5003o00@0003o0`00o`02
0?n000800?l00P3oP003003o00H0oh005`00o`020?n000X00?l00P3oP006003o00D0oh000P3o0002
0?n000030000o`3oP000oh0000800?l03_oooolk0000o`H00?l01`000?l00`00o`00003o0000o`0o
0000o`kooooo103oP0000`3o0000oh000?n000020?l000D00?l010000?l40?n000D00?l00P3oP005
003o0080oh000P3o00000`3oP000o`000?l000020?l00080oh001@00o`040?n00080o`001@3oP002
0?l000<0oh000P3o00020?n00080o`0000<0oh00003o0000o`001P000?l50?l000@00?l000<0003o
0?n0003oP0001000o`020?n000030000o`3oP000oh0000@0oh000P00o`000`3o00000?l0003o0005
003o0080oh000P00o`070000o`80oh001@00o`040?n001Sooooo000Foooooad0o`0000<0oh000?l0
003o00000P3oP0070?l00080oh008P3o00020?n00380o`00103oP0050?l000kooooo3@000?l3003o
00L0003o0P00o`040000o`<0oh002`00o`070000o`800?l00P000?l5003o00@0003o0`00o`020?n0
00800?l00P3oP003003o00H0oh005`00o`020?n000X00?l00P3oP006003o00D0oh000P3o00020?n0
00030000o`3oP000oh0000800?l03_oooolk0000o`H00?l01`000?l00`00o`00003o0000o`0o0000
o`kooooo103oP0000`3o0000oh000?n000020?l000D00?l010000?l40?n000D00?l00P3oP005003o
0080oh000P3o00000`3oP000o`000?l000020?l00080oh001@00o`040?n00080o`001@3oP0020?l0
00<0oh000P3o00020?n00080o`0000<0oh00003o0000o`001P000?l50?l000@00?l000<0003o0?n0
003oP0001000o`020?n000030000o`3oP000oh0000@0oh000P00o`000`3o00000?l0003o0005003o
0080oh000P00o`070000o`80oh001@00o`040?n001Sooooo000Foooooad0o`0000<0oh000?l0003o
00007@3o00020?n004/0o`003_ooool20000o`80oh0000<0003o003o0000o`003`000?l5003o00<0
003o1P00o`020?n000D00?l02`000?l5003o0080003o1@00o`020?n000D0o`000P3oP0060?l000X0
0?l00P3oP00=003o00<0003o1`00o`020?n000H00?l00`3oP0060?l000D00?l03_oooolk0000o`H0
0?l01`000?l00`00o`00003o0000o`0o0000o`kooooo0P000?l50?n00080o`000P3oP005003o0080
003o103oP0000`000?l0oh000?n000040?n000<00?l00P000?l50?n000800?l01P3oP0000`00o`00
o`000?l000040?n00080o`000`3oP0020?l000800?l00`3oP0060?l000030?n00000o`000?l000H0
0?l00`3oP0020000o`@00?l000<0oh00003o0000o`001P00o`030?n000@00?l00P3o00080?n00080
o`001`00o`020000o`@0oh000`000?l40?n001Sooooo000Fooooo`/0o`000P3oP00@0?l000030?n0
003o0000o`000100o`00103oP0090?l00080oh000`3o00020?n001H0o`0000<0oh000?l0003o0000
3`3o00000`3oP000o`000?l0000K0?l000kooooo5`000?l2003o00/0003o0P3oP005003o00/0003o
0P00o`000`000?l00?l0003o00020?n000@00?l01@3oP0030?l000@0oh000P000?l20?l000<00?l0
0P3oP00=003o00030?n00000o`000?l000@00?l00P000?l00`3oP0000?l0003o00040000o`030?n0
00000?l0003o00800?l010000?l70?n000L00?l03_oooolk0000o`H00?l0<P000?l00`00o`00003o
0000o`0D0000o`kooooo0P00o`050?n00080o`00103oP005003o00D0oh000P00o`040?n00003003o
003oP000oh0000800?l0103oP0000`00o`00o`000?l000020000o`80oh000P3o0003003o0080oh00
0P00o`050?l000@00?l00P000?l<0?n000@00?l01`3oP003003o0080oh000P00o`040?n00003003o
003oP000oh000080oh00103o00000`3oP0000?l0003o00020?l000<0oh000P3o00020?n000h00?l0
103oP00Hooooo`005_ooool;0?l00080oh00403o00000`3oP000o`000?l0000@0?l000@0oh002@3o
00020?n000<0o`000P3oP00F0?l000030?n0003o0000o`0000l0o`0000<0oh000?l0003o00006`3o
000>oooooaL0003o0P00o`0;0000o`80oh001@00o`0;0000o`800?l000<0003o003o0000o`000P3o
P004003o00D0oh000`3o00040?n00080003o0P3o0003003o0080oh003@00o`000`3oP0000?l0003o
0004003o0080003o00<0oh00003o0000o`0010000?l00`3oP000003o0000o`02003o00@0003o1`3o
P007003o00kooooo>`000?l6003o0380003o00<00?l00000o`000?l050000?l>ooooo`800?l01@3o
P0020?l000@0oh001@00o`050?n000800?l0103oP0000`00o`00oh000?n00002003o00@0oh0000<0
0?l00?l0003o00000P000?l20?n00080o`000`00o`020?n000800?l01@3o0004003o0080003o303o
P004003o00L0oh000`00o`020?n000800?l0103oP0000`00o`00oh000?n000020?n000@0o`0000<0
oh00003o0000o`000P3o00030?n00080o`000P3oP00>003o00@0oh006?ooool001Kooooo2`3o0002
0?n002<0o`000P3oP0070?l00080oh000P3o00020?n000L0o`000P3oP0120?l000kooooo0P000?l2
003o00030000o`00o`000?l00180003o1@00o`020000o`800?l05`000?l2003o0080oh000P00o`05
0?n000L0o`000P3oP002003o0080o`000`00o`090?n000H0003o00<0oh00003o0000o`001000o`02
0000o`030?n00000o`000?l000d00?l00`3oP0020000o`80oh000`00o`040?n000koooooF0000?l2
003o0300003o3_ooool2003o00D0oh00103o0002003o00030?n00000o`000?l000800?l01@3oP002
0?l000@0oh001@00o`020?n000L00?l0103o0003003o00@0oh000`3o00040?n000800?l00`000?l6
0?n000<0o`000P3oP004003o00D0oh001000o`030?n000@00?l02@3oP0020?l000030?n0003o0000
o`000080o`001@00o`020?n00080o`000P3oP005003o0080003o0P00o`050?n001Sooooo000Foooo
o`/0o`000P3oP00S0?l00080oh001`3o00020?n00080o`000P3oP0070?l00080oh00@P3o000>oooo
o`80003o0P00o`000`000?l00?l0003o000B0000o`D00?l00P000?l2003o01L0003o0P00o`020?n0
00800?l01@3oP0070?l00080oh000P00o`020?l000<00?l02@3oP0060000o`030?n00000o`000?l0
00@00?l00P000?l00`3oP0000?l0003o000=003o00<0oh000P000?l20?n000<00?l0103oP00>oooo
oeP0003o0P00o`0`0000o`kooooo0P00o`050?n000@0o`000P00o`000`3oP0000?l0003o0002003o
00D0oh000P3o00040?n000D00?l00P3oP007003o00@0o`000`00o`040?n000<0o`00103oP002003o
00<0003o1P3oP0030?l00080oh001000o`050?n000@00?l00`3oP004003o00T0oh000P3o00000`3o
P000o`000?l000020?l000D00?l00P3oP0020?l00080oh001@00o`020000o`800?l01@3oP00Hoooo
o`005_ooool50?l00080oh00103o00020?n000X0o`000P3oP00P0?l00080oh000P3o00020?n000L0
o`000P3oP0090?l000030?n0003o0000o`000340o`0000<0oh000?l0003o00000P3o000>ooooo`d0
003o0`00o`0;0000o`T00?l04P000?l5003o0080oh001@000?l60?n000030?l0003oP000oh000080
o`001@3oP0020000o`@0oh000P00o`000`3oP0000?l0003o0004003o0080003o00<0oh000000o`00
0?l01000o`030000o`d00?l01`000?l20?n000800?l000<0003o003o0000o`000P3oP00>ooooo`80
0?l0@0000?l2003o00L0003o0P3oP0020000o`800?l08`000?l20?n000L0003o2@00o`040000o`ko
oooo0P00o`030?n000H0o`001`3oP0020?l00080oh0000<0o`000?n0003oP0000P00o`030?n000T0
0?l00P3oP002003o00@0o`0000<0oh000?l0003o00000P000?l50?n000P00?l00`3oP0020?l000<0
oh000P3o00020?n00080o`000`00o`040?n00080o`000P3oP0000`00o`00oh000?n00002003o00L0
oh000P00o`020?l00080oh0020000?l40?n000@0o`0000<0oh00003o0000o`000P3oP002003o0080
oh0000<0o`00003o0000o`000P3oP00Hooooo`005_ooool50?l00080oh00103o00020?n000X0o`00
0P3oP00P0?l00080oh000P3o00020?n000L0o`000P3oP0090?l000030?n0003o0000o`000340o`00
00<0oh000?l0003o00000P3o000>ooooo`d0003o0`00o`0;0000o`T00?l04P000?l5003o0080oh00
1@000?l60?n000030?l0003oP000oh000080o`001@3oP0020000o`@0oh000P00o`000`3oP0000?l0
003o0004003o0080003o00<0oh000000o`000?l01000o`030000o`d00?l01`000?l20?n000800?l0
00<0003o003o0000o`000P3oP00>ooooo`800?l0@0000?l2003o00L0003o0P3oP0020000o`800?l0
8`000?l20?n000L0003o2@00o`040000o`kooooo0P00o`030?n000H0o`001`3oP0020?l00080oh00
00<0o`000?n0003oP0000P00o`030?n000T00?l00P3oP002003o00@0o`0000<0oh000?l0003o0000
0P000?l50?n000P00?l00`3oP0020?l000<0oh000P3o00020?n00080o`000`00o`040?n00080o`00
0P3oP0000`00o`00oh000?n00002003o00L0oh000P00o`020?l00080oh0020000?l40?n000@0o`00
00<0oh00003o0000o`000P3oP002003o0080oh0000<0o`00003o0000o`000P3oP00Hooooo`005_oo
oolF0?l000<0oh001`3o00020?n000@0o`0000<0oh000?l0003o0000:03o00000`3oP000o`000?l0
000]0?l00080oh001`3o000>ooooo`d0003o0`00o`0;0000o`L00?l010000?l00`00o`00003o0000
o`020000o`D00?l010000?l7003o0080003o1000o`030?n000D00?l01P3oP0020?l000030?n00000
o`000?l00080003o0P3oP00>003o00/0003o2`00o`030?n000@00?l00P3oP005003o00kooooo1000
o`150000o`800?l01P000?l00`3oP000003o0000o`0D0000o`@00?l04@000?l8003o00<0003o0P00
o`0>ooooo`D0oh00103o00020000o`800?l01@3oP0050?l000@00?l01@3oP0020?l000D00?l04P3o
P002003o0080oh001000o`000`3oP0000?l0003o00040?l000030?n0003o0000o`000080003o1`3o
P0020?l00080oh000P00o`030?n00080o`000P00o`030?n000800?l01P3oP003003o0080oh000`00
0?l40?n00080o`000`00o`090?n000@00?l06?ooool001Kooooo5P3o00030?n000L0o`000P3oP004
0?l000030?n0003o0000o`0002P0o`0000<0oh000?l0003o0000;@3o00020?n000L0o`003_ooool=
0000o`<00?l02`000?l7003o00@0003o00<00?l00000o`000?l00P000?l5003o00@0003o1`00o`02
0000o`@00?l00`3oP005003o00H0oh000P3o00000`3oP0000?l0003o00020000o`80oh003P00o`0;
0000o`/00?l00`3oP004003o0080oh001@00o`0>ooooo`@00?l0A@000?l2003o00H0003o00<0oh00
0000o`000?l050000?l4003o0140003o2000o`030000o`800?l03_ooool50?n000@0o`000P000?l2
003o00D0oh001@3o0004003o00D0oh000P3o0005003o0180oh000P00o`020?n000@00?l000<0oh00
003o0000o`00103o00000`3oP000o`000?l000020000o`L0oh000P3o00020?n000800?l00`3oP002
0?l000800?l00`3oP002003o00H0oh000`00o`020?n000<0003o103oP0020?l000<00?l02@3oP004
003o01Sooooo000Fooooo`80oh00503o00000`3oP000o`000?l000040?l000030?n0003o0000o`00
0080oh001@3o0002003o0080oh00103o00000`3oP000o`000?l0001?0?l00080oh001`3o000>oooo
o`d0003o0`00o`0>0000o`T00?l03@000?l4003o00T0003o1@3oP0020?l000L0oh000P3o00050000
o`80oh000P000?l00`00o`00oh000?n0000;003o00L0003o0P00o`050000o`L00?l0103oP0020000
o`80oh001@00o`0>ooooo`800?l05@000?l2003o02/0003o1`00o`090000o`800?l03P000?l20?n0
01L0003o0P3oP002003o0080oh000P00o`050000o`kooooo103oP0000`3o0000oh000?n000040?n0
0080o`0000<0003o0?l0003o00000P3oP0040?l000030?n00000o`000?l000800?l00P000?l3003o
0080oh000P3o00030?n000800?l0103oP0050?l00080oh00103o0009003o00030?n00000o`000?l0
0080o`000P3oP0000`000?l0oh000?n000090?n000@0o`000P000?l00`3oP000003o0000o`02003o
00@0oh000`3o00060?n000030000o`3oP000oh0000D00?l0103oP002003o0080oh000`00o`060?n0
00030?l000000?l0003o0080003o6?ooool001Kooooo1@3o00020?n00280o`000P3oP0040?l00003
0?n0003o0000o`0000d0o`000P3oP0030?l00080oh00503o00000`3oP000o`000?l0000T0?l00080
oh001`3o000>oooooah0003o1P00o`0>0000o`800?l01`000?l6003o00<0oh000P00o`050?n00080
003o0P3o00020?n000<00?l00P000?l20?n001@00?l00`000?l=003o00030000o`3oP000oh000080
oh000P000?l2003o00030?n00000o`000?l000800?l03_ooool=0000o`03003o00000?l0003o01/0
003o0P00o`0I0000o`80oh0000<0003o003o0000o`001P000?l00`3oP000003o0000o`020?n000L0
003o1P00o`070000o`80oh004@000?l40?n00080o`000P00o`000`000?l00?l0003o0002003o00ko
oooo103oP0000`3o0000oh000?n00002003o0080003o0P3oP005003o00@0oh001@00o`020000o`<0
0?l03@3oP0030?l000@0oh000P3o00020?n000030?l00000o`000?l00080oh000P00o`050000o`80
oh000P3o00000`000?l00?l0003o00020?n000800?l00`3oP002003o0080o`000P3oP0020000o`03
0?n000000?l0003o0080003o0P3oP0050?l00080oh000P3o00050?n000800?l00P3oP0050000o`80
oh001@00o`040?n000800?l000<0o`00003o0000o`000P00o`0Hooooo`005_ooool50?l00080oh00
8P3o00020?n000@0o`0000<0oh000?l0003o00003@3o00020?n000<0o`000P3oP00D0?l000030?n0
003o0000o`0002@0o`000P3oP0070?l000kooooo7P000?l6003o00h0003o0P00o`070000o`H00?l0
0`3oP002003o00D0oh000P000?l20?l00080oh000`00o`020000o`80oh005000o`030000o`d00?l0
00<0003o0?n0003oP0000P3oP0020000o`800?l000<0oh00003o0000o`000P00o`0>ooooo`d0003o
00<00?l00000o`000?l06`000?l2003o01T0003o0P3oP0000`000?l00?l0003o00060000o`030?n0
00000?l0003o0080oh001`000?l6003o00L0003o0P3oP00A0000o`@0oh000P3o0002003o00030000
o`00o`000?l000800?l03_ooool40?n000030?l0003oP000oh0000800?l00P000?l20?n000D00?l0
103oP005003o0080003o0`00o`0=0?n000<0o`00103oP0020?l00080oh0000<0o`00003o0000o`00
0P3oP002003o00D0003o0P3oP0020?l000030000o`00o`000?l00080oh000P00o`030?n000800?l0
0P3o00020?n00080003o00<0oh000000o`000?l00P000?l20?n000D0o`000P3oP0020?l000D0oh00
0P00o`020?n000D0003o0P3oP005003o00@0oh000P00o`000`3o00000?l0003o0002003o01Sooooo
000Fooooo`/0o`000P3oP00[0?l000030?n0003o0000o`0000@0oh009`3o00020?n000@0o`0000<0
oh000?l0003o00006`3o000>ooooo`80003o0P00o`0J0000o`P00?l05@000?l2003o0080oh000`00
0?l60?n000<0o`000P000?l40?n000<00?l00P000?l50?n001400?l00`000?l2003o00<0003o2@00
o`020000o`80oh000P000?l20?n00003003o00000?l0003o00800?l03_oooolI0000o`800?l04000
0?l4003o00030000o`00o`000?l000800?l05@000?l20?n000800?l01`000?l20?n000800?l00`3o
P0020000o`80oh001000o`030000o`80oh0010000?l7003o00D0003o0P00o`050000o`80oh000P00
0?l2003o00030000o`00o`000?l00080003o3_ooool20000o`<0oh000P3o0002003o00@0oh001@3o
0002003o0080003o0`00o`040000o`D00?l0103oP0030?l000800?l00P3oP0090?l00080oh0000<0
o`00003o0000o`000P3oP007003o0080oh000P3o00000`3oP000o`000?l000020000o`@0oh0000<0
o`000?n0003oP0000P3o00020?n000L00?l00P3oP0050?l000@00?l01`3oP005003o00@0003o1`00
o`020?n000D00?l00P3oP00Hooooo`005_ooool;0?l00080oh00:`3o00000`3oP000o`000?l00004
0?n002L0o`000P3oP0040?l000030?n0003o0000o`0001/0o`003_ooool20000o`800?l06P000?l8
003o01D0003o0P00o`020?n000<0003o1P3oP0030?l00080003o103oP003003o0080003o1@3oP00A
003o00<0003o0P00o`030000o`T00?l00P000?l20?n00080003o0P3oP0000`00o`00003o0000o`02
003o00kooooo6@000?l2003o0100003o1000o`000`000?l00?l0003o0002003o01D0003o0P3oP002
003o00L0003o0P3oP002003o00<0oh000P000?l20?n000@00?l00`000?l20?n000@0003o1`00o`05
0000o`800?l01@000?l20?n00080003o0P00o`000`000?l00?l0003o00020000o`kooooo0P000?l3
0?n00080o`000P00o`040?n000D0o`000P00o`020000o`<00?l010000?l5003o00@0oh000`3o0002
003o0080oh002@3o00020?n000030?l00000o`000?l00080oh001`00o`020?n00080o`0000<0oh00
0?l0003o00000P000?l40?n000030?l0003oP000oh000080o`000P3oP007003o0080oh001@3o0004
003o00L0oh001@00o`040000o`L00?l00P3oP005003o0080oh006?ooool001Kooooo7@3o00000`3o
P000o`000?l000040?l00080oh004P3o00000`3oP000o`000?l000020?l00080oh00303o00020?n0
02T0o`000P00o`070?l00080oh002@3o000>ooooo`80003o0P00o`090000o`03003o00000?l0003o
0280003o1000o`020?n00003003o00000?l0003o0080003o0P3o0005003o0080003o0`3oP0020?l0
00800?l01@000?l2003o0080003o1@3oP0020?l000H0oh000`00o`090000o`@00?l000<0003o003o
0000o`002@000?l20?n00080003o0P3oP0030000o`800?l03_oooolM0000o`<00?l0:`000?l9003o
0080oh000P00o`020000o`030?n000000?l0003o0080003o1@00o`060000o`L00?l00`000?l20?n0
00@00?l00P000?l00`00o`00003o0000o`020?n000800?l01@000?l20?n000kooooo1@000?l2003o
0080oh000P00o`020?l000030?n0003o0000o`0000T0oh000P00o`020000o`D00?l0103oP0030?l0
00800?l0103oP0030?l00080oh001@3o0002003o0080oh000P00o`050?n00080o`000`3oP004003o
00@0003o00<00?l00?n0003oP0002`00o`020?n00080003o00<0o`000?n0003oP000103o00020?n0
00030?l0003oP000oh0000@0oh000`00o`040000o`80oh0000<0o`00003o0000o`000P00o`040000
o`D0oh006?ooool001Kooooo7@3o00000`3oP000o`000?l000040?l00080oh004P3o00000`3oP000
o`000?l000020?l00080oh00303o00020?n002T0o`000P00o`070?l00080oh002@3o000>ooooo`80
003o0P00o`090000o`03003o00000?l0003o0280003o1000o`020?n00003003o00000?l0003o0080
003o0P3o0005003o0080003o0`3oP0020?l000800?l01@000?l2003o0080003o1@3oP0020?l000H0
oh000`00o`090000o`@00?l000<0003o003o0000o`002@000?l20?n00080003o0P3oP0030000o`80
0?l03_oooolM0000o`<00?l0:`000?l9003o0080oh000P00o`020000o`030?n000000?l0003o0080
003o1@00o`060000o`L00?l00`000?l20?n000@00?l00P000?l00`00o`00003o0000o`020?n00080
0?l01@000?l20?n000kooooo1@000?l2003o0080oh000P00o`020?l000030?n0003o0000o`0000T0
oh000P00o`020000o`D00?l0103oP0030?l000800?l0103oP0030?l00080oh001@3o0002003o0080
oh000P00o`050?n00080o`000`3oP004003o00@0003o00<00?l00?n0003oP0002`00o`020?n00080
003o00<0o`000?n0003oP000103o00020?n000030?l0003oP000oh0000@0oh000`00o`040000o`80
oh0000<0o`00003o0000o`000P00o`040000o`D0oh006?ooool001Kooooo7@3o00000`3oP000o`00
0?l0000H0?l000030?n0003o0000o`0000/0o`000P3oP0030?l00080oh000P3o00020?n002<0o`00
103oP00B0?l000kooooo1000o`0^0000o`T00?l01`000?l20?n000D0003o0P3o0006003o00D0003o
103oP0000`3o0000oh000?n00007003o01@0003o0P00o`050000o`80oh000P000?l20?n00003003o
00000?l0003o0080003o3_ooool4003o02<0003o1000o`090000o`800?l03P000?l20?n000D00?l0
0P000?l;003o0080003o0`00o`0D0000o`80oh0000<0003o003o0000o`002@000?l20?n000T0003o
3_ooool50000o`80oh000P000?l2003o00T0oh000`00o`020?n000800?l00P3oP0000`00o`00oh00
0?n000020?n000800?l00`3oP006003o0080oh000`3o00020?n00080o`000P000?l00`3o0000oh00
0?n00002003o00D0oh001P3o00000`3oP000o`000?l00002003o0080oh001@00o`020?n000800?l0
0P3oP005003o0080oh001@00o`020000o`80oh000P3o00000`3oP000o`000?l000020000o`800?l0
1`000?l20?n000030000o`00o`000?l000800?l010000?l00`3oP000o`000?l000020?l001Sooooo
000Foooooad0o`0000<0oh000?l0003o0000;`3o00020?n002D0o`000P3oP0050?l00080oh002`3o
000>ooooo`800?l02`000?l00`00o`00003o0000o`0@0000o`800?l00P000?l2003o00`0003o2@00
o`0@0000o`80oh000P00o`020?n000030000o`3oP000oh000080oh000P000?l20?n000030000o`3o
0000o`0000800?l01@000?l2003o01/0003o0P00o`020000o`03003o00000?l0003o0080003o3_oo
ool5003o0280003o0P3oP004003o01L0003o0P3oP003003o0080oh000P000?l20?n000<00?l07`00
0?l20?n000030000o`00o`000?l000800?l01@000?l20?n00080003o0P00o`020000o`03003o0000
0?l0003o0080003o3_ooool4003o00030000o`3oP000oh000080003o0P3oP002003o00030000o`3o
P000oh000080o`000P3oP0020?l000030?n00000o`000?l000@00?l01`3oP002003o00<0oh001000
o`070?n000@0003o0`3oP004003o00<0oh001`3o00040?n000@00?l000<0o`000?n0003oP0000P3o
P002003o00<0003o0P3oP0040000o`<00?l02`3oP005003o0080oh000P00o`020000o`<00?l00P00
0?l6003o00<0oh000P3o000Hooooo`005_oooolM0?l000030?n0003o0000o`0002l0o`000P3oP00U
0?l00080oh001@3o00020?n000/0o`003_ooool2003o00/0003o00<00?l00000o`000?l040000?l2
003o0080003o0P00o`0<0000o`T00?l040000?l20?n000800?l00P3oP0000`000?l0oh000?n00002
0?n00080003o0P3oP0000`000?l0o`000?l00002003o00D0003o0P00o`0K0000o`800?l00P000?l0
0`00o`00003o0000o`020000o`kooooo1@00o`0R0000o`80oh001000o`0G0000o`80oh000`00o`02
0?n00080003o0P3oP003003o01l0003o0P3oP0000`000?l00?l0003o0002003o00D0003o0P3oP002
0000o`800?l00P000?l00`00o`00003o0000o`020000o`kooooo1000o`000`000?l0oh000?n00002
0000o`80oh000P00o`000`000?l0oh000?n000020?l00080oh000P3o00000`3oP0000?l0003o0004
003o00L0oh000P00o`030?n000@00?l01`3oP0040000o`<0oh001000o`030?n000L0o`00103oP004
003o00030?l0003oP000oh000080oh000P00o`030000o`80oh0010000?l3003o00/0oh001@00o`02
0?n000800?l00P000?l3003o0080003o1P00o`030?n00080o`006?ooool001Kooooo2@3o00020?n0
04d0o`000P3oP0030?l00080oh00103o00000`3oP000o`000?l0000P0?l00080oh000P3o000>oooo
o`D00?l020000?l3003o02@0003o1@00o`060?n000D0003o0P00o`050000o`L0oh000P00o`040000
o`80oh003P00o`0K0000o`80oh0000<00?l00000o`000?l00P000?l>ooooo`@0003o00<00?l00000
o`000?l04P000?l2003o0100003o1000o`0E0000o`@0oh000`00o`020000o`80oh001@00o`040000
o`<00?l05P000?l20?n00003003o00000?l0003o00800?l00P000?l3003o0080003o1000o`070000
o`kooooo0P3oP003003o00H0oh000P00o`030000o`80oh000P3o00020?n000030?l00000o`000?l0
00800?l01`3oP004003o00030?n00000o`000?l00080oh000P00o`020?n00003003o003oP000oh00
00800?l010000?l00`3oP0000?l0003o00020?n000@00?l000<0003o0?n0003oP0000P3o00020?n0
00L0o`001`00o`040000o`D00?l00P000?l5003o00@0oh002@3o00000`3oP0000?l0003o0002003o
00D0003o0P3oP002003o00@0oh000`3o00020?n001Sooooo000Fooooo`T0o`000P3oP01=0?l00080
oh000`3o00020?n000@0o`0000<0oh000?l0003o0000803o00020?n00080o`003_ooool5003o00P0
003o0`00o`0T0000o`D00?l01P3oP0050000o`800?l01@000?l70?n000800?l010000?l20?n000h0
0?l06`000?l20?n00003003o00000?l0003o0080003o3_ooool40000o`03003o00000?l0003o0180
003o0P00o`0@0000o`@00?l05@000?l40?n000<00?l00P000?l20?n000D00?l010000?l3003o01H0
003o0P3oP0000`00o`00003o0000o`02003o0080003o0`00o`020000o`@00?l01`000?l>ooooo`80
oh000`00o`060?n000800?l00`000?l20?n00080o`000P3oP0000`3o00000?l0003o0002003o00L0
oh001000o`000`3oP0000?l0003o00020?n000800?l00P3oP0000`00o`00oh000?n00002003o00@0
003o00<0oh00003o0000o`000P3oP004003o00030000o`3oP000oh000080o`000P3oP0070?l000L0
0?l010000?l5003o0080003o1@00o`040?n000T0o`0000<0oh00003o0000o`000P00o`050000o`80
oh000P00o`040?n000<0o`000P3oP00Hooooo`005_ooool90?l00080oh009@3o00020?n000@0o`00
0P3oP0030?l00080oh00803o00020?n000T0o`000P3oP00L0?l000@0oh003_ooool5003o00H0003o
0`00o`0V0000o`80oh000P000?l00`00o`00oh000?n000040?n000800?l000<0003o003o0000o`00
1@00o`040?n00080o`000`3oP006003o0080oh000`00o`040000o`800?l000<0003o003o0000o`00
0P00o`070000o`800?l00P000?l00`00o`00003o0000o`020000o`L00?l01P000?l00`00o`00003o
0000o`020000o`kooooo0P000?l3003o0140003o2P00o`0_0000o`80oh000`00o`0O0000o`X00?l0
0P000?l2003o00@0003o00<00?l00000o`000?l00P000?l>ooooo`800?l00P3oP0000`00o`00oh00
0?n000040?n000<00?l00P000?l20?n00080o`000P3oP0000`3o0000oh000?n000040?n00003003o
00000?l0003o00@0oh000P3o00000`00o`00oh000?n00004003o00L0oh001000o`030?n00080o`00
0P3oP002003o00L0003o00<0oh000?l0003o00000P3o0004003o00030?l0003oP000oh000080oh00
4000o`040?n000T0o`0000<0oh00003o0000o`000P00o`040000o`<00?l01P3oP0030?l00080oh00
6?ooool001Kooooo2@3o00020?n002D0o`000P3oP0040?l00080oh000`3o00020?n00200o`000P3o
P0090?l00080oh00703o00040?n000kooooo1@00o`060000o`<00?l09P000?l20?n00080003o00<0
0?l00?n0003oP000103oP002003o00030000o`00o`000?l000D00?l0103oP0020?l000<0oh001P00
o`020?n000<00?l010000?l2003o00030000o`00o`000?l000800?l01`000?l2003o0080003o00<0
0?l00000o`000?l00P000?l7003o00H0003o00<00?l00000o`000?l00P000?l>ooooo`80003o0`00
o`0A0000o`X00?l0;`000?l20?n000<00?l07`000?l:003o0080003o0P00o`040000o`03003o0000
0?l0003o0080003o3_ooool2003o0080oh0000<00?l00?n0003oP000103oP003003o0080003o0P3o
P0020?l00080oh0000<0o`000?n0003oP000103oP0000`00o`00003o0000o`040?n00080o`0000<0
0?l00?n0003oP0001000o`070?n000@00?l00`3oP0020?l00080oh000P00o`070000o`030?n0003o
0000o`000080o`001000o`000`3o0000oh000?n000020?n001000?l0103oP0090?l000030?n00000
o`000?l000800?l010000?l3003o00H0oh000`3o00020?n001Sooooo000Foooooa80o`000P3oP007
0?l00080oh006@3o00020?n000T0o`0000<0oh000?l0003o0000903o00020?n001`0o`00103oP00>
ooooo`@0003o3000o`070000o`@00?l01`000?l20?n00100003o0P3oP003003o00H0oh001`00o`02
0?n000<00?l0103oP0020?l000<00?l0103oP0020?l000030?n00000o`000?l000@0003o0P00o`0<
0000o`800?l00P000?l00`00o`00003o0000o`020000o`d00?l00`000?l2003o00kooooo5`000?l9
003o0340003o00<00?l00000o`000?l08P000?l4003o00/0003o00<00?l00000o`000?l00P000?l>
ooooo`@0o`0000<00?l00?n0003oP0000P3oP0020?l00080oh0000<00?l00000o`000?l0103oP003
0?l00080003o103oP003003o0080003o1@3oP0020?l000H0oh0000<00?l00?n0003oP0001000o`02
0?l000<0oh000P3o00020?n000<0o`000P3oP002003o00D0oh000P3o00050?n000800?l00P3oP004
003o00L0oh000`00o`040?n000D0o`000P3oP0040?l000D0oh000P000?l50?n000T0o`000P00o`0H
ooooo`005_oooolB0?l00080oh001`3o00020?n001T0o`000P3oP0090?l000030?n0003o0000o`00
02@0o`000P3oP00L0?l000@0oh003_ooool40000o``00?l01`000?l4003o00L0003o0P3oP00@0000
o`80oh000`00o`060?n000L00?l00P3oP003003o00@0oh000P3o0003003o00@0oh000P3o00000`3o
P0000?l0003o00040000o`800?l030000?l2003o0080003o00<00?l00000o`000?l00P000?l=003o
00<0003o0P00o`0>oooooaL0003o2@00o`0a0000o`03003o00000?l0003o0280003o1000o`0;0000
o`03003o00000?l0003o0080003o3_ooool40?l00003003o003oP000oh000080oh000P3o00020?n0
0003003o00000?l0003o00@0oh000`3o00020000o`@0oh000`00o`020000o`D0oh000P3o00060?n0
0003003o003oP000oh0000@00?l00P3o00030?n00080o`000P3oP0030?l00080oh000P00o`050?n0
0080o`001@3oP002003o0080oh001000o`070?n000<00?l0103oP0050?l00080oh00103o00050?n0
0080003o1@3oP0090?l000800?l06?ooool001Kooooo7@3o00000`3oP000o`000?l0000Q0?l00003
0?n0003o0000o`000200o`000P3oP00;0?l000D0oh00103o00020?n000X0o`00103oP00>ooooo`@0
003o2@00o`0@0000o`03003o00000?l0003o00800?l050000?l3003o00@0oh000P3o00020?n00003
0000o`3oP000oh000080o`000P3oP0000`3o0000oh000?n000020?n000D0003o0P3oP00D003o00/0
003o00<00?l00000o`000?l00P000?l5003o0080oh001P00o`050000o`kooooo6@000?l4003o0003
0000o`00o`000?l00100003o0P00o`160000o`800?l040000?l>ooooo`@0o`0000<00?l00?n0003o
P0000P3oP0020?l000<00?l00P000?l40?n00080o`0000<0oh00003o0000o`000P00o`020?n000<0
0?l00P000?l50?n000800?l00P3oP005003o0080oh001P00o`000`3oP0000?l0003o00060?l000<0
oh000P00o`0>0?n00080o`000P3oP0030?l00080oh00103o0002003o00D0oh000P3o00020?n000P0
o`002000o`030?n00080o`000P3oP0050?l00080oh006?ooool001Kooooo@@3o00000`3oP000o`00
0?l000050?l00080oh000P3o00020?n00280o`000P3oP0070?l00080oh003P3o000>ooooo`D0003o
1P00o`0@0000o`L00?l050000?l3003o00@0oh001@000?l20?n000@0o`001@3oP0020?l000<00?l0
20000?l00`00o`00oh000?n0000=003o00L0003o0P00o`050000o`/00?l01`000?l>ooooohD0003o
00<0oh00003o0000o`000P00o`0>ooooo`@0o`0000<00?l00?n0003oP0001P3oP003003o00@0003o
1`00o`020?n000<00?l00P000?l40?n00003003o003o0000o`000080oh000P00o`020?l00003003o
00000?l0003o0080oh000P000?l2003o00030?n000000?l0003o00@00?l00`3oP0020?l00080oh00
0P00o`030000o`@0oh000`00o`060?n00080o`000`3oP0020?l000D00?l0103oP0050?l000L0oh00
0P00o`020?n000@00?l000<0oh000?l0003o00000P3oP002003o00<0oh000P3o0002003o01Sooooo
000Foooood40o`0000<0oh000?l0003o00001@3o00020?n00080o`000P3oP00R0?l00080oh001`3o
00020?n000h0o`003_ooool50000o`H00?l040000?l7003o01@0003o0`00o`040?n000D0003o0P3o
P0040?l000D0oh000P3o0003003o00P0003o00<00?l00?n0003oP0003@00o`070000o`800?l01@00
0?l;003o00L0003o3_oooon50000o`030?n00000o`000?l000800?l03_ooool40?l00003003o003o
P000oh0000H0oh000`00o`040000o`L00?l00P3oP003003o0080003o103oP0000`00o`00o`000?l0
00020?n000800?l00P3o00000`00o`00003o0000o`020?n00080003o0P00o`000`3oP000003o0000
o`04003o00<0oh000P3o00020?n000800?l00`000?l40?n000<00?l01P3oP0020?l000<0oh000P3o
0005003o00@0oh001@3o00070?n000800?l00P3oP004003o00030?n0003o0000o`000080oh000P00
o`030?n00080o`000P00o`0Hooooo`005_ooool70?l00080oh000P3o00020?n000<0o`000P3oP00M
0?l000030?n0003o0000o`0002@0o`000P3oP0030?l00080oh007@3o00020?n000L0o`001@3oP002
0?l000kooooo1@000?l6003o0180003o00<0oh000000o`000?l05P000?l20?n000<00?l01`000?l6
0?n000<00?l0103oP0020000o`03003o00000?l0003o0080003o0P3oP00<003o0080o`001000o`0:
0000o`800?l01P000?l00`00o`00003o0000o`020000o`800?l00P3oP0050000o`koooooRP000?l>
ooooo`@0o`0000<0oh000?l0003o00001P3o00000`3oP0000?l0003o0002003o00@0003o00<0oh00
0000o`000?l00P00o`030?n000@00?l00P000?l20?n000030000o`3oP000oh0000@0oh000`00o`06
0000o`D00?l00P3oP002003o00L0oh000P00o`000`000?l0oh000?n000040?n00080003o00<0o`00
0?n0003oP0001`3o00020?n00080o`000P3oP002003o00030?l0003oP000oh0000H0o`001@3oP003
0?l00080oh000P3o0004003o00030?l0003oP000oh0000@0o`000P00o`030?n000800?l06?ooool0
01Kooooo1`3o00020?n00080o`000P3oP0030?l00080oh007@3o00000`3oP000o`000?l0000T0?l0
0080oh000`3o00020?n001d0o`000P3oP0070?l000D0oh000P3o000>ooooo`D0003o1P00o`0B0000
o`030?n000000?l0003o01H0003o0P3oP003003o00L0003o1P3oP003003o00@0oh000P000?l00`00
o`00003o0000o`020000o`80oh003000o`020?l000@00?l02P000?l2003o00H0003o00<00?l00000
o`000?l00P000?l2003o0080oh001@000?l>ooooohX0003o3_ooool40?l000030?n0003o0000o`00
00H0o`0000<0oh00003o0000o`000P00o`040000o`030?n000000?l0003o00800?l00`3oP004003o
0080003o0P3oP0000`000?l0oh000?n000040?n000<00?l01P000?l5003o0080oh000P00o`070?n0
00800?l000<0003o0?n0003oP000103oP0020000o`030?l0003oP000oh0000L0o`000P3oP0020?l0
0080oh000P00o`000`3o0000oh000?n000060?l000D0oh000`3o00020?n00080o`001000o`000`3o
0000oh000?n000040?l000800?l00`3oP002003o01Sooooo000Foooooa00o`000P3oP0020?l00080
oh007P3o00020?n00080o`0000<0oh000?l0003o0000103o00020?n00280o`0000<0oh000?l0003o
00007@3o00030?n000@0o`003_ooool20000o`<00?l00P000?l2003o0180003o1`00o`0P0000o`80
0?l00P3oP002003o00030?l00000o`000?l00080oh001@00o`040000o`80oh001`000?l2003o0080
003o00<0oh000000o`000?l00P3o0002003o00X0003o0P00o`020000o`800?l00P000?l00`3oP000
0?l0003o0004003o00L0003o3_oooomK0000o`800?l0;@000?l>ooooo`@0oh002P3o0004003o0080
003o0P00o`000`000?l00?l0003o00040?n000030?l0003oP000oh0000800?l00P000?l20?n00003
003o003oP000oh0000@0oh001@00o`070000o`l00?l01@3oP002003o0080003o00<00?l00?n0003o
P0000P3oP0020000o`80o`001@3oP004003o00030?n0003o0000o`000080o`00103oP0030?l00080
oh000`3o00040?n000800?l01@3oP0020?l000800?l00`3oP002003o0080oh006?ooool001Kooooo
403o00020?n00080o`000P3oP00N0?l00080oh000P3o00000`3oP000o`000?l000040?l00080oh00
8P3o00000`3oP000o`000?l0000M0?l000<0oh00103o000>ooooo`80003o0`00o`020000o`800?l0
4P000?l7003o0200003o0P00o`020?n000800?l000<0o`00003o0000o`000P3oP005003o00@0003o
0P3oP0070000o`800?l00P000?l00`3oP000003o0000o`020?l000800?l02P000?l2003o0080003o
0P00o`020000o`030?n00000o`000?l000@00?l01`000?l>oooooe/0003o0P00o`0]0000o`kooooo
103oP00:0?l000@00?l00P000?l2003o00030000o`00o`000?l000@0oh0000<0o`000?n0003oP000
0P00o`020000o`80oh0000<00?l00?n0003oP000103oP005003o00L0003o3`00o`050?n000800?l0
0P000?l00`00o`00oh000?n000020?n00080003o0P3o00050?n000@00?l000<0oh000?l0003o0000
0P3o00040?n000<0o`000P3oP0030?l000@0oh000P00o`050?n00080o`000P00o`030?n000800?l0
0P3oP00Hooooo`005_ooool@0?l00080oh000P3o00020?n002T0o`000P3oP0000`3o0000oh000?n0
000f0?l00080oh0000<0o`000?n0003oP0000P3o00020?n00080o`000`3oP0020?l000kooooo0P00
0?l;003o00h0003o1`00o`0B0000o`L00?l00P3oP004003o00<0003o103oP0000`000?l0o`000?l0
000D0000o`80oh001@000?l2003o0080oh002P000?l4003o0080003o3000o`040000o`kooooo1000
0?l00`00o`00003o0000o`1F0000o`80oh003@000?l3003o01/0003o3_ooool2003o0080oh001@3o
00070?n000T00?l01@3oP0020000o`800?l01@000?l60?n000<00?l02@000?l40?n00080o`000P3o
P0000`3o00000?l0003o0002003o0080o`001@3oP004003o00030000o`3oP000oh000080oh000P00
o`070?n00080o`000P00o`030?n000H0o`0000<0oh000?l0003o00000P3oP0020?l000030?n0003o
0000o`000080o`001@3oP0040?l000T00?l06?ooool001Kooooo403o00020?n00080o`000P3oP00Y
0?l00080oh0000<0o`000?n0003oP000=P3o00020?n000030?l0003oP000oh000080o`000P3oP002
0?l000<0oh000P3o000>ooooo`80003o2`00o`0>0000o`L00?l04P000?l7003o0080oh001000o`03
0000o`@0oh0000<0003o0?l0003o000050000?l20?n000D0003o0P00o`020?n000X0003o1000o`02
0000o``00?l010000?l>ooooo`@0003o00<00?l00000o`000?l0EP000?l20?n000d0003o0`00o`0K
0000o`kooooo0P00o`020?n000D0o`001`3oP009003o00D0oh000P000?l2003o00D0003o1P3oP003
003o00T0003o103oP0020?l00080oh0000<0o`00003o0000o`000P00o`020?l000D0oh001000o`00
0`000?l0oh000?n000020?n000800?l01`3oP0020?l000800?l00`3oP0060?l000030?n0003o0000
o`000080oh000P3o00000`3oP000o`000?l000020?l000D0oh00103o0009003o01Sooooo000Foooo
o`80oh006@3o00020?n00280o`000P3oP0000`3o0000oh000?n000040?l000030?n0003o0000o`00
0080oh00103o00000`3oP000o`000?l0000K0?l00080oh000`3o00020?n000H0o`001@00o`020?l0
00D0oh000P3o000>ooooo`80003o2`00o`0<0000o`800?l00P3oP0000`00o`00oh000?n00006003o
00D0003o0P00o`070000o`D00?l0103oP007003o0080oh000`00o`060000o`80oh000`000?l4003o
00D0003o1P00o`000`3oP000003o0000o`0>0000oaH00?l03_ooool20000o`<00?l02@000?l2003o
01/0003o0P00o`120000o`800?l050000?l00`3oP000003o0000o`020000o`kooooo103oP0030?l0
0080oh001`00o`020?n000800?l00P3oP0000`00o`00003o0000o`040000o`<0oh000P00o`050000
o`@0oh000P3o0003003o00/0003o0P00o`020?n00080003o0`3o00020?n00080o`000`3oP0020?l0
00D00?l01P3oP0020?l000<0oh00103o00020?n000<0o`000P3oP0050?l00080oh001000o`000`3o
P000o`000?l000070?n000@0o`001000o`000`3oP000003o0000o`02003o01Sooooo000Fooooo`80
oh001`3o00020?n003@0o`000P3oP0070?l000030?n0003o0000o`0000T0o`000P3oP0020?l00080
oh005@3o00020?n00080o`0000<0oh000?l0003o00000P3o00020?n00080o`0000<0oh00003o0000
o`000P00o`090?l000kooooo0P000?l7003o0080oh001@00o`090000o`800?l00`3oP008003o00`0
003o1`00o`040?n000L00?l00P3oP0020000o`03003o003oP000oh0000H00?l01@000?l2003o00<0
003o0P3oP00R0000o`/00?l03_ooool20000o`D00?l080000?l6003o00T0003o0P00o`0:0000o`80
0?l02`000?l2003o00h0003o5`00o`0D0000o`kooooo0P3oP0020?l00003003o003oP000oh000080
oh001000o`000`000?l00?l0003o00020?n000D00?l01P000?l00`3oP000003o0000o`020?n000D0
003o203oP0000`00o`00o`000?l000020000o`800?l00`000?l20?n000800?l02@3oP0070?l000D0
0?l00P3oP0020?l00080oh002@3o00090?n00080o`000`3oP004003o00030?l0003oP000oh000080
oh000P3o00030?n000H00?l00P000?l00`3oP0000?l0003o00020?n001Sooooo000Fooooo`80oh00
1`3o00020?n003@0o`000P3oP0070?l000030?n0003o0000o`0000T0o`000P3oP0020?l00080oh00
5@3o00020?n00080o`0000<0oh000?l0003o00000P3o00020?n00080o`0000<0oh00003o0000o`00
0P00o`090?l000kooooo0P000?l7003o0080oh001@00o`090000o`800?l00`3oP008003o00`0003o
1`00o`040?n000L00?l00P3oP0020000o`03003o003oP000oh0000H00?l01@000?l2003o00<0003o
0P3oP00R0000o`/00?l03_ooool20000o`D00?l080000?l6003o00T0003o0P00o`0:0000o`800?l0
2`000?l2003o00h0003o5`00o`0D0000o`kooooo0P3oP0020?l00003003o003oP000oh000080oh00
1000o`000`000?l00?l0003o00020?n000D00?l01P000?l00`3oP000003o0000o`020?n000D0003o
203oP0000`00o`00o`000?l000020000o`800?l00`000?l20?n000800?l02@3oP0070?l000D00?l0
0P3oP0020?l00080oh002@3o00090?n00080o`000`3oP004003o00030?l0003oP000oh000080oh00
0P3o00030?n000H00?l00P000?l00`3oP0000?l0003o00020?n001Sooooo000Fooooo`h0o`000P3o
P0070?l00080oh00403o00020?n00080o`000P3oP0030?l00080oh002`3o00020?n001<0o`000P3o
P0040?l000030?n0003o0000o`000180o`000P3oP0070?l00080oh000P3o00000`3oP000o`000?l0
000;0?l000kooooo4000o`0=0000o`D00?l03P000?l9003o0080oh000P3o00020000o`800?l000<0
003o0?n0003oP0000P3oP002003o00030?n00000o`000?l000L00?l00P000?l7003o0080oh002@00
o`0=0000o`<00?l01`000?l;003o0080003o3_ooool20000o`D00?l080000?l8003o00030000o`00
o`000?l00080003o1000o`0@0000o`D00?l010000?l<003o0080003o1@00o`020?n000800?l00P3o
P005003o0080003o0P00o`0G0000o`kooooo1@00o`060000o`80oh000`00o`020?l00080oh000`00
o`090000o`800?l010000?l00`00o`00oh000?n000020?l00080oh001@3o00020000o`800?l00`00
0?l80?n000P0o`000P3oP0020?l000@0oh000`3o00020?n000T0o`001`3oP0020?l000@0oh0000<0
o`000000o`000?l01000o`000`3oP000o`000?l000040?l000<0oh000P00o`020?n000@00?l000<0
oh00003o0000o`000P3oP00Hooooo`005_ooool>0?l00080oh001`3o00020?n00100o`000P3oP002
0?l00080oh000`3o00020?n000/0o`000P3oP00C0?l00080oh00103o00000`3oP000o`000?l0000B
0?l00080oh001`3o00020?n00080o`0000<0oh000?l0003o00002`3o000>oooooa000?l03@000?l5
003o00h0003o2@00o`020?n00080o`000P000?l2003o00030000o`3oP000oh000080oh000P00o`00
0`3oP0000?l0003o0007003o0080003o1`00o`020?n000T00?l03@000?l3003o00L0003o2`00o`02
0000o`kooooo0P000?l5003o0200003o2000o`000`000?l00?l0003o00020000o`@00?l040000?l5
003o00@0003o3000o`020000o`D00?l00P3oP002003o0080oh001@00o`020000o`800?l05`000?l>
ooooo`D00?l01P000?l20?n000<00?l00P3o00020?n000<00?l02@000?l2003o00@0003o00<00?l0
0?n0003oP0000P3o00020?n000D0o`000P000?l2003o00<0003o203oP0080?l00080oh000P3o0004
0?n000<0o`000P3oP0090?l000L0oh000P3o00040?n000030?l000000?l0003o00@00?l000<0oh00
0?l0003o0000103o00030?n000800?l00P3oP004003o00030?n00000o`000?l00080oh006?ooool0
01Kooooo0P00o`0<0?l00080oh001`3o00020?n00100o`000P3oP0070?l00080oh00803o00020?n0
0280o`000P3oP0020?l000030?n0003o0000o`0000/0o`003_ooool7003o00H0003o0`00o`0T0000
o`h00?l0103oP0020000o`030?l0003oP000oh0000@00?l00P3oP0000`000?l00?l0003o0004003o
0080003o5@00o`040000o`T00?l00`000?l7003o00@0003o3_ooool20000o`D00?l03`000?l3003o
01@0003o0P00o`000`000?l00?l0003o000F0000o`T00?l01@000?l5003o00@0003o0P00o`020000
o`D0oh001`00o`020000o`D00?l050000?l>ooooo`80o`000P00o`070000o`800?l01`3oP002003o
00P0003o1000o`050000o`80oh002@3o0004003o0080003o00<00?l00?n0003oP000103oP0090?l0
00030?n0003o0000o`000080o`000P3oP0030?l000@0oh002@3o00040?n000D0o`000P3oP007003o
0080003o00<0o`000?n0003oP0001`3o00020?n00080o`000P3oP002003o00030?n0003o0000o`00
0080o`006?ooool001Kooooo0P00o`0<0?l00080oh001`3o00020?n00100o`000P3oP0070?l00080
oh00803o00020?n00280o`000P3oP0020?l000030?n0003o0000o`0000/0o`003_ooool7003o00H0
003o0`00o`0T0000o`h00?l0103oP0020000o`030?l0003oP000oh0000@00?l00P3oP0000`000?l0
0?l0003o0004003o0080003o5@00o`040000o`T00?l00`000?l7003o00@0003o3_ooool20000o`D0
0?l03`000?l3003o01@0003o0P00o`000`000?l00?l0003o000F0000o`T00?l01@000?l5003o00@0
003o0P00o`020000o`D0oh001`00o`020000o`D00?l050000?l>ooooo`80o`000P00o`070000o`80
0?l01`3oP002003o00P0003o1000o`050000o`80oh002@3o0004003o0080003o00<00?l00?n0003o
P000103oP0090?l000030?n0003o0000o`000080o`000P3oP0030?l000@0oh002@3o00040?n000D0
o`000P3oP007003o0080003o00<0o`000?n0003oP0001`3o00020?n00080o`000P3oP002003o0003
0?n0003o0000o`000080o`006?ooool001Kooooo0P00o`020?n001<0o`000P3oP0020?l00080oh00
5@3o00020?n00080o`000P3oP0050?l00080oh006`3o00000`3oP000o`000?l000090?l00080oh00
403o00020?n000`0o`000P3oP0020?l000kooooo1`00o`040000o`D00?l03@000?l00`00o`00003o
0000o`0I0000o`80oh003@00o`030?l00080oh003@00o`000`3oP0000?l0003o0006003o00030000
o`00o`000?l000T00?l01@000?lB003o00@0003o3_ooool20000o`D00?l02@000?l2003o01T0003o
1`00o`020000o`D00?l00P000?l9003o00@0003o2P00o`080000o`03003o00000?l0003o00L00?l0
0P3oP0070000o`@00?l00P3oP0000`00o`00003o0000o`020000o`800?l02@000?l5003o0080003o
3_ooool20?n000800?l00`000?l20?n00080003o2`00o`080000o`800?l010000?l2003o00030000
o`3oP000oh000080oh001@3o00020?n000L00?l0103oP0040?l000030?n0003o0000o`000080oh00
0P3o00000`3oP000o`000?l000060?l000030?n00000o`000?l000@0oh001@3o0002003o00D0oh00
103o00020?n000<0o`000P3oP0070000o`@0oh000P3o00000`3oP000o`000?l000020?l000@00?l0
00<0o`000?n0003oP0000P3o000Hooooo`005_oooolW0?l00080oh00503o00020?n000L0o`000P3o
P00N0?l00080oh002`3o00000`3oP000o`000?l0000@0?l00080oh000P3o000>ooooo`800?l00P3o
P003003o00H0003o0`00o`0]0000o`800?l00P3oP003003o00@0003o0`3oP0040?l000800?l01@00
0?l2003o00D0003o0P00o`040000o`030?n000000?l0003o00800?l00P3oP003003o00L0003o4P00
o`040000o`kooooo0P000?l5003o01/0003o3P00o`020?n000H0003o00<00?l00000o`000?l00P00
0?l5003o00L0003o2000o`000`000?l00?l0003o000M0000o`T00?l02`000?l5003o00kooooo1@00
o`060000o`L00?l00P000?l5003o0080003o1@00o`020?n000800?l00`3oP0020000o`H0oh0000<0
o`000?n0003oP0000P00o`020?n00080o`0000<00?l00?n0003oP0002@3oP0020?l00080oh0000<0
003o0?n0003oP0000P3oP0040?l000030?n00000o`000?l000@00?l00P3oP005003o00@0oh001@3o
00020?n00080o`001@00o`020?n00003003o003oP000oh0000H0oh0000<0o`000?n0003oP0000P3o
00050?n000@0o`006?ooool001Kooooo9`3o00020?n001@0o`000P3oP0070?l00080oh007P3o0002
0?n000/0o`0000<0oh000?l0003o0000403o00020?n00080o`003_ooool2003o0080oh000`00o`06
0000o`<00?l0;@000?l2003o0080oh000`00o`040000o`<0oh00103o0002003o00D0003o0P00o`05
0000o`800?l010000?l00`3oP000003o0000o`02003o0080oh000`00o`070000oa800?l010000?l>
ooooo`80003o1@00o`0K0000o`h00?l00P3oP0060000o`03003o00000?l0003o0080003o1@00o`07
0000o`P00?l000<0003o003o0000o`007@000?l9003o00/0003o1@00o`0>ooooo`D00?l01P000?l7
003o0080003o1@00o`020000o`D00?l00P3oP002003o00<0oh000P000?l60?n000030?l0003oP000
oh0000800?l00P3oP0020?l00003003o003oP000oh0000T0oh000P3o00020?n000030000o`3oP000
oh000080oh00103o00000`3oP0000?l0003o0004003o0080oh001@00o`040?n000D0o`000P3oP002
0?l000D00?l00P3oP0000`00o`00oh000?n000060?n000030?l0003oP000oh000080o`001@3oP004
0?l001Sooooo000Fooooo`d0o`0000<0oh000?l0003o00005`3o00020?n001@0o`000P3oP0070?l0
0080oh0000<0o`000?n0003oP000?`3o000>ooooo`80003o0P3oP003003o00@0003o1@00o`0]0000
o`80oh000`00o`020?n000D00?l00P3oP0040?l000T00?l00P000?l00`00o`00003o0000o`040000
o`L00?l00P3oP003003o00T0003o2@00o`020?n000D00?l010000?l>ooooo`D0003o0P00o`0K0000
oaL00?l010000?l5003o00L0003o2000o`0>0000oa000?l00P3oP005003o0080003o0P00o`090000
o`L00?l03_ooool20000o`80o`0000<00?l00000o`000?l010000?l30?n000H00?l01@3oP004003o
00030?n00000o`000?l000@00?l01@3oP0020?l00080oh000P00o`030?l00080oh000P00o`020?l0
00L00?l00P3o00030?n00080o`000P00o`050000o`@0oh000`3o00040000o`D0oh000P00o`050?n0
00P0o`0000<00?l00?n0003oP0000P3oP0020?l00003003o003oP000oh000080oh001000o`030?n0
0080o`000P3oP002003o00<0oh000P3o000Hooooo`005_ooool=0?l000030?n0003o0000o`0001L0
o`000P3oP00D0?l00080oh001`3o00020?n000030?l0003oP000oh0003l0o`003_ooool20000o`80
oh000`00o`040000o`D00?l0;@000?l20?n000<00?l00P3oP005003o0080oh00103o0009003o0080
003o00<00?l00000o`000?l010000?l7003o0080oh000`00o`090000o`T00?l00P3oP005003o00@0
003o3_ooool50000o`800?l06`000?lG003o00@0003o1@00o`070000o`P00?l03P000?l@003o0080
oh001@00o`020000o`800?l02@000?l7003o00kooooo0P000?l20?l00003003o00000?l0003o00@0
003o0`3oP006003o00D0oh001000o`000`3oP0000?l0003o0004003o00D0oh000P3o00020?n00080
0?l00`3o00020?n000800?l00P3o0007003o0080o`000`3oP0020?l000800?l01@000?l40?n000<0
o`0010000?l50?n000800?l01@3oP0080?l00003003o003oP000oh000080oh000P3o00000`00o`00
oh000?n000020?n000@00?l00`3oP0020?l00080oh000P00o`030?n00080o`006?ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo000Rooooog;o00009ooooomao`0002OoooooLOl0000Wooooog7o00009?ooool002;o
oooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Go
oooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo
5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo
5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`001?oooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooo
oaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
7ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00
1OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l07ooo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o
01oooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaKoo`001OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l07ooooolGoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o01oooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0O
oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000O
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0P
oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00
OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0Oo`00
OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o00;o001o5ooo000Oo`00
OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0Po`00
OaKoogl01?l007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0OoooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0OoooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0OoooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000OoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool005Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001D
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo001Dooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`0jo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co
001o00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00
O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oooomb
o`0002OoooooLOl0000Wooooog7o00009ooooomao`0002Cooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo000Fooooo`80o`000P00o`0L0?l00080003o0P3o00030000oaX0o`0000<0003o
0?l0003o00002`3o00020000o`D0o`000P000?l50?l00180003o403o00020000o`D0o`000P000?l2
0?l000kooooo0P00o`020?n001<00?l0103oP002003o00030?n00000o`000?l000800?l00P3o0002
0?n00003003o003oP000oh0000l00?l00`3oP002003o0080003o0P3o00000`000?l0oh000?n00002
003o0080oh000`00o`020?l000800?l01@3o00020000o`80oh000`00o`020?l000@00?l01@3o0002
0000o`80oh000`00o`020?n000D00?l01P3oP003003o0080oh000P00o`020?n00080o`0000<0003o
0?n0003oP0000P00o`0>ooooo`D0o`000P3oP002003o0080oh000P00o`000`3oP000o`000?l00002
003o0080o`000P3oP0000`00o`00o`000?l00004003o00<0003o103o0002003o00D0oh000P00o`02
0000o`030?l00000o`000?l000800?l01@3o0002003o0080o`000P00o`020000o`<0o`000P000?l2
0?n000030?l000000?l0003o00800?l0103o00050000o`D0o`001P000?l20?n000030?l00000o`00
0?l000/0o`000P000?l00`3oP0000?l0003o0002003o0080oh000P00o`0>0?l000kooooo0P3oP002
003o00D0oh000P00o`030?n000H00?l01@3oP004003o00D0oh000P00o`050?n000800?l01@3oP009
003o00@0oh001000o`050?n000800?l0303oP002003o00@0oh000`3o0004003o00D0oh000P3o0002
0000o`80oh0000<00?l00?n0003oP000103oP0000`00o`00oh000?n000040?n00080o`0000<00?l0
0?l0003o00000P3oP0020?l000<0oh001000o`0Hooooo`005_ooool20?l000800?l0703o00020000
o`80o`000`000?lJ0?l000030000o`3o0000o`0000/0o`000P000?l50?l00080003o1@3o000B0000
oa00o`000P000?l50?l00080003o0P3o000>ooooo`800?l00P3oP00C003o00@0oh000P00o`000`3o
P0000?l0003o0002003o0080o`000P3oP0000`00o`00oh000?n0000?003o00<0oh000P00o`020000
o`80o`0000<0003o0?n0003oP0000P00o`020?n000<00?l00P3o0002003o00D0o`000P000?l20?n0
00<00?l00P3o0004003o00D0o`000P000?l20?n000<00?l00P3oP005003o00H0oh000`00o`020?n0
00800?l00P3oP0020?l000030000o`3oP000oh0000800?l03_ooool50?l00080oh000P00o`020?n0
00800?l000<0oh000?l0003o00000P00o`020?l00080oh0000<00?l00?l0003o00001000o`030000
o`@0o`000P00o`050?n000800?l00P000?l00`3o00000?l0003o0002003o00D0o`000P00o`020?l0
00800?l00P000?l30?l00080003o0P3oP0000`3o0000003o0000o`02003o00@0o`001@000?l50?l0
00H0003o0P3oP0000`3o00000?l0003o000;0?l00080003o00<0oh00003o0000o`000P00o`020?n0
00800?l03P3o000>ooooo`80oh000P00o`050?n000800?l00`3oP006003o00D0oh001000o`050?n0
00800?l01@3oP002003o00D0oh002@00o`040?n000@00?l01@3oP002003o00`0oh000P00o`040?n0
00<0o`001000o`050?n00080o`000P000?l20?n00003003o003oP000oh0000@0oh0000<00?l00?n0
003oP000103oP0020?l00003003o003o0000o`000080oh000P3o00030?n000@00?l06?ooool001Ko
oooo803o00020000o`80o`000`000?lJ0?l000030000o`3o0000o`0000/0o`000P000?l<0?l00180
003o2@3o00020000o``0o`000P000?l20?l000kooooo0P00o`020?n000L00?l00P3oP00:003o00@0
oh000P00o`000`3oP0000?l0003o0002003o0080o`000P3oP0000`00o`00oh000?n0000@003o00@0
oh000P000?l20?l000030000o`3oP000oh0000800?l00P3oP003003o0080o`000P3oP002003o00<0
o`00103oP003003o0080o`001000o`050?l00080003o0P3oP003003o0080oh001000o`070?n000<0
0?l00P3oP002003o0080oh000`00o`020?n000800?l03_ooool50?l00080oh000P00o`020?n00080
0?l00`3o0002003o0080o`000P3oP0000`00o`00o`000?l00004003o00030?l000000?l0003o00@0
o`000P00o`050?n000800?l00P000?l00`3o00000?l0003o00020?n000800?l00`3o0002003o0080
o`000P00o`0B0?l000D0003o0P3o00020000o`030?l000000?l0003o0080003o1@3o0002003o00@0
o`000P00o`050?l00080003o00<0oh00003o0000o`000P3oP0020000o`800?l000<0003o0?l0003o
00001P3o00000`00o`00o`000?l000020?l000kooooo0P3oP002003o00<0oh001000o`030?n00080
0?l00P3oP002003o00L0oh000`00o`040?n000@00?l00`3oP002003o00L0oh001`00o`040?n00080
0?l01`3oP002003o0180oh000`3o0002003o00L0oh001P3o00000`000?l0oh000?n00002003o00T0
oh001@3o0004003o00<0oh000P3o0002003o01Sooooo000Fooooob00o`000P000?l20?l000<0003o
6P3o00000`000?l0o`000?l0000;0?l00080003o303o000B0000o`T0o`000P000?l<0?l00080003o
0P3o000>ooooo`800?l00P3oP007003o0080oh002P00o`040?n000800?l000<0oh00003o0000o`00
0P00o`020?l00080oh0000<00?l00?n0003oP0004000o`040?n00080003o0P3o00000`000?l0oh00
0?n00002003o0080oh000`00o`020?l00080oh000P00o`030?l000@0oh000`00o`020?l000@00?l0
1@3o00020000o`80oh000`00o`020?n000@00?l01`3oP003003o0080oh000P00o`020?n000<00?l0
0P3oP002003o00kooooo1@3o00020?n000800?l00P3oP002003o00<0o`000P00o`020?l00080oh00
00<00?l00?l0003o00001000o`000`3o0000003o0000o`040?l000800?l01@3oP002003o0080003o
00<0o`00003o0000o`000P3oP002003o00<0o`000P00o`020?l000800?l04P3o00050000o`80o`00
0P000?l00`3o0000003o0000o`020000o`D0o`000P00o`040?l000800?l01@3o00020000o`030?n0
0000o`000?l00080oh000P000?l2003o00030000o`3o0000o`0000H0o`0000<00?l00?l0003o0000
0P3o000>ooooo`80oh000P00o`030?n000@00?l00`3oP002003o0080oh000P00o`070?n000<00?l0
103oP004003o00<0oh000P00o`070?n000L00?l0103oP002003o00L0oh000P00o`0B0?n000<0o`00
0P00o`070?n000H0o`0000<0003o0?n0003oP0000P00o`090?n000D0o`001000o`030?n00080o`00
0P00o`0Hooooo`005_ooool2003o0100o`000P000?l30?l00080003o1`3o00020000obT0o`000P00
0?l20?l00080003o303o000B0000o`T0o`000P000?l<0?l00080003o0P3o000>ooooo`80003o0P3o
P007003o0080oh002P00o`020?n000@00?l000<0oh00003o0000o`000P00o`020?l00080oh0000<0
0?l00?n0003oP0004000o`060?n00080o`0000<0003o0?n0003oP000103oP003003o0080o`001000
o`030?l000@0oh000`00o`020?l000@00?l01@3o00020000o`80oh000`00o`020?n000@00?l01@3o
P002003o00D0oh000P00o`020?n000<00?l00P3oP002003o00kooooo0P3o00020?n000030?l0003o
P000oh0000@0oh002@3o00020?n00003003o003o0000o`0000800?l00P3o00050000o`80o`000P00
o`000`000?l0oh000?n000020?n000@00?l000<0o`000?n0003oP0000P3oP004003o00030?n00000
o`000?l00080oh000P00o`0B0?l000T0003o00<0o`000000o`000?l00P000?l40?l000030000o`3o
0000o`000080oh000P3o0002003o00030?l000000?l0003o00@00?l000<0o`00003o0000o`000P3o
P0050000o`80o`000P3oP0040?l00003003o003oP000oh000080o`003_ooool20?n000800?l000<0
oh00003o0000o`001000o`030?n000H00?l00`3oP002003o0080oh000`00o`040?n000@00?l02@3o
P0000`00o`00oh000?n00004003o0080oh000`00o`070?n000800?l00P3oP002003o00`0oh001000
o`0>0?n000H0o`0000<0003o0?n0003oP0000P00o`070?n000800?l00`3o00040?n000800?l01@3o
P002003o01Sooooo000Foooooa80o`000P000?l30?l00080003o5P3o00000`000?l0o`000?l0000;
0?l00080003o303o00020000o`80o`000P000?l90?l000030000o`3o0000o`000180003o0P3o0002
003o00030?l0003oP000oh0001@0o`003_ooool20000o`<0oh001P00o`020?n000X00?l01`3oP004
003o0080o`000P3oP0000`00o`00oh000?n0000=003o0080oh0000<00?l00?l0003o0000103oP005
0000o`@0oh0000<00?l00?l0003o00000P3oP002003o0080003o0`3o00040?n000800?l00`3o0004
003o00D0o`000P000?l20?n000<00?l00P3oP0020?l00080003o1@3oP002003o0080oh000`3o0002
003o0080o`000`00o`020?n000800?l03_ooool20?l00080oh0000<00?l00?n0003oP000103oP009
0?l00080oh0000<00?l00?l0003o00000P00o`020?l000<0003o0P3o00020000o`80o`0000<0003o
0?l0003o00000P3oP002003o00<0o`00103oP004003o00030?l00000o`000?l00080o`000P00o`0<
0?l000800?l0103o00090000o`030?l000000?l0003o0080003o103o00000`000?l0oh000?n00002
0?n00080o`000P00o`000`3o0000003o0000o`02003o0080003o00<0o`000?n0003oP0000P3oP002
003o0080003o00<0o`000000o`000?l00P00o`040?l00003003o003oP000oh0000800?l03_ooool5
0?n000H00?l00`3oP006003o0080oh000`00o`090?n000800?l02@3oP003003o00T0oh000P00o`02
0?n000800?l00`3oP006003o00030?n00000o`000?l000@0oh000P00o`030?n000800?l04P3oP004
0?l000<0oh000P00o`090?n000<0o`000P000?l20?n000800?l01`3oP00Hooooo`005_oooolB0?l0
0080003o0`3o00020000oaH0o`0000<0003o0?l0003o00002`3o00020000o``0o`000P000?l20?l0
0080003o2@3o00000`000?l0o`000?l0000B0000o`80o`000P00o`000`3o0000oh000?n0000D0?l0
00kooooo0P000?l30?n000H00?l00P3oP00:003o00L0oh001000o`020?l00080oh0000<00?l00?n0
003oP0003@00o`020?n00003003o003o0000o`0000@0oh001@000?l40?n00003003o003o0000o`00
0080oh000P00o`020000o`<0o`00103oP002003o00<0o`001000o`050?l00080003o0P3oP003003o
0080oh000P3o00020000o`D0oh000P00o`020?n000<0o`000P00o`020?l000<00?l00P3oP002003o
00kooooo0P3o00020?n00003003o003oP000oh0000@0oh002@3o00020?n00003003o003o0000o`00
00800?l00P3o00030000o`80o`000P000?l20?l000030000o`3o0000o`000080oh000P00o`030?l0
00@0oh001000o`000`3o00000?l0003o00020?l000800?l0303o0002003o00@0o`002@000?l00`3o
0000003o0000o`020000o`@0o`0000<0003o0?n0003oP0000P3oP0020?l000800?l000<0o`000000
o`000?l00P00o`020000o`030?l0003oP000oh000080oh000P00o`020000o`030?l000000?l0003o
00800?l0103o00000`00o`00oh000?n00002003o00kooooo1@3oP006003o00<0oh001P00o`020?n0
00<00?l02@3oP002003o00T0oh000`00o`090?n000800?l00P3oP002003o00<0oh001P00o`000`3o
P0000?l0003o00040?n000800?l00`3oP002003o0180oh00103o00030?n000800?l02@3oP0030?l0
0080003o0P3oP002003o00L0oh006?ooool001Kooooo0P3o00020000o`h0o`000P000?l@0?l00080
003o5`3o00020000o``0o`000P000?l20?l00080003o2@3o00000`000?l0o`000?l0000B0000o`D0
o`000P3oP0020000o`L0o`000P00o`020?l000800?l01@3o000>ooooo`@00?l000<0oh00003o0000
o`001000o`020?n000T00?l0203oP004003o0080o`000P3oP0000`00o`00oh000?n0000=003o0080
oh000`00o`020?l000L0003o103oP0000`00o`00o`000?l000020?n000800?l00P000?l00`3o0000
003o0000o`020?n00080003o0P00o`030?l000800?l0103o00000`00o`00o`000?l000020000o`80
oh000`00o`020?n00080o`000P000?l50?n000800?l00`3o00020000o`80oh000P3o0003003o0080
oh000P00o`0>ooooo`@0oh0000<00?l00?n0003oP000103oP002003o00030000o`00o`000?l000@0
o`001`00o`020000o`030?l000000?l0003o00L0003o0P3o0004003o00<0o`00103oP002003o00<0
o`000P00o`020?l000@00?l02P3o0002003o00@0o`002@000?l00`00o`00003o0000o`060?l00003
0000o`3oP000oh000080o`001000o`000`3o0000003o0000o`020000o`<0o`00103oP002003o0080
003o0`3o0002003o00@0o`0000<0003o0?n0003oP0000P3o000>ooooo`L0oh000P00o`050?n00080
0?l0103oP002003o00030?n00000o`000?l000@0oh000`00o`040?n000<00?l0203oP0000`00o`00
oh000?n000070?n000800?l00P3oP002003o00D0oh000P00o`030?n000@00?l01`3oP002003o00T0
oh000P00o`0>0?n000@00?l01@3oP0020?l00080003o1@3oP002003o00L0oh006?ooool001Kooooo
0P3o00020000o`h0o`000P000?l@0?l00080003o5`3o00020000o``0o`000P000?l20?l00080003o
2@3o00000`000?l0o`000?l0000B0000o`D0o`000P3oP0020000o`L0o`000P00o`020?l000800?l0
1@3o000>ooooo`@00?l000<0oh00003o0000o`001000o`020?n000T00?l0203oP004003o0080o`00
0P3oP0000`00o`00oh000?n0000=003o0080oh000`00o`020?l000L0003o103oP0000`00o`00o`00
0?l000020?n000800?l00P000?l00`3o0000003o0000o`020?n00080003o0P00o`030?l000800?l0
103o00000`00o`00o`000?l000020000o`80oh000`00o`020?n00080o`000P000?l50?n000800?l0
0`3o00020000o`80oh000P3o0003003o0080oh000P00o`0>ooooo`@0oh0000<00?l00?n0003oP000
103oP002003o00030000o`00o`000?l000@0o`001`00o`020000o`030?l000000?l0003o00L0003o
0P3o0004003o00<0o`00103oP002003o00<0o`000P00o`020?l000@00?l02P3o0002003o00@0o`00
2@000?l00`00o`00003o0000o`060?l000030000o`3oP000oh000080o`001000o`000`3o0000003o
0000o`020000o`<0o`00103oP002003o0080003o0`3o0002003o00@0o`0000<0003o0?n0003oP000
0P3o000>ooooo`L0oh000P00o`050?n000800?l0103oP002003o00030?n00000o`000?l000@0oh00
0`00o`040?n000<00?l0203oP0000`00o`00oh000?n000070?n000800?l00P3oP002003o00D0oh00
0P00o`030?n000@00?l01`3oP002003o00T0oh000P00o`0>0?n000@00?l01@3oP0020?l00080003o
1@3oP002003o00L0oh006?ooool001Kooooo0P3o0002003o04L0o`000P000?l@0?l00080003o0P3o
00070000o`80o`000P000?l00`3o0000003o0000o`070?l000H0003o0`3o0002003o0080o`000P00
o`050?l000kooooo1000o`000`3oP0000?l0003o0004003o0080oh001@00o`050?n00080o`001@3o
P004003o0080o`000P3oP0000`00o`00oh000?n0000=003o0080oh0000<0o`00003o0000o`002@00
0?l40?n000D0o`0010000?l00`3o0000003o0000o`020?n00080003o0P00o`030?l000800?l0103o
00000`00o`00o`000?l000020000o`@0oh0000<00?l00?l0003o00000P3o00020000o`<0oh001000
o`030?l00080003o103oP003003o0080oh000P00o`0>ooooo`80oh000`00o`060?n000800?l000<0
oh00003o0000o`000P3o0004003o00030?l0003oP000oh000080oh000P3o00000`000?l0o`000?l0
00060000o`<0o`000P00o`050?l000@0oh000P00o`030?l00080oh000P3o0002003o0180o`000`00
0?l40?l00080003o00<00?l00000o`000?l010000?l20?l000030000o`3oP000oh000080o`001000
o`030?l00080003o0P3o00050?n000@00?l00`3o0004003o00L0o`003_ooool70?n000800?l0103o
P003003o00@0oh001@00o`050?n000800?l0103oP003003o0180oh000P00o`020?n000800?l00P3o
P0000`00o`00oh000?n00002003o00<0oh001000o`040?n00003003o003oP000oh0000/0oh000P00
o`0@0?n000800?l00`3oP0040?l00080003o1@3oP002003o00L0oh006?ooool001Kooooo0P3o0002
003o04L0o`000P000?l@0?l00080003o0P3o00070000o`80o`000P000?l00`3o0000003o0000o`07
0?l000H0003o0`3o0002003o0080o`000P00o`050?l000kooooo1000o`000`3oP0000?l0003o0004
003o0080oh001@00o`050?n00080o`001@3oP004003o0080o`000P3oP0000`00o`00oh000?n0000=
003o0080oh0000<0o`00003o0000o`002@000?l40?n000D0o`0010000?l00`3o0000003o0000o`02
0?n00080003o0P00o`030?l000800?l0103o00000`00o`00o`000?l000020000o`@0oh0000<00?l0
0?l0003o00000P3o00020000o`<0oh001000o`030?l00080003o103oP003003o0080oh000P00o`0>
ooooo`80oh000`00o`060?n000800?l000<0oh00003o0000o`000P3o0004003o00030?l0003oP000
oh000080oh000P3o00000`000?l0o`000?l000060000o`<0o`000P00o`050?l000@0oh000P00o`03
0?l00080oh000P3o0002003o0180o`000`000?l40?l00080003o00<00?l00000o`000?l010000?l2
0?l000030000o`3oP000oh000080o`001000o`030?l00080003o0P3o00050?n000@00?l00`3o0004
003o00L0o`003_ooool70?n000800?l0103oP003003o00@0oh001@00o`050?n000800?l0103oP003
003o0180oh000P00o`020?n000800?l00P3oP0000`00o`00oh000?n00002003o00<0oh001000o`04
0?n00003003o003oP000oh0000/0oh000P00o`0@0?n000800?l00`3oP0040?l00080003o1@3oP002
003o00L0oh006?ooool001Kooooo0P3o0002003o00L0o`000P3oP0030000obH0o`000P00o`030?l0
00800?l03P3o00020000o`d0o`0000<0003o0?l0003o00000P000?l40?l000D0003o0P3o00020000
o`030?l000000?l0003o00L0o`000P000?l20?l00080003o0`3o0002003o00@0o`000`00o`020?l0
00kooooo0P3o0002003o00030?n00000o`000?l000@00?l00P3oP005003o00D0oh000P3o00050?n0
00@00?l00P3o00020?n000<00?l00P3oP00;003o0080oh0000<0o`000?n0003oP0000P000?l20?l0
00D0003o103oP0050?l000@0003o00<0o`000000o`000?l00P3oP0020000o`800?l000<0o`000000
o`000?l00P00o`020?l000<00?l00P3o00020000o`@0oh0000<00?l00?l0003o00000P3o00020000
o`<0oh001000o`020?n00003003o003oP000oh0000@0oh000`00o`040?n000kooooo0P3oP005003o
00L0oh000P00o`020?l000800?l00`3o0002003o0080oh000P3o000:0000o`80o`000P00o`040?l0
00030000o`3oP000oh000080oh001000o`000`3o0000003o0000o`02003o00@0o`0000<0003o0?l0
003o00002@3o00020000o`<0o`000P000?l20?l000@0003o00<0o`000000o`000?l010000?l70?l0
0080003o0`3o00040000o`<0o`001P3oP005003o0080oh000P00o`070?l000kooooo0P00o`030?n0
00@00?l00P3oP005003o00h0oh000P00o`040?n000<00?l04P3oP002003o0080oh001`00o`020?n0
00800?l000<0oh00003o0000o`003@3oP003003o00@0oh000P00o`0;0?n00003003o003oP000oh00
00L0oh000P3o0002003o00L0oh000P00o`030?n000800?l00P3oP00Hooooo`005_ooool20?l00080
0?l01`3o00020?n000L0003o4`3o00020000ob00o`000P000?l?0?l000030000o`3o0000o`000080
003o0P3o00020000o`030?l000000?l0003o00@0o`001@000?l;0?l000<0003o203o00000`00o`00
oh000?n000020?n000kooooo0P3o0002003o00030?n00000o`000?l000@00?l00P3oP005003o00@0
oh0000<00?l00?l0003o0000103oP0030?l000800?l00P3o00020?n00003003o003o0000o`000080
oh001000o`030?n000@00?l00P3o00000`00o`00oh000?n000090000o`@0oh000`3o00020?n000@0
003o00<0o`000000o`000?l00P3oP0040000o`030?l000000?l0003o00800?l00P3o0003003o0080
o`000P000?l40?n00003003o003o0000o`000080o`000P000?l30?n000800?l0103oP0000`00o`00
oh000?n000040?n000<00?l00P3oP002003o00kooooo0P3oP0020?l000D00?l0103oP003003o0080
o`001000o`000`3o00000?l0003o00020?n000/0003o0`3o00020?n000800?l00P3o00000`000?l0
oh000?n000020?n000@00?l000<0o`000000o`000?l00P00o`070000o`@0o`0000<00?l00?l0003o
00000P3oP002003o0080oh000`3o000=0000o`80o`0000<0003o0?l0003o00001P3o00000`000?l0
o`000?l000020?l000800?l01`3oP002003o00030?l000000?l0003o0080oh000P00o`030000o`@0
o`003_ooool40?n000<00?l0103oP005003o00@0oh000P00o`000`3oP0000?l0003o00040?n000<0
0?l0103oP002003o00h0oh000P00o`020?n000<00?l00P3oP002003o0080oh000`00o`020?n00080
0?l01@3oP002003o01L0oh000P00o`040?n00003003o003oP000oh0000T0oh000P00o`020?n00003
003o003oP000oh0000/0oh006?ooool001Kooooo0P3o0002003o00L0o`000P3oP0070000oa<0o`00
0P000?lP0?l00080003o3`3o00000`000?l0o`000?l000020000o`80o`000P000?l00`3o0000003o
0000o`040?l000D0003o2`3o00030000o`P0o`0000<00?l00?n0003oP0000P3oP00>ooooo`80o`00
0P00o`000`3oP0000?l0003o0004003o0080oh001@00o`040?n00003003o003o0000o`0000@0oh00
0`3o0002003o0080o`000P3oP0000`00o`00o`000?l000020?n000@00?l00`3oP004003o0080o`00
00<00?l00?n0003oP0002@000?l40?n000<0o`000P3oP0040000o`030?l000000?l0003o0080oh00
10000?l00`3o0000003o0000o`02003o0080o`000`00o`020?l00080003o103oP0000`00o`00o`00
0?l000020?l00080003o0`3oP002003o00@0oh0000<00?l00?n0003oP000103oP003003o0080oh00
0P00o`0>ooooo`80oh000P3o0005003o00@0oh000`00o`020?l000@00?l000<0o`00003o0000o`00
0P3oP00;0000o`<0o`000P3oP002003o0080o`0000<0003o0?n0003oP0000P3oP004003o00030?l0
00000?l0003o00800?l01`000?l40?l00003003o003o0000o`000080oh000P00o`020?n000<0o`00
3@000?l20?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00000P3o0002003o00L0oh00
0P00o`000`3o0000003o0000o`020?n000800?l00`000?l40?l000kooooo103oP003003o00@0oh00
1@00o`040?n000800?l000<0oh00003o0000o`00103oP003003o00@0oh000P00o`0>0?n000800?l0
0P3oP003003o0080oh000P00o`020?n000<00?l00P3oP002003o00D0oh000P00o`0G0?n000800?l0
103oP0000`00o`00oh000?n000090?n000800?l00P3oP0000`00o`00oh000?n0000;0?n001Sooooo
000Fooooo`80o`000P00o`070?l00080oh0000<0003o0?l0003o00000P000?lE0?l00080003o803o
00020000o`@0o`000`000?l80?l000030000o`3o0000o`000080o`000P000?l30?l00080003o103o
00050000o`80oh002@3o00030000o`P0o`0000<00?l00?l0003o00000P3o000>ooooo`80oh000P00
o`000`3oP0000?l0003o0004003o00<0oh001P00o`020?n00003003o003o0000o`000080oh000P00
o`000`3o00000?l0003o0002003o0080o`000P3oP003003o0080oh001000o`030?n000L00?l00P3o
P0020000o`80o`000`000?l60?n000<0o`000P3oP002003o0080003o00<0o`000000o`000?l00P3o
00050000o`80o`000P00o`020?l000<00?l0103o00040?n00003003o003oP000oh000080o`000P00
0?l30?n000800?l0103oP0000`00o`00o`000?l00006003o00030?l0003oP000oh0000800?l03_oo
ool20?n00080o`001@00o`020?n000<00?l00P3o00020?n000L00?l00P3oP0020?l000X0003o0P3o
00020?n000@0o`0000<0003o0?n0003oP0000P3oP004003o00<0o`000P00o`020?l000D0003o103o
00000`00o`00o`000?l000020?n000800?l00`3oP0020?l000d0003o0P3o00000`000?l0o`000?l0
00020?l00080003o1@3o0004003o00D0oh001@3o00020000o`80oh001`000?l2003o00kooooo0P00
o`020?n000<00?l0103oP007003o0080oh000P00o`070?n00003003o003oP000oh0000@0oh000P00
o`0>0?n000@00?l01@3oP002003o0080oh000`00o`020?n000<00?l0103oP002003o00L0oh001000
o`0<0?n000800?l0103oP0000`00o`00oh000?n000090?n000800?l00P3oP003003o00/0oh006?oo
ool001Kooooo0P3o0002003o00L0o`000P3oP0000`000?l0o`000?l000020000oaD0o`000P000?lP
0?l00080003o103o00030000o`P0o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l4
0?l000D0003o0P3oP0090?l000<0003o203o00000`00o`00o`000?l000020?l000kooooo0P3oP002
003o00030?n00000o`000?l000@00?l00`3oP006003o0080oh0000<00?l00?l0003o00000P3oP002
003o00030?l00000o`000?l000800?l00P3o00020?n000<00?l00P3oP004003o00<0oh001`00o`02
0?n00080003o0P3o00030000o`H0oh000`3o00020?n000800?l00P000?l00`3o0000003o0000o`02
0?l000D0003o0P3o0002003o0080o`000`00o`040?l000@0oh0000<00?l00?n0003oP0000P3o0002
0000o`<0oh000P00o`040?n00003003o003o0000o`0000H00?l000<0o`000?n0003oP0000P00o`0>
ooooo`80oh000P3o0005003o0080oh000`00o`020?l00080oh001`00o`020?n00080o`002P000?l2
0?l00080oh00103o00000`000?l0oh000?n000020?n000@00?l00`3o0002003o0080o`001@000?l4
0?l00003003o003o0000o`000080oh000P00o`030?n00080o`003@000?l20?l000030000o`3o0000
o`000080o`000P000?l50?l000@00?l01@3oP0050?l00080003o0P3oP0070000o`800?l03_ooool2
003o0080oh000`00o`040?n000L00?l00P3oP002003o00L0oh0000<00?l00?n0003oP000103oP002
003o00h0oh001000o`050?n000800?l00P3oP003003o0080oh000`00o`040?n000800?l01`3oP004
003o00`0oh000P00o`040?n00003003o003oP000oh0000T0oh000P00o`020?n000<00?l02`3oP00H
ooooo`005_ooool20000o`L0o`000P000?lL0?l00080003o503o00020000o`D0o`000P00o`0;0?l0
00030000o`3o0000o`0000T0o`000P000?l50?l000@0003o0P3o00050000o`80oh002@3o00020000
o`L0o`000P3oP0000`00o`00o`000?l000020?l000kooooo0P3oP002003o00030?n00000o`000?l0
00@00?l00`3oP006003o0080oh0000<00?l00?n0003oP0000P3oP002003o00030?n00000o`000?l0
00800?l00P3o00020?n000<00?l00P3oP009003o0080oh000P00o`050?n000800?l00`000?l60?n0
00030?l000000?l0003o0080oh000P00o`020000o`030?l000000?l0003o0080o`000P000?l3003o
0080o`000P00o`020?l000<00?l0103o00050?n000H00?l00`3oP002003o0080oh000`00o`020?l0
00800?l00P000?l2003o00<0o`000P00o`0>ooooo`@0o`000`00o`020?l00080oh000`00o`020?l0
00H0oh000`00o`020?n000<0o`000P000?l20?l00080003o0`3o00020000o`80oh000P3o0002003o
00D0oh001000o`000`3o0000oh000?n00002003o00L0003o1`3o00020?n000800?l00`3oP0040000
o`@0o`001`000?l20?l000030000o`3oP000oh000080o`000P000?l2003o00<0o`001@00o`040?n0
00D0o`000P000?l20?l00080003o0P3o00030000o`80o`003_ooool2003o0080oh000`00o`040?n0
00800?l000<0oh00003o0000o`000P00o`020?n00080o`000`3oP002003o0080oh0000<00?l00?n0
003oP000103oP003003o00d0oh001@00o`040?n000800?l00`3oP007003o00@0oh001000o`050?n0
00800?l02`3oP0000`00o`00oh000?n000060?n00003003o003oP000oh0000T0oh000P00o`020?n0
00D00?l01@3oP002003o0080oh006?ooool001Kooooo0P000?l70?l00080003o703o00020000oa@0
o`000P000?l50?l000800?l02`3o00000`000?l0o`000?l000090?l00080003o1@3o00040000o`80
o`001@000?l20?n000T0o`000P000?l70?l00080oh0000<00?l00?l0003o00000P3o000>ooooo`80
oh000P00o`000`3oP0000?l0003o0004003o00<0oh001P00o`020?n00003003o003oP000oh000080
oh000P00o`000`3oP0000?l0003o0002003o0080o`000P3oP003003o0080oh002@00o`020?n00080
0?l01@3oP002003o00<0003o1P3oP0000`3o0000003o0000o`020?n000800?l00P000?l00`3o0000
003o0000o`020?l00080003o0`00o`020?l000800?l00P3o0003003o00@0o`001@3oP006003o00<0
oh000P00o`020?n000<00?l00P3o0002003o0080003o0P00o`030?l000800?l03_ooool40?l000<0
0?l00P3o00020?n000<00?l00P3o00060?n000<00?l00P3oP0030?l00080003o0P3o00020000o`<0
o`000P000?l20?n00080o`000P00o`050?n000@00?l000<0o`000?n0003oP0000P00o`070000o`L0
o`000P3oP002003o00<0oh0010000?l40?l000L0003o0P3o00000`000?l0oh000?n000020?l00080
003o0P00o`030?l000D00?l0103oP0050?l00080003o0P3o00020000o`80o`000`000?l20?l000ko
oooo0P00o`020?n000<00?l0103oP002003o00030?n00000o`000?l000800?l00P3oP0020?l000<0
oh000P00o`020?n00003003o003oP000oh0000@0oh000`00o`0=0?n000D00?l0103oP002003o00<0
oh001`00o`040?n000@00?l01@3oP002003o00/0oh0000<00?l00?n0003oP0001P3oP0000`00o`00
oh000?n000090?n000800?l00P3oP005003o00D0oh000P00o`020?n001Sooooo000Fooooo`80oh00
0P00o`0i0?l00080003o1@3o0002003o00/0o`000`000?l90?l00080003o103o00000`000?l0o`00
0?l000040?l00080003o3P3o00030000o`80o`000P00o`020?l00080oh001@3o000>ooooo`80oh00
0P00o`000`3oP0000?l0003o0004003o00<0oh002@00o`040?n000L00?l0103oP003003o0080oh00
2@00o`020?n000D00?l00P3oP002003o00<0003o1P3oP0000`3o0000003o0000o`020?n000800?l0
0P000?l90?l00003003o003o0000o`000080oh000P3o0007003o00D0oh001P00o`000`3oP0000?l0
003o0002003o0080oh000P00o`030?l000800?l01@000?l40?n000kooooo0P3o0003003o00@0o`00
0P3oP003003o0080o`001000o`030?n000800?l00P3oP002003o00030000o`3o0000o`0000L0o`00
0P000?l60?l000<0oh001000o`030?l00080003o0P00o`020000o`80o`001@000?l50?l00080oh00
0P00o`020?l000030?n000000?l0003o00@0003o0P3o00070000o`80o`0000<0003o0?n0003oP000
0P00o`020000o`800?l00`3o0005003o00@0oh000P00o`020?n000D0o`000P000?l20?l000D0003o
3_ooool2003o0080oh0000<0o`00003o0000o`001`3oP002003o00@0oh000P00o`030?n000800?l0
0P3oP0000`00o`00oh000?n000020?n000D00?l03@3oP002003o0080oh0000<00?l00?n0003oP000
0P3oP002003o00L0oh000`00o`060?n000800?l00`3oP002003o00L0oh000P00o`020?n000<00?l0
203oP0000`3o0000oh000?n000020?n000800?l02P3oP004003o00@0oh000`00o`020?n001Sooooo
000Fooooo`80oh000P00o`0i0?l00080003o1@3o0002003o00/0o`000`000?l90?l00080003o103o
00000`000?l0o`000?l000040?l00080003o3P3o00030000o`80o`000P00o`020?l00080oh001@3o
000>ooooo`80oh000P00o`000`3oP0000?l0003o0004003o00<0oh002@00o`040?n000L00?l0103o
P003003o0080oh002@00o`020?n000D00?l00P3oP002003o00<0003o1P3oP0000`3o0000003o0000
o`020?n000800?l00P000?l90?l00003003o003o0000o`000080oh000P3o0007003o00D0oh001P00
o`000`3oP0000?l0003o0002003o0080oh000P00o`030?l000800?l01@000?l40?n000kooooo0P3o
0003003o00@0o`000P3oP003003o0080o`001000o`030?n000800?l00P3oP002003o00030000o`3o
0000o`0000L0o`000P000?l60?l000<0oh001000o`030?l00080003o0P00o`020000o`80o`001@00
0?l50?l00080oh000P00o`020?l000030?n000000?l0003o00@0003o0P3o00070000o`80o`0000<0
003o0?n0003oP0000P00o`020000o`800?l00`3o0005003o00@0oh000P00o`020?n000D0o`000P00
0?l20?l000D0003o3_ooool2003o0080oh0000<0o`00003o0000o`001`3oP002003o00@0oh000P00
o`030?n000800?l00P3oP0000`00o`00oh000?n000020?n000D00?l03@3oP002003o0080oh0000<0
0?l00?n0003oP0000P3oP002003o00L0oh000`00o`060?n000800?l00`3oP002003o00L0oh000P00
o`020?n000<00?l0203oP0000`3o0000oh000?n000020?n000800?l02P3oP004003o00@0oh000`00
o`020?n001Sooooo000Fooooo`80003o0P00o`000`000?l0o`000?l0000;0?l00080003o<P3o0002
0000o`<0o`0010000?l>0?l00080003o103o00030000oaT0o`000P00o`020?l00080oh001@3o000>
ooooo`80oh002@00o`020?n000X00?l0103oP003003o0080oh002@00o`020?n001000?l00P3oP002
003o00<0003o1P3oP0000`3o0000003o0000o`020000o`800?l00P000?l70?l00080003o1@3oP002
0?l000T00?l00`3oP006003o00030?n00000o`000?l000800?l00P3oP002003o00D0o`000P000?l2
0?l000030000o`3oP000oh000080oh003_ooool20?l000<0oh000P3o0002003o0080oh000`00o`02
0?l000@00?l00`3oP002003o0080003o303o00020000o`H0o`0000<0003o0?n0003oP0001000o`05
0?l000800?l0103o00070000o`<0o`001000o`030?l00080003o0P3o00020000o`80o`0000<00?l0
0000o`000?l01`000?l20?n000800?l01`3o00020?n000<00?l00P3o00020?n000800?l00P3oP000
0`00o`00003o0000o`02003o0080003o0P3o00000`000?l0oh000?n000020000o`kooooo0P00o`03
0?n000800?l01`3oP004003o0080oh000P00o`030?n000D00?l01P3oP003003o00P0oh0000<00?l0
0?n0003oP000103oP003003o00@0oh000P00o`030?n000800?l00P3oP002003o00<0oh000P00o`02
0?n000800?l000<0oh00003o0000o`003@3oP0020?l00003003o003oP000oh0000@0oh000`3o0002
0000o`h0oh001000o`040?n000<00?l00P3oP00Hooooo`005_ooool20?n000800?l01@3o00020000
o`L0o`000P000?l20?l000030000o`3o0000o`0001L0o`000P00o`0D0?l000<0003o0P3o00040000
o`h0o`000P000?l40?l000<0003o6@3o0002003o0080o`000P3oP0050?l000kooooo0P3oP009003o
0080oh004@00o`020?n000T00?l00P3oP00=003o00030?n00000o`000?l00080oh000P00o`030000
o`800?l0103oP0000`3o0000003o0000o`060000o`030?l00000o`000?l000H0o`001@3oP0020?l0
0080oh002@00o`000`3oP0000?l0003o0002003o00<0oh001000o`020?n000800?l01@3o00020000
o`80o`0000<0003o0?n0003oP0000P00o`0>ooooo`80o`000`3oP004003o0080oh000`00o`020?n0
00@00?l00`3oP002003o00D0o`000P000?l70?l00080003o0P3oP0020000o`80o`0000<0003o0?n0
003oP0001000o`0;0?l000<0003o0P3o00020000o`03003o003o0000o`0000H0003o403o00020000
o`<0o`000P00o`020?l00080oh0000<0o`00003o0000o`000P3oP0020?l00003003o003oP000oh00
0080oh000P00o`030?n00080003o0P00o`020000o`80o`0000<0003o0?n0003oP0000P000?l>oooo
o`800?l00`3oP002003o0080o`001@3oP004003o0080oh000P00o`030?n000800?l00P3oP0000`00
o`00oh000?n000020?n000D00?l0103oP002003o0080oh0000<00?l00?n0003oP0001P3oP0000`00
o`00oh000?n000020?n000@00?l000<0oh00003o0000o`000P3oP002003o00<0oh000P00o`020?n0
00800?l000<0oh00003o0000o`000P3oP0020?l000D0oh000P00o`040?l00003003o003oP000oh00
00H0oh0000<0o`000?n0003oP0000P3oP002003o0100oh000P00o`030?n000800?l06?ooool001Ko
oooo0P3oP002003o00D0o`000P000?l70?l00080003o0P3o00000`000?l0o`000?l0000G0?l00080
0?l0503o00030000o`80o`0010000?l>0?l00080003o103o00030000oaT0o`000P00o`020?l00080
oh001@3o000>ooooo`80oh002@00o`020?n001400?l00P3oP009003o0080oh003@00o`000`3oP000
0?l0003o00020?n000800?l00`000?l2003o00@0oh0000<0o`000000o`000?l01P000?l00`3o0000
0?l0003o00060?l000D0oh000P3o00020?n000T00?l000<0oh00003o0000o`000P00o`030?n000@0
0?l00P3oP002003o00D0o`000P000?l20?l000030000o`3oP000oh0000800?l03_ooool20?l000<0
oh001000o`020?n000<00?l00P3oP004003o00<0oh000P00o`050?l00080003o1`3o00020000o`80
oh000P000?l20?l000030000o`3oP000oh0000@00?l02`3o00030000o`80o`000P000?l00`00o`00
o`000?l000060000oa00o`000P000?l30?l000800?l00P3o00020?n000030?l00000o`000?l00080
oh000P3o00000`00o`00oh000?n000020?n000800?l00`3oP0020000o`800?l00P000?l20?l00003
0000o`3oP000oh000080003o3_ooool2003o00<0oh000P00o`020?l000D0oh001000o`020?n00080
0?l00`3oP002003o0080oh0000<00?l00?n0003oP0000P3oP005003o00@0oh000P00o`020?n00003
003o003oP000oh0000H0oh0000<00?l00?n0003oP0000P3oP004003o00030?n00000o`000?l00080
oh000P00o`030?n000800?l00P3oP002003o00030?n00000o`000?l00080oh000P3o00050?n00080
0?l0103o00000`00o`00oh000?n000060?n000030?l0003oP000oh000080oh000P00o`0@0?n00080
0?l00`3oP002003o01Sooooo000Fooooo`80oh000P00o`0>0?l00080003o0P3o00000`000?l0o`00
0?l0000;0?l00080003o2P3o0002003o01@0o`000P000?l00`3o0000003o0000o`0B0?l00080003o
1@3o00020000o`@0o`000P000?l80?l00080003o0P3o00020000o`80o`0000<0003o0?l0003o0000
103o0002003o00D0o`003_ooool;003o0080oh004@00o`020?n001T00?l00P3oP0070000o`800?l0
103oP0000`00o`00003o0000o`040000o`<0o`000P000?l70?l00080003o0P00o`050?n000P00?l0
00<0oh00003o0000o`000P00o`030?n000H00?l00P3oP0000`00o`00o`000?l000020?l00080003o
0P3o00000`000?l0oh000?n000020?n000kooooo0P00o`030?n000T00?l0103oP004003o00030?n0
0000o`000?l00080o`000P3oP0000`00o`00o`000?l000070?l00080003o0P3oP0020000o`80o`00
00<0003o0?n0003oP0003`3o00030000o`80o`000P000?l00`00o`00o`000?l0000;0000o`@0o`00
00<0003o0?l0003o0000103o00020000o`L0o`000P3oP0000`3o00000?l0003o00020?n00080o`00
00<00?l00?n0003oP0000P3oP002003o00<0oh000P000?l20?l00080003o1@3o00020000o`kooooo
0P00o`030?n000800?l01`3oP004003o0080oh000P00o`030?n000D00?l0103oP005003o00@0oh00
0P00o`020?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0001`3oP002003o00L0oh00
0P00o`050?n000800?l02@3oP002003o00@0oh0000<00?l00?n0003oP0001P3oP0000`00o`00o`00
0?l00004003o00030?n00000o`000?l000800?l02@3oP004003o00D0oh006?ooool001Kooooo0P3o
P002003o00h0o`000P000?l20?l000030000o`3o0000o`0000/0o`000P000?l:0?l000800?l0503o
00020000o`030?l000000?l0003o0180o`000P000?l50?l00080003o103o00020000o`P0o`000P00
0?l20?l00080003o0P3o00000`000?l0o`000?l000040?l000800?l01@3o000>ooooo`/00?l00P3o
P00A003o0080oh006@00o`020?n000L0003o0P00o`040?n00003003o00000?l0003o00@0003o0`3o
00020000o`L0o`000P000?l2003o00D0oh002000o`000`3oP0000?l0003o0002003o00<0oh001P00
o`020?n00003003o003o0000o`000080o`000P000?l20?l000030000o`3oP000oh000080oh003_oo
ool2003o00<0oh002@00o`040?n000@00?l000<0oh00003o0000o`000P3o00020?n00003003o003o
0000o`0000L0o`000P000?l20?n00080003o0P3o00000`000?l0oh000?n0000?0?l000<0003o0P3o
00020000o`03003o003o0000o`0000/0003o103o00000`000?l0o`000?l000040?l00080003o1`3o
00020?n000030?l00000o`000?l00080oh000P3o00000`00o`00oh000?n000020?n000800?l00`3o
P0020000o`80o`000P000?l50?l00080003o3_ooool2003o00<0oh000P00o`070?n000@00?l00P3o
P002003o00<0oh001@00o`040?n000D00?l0103oP002003o0080oh0000<00?l00?n0003oP0001P3o
P0000`00o`00oh000?n000070?n000800?l01`3oP002003o00D0oh000P00o`090?n000800?l0103o
P0000`00o`00oh000?n000060?n00003003o003o0000o`0000@00?l000<0oh00003o0000o`000P00
o`090?n000@00?l01@3oP00Hooooo`005_ooool20000o`800?l01`3o00020?n001X0o`000P00o`07
0?l000800?l0503o00020000oa/0o`000`000?l40?l00080003o1@3o00020000o`030?l000000?l0
003o0080o`001@000?l20?l00080003o2@3o000>oooooc@00?l00P3oP003003o0080oh001`000?l2
003o0080o`000P3oP0000`00o`00003o0000o`040000o`<0o`000P000?l70?l00080003o1000o`03
0?n000@00?l00P3oP002003o00030?n00000o`000?l00080o`000P000?l00`3oP0000?l0003o0004
003o00<0oh00103o00020000o`80oh0000<00?l00?n0003oP0000P3oP00>ooooo`800?l00P3o0000
0`3oP0000?l0003o0004003o0080oh0000<0o`00003o0000o`00103oP002003o00030?n00000o`00
0?l000800?l00P3oP0000`00o`00o`000?l000020000o`D0o`000P000?l20?n00080003o2`3o0000
0`000?l0o`000?l000040?l00080003o00<0o`000000o`000?l00P000?l50?l000/0003o103o0000
0`000?l0o`000?l000020000o`80o`000P000?l<0?l00080oh000P00o`050?n000800?l00`3oP002
0000o`80o`000P000?l30?l000800?l00P3o000>ooooo`800?l00`3oP002003o00L0oh001000o`07
0?n000D00?l0103oP002003o0080oh0000<00?l00?n0003oP0000P3oP002003o0080oh0000<00?l0
0?n0003oP0001P3oP0000`00o`00oh000?n000020?n000800?l00`3oP002003o00L0oh000P00o`04
0?n000<00?l00P3oP004003o00<0oh000P00o`040?n00003003o003oP000oh0000H0oh001`00o`03
0?n000800?l02@3oP004003o00<0oh000P00o`0Hooooo`005_ooool20000o`800?l01`3o00020?n0
01X0o`000P00o`070?l000800?l0503o00020000oa/0o`000`000?l40?l00080003o1@3o00020000
o`030?l000000?l0003o0080o`001@000?l20?l00080003o2@3o000>oooooc@00?l00P3oP003003o
0080oh001`000?l2003o0080o`000P3oP0000`00o`00003o0000o`040000o`<0o`000P000?l70?l0
0080003o1000o`030?n000@00?l00P3oP002003o00030?n00000o`000?l00080o`000P000?l00`3o
P0000?l0003o0004003o00<0oh00103o00020000o`80oh0000<00?l00?n0003oP0000P3oP00>oooo
o`800?l00P3o00000`3oP0000?l0003o0004003o0080oh0000<0o`00003o0000o`00103oP002003o
00030?n00000o`000?l000800?l00P3oP0000`00o`00o`000?l000020000o`D0o`000P000?l20?n0
0080003o2`3o00000`000?l0o`000?l000040?l00080003o00<0o`000000o`000?l00P000?l50?l0
00/0003o103o00000`000?l0o`000?l000020000o`80o`000P000?l<0?l00080oh000P00o`050?n0
00800?l00`3oP0020000o`80o`000P000?l30?l000800?l00P3o000>ooooo`800?l00`3oP002003o
00L0oh001000o`070?n000D00?l0103oP002003o0080oh0000<00?l00?n0003oP0000P3oP002003o
0080oh0000<00?l00?n0003oP0001P3oP0000`00o`00oh000?n000020?n000800?l00`3oP002003o
00L0oh000P00o`040?n000<00?l00P3oP004003o00<0oh000P00o`040?n00003003o003oP000oh00
00H0oh001`00o`030?n000800?l02@3oP004003o00<0oh000P00o`0Hooooo`005_ooool20?n00080
0?l00`3o0002003o0080o`000`3oP00I0?l000800?l03@3o00020000o`h0o`000P000?lI0?l000D0
003o103o00020000o`P0o`000P000?l20?l000D0003o0P3o00020000o`D0o`000P000?l20?l000ko
oooo2`00o`020?n001<00?l00P3oP00@003o00@0oh000`00o`020?n000L0003o103o00020?n000L0
003o0P3o00000`00o`00003o0000o`090?l000@00?l00`3oP004003o0080oh000P00o`030?n00080
o`000P000?l00`3oP0000?l0003o0004003o00<0oh00103o00020000o`80oh0000<00?l00?n0003o
P0000P3oP00>ooooo`800?l00P3o00000`3oP0000?l0003o00020?n000800?l00P3oP0000`3o0000
003o0000o`020?n000@00?l000<0o`00003o0000o`000P00o`020?l00003003o003o0000o`000080
o`000P3oP0020000o`030?l000000?l0003o0080o`000P000?l20?n000D0o`000P3oP003003o0080
oh00103o00020000o`030?l000000?l0003o0080003o0`3o00020000o`80o`000P000?l20?l000L0
003o0`3o00090000o`80o`001P000?l30?l00080oh000P3o00000`000?l0oh000?n000020?n000@0
0?l02@3o00000`000?l0o`000?l000020?l000kooooo0P00o`030?n000800?l01P3oP0000`00o`00
oh000?n00002003o00@0oh0000<00?l00?n0003oP0000P3oP002003o00T0oh001@00o`050?n00080
0?l0403oP002003o00d0oh000`00o`020?n000@00?l000<0oh00003o0000o`000P00o`040?n00003
003o003oP000oh000080oh000P00o`020?n000<00?l00P3o0002003o00D0oh000P00o`090?n00080
0?l01@3oP00Hooooo`005_ooool20?n000800?l00`3o0002003o0080o`000`3oP00I0?l000800?l0
3@3o00020000o`h0o`000P000?lI0?l000D0003o103o00020000o`P0o`000P000?l20?l000D0003o
0P3o00020000o`D0o`000P000?l20?l000kooooo2`00o`020?n001<00?l00P3oP00@003o00@0oh00
0`00o`020?n000L0003o103o00020?n000L0003o0P3o00000`00o`00003o0000o`090?l000@00?l0
0`3oP004003o0080oh000P00o`030?n00080o`000P000?l00`3oP0000?l0003o0004003o00<0oh00
103o00020000o`80oh0000<00?l00?n0003oP0000P3oP00>ooooo`800?l00P3o00000`3oP0000?l0
003o00020?n000800?l00P3oP0000`3o0000003o0000o`020?n000@00?l000<0o`00003o0000o`00
0P00o`020?l00003003o003o0000o`000080o`000P3oP0020000o`030?l000000?l0003o0080o`00
0P000?l20?n000D0o`000P3oP003003o0080oh00103o00020000o`030?l000000?l0003o0080003o
0`3o00020000o`80o`000P000?l20?l000L0003o0`3o00090000o`80o`001P000?l30?l00080oh00
0P3o00000`000?l0oh000?n000020?n000@00?l02@3o00000`000?l0o`000?l000020?l000kooooo
0P00o`030?n000800?l01P3oP0000`00o`00oh000?n00002003o00@0oh0000<00?l00?n0003oP000
0P3oP002003o00T0oh001@00o`050?n000800?l0403oP002003o00d0oh000`00o`020?n000@00?l0
00<0oh00003o0000o`000P00o`040?n00003003o003oP000oh000080oh000P00o`020?n000<00?l0
0P3o0002003o00D0oh000P00o`090?n000800?l01@3oP00Hooooo`005_ooool20000o`800?l00`3o
0002003o0080o`000P3oP0050?l00080003o4`3o0002003o0380o`000P000?l20?l000L0003o103o
00020000o`P0o`000P000?l20?l000D0003o0P3o00020000o`T0o`003_ooool>003o0080oh003@00
o`000`3oP0000?l0003o00020?n001000?l00P3oP004003o00<0oh001P000?l50?l000800?l000<0
o`000000o`000?l00P000?l40?l00003003o003o0000o`000080o`0010000?l30?l000@00?l00P3o
00000`3oP000o`000?l000020000o`80oh000P00o`000`3oP000o`000?l000020?l00080003o00<0
oh00003o0000o`001000o`0;0?n00003003o003oP000oh0000800?l03_ooool2003o0080o`0000<0
oh00003o0000o`000P3o0002003o00<0o`000P000?l20?l000800?l00`3oP0060?l00003003o003o
0000o`000080o`000P00o`020000o`03003o00000?l0003o00T0o`00103oP003003o00@0oh005@3o
00060000o`<0o`002`000?l20?l00080003o0P3o00000`3oP0000?l0003o00020?n00080o`0000<0
003o0?n0003oP0000P3oP004003o00<0o`000P3oP0070?l00080003o3_ooool2003o00/0oh000`00
o`060?n00003003o003oP000oh0000@00?l00`3oP002003o00D0oh000P00o`0@0?n000800?l00P3o
P002003o00<0oh000P00o`0=0?n00003003o003oP000oh000080oh001000o`000`3oP0000?l0003o
00040?n000<00?l0103oP002003o0080oh000`00o`020?l00080oh0000<00?l00?n0003oP0000P00
o`040?l000L0oh000P00o`030?n000800?l06?ooool001Kooooo0P000?l2003o00<0o`000P00o`09
0?l00080003o403o00020000o`030?l00000o`000?l00100o`000P00o`0K0?l00080oh000`3o0002
0000o`80o`001`000?l40?l00080003o4`3o00020000o`@0o`0000<00?l00?l0003o00000P3o000>
ooooo`h00?l00P3oP00=003o00030?n00000o`000?l001P00?l00`3oP002003o0080003o0`3o0004
0?n000<0o`000P000?l;0?l00080003o0P00o`000`000?l0o`000?l00004003o0080o`0000<0oh00
0?l0003o00000P3o0002003o00<0oh00103o00020000o`030?n00000o`000?l000@00?l00`3oP002
003o0080oh001000o`030?n000800?l03_ooool4003o00030?n00000o`000?l00080o`000P00o`02
0000o`030?l000000?l0003o0080o`001000o`070?l000030000o`3o0000o`0000@0o`002@000?l2
0?l000030000o`3o0000o`0000@0oh000`00o`020?n000800?l02`3o00000`00o`00o`000?l00004
0?l000D0oh000P00o`020000o`<0o`000P000?l20?l000L0003o1P3o00000`3oP0000?l0003o0004
0?l000030000o`3oP000oh000080oh001`3o00020?n00080o`000P00o`000`000?l0o`000?l00002
0000o`kooooo0P00o`020?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0000P3oP002
003o0080oh0000<00?l00?n0003oP000103oP0000`00o`00oh000?n000070?n000800?l0103oP002
003o00X0oh000P00o`020?n000800?l00`3oP002003o00@0oh0000<00?l00?n0003oP0000P3oP002
003o0080oh0000<00?l00?n0003oP000103oP002003o00030?n00000o`000?l000800?l00P3oP002
003o00<0oh001000o`020?n00003003o003oP000oh0000@0oh0000<00?l00?n0003oP0000P3oP004
0?l000L0oh000`00o`040?n001Sooooo000Fooooo`80003o0P00o`030?l000800?l02@3o00020000
oa00o`000P000?l00`3o00000?l0003o000@0?l000800?l06`3o00020?n000<0o`000P000?l20?l0
00L0003o103o00020000oa<0o`000P000?l40?l00003003o003o0000o`000080o`003_ooool>003o
0080oh003@00o`000`3oP0000?l0003o000H003o00<0oh000P00o`020000o`<0o`00103oP0030?l0
0080003o2`3o00020000o`800?l000<0003o0?l0003o00001000o`020?l000030?n0003o0000o`00
0080o`000P00o`030?n000@0o`000P000?l00`3oP0000?l0003o0004003o00<0oh000P00o`020?n0
00@00?l00`3oP002003o00kooooo1000o`000`3oP0000?l0003o00020?l000800?l00P000?l00`3o
0000003o0000o`020?l000@00?l01`3o00000`000?l0o`000?l000040?l000T0003o0P3o00000`00
0?l0o`000?l000040?n000<00?l00P3oP002003o00/0o`0000<00?l00?l0003o0000103o00050?n0
00800?l00P000?l30?l00080003o0P3o00070000o`H0o`0000<0oh00003o0000o`00103o00000`00
0?l0oh000?n000020?n000L0o`000P3oP0020?l000800?l000<0003o0?l0003o00000P000?l>oooo
o`800?l00P3oP0000`00o`00oh000?n000060?n00003003o003oP000oh000080oh000P00o`020?n0
0003003o003oP000oh0000@0oh0000<00?l00?n0003oP0001`3oP002003o00@0oh000P00o`0:0?n0
00800?l00P3oP002003o00<0oh000P00o`040?n00003003o003oP000oh000080oh000P00o`020?n0
0003003o003oP000oh0000@0oh000P00o`000`3oP0000?l0003o0002003o0080oh000P00o`030?n0
00@00?l00P3oP0000`00o`00oh000?n000040?n00003003o003oP000oh000080oh00103o00070?n0
00<00?l0103oP00Hooooo`005_ooool20000o`800?l0=@3o0002003o00h0o`000P000?l20?l00080
003o0`3o00020000o`L0o`000P000?l20?l00080003o0P3o00000`000?l0o`000?l0000F0?l00003
0000o`3o0000o`0000/0o`003_oooolM003o00<0oh000P00o`020?n000`00?l00P3oP004003o0080
o`0000<00?l00?n0003oP0000P3oP0020?l00080003o00<0o`000?n0003oP0000P3oP0030?l00080
003o2@3o00020?n00080003o0P00o`000`000?l0o`000?l00002003o0080o`001@00o`040?l00080
0?l000<0oh00003o0000o`000P00o`020000o`030?n00000o`000?l000H00?l000<0oh00003o0000
o`000P00o`020?l000800?l00`3oP002003o00kooooo0P000?l2003o00030?n00000o`000?l000@0
0?l00P3o0003003o0080o`001000o`050?l000L0003o0P3o00050000o`80o`001`000?l40?l00080
0?l000<0oh000?l0003o00000P00o`050?l00080003o1@3o00020000o`@0o`000P000?l30?l00080
0?l00P3oP002003o00030?l000000?l0003o0080o`001`000?l40?l00080003o0`00o`020?l00080
0?l000<0o`000000o`000?l03@3o0002003o00<0o`000P000?l>ooooo`@00?l02@3oP0000`00o`00
oh000?n000020?n000D00?l0103oP003003o00T0oh000P00o`040?n000<00?l02@3oP002003o0080
oh000P00o`030?n000@00?l00P3oP0000`00o`00oh000?n000060?n00003003o003oP000oh0000@0
oh000P00o`000`3oP0000?l0003o00040?n000800?l01@3oP002003o0080oh0000<00?l00?n0003o
P000103oP0000`00o`00oh000?n000040?n00080o`000`3oP002003o0080oh000`00o`040?n001So
oooo000Fooooo`80003o0P00o`0e0?l000800?l03P3o00020000o`80o`000P000?l30?l00080003o
1`3o00020000o`80o`000P000?l20?l000030000o`3o0000o`0001H0o`0000<0003o0?l0003o0000
2`3o000>oooooad00?l00`3oP002003o0080oh003000o`020?n000@00?l00P3o00000`00o`00oh00
0?n000020?n00080o`000P000?l00`3o0000oh000?n000020?n000<0o`000P000?l90?l00080oh00
0P000?l2003o00030000o`3o0000o`0000800?l00P3o0005003o00@0o`000P00o`000`3oP0000?l0
003o0002003o0080003o00<0oh00003o0000o`001P00o`000`3oP0000?l0003o0002003o0080o`00
0P00o`030?n000800?l03_ooool20000o`800?l000<0oh00003o0000o`001000o`020?l000<00?l0
0P3o0004003o00D0o`001`000?l20?l000D0003o0P3o00070000o`@0o`000P00o`000`3oP000o`00
0?l00002003o00D0o`000P000?l50?l00080003o103o00020000o`<0o`000P00o`020?n000800?l0
00<0o`000000o`000?l00P3o00070000o`@0o`000P000?l3003o0080o`000P00o`000`3o0000003o
0000o`0=0?l000800?l00`3o00020000o`kooooo1000o`090?n00003003o003oP000oh000080oh00
1@00o`040?n000<00?l02@3oP002003o00@0oh000`00o`090?n000800?l00P3oP002003o00<0oh00
1000o`020?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP000103oP002003o00030?n0
0000o`000?l000@0oh000P00o`050?n000800?l00P3oP0000`00o`00oh000?n000040?n00003003o
003oP000oh0000@0oh000P3o00030?n000800?l00P3oP003003o00@0oh006?ooool001Kooooo9P3o
00000`3oP000o`000?l0000@0?l000800?l03P3o00020000o`80o`000P000?l<0?l000H0003o0P3o
00000`000?l0o`000?l000040?l000<0003o2`3o00020000oa00o`003_oooolM003o00<0oh000P3o
00020?n000`00?l00P3oP004003o0080oh0000<00?l00?n0003oP0000P000?l20?l000<0003o103o
P0030?l00080003o2@3o00040000o`800?l000<0003o0?l0003o00000P3oP0020?l000<00?l0103o
P004003o00030?n00000o`000?l000800?l00P3o00000`3oP0000?l0003o0006003o00030?n00000
o`000?l000800?l00P3o00020000o`<0oh000P00o`0>ooooo`80003o0P00o`030?n000@00?l00P00
0?l3003o0080o`000P3oP002003o00030?n0003o0000o`0000D0o`000P000?l40?l000<0003o103o
00070000o`@0o`000P00o`000`3oP000o`000?l000020?l000T0003o2@3o00020000o`<0o`000P00
0?l20?l000800?l01@3o00050000o`80o`000P3oP002003o0080003o0`00o`020?l000D0003o103o
0002003o00<0003o0P3o00020000o`800?l00`3o0002003o00kooooo0P3oP002003o00<0oh000P00
o`040?n000<00?l01P3oP003003o0080oh000`00o`090?n000800?l01P3oP0000`00o`00oh000?n0
00040?n000800?l000<0oh00003o0000o`003@3oP0000`00o`00oh000?n000060?n00003003o003o
P000oh0000L0oh000P00o`040?n000800?l01@3oP004003o00h0oh000P00o`030?n000800?l02@3o
P00Hooooo`005_oooolV0?l000030?n0003o0000o`000100o`000P00o`0>0?l00080003o0P3o0002
0000o``0o`001P000?l20?l000030000o`3o0000o`0000@0o`000`000?l;0?l00080003o403o000>
oooooad00?l00`3oP0020?l00080oh003000o`020?n000@00?l00P3oP0000`00o`00oh000?n00002
0000o`80o`000`000?l40?n000<0o`000P000?l90?l000@0003o0P00o`000`000?l0o`000?l00002
0?n00080o`000`00o`040?n000@00?l000<0oh00003o0000o`000P00o`020?l000030?n00000o`00
0?l000H00?l000<0oh00003o0000o`000P00o`020?l00080003o0`3oP002003o00kooooo0P000?l2
003o00<0oh001000o`020000o`<00?l00P3o00020?n000800?l000<0oh000?l0003o00001@3o0002
0000o`@0o`000`000?l40?l000L0003o103o0002003o00030?n0003o0000o`000080o`002@000?l9
0?l00080003o0`3o00020000o`80o`000P00o`050?l000D0003o0P3o00020?n000800?l00P000?l3
003o0080o`001@000?l40?l000800?l00`000?l20?l00080003o0P00o`030?l000800?l03_ooool2
0?n000800?l00`3oP002003o00@0oh000`00o`060?n000<00?l00P3oP003003o00T0oh000P00o`06
0?n00003003o003oP000oh0000@0oh000P00o`000`3oP0000?l0003o000=0?n00003003o003oP000
oh0000H0oh0000<00?l00?n0003oP0001`3oP002003o00@0oh000P00o`050?n000@00?l03P3oP002
003o00<0oh000P00o`090?n001Sooooo000FoooooeH0o`000P000?l30?l00080003o0P3o00020000
o`80o`001`000?l20?l000030000o`3o0000o`0001/0o`003_oooolM003o00030?n0003o0000o`00
0080003o0P3oP00<003o0080oh001000o`020?n00003003o003oP000oh0000H0003o00<0o`000?n0
003oP0000P3oP0030?l00080003o0P3o00020000o`<0o`000P000?l20?n00080003o0P00o`000`00
0?l0o`000?l000040?n000<00?l0103oP004003o00030?n00000o`000?l000800?l00P3o00030?n0
00H00?l000<0oh00003o0000o`001P3o00030?n000800?l03_ooool20?l000<00?l00P3oP002003o
00@0oh000`00o`020?l00080oh000`00o`040?n000<0o`000P000?l20?l000@0003o0`3o00020000
o`@0o`000`000?l2003o0080o`000`00o`040?l000T0003o1@3o00020000o`80o`000P000?l30?l0
00800?l00P3o00020?n000030000o`00o`000?l000L0003o0P3o0004003o0080oh000`00o`050000
o`80o`00103oP002003o00L0003o1@3o00020000o`kooooo1`3oP004003o00/0oh0000<00?l00?n0
003oP0000P3oP005003o00L0oh000P00o`060?n000<00?l0103oP002003o00030?n00000o`000?l0
00H0oh0000<00?l00?n0003oP0003@3oP0000`00o`00oh000?n000070?n000800?l00P3oP004003o
00030?n00000o`000?l00080oh001000o`0C0?n000800?l01@3oP002003o0080oh006?ooool001Ko
oooo1@3o0002003o0080003o9P3o00000`00o`00o`000?l000060?l00003003o003o0000o`0001/0
o`000P000?l70?l00080003o0P3o00050000ob00o`000P000?l>ooooo`L00?l00P3oP00D003o0003
0?n0003o0000o`000080003o0P3oP002003o00030?n00000o`000?l000L00?l00P3oP002003o0080
o`000P3oP0000`00o`00oh000?n000060000o`030?l0003oP000oh000080oh000P00o`000`3o0000
003o0000o`020?l00080003o0`3o00020000o`80oh001@000?l20?l000H0oh000`00o`020?n000@0
0?l000<0oh00003o0000o`000P00o`020?l000<0oh001000o`020?n00003003o003o0000o`000080
o`000P000?l20?l000<0oh000P00o`0>ooooo`800?l00P3o00000`00o`00oh000?n00004003o0080
oh000`00o`020?l00080oh001`00o`070?l00080003o1@3o00060?n000030?l000000?l0003o00@0
o`000`00o`080?l000030000o`3o0000o`0000L0o`001P000?l90?l000X0003o0P3o0004003o0080
o`000`00o`020?l000800?l000<0003o0?l0003o00000P3o00040?n000L0003o0P3o00000`000?l0
o`000?l000020000o`kooooo2@3oP002003o00<0oh000P00o`060?n00003003o003oP000oh000080
oh000`00o`020?n000800?l01@3oP002003o00H0oh000`00o`070?n000800?l01`3oP002003o00d0
oh0000<00?l00?n0003oP000103oP002003o00D0oh001000o`000`3oP0000?l0003o000>0?n00080
0?l01P3oP0000`00o`00oh000?n00002003o00D0oh000P00o`020?n001Sooooo000Fooooo`D0o`00
0P00o`020000obH0o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l0000K0?l00080003o
1`3o00020000o`80o`001@000?lP0?l00080003o3_ooool7003o0080oh005000o`000`3oP000o`00
0?l000020000o`80oh000P00o`000`3oP0000?l0003o0007003o0080oh000P00o`020?l00080oh00
00<00?l00?n0003oP0001P000?l00`3o0000oh000?n000020?n000800?l000<0o`000000o`000?l0
0P3o00020000o`<0o`000P000?l20?n000D0003o0P3o00060?n000<00?l00P3oP004003o00030?n0
0000o`000?l000800?l00P3o00030?n000@00?l00P3oP0000`00o`00o`000?l000020?l00080003o
0P3o00030?n000800?l03_ooool2003o0080o`0000<00?l00?n0003oP0001000o`020?n000<00?l0
0P3o00020?n000L00?l01`3o00020000o`D0o`001P3oP0000`3o0000003o0000o`040?l000<00?l0
203o00000`000?l0o`000?l000070?l000H0003o2@3o000:0000o`80o`001000o`020?l000<00?l0
0P3o0002003o00030000o`3o0000o`000080o`00103oP0070000o`80o`0000<0003o0?l0003o0000
0P000?l>ooooo`T0oh000P00o`030?n000800?l01P3oP0000`00o`00oh000?n000020?n000<00?l0
0P3oP002003o00D0oh000P00o`060?n000<00?l01`3oP002003o00L0oh000P00o`0=0?n00003003o
003oP000oh0000@0oh000P00o`050?n000@00?l000<0oh00003o0000o`003P3oP002003o00H0oh00
00<00?l00?n0003oP0000P00o`050?n000800?l00P3oP00Hooooo`005_ooool4003o00030?l00000
o`000?l002P0o`0000<00?l00?l0003o00001P3o00000`00o`00o`000?l0000B0?l00080003o0`3o
00020000o`80o`000P000?l;0?l000D0003o7@3o00000`000?l0o`000?l000020000o`kooooo5P00
o`000`3oP0000?l0003o0004003o00030?n0003o0000o`000080003o0P3oP002003o00030?n00000
o`000?l000@00?l01@3oP004003o0080oh0000<00?l00?n0003oP0001P000?l00`3o0000003o0000
o`020000o`800?l01@3o00040000o`D0o`000P000?l20?l000030000o`3o0000o`0000H0oh000`00
o`020?n000800?l00`3oP004003o00D0oh000P00o`040?n00003003o003o0000o`000080o`000P00
0?l30?l000@0oh003_ooool20?l00080oh0000<00?l00?n0003oP0001000o`020?n000<00?l00P3o
00040?n000030?l0003oP000oh0000@0oh001@3o00020000o`D0o`001`3oP002003o0080o`001@00
o`020?n000800?l00P000?l<0?l000H0003o0`3o00020000o`@0o`002@000?l30?l000800?l0103o
0003003o0080o`000`00o`040?l000@0oh001`000?l20?l000030000o`3o0000o`000080003o3_oo
ool2003o00L0oh000P00o`030?n000800?l0103oP003003o00@0oh000`00o`020?n000L00?l0203o
P003003o00L0oh000P00o`060?n00003003o003oP000oh0000D0oh000P00o`090?n000800?l02`3o
P002003o00030?n00000o`000?l00080oh000P3o00090?n000<0o`00103oP003003o0080oh000P00
o`040?n00003003o003o0000o`000080oh006?ooool001Kooooo1000o`000`3o00000?l0003o000X
0?l00003003o003o0000o`0000H0o`0000<00?l00?l0003o00004P3o00020000o`<0o`000P000?l2
0?l00080003o2`3o00050000oad0o`0000<0003o0?l0003o00000P000?l>oooooaH00?l000<0oh00
003o0000o`001000o`000`3oP000o`000?l000020000o`80oh000P00o`000`3oP0000?l0003o0004
003o00D0oh001000o`020?n00003003o003oP000oh0000H0003o00<0o`000000o`000?l00P000?l2
003o00D0o`0010000?l50?l00080003o0P3o00000`000?l0o`000?l000060?n000<00?l00P3oP002
003o00<0oh001000o`050?n000800?l0103oP0000`00o`00o`000?l000020?l00080003o0`3o0004
0?n000kooooo0P3o00020?n00003003o003oP000oh0000@00?l00P3oP003003o0080o`00103oP000
0`3o0000oh000?n000040?n000D0o`000P000?l50?l000L0oh000P00o`020?l000D00?l00P3oP002
003o0080003o303o00060000o`<0o`000P000?l40?l000T0003o0`3o0002003o00@0o`000`00o`02
0?l000<00?l0103o00040?n000L0003o0P3o00000`000?l0o`000?l000020000o`kooooo0P00o`07
0?n000800?l00`3oP002003o00@0oh000`00o`040?n000<00?l00P3oP007003o00P0oh000`00o`07
0?n000800?l01P3oP0000`00o`00oh000?n000050?n000800?l02@3oP002003o00/0oh000P00o`00
0`3oP0000?l0003o00020?n00080o`002@3oP0030?l000@0oh000`00o`020?n000800?l0103oP000
0`00o`00o`000?l000020?n001Sooooo000Fooooo`800?l00P3o0003003o02/0o`000P3oP0040?l0
0003003o003o0000o`0000@0o`000P000?l<0?l00080003o0`3o00020000oa00o`000P000?lM0?l0
00<0003o0P00o`020000o`kooooo7@00o`000`3oP0000?l0003o00020?l00080oh000P00o`000`3o
P0000?l0003o00020?n000800?l01@3oP002003o00@0oh0000<00?l00?n0003oP000103o00020000
o`030?n000000?l0003o0080oh000`00o`020?l000L0003o0P3o0002003o00@0o`0000<0003o0?n0
003oP0001P3oP003003o0080oh001000o`000`3oP0000?l0003o0002003o00D0oh000P00o`040?n0
00L0o`000P00o`000`3o0000oh000?n000020?n000kooooo0P00o`030?l00080oh001000o`030?n0
00800?l00P3o0002003o00<0o`001P3oP0000`3o0000003o0000o`020?l00080003o1@3o0004003o
0080o`000`00o`020?l000D00?l00P3oP004003o00T0o`0000<0003o0?l0003o00001P000?l00`3o
0000003o0000o`020000o`@0o`0000<0003o003o0000o`001P000?l50?l00080003o0P3o0003003o
0080o`000`00o`040?l000@00?l01`000?l20?l000030000o`3o0000o`000080003o3_ooool20?n0
00800?l01@3oP002003o00<0oh000P00o`040?n000800?l01@3oP003003o0080oh001P00o`000`3o
P0000?l0003o0004003o00<0oh000P00o`070?n000800?l01P3oP003003o00D0oh000P00o`040?n0
0080o`0000<0003o0?n0003oP0000P00o`040?n00003003o003oP000oh0000@0oh000P00o`050?n0
00@0o`001`3oP0030?l000@0oh000`00o`020?n000800?l0103oP0000`00o`00o`000?l000020?n0
01Sooooo000Fooooo`800?l00P3o0003003o02/0o`000P3oP0040?l00003003o003o0000o`0000@0
o`000P000?l<0?l00080003o0`3o00020000oa00o`000P000?lM0?l000<0003o0P00o`020000o`ko
oooo7@00o`000`3oP0000?l0003o00020?l00080oh000P00o`000`3oP0000?l0003o00020?n00080
0?l01@3oP002003o00@0oh0000<00?l00?n0003oP000103o00020000o`030?n000000?l0003o0080
oh000`00o`020?l000L0003o0P3o0002003o00@0o`0000<0003o0?n0003oP0001P3oP003003o0080
oh001000o`000`3oP0000?l0003o0002003o00D0oh000P00o`040?n000L0o`000P00o`000`3o0000
oh000?n000020?n000kooooo0P00o`030?l00080oh001000o`030?n000800?l00P3o0002003o00<0
o`001P3oP0000`3o0000003o0000o`020?l00080003o1@3o0004003o0080o`000`00o`020?l000D0
0?l00P3oP004003o00T0o`0000<0003o0?l0003o00001P000?l00`3o0000003o0000o`020000o`@0
o`0000<0003o003o0000o`001P000?l50?l00080003o0P3o0003003o0080o`000`00o`040?l000@0
0?l01`000?l20?l000030000o`3o0000o`000080003o3_ooool20?n000800?l01@3oP002003o00<0
oh000P00o`040?n000800?l01@3oP003003o0080oh001P00o`000`3oP0000?l0003o0004003o00<0
oh000P00o`070?n000800?l01P3oP003003o00D0oh000P00o`040?n00080o`0000<0003o0?n0003o
P0000P00o`040?n00003003o003oP000oh0000@0oh000P00o`050?n000@0o`001`3oP0030?l000@0
oh000`00o`020?n000800?l0103oP0000`00o`00o`000?l000020?n001Sooooo000Fooooo`800?l0
0P3oP0000`00o`00o`000?l0000[0?l00080oh00103o00000`00o`00o`000?l0000B0?l000@0003o
5`3o00020000oaT0o`000`000?l2003o0080003o3_oooolM003o00030?n00000o`000?l000800?l0
0P3oP002003o00030?n00000o`000?l00080oh000P00o`090?n000<00?l00P3oP0020000o`80o`00
0P000?l00`3o0000oh000?n000040?n00003003o003o0000o`0000L0003o0P3o0002003o00/0o`00
0P3oP009003o00<0oh000P00o`050?n000800?l00P3oP002003o00T0o`0000<00?l00?n0003oP000
0P3oP00>ooooo`D0o`000P3oP004003o0080o`000`00o`020?l000@00?l000<0o`000?n0003oP000
103oP0000`00o`00003o0000o`020?l000800?l01@3o00020000o`800?l00P3o00000`00o`00o`00
0?l000060?l00003003o003oP000oh0000@00?l00`3o00020000o`80oh001@000?l2003o00/0003o
1@3o00020000o`800?l00P000?l00`3o0000003o0000o`020?l00080003o0P3o0003003o0080o`00
0`000?l40?l000800?l00`3o00060000o`D0o`000P000?l>ooooo`80oh000`00o`040?n000800?l0
0`3oP004003o00/0oh0000<00?l00?n0003oP000103oP002003o00<0oh001000o`050?n000800?l0
103oP003003o00@0oh001@00o`0;0?n00080o`0000<0003o0?n0003oP0000P00o`040?n000<00?l0
103o0002003o00<0oh001P3o000>0?n000800?l00`3oP002003o00@0oh0000<00?l00?l0003o0000
0P3o000Hooooo`005_ooool2003o0080oh0000<00?l00?l0003o0000:`3o00020?n000@0o`0000<0
0?l00?l0003o00004P3o00040000oaL0o`000P000?lI0?l000<0003o0P00o`020000o`kooooo7@00
o`000`3oP0000?l0003o0002003o0080oh000P00o`000`3oP0000?l0003o00020?n000800?l02@3o
P003003o0080oh000P000?l20?l00080003o00<0o`000?n0003oP000103oP0000`00o`00o`000?l0
00070000o`80o`000P00o`0;0?l00080oh002@00o`030?n000800?l01@3oP002003o0080oh000P00
o`090?l00003003o003oP000oh000080oh003_ooool50?l00080oh001000o`020?l000<00?l00P3o
0004003o00030?l0003oP000oh0000@0oh0000<00?l00000o`000?l00P3o0002003o00D0o`000P00
0?l2003o0080o`0000<00?l00?l0003o00001P3o00000`00o`00oh000?n00004003o00<0o`000P00
0?l20?n000D0003o0P00o`0;0000o`D0o`000P000?l2003o0080003o00<0o`000000o`000?l00P3o
00020000o`80o`000`00o`020?l000<0003o103o0002003o00<0o`001P000?l50?l00080003o3_oo
ool20?n000<00?l0103oP002003o00<0oh001000o`0;0?n00003003o003oP000oh0000@0oh000P00
o`030?n000@00?l01@3oP002003o00@0oh000`00o`040?n000D00?l02`3oP0020?l000030000o`3o
P000oh0000800?l0103oP003003o00@0o`000P00o`030?n000H0o`003P3oP002003o00<0oh000P00
o`040?n00003003o003o0000o`000080o`006?ooool001Kooooo0P00o`020?l00003003o003o0000
o`0002H0o`000P00o`030?l00080oh001@3o00020000ob80o`000P000?l90?l000@0003o5`3o0003
0000o`800?l00P000?l>oooooa/00?l00`3oP008003o00030?n00000o`000?l00080oh000P00o`09
0?n000<00?l00P3oP0020000o`80o`000P000?l00`3o0000oh000?n000020?n000<00?l01P3o0002
0000o`030?n0003o0000o`0000H00?l000<0o`00003o0000o`000P00o`020?l00080oh001@00o`02
0?n000800?l000<0oh00003o0000o`000P00o`050?n000800?l00P3oP002003o00030?l00000o`00
0?l000800?l0103o00000`00o`00oh000?n000020?n000kooooo103o00000`000?l0oh000?n00002
0?l00080003o0`3oP0040?l000D00?l01P3oP003003o0080o`000P00o`030?l00080oh000P000?l2
003o0080o`0000<00?l00?n0003oP0000P3oP0040?l000030000o`3oP000oh0000@00?l00`3o0002
0000o`80oh000P3o00000`00o`00003o0000o`02003o0080003o0P3o00030000o`80o`000P000?l2
0?l00003003o003o0000o`000080003o0P00o`020000o`030?l000000?l0003o0080o`000P00o`02
0?l000030?n0003o0000o`0000@0o`0000<0003o0?l0003o00000P3o0002003o00L0o`000P00o`05
0?l00080003o3_ooool20?n000<00?l01P3oP002003o00<0oh000P00o`0;0?n00003003o003oP000
oh0000@0oh000`00o`020?n000@00?l00P3oP0000`00o`00oh000?n00002003o00D0oh000P00o`06
0?n000<00?l0103oP0000`00o`00oh000?n000040?n00080o`0000<0003o0?n0003oP0000P00o`04
0?n000<00?l00P3oP002003o00D0oh000P00o`040?l000X0oh000P00o`020?n000800?l00`3oP002
003o00D0oh00103o000Hooooo`005_ooool_0?l000D0oh001@3o00020000oal0o`001@000?l;0?l0
0080003o6@3o00000`000?l0o`000?l000020?l000kooooo6`00o`030?n000P00?l000<0oh00003o
0000o`000P3oP004003o00030?n00000o`000?l000@0oh000`00o`020?l000H0003o00<0o`000?n0
003oP0000P3oP003003o00H0o`000P000?l00`3oP0000?l0003o0006003o00030?n00000o`000?l0
00800?l0103o0005003o0080oh000P00o`030?n000D00?l00P3oP002003o0080oh000P00o`070?l0
00L0oh003_ooool40?l00003003o003oP000oh000080o`000P000?l30?n00080o`001`00o`020?n0
00800?l00P3oP003003o0080o`000P000?l2003o00030000o`3oP000oh0000@00?l00`3o0002003o
0080oh00103o00000`000?l0oh000?n00004003o00<0o`000P000?l50?n00080003o0P00o`020000
o`80o`001`000?l20?l00003003o003o0000o`000080o`000P00o`020000o`030?l000000?l0003o
0080oh001`00o`020?n00080o`001@000?l2003o00<0003o0P3o00020000o`D0o`0010000?l>oooo
o`80oh001@00o`040?n000800?l00`3oP002003o00/0oh0000<00?l00?n0003oP0001P3oP0000`00
o`00oh000?n000020?n000800?l00P3oP0000`00o`00oh000?n00002003o00D0oh000P00o`060?n0
00<00?l02`3oP0030?l00080oh000P00o`040?n00003003o003oP000oh0000/0oh000P00o`050?n0
00800?l01@3oP002003o0080oh000P00o`090?n00003003o003o0000o`0000800?l06?ooool001Ko
oooo;`3o00050?n000D0o`000P000?lO0?l000D0003o2`3o00020000oaT0o`0000<0003o0?l0003o
00000P3o000>oooooa/00?l00`3oP008003o00030?n00000o`000?l00080oh001000o`000`3oP000
0?l0003o00040?n000<00?l00P3o00060000o`030?l0003oP000oh000080oh000`00o`060?l00080
003o00<0oh00003o0000o`001P00o`000`3oP0000?l0003o0002003o00@0o`001@00o`020?n00080
0?l00`3oP005003o0080oh000P00o`020?n000800?l01`3o00070?n000kooooo103o00000`00o`00
oh000?n000020?l00080003o0`3oP0020?l000L00?l00P3oP002003o0080oh000`00o`020?l00080
003o0P00o`000`000?l0oh000?n00004003o00<0o`000P00o`020?n000@0o`0000<0003o0?n0003o
P0001000o`030?l00080003o1@3oP0020000o`800?l00P000?l20?l000L0003o0P3o00000`00o`00
o`000?l000020?l000800?l00P000?l00`3o0000003o0000o`020?n000L00?l00P3oP0020?l000D0
003o0P00o`030000o`80o`000P000?l50?l000@0003o3_ooool20?n000D00?l0103oP002003o00<0
oh000P00o`0;0?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0000P3oP002003o0080
oh0000<00?l00?n0003oP0000P00o`050?n000800?l01P3oP003003o00/0oh000`3o00020?n00080
0?l0103oP0000`00o`00oh000?n0000;0?n000800?l01@3oP002003o00D0oh000P00o`020?n00080
0?l02@3oP0000`00o`00o`000?l00002003o01Sooooo000Fooooo`L0o`000P3oP0040?l00003003o
003o0000o`0001l0o`0000<0oh00003o0000o`000P3oP0020?l000800?l03P3o00020000o`X0o`00
0P3oP00?0?l000030000o`3o0000o`000080003o0P3o00020000oah0o`003_oooolK003o00<0oh00
2000o`000`3oP0000?l0003o00020?n000@00?l00`3oP002003o0080o`000`00o`020000o`800?l0
1@000?l20?n00080003o0P00o`070000o`80o`0000<0oh00003o0000o`000P3oP004003o00030?n0
0000o`000?l000800?l01@3o00020000o`@0oh000P00o`000`3oP0000?l0003o0002003o0080o`00
1@3oP0020?l000<00?l01P3o00020?n00003003o003oP000oh000080oh003_ooool20?n00080o`00
00<00?l00?n0003oP0000P3o0002003o00D0oh000P00o`020?n000<00?l01P3oP003003o0080o`00
10000?l00`3o0000oh000?n00002003o00D0o`000P000?l20?n000@0o`0000<0003o0?n0003oP000
1000o`050?l00080003o0P3oP0000`3o0000003o0000o`02003o0080003o0P3o00090000o`03003o
003o0000o`0000H0o`0000<0003o0?n0003oP0000P3o00020?n000D00?l00P3oP0030?l000d0003o
1@3o00040000o`kooooo103oP003003o0080oh000P00o`070?n000@00?l0203oP002003o00@0oh00
0P00o`030?n000800?l0103oP0000`00o`00oh000?n00002003o00D0oh000P00o`060?n000030?l0
00000?l0003o00T0oh000P00o`030?n000@00?l06@3oP002003o00L0oh001000o`070?n000L00?l0
6?ooool001Kooooo1`3o00020?n000@0o`0000<00?l00?l0003o00007`3o00000`3oP0000?l0003o
00020?n00080o`000P00o`0>0?l00080003o2P3o00020?n000l0o`0000<0003o0?l0003o00000P00
0?l20?l00080003o7P3o000>oooooa/00?l00`3oP008003o00030?n00000o`000?l00080oh001000
o`030?n000800?l00P3o0003003o0080003o0P00o`050000o`80oh000P000?l2003o00L0003o0P3o
00000`3oP0000?l0003o00020?n000@00?l000<0oh00003o0000o`000P00o`050?l00080003o103o
P002003o00030?n00000o`000?l000800?l00P3o00050?n00080o`000`00o`060?l00080oh0000<0
0?l00?n0003oP0000P3oP00>ooooo`80oh000P3o00000`00o`00oh000?n000020?l000800?l01@3o
P002003o0080oh000`00o`060?n000<00?l00P3o00040000o`030?l0003oP000oh0000800?l01@3o
00020000o`80oh00103o00000`000?l0oh000?n00004003o00D0o`000P000?l20?n000030?l00000
0?l0003o00800?l00P000?l20?l000T0003o00<00?l00?l0003o00001P3o00000`000?l0oh000?n0
00020?l00080oh001@00o`020?n000<0o`003@000?l50?l000@0003o3_ooool40?n000<00?l00P3o
P002003o00L0oh001000o`080?n000800?l0103oP002003o00<0oh000P00o`040?n00003003o003o
P000oh0000800?l01@3oP002003o00H0oh0000<0o`000000o`000?l02@3oP002003o00<0oh001000
o`0I0?n000800?l01`3oP004003o00L0oh001`00o`0Hooooo`005_ooool_0?l000030?n0003o0000
o`0000T0o`000P000?l90?l00080003o2P3o00020?n000l0o`0000<0003o0?l0003o00000P000?l2
0?l00080003o5@3o00020000o`L0o`003_oooolK003o00<0oh000P00o`020?n000d00?l00`3oP002
003o0080o`000P3oP0000`00o`00003o0000o`02003o00D0003o0P3oP0020000o`<00?l01P000?l2
0?l000D0oh001000o`000`3oP000o`000?l000020?l00080003o0`3o00020000o`@0oh000P00o`00
0`3oP0000?l0003o0002003o0080o`0000<0003o0?n0003oP0000P3oP004003o00D0o`000P00o`02
0?n00003003o003oP000oh000080oh003_ooool20?n00080o`000`3oP004003o0080oh0000<00?l0
0?n0003oP0000P00o`020?l000<00?l00P3o0007003o00L0o`000P3oP0070?l00080003o0P3oP007
0?l000@00?l00P3o00000`000?l0o`000?l000020000o`80oh0000<0o`000000o`000?l00P00o`02
0000o`80o`002@000?l00`00o`00003o0000o`060?l000030000o`3o0000o`000080o`000P000?l2
0?n000<00?l00P3oP002003o00D0o`002@000?l50?l000@0003o3_ooool20?n000<00?l0103oP002
003o0080oh0000<00?l00?n0003oP0000P3oP004003o00030?n00000o`000?l000D0oh000P00o`04
0?n000800?l00`3oP002003o00L0oh000P00o`040?n000<00?l01P3oP0000`3o0000003o0000o`09
0?n000800?l00`3oP004003o00h0oh000P3o00070?n000@00?l01@3oP002003o00T0oh001000o`00
0`3oP0000?l0003o0002003o01Sooooo000Fooooobl0o`0000<0oh000?l0003o00002@3o00020000
o`T0o`000P000?l:0?l00080oh003`3o00000`000?l0o`000?l000020000o`80o`000P000?lE0?l0
0080003o1`3o000>oooooa/00?l00`3oP002003o0080oh003@00o`030?n000800?l00P3o00020?n0
0003003o00000?l0003o00800?l01@000?l20?n00080003o0`00o`060000o`80o`001@3oP004003o
00030?n0003o0000o`000080o`000P000?l30?l00080003o103oP002003o00030?n00000o`000?l0
00800?l00P3o00000`000?l0oh000?n000020?n000@00?l01@3o0002003o0080oh0000<00?l00?n0
003oP0000P3oP00>ooooo`80oh000P3o00030?n000@00?l00P3oP0000`00o`00oh000?n00002003o
0080o`000`00o`020?l000L00?l01`3o00020?n000L0o`000P000?l20?n000L0o`001000o`020?l0
00030000o`3o0000o`000080003o0P3oP0000`3o0000003o0000o`02003o0080003o0P3o00090000
o`03003o00000?l0003o00H0o`0000<0003o0?l0003o00000P3o00020000o`80oh000`00o`020?n0
00800?l01@3o00090000o`D0o`0010000?l>ooooo`80oh000`00o`040?n000800?l00P3oP0000`00
o`00oh000?n000020?n000@00?l000<0oh00003o0000o`001@3oP002003o00@0oh000P00o`030?n0
00800?l01`3oP002003o00@0oh000`00o`060?n000030?l000000?l0003o00T0oh000P00o`030?n0
00@00?l03P3oP0020?l000L0oh001000o`050?n000800?l02@3oP004003o00030?n00000o`000?l0
00800?l06?ooool001Kooooo0P3o0002003o0680o`000P000?l>0?l00080003o2@3o00020000o`L0
o`003_oooolK003o0080oh000`00o`020?n000800?l00P3oP00:003o0080oh00103o00020?n00003
003o003oP000oh0000800?l01@000?l40?n000<00?l00P3o00020000o`D0o`001P3oP002003o00<0
o`000P00o`020000o`80oh0000<0o`00003o0000o`00103oP002003o00030?n00000o`000?l00080
0?l00P3o00070?n000800?l01@3o0004003o00030?l00000o`000?l000800?l03_ooool20?n00080
o`0000<0oh000?l0003o00001000o`020?n00003003o003oP000oh000080oh000P3o00020?n00003
003o003o0000o`0000@00?l000<0o`00003o0000o`000P00o`050?l00080003o103o00090000o`80
0?l00`3o0002003o0080oh002@000?l00`3o00000?l0003o0002003o0080003o0P00o`000`3o0000
003o0000o`060000o`03003o00000?l0003o00H0o`0000<0003o0?l0003o00000P3o00020000o`<0
oh000P00o`020?n000800?l000<0o`000000o`000?l00P3o00090000o`80o`001`000?l>ooooo`h0
oh000P00o`040?n000800?l01`3oP003003o00@0oh000P00o`030?n000800?l0103oP00<003o00H0
oh0000<0o`00003o0000o`001`3oP004003o00<0oh001000o`050?n000@00?l01@3oP0020?l000L0
oh001000o`050?n000800?l0403oP002003o01Sooooo000Fooooo`80o`000P00o`1R0?l00080003o
3P3o00020000o`T0o`000P000?l70?l000kooooo6`00o`020?n000<00?l00P3oP002003o0080oh00
2P00o`020?n000@0o`000P3oP0000`00o`00oh000?n00002003o00D0003o103oP003003o0080o`00
0P000?l50?l000H0oh000P00o`030?l000800?l00P000?l20?n000030?l00000o`000?l000@0oh00
0P00o`000`3oP0000?l0003o0002003o0080o`001`3oP002003o00D0o`001000o`000`3o00000?l0
003o0002003o00kooooo0P3oP0020?l000030?n0003o0000o`0000@00?l00P3oP0000`00o`00oh00
0?n000020?n00080o`000P3oP0000`00o`00o`000?l00004003o00030?l00000o`000?l000800?l0
1@3o00020000o`@0o`002@000?l2003o00<0o`000P00o`020?n000T0003o00<0o`00003o0000o`00
0P00o`020000o`800?l000<0o`000000o`000?l01P000?l00`00o`00003o0000o`060?l000030000
o`3o0000o`000080o`000P000?l30?n000800?l00P3oP002003o00030?l000000?l0003o0080o`00
2@000?l20?l000L0003o3_ooool>0?n000800?l0103oP002003o00L0oh000`00o`040?n000800?l0
0`3oP002003o00@0oh003000o`060?n000030?l00000o`000?l000L0oh001000o`030?n000@00?l0
1@3oP004003o00D0oh000P3o00070?n000@00?l01@3oP002003o0100oh000P00o`0Hooooo`005_oo
ool20?l000800?l04`3o00020000o`80oh00@03o00020000ob@0o`000P000?l20?l000030000o`3o
0000o`000080o`003_oooolK003o0080oh000`00o`020?n000800?l00P3oP00:003o0080oh000P00
o`020?l00080oh0000<00?l00?n0003oP0000P00o`040?l000030000o`3oP000oh0000@0oh0000<0
0?l00?l0003o00001`3o0004003o0080o`000`00o`020?n000800?l0103oP003003o00@0oh000P00
o`000`3oP0000?l0003o0002003o0080o`001`3oP002003o00<0oh001P00o`000`3oP0000?l0003o
0002003o00kooooo0P3oP0020?l000030?n0003o0000o`0000@00?l00P3oP0000`00o`00oh000?n0
00020?l00080003o0P3oP0000`00o`00o`000?l0000;0?l00080003o00<0o`000000o`000?l0103o
00090000o`800?l00`3o0002003o0080oh002@000?l00`3o00000?l0003o0002003o00@0o`0000<0
0?l00000o`000?l01P000?l00`00o`00o`000?l000020000o`80o`000P000?l00`3o0000003o0000
o`020?l00080003o0`3oP002003o0080oh000P000?l00`3o0000003o0000o`020?l000T0003o0P3o
P0020000o`030?l000000?l0003o0080003o3_ooool2003o0080oh0000<00?l00?n0003oP0001`3o
P0020?l00080003o2`3oP003003o00@0oh000P00o`000`3oP000o`000?l00004003o0080oh001@00
o`090?n00080o`000P00o`000`3o0000oh000?n000070?n00080o`000P00o`030?n00080o`000P00
o`040?n000030000o`00o`000?l000800?l00P3oP002003o00<0oh000P00o`070?n000800?l01@3o
P002003o00@0oh0000<00?l00?n0003oP0000P3oP002003o0080oh001@00o`0Hooooo`005_ooool2
0?n000800?l02@3o00000`000?l0o`000?l0000B0?l000800?l05@3o00020000oad0o`000P000?l0
0`3o0000003o0000o`060?l00003003o003o0000o`0000800?l04P3o0002003o00h0o`003_oooolK
003o0080oh001`00o`020?n000X00?l00P3oP002003o0080003o0P3oP0000`00o`00oh000?n00002
003o00@0o`0000<0003o0?n0003oP000103oP0000`00o`00oh000?n000040?n000800?l000<0o`00
003o0000o`000P00o`020?l000<00?l00P3oP002003o00@0oh000`00o`020?n000D00?l00P3oP002
003o00D0oh001P00o`030?n000H00?l000<0oh00003o0000o`000P00o`0>ooooo`80o`001@3oP004
003o00D0oh000P3o00020000o`80oh003P3o00020000o`030?l000000?l0003o00@0o`001`000?l2
0?l000800?l000<0o`000?n0003oP0000P00o`020?n000T0003o0`3o0002003o00D0o`001P000?l5
0?l000H0003o00<0o`000000o`000?l00P3o00020000o`<0oh000P00o`020?n00080003o00<0o`00
0000o`000?l00P3o000B0000o`kooooo3P3oP0020?l00080003o2`3oP003003o00@0oh000P00o`03
0?n000@00?l01`3oP002003o00L0oh000P3o0002003o00L0oh000`00o`040?l00080oh0000<00?l0
0?n0003oP000103oP002003o00030000o`00o`000?l000@0oh000P00o`050?n00080o`001@3oP002
003o00D0oh000P00o`040?n00003003o003oP000oh0000@00?l00P3oP0000`00o`00oh000?n00002
0?n001Sooooo000Fooooo`80oh000P00o`090?l000030000o`3o0000o`000180o`000P00o`0E0?l0
0080003o7@3o00020000o`030?l000000?l0003o00H0o`0000<00?l00?l0003o00000P00o`0B0?l0
00800?l03P3o000>oooooa/00?l00P3oP007003o0080oh002P00o`020?n000800?l00P000?l20?n0
0003003o003oP000oh0000800?l0103o00000`000?l0oh000?n000040?n00003003o003oP000oh00
00@0oh000P00o`000`3o00000?l0003o0002003o0080o`000`00o`020?n000800?l0103oP003003o
0080oh001@00o`020?n000800?l01@3oP006003o00<0oh001P00o`000`3oP0000?l0003o0002003o
00kooooo0P3o00050?n000@00?l01@3oP0020?l00080003o0P3oP00>0?l00080003o00<0o`000000
o`000?l0103o00070000o`80o`000P00o`000`3o0000oh000?n00002003o0080oh002@000?l30?l0
00800?l01@3o00060000o`D0o`001P000?l00`3o0000003o0000o`020?l00080003o0`3oP002003o
0080oh000P000?l00`3o0000003o0000o`020?l00180003o3_ooool>0?n00080o`000P000?l;0?n0
00<00?l0103oP002003o00<0oh001000o`070?n000800?l01`3oP0020?l000800?l01`3oP003003o
00@0o`000P3oP0000`00o`00oh000?n000040?n000800?l000<0003o003o0000o`00103oP002003o
00D0oh000P3o00050?n000800?l01@3oP002003o00@0oh0000<00?l00?n0003oP0001000o`020?n0
0003003o003oP000oh000080oh006?ooool001Kooooo0P3oP002003o00030?l00000o`000?l000H0
o`0000<0003o0?l0003o00001P3o00000`000?l0oh000?n0000K0?l000800?l00`3o00020000obP0
o`0000<00?l00?l0003o00000P00o`0G0?l000800?l02@3o000>oooooaL00?l00P3oP004003o0003
0?n00000o`000?l000@00?l00P3oP00:003o0080oh000P00o`040?n00003003o003oP000oh000080
0?l0103o00000`000?l0oh000?n000020?n000800?l000<0003o0?n0003oP0000P00o`020?n00080
0?l000<0o`00003o0000o`000P00o`020?l000<00?l00P3oP002003o00@0oh000`00o`020?n000D0
0?l00P3oP002003o00D0oh001P00o`030?n000H00?l000<0oh00003o0000o`000P00o`0>ooooo`80
o`000P000?l30?n00080o`000P00o`030?n000@0o`000P000?l30?l00080003o1@3o00020000o`80
o`001`000?l20?l000/0003o0P3oP0000`3o0000oh000?n00002003o0080oh002P000?l20?l00080
0?l01`3o00020000o`80oh001@3o00060000o`030?l000000?l0003o0080o`000P000?l30?n00080
0?l0103oP0000`3o0000003o0000o`0D0000o`kooooo0P00o`070?n000800?l00P3oP0030?l00080
003o1@3oP004003o00<0oh000P00o`040?n000800?l02@3oP0000`00o`00oh000?n000020?n00080
0?l01`3oP0020?l000800?l00`3oP0020?l000<00?l00P3oP002003o0080oh000P00o`070?n000<0
o`000P00o`040?n000800?l01@3oP002003o00<0oh001000o`050?n000800?l0103oP0000`00o`00
oh000?n00004003o0080oh0000<00?l00?n0003oP0000P00o`0Hooooo`005_ooool20?n000800?l0
00<0o`00003o0000o`001P3o00000`000?l0o`000?l000060?l000030000o`3oP000oh0001/0o`00
0P00o`030?l00080003o:03o00000`00o`00o`000?l00002003o01L0o`000P00o`090?l000kooooo
5`00o`020?n000@00?l000<0oh00003o0000o`001000o`020?n000X00?l00P3oP002003o00@0oh00
00<00?l00?n0003oP0000P00o`040?l000030000o`3oP000oh000080oh000P00o`000`000?l0oh00
0?n00002003o0080oh000P00o`000`3o00000?l0003o0002003o0080o`000`00o`020?n000800?l0
103oP003003o0080oh001@00o`020?n000800?l01@3oP006003o00<0oh001P00o`000`3oP0000?l0
003o0002003o00kooooo0P3o00020000o`<0oh000P3o0002003o00<0oh00103o00020000o`<0o`00
0P000?l50?l00080003o0P3o00070000o`80o`002`000?l20?n000030?l0003oP000oh0000800?l0
0P3oP00:0000o`80o`000P00o`070?l00080003o0P3oP0050?l000H0003o00<0o`000000o`000?l0
0P3o00020000o`<0oh000P00o`040?n000030?l000000?l0003o01@0003o3_ooool2003o00L0oh00
0P00o`020?n000<0o`000P000?l50?n000@00?l00`3oP002003o00@0oh000P00o`090?n00003003o
003oP000oh000080oh000P00o`070?n00080o`000P00o`030?n00080o`000`00o`020?n000800?l0
0P3oP002003o00L0oh000`3o0002003o00@0oh000P00o`050?n000800?l00`3oP004003o00D0oh00
0P00o`040?n00003003o003oP000oh0000@00?l00P3oP0000`00o`00oh000?n00002003o01Sooooo
000Fooooo`80oh000P00o`0B0?l000030000o`3oP000oh0001/0o`000P00o`030?l000800?l0:03o
00000`00o`00003o0000o`02003o01L0o`000P00o`040?n000D0o`003_oooolG003o0080oh001000
o`000`3oP0000?l0003o0004003o0080oh002P00o`020?n000@00?l00P3oP0000`00o`00oh000?n0
0002003o0080003o0P3o00000`000?l0oh000?n000040?l000030000o`3oP000oh0000800?l00P3o
P002003o00030?l00000o`000?l000800?l00P3o0002003o00<0o`001000o`020?n00003003o003o
P000oh000080oh001@00o`040?n000800?l00`3oP006003o00<0oh001P00o`030?n000800?l03_oo
ool20?l00080003o0`3oP0020?l000@0oh0000<00?l00?l0003o00000P3o00020000o`80oh0000<0
o`000000o`000?l00P3o00050000o`80o`001`000?l20?l000/0003o0P3oP0000`3o0000oh000?n0
0002003o0080oh002P000?l20?n000@0o`001`000?l20?n000D0o`001P000?l00`3o0000003o0000
o`020?n00080003o2@3oP0000`3o0000003o0000o`0D0000o`kooooo0P00o`030?n000800?l00P3o
P002003o00D0oh001000o`030?n000H00?l000<0oh00003o0000o`001P3oP0000`00o`00oh000?n0
000D0?n00080o`000P00o`030?n000800?l02@3oP003003o0080oh000P00o`040?n00003003o003o
P000oh0000/0oh000P00o`030?n000@00?l02`3oP0000`00o`00oh000?n000060?n000D00?l06?oo
ool001Kooooo0P3oP002003o0180o`0000<0003o0?n0003oP0006`3o0002003o00<0o`000P00o`0X
0?l00003003o00000?l0003o00800?l05`3o0002003o00@0oh001@3o000>oooooaL00?l00P3oP004
003o00030?n00000o`000?l000@00?l00P3oP00:003o0080oh001000o`020?n00003003o003oP000
oh0000800?l00P000?l20?l000030000o`3oP000oh0000@0o`0000<0003o0?n0003oP0000P00o`02
0?n000800?l000<0o`00003o0000o`000P00o`020?l000800?l00`3o0004003o0080oh0000<00?l0
0?n0003oP0000P3oP005003o00@0oh000P00o`030?n000H00?l00`3oP006003o00<0oh000P00o`0>
ooooo`80o`000P000?l30?n00080o`00103oP0000`00o`00o`000?l000020?l00080003o0P3oP000
0`3o0000003o0000o`020?l000D0003o0P3o00070000o`80o`002`000?l20?n000030?l0003oP000
oh0000800?l00P3oP00:0000o`80oh00103o00070000o`80oh001@3o00060000o`030?l000000?l0
003o0080oh000P000?l90?n000030?l000000?l0003o01@0003o3_ooool2003o00<0oh000P00o`02
0?n000800?l01@3oP004003o00<0oh001P00o`000`3oP0000?l0003o00060?n00003003o003oP000
oh0001@0oh000P3o0002003o00<0oh000P00o`090?n000<00?l00P3oP002003o00@0oh0000<00?l0
0?n0003oP0002`3oP002003o00<0oh001000o`0;0?n00003003o003oP000oh0000H0oh001@00o`0H
ooooo`005_ooool20?n000800?l04`3o00020?n001/0o`000P00o`030?l000800?l02@3o00020000
o`80o`0000<0003o0?l0003o00001P3o00000`00o`00o`000?l0000?0?l00003003o00000?l0003o
00800?l05`3o00020000o`T0o`003_oooolG003o0080oh001000o`000`3oP0000?l0003o0004003o
0080oh004000o`020?n00003003o003oP000oh0000800?l00P000?l20?l000030000o`3oP000oh00
00@0o`0000<0003o0?n0003oP0000P00o`020?l000800?l000<0o`00003o0000o`00103o0002003o
00<0o`001000o`020?n000030?l000000?l0003o0080oh001@00o`020?n000@00?l00`3oP006003o
00030?n00000o`000?l00080oh001000o`030?n000800?l03_ooool20?l00080003o0`3oP0020?l0
0080003o0P3oP0000`00o`00o`000?l000060000o`030?l00000o`000?l00080oh001@000?l20?l0
00L0003o0P3o000;0000o`800?l000<0o`000?n0003oP0000P00o`020?l000X0003o103o0002003o
00T0003o0P3oP0000`3o00000?l0003o00070000o`@0o`000P000?l50?n000800?l00P3oP0000`3o
0000003o0000o`040000o`80o`003P000?l>ooooo`@00?l000<0oh00003o0000o`000P3oP002003o
00`0oh001P00o`000`3oP0000?l0003o00060?n00003003o003oP000oh0000H0oh0000<00?l00?n0
003oP0000P3oP002003o00<0oh000P00o`040?n000800?l00`3oP002003o00L0oh000P00o`050?n0
00800?l0103oP0000`00o`00oh000?n000020?n000800?l0303oP007003o0080oh000P00o`050?n0
00800?l02@3oP002003o01Sooooo000Fooooo`@00?l02P3o0002003o02P0o`0000<00?l00?l0003o
00002@3o00020000oad0o`0000<00?l00000o`000?l00P00o`0G0?l000800?l00P3oP0020?l00003
003o003o0000o`000080003o3_oooolG003o0080oh000P00o`030?n000H00?l00P3oP00@003o0080
oh0000<00?l00?n0003oP0000P3o00070000o`@0o`0000<0003o0?l0003o00000P00o`020?l00080
0?l01@3o00020000o`800?l00`3o0002003o0080oh000`3o00020000o`80oh001@00o`020?l000@0
0?l000<0o`00003o0000o`000P00o`020?n000<00?l0103oP004003o00<0oh000P00o`0>ooooo`80
o`000P000?l30?n00080o`000P000?l20?n00003003o003o0000o`0000H0003o00<0o`000?n0003o
P000103oP0000`3o0000003o0000o`020?l00100003o0P3oP0020000o`<0o`000P3oP002003o0080
o`002P000?l40?l000/0003o0P3oP0000`000?l00?l0003o00070000o`@0o`000P000?l50?n00080
0?l00P3oP0000`3o0000003o0000o`040000o`<0o`003@000?l>ooooo`L00?l00P3oP002003o00T0
oh000P00o`000`3oP0000?l0003o0004003o00030?n00000o`000?l000H0oh0000<00?l00?n0003o
P000103oP003003o00@0oh001000o`000`3oP0000?l0003o00040?n000800?l00`3oP002003o00<0
oh001000o`070?n000800?l02@3oP002003o0080oh0000<00?l00?n0003oP0001`3oP002003o0080
oh000P00o`030?n000@00?l00`3oP002003o00T0oh000P00o`0Hooooo`005_ooool4003o00X0o`00
0P00o`0X0?l00003003o003o0000o`0000T0o`000P000?lM0?l00003003o00000?l0003o00800?l0
5`3o0002003o0080oh000P3o00000`00o`00o`000?l000020000o`kooooo5`00o`020?n000800?l0
0`3oP006003o0080oh004000o`020?n00003003o003oP000oh000080o`001`000?l40?l000030000
o`3o0000o`0000800?l00P3o0002003o00D0o`000P000?l2003o00<0o`000P00o`020?n000<0o`00
0P000?l20?n000D00?l00P3o0004003o00030?l00000o`000?l000800?l00P3oP003003o00@0oh00
1000o`030?n000800?l03_ooool20?l00080003o0`3oP0020?l00080003o0P3oP0000`00o`00o`00
0?l000060000o`030?l0003oP000oh0000@0oh0000<0o`000000o`000?l00P3o000@0000o`80oh00
0P000?l30?l00080oh000P00o`020?l000X0003o103o000;0000o`80oh0000<0003o003o0000o`00
1`000?l40?l00080003o1@3oP002003o0080oh0000<0o`000000o`000?l010000?l30?l000d0003o
3_ooool7003o0080oh000P00o`090?n000800?l000<0oh00003o0000o`001000o`000`3oP0000?l0
003o00060?n00003003o003oP000oh0000@0oh000`00o`040?n000@00?l000<0oh00003o0000o`00
103oP002003o00<0oh000P00o`030?n000@00?l01`3oP002003o00T0oh000P00o`020?n00003003o
003oP000oh0000L0oh000P00o`020?n000800?l00`3oP004003o00<0oh000P00o`090?n000800?l0
6?ooool001Kooooo0P00o`0N0?l00080003o403o00020?n000@0o`0000<00?l00?l0003o0000:03o
00000`00o`00003o0000o`02003o00@0o`0000<00?l00?l0003o00004P3o0002003o0080o`0000<0
0?l00?l0003o00000P3o000>ooooo`h00?l00P3oP00;003o0080oh001`00o`020?n000h00?l00P3o
P003003o0080oh000P3o00040000o`030?l000000?l0003o00@0o`0000<0003o0?l0003o00000P00
o`020?l000800?l000<0003o0?l0003o000010000?l2003o00030?l00000o`000?l000L0o`000P00
0?l40?n000800?l000<0oh000?l0003o00000P00o`020?n000030?l00000o`000?l000L00?l0103o
P004003o00<0oh000P00o`0>ooooo`80o`000P000?l00`3oP000o`000?l000020?l00080003o0P3o
P0000`00o`00o`000?l000060000o`030?l0003oP000oh0000@0oh0000<0o`000000o`000?l00P00
0?l2003o00L0003o0P3o00050000o`80oh001@3o00020?n000800?l00P3o000:0000o`@0o`002@00
0?l20?n00080o`0000<0003o003o0000o`002@000?l20?l00080003o1@3oP002003o0080003o00<0
o`000000o`000?l050000?l>ooooo`L00?l00P3oP002003o0080oh000`00o`040?n000800?l000<0
oh00003o0000o`000P3oP002003o00T0oh0000<00?l00?n0003oP0002@3oP004003o00<0oh000P00
o`090?n000800?l00`3oP004003o00D0oh001000o`050?n000800?l01P3oP0000`00o`00oh000?n0
000;0?n000<00?l00P3oP002003o00@0oh0000<0o`00003o0000o`001P3oP0000`00o`00oh000?n0
0002003o01Sooooo000Fooooo`800?l07P3o00020000oa00o`000P3oP0040?l00003003o003o0000
o`0002P0o`0000<00?l00000o`000?l00P00o`040?l00003003o003o0000o`000180o`000P00o`02
0?l00003003o003o0000o`000080o`003_ooool>003o0080oh002`00o`020?n000L00?l00P3oP00>
003o0080oh000`00o`020?n00080o`0010000?l00`3o0000003o0000o`040?l000030000o`3o0000
o`0000800?l00P3o0002003o00030000o`3o0000o`0000@0003o0P00o`000`3o00000?l0003o0007
0?l00080003o103oP002003o00030?n0003o0000o`0000800?l00P3oP0000`3o00000?l0003o0007
003o00@0oh001000o`030?n000800?l03_ooool20?l00080003o00<0oh000?l0003o00000P3o0002
0000o`80oh0000<00?l00?l0003o00001P000?l00`3o0000oh000?n000040?n000030?l000000?l0
003o0080003o0P00o`070000o`80o`001@000?l20?n000D0o`000P3oP002003o0080o`002P000?l4
0?l000T0003o0P3oP0020?l000030000o`00o`000?l000T0003o0P3o00020000o`D0oh000P00o`02
0000o`030?l000000?l0003o01@0003o3_ooool7003o0080oh000P00o`020?n000<00?l0103oP002
003o00030?n00000o`000?l00080oh000P00o`090?n00003003o003oP000oh0000T0oh001000o`03
0?n000800?l02@3oP002003o00<0oh001000o`050?n000@00?l01@3oP002003o00H0oh0000<00?l0
0?n0003oP0002`3oP003003o0080oh000P00o`040?n000030?l00000o`000?l000H0oh0000<00?l0
0?n0003oP0000P00o`0Hooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000Wooooog7o00009ooo
oomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool0
00Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo
5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`0O
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00
O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0
o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0
o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_oo
O`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`00
0?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo
02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o
06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0K_l007l00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooo
oombo`0002?ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Fooooo`80oh00<03o
00020?n002l0o`0000<0oh000?l0003o00002@3o00020?n00080o`0000<0oh000?l0003o0000103o
P00@0?l000kooooo0P3o0007003o00@0003o00<00?l00000o`000?l03@00o`000`000?l00?l0003o
0002003o0080oh000`3o0004003o0080003o1@00o`020?n000d00?l00`3o0004003o00<0003o8@00
o`000`000?l00?l0003o0002003o00<0o`001P00o`020?l00003003o003oP000oh0000/00?l03_oo
oolP0000o`L00?l08@000?l<003o00@0003o0P00o`070000o`800?l01@000?l7003o01H0003o1@00
o`0>ooooo`@0o`001`3oP0020?l000L0oh000`00o`070?n000H00?l00P3o00030?n00080o`000P3o
P0020?l000<0oh000P00o`020?n000<00?l0103oP002003o00<0oh00103o0002003o00D0o`000P3o
P0020?l000X0oh000P3o000@0?n000800?l00P3oP0020?l000030?n00000o`000?l000@0oh001@3o
0002003o0080oh000P00o`050?n001Sooooo000Fooooo`80oh00<03o00020?n002l0o`0000<0oh00
0?l0003o00002@3o00020?n00080o`0000<0oh000?l0003o0000103oP00@0?l000kooooo0P3o0007
003o00@0003o00<00?l00000o`000?l03@00o`000`000?l00?l0003o0002003o0080oh000`3o0004
003o0080003o1@00o`020?n000d00?l00`3o0004003o00<0003o8@00o`000`000?l00?l0003o0002
003o00<0o`001P00o`020?l00003003o003oP000oh0000/00?l03_oooolP0000o`L00?l08@000?l<
003o00@0003o0P00o`070000o`800?l01@000?l7003o01H0003o1@00o`0>ooooo`@0o`001`3oP002
0?l000L0oh000`00o`070?n000H00?l00P3o00030?n00080o`000P3oP0020?l000<0oh000P00o`02
0?n000<00?l0103oP002003o00<0oh00103o0002003o00D0o`000P3oP0020?l000X0oh000P3o000@
0?n000800?l00P3oP0020?l000030?n00000o`000?l000@0oh001@3o0002003o0080oh000P00o`05
0?n001Sooooo000Fooooo`80oh000P3o00000`3oP000o`000?l0001V0?l00080oh001`3o00040?n0
0100o`003_ooool20?l000L00?l01`000?l;003o00<0003o1000o`050?l000@00?l02`000?l;003o
00D0o`009P00o`000`000?l00?l0003o0009003o00D0o`000P3oP002003o0080oh001`00o`0>oooo
o`800?l05@000?l2003o00D0003o2`00o`0P0000o`P00?l01`000?l3003o00H0003o3P00o`040000
oaL00?l03_oooolI0?n00080o`005`3oP002003o0080oh000P00o`0A0?n00080o`001P3oP00:003o
0080oh000P3o00090?n00080o`000P3oP0000`00o`00oh000?n0000F0?n000D0o`006?ooool001Ko
oooo0P3oP0020?l000030?n0003o0000o`0006H0o`000P3oP0070?l000@0oh00403o000>ooooo`80
o`001`00o`070000o`/00?l00`000?l4003o00D0o`001000o`0;0000o`/00?l01@3o000V003o0003
0000o`00o`000?l000T00?l01@3o00020?n000800?l00P3oP007003o00kooooo0P00o`0E0000o`80
0?l01@000?l;003o0200003o2000o`070000o`<00?l01P000?l>003o00@0003o5`00o`0>oooooaT0
oh000P3o000G0?n000800?l00P3oP002003o0140oh000P3o00060?n000X00?l00P3oP0020?l000T0
oh000P3o00020?n00003003o003oP000oh0001H0oh001@3o000Hooooo`005_ooool50?l000@0oh00
103o00000`3oP000o`000?l0000]0?l00080oh002@3o00050?n00080o`000P3oP00`0?l00080oh00
0P3o00030?n00080o`003_ooool20?l000L00?l010000?l>003o00<0003o0P00o`060?n000<00?l0
3@000?l5003o0080oh000P00o`020?n000D0o`002@00o`020?l000`00?l0103oP003003o0080oh00
0P3o0004003o00030000o`00o`000?l000h00?l00P3oP002003o0080oh001`00o`0>ooooo`800?l0
40000?l2003o0080003o00<00?l00000o`000?l01@000?l8003o01<0003oD@00o`0>ooooo`T0oh00
1@3o00020?n000@0o`005@3oP0020?l000L0oh001`00o`060?n00080o`000`3oP004003o00030?n0
003o0000o`000080o`002@3oP007003o00@0o`000`3oP0020?l000/0oh000`3o00020?n000800?l0
103oP0030?l000H0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool50?l00080oh002@3o
00020?n002/0o`000P3oP0070?l00080oh000`3o00020?n00080o`000`3oP00a0?l000L0oh003_oo
ool2003o0080o`001@00o`0;0000o`D00?l01@000?l?003o0080003o00<00?l00000o`000?l01000
0?l<003o0080o`000P3oP00E003o0080oh002@00o`020?l001@00?l000<0o`000?n0003oP0001P3o
P005003o00kooooo0P00o`0D0000o`<00?l01@000?l;003o00d0003oE000o`0>ooooo`d0oh0000<0
o`000?n0003oP0003@3oP0000`00o`00oh000?n000020?n000@0o`00303oP004003o0100oh000P00
o`000`3o00000?l0003o000;0?n000@00?l000<0oh000?l0003o00001`3o00040?n000800?l03P3o
P0020?l000800?l01@3o00020?n00080o`001@3oP00Hooooo`005_ooool50?l00080oh002@3o0002
0?n002/0o`000P3oP0070?l00080oh000`3o00020?n00080o`000`3oP00a0?l000L0oh003_ooool2
003o0080o`001@00o`0;0000o`D00?l01@000?l?003o0080003o00<00?l00000o`000?l010000?l<
003o0080o`000P3oP00E003o0080oh002@00o`020?l001@00?l000<0o`000?n0003oP0001P3oP005
003o00kooooo0P00o`0D0000o`<00?l01@000?l;003o00d0003oE000o`0>ooooo`d0oh0000<0o`00
0?n0003oP0003@3oP0000`00o`00oh000?n000020?n000@0o`00303oP004003o0100oh000P00o`00
0`3o00000?l0003o000;0?n000@00?l000<0oh000?l0003o00001`3o00040?n000800?l03P3oP002
0?l000800?l01@3o00020?n00080o`001@3oP00Hooooo`005_ooool20?n000`0o`000P3oP0070?l0
0080oh001@3o00020?n006X0o`003_ooool9003o00/0003o0`00o`070000o`d00?l03@000?l00`00
o`00003o0000o`020000oad00?l000<0oh00003o0000o`004000o`020000o`h00?l00P3o000;003o
00kooooo0P00o`0G0000o`D00?l00P000?l=003o00L0003o6@00o`020?n000800?l000<0oh00003o
0000o`001000o`050000obd00?l03_ooool2003o00`0oh002000o`000`3oP0000?l0003o0004003o
00D0oh001@3o000A0?n000<0o`001`3oP004003o01@0oh0000<0o`000?n0003oP0002@3oP004003o
00D0oh000P3o000;0?n000030?l0003oP000oh0000/0oh006?ooool001Kooooo0P3oP00<0?l00080
oh001`3o00020?n000D0o`000P3oP01Z0?l000kooooo2@00o`0;0000o`<00?l01`000?l=003o00d0
003o00<00?l00000o`000?l00P000?lM003o00030?n00000o`000?l001000?l00P000?l>003o0080
o`002`00o`0>ooooo`800?l05`000?l5003o0080003o3@00o`070000oaT00?l00P3oP002003o0003
0?n00000o`000?l000@00?l01@000?l]003o00kooooo0P00o`0<0?n000P00?l000<0oh00003o0000
o`001000o`050?n000D0o`004@3oP0030?l000L0oh001000o`0D0?n000030?l0003oP000oh0000T0
oh001000o`050?n00080o`002`3oP0000`3o0000oh000?n0000;0?n001Sooooo000Fooooob00o`00
1P3oP0030?l000@0oh00>`3o00020?n000<0o`000P3oP00K0?l000kooooo0P000?l5003o01L0003o
3`00o`0E0000oa000?l00P3oP006003o00030?n00000o`000?l000/00?l010000?lN003o00kooooo
1000o`0E0000o`D00?l010000?l;003o00T0003o5@00o`090?n000@00?l00`000?l9003o00@0003o
6@00o`020000o`<00?l010000?l>ooooo`T0oh000P3o00070?n000D00?l01`3oP002003o0080oh00
1@3o000;0?n000800?l0103oP0030?l000@0oh000P00o`070?n000T00?l01@3oP0020?l001000?l0
8P3oP00Hooooo`005_oooolP0?l000H0oh000`3o00040?n003/0o`000P3oP0030?l00080oh006`3o
000>ooooo`80003o1@00o`0G0000o`l00?l05@000?l@003o0080oh001P00o`000`3oP0000?l0003o
000;003o00@0003o7P00o`0>ooooo`@00?l05@000?l5003o00@0003o2`00o`090000oaD00?l02@3o
P004003o00<0003o2@00o`040000oaT00?l00P000?l3003o00@0003o3_ooool90?n00080o`001`3o
P005003o00L0oh000P00o`020?n000D0o`002`3oP002003o00@0oh000`3o00040?n000800?l01`3o
P009003o00D0oh000P3o000@003o0280oh006?ooool001Kooooo1@3oP00T0?l00080oh002@3o0002
0?n000L0o`000P3oP00^0?l000/0oh004P3o000>ooooo`80003o1`00o`0D0000o`D00?l0103oP007
003o01D0003o7@00o`0=0000o`L00?l000<0003o003o0000o`001`00o`020?n00080o`000P3oP007
003o00kooooo5`000?l6003o00D0003o1`00o`020?n000800?l00P000?l00`00o`00003o0000o`09
0000o`d00?l000<0003o003o0000o`001000o`020?l000030?n00000o`000?l000@00?l02`000?lJ
003o0080003o1`00o`040000o`kooooo2@3oP0020?l000L0oh000P3o00070?n000<0o`001000o`09
0?n000@0o`001`3oP0030?l000H0oh000P3o00080?n000800?l05P3oP005003o00T0oh000P00o`0I
0?n001Sooooo000Fooooo`T0o`000P3oP00W0?l00080oh00@03o00040?n00080o`000P3oP00>0?l0
00kooooo0P000?l7003o01D0003o1P00o`020?n000<00?l05P000?l7003o0080003o00<00?l00000
o`000?l04000o`060000o`D00?l02@000?l4003o00030000o`00o`000?l000L00?l0103oP007003o
0080003o3_oooolD0000o`<00?l03@000?l9003o0080003o00<00?l00000o`000?l01`000?lB003o
0080oh000P00o`030?n000@00?l02`000?lY003o00kooooo103oP0000`3o0000oh000?n000040?l0
00800?l000<0o`00003o0000o`00103o00020?n000D0o`001@3oP002003o01L0oh000P3o00020?n0
00800?l00P3o00050?n00080o`0000<0oh00003o0000o`002`3oP0020?l001T0oh000P00o`0@0?n0
00<0o`00103oP00Hooooo`005_ooool90?l00080oh009`3o00020?n00400o`00103oP0020?l00080
oh003P3o000>ooooo`80003o1`00o`0E0000o`H00?l00P3oP003003o01H0003o1`00o`020000o`03
003o00000?l0003o01000?l01P000?l5003o00T0003o1000o`000`000?l00?l0003o0007003o00@0
oh001`00o`020000o`kooooo50000?l3003o00d0003o2@00o`020000o`03003o00000?l0003o00L0
003o4P00o`020?n000800?l00`3oP004003o00/0003o:@00o`0>ooooo`@0oh0000<0o`000?n0003o
P000103o0002003o00030?l00000o`000?l000@0o`000P3oP0050?l000D0oh000P00o`0G0?n00080
o`000P3oP002003o0080o`001@3oP0020?l000030?n00000o`000?l000/0oh000P3o000I0?n00080
0?l0403oP0030?l000@0oh006?ooool001Kooooo3@3o00030?n003@0o`000P3oP0020?l000<0oh00
103o00020?n002L0o`000P3oP00@0?l000kooooo0P000?l7003o01D0003o1P00o`020?l000<00?l0
2`000?lB003o00D0003o4P00o`0D0000o`800?l000<0003o003o0000o`002@00o`020?n000800?l0
0P3o0003003o0080003o3_ooool4003o00`0003o2@00o`090000oa800?l02@000?lI003o00d0003o
1@00o`020000oa000?l00P000?l>003o00kooooo0P3oP0070?l000D0oh000P00o`070?n000H0o`00
0`3oP002003o0080oh000P3o000:0?n000@00?l00P3oP0020?l000D0oh000P3o000I0?n000800?l0
0`3oP0040?l00080oh000`3o000>0?n000@00?l02`3oP0050?l00080oh006?ooool001Kooooo3@3o
00030?n003@0o`000P3oP0020?l000<0oh00103o00020?n002L0o`000P3oP00@0?l000kooooo0P00
0?l7003o01D0003o1P00o`020?l000<00?l02`000?lB003o00D0003o4P00o`0D0000o`800?l000<0
003o003o0000o`002@00o`020?n000800?l00P3o0003003o0080003o3_ooool4003o00`0003o2@00
o`090000oa800?l02@000?lI003o00d0003o1@00o`020000oa000?l00P000?l>003o00kooooo0P3o
P0070?l000D0oh000P00o`070?n000H0o`000`3oP002003o0080oh000P3o000:0?n000@00?l00P3o
P0020?l000D0oh000P3o000I0?n000800?l00`3oP0040?l00080oh000`3o000>0?n000@00?l02`3o
P0050?l00080oh006?ooool001Kooooo7P3o00040?n002/0o`000P3oP00d0?l00080oh001@3o000>
ooooo`80003o1`00o`040000o`03003o00000?l0003o0080003o1000o`070000o`h00?l01`000?l7
003o00@0oh001000o`030?l000L00?l01`3oP00F003o00@0003o1`00o`000`000?l00?l0003o0004
003o00L0oh00103o0005003o00kooooo0P00o`0@0000o`D00?l03@000?l7003o0080003o2@00o`0;
0000o``00?l00P3oP005003o00d0003o:@00o`0>ooooo`80oh000P3o00000`3oP000o`000?l00002
0?n000D00?l00P000?l2003o0280oh000P3o00020?n000030?l0003oP000oh000080oh000P3o0002
0?n000030?l0003oP000oh0000L0oh001P00o`030?n000800?l00P3oP002003o00<0oh00103o000B
0?n000<00?l03`3oP0000`3o0000oh000?n000020?n001Sooooo000Foooooah0o`00103oP00[0?l0
0080oh00=03o00020?n000D0o`003_ooool20000o`L00?l010000?l00`00o`00003o0000o`020000
o`@00?l01`000?l>003o00L0003o1`00o`040?n000@00?l00`3o0007003o00L0oh005P00o`040000
o`L00?l000<0003o003o0000o`001000o`070?n000@0o`001@00o`0>ooooo`800?l040000?l5003o
00d0003o1`00o`020000o`T00?l02`000?l<003o0080oh001@00o`0=0000obT00?l03_ooool20?n0
0080o`0000<0oh000?l0003o00000P3oP005003o0080003o0P00o`0R0?n00080o`000P3oP0000`3o
0000oh000?n000020?n00080o`000P3oP0000`3o0000oh000?n000070?n000H00?l00`3oP002003o
0080oh000P00o`030?n000@0o`004P3oP003003o00l0oh0000<0o`000?n0003oP0000P3oP00Hoooo
o`005_oooolN0?l00080oh000P3o00020?n000D0o`000P3oP01J0?l000030?n0003o0000o`000080
o`003_ooool9003o00/0003o1@00o`090000o`@00?l03P000?l5003o00P0oh000`3o0009003o0080
oh000P3o00000`3oP0000?l0003o000D003o00@0003o3P00o`020?l000L00?l00`3o0004003o00ko
oooo1000o`0@0000o`800?l04`000?l2003o00@0003o00<00?l00000o`000?l00P00o`0=0000oa40
0?l02@000?l?003o0100003o1`00o`020000o`800?l000<0003o003o0000o`000P00o`0>ooooo`80
oh000P3o000:0?n000800?l04P3oP0020?l000/0oh0000<0o`00003o0000o`003`3oP0000`3o0000
oh000?n000040?n000030?l0003oP000oh0001T0oh000P3o00040?n000D0o`002`3oP0020?l00003
0?n0003o0000o`0000/0oh006?ooool001Kooooo7P3o00020?n00080o`000P3oP0050?l00080oh00
FP3o00000`3oP000o`000?l000020?l000kooooo2@00o`0;0000o`D00?l02@000?l4003o00h0003o
1@00o`080?n000<0o`002@00o`020?n00080o`0000<0oh00003o0000o`005000o`040000o`h00?l0
0P3o0007003o00<0o`001000o`0>ooooo`@00?l040000?l2003o01<0003o0P00o`040000o`03003o
00000?l0003o00800?l03@000?lA003o00T0003o3`00o`0@0000o`L00?l00P000?l2003o00030000
o`00o`000?l000800?l03_ooool20?n00080o`002P3oP002003o0180oh000P3o000;0?n000030?l0
0000o`000?l000l0oh0000<0o`000?n0003oP000103oP0000`3o0000oh000?n0000I0?n00080o`00
103oP0050?l000/0oh000P3o00000`3oP000o`000?l0000;0?n001Sooooo000Foooooc80o`000P3o
P01A0?l000030?n0003o0000o`000080o`003_ooool9003o00h0003o0P00o`0;0000o`800?l03P00
0?l20?n000800?l00`3oP0040?l00080oh000`3o0009003o00L0oh001P3o000>003o00@0003o1`00
o`000`000?l00?l0003o000=003o0080oh001@00o`0>ooooo`@00?l09@000?l2003o00@0003o00<0
0?l00000o`000?l00P00o`0>0000oa000?l04@000?l7003o0100003o1`00o`040000o`D00?l03_oo
oolF0?n000L00?l000<0o`000?n0003oP000503oP0020?l000T0oh002@3o00030?n000800?l00P3o
P002003o00D0oh000P3o00020?n00003003o003oP000oh0000800?l00P3oP0020?l000T0oh000`3o
000K0?n001Sooooo000Foooooc@0o`00103oP00<0?l00080oh00A03o000>ooooo`80003o1`00o`0;
0000oa000?l00P3oP003003o00@0003o0P00o`000`000?l00?l0003o00060000o`L00?l00P3o000:
003o00H0oh0000<0o`000?n0003oP0000P3o0002003o00<0oh003@00o`040000oah00?l03_ooool4
003o02T0003o0`00o`0B0000oa@00?l00P000?l2003o00T0003o2@00o`0>0000o`L00?l010000?l5
003o00kooooo0P3oP0020?l000D0oh000P3o000<0?n00080o`001@3oP0020?l000@00?l02@3oP002
0?l000<0oh000P3o00020?n000800?l02P3oP004003o00<0oh000P3o00040?n000800?l000<0oh00
0?l0003o0000103o000L0?n00080o`000P3oP0050?l000T0oh000P3o00020?n001Sooooo000Foooo
oc@0o`00103oP00<0?l00080oh00A03o000>ooooo`80003o1`00o`0;0000oa000?l00P3oP003003o
00@0003o0P00o`000`000?l00?l0003o00060000o`L00?l00P3o000:003o00H0oh0000<0o`000?n0
003oP0000P3o0002003o00<0oh003@00o`040000oah00?l03_ooool4003o02T0003o0`00o`0B0000
oa@00?l00P000?l2003o00T0003o2@00o`0>0000o`L00?l010000?l5003o00kooooo0P3oP0020?l0
00D0oh000P3o000<0?n00080o`001@3oP0020?l000@00?l02@3oP0020?l000<0oh000P3o00020?n0
00800?l02P3oP004003o00<0oh000P3o00040?n000800?l000<0oh000?l0003o0000103o000L0?n0
0080o`000P3oP0050?l000T0oh000P3o00020?n001Sooooo000Fooooo`h0o`00103oP0020?l00080
oh007P3o00020?n00180o`0000<0oh000?l0003o0000?`3o000>ooooo`T00?l05@000?l9003o0180
003o1000o`020?n000`00?l00P3oP0040?l000030?n00000o`000?l00080oh000P3o000@003o00@0
003o1`00o`030000oa@00?l03_ooool4003o03T0003o0P00o`030000oaP00?l00`000?l2003o00@0
003o00<00?l00000o`000?l00P00o`0K0000o`L00?l03_ooool40?l000030?n0003o0000o`000100
oh000P3o00090?n000800?l00P3o00000`3oP000o`000?l000060?n000<0o`000P00o`020?n00080
0?l00`3o000;0?n000D00?l00P3o0002003o00`0oh000P3o000;0?n000D0o`00103oP0020?l000D0
oh000P3o000;0?n000<00?l00P3oP00Hooooo`005_ooool>0?l000@0oh000P3o00020?n001h0o`00
0P3oP00B0?l000030?n0003o0000o`0003l0o`003_ooool9003o01D0003o2@00o`0B0000o`@00?l0
0P3oP00<003o0080oh00103o00000`3oP0000?l0003o00020?n00080o`004000o`040000o`L00?l0
0`000?lD003o00kooooo1000o`0i0000o`800?l00`000?lH003o00<0003o0P00o`040000o`03003o
00000?l0003o00800?l06`000?l7003o00kooooo103o00000`3oP000o`000?l0000@0?n00080o`00
2@3oP002003o0080o`0000<0oh000?l0003o00001P3oP0030?l000800?l00P3oP002003o00<0o`00
2`3oP005003o0080o`000P00o`0<0?n00080o`002`3oP0050?l000@0oh000P3o00050?n00080o`00
2`3oP003003o0080oh006?ooool001Kooooo6@3o00020?n003@0o`000P3oP00i0?l000kooooo1000
0?l00`00o`00003o0000o`02003o00/0003o1@00o`050000o`T00?l03`000?l5003o00@0oh003000
o`040?l001T00?l01@000?l6003o00D0003o4P00o`0>ooooo`80003o0P00o`0E0000o`800?l02@00
0?l9003o0100003o2@00o`020000o`03003o00000?l0003o00@0003o2@00o`0;0000o`D00?l05@00
0?l=003o00kooooo103oP0000`3o0000oh000?n000040?n00080o`002@3oP0000`3o00000?l0003o
00040?l000D0oh000P00o`030?n00080o`000P3oP0020?l00080oh0000<0o`000?n0003oP0001P3o
P0030?l000L00?l00P3o00050?n00080o`002`3oP0020?l00380oh006?ooool001Kooooo6@3o0002
0?n003@0o`000P3oP00i0?l000kooooo10000?l00`00o`00003o0000o`02003o00/0003o1@00o`05
0000o`T00?l03`000?l5003o00@0oh003000o`040?l001T00?l01@000?l6003o00D0003o4P00o`0>
ooooo`80003o0P00o`0E0000o`800?l02@000?l9003o0100003o2@00o`020000o`03003o00000?l0
003o00@0003o2@00o`0;0000o`D00?l05@000?l=003o00kooooo103oP0000`3o0000oh000?n00004
0?n00080o`002@3oP0000`3o00000?l0003o00040?l000D0oh000P00o`030?n00080o`000P3oP002
0?l00080oh0000<0o`000?n0003oP0001P3oP0030?l000L00?l00P3o00050?n00080o`002`3oP002
0?l00380oh006?ooool001Kooooo0P3oP0020?l000030?n0003o0000o`0001H0o`0000<0oh000?l0
003o0000103oP00d0?l00080oh00703o00020?n000L0o`00103oP0070?l000kooooo7P000?l8003o
00h0003o5`00o`020?l001d00?l00`000?l7003o00H0003o4000o`0>ooooo`80003o0P00o`0P0000
o``00?l01P000?l2003o00X0003o6000o`000`000?l00?l0003o00060000o`L00?l04P000?l:003o
0080003o0P00o`0>ooooo`d0oh001@3o00090?n000<0o`003`3oP0020?l000030?n0003o0000o`00
00d0oh000P00o`0>0?n000800?l04`3oP002003o0180oh00103o00070?n000<00?l00P3oP002003o
01Sooooo000Fooooo`80oh000P3o00000`3oP000o`000?l0000F0?l000030?n0003o0000o`0000@0
oh00=03o00020?n001`0o`000P3oP0070?l000@0oh001`3o000>oooooah0003o2000o`0>0000oaL0
0?l00P3o000M003o00<0003o1`00o`060000oa000?l03_ooool20000o`800?l080000?l<003o00H0
003o0P00o`0:0000oaP00?l000<0003o003o0000o`001P000?l7003o0180003o2P00o`020000o`80
0?l03_ooool=0?n000D0o`002@3oP0030?l000l0oh000P3o00000`3oP000o`000?l0000=0?n00080
0?l03P3oP002003o01<0oh000P00o`0B0?n000@0o`001`3oP003003o0080oh000P00o`0Hooooo`00
5_ooool40?l000<0oh006@3o00020?n000@0o`0000<0oh000?l0003o0000;`3o00020?n002D0o`00
0P3oP0090?l000kooooo7P000?l8003o0100003o9000o`000`000?l00?l0003o000=003o00<0003o
1`00o`040000o`T00?l00P3o0007003o00kooooo1000o`0P0000o`<00?l0103oP00=003o00`0003o
5P00o`000`000?l00?l0003o00040000o`L00?l01@000?l6003o00D0003o4P00o`0>ooooo`d0oh00
00<0o`000?n0003oP0003P3oP0020?l000@0oh001`00o`020?n00080o`001`3oP0020?l000030?n0
003o0000o`000080o`000P3oP002003o00030?l0003oP000oh0000800?l00P3o000<0?n000@0o`00
5@3oP0020?l000T0oh000P3o00030?n00080o`002`3oP00Hooooo`005_ooool=0?l000<0oh008P3o
00040?n00300o`000P3oP00R0?l000kooooo3P000?l2003o00h0003o2000o`0>0000obH00?l000<0
003o003o0000o`001`00o`090000o`L00?l010000?l9003o0080o`001`00o`0>ooooo`80003o0P00
o`0P0000o`<00?l00P3oP009003o0080003o0P00o`0>0000odH00?l03_oooolB0?n000@0o`001`3o
P0030?l000@0oh001`00o`0B0?n00080o`003P3oP002003o0080oh000`3o00020?n000800?l00P3o
P0000`00o`00oh000?n000090?n00080o`00103oP0000`3o0000oh000?n0000K0?n001Sooooo000F
ooooo`d0o`000`3oP00R0?l000@0oh00<03o00020?n00280o`003_ooool>0000o`800?l03P000?l8
003o00h0003o9P00o`000`000?l00?l0003o0007003o00T0003o1`00o`040000o`T00?l00P3o0007
003o00kooooo0P000?l2003o0200003o0`00o`020?n000T00?l00P000?l2003o00h0003oAP00o`0>
oooooa80oh00103o00070?n000<0o`00103oP007003o0180oh000P3o000>0?n000800?l00P3oP003
0?l00080oh000P00o`020?n00003003o003oP000oh0000T0oh000P3o00040?n000030?l0003oP000
oh0001/0oh006?ooool001Kooooo403o00020?n000D0o`000P3oP00I0?l00080oh003@3o00000`3o
P000o`000?l0000X0?l000<0oh006`3o000>ooooo`D0003o0P00o`0I0000o`@00?l040000?lB003o
00<0003o6P00o`0:0000o`L00?l00P000?l9003o0080o`000P00o`020?n000D00?l03_ooool5003o
01l0003o0P00o`000`3oP0000?l0003o0007003o01@0003o1`00o`020?n002L00?l00P000?l@003o
0080003o0P00o`0>ooooo`/0oh000P3o00090?n00003003o003oP000oh0000/0oh000`00o`020?l0
01l0oh0000<00?l00?n0003oP0001000o`0;0?n000030?l0003oP000oh0000H0o`00303oP0040?l0
00<0oh000P3o00020?n000800?l01@3oP0040?l000030?n0003o0000o`000080oh006?ooool001Ko
oooo403o00020?n000D0o`000P3oP00I0?l00080oh003@3o00000`3oP000o`000?l0000X0?l000<0
oh006`3o000>ooooo`D0003o0P00o`0I0000o`@00?l040000?lB003o00<0003o6P00o`0:0000o`L0
0?l00P000?l9003o0080o`000P00o`020?n000D00?l03_ooool5003o01l0003o0P00o`000`3oP000
0?l0003o0007003o01@0003o1`00o`020?n002L00?l00P000?l@003o0080003o0P00o`0>ooooo`/0
oh000P3o00090?n00003003o003oP000oh0000/0oh000`00o`020?l001l0oh0000<00?l00?n0003o
P0001000o`0;0?n000030?l0003oP000oh0000H0o`00303oP0040?l000<0oh000P3o00020?n00080
0?l01@3oP0040?l000030?n0003o0000o`000080oh006?ooool001Kooooo7P3o00020?n002@0o`00
103oP00/0?l000@0oh004P3o000>ooooo`80003o1@00o`070000o`800?l040000?l6003o01<0003o
:P00o`0:0000o`H00?l00`000?l9003o00L0oh000P00o`020000o`kooooo1@00o`0A0000o`03003o
00000?l0003o00@0003o00<00?l00000o`000?l010000?l<003o0180003o2@00o`020?n000/00?l0
0P000?lB003o00D0003o6@00o`0>ooooo`D0oh002@3o000;0?n000@0o`002@3oP0000`00o`00oh00
0?n000070?n000800?l00P3oP002003o00<0oh000P3o000=0?n000D00?l02@3oP004003o00L0oh00
0`3o000V0?n001Sooooo000Foooooah0o`000P3oP00T0?l000@0oh00;03o00040?n00180o`003_oo
ool20000o`D00?l01`000?l2003o0100003o1P00o`0C0000obX00?l02P000?l6003o00<0003o2@00
o`070?n000800?l00P000?l>ooooo`D00?l04@000?l00`00o`00003o0000o`040000o`03003o0000
0?l0003o00@0003o3000o`0B0000o`T00?l00P3oP00;003o0080003o4P00o`050000oaT00?l03_oo
ool50?n000T0o`002`3oP0040?l000T0oh0000<00?l00?n0003oP0001`3oP002003o0080oh000P00
o`030?n00080o`003@3oP005003o00T0oh001000o`070?n000<0o`009P3oP00Hooooo`005_oooolN
0?l00080oh00;@3o00020?n000L0o`00103oP00J0?l00080oh00103o00020?n000h0o`003_ooool7
003o00@0003o0P00o`000`000?l00?l0003o000@0000o`800?l00P000?l2003o01<0003o6@00o`06
0000o`/00?l04`000?l@003o00@0003o3_ooool5003o01H0003o1@00o`040000o`D00?l0103oP003
003o0140003o3P00o`020?n000030?l0003oP000oh000080oh004000o`020?n001L00?l00P3oP009
003o00kooooo1000o`070?n000T0o`00303oP002003o00D0oh000P3o00020?n000@0o`001@3oP002
003o01T0oh001@00o`040?n000800?l000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n00007
0?n000800?l01`3oP002003o00L0oh000P00o`020?n00080o`001@3oP00Hooooo`005_ooool40?n0
00<0o`000P3oP00N0?l000@0oh00G`3o000>ooooo`80003o1`00o`0E0000o`P00?l04`000?lD003o
0080oh001@00o`060000o`L00?l05@000?l@003o00@0003o3_ooool7003o0080003o5`00o`040000
o`<00?l00P3oP007003o00@0003o1@00o`090000oa000?l00P3oP004003o00<0003o3@00o`050000
o`/00?l00P3oP002003o00<0oh002`00o`0>ooooo`h0oh002@3o0002003o0100oh001`3o000=0?n0
00@00?l000<0oh000?l0003o00000P3o0002003o00X0oh000P00o`0P0?n00080o`000P00o`070?n0
00800?l02@3oP00Hooooo`005_ooool40?n000<0o`000P3oP00N0?l000@0oh00G`3o000>ooooo`80
003o1`00o`0E0000o`P00?l04`000?lD003o0080oh001@00o`060000o`L00?l05@000?l@003o00@0
003o3_ooool7003o0080003o5`00o`040000o`<00?l00P3oP007003o00@0003o1@00o`090000oa00
0?l00P3oP004003o00<0003o3@00o`050000o`/00?l00P3oP002003o00<0oh002`00o`0>ooooo`h0
oh002@3o0002003o0100oh001`3o000=0?n000@00?l000<0oh000?l0003o00000P3o0002003o00X0
oh000P00o`0P0?n00080o`000P00o`070?n000800?l02@3oP00Hooooo`005_ooool;0?l000<0oh00
0P3o00020?n001h0o`00103oP0040?l000030?n0003o0000o`0001/0o`000P3oP00[0?l00080oh00
00<0o`000?n0003oP0000P3o000>ooooo`80003o1@00o`0G0000o`@00?l00P000?l2003o0180003o
6P00o`060000o`L00?l05`000?l6003o00030000o`00o`000?l000L00?l010000?l>ooooo`D00?l0
10000?l>003o0080003o0P00o`0;0000o``00?l00P000?l4003o00`0003o5000o`030000o`d00?l0
1@000?lM003o00kooooo4P3oP0020?l000D0oh000P00o`0d0?n00080o`001@3oP002003o00<0oh00
103o00050?n000@0o`000P3oP003003o00@0o`002@3oP005003o00/0oh006?ooool001Kooooo2`3o
00030?n00080o`000P3oP00N0?l000@0oh00103o00000`3oP000o`000?l0000K0?l00080oh00:`3o
00020?n000030?l0003oP000oh000080o`003_ooool20000o`D00?l05`000?l4003o0080003o0P00
o`0B0000oaX00?l01P000?l7003o01L0003o1P00o`000`000?l00?l0003o0007003o00@0003o3_oo
ool5003o00@0003o3P00o`020000o`800?l02`000?l<003o0080003o1000o`0<0000oa@00?l00`00
0?l=003o00D0003o7@00o`0>oooooa80oh000P3o00050?n000800?l0=03oP0020?l000D0oh000P00
o`030?n000@0o`001@3oP0040?l00080oh000`00o`040?l000T0oh001@00o`0;0?n001Sooooo000F
oooooaH0o`0000<0oh000?l0003o00005`3o00020?n000@0o`000P3oP0000`3o0000oh000?n0000V
0?l00080oh000`3o00020?n00080o`000`3oP00M0?l000kooooo0P000?l5003o01L0003o1000o`02
0000o`800?l030000?lV003o00<0003o0P00o`0I0000o`H00?l000<0003o003o0000o`001P00o`05
0000o`kooooo1@00o`040000o`h00?l00P000?l4003o00X0003o4@00o`090000o`03003o00000?l0
003o0080003o4000o`070000o`/00?l010000?lE003o00@0003o1@00o`0>ooooo`800?l00`3o0002
0?n00080o`000P3oP0020?l000X0oh001P00o`070?n00080o`005@3oP0040?l00080oh001`00o`03
0?n000H0o`001@3oP004003o00030?l0003oP000oh0000H0oh001`3o00030?n00080o`002`3oP005
003o00@0o`001@3oP0020?l001Sooooo000FoooooaH0o`0000<0oh000?l0003o00005`3o00020?n0
00@0o`000P3oP0000`3o0000oh000?n0000V0?l00080oh000`3o00020?n00080o`000`3oP00M0?l0
00kooooo0P000?l5003o01L0003o1000o`020000o`800?l030000?lV003o00<0003o0P00o`0I0000
o`H00?l000<0003o003o0000o`001P00o`050000o`kooooo1@00o`040000o`h00?l00P000?l4003o
00X0003o4@00o`090000o`03003o00000?l0003o0080003o4000o`070000o`/00?l010000?lE003o
00@0003o1@00o`0>ooooo`800?l00`3o00020?n00080o`000P3oP0020?l000X0oh001P00o`070?n0
0080o`005@3oP0040?l00080oh001`00o`030?n000H0o`001@3oP004003o00030?l0003oP000oh00
00H0oh001`3o00030?n00080o`002`3oP005003o00@0o`001@3oP0020?l001Sooooo000FoooooaL0
o`00103oP0020?l000<0oh006@3o00020?n002T0o`000P3oP0040?l000<0oh007@3o000>ooooo`80
003o1`00o`040000o`03003o00000?l0003o00L0003o0P00o`020000o`800?l000<0003o003o0000
o`001P00o`0:0000o`P00?l000<0003o003o0000o`009000o`020000o`800?l04`000?l?003o00D0
003o3_ooool5003o00/0003o1`00o`020000o`800?l030000?l9003o0080003o1P00o`0G0000o`<0
0?l03`000?l7003o00@0003o4@00o`080000o`03003o00000?l0003o00800?l03_ooool=0?n00003
003o003o0000o`0000L0oh000P00o`020?n00080o`004`3oP0020?l00080oh003@3o000@0?n000<0
o`000P3oP0020?l000L0oh00103o00050?n000D0o`00103oP0020?l000L0oh000P00o`070?n00080
o`001@3oP00Hooooo`005_oooolG0?l000@0oh000P3o00030?n001T0o`000P3oP00Y0?l00080oh00
103o00030?n001d0o`003_ooool20000o`L00?l010000?l00`00o`00003o0000o`070000o`800?l0
0P000?l2003o00030000o`00o`000?l000H00?l02P000?l8003o00030000o`00o`000?l002@00?l0
0P000?l2003o01<0003o3`00o`050000o`kooooo1@00o`0;0000o`L00?l00P000?l2003o00`0003o
2@00o`020000o`H00?l05`000?l3003o00l0003o1`00o`040000oa400?l020000?l00`00o`00003o
0000o`02003o00kooooo3@3oP0000`00o`00o`000?l000070?n000800?l00P3oP0020?l001<0oh00
0P3o00020?n000d0o`00403oP0030?l00080oh000P3o00070?n000@0o`001@3oP0050?l000@0oh00
0P3o00070?n000800?l01`3oP0020?l000D0oh006?ooool001Kooooo103oP00I0?l000030?n0003o
0000o`000080o`000P3oP0020?l000<0oh008P3o00040?n002D0o`000P3oP00D0?l000kooooo0P00
0?l7003o00@0003o00<00?l00000o`000?l03@000?l9003o00X0003o2000o`000`000?l00?l0003o
000]003o00h0003o4P00o`020000o`kooooo1@00o`0=0000o`800?l00P000?l00`00o`00003o0000
o`0@0000o`L00?l08P000?l2003o00l0003o00<00?l00000o`000?l00P00o`070000o`T00?l02`00
0?l7003o00kooooo0P3oP005003o00@0oh000P3o0007003o00<0oh000P00o`020?n00080o`001@00
o`0;0?n000<0o`006@3oP002003o01@0oh00103o00030?n00080o`000P3oP0020?l000P0oh00103o
0007003o00@0o`000P3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`/0o`000P3oP00R
0?l000030?n0003o0000o`0001T0o`000P3oP0020?l000<0oh000P3o00040?n001/0o`0000<0oh00
0?l0003o0000503o000>ooooo`80003o3P00o`0>0000o`P00?l030000?l2003o0080003o0P00o`00
0`000?l00?l0003o0004003o0080oh009`00o`0<0000oa@00?l00P000?l>ooooo`D00?l09P000?l7
003o0200003o0P00o`0?0000o`L00?l01`000?l2003o01L0003o3_ooool5003o00@0oh000P3o0002
0?n000T00?l000<0oh00003o0000o`00103o000<0?n00080o`001`3oP0020?l00080oh000P3o0000
0`00o`00oh000?n0000M0?n000`0o`002`3oP002003o00T0oh001`00o`020?l000D0oh000P3o000H
ooooo`005_ooool;0?l00080oh008P3o00000`3oP000o`000?l0000I0?l00080oh000P3o00030?n0
0080o`00103oP00K0?l000030?n0003o0000o`0001@0o`003_ooool20000o`h00?l03P000?l8003o
00`0003o0P00o`020000o`800?l000<0003o003o0000o`001000o`020?n002L00?l030000?lD003o
0080003o3_ooool5003o02H0003o1`00o`0P0000o`800?l03`000?l7003o00L0003o0P00o`0G0000
o`kooooo1@00o`040?n00080o`000P3oP009003o00030?n00000o`000?l000@0o`00303oP0020?l0
00L0oh000P3o00020?n00080o`0000<00?l00?n0003oP0007@3oP00<0?l000/0oh000P00o`090?n0
00L00?l00P3o00050?n00080o`006?ooool001Kooooo503o00020?n001T0o`000`3oP0020?l00080
oh000P3o00030?n001T0o`000P3oP0070?l000@0oh00803o00020?n000L0o`003_ooool20000o`L0
0?l00P000?l5003o00d0003o1`00o`0E0000obP00?l00P3oP005003o00`0003o5P00o`0>ooooobT0
003o1`00o`0Q0000o`L00?l02`000?l9003o01D0003o1000o`050000o`kooooo0P3oP003003o01T0
oh000P3o000D0?n000/00?l04`3oP0040?l00080oh000P3o00030?n000@0o`002@3oP0050?l001@0
oh000P3o00050?n001Sooooo000Foooooa@0o`000P3oP00I0?l000<0oh000P3o00020?n00080o`00
0`3oP00I0?l00080oh001`3o00040?n00200o`000P3oP0070?l000kooooo0P000?l7003o0080003o
1@00o`0=0000o`L00?l05@000?lX003o0080oh001@00o`0<0000oaH00?l03_oooolY0000o`L00?l0
8@000?l7003o00/0003o2@00o`0E0000o`@00?l01@000?l>ooooo`80oh000`00o`0I0?n00080o`00
503oP00;003o01<0oh00103o00020?n00080o`000`3oP0040?l000T0oh001@3o000D0?n00080o`00
1@3oP00Hooooo`005_oooolB0?l00080oh000P3o00000`3oP000o`000?l000020?l000<0oh006P3o
00000`3oP000o`000?l000070?l00080oh006@3o00020?n000/0o`000P3oP00L0?l00080oh003_oo
ool20000o`800?l01@000?l7003o00d0003o1`00o`0E0000o`@00?l00P3oP0020?l000<00?l01000
0?lC003o0080oh002`00o`0>0000o`d00?l00P000?l00`00o`00003o0000o`020000o`kooooo:@00
0?l6003o02<0003o1P00o`0;0000o`T00?l05@000?l4003o00030000o`00o`000?l00080003o3_oo
ool70?n00080o`004P3oP0020?l000030?n0003o0000o`0000d0oh000P3o00030?n000800?l00P3o
P007003o00T0oh000P00o`0B0?n000<0o`00103oP0030?l001/0oh000P3o00090?n001Sooooo000F
oooooa80o`000P3oP0020?l000030?n0003o0000o`000080o`000`3oP00J0?l000030?n0003o0000
o`0000L0o`000P3oP00I0?l00080oh002`3o00020?n001`0o`000P3oP00>ooooo`80003o0P00o`05
0000o`L00?l03@000?l7003o01D0003o1000o`020?n00080o`000`00o`040000oa<00?l00P3oP00;
003o00h0003o3@00o`020000o`03003o00000?l0003o0080003o3_oooolY0000o`H00?l08`000?l6
003o00/0003o2@00o`0E0000o`@00?l000<0003o003o0000o`000P000?l>ooooo`L0oh000P3o000B
0?n00080o`0000<0oh000?l0003o00003@3oP0020?l000<0oh000P00o`020?n000L00?l02@3oP002
003o0180oh000`3o00040?n000<0o`006`3oP0020?l000T0oh006?ooool001Kooooo0P3oP00I0?l0
0080oh000`3o00020?n001l0o`0000<0oh000?l0003o0000A03o00020?n000kooooo4000o`0;0000
o`D00?l00P3o0002003o01D0003o1P00o`020?n000h00?l01`000?l=003o00030?n00000o`000?l0
00800?l03P000?l=003o0080003o1@00o`0>ooooobT0003o2@00o`0P0000o`P00?l02P000?l8003o
00X0003o1P00o`070000o`800?l01@000?l>ooooo`h0oh00103o00020?n00080o`001@3oP0020?l0
00<0oh000P3o00020?n000/0o`0000<0oh000?l0003o00000P00o`020?n00080o`000`00o`0M0?n0
00<0o`00203oP0030?l000H0oh0000<0o`000?n0003oP0002@3oP0020?l000/0oh0000<0o`000?n0
003oP0000P3oP00Hooooo`005_ooool20?n001T0o`000P3oP0030?l00080oh007`3o00000`3oP000
o`000?l000140?l00080oh003_ooool@003o00/0003o1@00o`020?l000800?l05@000?l6003o0080
oh003P00o`070000o`d00?l000<0oh00003o0000o`000P00o`0>0000o`d00?l00P000?l5003o00ko
oooo:@000?l9003o0200003o2000o`0:0000o`P00?l02P000?l6003o00L0003o0P00o`050000o`ko
oooo3P3oP0040?l00080oh000P3o00050?n00080o`000`3oP0020?l00080oh002`3o00000`3oP000
o`000?l00002003o0080oh000P3o0003003o01d0oh000`3o00080?n000<0o`001P3oP0000`3o0000
oh000?n000090?n00080o`002`3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`80o`00
0P3oP00P0?l000<0oh00903o00020?n002T0o`000P3oP00B0?l000kooooo4000o`060000o`<00?l0
0P000?l;003o01<0003o5P00o`020000o`L00?l00P000?l7003o01D0003o5000o`0>ooooobT0003o
1`00o`0T0000o`L00?l02@000?l8003o00L0003o2@00o`030000o`L00?l010000?l>ooooo`800?l0
0`3o000_0?n000800?l00P3oP0000`00o`00oh000?n000060?n000<00?l00P3oP0020?l000<0oh00
1`3o000;0?n000L0o`002@3oP0060?l000T0oh0000<0o`000?n0003oP0002`3oP00Hooooo`005_oo
ool20?l00080oh001@3o00020?n001T0o`000P3oP0070?l00080oh006P3o00020?n00080o`00103o
P0000`3o0000oh000?n0000O0?l000030?n0003o0000o`0000H0o`0000<0oh000?l0003o00002`3o
000>oooooa000?l01P000?l3003o0080003o2`00o`0>0000o`/00?l00P3o000R003o01<0003o5000
o`0>ooooo`D00?l04@000?l00`00o`00003o0000o`0>0000o`P00?l09@000?l;003o0080003o0`00
o`040?n000@00?l000<0003o003o0000o`000P000?lG003o0080003o3_ooool;0?n000<0o`00503o
P002003o02@0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000060?n000030?l0003o
P000oh0000L0oh00103o00050?n000@0o`000P3oP0030?l00180oh000P00o`0Hooooo`005_ooool2
0?l00080oh001@3o00020?n001T0o`000P3oP0070?l00080oh006P3o00020?n00080o`00103oP000
0`3o0000oh000?n0000O0?l000030?n0003o0000o`0000H0o`0000<0oh000?l0003o00002`3o000>
oooooa000?l01P000?l3003o0080003o2`00o`0>0000o`/00?l00P3o000R003o01<0003o5000o`0>
ooooo`D00?l04@000?l00`00o`00003o0000o`0>0000o`P00?l09@000?l;003o0080003o0`00o`04
0?n000@00?l000<0003o003o0000o`000P000?lG003o0080003o3_ooool;0?n000<0o`00503oP002
003o02@0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000060?n000030?l0003oP000
oh0000L0oh00103o00050?n000@0o`000P3oP0030?l00180oh000P00o`0Hooooo`005_ooool=0?l0
00030?n0003o0000o`000080o`000P3oP00I0?l000<0oh008P3o00020?n00200o`000P3oP0040?l0
00<0oh003@3o000>ooooo`800?l00P3o000<003o00H0003o00<0oh00003o0000o`000P000?l<003o
0180003o4P00o`020?l001@00?l01@000?l2003o00h0003o5000o`0>ooooo`L00?l02`000?l7003o
00h0003o2@00o`0F0000o`800?l000<0003o003o0000o`00>`00o`040000o`kooooo0P3oP0050?l0
0080oh001`3o00060?n000P0o`001000o`020000o`<00?l0203oP0000`3o0000oh000?n000020?l0
00D0oh001P3o00050?n000D0o`002`3oP0020?l00080oh004P3o00030?n000T0o`00503oP00Hoooo
o`005_ooool=0?l000030?n0003o0000o`000080o`000P3oP00I0?l000<0oh008P3o00020?n00200
o`000P3oP0040?l000<0oh003@3o000>ooooo`800?l00P3o000<003o00H0003o00<0oh00003o0000
o`000P000?l<003o0180003o4P00o`020?l001@00?l01@000?l2003o00h0003o5000o`0>ooooo`L0
0?l02`000?l7003o00h0003o2@00o`0F0000o`800?l000<0003o003o0000o`00>`00o`040000o`ko
oooo0P3oP0050?l00080oh001`3o00060?n000P0o`001000o`020000o`<00?l0203oP0000`3o0000
oh000?n000020?l000D0oh001P3o00050?n000D0o`002`3oP0020?l00080oh004P3o00030?n000T0
o`00503oP00Hooooo`005_ooool@0?l00080oh009P3o00000`3oP000o`000?l0000o0?l00080oh00
00<0o`000?n0003oP0000P00o`090?l000kooooo4000o`0=0000o`<00?l00P000?l2003o01L0003o
3P00o`060?l001800?l05@000?l7003o00@0oh000P3o0007003o00kooooo1`00o`0?0000o`03003o
00000?l0003o00h0003o2@00o`090000o`800?l00P000?l5003o00L0003o2@00o`020000oaP00?l0
00<0003o003o0000o`000P00o`020000oaL00?l03_ooool=0?n000<0o`00403oP0020?l000800?l0
0P3o0003003o01@0oh000P3o000E0?n000800?l03@3o00070?n000<0o`000P3oP002003o0080oh00
00<0o`000?n0003oP0001P3oP0030?l000@00?l00P000?l50?n001Sooooo000Foooooa00o`000P3o
P00V0?l000030?n0003o0000o`0003l0o`000P3oP0000`3o0000oh000?n00002003o00T0o`003_oo
ool@003o00d0003o0`00o`020000o`800?l05`000?l>003o00H0o`004P00o`0E0000o`L00?l0103o
P0020?l000L00?l03_ooool7003o00l0003o00<00?l00000o`000?l03P000?l9003o00T0003o0P00
o`020000o`D00?l01`000?l9003o0080003o6000o`000`000?l00?l0003o0002003o0080003o5`00
o`0>ooooo`d0oh000`3o000@0?n00080o`000P00o`020?l000<00?l0503oP0020?l001D0oh000P00
o`0=0?l000L0oh000`3o00020?n000800?l00P3oP0000`3o0000oh000?n000060?n000<0o`001000
o`020000o`D0oh006?ooool001Kooooo103oP00G0?l00080oh006@3o00020?n000L0o`000`3oP00I
0?l00080oh001P3o00000`3oP000o`000?l000020?l00080oh004`3o00020?n000800?l02@3o000>
ooooo`800?l00P3oP00<003o02T0003o3`00o`050?l001L00?l00P000?l2003o0100003o1`00o`04
0?n000L00?l03_ooool7003o00@0003o0P00o`090000o`03003o00000?l0003o00d0003o00<00?l0
0000o`000?l01`00o`040000o`@00?l000<0003o003o0000o`000P000?l2003o00L0003o7P00o`02
0?n000H00?l000<0003o003o0000o`003P00o`020?n000T00?l00P000?l>ooooobd0oh000P3o0000
0`00o`00oh000?n000020?n00080o`000P3oP0000`00o`00o`000?l000020?l00100oh00103o0000
0`3oP0000?l0003o000f0?n001Sooooo000Fooooo`@0oh0000<0o`000?n0003oP0000P3oP00I0?l0
0080oh006`3o00020?n000030?l0003oP000oh000080oh000P3o00030?n001/0o`000P3oP00R0?l0
00kooooo0P00o`020?n000X00?l0:`000?l?003o00D0oh006`00o`0@0000o`L00?l0103o0007003o
00kooooo1`00o`0?0000o`03003o00000?l0003o00L0003o1`00o`040000o`D00?l010000?l7003o
0080003o0P00o`090000o`D00?l010000?l7003o0080003o00<00?l00000o`000?l01`000?lV003o
00kooooo103oP003003o01T0oh00103o000[0?n00080o`000`3oP002003o02@0oh000P3o00000`3o
P000o`000?l0000;0?n001Sooooo000Fooooo`@0oh0000<0o`000?n0003oP0000P3oP00I0?l00080
oh006`3o00020?n000030?l0003oP000oh000080oh000P3o00030?n001/0o`000P3oP00R0?l000ko
oooo0P00o`020?n000X00?l0:`000?l?003o00D0oh006`00o`0@0000o`L00?l0103o0007003o00ko
oooo1`00o`0?0000o`03003o00000?l0003o00L0003o1`00o`040000o`D00?l010000?l7003o0080
003o0P00o`090000o`D00?l010000?l7003o0080003o00<00?l00000o`000?l01`000?lV003o00ko
oooo103oP003003o01T0oh00103o000[0?n00080o`000`3oP002003o02@0oh000P3o00000`3oP000
o`000?l0000;0?n001Sooooo000Fooooo`80oh000`3o00020?n001/0o`000P3oP0020?l000<0oh00
6@3o00020?n00080o`001@3oP00I0?l00080oh00103o00050?n00080o`000P3oP00G0?l000kooooo
3P00o`0]0000oal00?l00`3oP00;003o00@0003o1@00o`050000o`T00?l00P3oP009003o00kooooo
1@00o`0a0000o`800?l000<0003o003o0000o`003P000?l4003o00@0003o1`00o`0;0000o`T00?l0
00<0003o003o0000o`006`00o`0>ooooo`@0oh000`00o`060?n000030?l0003oP000oh000080o`00
2@3oP0020?l001L0oh000P3o00030?n000@0o`003P3oP0040?l001L0oh00103o00020?n000030?l0
003oP000oh000080oh000`3o000F0?n001Sooooo000Fooooo`80oh000`3o00020?n001/0o`000P3o
P0020?l000<0oh006@3o00020?n00080o`001@3oP00I0?l00080oh00103o00050?n00080o`000P3o
P00G0?l000kooooo3P00o`0]0000oal00?l00`3oP00;003o00@0003o1@00o`050000o`T00?l00P3o
P009003o00kooooo1@00o`0a0000o`800?l000<0003o003o0000o`003P000?l4003o00@0003o1`00
o`0;0000o`T00?l000<0003o003o0000o`006`00o`0>ooooo`@0oh000`00o`060?n000030?l0003o
P000oh000080o`002@3oP0020?l001L0oh000P3o00030?n000@0o`003P3oP0040?l001L0oh00103o
00020?n000030?l0003oP000oh000080oh000`3o000F0?n001Sooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59655 L
.2381 .59655 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59655 L
.2381 .59655 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01501 L
.47619 .01501 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01501 L
.47619 .01501 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01814 L
.95238 .01814 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01731 L
.2381 .01731 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01731 L
.2381 .01731 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .48371 L
.47619 .48371 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .48371 L
.47619 .48371 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .12139 L
.71429 .12139 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .12139 L
.71429 .12139 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01939 L
.95238 .01939 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01939 L
.95238 .01939 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF00FF000000FF0000FF0000FF0000FF0000FF000000FFFF80000000FF
0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF00000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF0000FF80000000FF
FF80000000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF800000FF00
00FF000000FF0000FF0000FF00FF00
0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF000000FFFF80000000FFFF0000FF800000FF00
0000FFFF80000000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
FF80000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF000000FF000000FF00FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FFFF8000
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000FF000000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF00000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF000000FF00FF00000000FF00FF00FF0000
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF00FF000000FF000000FF0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF000000FFFF000000FF000000FF0000FF0000FF00FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FFFF00000000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FFFF00000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FF00FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF00FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FFFF80000000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF000000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01293 L
.2381 .01293 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01293 L
.2381 .01293 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .09761 L
.47619 .09761 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .09761 L
.47619 .09761 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .515 L
.71429 .515 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .515 L
.71429 .515 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01627 L
.95238 .01627 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF00000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01418 L
.2381 .01418 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01418 L
.2381 .01418 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01376 L
.47619 .01376 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01376 L
.47619 .01376 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .60135 L
.95238 .60135 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .60135 L
.95238 .60135 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooooaKoo`001?oooolG
o`3o00Cooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo
00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o
00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo
000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooo
oaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooo
oaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04oooo
o`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooo
oooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolG
o`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo
001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co
001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000oooo
ooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00
Ool007l0D_l007lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?oo
ool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l0
07lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03Oo
001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l007lGoomo00Co
001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0goooooaOo003o7oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000T
ooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04oooo
o`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOo
ogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00
EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooo
oooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0
003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooo
ooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Soooo
o`009?oooomao`0002KoooooLOl0000Wooooog7o00009_oooomao`0002Gooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`005ooooolV0?l00003003o003o0000o`0003X0o`0000<0003o0?l0003o00003@3o00000`3o
P000o`000?l000040?l00080oh003P3o000>ooooob800?l00P3o00030?n00080003o3P00o`020?n0
00D00?l00P000?l20?l000h00?l00P000?l9003o0080003o1@00o`020000o`T00?l000<0003o003o
0000o`000P3o0009003o0080003o00<0oh000000o`000?l01`000?l2003o00kooooo1@000?l4003o
0080003o00<00?l00000o`000?l03@000?l00`00o`00003o0000o`0D0000o`800?l0E@000?l>oooo
od80oh000P3o00160?n001Wooooo000GooooobH0o`0000<00?l00?l0003o0000>P3o00000`000?l0
o`000?l0000=0?l000030?n0003o0000o`0000@0o`000P3oP00>0?l000kooooo8P00o`020?l000<0
oh000P000?l>003o0080oh001@00o`020000o`80o`003P00o`020000o`T00?l00P000?l5003o0080
003o2@00o`000`000?l00?l0003o00020?l000T00?l00P000?l00`3oP000003o0000o`070000o`80
0?l03_ooool50000o`@00?l00P000?l00`00o`00003o0000o`0=0000o`03003o00000?l0003o01@0
003o0P00o`1E0000o`kooooo@P3oP0020?l004H0oh006Oooool001Oooooo>03o00000`3oP000o`00
0?l0000G0?l00080oh003`3o00000`00o`00o`000?l0000G0?l00080oh001`3o00020?n00080o`00
3_ooool2003o0080003o7P00o`020?l000030?n0003o0000o`000080003o4P00o`030000o`800?l0
0P3o000>003o0080003o8`00o`020000o`800?l0103o00000`3oP000003o0000o`020?n000D0003o
0P00o`0>ooooo`D0003o1P00o`0@0000o`03003o00000?l0003o0180003o0P00o`020000o`03003o
00000?l0003o00@00?l0;P000?l2003o00T0003o00<00?l00000o`000?l04P000?l>ooooodH0oh00
0P3o000R0?n00080o`007P3oP00Iooooo`005ooooolh0?l000030?n0003o0000o`0001L0o`000P3o
P00?0?l00003003o003o0000o`0001L0o`000P3oP0070?l00080oh000P3o000>ooooo`800?l00P00
0?lN003o0080o`0000<0oh000?l0003o00000P000?lB003o00<0003o0P00o`020?l000h00?l00P00
0?lS003o0080003o0P00o`040?l000030?n000000?l0003o0080oh001@000?l2003o00kooooo1@00
0?l6003o0100003o00<00?l00000o`000?l04P000?l2003o0080003o00<00?l00000o`000?l01000
o`0^0000o`800?l02@000?l00`00o`00003o0000o`0B0000o`koooooAP3oP0020?l00280oh000P3o
000N0?n001Wooooo000Goooooe@0o`000P3oP00>0?l000800?l0503o00020?n000T0o`001@3oP00>
ooooo`800?l00P000?lP003o00030?n00000o`000?l001T00?l00P3o00020?n003D00?l00P000?l2
003o00030?n00000o`000?l000800?l01@000?l2003o00kooooo1@000?l6003o00T0003o00<00?l0
0000o`000?l08P000?l2003o03D0003o0P00o`020000o`<00?l04P000?l>ooooodH0oh000P000?m2
0?n001Wooooo000GooooodT0o`000P3oP00k0?l000@0oh003_ooool20000o`80oh008000o`000`00
0?l00?l0003o000>003o0080003o0P00o`030000o`800?l00P000?l>003o00@0003o1`00o`020000
oa<00?l00P000?l5003o0080003o0P3oP0020000o`80o`0000<0oh00003o0000o`000P000?l20?n0
00<0003o0P00o`0>ooooo`@0003o1`00o`0^0000o`800?l0?0000?l2003o0100003o3_oooon:0?n0
01Wooooo000GooooodT0o`000P3oP00k0?l000@0oh003_ooool20000o`80oh008000o`000`000?l0
0?l0003o000>003o0080003o0P00o`030000o`800?l00P000?l>003o00@0003o1`00o`020000oa<0
0?l00P000?l5003o0080003o0P3oP0020000o`80o`0000<0oh00003o0000o`000P000?l20?n000<0
003o0P00o`0>ooooo`@0003o1`00o`0^0000o`800?l0?0000?l2003o0100003o3_oooon:0?n001Wo
oooo000Goooooe80o`000P3oP00P0?l00080oh00503o000>ooooo`@0003o8000o`000`000?l00?l0
003o0002003o0080003o4@00o`080000o`03003o00000?l0003o00L00?l00P000?l>003o0080003o
1@00o`040000o`@00?l000<0003o003o0000o`001`00o`060000o`030?n000000?l0003o00@0003o
1@00o`0>ooooo`@0003o2000o`0;0000o`800?l05`000?l2003o00L0003o0P00o`0B0000o`030?l0
00000?l0003o00T0003o0P00o`0I0000o`03003o00000?l0003o0180003o3_oooon:0?n001Wooooo
000Goooooe80o`000P3oP00P0?l00080oh00503o000>ooooo`@0003o8000o`000`000?l00?l0003o
0002003o0080003o4@00o`080000o`03003o00000?l0003o00L00?l00P000?l>003o0080003o1@00
o`040000o`@00?l000<0003o003o0000o`001`00o`060000o`030?n000000?l0003o00@0003o1@00
o`0>ooooo`@0003o2000o`0;0000o`800?l05`000?l2003o00L0003o0P00o`0B0000o`030?l00000
0?l0003o00T0003o0P00o`0I0000o`03003o00000?l0003o0180003o3_oooon:0?n001Wooooo000G
ooooogP0o`000P00o`0@0?l000kooooo9000o`000`000?l00?l0003o0002003o0080003o4@00o`08
0000o`03003o00000?l0003o00@0003o0P00o`030000o`D00?l00P000?l2003o0080003o1`00o`05
0000o`H00?l000<0003o003o0000o`001`00o`0@0000o`800?l03_ooool40000o`P00?l0;@000?l2
003o00030000o`00o`000?l000d0003o1`3oP00E0000o`800?l02@000?l2003o00030000o`00o`00
0?l00180003o3_oooon:0?n001Wooooo000GooooogP0o`000P00o`0@0?l000kooooo9000o`000`00
0?l00?l0003o0002003o0080003o4@00o`080000o`03003o00000?l0003o00@0003o0P00o`030000
o`D00?l00P000?l2003o0080003o1`00o`050000o`H00?l000<0003o003o0000o`001`00o`0@0000
o`800?l03_ooool40000o`P00?l0;@000?l2003o00030000o`00o`000?l000d0003o1`3oP00E0000
o`800?l02@000?l2003o00030000o`00o`000?l00180003o3_oooon:0?n001Wooooo000Gooooo`h0
o`000P00o`1C0?l00003003o003o0000o`0000d0o`001@3oP00B0?l000kooooo:@00o`020000oa00
0?l01`000?l3003o00H0003o0P00o`030000o`800?l00P000?l00`00o`00003o0000o`02003o0080
003o4P00o`000`000?l00?l0003o0007003o00H0003o0`00o`020?n000L0003o3_ooool40000o`L0
0?l09@000?l2003o01/0003o1@3oP00g0000o`koooooRP3oP00Iooooo`005oooool>0?l000800?l0
NP3o000>ooooobL00?l010000?l:003o0080003o1000o`070000o`L00?l01`000?l5003o00@0003o
0P00o`020000oa000?l000<0003o003o0000o`001`00o`040000o`D00?l01`000?l2003o00kooooo
10000?l5003o00T0003o0`00o`0K0000o`800?l00`000?l2003o01@0003o1`3oP00g0000o`kooooo
RP3oP00Iooooo`005oooool>0?l000800?l0NP3o000>ooooobL00?l010000?l:003o0080003o1000
o`070000o`L00?l01`000?l5003o00@0003o0P00o`020000oa000?l000<0003o003o0000o`001`00
o`040000o`D00?l01`000?l2003o00kooooo10000?l5003o00T0003o0`00o`0K0000o`800?l00`00
0?l2003o01@0003o1`3oP00g0000o`koooooRP3oP00Iooooo`005ooooon30?l00080oh001@3o000>
oooooaL00?l00P000?l<003o0080003o0P00o`020000oa000?l01`000?l5003o0180003o9000o`00
0`000?l00?l0003o00050000o`@00?l03_ooool2003o0080003o1@00o`0;0000o`03003o00000?l0
003o00800?l0F`000?l3003o0180003o3_oooon:0?n001Wooooo000Goooooh<0o`000P3oP0050?l0
00kooooo5`00o`020000o``00?l00P000?l2003o0080003o4000o`070000o`D00?l04P000?lT003o
00030000o`00o`000?l000D0003o1000o`0>ooooo`800?l00P000?l5003o00/0003o00<00?l00000
o`000?l00P00o`1K0000o`<00?l04P000?l>ooooohX0oh006Oooool001OoooooP`3o00020?n000D0
o`003_oooolT003o00030000o`00o`000?l000800?l00P000?lC003o0080003o1000o`000`000?l0
0?l0003o0004003o00<0oh000P3o0002003o0080003o00<00?l00000o`000?l00P000?l2003o0080
003o1`00o`000`000?l00?l0003o000B003o0080003o0P00o`000`000?l0oh000?n000020?l000D0
003o0P00o`0>ooooo`80003o2P00o`040000o`L00?l06@000?l2003o01/0003o00<0oh000000o`00
0?l08P000?l3003o00/0003o1000o`050000o`koooooRP3oP00Iooooo`005ooooon30?l00080oh00
1@3o000>ooooob@00?l000<0003o003o0000o`000P00o`020000oa<00?l00P000?l4003o00030000
o`00o`000?l000@00?l00`3oP0020?l000800?l00P000?l00`00o`00003o0000o`020000o`800?l0
0P000?l7003o00030000o`00o`000?l001800?l00P000?l2003o00030000o`3oP000oh000080o`00
1@000?l2003o00kooooo0P000?l:003o00@0003o1`00o`0I0000o`800?l06`000?l00`3oP000003o
0000o`0R0000o`<00?l02`000?l4003o00D0003o3_oooon:0?n001Wooooo000Goooooe80o`000P00
o`0_0?l00080oh001@3o000>ooooodL00?l010000?l30?n00080o`001000o`030000obH00?l00`00
0?l20?l00080003o00<00?l00000o`000?l00P00o`0>ooooo`T0003o0P00o`000`000?l00?l0003o
00020000o`T00?l0F@000?l3003o01@0003o3_oooon:0?n001Wooooo000Goooooe80o`000P00o`0_
0?l00080oh001@3o000>ooooodL00?l010000?l30?n00080o`001000o`030000obH00?l00`000?l2
0?l00080003o00<00?l00000o`000?l00P00o`0>ooooo`T0003o0P00o`000`000?l00?l0003o0002
0000o`T00?l0F@000?l3003o01@0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolU003o
0080003o5`00o`020000o`/00?l01@3oP00]003o00030000o`00o`000?l000@0o`000`000?l2003o
00kooooo10000?l00`00o`00003o0000o`07003o0080003o1@00o`020000o`800?l06@000?l2003o
00L0003o00<00?l00000o`000?l0=0000?l2003o00030000o`00o`000?l000800?l01`000?l2003o
00L0003o3_oooolI0?n000800?l0K`3oP00Iooooo`005ooooon:0?l000kooooo?P00o`040000o`T0
0?l00P3o00000`00o`00o`000?l000020000o`800?l000<0o`000000o`000?l00P3o000E003o0080
003o2@00o`020000o`<00?l02`000?l>ooooo`D0003o1000o`020000o`<00?l00P000?l4003o00<0
003o0P00o`0R0000o`D00?l09@000?l2003o0100003o0P00o`0@0000o`koooooRP3oP00Iooooo`00
5ooooon:0?l000kooooo?P00o`040000o`T00?l00P3o00000`00o`00o`000?l000020000o`800?l0
00<0o`000000o`000?l00P3o000E003o0080003o2@00o`020000o`<00?l02`000?l>ooooo`D0003o
1000o`020000o`<00?l00P000?l4003o00<0003o0P00o`0R0000o`D00?l09@000?l2003o0100003o
0P00o`0@0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo?P00o`040000o`D00?l00P3o
0002003o00<0003o0P00o`040000o``00?l00P000?lG003o00@0003o00<00?l00000o`000?l01`00
0?l2003o00kooooo1@000?l4003o00<0003o2000o`030000o`800?l00P000?l3003o06/0003o3_oo
oolh0?n000030?l0003oP000oh0004l0oh006Oooool001OoooooRP3o000>oooooch00?l010000?l5
003o0080o`000P00o`030000o`800?l010000?l<003o0080003o5`00o`040000o`03003o00000?l0
003o00L0003o0P00o`0>ooooo`D0003o1000o`030000o`P00?l00`000?l2003o0080003o0`00o`1[
0000o`kooooo>03oP0000`3o0000oh000?n0001?0?n001Wooooo000GooooogX0o`000`00o`0=0?l0
00kooooo>`00o`000`000?l00?l0003o00040000o`L00?l00P000?l20?l00003003o00000?l0003o
00@0003o0`00o`020000o`800?l00P000?lP003o00P0003o1000o`0>ooooo`800?l00`000?l2003o
0180003o0P00o`1^0000o`kooooo>`3oP0020000odd0oh006Oooool001OoooooNP3o0003003o00d0
o`003_oooolk003o00030000o`00o`000?l000@0003o1`00o`020000o`80o`0000<00?l00000o`00
0?l010000?l3003o0080003o0P00o`020000ob000?l020000?l4003o00kooooo0P00o`030000o`80
0?l04P000?l2003o06h0003o3_oooolk0?n00080003oC@3oP00Iooooo`005ooooolR0?l00080oh00
?@3o0002003o02L0o`003_oooolk003o00T0003o0`00o`040000o`80o`0000<0003o003o0000o`00
0P000?l7003o00@0003o4@00o`020000o`/00?l01`000?l7003o00kooooo0P00o`070000o`800?l0
4@000?l2003o01L0003o1000o`0l0000o`@00?l040000?l>ooooohX0oh006Oooool001Oooooo8P3o
00020?n003d0o`000P00o`0W0?l000kooooo>`00o`090000o`<00?l010000?l20?l000030000o`00
o`000?l00080003o1`00o`040000oa400?l00P000?l;003o00L0003o1`00o`0>ooooo`800?l01`00
0?l2003o0140003o0P00o`0G0000o`@00?l0?0000?l4003o0100003o3_oooon:0?n001Wooooo000G
ooooof40o`000P00o`0R0?l000030?n0003o0000o`000080o`003_oooolL003o0080003o0P00o`02
0000oaL00?l01`000?l7003o0080003o0P00o`020000o`<00?l00P000?l5003o00L0003o1`00o`02
0000o`@00?l00P000?l3003o0080003o4000o`020000o`D00?l03_ooool2003o0100003o0P00o`08
0000o`800?l050000?l2003o00<0003o0P00o`0P0000o`800?l06P000?l2003o00T0003o0P3o0007
0000o`koooooN03oP0020?l00100oh006Oooool001OoooooH@3o0002003o00030?l00000o`000?l0
02@0o`003_oooolN003o0080003o6@00o`090000o`<00?l00P000?l4003o0080003o00<00?l00000
o`000?l00P000?l2003o00030000o`00o`000?l000800?l010000?l8003o0080003o1000o`020000
oa400?l00P000?l9003o00kooooo4P000?l2003o02<0003o0P00o`150000o`80oh000P3o00070000
o`koooooN03oP0020?l00100oh006Oooool001OoooooH@3o0002003o00030?l00000o`000?l002@0
o`003_oooolN003o0080003o6@00o`090000o`<00?l00P000?l4003o0080003o00<00?l00000o`00
0?l00P000?l2003o00030000o`00o`000?l000800?l010000?l8003o0080003o1000o`020000oa40
0?l00P000?l9003o00kooooo4P000?l2003o02<0003o0P00o`150000o`80oh000P3o00070000o`ko
ooooN03oP0020?l00100oh006Oooool001OoooooRP3o000>ooooocD00?l00P000?l2003o00T0003o
2@00o`070000o`L00?l010000?l8003o00@0003o0P00o`020000oa<00?l00P000?l7003o00kooooo
10000?l7003o00L0003o0P00o`0Q0000o`@00?l04P000?l20?l000P0003o0P00o`020000o`800?l0
;P000?l>ooooohX0oh006Oooool001OoooooRP3o000>ooooocD00?l00P000?l2003o00T0003o2@00
o`070000o`L00?l010000?l8003o00@0003o0P00o`020000oa<00?l00P000?l7003o00kooooo1000
0?l7003o00L0003o0P00o`0Q0000o`@00?l04P000?l20?l000P0003o0P00o`020000o`800?l0;P00
0?l>ooooohX0oh006Oooool001OoooooRP3o000>ooooob000?l00P000?lG003o00T0003o2@00o`07
0000o`L00?l00P000?l20?l000030000o`00o`000?l000D00?l020000?lL003o00kooooo10000?l5
003o00T0003o0P00o`0S0000o`800?l04P000?l20?n002`0003o0P00o`0>0000o`koooooRP3oP00I
ooooo`005ooooon:0?l000kooooo8000o`020000oaL00?l02@000?l9003o00L0003o1`00o`020000
o`80o`0000<0003o003o0000o`001@00o`080000oa`00?l03_ooool40000o`D00?l02@000?l2003o
02<0003o0P00o`0B0000o`80oh00;0000?l2003o00h0003o3_oooon:0?n001Wooooo000GooooohX0
o`003_oooolN003o00@0003o6@00o`070000o`800?l000<0003o003o0000o`000P000?l2003o00T0
003o1`00o`030000ob800?l00P000?l7003o00kooooo10000?l<003o0080003o0P00o`030000o`80
0?l040000?l30?n000H0003o0`00o`020000o`800?l05`000?l50?n00100003o0P3oP00R0000o`ko
oooo0P3oP002003o07/0oh000P00o`090?n001Wooooo000GooooofH0o`000P00o`0R0?l000kooooo
7P00o`020000oa000?l01@000?l4003o00T0003o1@00o`040000o`D00?l00P000?l3003o00H0003o
0P00o`000`000?l00?l0003o000N003o0080003o2@00o`0>ooooo`800?l00P000?l<003o00L0003o
1000o`0J0000o`@00?l040000?l20?l002D0003o0P00o`0G0000o`koooooO`3oP002003o00T0oh00
6Oooool001OoooooIP3o0002003o0280o`003_oooolN003o0080003o4000o`050000o`@00?l02@00
0?l5003o00@0003o1@00o`020000o`<00?l01P000?l2003o00030000o`00o`000?l001h00?l00P00
0?l9003o00kooooo0P00o`020000o``00?l01`000?l4003o01X0003o1000o`0@0000o`80o`009@00
0?l2003o01L0003o3_oooomo0?n000800?l02@3oP00Iooooo`005ooooon:0?l000kooooo7P00o`06
0000oaP00?l020000?l5003o00T0003o0`00o`080000oaX00?l02`000?l7003o00kooooo10000?l<
003o00L0003o0P00o`0B0000o`030?n000000?l0003o00H0003o2000o`0f0000o`800?l01@000?l2
003o00h0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolN003o00H0003o6000o`080000
o`D00?l02@000?l3003o00P0003o6P00o`0;0000o`L00?l03_ooool40000o``00?l01`000?l2003o
0180003o00<0oh000000o`000?l01P000?l8003o03H0003o0P00o`050000o`800?l03P000?l>oooo
ohX0oh006Oooool001OoooooRP3o000>oooooah00?l01P000?lA003o0080003o1`00o`040000o`T0
0?l00P000?l00`00o`00003o0000o`020000o`<00?l020000?lN003o00L0003o1`00o`0>ooooo`80
003o0P00o`000`000?l00?l0003o00020000o`<00?l02`000?l5003o01H0003o0P00o`000`000?l0
0?l0003o0007003o02l0003o00<00?l00000o`000?l06@000?l>ooooohX0oh006Oooool001Oooooo
RP3o000>oooooah00?l01P000?lA003o0080003o1`00o`040000o`T00?l00P000?l00`00o`00003o
0000o`020000o`<00?l020000?lN003o00L0003o1`00o`0>ooooo`80003o0P00o`000`000?l00?l0
003o00020000o`<00?l02`000?l5003o01H0003o0P00o`000`000?l00?l0003o0007003o02l0003o
00<00?l00000o`000?l06@000?l>ooooohX0oh006Oooool001Oooooo?@3o00020?n004/0o`003_oo
ooln003o0080003o2`00o`030000o`80oh000P000?l3003o0080003o0P00o`040000oah00?l00P00
0?l<003o00kooooo1@000?l6003o00<0003o0P00o`070000o`L00?l050000?l2003o00030000o`00
o`000?l000L00?l090000?l2003o00T0003o00<00?l00000o`000?l01@000?l4003o0100003o3_oo
oolk0?n00080o`00C@3oP00Iooooo`005ooooolm0?l00080oh00B`3o000>oooooch00?l00P000?l;
003o00<0003o0P3oP0020000o`<00?l00P000?l2003o00@0003o7P00o`020000o``00?l03_ooool5
0000o`H00?l00`000?l2003o00L0003o1`00o`0D0000o`800?l000<0003o003o0000o`001`00o`0T
0000o`800?l02@000?l00`00o`00003o0000o`050000o`@00?l040000?l>oooooc/0oh000P3o001=
0?n001Wooooo000GooooohX0o`003_ooooln003o00@0003o1`00o`090000o`D00?l01P000?lL003o
00@0003o3000o`0>ooooo`80003o0P00o`000`000?l00?l0003o0005003o00P0003o3000o`020000
o`800?l02P000?l2003o0080003o0P00o`000`000?l00?l0003o0007003o00d0003o0P00o`0W0000
o`D00?l040000?l>oooooa/0oh000P3o00000`00o`00oh000?n0001Z0?n001Wooooo000GooooohX0
o`003_ooooll003o0080003o0P00o`020000o`L00?l010000?l00`00o`00003o0000o`020000o`<0
0?l00P000?l2003o00@0003o8`00o`020000o`L00?l03_ooool40000o`X00?l01P000?l7003o00T0
003o00<00?l00000o`000?l02`000?l2003o00030000o`00o`000?l000L00?l03@000?l2003o01D0
003o0`00o`060000o`D00?l01`000?l2003o0100003o3_ooool@0?n00080003o0P00o`1V0?n00080
0?l03P3oP00Iooooo`005ooooon:0?l000kooooo?000o`020000o`800?l00P000?l7003o00@0003o
00<00?l00000o`000?l00P000?l3003o0080003o0P00o`040000ob<00?l00P000?l7003o00kooooo
10000?l:003o00H0003o1`00o`090000o`03003o00000?l0003o00/0003o0P00o`000`000?l00?l0
003o0007003o00d0003o0P00o`0E0000o`<00?l01P000?l5003o00L0003o0P00o`0@0000o`kooooo
403oP0020000o`800?l0IP3oP002003o00h0oh006Oooool001OoooooRP3o000>oooooa`00?l00P00
0?lN003o00H0003o1@00o`090000obL00?l010000?l2003o00D0003o1`00o`0>ooooo`@0003o0`00
o`020000o`800?l000<0003o003o0000o`001P00o`000`000?l00?l0003o0004003o00L0003o0P00
o`0>0000o`L00?l00P000?l3003o00d0003o0P00o`0@0000o`03003o00000?l0003o0080003o0`00
o`020000o`800?l010000?l00`00o`00003o0000o`0I0000o`koooooRP3oP00Iooooo`005ooooon:
0?l000kooooo7000o`020000oah00?l01P000?l5003o00T0003o9`00o`040000o`800?l01@000?l7
003o00kooooo10000?l3003o0080003o0P00o`000`000?l00?l0003o0006003o00030000o`00o`00
0?l000@00?l01`000?l2003o00h0003o1`00o`020000o`<00?l03@000?l2003o0100003o00<00?l0
0000o`000?l00P000?l3003o0080003o0P00o`040000o`03003o00000?l0003o01T0003o3_oooon:
0?n001Wooooo000GooooohX0o`003_ooooln003o00L0003o0P00o`020?l000D0003o3@00o`070000
o`800?l000<0003o003o0000o`005P00o`050000o`L00?l03_ooool40000oa000?l000<0003o003o
0000o`0010000?l00`00o`00003o0000o`040000o`800?l040000?l:003o00@0003o0P00o`000`00
0?l00?l0003o00040000o`800?l07P000?l2003o01`0003o3_oooon:0?n001Wooooo000GooooohX0
o`003_ooooln003o00L0003o0P00o`020?l000D0003o3@00o`070000o`800?l000<0003o003o0000
o`005P00o`050000o`L00?l03_ooool40000oa000?l000<0003o003o0000o`0010000?l00`00o`00
003o0000o`040000o`800?l040000?l:003o00@0003o0P00o`000`000?l00?l0003o00040000o`80
0?l07P000?l2003o01`0003o3_oooon:0?n001Wooooo000Goooooh40o`000P3oP0070?l000kooooo
=@00o`020000o`D00?l00P000?l2003o00@0003o00<00?l00000o`000?l02`000?l7003o00@0003o
00<00?l00000o`000?l00P00o`020000oaL00?l01`000?l2003o00030000o`00o`000?l000800?l0
3_ooool40000o`D00?l00P000?l7003o01<0003o0P00o`090000o`800?l00`000?l4003o0080003o
0`00o`0;0000o`800?l0?P000?l>ooooohX0oh006Oooool001OoooooP@3o00020?n000L0o`003_oo
oole003o0080003o1@00o`020000o`800?l010000?l00`00o`00003o0000o`0;0000o`L00?l01000
0?l00`00o`00003o0000o`02003o0080003o5`00o`070000o`800?l000<0003o003o0000o`000P00
o`0>ooooo`@0003o1@00o`020000o`L00?l04`000?l2003o00T0003o0P00o`030000o`@00?l00P00
0?l3003o00/0003o0P00o`0n0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo?000o`02
0000o`800?l010000?l50?n000D0003o0P00o`020000o`T00?l00`000?l4003o0080003o9@00o`0>
oooooaD00?l040000?l2003o00h0003o0P00o`040000o`<00?l02`000?l2003o03h0003o3_oooon:
0?n001Wooooo000GooooohX0o`003_ooooll003o0080003o1000o`020000o`030?n000000?l0003o
0080003o0P3oP00>003o00@0003o7P00o`020000o``00?l03_ooool20000o`800?l000<0003o003o
0000o`001@000?l4003o0080003o0`00o`0P0000o`800?l00P000?l5003o00d0003o0P00o`0G0000
o`<00?l08P000?l>ooooog<0oh0000<0o`000?n0003oP000503oP00Iooooo`005ooooon:0?l000ko
oooo?000o`020000o`@00?l00P000?l00`3oP000003o0000o`020000o`80oh003P00o`040000oah0
0?l00P000?l<003o00kooooo0P000?l2003o00030000o`00o`000?l000D0003o1000o`020000o`<0
0?l080000?l2003o0080003o1@00o`0=0000o`800?l05`000?l3003o0280003o3_oooomc0?n00003
0?l0003oP000oh0001@0oh006Oooool001OoooooC@3o00020?n003/0o`003_ooooll003o00T0003o
103oP0020000ocX00?l00P000?l2003o00kooooo10000?l3003o00D0003o0P00o`040000o`L00?l0
8P000?l3003o01d0003o0P00o`0/0000o`koooooAP3oP0020?l00480oh006Oooool001OoooooC@3o
00020?n003/0o`003_ooooll003o00T0003o103oP0020000ocX00?l00P000?l2003o00kooooo1000
0?l3003o00D0003o0P00o`040000o`L00?l08P000?l3003o01d0003o0P00o`0/0000o`koooooAP3o
P0020?l00480oh006Oooool001OoooooO`3o00020?n000T0o`003_ooooll003o00/0003o0P00o`02
0?n000h00?l01@000?l[003o00kooooo1@000?l2003o0080003o1@00o`060000o`03003o00000?l0
003o00800?l08`000?l2003o01/0003o0P00o`070000o`800?l02@000?l00`00o`00003o0000o`0I
0000o`koooooRP3oP00Iooooo`005ooooomo0?l00080oh002@3o000>oooooc`00?l02`000?l2003o
0080oh003P00o`050000ob/00?l03_ooool50000o`800?l00P000?l5003o00H0003o00<00?l00000
o`000?l00P00o`0S0000o`800?l06`000?l2003o00L0003o0P00o`090000o`03003o00000?l0003o
01T0003o3_oooon:0?n001Wooooo000Gooooo`80oh00O@3o00020?n000T0o`003_ooooll003o00/0
003o3@00o`030000o`@00?l00P000?l5003o00<0003o9000o`0>ooooo`D0003o1000o`020000o`<0
0?l02@000?l4003o01X0003o0P00o`0R0000o`@00?l0;0000?l>ooooocd0oh000P3o001;0?n001Wo
oooo000GooooohX0o`003_oooolk003o00`0003o1P3oP0000`3o00000?l0003o00020000o`800?l0
2@000?l3003o0080003o0P00o`000`000?l00?l0003o000R003o00kooooo10000?l00`00o`00003o
0000o`0@0000o`800?l06@000?l2003o02L0003o0P00o`0C0000o`@00?l05@000?l>ooooohX0oh00
6Oooool001OoooooRP3o000>oooooc/00?l030000?l60?n000030?l00000o`000?l00080003o0P00
o`090000o`<00?l00P000?l2003o00030000o`00o`000?l002800?l03_ooool40000o`03003o0000
0?l0003o0100003o0P00o`0I0000o`800?l09`000?l2003o01<0003o1000o`0E0000o`koooooRP3o
P00Iooooo`005ooooon:0?l000kooooo>`00o`0@0000o`T00?l030000?lY003o00kooooo2`000?l0
0`00o`00003o0000o`0D0000o`800?l05@000?l3003o04d0003o3_ooool40?n000<00?l0P`3oP00I
ooooo`005ooooon:0?l000kooooo>`00o`0@0000o`T00?l030000?lY003o00kooooo2`000?l00`00
o`00003o0000o`0D0000o`800?l05@000?l3003o04d0003o3_ooool40?n000<00?l0P`3oP00Ioooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.00617655 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13825 -12 -4.5 ]
[-0.0125 .13825 0 4.5 ]
[-0.0125 .26178 -12 -4.5 ]
[-0.0125 .26178 0 4.5 ]
[-0.0125 .38531 -12 -4.5 ]
[-0.0125 .38531 0 4.5 ]
[-0.0125 .50884 -12 -4.5 ]
[-0.0125 .50884 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13825 m
1 .13825 L
s
0 .26178 m
1 .26178 L
s
0 .38531 m
1 .38531 L
s
0 .50884 m
1 .50884 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13825 m
.00625 .13825 L
s
[(20)] -0.0125 .13825 1 0 Mshowa
0 .26178 m
.00625 .26178 L
s
[(40)] -0.0125 .26178 1 0 Mshowa
0 .38531 m
.00625 .38531 L
s
[(60)] -0.0125 .38531 1 0 Mshowa
0 .50884 m
.00625 .50884 L
s
[(80)] -0.0125 .50884 1 0 Mshowa
.125 Mabswid
0 .0456 m
.00375 .0456 L
s
0 .07648 m
.00375 .07648 L
s
0 .10736 m
.00375 .10736 L
s
0 .16913 m
.00375 .16913 L
s
0 .20001 m
.00375 .20001 L
s
0 .23089 m
.00375 .23089 L
s
0 .29266 m
.00375 .29266 L
s
0 .32354 m
.00375 .32354 L
s
0 .35443 m
.00375 .35443 L
s
0 .41619 m
.00375 .41619 L
s
0 .44707 m
.00375 .44707 L
s
0 .47796 m
.00375 .47796 L
s
0 .53972 m
.00375 .53972 L
s
0 .5706 m
.00375 .5706 L
s
0 .60149 m
.00375 .60149 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13825 m
1 .13825 L
s
.99375 .26178 m
1 .26178 L
s
.99375 .38531 m
1 .38531 L
s
.99375 .50884 m
1 .50884 L
s
.125 Mabswid
.99625 .0456 m
1 .0456 L
s
.99625 .07648 m
1 .07648 L
s
.99625 .10736 m
1 .10736 L
s
.99625 .16913 m
1 .16913 L
s
.99625 .20001 m
1 .20001 L
s
.99625 .23089 m
1 .23089 L
s
.99625 .29266 m
1 .29266 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .35443 m
1 .35443 L
s
.99625 .41619 m
1 .41619 L
s
.99625 .44707 m
1 .44707 L
s
.99625 .47796 m
1 .47796 L
s
.99625 .53972 m
1 .53972 L
s
.99625 .5706 m
1 .5706 L
s
.99625 .60149 m
1 .60149 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .57579 L
.06452 .57579 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .57579 L
.06452 .57579 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .52484 L
.22581 .52484 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .52484 L
.22581 .52484 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .57665 L
.3871 .57665 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .57665 L
.3871 .57665 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .46782 L
.54839 .46782 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .46782 L
.54839 .46782 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .5127 L
.70968 .5127 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .5127 L
.70968 .5127 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .48928 L
.87097 .48928 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .48928 L
.87097 .48928 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .36961 L
.09677 .36961 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .36961 L
.09677 .36961 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .32365 L
.25806 .32365 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .32365 L
.25806 .32365 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .25297 L
.41935 .25297 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .25297 L
.41935 .25297 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .39649 L
.58065 .39649 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .39649 L
.58065 .39649 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .38023 L
.74194 .38023 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .38023 L
.74194 .38023 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .47671 L
.90323 .47671 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .47671 L
.90323 .47671 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .32192 L
.12903 .32192 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .32192 L
.12903 .32192 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .19964 L
.29032 .19964 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .19964 L
.29032 .19964 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .52332 L
.45161 .52332 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .52332 L
.45161 .52332 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .17103 L
.6129 .17103 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .17103 L
.6129 .17103 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .09428 L
.77419 .09428 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .09428 L
.77419 .09428 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .43682 L
.93548 .43682 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .43682 L
.93548 .43682 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .46565 L
.16129 .46565 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .46565 L
.16129 .46565 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .41969 L
.32258 .41969 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .41969 L
.32258 .41969 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .25363 L
.48387 .25363 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .25363 L
.48387 .25363 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .60332 L
.64516 .60332 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .60332 L
.64516 .60332 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .33623 L
.80645 .33623 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .33623 L
.80645 .33623 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .33579 L
.96774 .33579 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .33579 L
.96774 .33579 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00?_ooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000<Oooool003oooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo0000033ooooo000oooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000<?ooool003oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000aooooo`00?oooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo03;ooooo000nooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo037ooooo000oooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`00037ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Noooooooo0000IOl0000>ooooo`007_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00co
oooo000Dooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`coogl02ol0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000>ooooo`005?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001Cooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_o
o`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0
01kooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool0
00_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00003_ooool001ko
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool0
00_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000Wo
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00Wooooo0ol0000>ooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo
00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_o
o`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002Oooool<ool000_o0?l0
3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl0
2oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`00
2ol0o`0<o`00o`coogl02Oooool3o`0000kooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool03?ooool000gooooo1Ol00003ooooo`;o00001oooool00ol0
003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo
00cooooo000>ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<
ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooo
oooo00cooooo000?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<
ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooo
oooo00cooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04
ooooo`?o00002?l007l<ool000_o0?l03?l00?l<oomo00[o001o3?oo000;o`3o00co003o3?ooO`0;
o`00O`_oo`003?l0o`0;o`00o`coogl02ol007l;ool000co0?l02ol00?l=oomo00[o001o3?oo000<
o`3o00[o001o3OooO`0:o`00O`coo`002ol0o`0<o`00o`coogl02?l007l4o`0000kooooo000=oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02ooo
ool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?oo
ool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo
3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003ooooo
ooooo`0<ooooo`003_ooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool0
00_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000Wo
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00Wooooo0ol0000>ooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo
00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002Oooool<ool000_o0?l0
3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl0
2oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`00
2ol0o`0<o`00o`coogl02Oooool3o`0000kooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00co0?l02oooool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02ooo
ool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool0
00_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_o
oooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co
0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00co
oooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`00
3?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
00?o0000ooooooooool03?ooool001kooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_oo
ool<ool000co0?l02oooool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0
o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?oo
O`09ooooo`?o00003_ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o
00_ooooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo
00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`0<ooooo`003oooool3o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0013ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`co
o`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool000gooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKo
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool000gooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00006ooooo`?o00002?l007l<ool000_o0?l03?l00?l<oomo
00[o001o3?oo000<o`3o00_o001o3?ooO`0;o`00O`coo`002ol007l<o`00oaKo001o2ooo000=o`3o
00[o001o3OooO`0:o`00O`coo`003?l0o`0:o`00O`googl02_l007l<ool000_o0?l03?l00?l<oomo
00So001o1?l0000>ooooo`003_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o
00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:oooo
o`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooo
ooooool03?ooool000oooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;oooo
o`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool0013o
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKo
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`00
2oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?oo
O`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?oo
ool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<
o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo
00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o
00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKo
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`00
2oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?oo
O`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?oo
ool001kooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<
oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3o`0000kooooo000Noooo
o`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;oooo
o`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`go
ogl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o
3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l0
0?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<
ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Noooo
o`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;oooo
o`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`go
ogl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o
3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<ool000_ooooo3?l0
0?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool<
ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo000Noooo
o`;o00002Oooool<ool000co0?l02oooool<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;oooo
o`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl02_ooool<ool000_o0?l03?l00?l<oomo00Wooooo0ol0000>ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`co
o`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00Sooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003ooooooooo
o`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000co0?l02oooool<oomo
00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`go
o`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Ooo
ool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;
ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;
o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00
oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00
oaKooooo00?o0000ooooooooool03?ooool001kooooo0_l00009ooooo`coo`003?l0o`0;ooooo`co
ogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[o
oooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaCooooo0ol0000>ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo
3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo3Ooo000Fooooo`coogl02ooo
ool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Ooo
ool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;
ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo000;
o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00
oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00
oaKooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool<ool000co
0?l02oooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03Ol00?lFooooo`03
o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl0
2_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo
3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool0
3?ooool001kooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_oo
ool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`003_ooool3
o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=
ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:
ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool03?ooool0
00gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3?oo
000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`003Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool3o`0000So001o3Ooo000Fo`00O`coogl0
2_l007l=ool001Ko001o3?ooO`0;o`00O`coo`002ol007l<o`00oaKo001o2ooo000=o`3o00[o001o
3OooO`0:o`00O`goo`00;?l007l<ool000_o0?l03Ol00?lCo`00O`Co00003_ooool000gooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool001Kooooo
3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l0
2_ooool=oomo00[ooooo3Ooo000/ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`goo`00;?ooool<ool000_o0?l0
3Ol00?lFooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo
3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_oo`003Ol0o`0:ooooo`googl0
2_ooool=ool002cooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`003ooo
ool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_oo
ool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`goo`00;?ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000N
ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;
ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000;
o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08oooo
o`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFoooo
o`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000oooo
ooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`go
o`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`go
o`00;?ooool<ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`00
0?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00
2oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000;o`3o00go003o
5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`005_oo
ool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`coo`005_oo
ool=oomo00[ooooo3Ooo000/ooooo`coo`002ol0o`0=o`00oaKooooo00?o0000ooooooooool03?oo
ool001kooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<
oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool<
ool000_o0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002Oooool=ool0
01Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool0
01Kooooo3OooO`0:ooooo`goo`00;?ooool<ool000_o0?l03Ol00?lDooooo`?o00003_ooool001ko
oooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_o
oooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool<ool000_o
0?l03Ol00?lFooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo
3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo
3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000;o`3o00go003o5_ooool00ol0003ooooo
ooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo
000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo
000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08
ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000F
ooooo`googl02_ooool=ool002cooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]oooo
o`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000;o`3o
00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`go
o`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`go
ogl02_ooool=ool002cooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00
2oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000;o`3o00go003o
5_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`005_oo
ool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_oo
ool=ool002cooooo3?oo000;o`3o00go003o5_ooool00ol0003oooooooooo`0<ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<
o`00oaKooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:oooo
o`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3Ooo000/oooo
o`coo`003?l0o`0Rooooo`03o`000?oooooooooo00cooooo000Nooooo`;o00002Oooool=ool001Ko
oooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[o
oooo3Ooo000/ooooo`coo`003?l0o`0Pooooo`?o00003_ooool001kooooo00?o0000ooooooooool0
2?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`00
5_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo00cooooo
000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo
000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool<ool000co0?l08_oo
ool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`005_ooool<
oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool=
ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooo
ooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFoooo
o`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002go
oooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool<ool000co
0?l08_ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00
5_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl0
2_ooool=ool002cooooo3?oo000<o`3o02;ooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l0
0?lFooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0Rooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<
ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`coo`003?l0o`0R
ooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000/oooo
o`goo`00;Oooool<ool000_ooooo3?l00?lhooooo`googl02_ooool=ool002cooooo3?oo000<o`3o
02;ooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=ool002co
oooo3Ooo000]ooooo`coo`002oooool<o`00ocSooooo3OooO`0:ooooo`goo`00;?ooool<ool000co
0?l08_ooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000Wooooo3Ooo000/ooooo`goo`00
;Oooool<ool000_ooooo3?l00?lhooooo`googl02_ooool=ool002cooooo3?oo000<o`3o023ooooo
0ol0000>ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo
000;ooooo`co003o>?ooool=oomo00[ooooo3Ooo000/ooooo`goo`00;Oooool00ol0003ooooooooo
o`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;
ooooo`co003o>?ooool=oomo00[ooooo3Ooo000/ooooo`goo`00;Oooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;oooo
o`co003o>?ooool=oomo00[ooooo3Ooo000/ooooo`goo`00;Oooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co
003o>?ooool=oomo00[ooooo3Ooo000/ooooo`goo`00;Oooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co003o
>?ooool=oomo00[ooooo3Ooo001Vooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oo
oooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l00?lhooooo`googl02_oo
ool=ool006Kooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=
ool002cooooo3Ooo000]ooooo`coo`002oooool<o`00ocSooooo3OooO`0:ooooo`goo`00I_ooool0
0ol0003oooooooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool0
02gooooo3?oo000;ooooo`co003o>?ooool=oomo00[ooooo3Ooo001Vooooo`03o`000?oooooooooo
00cooooo000>ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool002co
oooo3Ooo000]ooooo`coo`002oooool<o`00ocSooooo3OooO`0:ooooo`goo`00I_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;oooo
o`co003o>?ooool=oomo00[ooooo3Ooo001Vooooo`03o`000?oooooooooo00cooooo000=ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`?o00002?l007l=
ool002co001o3Ooo000]o`00O`coo`002ol007l<o`00ocSo001o3OooO`0:o`00O`goo`00Hol007l4
o`0000kooooo000>ooooo`?o00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l00?lhooooo`googl02_ooool=
ool006Kooooo00?o0000ooooooooool03?ooool000gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool002cooooo3Ooo
000]ooooo`coo`002oooool<o`00ocSooooo3OooO`0:ooooo`goo`00I_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co003o
>?ooool=oomo07gooooo00?o0000ooooooooool03?ooool000kooooo0ol00004ooooo`;o00001ooo
ool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co003o>?oo
ool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=
ool002cooooo3Ooo000]ooooo`coo`002oooool<o`00ocSooooo3OooO`1mooooo`03o`000?oooooo
oooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool0
04oooooo3OooO`1mooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00So
oooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003ooooo
ooooo`0<ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3Ooo
O`1mooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo001V
ooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo0_l00009oooo
o`goo`00I_ooool<ool004oooooo3OooO`1kooooo`?o00003_ooool001kooooo00?o0000oooooooo
ool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`0<ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`00
0?oooooooooo00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Cooo
ool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=
ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0
003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo
00cooooo000Nooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07go
oooo00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=ool006Kooooo
3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooooooo
o`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00cooooo000N
ooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000
ooooooooool03?ooool001kooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?oooo
o`googl0OOooool00ol0003oooooooooo`0<ooooo`007_ooool2o`0000Wooooo3Ooo001Vooooo`co
o`00Coooool=oomo07_ooooo0ol0000>ooooo`007_ooool00ol0003oooooooooo`08ooooo`goo`00
I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00cooooo000Nooooo`03o`000?oo
oooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool03?oo
ool001kooooo00?o0000ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool0
01kooooo00?o0000ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001ko
oooo00?o0000ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo
00?o0000ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o
0000ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o0000
ooooooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooo
ooooool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool0e_ooool=oomo07gooooo00?o0000ooooooooool03?ooool001kooooo0_l0003Gooooo`googl0
Noooool3o`0000kooooo000Nooooo`03o`000?oooooooooo0=Kooooo3OooO`1mooooo`03o`000?oo
oooooooo00cooooo000Nooooo`03o`000?oooooooooo0?ooooooHOooool00ol0003oooooooooo`0<
ooooo`007_ooool00ol0003oooooooooo`3oooooof7ooooo00?o0000ooooooooool03?ooool001ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`007_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00cooooo000Noooooooo0000IOl0000>ooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00?_ooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000<Oooool003oooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo0000033ooooo000oooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000<?ooool003oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000aooooo`00?oooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo03;ooooo000nooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo037ooooo000oooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`00037ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.171904, -8.51292, \
0.0174717, 0.456245}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.00593394 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13339 -12 -4.5 ]
[-0.0125 .13339 0 4.5 ]
[-0.0125 .25207 -12 -4.5 ]
[-0.0125 .25207 0 4.5 ]
[-0.0125 .37075 -12 -4.5 ]
[-0.0125 .37075 0 4.5 ]
[-0.0125 .48943 -12 -4.5 ]
[-0.0125 .48943 0 4.5 ]
[-0.0125 .60811 -18 -4.5 ]
[-0.0125 .60811 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13339 m
.00625 .13339 L
s
[(20)] -0.0125 .13339 1 0 Mshowa
0 .25207 m
.00625 .25207 L
s
[(40)] -0.0125 .25207 1 0 Mshowa
0 .37075 m
.00625 .37075 L
s
[(60)] -0.0125 .37075 1 0 Mshowa
0 .48943 m
.00625 .48943 L
s
[(80)] -0.0125 .48943 1 0 Mshowa
0 .60811 m
.00625 .60811 L
s
[(100)] -0.0125 .60811 1 0 Mshowa
.125 Mabswid
0 .04438 m
.00375 .04438 L
s
0 .07405 m
.00375 .07405 L
s
0 .10372 m
.00375 .10372 L
s
0 .16306 m
.00375 .16306 L
s
0 .19273 m
.00375 .19273 L
s
0 .2224 m
.00375 .2224 L
s
0 .28174 m
.00375 .28174 L
s
0 .31141 m
.00375 .31141 L
s
0 .34108 m
.00375 .34108 L
s
0 .40042 m
.00375 .40042 L
s
0 .43009 m
.00375 .43009 L
s
0 .45976 m
.00375 .45976 L
s
0 .5191 m
.00375 .5191 L
s
0 .54877 m
.00375 .54877 L
s
0 .57844 m
.00375 .57844 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13339 m
1 .13339 L
s
.99375 .25207 m
1 .25207 L
s
.99375 .37075 m
1 .37075 L
s
.99375 .48943 m
1 .48943 L
s
.99375 .60811 m
1 .60811 L
s
.125 Mabswid
.99625 .04438 m
1 .04438 L
s
.99625 .07405 m
1 .07405 L
s
.99625 .10372 m
1 .10372 L
s
.99625 .16306 m
1 .16306 L
s
.99625 .19273 m
1 .19273 L
s
.99625 .2224 m
1 .2224 L
s
.99625 .28174 m
1 .28174 L
s
.99625 .31141 m
1 .31141 L
s
.99625 .34108 m
1 .34108 L
s
.99625 .40042 m
1 .40042 L
s
.99625 .43009 m
1 .43009 L
s
.99625 .45976 m
1 .45976 L
s
.99625 .5191 m
1 .5191 L
s
.99625 .54877 m
1 .54877 L
s
.99625 .57844 m
1 .57844 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .59853 L
.2381 .59853 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .59853 L
.2381 .59853 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .48585 L
.47619 .48585 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .48585 L
.47619 .48585 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .51709 L
.71429 .51709 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .51709 L
.71429 .51709 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00DOooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`0003gooooo001Booooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0??ooool005;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol0000mooooo`00D_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
03kooooo001Booooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000?_ooool0057ooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l0000n
ooooo`00D_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0??ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool0027oooooool0001Uo`0000_ooooo000Qooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`006?ooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00002oooool0
01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`005oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>ooooo`?o0000
2oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000?ooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl03Oooool4o`0000_ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
3ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool001;ooooo0ol00003ooooo`;o
00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000;ooooo
00Co0000oooooooooooo00001_ooool3o`0000koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0=ooooo`Co00002oooool0013ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`?o00003_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo00gooooo1?l0000;ooooo`004?ooool4o`0000?ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>
ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0017ooooo0ol00004ooooo`;o00001oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool3o`0000koooooA?oo001UooooodCo003o4?oooom5oomo
00gooooo1?l0000;ooooo`004Oooool3o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooo
oooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo001Uoooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCo
o`00^Ooooom5oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00
^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002ioooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo002iooooodGo
ogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo002iooooodGoogl0
3_ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
0;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`002oooool3o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`3ooooo
o`coooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0?oooooo3?oooom5oomo013ooooo00?o0000ooooooooool02Oooool000cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`?o0000
oooooomNooooo`Co00002oooool000cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000;ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001oooooooo`0006Go00002oooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0057ooooo0ol0
001Aooooo`Go0000D?ooool3o`0005?ooooo0ol0000mooooo`00D_ooool00ol0003oooooooooo`1A
ooooo`04o`000?ooooooooooo`0004oooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`00
0?oooooooooo03cooooo001Booooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`1>ooooo`Go0000?Oooool005;ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`1@ooooo`;o0000DOooool01?l0003oooooooooool0000nooooo`00D_ooool0
0ol0003oooooooooo`1@ooooo`05o`000?ooooooooooooooool00000Doooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooo000003kooooo001Aooooo`;o0000D_ooool01Ol0003ooooooooooooo
oooo000004oooooo00Go0000ooooooooooooooooo`00001Booooo`;o0000?_ooool005;ooooo00?o
0000ooooooooool0DOooool3o`00057ooooo0ol0001Dooooo`03o`000?oooooooooo03cooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.00675159, -8.86097, \
0.0118357, 0.474898}}],

Cell[BoxData[
    \(90.4089154089154`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #5 (32 clusters per band)", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 5;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C3683BF5023190A
6748E49D2E3E1100
8731888352391519
763BCF94382D040A
7A546F7F4D3C2B1D
7730FFB6422C151C
4F36938530290C08
5C37A78041321C20
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
336D6D7381735D55
A8D3D6F3FFA19859
4D3759486B354E32
270E150012070E1B
3E272A1A2B1A2526
3E536F939FAA9675
4F7E82A7A492A26F
928DC59AAB9AC282
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F2B632D51536A52
1F5900088509256B
1F390A3215167503
8A1705701B022D1F
5B4B643C19633806
FF3536B92F365C50
A127C6511EFF1E16
4D34221679162658
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
24E91260AA34502F
79A40AFF4D12D421
8D8111BA6A6A880E
4A9419B9496ED70A
950B0ED90458C113
3E254439178C4800
43032F5F063D6F25
2A21444B121A1302
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
571E39232B244231
2C192F2A5242522F
307167AB80966E47
C8CFECE0CA836F2E
442D403D37393032
270C090002081524
4C211C14050E131F
FFAAC498A27C765E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
14322B413A272818
12170D1414101410
1C19191509060015
1F13212238282623
1F36344C5F484D27
263629313A1F2F21
180C0A1213200E1B
525DBAFFC8A38844
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A6C350A4E591D25
2E455F6349253423
20FF1A2E9C203440
708F3EF94712CA1D
5DD82B7AA7616622
5BC81AE4723BFC1E
8E4217D53256B819
3300376000215739
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EA2F0ECA06176B21
8C706D6E26C32505
CF3B43EA285D777D
D91B7FA20DFF2531
5631A27212C13D9A
91024B80318D3880
0A098F010CB61360
035828004D270605
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C293E6A52426F62
10483F48214E5255
ABAE6CFF9DA4DABA
1A3951444B683745
9DBE77EE889BB1CB
0034213E1B461C2D
61542F8A5D4E7B67
63787E93A293B4BC
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
14131314252A2C1D
1813181419121711
16251C201D2B2213
181B13131B19201F
1420171411181713
222317090A16160C
19150F050B000511
413E4D364B86FFAA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A732555D37442A2D
5A28E91823A32023
858A9931C55C1B95
656DE81978A96544
2563D30CD06D389D
34B16A0EFF4A6A7E
24549C3A865B8956
1235202921245B00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CA6320FF2D73D814
6A77508C4DE7BA16
70113CBD078FDF28
3810543E0688310C
131451320B4C2B21
21662B00312F0307
124A741E395B2100
5D9A088A5A27821F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D1D0D25532B9065
2D0E000D193EA148
1E0D1D105B56885A
19101030553BF571
260D1E136462AA3E
182311323C47FF79
24102806315E9E42
3A3C2D1C6C55A95C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A2F331C1C1B1E12
10081207110C1B1C
180A00050111131D
1D151E2210202418
37373E3628202021
342C4427352C2E1A
11192031152E2623
F7FF814A563A4447
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
42C5B709FF4B22A1
32B1BE1BC57AA257
2496B023E1446D89
07D34517F61B8578
37454E696227C12A
3062071E810E5E4F
52351D691E148C00
2D1F9A16217B3500
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A339F0501CFF1B22
BC2FB1887B8D4FD2
C023B65C53E0346A
2F16D91D6EC71CC9
5A534841B0601DA7
081A7E093C91404C
253E0F0F75000A7A
8214076D30115345
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B4D5683A34370923
CB922B3E0D1E1424
96A6772D1F2C001B
D8D42D3D30290E2B
9E8067402830051C
FFC63442143A111A
CAD77D57374A2033
EAE96B802F443B3C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9C33876473BD297E
0B03BB003DD410A3
234218129632079A
0B3530012F4E2D19
3C34153045000B3D
42B5122D55213416
EE561CFF1F1D7513
5028883B41853B85
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A1F0A0B040F232B
240F01000708121E
3E282837332F3548
7A867C7773786D6C
99AFA4CAA9C9A5B0
ADC0D1E7D9D2B0B9
A4CBBFCCB8BCA49E
BEC5B0C5B9FFD3CE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19550F14861A1D7B
1F7921253F285215
8837117E33194230
5A90514A4A64361E
EC4721FF1731853E
B54B918D26EB2D1F
964575B22E837C8D
081C840039951327
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C27151B142C1D47
5979667E66737289
D3E7E3D8D0A09283
B6BFA1BBE8FFD8B5
7B77897F85B4A996
3C34333F4C545E4A
1D2A001214150D2D
7962576A5B89677C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F13252C33372114
15141612121B1917
0F0F02130E110A10
04040300090B1214
09090309000B0B0B
14090E0F0D161A0A
191821190A1C1B13
4C3D3862FFA13638
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
316C97615F39830E
1CFF4234FD15455C
22B63E8E9D14F113
4670388A9812B124
1FAE095FA824B01B
631611AA1518CD00
44423228445F3B10
366C161235120621
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
424325441D2F5E03
DD1C1C9912294B16
8F29C04800BF2712
DB17799550714990
CA14D05D2FFF2648
611BE2386EB815C6
85367A4E8391208F
151F0E2354063B49
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
609475558C66A767
9A8D979E4E84B34D
3E3F6F006C565340
B9AEC0A8A99DEC78
513F6E0F60667214
BA98D095B26EF980
56697D2330848A5C
A5E8E0FFA6EBC4AA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
445349413541514F
5965413323353E3B
32461920040C0A16
30260F0600030402
1B1E0A1308150B16
2223232925252436
22342D2A494A5667
8E596379677BC4FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E31681725872917
240C384E1E2B572C
36434F141A5F170D
123091112D5F0D13
3DFF571CAE27094A
3C76905F484E741E
25C75D2FE23F4168
480030980B29930A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36F22883E21FE629
653624C75917FF0B
2F7D23498C3F682C
46110D7B131CA706
6E2E3A2D275B1813
3925AF2E0B643200
948D7E3E853F1545
157B4F3090265624
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
20376D446AB85836
1A364F49FF7E4057
06163A1B494B3607
1A133D37615C1726
00164818553A241D
152A392BC2802936
35315D6ABE6D4F3C
2D3540497A7E313E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3F51395531231B23
39333F383A23292B
1A312F3132444236
000B13151A1E2C23
060604080207080D
17090A0B0A030D1C
2623202D2F232018
74CEFFBF4D4D3039
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26133E4C1E3A5028
326D380C3C460709
1838752F3A383202
21FF2310C51F0F42
2684787B752AB400
25CB4B5CEC12533D
12D02484AB15DC10
4454060B32420F14
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9426DDB644FF67F9
D10C8F9D5BF037A6
1713EE301FEF1B95
402245367B2E26CC
044F5905377C2C46
44442D324F00134F
2AEA1A2A6033350D
E12E8D8415BE191D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool7ofa/K0Oo=SHf1on3Ph<7okno_`OoD51@1_lS8b<7oaTI6@Ko
2PX:1_ooool7oc<c<`koKFe]1omcLg<7oh61P@KoLg=c1omMGEd6oeEEE@Kooooo1ol?3`l7ob/[:`Oo
Hf=S1ol];Bd6oe5AD@OoDe=C1omZJVX6oe9BDPKooooo1olT92@7onWYj@Oo4Q8B1omPH606ojZZZPOo
=3@d1om@D506obl_;`Kooooo1omGEeL7oahN7POo>CTi1_lS8b<7ob/[:`Oo92@T1om2@T86oc4a<@Ko
oooo1olD51@7oc8b<POo:b/[1_m1@D47ocXj>POo9bLW1olX:2P6oaPH60Kooooo1olJ6QX7ofa/K0Ko
=CDe1ol:2PX7odi>CPOoFEUI1olM7Ad6obDU9@Kooooo1ooZj^X6obl_;`Oo3Ph>1oo:b/X7o`H61POo
5aLG1om[Jf/6ob4Q8@kooooo000<ooooo`OoK6a/1olf=SH7oh>3P`Oo_kno1om@D506ob<S8`Oo6ATI
1_l:2PX6ooooo`Oo<c<c3_m]KFd7og=cL`OoPH611_mcLg<7oeeMG@KoEEEE1_ooool7o`l?3`Oo:b/[
1omSHf<7obd];@KoDE5A1omCDe<7ofYZJPKoDU9B1_ooool7ob@T90OojNWY1olB4Q87of1PH0KoZZZZ
1old=3@7oe1@D0Ko;bl_1_ooool7oeMGE`Oo7QhN1oli>CT6ob<S8`Oo:b/[1olT92@7od92@PKo<C4a
1_ooool7oa@D50Oo<S8b1ol[:b/6od51@@Oo>SXj1olW9bL7obPX:0Ko61PH1_ooool7oaXJ6POoK6a/
1_le=CD7o`X:2POoCTi>1omIFET7oadM7@Ko9BDU1_ooool7on[ZjPKo;bl_1ol>3Ph7ol[:bPOo1PH6
1olG5aL7of][J`Ko8B4Q3_ooool000cooooo1om/K6`7ocHf=POoPh>31ono_kl7oe1@D0Ko8b<S1olI
6AT6o`X:2PKooooo1olc<c<>ofe]K@OoLg=c1on1PH46og=cL`OoGEeM1_mEEED6ooooo`Oo3`l?1ol[
:b/7of=SH`Oo;Bd]1_mADE47oe=CD`OoJVYZ1_mBDU86ooooo`Oo92@T1ooYjNT7oa8B4POoH61P1_nZ
ZZX7oc@d=0OoD51@1_l_;bl6ooooo`OoEeMG1olN7Qh7ocTi>@Ko8b<S1ol[:b/7ob@T90Oo@T921_la
<C46ooooo`Oo51@D1olb<S87ob/[:`Ko@D511olj>SX7obLW9`Oo:2PX1_lH61P6ooooo`Oo6QXJ1om/
K6`6ocDe=@Oo2PX:1om>CTh7oeUIF@Oo7AdM1_lU9BD6ooooo`Ooj^[Z1_l_;bl7o`h>3POob/[:1ol6
1PH7oaLG5`OoJf][1_lQ8B4>ooooo`003?ooool7ofa/K0Oo=SHf1on3Ph<7okno_`OoD51@1_lS8b<7
oaTI6@Ko2PX:1_ooool7oc<c<`koKFe]1omcLg<7oh61P@KoLg=c1omMGEd6oeEEE@Kooooo1ol?3`l7
ob/[:`OoHf=S1ol];Bd6oe5AD@OoDe=C1omZJVX6oe9BDPKooooo1olT92@7onWYj@Oo4Q8B1omPH606
ojZZZPOo=3@d1om@D506obl_;`Kooooo1omGEeL7oahN7POo>CTi1_lS8b<7ob/[:`Oo92@T1om2@T86
oc4a<@Kooooo1olD51@7oc8b<POo:b/[1_m1@D47ocXj>POo9bLW1olX:2P6oaPH60Kooooo1olJ6QX7
ofa/K0Ko=CDe1ol:2PX7odi>CPOoFEUI1olM7Ad6obDU9@Kooooo1ooZj^X6obl_;`Oo3Ph>1oo:b/X7
o`H61POo5aLG1om[Jf/6ob4Q8@kooooo000<ooooo`OoK6a/1olf=SH7oh>3P`Oo_kno1om@D506ob<S
8`Oo6ATI1_l:2PX6ooooo`Oo<c<c3_m]KFd7og=cL`OoPH611_mcLg<7oeeMG@KoEEEE1_ooool7o`l?
3`Oo:b/[1omSHf<7obd];@KoDE5A1omCDe<7ofYZJPKoDU9B1_ooool7ob@T90OojNWY1olB4Q87of1P
H0KoZZZZ1old=3@7oe1@D0Ko;bl_1_ooool7oeMGE`Oo7QhN1oli>CT6ob<S8`Oo:b/[1olT92@7od92
@PKo<C4a1_ooool7oa@D50Oo<S8b1ol[:b/6od51@@Oo>SXj1olW9bL7obPX:0Ko61PH1_ooool7oaXJ
6POoK6a/1_le=CD7o`X:2POoCTi>1omIFET7oadM7@Ko9BDU1_ooool7on[ZjPKo;bl_1ol>3Ph7ol[:
bPOo1PH61olG5aL7of][J`Ko8B4Q3_ooool000cooooo1om/K6`7ocHf=POoPh>31ono_kl7oe1@D0Ko
8b<S1olI6AT6o`X:2PKooooo1olc<c<>ofe]K@OoLg=c1on1PH46og=cL`OoGEeM1_mEEED6ooooo`Oo
3`l?1ol[:b/7of=SH`Oo;Bd]1_mADE47oe=CD`OoJVYZ1_mBDU86ooooo`Oo92@T1ooYjNT7oa8B4POo
H61P1_nZZZX7oc@d=0OoD51@1_l_;bl6ooooo`OoEeMG1olN7Qh7ocTi>@Ko8b<S1ol[:b/7ob@T90Oo
@T921_la<C46ooooo`Oo51@D1olb<S87ob/[:`Ko@D511olj>SX7obLW9`Oo:2PX1_lH61P6ooooo`Oo
6QXJ1om/K6`6ocDe=@Oo2PX:1om>CTh7oeUIF@Oo7AdM1_lU9BD6ooooo`Ooj^[Z1_l_;bl7o`h>3POo
b/[:1ol61PH7oaLG5`OoJf][1_lQ8B4>ooooo`003?ooool7ofa/K0Oo=SHf1on3Ph<7okno_`OoD51@
1_lS8b<7oaTI6@Ko2PX:1_ooool7oc<c<`koKFe]1omcLg<7oh61P@KoLg=c1omMGEd6oeEEE@Kooooo
1ol?3`l7ob/[:`OoHf=S1ol];Bd6oe5AD@OoDe=C1omZJVX6oe9BDPKooooo1olT92@7onWYj@Oo4Q8B
1omPH606ojZZZPOo=3@d1om@D506obl_;`Kooooo1omGEeL7oahN7POo>CTi1_lS8b<7ob/[:`Oo92@T
1om2@T86oc4a<@Kooooo1olD51@7oc8b<POo:b/[1_m1@D47ocXj>POo9bLW1olX:2P6oaPH60Kooooo
1olJ6QX7ofa/K0Ko=CDe1ol:2PX7odi>CPOoFEUI1olM7Ad6obDU9@Kooooo1ooZj^X6obl_;`Oo3Ph>
1oo:b/X7o`H61POo5aLG1om[Jf/6ob4Q8@kooooo000<ooooo`OoIfMW1om8B4P7onCTi0OoWIfM1ol^
;Rh6ochn?POo4A4A1_l00006ooooo`OoZ:RX1ooCdm<7omKFePOolo?c1oooool6oj6QX@OoV9RH1_mI
FET6ooooo`Oo7alO1omIFET7o`0000Oo20P81_n5QHD7o`T92@Oo9BDU1_m[Jf/6ooooo`OoNGUi1onT
Y:@7o`X:2POooooo1_m=CDd7oa8B4POoe=CD1_lQ8B46ooooo`Oo;2`/1olI6AT7obl_;`Ko:RXZ1omB
DU87od92@POoDU9B1_l_;bl6ooooo`Oo4Q8B1olG5aL7o`d=3@go51@D1ol@4107oa@D50Ko410@1_oo
ool7obh^;POoADE51_mOGel7of=SH`OoBDU91olU9BD7oc@d=0Ko8b<S1_ooool7ohb<S0KoL71`1om]
KFd7ofi^KPOo9RHV1oo3`l<7obDU9@Ko1@D53_ooool000cooooo1omWIfL7odQ8B0Ooi>CT1onMWId7
obh^;PKo?Shn1olA4A46o`0000Kooooo1onXZ:P7om?Cd`Ooe]KF1ooclo<7ooooo`KoXJ6Q1onHV9P6
oeUIF@Kooooo1olO7al7oeUIF@Oo00001ol820P6ohF5Q@Oo2@T91olU9BD6of][J`Kooooo1omiNGT7
ojBTY0Oo2PX:1oooool6ode=C@Oo4Q8B1ooDe=@6ob4Q8@Kooooo1ol/;2`7oaTI6@Oo;bl_1_lZ:RX7
oe9BDPOo@T921omBDU86obl_;`Kooooo1olB4Q87oaLG5`Oo3@d=3OlD51@7oa0@40Oo51@D1_l@4106
ooooo`Oo;Rh^1om5ADD6oemOG`OoHf=S1om9BDT7obDU9@Oo=3@d1_lS8b<6ooooo`OoS8b<1_m`L707
ofe]K@OoKVi^1olV9RH7ol?3``Oo9BDU1_l51@D>ooooo`003?ooool7ofMWI`OoB4Q81ooTi>@7oifM
W@Oo;Rh^1_ln?Sh7oa4A4@Ko00001_ooool7ojRXZ0Oodm?C1ooFe]H7oo?cl`Oooooo1_nQXJ47oiRH
V0KoFEUI1_ooool7oalO7`OoFEUI1ol00007o`P820KoQHF51ol92@T7obDU9@KoJf][1_ooool7ogUi
N@OoY:BT1ol:2PX7ooooo`KoCDe=1olB4Q87omCDe0Ko8B4Q1_ooool7ob`/;0Oo6ATI1ol_;bl6obXZ
:POoDU9B1om2@T87oe9BDPKo;bl_1_ooool7oa8B4POo5aLG1ol=3@d=oa@D50Oo410@1olD51@6oa0@
40Kooooo1ol^;Rh7odE5A@KoGemO1omSHf<7odU9B@Oo9BDU1old=3@6ob<S8`Kooooo1on<S8`6og1`
L0OoKFe]1om^KVh7obHV9POo`l?31olU9BD6o`D51@kooooo000<ooooo`OoIfMW1om8B4P7onCTi0Oo
WIfM1ol^;Rh6ochn?POo4A4A1_l00006ooooo`OoZ:RX1ooCdm<7omKFePOolo?c1oooool6oj6QX@Oo
V9RH1_mIFET6ooooo`Oo7alO1omIFET7o`0000Oo20P81_n5QHD7o`T92@Oo9BDU1_m[Jf/6ooooo`Oo
NGUi1onTY:@7o`X:2POooooo1_m=CDd7oa8B4POoe=CD1_lQ8B46ooooo`Oo;2`/1olI6AT7obl_;`Ko
:RXZ1omBDU87od92@POoDU9B1_l_;bl6ooooo`Oo4Q8B1olG5aL7o`d=3@go51@D1ol@4107oa@D50Ko
410@1_ooool7obh^;POoADE51_mOGel7of=SH`OoBDU91olU9BD7oc@d=0Ko8b<S1_ooool7ohb<S0Ko
L71`1om]KFd7ofi^KPOo9RHV1oo3`l<7obDU9@Ko1@D53_ooool000cooooo1omWIfL7odQ8B0Ooi>CT
1onMWId7obh^;PKo?Shn1olA4A46o`0000Kooooo1onXZ:P7om?Cd`Ooe]KF1ooclo<7ooooo`KoXJ6Q
1onHV9P6oeUIF@Kooooo1olO7al7oeUIF@Oo00001ol820P6ohF5Q@Oo2@T91olU9BD6of][J`Kooooo
1omiNGT7ojBTY0Oo2PX:1oooool6ode=C@Oo4Q8B1ooDe=@6ob4Q8@Kooooo1ol/;2`7oaTI6@Oo;bl_
1_lZ:RX7oe9BDPOo@T921omBDU86obl_;`Kooooo1olB4Q87oaLG5`Oo3@d=3OlD51@7oa0@40Oo51@D
1_l@4106ooooo`Oo;Rh^1om5ADD6oemOG`OoHf=S1om9BDT7obDU9@Oo=3@d1_lS8b<6ooooo`OoS8b<
1_m`L707ofe]K@OoKVi^1olV9RH7ol?3``Oo9BDU1_l51@D>ooooo`003?ooool7ofMWI`OoB4Q81ooT
i>@7oifMW@Oo;Rh^1_ln?Sh7oa4A4@Ko00001_ooool7ojRXZ0Oodm?C1ooFe]H7oo?cl`Oooooo1_nQ
XJ47oiRHV0KoFEUI1_ooool7oalO7`OoFEUI1ol00007o`P820KoQHF51ol92@T7obDU9@KoJf][1_oo
ool7ogUiN@OoY:BT1ol:2PX7ooooo`KoCDe=1olB4Q87omCDe0Ko8B4Q1_ooool7ob`/;0Oo6ATI1ol_
;bl6obXZ:POoDU9B1om2@T87oe9BDPKo;bl_1_ooool7oa8B4POo5aLG1ol=3@d=oa@D50Oo410@1olD
51@6oa0@40Kooooo1ol^;Rh7odE5A@KoGemO1omSHf<7odU9B@Oo9BDU1old=3@6ob<S8`Kooooo1on<
S8`6og1`L0OoKFe]1om^KVh7obHV9POo`l?31olU9BD6o`D51@kooooo000<ooooo`OoIfMW1om8B4P7
onCTi0OoWIfM1ol^;Rh6ochn?POo4A4A1_l00006ooooo`OoZ:RX1ooCdm<7omKFePOolo?c1oooool6
oj6QX@OoV9RH1_mIFET6ooooo`Oo7alO1omIFET7o`0000Oo20P81_n5QHD7o`T92@Oo9BDU1_m[Jf/6
ooooo`OoNGUi1onTY:@7o`X:2POooooo1_m=CDd7oa8B4POoe=CD1_lQ8B46ooooo`Oo;2`/1olI6AT7
obl_;`Ko:RXZ1omBDU87od92@POoDU9B1_l_;bl6ooooo`Oo4Q8B1olG5aL7o`d=3@go51@D1ol@4107
oa@D50Ko410@1_ooool7obh^;POoADE51_mOGel7of=SH`OoBDU91olU9BD7oc@d=0Ko8b<S1_ooool7
ohb<S0KoL71`1om]KFd7ofi^KPOo9RHV1oo3`l<7obDU9@Ko1@D53_ooool000cooooo1on7QhL7oc4a
<@OoR8R81on3Ph<7oe9BDPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][
J`Ko=CDe1om>CTh6oc8b<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<3
0`Kooooo1on=SHd7oh61P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMW
I`KoZj^[1on0P807oiJFUPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`00
00Ko5ADE1_ooool7ob0P80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?
c`Ko>c/k1om3@d<7on[ZjPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1on7QhL7oc4a<@Oo
R8R81on3Ph<7oe9BDPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][J`Ko
=CDe1om>CTh6oc8b<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<30`Ko
oooo1on=SHd7oh61P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMWI`Ko
Zj^[1on0P807oiJFUPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`0000Ko
5ADE1_ooool7ob0P80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?c`Ko
>c/k1om3@d<7on[ZjPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1on7QhL7oc4a<@OoR8R8
1on3Ph<7oe9BDPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][J`Ko=CDe
1om>CTh6oc8b<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<30`Kooooo
1on=SHd7oh61P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMWI`KoZj^[
1on0P807oiJFUPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`0000Ko5ADE
1_ooool7ob0P80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?c`Ko>c/k
1om3@d<7on[ZjPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1on7QhL7oc4a<@OoR8R81on3
Ph<7oe9BDPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][J`Ko=CDe1om>
CTh6oc8b<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<30`Kooooo1on=
SHd7oh61P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMWI`KoZj^[1on0
P807oiJFUPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`0000Ko5ADE1_oo
ool7ob0P80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?c`Ko>c/k1om3
@d<7on[ZjPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1on7QhL7oc4a<@OoR8R81on3Ph<7
oe9BDPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][J`Ko=CDe1om>CTh6
oc8b<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<30`Kooooo1on=SHd7
oh61P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMWI`KoZj^[1on0P807
oiJFUPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`0000Ko5ADE1_ooool7
ob0P80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?c`Ko>c/k1om3@d<7
on[ZjPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1on7QhL7oc4a<@OoR8R81on3Ph<7oe9B
DPKo>CTi1olE5AD6oaTI6@Kooooo1om=CDd7ocLg=`OoFEUI1om8B4P7of][J`Ko=CDe1om>CTh6oc8b
<PKooooo1olO7al7ocTi>@Oo2PX:1olb<S86oaDE5@Oo5QHF1omeMGD6o`<30`Kooooo1on=SHd7oh61
P@Oo4A4A1onj^[X=ofYZJPOoR8R81_l>3Ph6ooooo`Oo<30`1omaLG47ofMWI`KoZj^[1on0P807oiJF
UPOoKVi^1_m7AdL6ooooo`Oo71`L3_lI6AT6oaDE5@Oo2@T91ol61PH7o`0000Ko5ADE1_ooool7ob0P
80Oooooo1_lJ6QX7obh^;POoW9bL1olP8207oc@d=0Ko@4101_ooool7olo?c`Ko>c/k1om3@d<7on[Z
jPOo:2PX1omMGEd7ogMgM`KoOGem3_ooool000cooooo1omfMWH7oc/k>`Ooclo?1onDU9@7ocPh>0Ko
;Bd]1ol410@6o`X:2PKooooo1olW9bL7o`h>3POo5ADE1ol00007oa8B4PKo1`L71ol>3Ph6oa/K6`Ko
oooo1on:RXX7oaLG5`Oo1@D51om`L706oa/K6`Oo0P821ol];Bd6oalO7`Kooooo1om:BTX7oiBDU0Oo
6ATI1oni^KT6odU9B@OoKVi^1ooGemL6o`X:2PKooooo1oo8b<P7olo?c`Ook>c/1_oPh>07ol[:bPOo
Ph>31om_Kfl6obh^;PKooooo1olO7al7oa<C4`Oo8B4Q1_lR8R87ocPh>0Oo:2PX1olV9RH6ob<S8`Ko
oooo1om`L707ohn?S`Ko?Shn1ooinOT7odM7A`Oo4Q8B1oo:b/X6oadM7@Kooooo1ooIfMT6oa/K6`Oo
Ogmo1onRXZ87o`d=3@Oooooo1olU9BD6oc4a<@kooooo000<ooooo`OoMWIf1olk>c/7olo?c`OoU9BD
1olh>3P6obd];@Oo10@41_l:2PX6ooooo`Oo9bLW1ol>3Ph7oaDE5@Oo00001olB4Q86o`L71`Oo3Ph>
1_lK6a/6ooooo`OoRXZ:1olG5aL7o`D51@OoL71`1_lK6a/7o`820POo;Bd]1_lO7al6ooooo`OoBTY:
1onDU9@7oaTI6@Oo^KVi1_m9BDT7ofi^KPOoemOG1_l:2PX6ooooo`Oob<S81oo?cll7onc/k0Koh>3P
1oo:b/X7oh>3P`OoKfm_1_l^;Rh6ooooo`Oo7alO1olC4a<7ob4Q8@Ko8R8R1olh>3P7obPX:0Oo9RHV
1_lS8b<6ooooo`OoL71`1on?Shl6ochn?POonOWi1om7AdL7oa8B4POob/[:1_lM7Ad6ooooo`OofMWI
1_lK6a/7ogmoO`OoXZ:R1ol=3@d7ooooo`Oo9BDU1_la<C4>ooooo`003?ooool7ogIfMPOo>c/k1oo?
cll7oiBDU0Oo>3Ph1_l];Bd7o`@410Ko2PX:1_ooool7obLW9`Oo3Ph>1olE5AD7o`0000Oo4Q8B1_l7
1`L7o`h>3PKo6a/K1_ooool7ohZ:RPOo5aLG1ol51@D7og1`L0Ko6a/K1ol20P87obd];@Ko7alO1_oo
ool7odY:BPOoU9BD1olI6AT7okVi^@KoBDU91om^KVh7omOGe`Ko2PX:1_ooool7olS8b0Ooclo?1oo/
k>`6on3Ph0Oob/[:1on3Ph<7ofm_K`Ko;Rh^1_ooool7oalO7`Oo4a<C1olQ8B46ob8R8POo>3Ph1olX
:2P7obHV9PKo8b<S1_ooool7og1`L0OoShn?1_ln?Sh7ooWin@OoAdM71olB4Q87ol[:bPKo7AdM1_oo
ool7omWIf@Ko6a/K1omoOgl7oj:RXPOo3@d=1oooool7obDU9@Ko<C4a3_ooool000cooooo1omfMWH7
oc/k>`Ooclo?1onDU9@7ocPh>0Ko;Bd]1ol410@6o`X:2PKooooo1olW9bL7o`h>3POo5ADE1ol00007
oa8B4PKo1`L71ol>3Ph6oa/K6`Kooooo1on:RXX7oaLG5`Oo1@D51om`L706oa/K6`Oo0P821ol];Bd6
oalO7`Kooooo1om:BTX7oiBDU0Oo6ATI1oni^KT6odU9B@OoKVi^1ooGemL6o`X:2PKooooo1oo8b<P7
olo?c`Ook>c/1_oPh>07ol[:bPOoPh>31om_Kfl6obh^;PKooooo1olO7al7oa<C4`Oo8B4Q1_lR8R87
ocPh>0Oo:2PX1olV9RH6ob<S8`Kooooo1om`L707ohn?S`Ko?Shn1ooinOT7odM7A`Oo4Q8B1oo:b/X6
oadM7@Kooooo1ooIfMT6oa/K6`OoOgmo1onRXZ87o`d=3@Oooooo1olU9BD6oc4a<@kooooo000<oooo
o`OoMWIf1olk>c/7olo?c`OoU9BD1olh>3P6obd];@Oo10@41_l:2PX6ooooo`Oo9bLW1ol>3Ph7oaDE
5@Oo00001olB4Q86o`L71`Oo3Ph>1_lK6a/6ooooo`OoRXZ:1olG5aL7o`D51@OoL71`1_lK6a/7o`82
0POo;Bd]1_lO7al6ooooo`OoBTY:1onDU9@7oaTI6@Oo^KVi1_m9BDT7ofi^KPOoemOG1_l:2PX6oooo
o`Oob<S81oo?cll7onc/k0Koh>3P1oo:b/X7oh>3P`OoKfm_1_l^;Rh6ooooo`Oo7alO1olC4a<7ob4Q
8@Ko8R8R1olh>3P7obPX:0Oo9RHV1_lS8b<6ooooo`OoL71`1on?Shl6ochn?POonOWi1om7AdL7oa8B
4POob/[:1_lM7Ad6ooooo`OofMWI1_lK6a/7ogmoO`OoXZ:R1ol=3@d7ooooo`Oo9BDU1_la<C4>oooo
o`003?ooool7ogIfMPOo>c/k1oo?cll7oiBDU0Oo>3Ph1_l];Bd7o`@410Ko2PX:1_ooool7obLW9`Oo
3Ph>1olE5AD7o`0000Oo4Q8B1_l71`L7o`h>3PKo6a/K1_ooool7ohZ:RPOo5aLG1ol51@D7og1`L0Ko
6a/K1ol20P87obd];@Ko7alO1_ooool7odY:BPOoU9BD1olI6AT7okVi^@KoBDU91om^KVh7omOGe`Ko
2PX:1_ooool7olS8b0Ooclo?1oo/k>`6on3Ph0Oob/[:1on3Ph<7ofm_K`Ko;Rh^1_ooool7oalO7`Oo
4a<C1olQ8B46ob8R8POo>3Ph1olX:2P7obHV9PKo8b<S1_ooool7og1`L0OoShn?1_ln?Sh7ooWin@Oo
AdM71olB4Q87ol[:bPKo7AdM1_ooool7omWIf@Ko6a/K1omoOgl7oj:RXPOo3@d=1oooool7obDU9@Ko
<C4a3_ooool000cooooo1omfMWH7oc/k>`Ooclo?1onDU9@7ocPh>0Ko;Bd]1ol410@6o`X:2PKooooo
1olW9bL7o`h>3POo5ADE1ol00007oa8B4PKo1`L71ol>3Ph6oa/K6`Kooooo1on:RXX7oaLG5`Oo1@D5
1om`L706oa/K6`Oo0P821ol];Bd6oalO7`Kooooo1om:BTX7oiBDU0Oo6ATI1oni^KT6odU9B@OoKVi^
1ooGemL6o`X:2PKooooo1oo8b<P7olo?c`Ook>c/1_oPh>07ol[:bPOoPh>31om_Kfl6obh^;PKooooo
1olO7al7oa<C4`Oo8B4Q1_lR8R87ocPh>0Oo:2PX1olV9RH6ob<S8`Kooooo1om`L707ohn?S`Ko?Shn
1ooinOT7odM7A`Oo4Q8B1oo:b/X6oadM7@Kooooo1ooIfMT6oa/K6`OoOgmo1onRXZ87o`d=3@Oooooo
1olU9BD6oc4a<@kooooo000<ooooo`OoNWYj1omDE5@7ofm_K`OoOgmo1om=CDd6oc`l?0Oo:b/[1_lM
7Ad6ooooo`Oo?Shn1olW9bL7obXZ:POo6QXJ1ol[:b/6oaXJ6POo9BDU1_lV9RH6ooooo`OoFe]K1om;
Bd/7ofATI0Oo?3`l1_lI6AT7of=SH`Oo>3Ph1_l61PH6ooooo`OoUIFE1ol;2`/7o`h>3POofMWI1_l4
10@7oeQHF0Oo`L711_lC4a<6ooooo`OoA4A41ol];Bd7od10@0Ko?Cdm1olg=cL7ocTi>@Oo<30`1_lb
<S86ooooo`Oo7alO1olf=SH7oc@d=0KoC4a<1omOGel7odQ8B0OoCDe=1_lW9bL6ooooo`OoGEeM1ooH
f=P6ob/[:`OoNWYj1onWYjL7of5QH@OoIVIV1_lR8R86ooooo`OoEUIF1_la<C47oj:RXPOoLW9b1olB
4Q87ol71`@Oo?Cdm1_nJVYX>ooooo`003?ooool7ogYjNPOoE5AD1om_Kfl7ogmoO`OoCDe=1_ll?3`7
ob/[:`Ko7AdM1_ooool7ochn?POo9bLW1olZ:RX7oaXJ6POo:b/[1_lJ6QX7obDU9@Ko9RHV1_ooool7
oe]KF`OoBd];1omTI6@7oc`l?0Ko6ATI1omSHf<7ocPh>0Ko1PH61_ooool7oiFEU@Oo2`/;1ol>3Ph7
omWIf@Ko10@41omHF5P7ol71`@Ko4a<C1_ooool7odA4A0Oo;Bd]1om0@406ocdm?@Oo=cLg1oli>CT7
oc0`<0Ko<S8b1_ooool7oalO7`Oo=SHf1old=3@6oda<C0OoGemO1om8B4P7ode=C@Ko9bLW1_ooool7
oeeMG@Oof=SH1_l[:b/7ogYjNPOoYjNW1omQHF47ofIVIPKo8R8R1_ooool7oeIFEPKo<C4a1onRXZ87
og9bLPOo4Q8B1oo1`L47ocdm?@KoVYZJ3_ooool000cooooo1omjNWX7oeADE0OoKfm_1omoOgl7ode=
C@Ko?3`l1ol[:b/6oadM7@Kooooo1oln?Sh7obLW9`Oo:RXZ1olJ6QX7ob/[:`Ko6QXJ1olU9BD6obHV
9PKooooo1omKFe/7od];B`OoI6AT1oll?3`6oaTI6@OoHf=S1olh>3P6o`H61PKooooo1onEUID7o`/;
2`Oo3Ph>1ooIfMT6o`@410OoF5QH1oo1`L46oa<C4`Kooooo1om4A4@7obd];@Oo@4101_lm?Cd7ocLg
=`Oo>CTi1ol`<306oc8b<PKooooo1olO7al7ocHf=POo=3@d1_m<C4`7oemOG`OoB4Q81om=CDd6obLW
9`Kooooo1omMGEd7omSHf0Ko:b/[1omjNWX7ojNWY`OoHF5Q1omVIVH6ob8R8PKooooo1omFEUH6oc4a
<@OoXZ:R1ombLW87oa8B4POo`L711olm?Cd6oiZJVPkooooo000<ooooo`OoNWYj1omDE5@7ofm_K`Oo
Ogmo1om=CDd6oc`l?0Oo:b/[1_lM7Ad6ooooo`Oo?Shn1olW9bL7obXZ:POo6QXJ1ol[:b/6oaXJ6POo
9BDU1_lV9RH6ooooo`OoFe]K1om;Bd/7ofATI0Oo?3`l1_lI6AT7of=SH`Oo>3Ph1_l61PH6ooooo`Oo
UIFE1ol;2`/7o`h>3POofMWI1_l410@7oeQHF0Oo`L711_lC4a<6ooooo`OoA4A41ol];Bd7od10@0Ko
?Cdm1olg=cL7ocTi>@Oo<30`1_lb<S86ooooo`Oo7alO1olf=SH7oc@d=0KoC4a<1omOGel7odQ8B0Oo
CDe=1_lW9bL6ooooo`OoGEeM1ooHf=P6ob/[:`OoNWYj1onWYjL7of5QH@OoIVIV1_lR8R86ooooo`Oo
EUIF1_la<C47oj:RXPOoLW9b1olB4Q87ol71`@Oo?Cdm1_nJVYX>ooooo`003?ooool7ogYjNPOoE5AD
1om_Kfl7ogmoO`OoCDe=1_ll?3`7ob/[:`Ko7AdM1_ooool7ochn?POo9bLW1olZ:RX7oaXJ6POo:b/[
1_lJ6QX7obDU9@Ko9RHV1_ooool7oe]KF`OoBd];1omTI6@7oc`l?0Ko6ATI1omSHf<7ocPh>0Ko1PH6
1_ooool7oiFEU@Oo2`/;1ol>3Ph7omWIf@Ko10@41omHF5P7ol71`@Ko4a<C1_ooool7odA4A0Oo;Bd]
1om0@406ocdm?@Oo=cLg1oli>CT7oc0`<0Ko<S8b1_ooool7oalO7`Oo=SHf1old=3@6oda<C0OoGemO
1om8B4P7ode=C@Ko9bLW1_ooool7oeeMG@Oof=SH1_l[:b/7ogYjNPOoYjNW1omQHF47ofIVIPKo8R8R
1_ooool7oeIFEPKo<C4a1onRXZ87og9bLPOo4Q8B1oo1`L47ocdm?@KoVYZJ3_ooool000cooooo1omj
NWX7oeADE0OoKfm_1omoOgl7ode=C@Ko?3`l1ol[:b/6oadM7@Kooooo1oln?Sh7obLW9`Oo:RXZ1olJ
6QX7ob/[:`Ko6QXJ1olU9BD6obHV9PKooooo1omKFe/7od];B`OoI6AT1oll?3`6oaTI6@OoHf=S1olh
>3P6o`H61PKooooo1onEUID7o`/;2`Oo3Ph>1ooIfMT6o`@410OoF5QH1oo1`L46oa<C4`Kooooo1om4
A4@7obd];@Oo@4101_lm?Cd7ocLg=`Oo>CTi1ol`<306oc8b<PKooooo1olO7al7ocHf=POo=3@d1_m<
C4`7oemOG`OoB4Q81om=CDd6obLW9`Kooooo1omMGEd7omSHf0Ko:b/[1omjNWX7ojNWY`OoHF5Q1omV
IVH6ob8R8PKooooo1omFEUH6oc4a<@OoXZ:R1ombLW87oa8B4POo`L711olm?Cd6oiZJVPkooooo000<
ooooo`OoNWYj1omDE5@7ofm_K`OoOgmo1om=CDd6oc`l?0Oo:b/[1_lM7Ad6ooooo`Oo?Shn1olW9bL7
obXZ:POo6QXJ1ol[:b/6oaXJ6POo9BDU1_lV9RH6ooooo`OoFe]K1om;Bd/7ofATI0Oo?3`l1_lI6AT7
of=SH`Oo>3Ph1_l61PH6ooooo`OoUIFE1ol;2`/7o`h>3POofMWI1_l410@7oeQHF0Oo`L711_lC4a<6
ooooo`OoA4A41ol];Bd7od10@0Ko?Cdm1olg=cL7ocTi>@Oo<30`1_lb<S86ooooo`Oo7alO1olf=SH7
oc@d=0KoC4a<1omOGel7odQ8B0OoCDe=1_lW9bL6ooooo`OoGEeM1ooHf=P6ob/[:`OoNWYj1onWYjL7
of5QH@OoIVIV1_lR8R86ooooo`OoEUIF1_la<C47oj:RXPOoLW9b1olB4Q87ol71`@Oo?Cdm1_nJVYX>
ooooo`003?ooool7ogMgM`Oo<30`1oooool7okJf]POo@T921_l/;2`7oaDE5@Ko71`L1_ooool7ochn
?POoDe=C1om_Kfl7oi>CT`OoWinO1_nZZZX7oiJFUPKoMGEe3Oooool7ocDe=@Oo=SHf1oni^KT6obl_
;`Oo=SHf1omLG5`6oe1@D0Kooooo1oln?Sh7obDU9@OoA4A41oli>CT6oaLG5`OoS8b<1om8B4P6o`00
00Kooooo1olW9bL7o``<30Oo2@T91_l00007o`820POo20P81olE5AD6ob@T90Kooooo1olV9RH7ocHf
=POo:BTY1_la<C47ocXj>POo7alO1ol_;bl6ob4Q8@Kooooo1omKFe/7olS8b0Ko6QXJ1ooTi>@7og9b
LPOo>c/k1oolo?`6oahN7PKooooo1onATI46o`820POoBd];1on0P807oc4a<@OoSHf=1olh>3P6oh20
P0kooooo000<ooooo`OoMgMg1ol`<307ooooo`Oo][Jf1om2@T86ob`/;0Oo5ADE1_lL71`6ooooo`Oo
?Shn1omCDe<7ofm_K`OoTi>C1onOWil6ojZZZPOoUYJF1_meMGD=ooooo`Oo=CDe1olf=SH7okVi^@Ko
;bl_1olf=SH7oeaLG0KoD51@1_ooool7ochn?POo9BDU1om4A4@7ocTi>@Ko5aLG1on<S8`7odQ8B0Ko
00001_ooool7obLW9`Oo30`<1ol92@T6o`0000Oo0P821ol820P7oaDE5@Ko92@T1_ooool7obHV9POo
=SHf1olY:BT6oc4a<@Oo>SXj1olO7al7obl_;`Ko8B4Q1_ooool7oe]KF`Oob<S81_lJ6QX7onCTi0Oo
LW9b1olk>c/7ooclo0Ko7QhN1_ooool7oi6AT@Ko0P821om;Bd/7oh20P0Oo<C4a1on=SHd7ocPh>0Ko
P8203_ooool000cooooo1omgMgL7oc0`<0Oooooo1onf][H7od92@PKo;2`/1olE5AD6oa`L70Kooooo
1oln?Sh7oe=CD`OoKfm_1onCTi<7oinOW`KoZZZZ1onFUYH6ogEeM@gooooo1ole=CD7ocHf=POo^KVi
1_l_;bl7ocHf=POoG5aL1_m@D506ooooo`Oo?Shn1olU9BD7odA4A0Oo>CTi1_lG5aL7ohb<S0OoB4Q8
1_l00006ooooo`Oo9bLW1ol<30`7o`T92@Ko00001ol20P87o`P820Oo5ADE1_lT92@6ooooo`Oo9RHV
1olf=SH7obTY:@Ko<C4a1olj>SX7oalO7`Oo;bl_1_lQ8B46ooooo`OoFe]K1oo8b<P6oaXJ6POoi>CT
1ombLW87oc/k>`Ooo?cl1_lN7Qh6ooooo`OoTI6A1_l20P87od];B`OoP8201ola<C47ohf=S@Oo>3Ph
1_n0P80>ooooo`003?ooool7ogMgM`Oo<30`1oooool7okJf]POo@T921_l/;2`7oaDE5@Ko71`L1_oo
ool7ochn?POoDe=C1om_Kfl7oi>CT`OoWinO1_nZZZX7oiJFUPKoMGEe3Oooool7ocDe=@Oo=SHf1oni
^KT6obl_;`Oo=SHf1omLG5`6oe1@D0Kooooo1oln?Sh7obDU9@OoA4A41oli>CT6oaLG5`OoS8b<1om8
B4P6o`0000Kooooo1olW9bL7o``<30Oo2@T91_l00007o`820POo20P81olE5AD6ob@T90Kooooo1olV
9RH7ocHf=POo:BTY1_la<C47ocXj>POo7alO1ol_;bl6ob4Q8@Kooooo1omKFe/7olS8b0Ko6QXJ1ooT
i>@7og9bLPOo>c/k1oolo?`6oahN7PKooooo1onATI46o`820POoBd];1on0P807oc4a<@OoSHf=1olh
>3P6oh20P0kooooo000<ooooo`OoMgMg1ol`<307ooooo`Oo][Jf1om2@T86ob`/;0Oo5ADE1_lL71`6
ooooo`Oo?Shn1omCDe<7ofm_K`OoTi>C1onOWil6ojZZZPOoUYJF1_meMGD=ooooo`Oo=CDe1olf=SH7
okVi^@Ko;bl_1olf=SH7oeaLG0KoD51@1_ooool7ochn?POo9BDU1om4A4@7ocTi>@Ko5aLG1on<S8`7
odQ8B0Ko00001_ooool7obLW9`Oo30`<1ol92@T6o`0000Oo0P821ol820P7oaDE5@Ko92@T1_ooool7
obHV9POo=SHf1olY:BT6oc4a<@Oo>SXj1olO7al7obl_;`Ko8B4Q1_ooool7oe]KF`Oob<S81_lJ6QX7
onCTi0OoLW9b1olk>c/7ooclo0Ko7QhN1_ooool7oi6AT@Ko0P821om;Bd/7oh20P0Oo<C4a1on=SHd7
ocPh>0KoP8203_ooool000cooooo1omgMgL7oc0`<0Oooooo1onf][H7od92@PKo;2`/1olE5AD6oa`L
70Kooooo1oln?Sh7oe=CD`OoKfm_1onCTi<7oinOW`KoZZZZ1onFUYH6ogEeM@gooooo1ole=CD7ocHf
=POo^KVi1_l_;bl7ocHf=POoG5aL1_m@D506ooooo`Oo?Shn1olU9BD7odA4A0Oo>CTi1_lG5aL7ohb<
S0OoB4Q81_l00006ooooo`Oo9bLW1ol<30`7o`T92@Ko00001ol20P87o`P820Oo5ADE1_lT92@6oooo
o`Oo9RHV1olf=SH7obTY:@Ko<C4a1olj>SX7oalO7`Oo;bl_1_lQ8B46ooooo`OoFe]K1oo8b<P6oaXJ
6POoi>CT1ombLW87oc/k>`Ooo?cl1_lN7Qh6ooooo`OoTI6A1_l20P87od];B`OoP8201ola<C47ohf=
S@Oo>3Ph1_n0P80>ooooo`003?ooool7odm?C`Oo=SHf1onCTi<7ohF5Q@Oo<30`1_lY:BT7o``<30Ko
20P81_ooool7odm?C`OoOWin1on2PX87ojNWY`OoY:BT1_nBTY87oj:RXPKoKfm_1_ooool7oj6QX@Oo
9bLW1oo6a/H7oe5AD@Ko7QhN1oooool7oahN7PKo5QHF1_ooool7od=3@`Oo0`<31ol_;bl7oemOG`Ko
1PH61olm?Cd7ofm_K`Ko9BDU1_ooool7oda<C0Oo8B4Q1olL71`6oa@D50Oo1@D51ol>3Ph7oa<C4`Ko
7alO1_ooool7oaPH60Oo30`<1ol:2PX6oa8B4POo4a<C1olP8207o`h>3PKo6a/K1_ooool7ohj>SPOo
@T921_lG5aL7omGEe@Oo<S8b1omFEUH7okRh^0Ko6ATI1_ooool7o`X:2PKo2@T91on?Shl7o`410@Oo
30`<1onf][H7oa<C4`KoH61P3_ooool000cooooo1om?Cdl7ocHf=POoTi>C1on5QHD7oc0`<0Ko:BTY
1ol<30`6o`P820Kooooo1om?Cdl7oginOPOoPX:21onWYjL7ojBTY0KoTY:B1onRXZ86ofm_K`Kooooo
1onQXJ47obLW9`Ooa/K61omADE46oahN7POooooo1olN7Qh6oaHF5PKooooo1om3@d<7o`<30`Oo;bl_
1omOGel6o`H61POo?Cdm1om_Kfl6obDU9@Kooooo1om<C4`7ob4Q8@Oo71`L1_lD51@7o`D51@Oo3Ph>
1olC4a<6oalO7`Kooooo1olH61P7o``<30Oo2PX:1_lB4Q87oa<C4`Oo820P1ol>3Ph6oa/K6`Kooooo
1on>SXh7od92@PKo5aLG1ooEeMD7oc8b<POoEUIF1onh^;P6oaTI6@Kooooo1ol:2PX6o`T92@OoShn?
1ol10@47o``<30Oo][Jf1olC4a<6of1PH0kooooo000<ooooo`OoCdm?1olf=SH7oi>CT`OoQHF51ol`
<306obTY:@Oo30`<1_l820P6ooooo`OoCdm?1omnOWh7oh:2PPOoYjNW1onTY:@6oi:BTPOoXZ:R1_m_
Kfl6ooooo`OoXJ6Q1olW9bL7olK6aPOoDE5A1_lN7Qh7ooooo`Oo7QhN1_lF5QH6ooooo`Oo@d=31ol3
0`<7obl_;`OoGemO1_l61PH7ocdm?@OoKfm_1_lU9BD6ooooo`OoC4a<1olQ8B47oa`L70Ko51@D1ol5
1@D7o`h>3POo4a<C1_lO7al6ooooo`Oo61PH1ol<30`7o`X:2PKo4Q8B1olC4a<7ob0P80Oo3Ph>1_lK
6a/6ooooo`OoSXj>1om2@T86oaLG5`OoeMGE1olb<S87oeIFEPOo^;Rh1_lI6AT6ooooo`Oo2PX:1_l9
2@T7ohn?S`Oo0@411ol<30`7okJf]POo4a<C1_mPH60>ooooo`003?ooool7odm?C`Oo=SHf1onCTi<7
ohF5Q@Oo<30`1_lY:BT7o``<30Ko20P81_ooool7odm?C`OoOWin1on2PX87ojNWY`OoY:BT1_nBTY87
oj:RXPKoKfm_1_ooool7oj6QX@Oo9bLW1oo6a/H7oe5AD@Ko7QhN1oooool7oahN7PKo5QHF1_ooool7
od=3@`Oo0`<31ol_;bl7oemOG`Ko1PH61olm?Cd7ofm_K`Ko9BDU1_ooool7oda<C0Oo8B4Q1olL71`6
oa@D50Oo1@D51ol>3Ph7oa<C4`Ko7alO1_ooool7oaPH60Oo30`<1ol:2PX6oa8B4POo4a<C1olP8207
o`h>3PKo6a/K1_ooool7ohj>SPOo@T921_lG5aL7omGEe@Oo<S8b1omFEUH7okRh^0Ko6ATI1_ooool7
o`X:2PKo2@T91on?Shl7o`410@Oo30`<1onf][H7oa<C4`KoH61P3_ooool000cooooo1om?Cdl7ocHf
=POoTi>C1on5QHD7oc0`<0Ko:BTY1ol<30`6o`P820Kooooo1om?Cdl7oginOPOoPX:21onWYjL7ojBT
Y0KoTY:B1onRXZ86ofm_K`Kooooo1onQXJ47obLW9`Ooa/K61omADE46oahN7POooooo1olN7Qh6oaHF
5PKooooo1om3@d<7o`<30`Oo;bl_1omOGel6o`H61POo?Cdm1om_Kfl6obDU9@Kooooo1om<C4`7ob4Q
8@Oo71`L1_lD51@7o`D51@Oo3Ph>1olC4a<6oalO7`Kooooo1olH61P7o``<30Oo2PX:1_lB4Q87oa<C
4`Oo820P1ol>3Ph6oa/K6`Kooooo1on>SXh7od92@PKo5aLG1ooEeMD7oc8b<POoEUIF1onh^;P6oaTI
6@Kooooo1ol:2PX6o`T92@OoShn?1ol10@47o``<30Oo][Jf1olC4a<6of1PH0kooooo000<ooooo`Oo
Cdm?1olf=SH7oi>CT`OoQHF51ol`<306obTY:@Oo30`<1_l820P6ooooo`OoCdm?1omnOWh7oh:2PPOo
YjNW1onTY:@6oi:BTPOoXZ:R1_m_Kfl6ooooo`OoXJ6Q1olW9bL7olK6aPOoDE5A1_lN7Qh7ooooo`Oo
7QhN1_lF5QH6ooooo`Oo@d=31ol30`<7obl_;`OoGemO1_l61PH7ocdm?@OoKfm_1_lU9BD6ooooo`Oo
C4a<1olQ8B47oa`L70Ko51@D1ol51@D7o`h>3POo4a<C1_lO7al6ooooo`Oo61PH1ol<30`7o`X:2PKo
4Q8B1olC4a<7ob0P80Oo3Ph>1_lK6a/6ooooo`OoSXj>1om2@T86oaLG5`OoeMGE1olb<S87oeIFEPOo
^;Rh1_lI6AT6ooooo`Oo2PX:1_l92@T7ohn?S`Oo0@411ol<30`7okJf]POo4a<C1_mPH60>ooooo`00
3?ooool7odm?C`Oo=SHf1onCTi<7ohF5Q@Oo<30`1_lY:BT7o``<30Ko20P81_ooool7odm?C`OoOWin
1on2PX87ojNWY`OoY:BT1_nBTY87oj:RXPKoKfm_1_ooool7oj6QX@Oo9bLW1oo6a/H7oe5AD@Ko7QhN
1oooool7oahN7PKo5QHF1_ooool7od=3@`Oo0`<31ol_;bl7oemOG`Ko1PH61olm?Cd7ofm_K`Ko9BDU
1_ooool7oda<C0Oo8B4Q1olL71`6oa@D50Oo1@D51ol>3Ph7oa<C4`Ko7alO1_ooool7oaPH60Oo30`<
1ol:2PX6oa8B4POo4a<C1olP8207o`h>3PKo6a/K1_ooool7ohj>SPOo@T921_lG5aL7omGEe@Oo<S8b
1omFEUH7okRh^0Ko6ATI1_ooool7o`X:2PKo2@T91on?Shl7o`410@Oo30`<1onf][H7oa<C4`KoH61P
3_ooool000cooooo1omLG5`7ocLg=`OoYjNW1on0P807od51@@Ko<S8b1olL71`6ob0P80Kooooo1onB
TY87ohf=S@OoaLG51onJVYX7oj^[Z`KoVYZJ1oo2`/86oh:2PPKooooo1om=CDd7oc@d=0Oo8R8R1olF
5QH6ogUiN@Oo5QHF1olV9RH6oeQHF0Kooooo1olZ:RX7ob4Q8@OoA4A41om;Bd/6oa8B4POo6QXJ1olC
4a<6o`820Pgooooo1onZZZX7olC4a0KoV9RH1onRXZ87ogalO0OoMWIf1_mNGUh6ooooo`OoDU9B1omM
GEd7okZj^PKooooo1oo8b<P7oj>SX`OoR8R81_m4A4@6ooooo`Oo<c<c1ol00006ocLg=`OoH61P1ol0
0007ob4Q8@OoEeMG1_li>CT6ooooo`Oo0`<31_mHF5P7obPX:0Oo00001om=CDd7obLW9`Oo1PH61_l5
1@D>ooooo`003?ooool7oeaLG0Oo=cLg1onWYjL7oh20P0Oo@D511_lb<S87oa`L70Ko820P1_ooool7
oi:BTPOoSHf=1oo5aLD7oiZJVPOoZj^[1_nJVYX7ol;2`PKoPX:21_ooool7ode=C@Oo=3@d1olR8R87
oaHF5PKoNGUi1olF5QH7obHV9PKoF5QH1_ooool7obXZ:POo8B4Q1om4A4@7od];B`Ko4Q8B1olJ6QX7
oa<C4`Ko0P823Oooool7ojZZZPOoa<C41_nHV9P7oj:RXPOoO7al1omfMWH6oeiNGPKooooo1omBDU87
oeeMG@Oo^[Zj1_ooool7olS8b0OoXj>S1on8R8P6odA4A0Kooooo1olc<c<7o`0000Ko=cLg1omPH607
o`0000Oo8B4Q1omGEeL6ocTi>@Kooooo1ol30`<6oeQHF0Oo:2PX1ol00007ode=C@Oo9bLW1ol61PH6
o`D51@kooooo000<ooooo`OoG5aL1olg=cL7ojNWY`OoP8201om1@D46oc8b<POo71`L1_lP8206oooo
o`OoTY:B1on=SHd7olG5a@OoVYZJ1on[Zj/6oiZJVPOo`/;21_n2PX86ooooo`OoCDe=1old=3@7ob8R
8POo5QHF1_miNGT7oaHF5POo9RHV1_mHF5P6ooooo`Oo:RXZ1olQ8B47odA4A0OoBd];1_lB4Q87oaXJ
6POo4a<C1_l20P8=ooooo`OoZZZZ1oo4a<@6oiRHV0OoXZ:R1omlO7`7ogIfMPKoGUiN1_ooool7oe9B
DPOoGEeM1onj^[X6ooooo`Oob<S81onSXj<7ohR8R0KoA4A41_ooool7oc<c<`Oo00001_lg=cL7of1P
H0Oo00001olQ8B47oeMGE`Ko>CTi1_ooool7o`<30`KoF5QH1olX:2P7o`0000OoCDe=1olW9bL7o`H6
1PKo1@D53_ooool000cooooo1omLG5`7ocLg=`OoYjNW1on0P807od51@@Ko<S8b1olL71`6ob0P80Ko
oooo1onBTY87ohf=S@OoaLG51onJVYX7oj^[Z`KoVYZJ1oo2`/86oh:2PPKooooo1om=CDd7oc@d=0Oo
8R8R1olF5QH6ogUiN@Oo5QHF1olV9RH6oeQHF0Kooooo1olZ:RX7ob4Q8@OoA4A41om;Bd/6oa8B4POo
6QXJ1olC4a<6o`820Pgooooo1onZZZX7olC4a0KoV9RH1onRXZ87ogalO0OoMWIf1_mNGUh6ooooo`Oo
DU9B1omMGEd7okZj^PKooooo1oo8b<P7oj>SX`OoR8R81_m4A4@6ooooo`Oo<c<c1ol00006ocLg=`Oo
H61P1ol00007ob4Q8@OoEeMG1_li>CT6ooooo`Oo0`<31_mHF5P7obPX:0Oo00001om=CDd7obLW9`Oo
1PH61_l51@D>ooooo`003?ooool7oeaLG0Oo=cLg1onWYjL7oh20P0Oo@D511_lb<S87oa`L70Ko820P
1_ooool7oi:BTPOoSHf=1oo5aLD7oiZJVPOoZj^[1_nJVYX7ol;2`PKoPX:21_ooool7ode=C@Oo=3@d
1olR8R87oaHF5PKoNGUi1olF5QH7obHV9PKoF5QH1_ooool7obXZ:POo8B4Q1om4A4@7od];B`Ko4Q8B
1olJ6QX7oa<C4`Ko0P823Oooool7ojZZZPOoa<C41_nHV9P7oj:RXPOoO7al1omfMWH6oeiNGPKooooo
1omBDU87oeeMG@Oo^[Zj1_ooool7olS8b0OoXj>S1on8R8P6odA4A0Kooooo1olc<c<7o`0000Ko=cLg
1omPH607o`0000Oo8B4Q1omGEeL6ocTi>@Kooooo1ol30`<6oeQHF0Oo:2PX1ol00007ode=C@Oo9bLW
1ol61PH6o`D51@kooooo000<ooooo`OoG5aL1olg=cL7ojNWY`OoP8201om1@D46oc8b<POo71`L1_lP
8206ooooo`OoTY:B1on=SHd7olG5a@OoVYZJ1on[Zj/6oiZJVPOo`/;21_n2PX86ooooo`OoCDe=1old
=3@7ob8R8POo5QHF1_miNGT7oaHF5POo9RHV1_mHF5P6ooooo`Oo:RXZ1olQ8B47odA4A0OoBd];1_lB
4Q87oaXJ6POo4a<C1_l20P8=ooooo`OoZZZZ1oo4a<@6oiRHV0OoXZ:R1omlO7`7ogIfMPKoGUiN1_oo
ool7oe9BDPOoGEeM1onj^[X6ooooo`Oob<S81onSXj<7ohR8R0KoA4A41_ooool7oc<c<`Oo00001_lg
=cL7of1PH0Oo00001olQ8B47oeMGE`Ko>CTi1_ooool7o`<30`KoF5QH1olX:2P7o`0000OoCDe=1olW
9bL7o`H61PKo1@D53_ooool000cooooo1omLG5`7ocLg=`OoYjNW1on0P807od51@@Ko<S8b1olL71`6
ob0P80Kooooo1onBTY87ohf=S@OoaLG51onJVYX7oj^[Z`KoVYZJ1oo2`/86oh:2PPKooooo1om=CDd7
oc@d=0Oo8R8R1olF5QH6ogUiN@Oo5QHF1olV9RH6oeQHF0Kooooo1olZ:RX7ob4Q8@OoA4A41om;Bd/6
oa8B4POo6QXJ1olC4a<6o`820Pgooooo1onZZZX7olC4a0KoV9RH1onRXZ87ogalO0OoMWIf1_mNGUh6
ooooo`OoDU9B1omMGEd7okZj^PKooooo1oo8b<P7oj>SX`OoR8R81_m4A4@6ooooo`Oo<c<c1ol00006
ocLg=`OoH61P1ol00007ob4Q8@OoEeMG1_li>CT6ooooo`Oo0`<31_mHF5P7obPX:0Oo00001om=CDd7
obLW9`Oo1PH61_l51@D>ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`003?ooool7ofa/K0Oo:BTY1oln?Sh7ofYZJPOo
DU9B1_m2@T87ofm_K`KoHV9R1_ooool7oa@D50ko4a<C1olD51@7obDU9@Ko:RXZ1ol/;2`6oadM7@Ko
oooo1onWYjL7oc8b<POoEEEE1omMGEd6ocLg=`OoA4A41olZ:RX6obd];@Kooooo1oo:b/X7of=SH`Oo
820P1oooool6obd];@OoLg=c1ooHf=P6oa@D50Kooooo3_lM7Ad7o`d=3@Ko9BDU1omCDe<7ob/[:`Oo
T92@1_mUIFD6ooooo`Oo>SXj1ol_;bl7oc<c<`go71`L1olK6a/7oahN7PKo4Q8B1_ooool7od92@POo
aLG51_ng]kL7o`T92@Oooooo1om;Bd/7ob8R8PKoXJ6Q1_ooool7oj>SX`Ko>CTi1oo`l?07oe1@D0Oo
71`L1oooool7oa/K6`Ko8R8R3_ooool000cooooo1om/K6`7obTY:@Oo?Shn1omZJVX7oe9BDPKo@T92
1om_Kfl6of9RHPKooooo1olD51@>oa<C4`Oo51@D1olU9BD6obXZ:POo;2`/1_lM7Ad6ooooo`OoYjNW
1olb<S87oeEEE@OoGEeM1_lg=cL7odA4A0Oo:RXZ1_l];Bd6ooooo`Oob/[:1omSHf<7ob0P80Oooooo
1_l];Bd7og=cL`Oof=SH1_lD51@6ooooo`ko7AdM1ol=3@d6obDU9@OoDe=C1ol[:b/7oi2@T0KoIFEU
1_ooool7ocXj>POo;bl_1olc<c<=oa`L70Oo6a/K1olN7Qh6oa8B4PKooooo1om2@T87olG5a@Ko]kNg
1ol92@T7ooooo`OoBd];1olR8R86oj6QX@Kooooo1onSXj<6ocTi>@Ool?3`1om@D507oa`L70Oooooo
1olK6a/6ob8R8Pkooooo000<ooooo`OoK6a/1olY:BT7ochn?POoJVYZ1omBDU86od92@POoKfm_1_mR
HV86ooooo`Oo51@D3_lC4a<7oa@D50Oo9BDU1_lZ:RX7ob`/;0Ko7AdM1_ooool7ojNWY`Oo<S8b1omE
EED7oeeMG@Ko=cLg1om4A4@7obXZ:PKo;Bd]1_ooool7ol[:bPOoHf=S1olP8207ooooo`Ko;Bd]1omc
Lg<7omSHf0Ko51@D1_ooool>oadM7@Oo3@d=1_lU9BD7oe=CD`Oo:b/[1on@T906ofEUI@Kooooo1olj
>SX7obl_;`Oo<c<c3OlL71`7oa/K6`Oo7QhN1_lB4Q86ooooo`Oo@T921oo5aLD6okNg]`Oo2@T91ooo
ool7od];B`Oo8R8R1_nQXJ46ooooo`OoXj>S1_li>CT7oo3`l0OoD51@1olL71`7ooooo`Oo6a/K1_lR
8R8>ooooo`003?ooool7ofa/K0Oo:BTY1oln?Sh7ofYZJPOoDU9B1_m2@T87ofm_K`KoHV9R1_ooool7
oa@D50ko4a<C1olD51@7obDU9@Ko:RXZ1ol/;2`6oadM7@Kooooo1onWYjL7oc8b<POoEEEE1omMGEd6
ocLg=`OoA4A41olZ:RX6obd];@Kooooo1oo:b/X7of=SH`Oo820P1oooool6obd];@OoLg=c1ooHf=P6
oa@D50Kooooo3_lM7Ad7o`d=3@Ko9BDU1omCDe<7ob/[:`OoT92@1_mUIFD6ooooo`Oo>SXj1ol_;bl7
oc<c<`go71`L1olK6a/7oahN7PKo4Q8B1_ooool7od92@POoaLG51_ng]kL7o`T92@Oooooo1om;Bd/7
ob8R8PKoXJ6Q1_ooool7oj>SX`Ko>CTi1oo`l?07oe1@D0Oo71`L1oooool7oa/K6`Ko8R8R3_ooool0
00cooooo1om/K6`7obTY:@Oo?Shn1omZJVX7oe9BDPKo@T921om_Kfl6of9RHPKooooo1olD51@>oa<C
4`Oo51@D1olU9BD6obXZ:POo;2`/1_lM7Ad6ooooo`OoYjNW1olb<S87oeEEE@OoGEeM1_lg=cL7odA4
A0Oo:RXZ1_l];Bd6ooooo`Oob/[:1omSHf<7ob0P80Oooooo1_l];Bd7og=cL`Oof=SH1_lD51@6oooo
o`ko7AdM1ol=3@d6obDU9@OoDe=C1ol[:b/7oi2@T0KoIFEU1_ooool7ocXj>POo;bl_1olc<c<=oa`L
70Oo6a/K1olN7Qh6oa8B4PKooooo1om2@T87olG5a@Ko]kNg1ol92@T7ooooo`OoBd];1olR8R86oj6Q
X@Kooooo1onSXj<6ocTi>@Ool?3`1om@D507oa`L70Oooooo1olK6a/6ob8R8Pkooooo000<ooooo`Oo
K6a/1olY:BT7ochn?POoJVYZ1omBDU86od92@POoKfm_1_mRHV86ooooo`Oo51@D3_lC4a<7oa@D50Oo
9BDU1_lZ:RX7ob`/;0Ko7AdM1_ooool7ojNWY`Oo<S8b1omEEED7oeeMG@Ko=cLg1om4A4@7obXZ:PKo
;Bd]1_ooool7ol[:bPOoHf=S1olP8207ooooo`Ko;Bd]1omcLg<7omSHf0Ko51@D1_ooool>oadM7@Oo
3@d=1_lU9BD7oe=CD`Oo:b/[1on@T906ofEUI@Kooooo1olj>SX7obl_;`Oo<c<c3OlL71`7oa/K6`Oo
7QhN1_lB4Q86ooooo`Oo@T921oo5aLD6okNg]`Oo2@T91oooool7od];B`Oo8R8R1_nQXJ46ooooo`Oo
Xj>S1_li>CT7oo3`l0OoD51@1olL71`7ooooo`Oo6a/K1_lR8R8>ooooo`003?ooool7ofa/K0Oo:BTY
1oln?Sh7ofYZJPOoDU9B1_m2@T87ofm_K`KoHV9R1_ooool7oa@D50ko4a<C1olD51@7obDU9@Ko:RXZ
1ol/;2`6oadM7@Kooooo1onWYjL7oc8b<POoEEEE1omMGEd6ocLg=`OoA4A41olZ:RX6obd];@Kooooo
1oo:b/X7of=SH`Oo820P1oooool6obd];@OoLg=c1ooHf=P6oa@D50Kooooo3_lM7Ad7o`d=3@Ko9BDU
1omCDe<7ob/[:`OoT92@1_mUIFD6ooooo`Oo>SXj1ol_;bl7oc<c<`go71`L1olK6a/7oahN7PKo4Q8B
1_ooool7od92@POoaLG51_ng]kL7o`T92@Oooooo1om;Bd/7ob8R8PKoXJ6Q1_ooool7oj>SX`Ko>CTi
1oo`l?07oe1@D0Oo71`L1oooool7oa/K6`Ko8R8R3_ooool000cooooo1ol@4107odQ8B0Oo?clo1om8
B4P7ob4Q8@KoCTi>1omBDU86oeEEE@Kooooo1olH61P7oa<C4`Oo61PH1olD51@7oaTI6@Ko4Q8B1olG
5aL6oa4A4@Kooooo1omJFUX7obPX:0OojNWY1olH61P6ob<S8`OoXj>S1olP8206ob<S8`Kooooo1omZ
JVX7ogMgM`OoD51@1on<S8`6ode=C@OoinOW1onj^[X6oaHF5PKooooo1ol];Bd7o`h>3POo00001_l=
3@d7oaTI6@Oo?Shn1onQXJ46odQ8B0Kooooo1ol@4107o`P820Oo4Q8B1_l71`L7oa4A4@Oo30`<1olK
6a/6oa`L70Kooooo1olb<S87ok6a/@Ko_[jn1olK6a/7olG5a@OoNWYj1onRXZ86oeMGE`Kooooo1onl
_;`6obl_;`Oo/K6a1on8R8P7og]kN`OoSHf=1om?Cdl6om;BdPkooooo000<ooooo`Oo410@1om8B4P7
oclo?`OoB4Q81olQ8B46odi>CPOoDU9B1_mEEED6ooooo`Oo61PH1olC4a<7oaPH60Oo51@D1olI6AT6
oa8B4POo5aLG1_lA4A46ooooo`OoFUYJ1olX:2P7onWYj@Oo61PH1_lS8b<7oj>SX`Oo820P1_lS8b<6
ooooo`OoJVYZ1omgMgL7oe1@D0OoS8b<1_m=CDd7onOWi`Oo^[Zj1_lF5QH6ooooo`Oo;Bd]1ol>3Ph7
o`0000Ko3@d=1olI6AT7ochn?POoXJ6Q1_m8B4P6ooooo`Oo410@1ol820P7oa8B4PKo1`L71olA4A47
o``<30Oo6a/K1_lL71`6ooooo`Oo<S8b1ona/K46okjn_POo6a/K1oo5aLD7ogYjNPOoXZ:R1_mGEeL6
ooooo`Oo_;bl1_l_;bl7ok6a/@OoR8R81omkNg/7ohf=S@OoCdm?1_oBd]8>ooooo`003?ooool7oa0@
40OoB4Q81olo?cl7odQ8B0Oo8B4Q1_m>CTh7oe9BDPKoEEEE1_ooool7oaPH60Oo4a<C1olH61P7oa@D
50Oo6ATI1_lB4Q87oaLG5`Ko4A4A1_ooool7oeYJFPOo:2PX1ooYjNT7oaPH60Ko8b<S1onSXj<7ob0P
80Ko8b<S1_ooool7ofYZJPOoMgMg1om@D507ohb<S0KoCDe=1ooWinL7okZj^PKo5QHF1_ooool7obd]
;@Oo3Ph>1ol00006o`d=3@Oo6ATI1oln?Sh7oj6QX@KoB4Q81_ooool7oa0@40Oo20P81olB4Q86o`L7
1`Oo4A4A1ol<30`7oa/K6`Ko71`L1_ooool7oc8b<POo/K6a1_nn_[h7oa/K6`OoaLG51omjNWX7oj:R
XPKoEeMG1_ooool7okbl_0Ko;bl_1ona/K47ohR8R0OoNg]k1on=SHd7odm?C`Kod];B3_ooool000co
oooo1ol@4107odQ8B0Oo?clo1om8B4P7ob4Q8@KoCTi>1omBDU86oeEEE@Kooooo1olH61P7oa<C4`Oo
61PH1olD51@7oaTI6@Ko4Q8B1olG5aL6oa4A4@Kooooo1omJFUX7obPX:0OojNWY1olH61P6ob<S8`Oo
Xj>S1olP8206ob<S8`Kooooo1omZJVX7ogMgM`OoD51@1on<S8`6ode=C@OoinOW1onj^[X6oaHF5PKo
oooo1ol];Bd7o`h>3POo00001_l=3@d7oaTI6@Oo?Shn1onQXJ46odQ8B0Kooooo1ol@4107o`P820Oo
4Q8B1_l71`L7oa4A4@Oo30`<1olK6a/6oa`L70Kooooo1olb<S87ok6a/@Ko_[jn1olK6a/7olG5a@Oo
NWYj1onRXZ86oeMGE`Kooooo1onl_;`6obl_;`Oo/K6a1on8R8P7og]kN`OoSHf=1om?Cdl6om;BdPko
oooo000<ooooo`Oo410@1om8B4P7oclo?`OoB4Q81olQ8B46odi>CPOoDU9B1_mEEED6ooooo`Oo61PH
1olC4a<7oaPH60Oo51@D1olI6AT6oa8B4POo5aLG1_lA4A46ooooo`OoFUYJ1olX:2P7onWYj@Oo61PH
1_lS8b<7oj>SX`Oo820P1_lS8b<6ooooo`OoJVYZ1omgMgL7oe1@D0OoS8b<1_m=CDd7onOWi`Oo^[Zj
1_lF5QH6ooooo`Oo;Bd]1ol>3Ph7o`0000Ko3@d=1olI6AT7ochn?POoXJ6Q1_m8B4P6ooooo`Oo410@
1ol820P7oa8B4PKo1`L71olA4A47o``<30Oo6a/K1_lL71`6ooooo`Oo<S8b1ona/K46okjn_POo6a/K
1oo5aLD7ogYjNPOoXZ:R1_mGEeL6ooooo`Oo_;bl1_l_;bl7ok6a/@OoR8R81omkNg/7ohf=S@OoCdm?
1_oBd]8>ooooo`003?ooool7oa0@40OoB4Q81olo?cl7odQ8B0Oo8B4Q1_m>CTh7oe9BDPKoEEEE1_oo
ool7oaPH60Oo4a<C1olH61P7oa@D50Oo6ATI1_lB4Q87oaLG5`Ko4A4A1_ooool7oeYJFPOo:2PX1ooY
jNT7oaPH60Ko8b<S1onSXj<7ob0P80Ko8b<S1_ooool7ofYZJPOoMgMg1om@D507ohb<S0KoCDe=1ooW
inL7okZj^PKo5QHF1_ooool7obd];@Oo3Ph>1ol00006o`d=3@Oo6ATI1oln?Sh7oj6QX@KoB4Q81_oo
ool7oa0@40Oo20P81olB4Q86o`L71`Oo4A4A1ol<30`7oa/K6`Ko71`L1_ooool7oc8b<POo/K6a1_nn
_[h7oa/K6`OoaLG51omjNWX7oj:RXPKoEeMG1_ooool7okbl_0Ko;bl_1ona/K47ohR8R0OoNg]k1on=
SHd7odm?C`Kod];B3_ooool000cooooo1ol@4107odQ8B0Oo?clo1om8B4P7ob4Q8@KoCTi>1omBDU86
oeEEE@Kooooo1olH61P7oa<C4`Oo61PH1olD51@7oaTI6@Ko4Q8B1olG5aL6oa4A4@Kooooo1omJFUX7
obPX:0OojNWY1olH61P6ob<S8`OoXj>S1olP8206ob<S8`Kooooo1omZJVX7ogMgM`OoD51@1on<S8`6
ode=C@OoinOW1onj^[X6oaHF5PKooooo1ol];Bd7o`h>3POo00001_l=3@d7oaTI6@Oo?Shn1onQXJ46
odQ8B0Kooooo1ol@4107o`P820Oo4Q8B1_l71`L7oa4A4@Oo30`<1olK6a/6oa`L70Kooooo1olb<S87
ok6a/@Ko_[jn1olK6a/7olG5a@OoNWYj1onRXZ86oeMGE`Kooooo1onl_;`6obl_;`Oo/K6a1on8R8P7
og]kN`OoSHf=1om?Cdl6om;BdPkooooo000<ooooo`OoZj^[1on^[Zh7ofa/K0Oooooo1onMWId6ojBT
Y0Oof][J1_nj^[X6ooooo`Oo5QHF1olU9BD7oa`L70Oo820P1olM7Ad6ob/[:`Oo8R8R1_lC4a<6oooo
o`OoQHF51on:RXX7oiVIV@Oo<C4a1_o5aLD7oeaLG0Oo6a/K1_nEUID6ooooo`OoL71`1olA4A47oc`l
?0Oo_Kfm1_l71`L7ohn?S`OogmoO1_lX:2P6ooooo`Oo7QhN1ol=3@d7oadM7@Ko410@1omKFe/7oeIF
EPOoR8R81_mJFUX6ooooo`Oo61PH1ol:2PX7o`0000Ko1@D51ol10@47oa4A4@Oo4a<C1_lM7Ad6oooo
o`Oo92@T1onFUYH6ok2`/0Oo8b<S1ooQhN47odA4A0OoKFe]1_n9RHT6ooooo`Oo`<301_lS8b<7okJf
]POoG5aL1omCDe<7on3Ph0Oo=3@d1_mZJVX>ooooo`003?ooool7oj^[Z`Oo[Zj^1om/K6`7ooooo`Oo
WIfM1_nTY:@7om[JfPKo^[Zj1_ooool7oaHF5POo9BDU1olL71`7ob0P80Oo7AdM1_l[:b/7ob8R8PKo
4a<C1_ooool7ohF5Q@OoRXZ:1onIVIT7oc4a<@KoaLG51omLG5`7oa/K6`KoUIFE1_ooool7og1`L0Oo
4A4A1oll?3`7okfm_@Ko1`L71on?Shl7omoOg`Ko:2PX1_ooool7oahN7POo3@d=1olM7Ad6oa0@40Oo
Fe]K1omFEUH7ohR8R0KoFUYJ1_ooool7oaPH60Oo2PX:1ol00006o`D51@Oo0@411olA4A47oa<C4`Ko
7AdM1_ooool7ob@T90OoUYJF1_n`/;07ob<S8`OohN7Q1om4A4@7ofe]K@KoRHV91_ooool7ol30`0Ko
8b<S1onf][H7oeaLG0OoDe=C1ooPh>07oc@d=0KoJVYZ3_ooool000cooooo1on[Zj/7ojj^[POoK6a/
1oooool7oifMW@KoY:BT1ooJf]X6okZj^PKooooo1olF5QH7obDU9@Oo71`L1olP8207oadM7@Ko:b/[
1olR8R86oa<C4`Kooooo1on5QHD7ohZ:RPOoVIVI1ola<C46olG5a@OoG5aL1olK6a/6oiFEU@Kooooo
1om`L707oa4A4@Oo?3`l1onm_Kd6o`L71`OoShn?1ooOgml6obPX:0Kooooo1olN7Qh7o`d=3@Oo7AdM
1_l@4107oe]KF`OoEUIF1on8R8P6oeYJFPKooooo1olH61P7o`X:2POo00001_l51@D7o`410@Oo4A4A
1olC4a<6oadM7@Kooooo1olT92@7oiJFUPKo/;2`1olS8b<7on7Qh@OoA4A41om]KFd6ohV9R@Kooooo
1oo0`<06ob<S8`Oo][Jf1omLG5`7oe=CD`Ooh>3P1old=3@6ofYZJPkooooo000<ooooo`OoZj^[1on^
[Zh7ofa/K0Oooooo1onMWId6ojBTY0Oof][J1_nj^[X6ooooo`Oo5QHF1olU9BD7oa`L70Oo820P1olM
7Ad6ob/[:`Oo8R8R1_lC4a<6ooooo`OoQHF51on:RXX7oiVIV@Oo<C4a1_o5aLD7oeaLG0Oo6a/K1_nE
UID6ooooo`OoL71`1olA4A47oc`l?0Oo_Kfm1_l71`L7ohn?S`OogmoO1_lX:2P6ooooo`Oo7QhN1ol=
3@d7oadM7@Ko410@1omKFe/7oeIFEPOoR8R81_mJFUX6ooooo`Oo61PH1ol:2PX7o`0000Ko1@D51ol1
0@47oa4A4@Oo4a<C1_lM7Ad6ooooo`Oo92@T1onFUYH6ok2`/0Oo8b<S1ooQhN47odA4A0OoKFe]1_n9
RHT6ooooo`Oo`<301_lS8b<7okJf]POoG5aL1omCDe<7on3Ph0Oo=3@d1_mZJVX>ooooo`003?ooool7
oj^[Z`Oo[Zj^1om/K6`7ooooo`OoWIfM1_nTY:@7om[JfPKo^[Zj1_ooool7oaHF5POo9BDU1olL71`7
ob0P80Oo7AdM1_l[:b/7ob8R8PKo4a<C1_ooool7ohF5Q@OoRXZ:1onIVIT7oc4a<@KoaLG51omLG5`7
oa/K6`KoUIFE1_ooool7og1`L0Oo4A4A1oll?3`7okfm_@Ko1`L71on?Shl7omoOg`Ko:2PX1_ooool7
oahN7POo3@d=1olM7Ad6oa0@40OoFe]K1omFEUH7ohR8R0KoFUYJ1_ooool7oaPH60Oo2PX:1ol00006
o`D51@Oo0@411olA4A47oa<C4`Ko7AdM1_ooool7ob@T90OoUYJF1_n`/;07ob<S8`OohN7Q1om4A4@7
ofe]K@KoRHV91_ooool7ol30`0Ko8b<S1onf][H7oeaLG0OoDe=C1ooPh>07oc@d=0KoJVYZ3_ooool0
00cooooo1on[Zj/7ojj^[POoK6a/1oooool7oifMW@KoY:BT1ooJf]X6okZj^PKooooo1olF5QH7obDU
9@Oo71`L1olP8207oadM7@Ko:b/[1olR8R86oa<C4`Kooooo1on5QHD7ohZ:RPOoVIVI1ola<C46olG5
a@OoG5aL1olK6a/6oiFEU@Kooooo1om`L707oa4A4@Oo?3`l1onm_Kd6o`L71`OoShn?1ooOgml6obPX
:0Kooooo1olN7Qh7o`d=3@Oo7AdM1_l@4107oe]KF`OoEUIF1on8R8P6oeYJFPKooooo1olH61P7o`X:
2POo00001_l51@D7o`410@Oo4A4A1olC4a<6oadM7@Kooooo1olT92@7oiJFUPKo/;2`1olS8b<7on7Q
h@OoA4A41om]KFd6ohV9R@Kooooo1oo0`<06ob<S8`Oo][Jf1omLG5`7oe=CD`Ooh>3P1old=3@6ofYZ
JPkooooo000<ooooo`Oo6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo
61PH1olK6a/>oa<C4`Oo6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@Ko
N7Qh1onYZJT7ofEUI@KoA4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko
30`<1_ooool7oaTI6@ko410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo
7QhN1_lR8R87oa0@40Oo820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo
6a/K1on5QHD6ogQhN0Kooooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@ko
oooo000<ooooo`Oo6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH
1olK6a/>oa<C4`Oo6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh
1onYZJT7ofEUI@KoA4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<
1_ooool7oaTI6@ko410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN
1_lR8R87oa0@40Oo820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K
1on5QHD6ogQhN0Kooooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo
000<ooooo`Oo6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH1olK
6a/>oa<C4`Oo6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh1onY
ZJT7ofEUI@KoA4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<1_oo
ool7oaTI6@ko410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN1_lR
8R87oa0@40Oo820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K1on5
QHD6ogQhN0Kooooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo000<
ooooo`Oo6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH1olK6a/>
oa<C4`Oo6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh1onYZJT7
ofEUI@KoA4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<1_ooool7
oaTI6@ko410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN1_lR8R87
oa0@40Oo820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K1on5QHD6
ogQhN0Kooooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo000<oooo
o`Oo6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH1olK6a/>oa<C
4`Oo6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh1onYZJT7ofEU
I@KoA4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<1_ooool7oaTI
6@ko410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN1_lR8R87oa0@
40Oo820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K1on5QHD6ogQh
N0Kooooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo000<ooooo`Oo
6QXJ1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH1olK6a/>oa<C4`Oo
6a/K1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh1onYZJT7ofEUI@Ko
A4A41_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<1_ooool7oaTI6@ko
410@1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN1_lR8R87oa0@40Oo
820P1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K1on5QHD6ogQhN0Ko
oooo1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo000<ooooo`Oo6QXJ
1oli>CT7oe5AD@OoA4A41om;Bd/6ofQXJ0Oo=cLg1_m5ADD6ooooo`Oo61PH1olK6a/>oa<C4`Oo6a/K
1_lI6AT7ob0P80Ko7alO1_ooool7ofEUI@OoKFe]1ooXj>P7oaTI6@KoN7Qh1onYZJT7ofEUI@KoA4A4
1_ooool7ocPh>0Oo410@1omDE5@7ochn?PKo1PH61on8R8P7oc4a<@Ko30`<1_ooool7oaTI6@ko410@
1_l`<307oeEEE@Oo>c/k1ooemOD6og5aL@Kooooo1olM7Ad7oaDE5@Oo7QhN1_lR8R87oa0@40Oo820P
1olT92@6oaPH60Kooooo1ol71`L7om?Cd`KoADE51olG5aL7ooKfmPOo6a/K1on5QHD6ogQhN0Kooooo
1ol_;bl6oaHF5POofMWI1olM7Ad7ofi^KPOoalO71olL71`6olW9b@kooooo000<ooooo`OoWIfM1onn
_[h7ogMgM`Ook^k^1on8R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA
4A46oaPH60Oo5aLG1_lC4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nM
WId6ooooo`Oo4a<C1olD51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=
3@d7oahN7PKo4a<C1omTI6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP
8206ob4Q8@Kooooo1olg=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJ
FUX6oe=CD`OoB4Q81om1@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7
ogMgM`Ook^k^1on8R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46
oaPH60Oo5aLG1_lC4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6
ooooo`Oo4a<C1olD51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7
oahN7PKo4a<C1omTI6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206
ob4Q8@Kooooo1olg=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6
oe=CD`OoB4Q81om1@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7ogMg
M`Ook^k^1on8R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46oaPH
60Oo5aLG1_lC4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6oooo
o`Oo4a<C1olD51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7oahN
7PKo4a<C1omTI6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206ob4Q
8@Kooooo1olg=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6oe=C
D`OoB4Q81om1@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7ogMgM`Oo
k^k^1on8R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46oaPH60Oo
5aLG1_lC4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6ooooo`Oo
4a<C1olD51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7oahN7PKo
4a<C1omTI6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206ob4Q8@Ko
oooo1olg=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6oe=CD`Oo
B4Q81om1@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7ogMgM`Ook^k^
1on8R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46oaPH60Oo5aLG
1_lC4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6ooooo`Oo4a<C
1olD51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7oahN7PKo4a<C
1omTI6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206ob4Q8@Kooooo
1olg=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6oe=CD`OoB4Q8
1om1@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7ogMgM`Ook^k^1on8
R8P6oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46oaPH60Oo5aLG1_lC
4a<6ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6ooooo`Oo4a<C1olD
51@7oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7oahN7PKo4a<C1omT
I6@7of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206ob4Q8@Kooooo1olg
=cL7odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6oe=CD`OoB4Q81om1
@D47ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`OoWIfM1onn_[h7ogMgM`Ook^k^1on8R8P6
oi^KV`Oo/K6a1_o;bl/6ooooo`Oo51@D1olP8207oaLG5`Oo51@D1olA4A46oaPH60Oo5aLG1_lC4a<6
ooooo`Oo9BDU1omSHf<7om?Cd`Oo30`<1_o@d=07ofe]K@Oo>3Ph1_nMWId6ooooo`Oo4a<C1olD51@7
oe5AD@Oo<S8b1_l;2`/7oda<C0Oo:b/[1_lQ8B46ooooo`Oo9RHV1ol=3@d7oahN7PKo4a<C1omTI6@7
of9RHPOoZZZZ1_ln?Sh6ooooo`ko=cLg1oln?Sh6ocHf=POo:2PX3_lP8206ob4Q8@Kooooo1olg=cL7
odE5A@KoCTi>1omYJFT7of9RHPOo9bLW1oo1`L46obXZ:PKooooo1omJFUX6oe=CD`OoB4Q81om1@D47
ok2`/0OoH61P1olM7Ad6ojNWY`kooooo000<ooooo`Oo00001old=3@7ob4Q8@Oo?Shn1olK6a/6odI6
APOo71`L1_l];Bd6ooooo`Oo8R8R1olS8b<7oaLG5`Oo2@T91ol:2PX=oaHF5PKo30`<1_ooool7oc@d
=0Oo/K6a1omZJVX7o`h>3PKooooo1om:BTX7ofYZJPKoOWin1_ooool7ob4Q8@OoIVIV1ol[:b/7o`00
00Ko<C4a1ol_;bl7o`<30`Ko1`L71_ooool7oaPH60Oo8b<S1olA4A46oc8b<POo?3`l1om7AdL7oooo
o`KoNGUi1_ooool7oc@d=0Oo;2`/1om4A4@6obLW9`Oo=CDe1ol/;2`7obh^;PKo6QXJ1_ooool7oc0`
<0OoHV9R1_l71`L7oahN7POoPH611ol>3Ph7oeiNGPKoCdm?1_ooool7o`P820Ko6QXJ1omnOWh7o`T9
2@Oo?3`l1onATI47od10@0KoC4a<3_ooool000cooooo1ol00007oc@d=0Oo8B4Q1oln?Sh7oa/K6`Ko
ATI61olL71`6obd];@Kooooo1olR8R87ob<S8`Oo5aLG1ol92@T7o`X:2Pgo5QHF1_l<30`6ooooo`Oo
=3@d1ona/K47ofYZJPOo3Ph>1_ooool7odY:BPOoJVYZ1_mnOWh6ooooo`Oo8B4Q1omVIVH7ob/[:`Oo
00001_la<C47obl_;`Oo0`<31_l71`L6ooooo`Oo61PH1olS8b<7oa4A4@Ko<S8b1oll?3`7odM7A`Oo
oooo1_miNGT6ooooo`Oo=3@d1ol/;2`7odA4A0Ko9bLW1ole=CD7ob`/;0Oo;Rh^1_lJ6QX6ooooo`Oo
<30`1omRHV86o`L71`Oo7QhN1on1PH47o`h>3POoGUiN1_m?Cdl6ooooo`Oo20P81_lJ6QX7oginOPOo
2@T91oll?3`7oi6AT@Oo@4101_m<C4`>ooooo`003?ooool7o`0000Oo=3@d1olQ8B47ochn?POo6a/K
1_m6ATH7oa`L70Ko;Bd]1_ooool7ob8R8POo8b<S1olG5aL7o`T92@Oo2PX:3OlF5QH6o``<30Kooooo
1old=3@7ok6a/@OoJVYZ1ol>3Ph6ooooo`OoBTY:1omZJVX6oginOPKooooo1olQ8B47ofIVIPOo:b/[
1ol00006oc4a<@Oo;bl_1ol30`<6o`L71`Kooooo1olH61P7ob<S8`Oo4A4A1_lb<S87oc`l?0OoAdM7
1oooool6ogUiN@Kooooo1old=3@7ob`/;0OoA4A41_lW9bL7ocDe=@Oo;2`/1ol^;Rh6oaXJ6PKooooo
1ol`<307of9RHPKo1`L71olN7Qh7oh61P@Oo3Ph>1omNGUh6odm?C`Kooooo1ol820P6oaXJ6POoOWin
1ol92@T7oc`l?0OoTI6A1om0@406oda<C0kooooo000<ooooo`Oo00001old=3@7ob4Q8@Oo?Shn1olK
6a/6odI6APOo71`L1_l];Bd6ooooo`Oo8R8R1olS8b<7oaLG5`Oo2@T91ol:2PX=oaHF5PKo30`<1_oo
ool7oc@d=0Oo/K6a1omZJVX7o`h>3PKooooo1om:BTX7ofYZJPKoOWin1_ooool7ob4Q8@OoIVIV1ol[
:b/7o`0000Ko<C4a1ol_;bl7o`<30`Ko1`L71_ooool7oaPH60Oo8b<S1olA4A46oc8b<POo?3`l1om7
AdL7ooooo`KoNGUi1_ooool7oc@d=0Oo;2`/1om4A4@6obLW9`Oo=CDe1ol/;2`7obh^;PKo6QXJ1_oo
ool7oc0`<0OoHV9R1_l71`L7oahN7POoPH611ol>3Ph7oeiNGPKoCdm?1_ooool7o`P820Ko6QXJ1omn
OWh7o`T92@Oo?3`l1onATI47od10@0KoC4a<3_ooool000cooooo1ol00007oc@d=0Oo8B4Q1oln?Sh7
oa/K6`KoATI61olL71`6obd];@Kooooo1olR8R87ob<S8`Oo5aLG1ol92@T7o`X:2Pgo5QHF1_l<30`6
ooooo`Oo=3@d1ona/K47ofYZJPOo3Ph>1_ooool7odY:BPOoJVYZ1_mnOWh6ooooo`Oo8B4Q1omVIVH7
ob/[:`Oo00001_la<C47obl_;`Oo0`<31_l71`L6ooooo`Oo61PH1olS8b<7oa4A4@Ko<S8b1oll?3`7
odM7A`Oooooo1_miNGT6ooooo`Oo=3@d1ol/;2`7odA4A0Ko9bLW1ole=CD7ob`/;0Oo;Rh^1_lJ6QX6
ooooo`Oo<30`1omRHV86o`L71`Oo7QhN1on1PH47o`h>3POoGUiN1_m?Cdl6ooooo`Oo20P81_lJ6QX7
oginOPOo2@T91oll?3`7oi6AT@Oo@4101_m<C4`>ooooo`003?ooool7o`0000Oo=3@d1olQ8B47ochn
?POo6a/K1_m6ATH7oa`L70Ko;Bd]1_ooool7ob8R8POo8b<S1olG5aL7o`T92@Oo2PX:3OlF5QH6o``<
30Kooooo1old=3@7ok6a/@OoJVYZ1ol>3Ph6ooooo`OoBTY:1omZJVX6oginOPKooooo1olQ8B47ofIV
IPOo:b/[1ol00006oc4a<@Oo;bl_1ol30`<6o`L71`Kooooo1olH61P7ob<S8`Oo4A4A1_lb<S87oc`l
?0OoAdM71oooool6ogUiN@Kooooo1old=3@7ob`/;0OoA4A41_lW9bL7ocDe=@Oo;2`/1ol^;Rh6oaXJ
6PKooooo1ol`<307of9RHPKo1`L71olN7Qh7oh61P@Oo3Ph>1omNGUh6odm?C`Kooooo1ol820P6oaXJ
6POoOWin1ol92@T7oc`l?0OoTI6A1om0@406oda<C0kooooo000<ooooo`OoHF5Q1omDE5@7obl_;`Oo
RXZ:1omMGEd6odi>CPOoNg]k1_mWIfL6ooooo`Oo6ATI1olE5AD7o`l?3`Oo1@D51ol;2`/6o`0000Oo
1@D51_lA4A46ooooo`Oo92@T1omDE5@7oibLW0Oo>SXj1_n6QXH7oe]KF`OoRHV91_mFEUH6ooooo`Oo
4Q8B1om:BTX7ogAdM0Oo7QhN1_li>CT7oe]KF`Oo8B4Q1_l00006ooooo`Oo92@T1ol@4107obPX:0Ko
1PH61ola<C47oeiNGPOoWYjN1_m2@T86ooooo`Oo4A4A1olI6AT7ob0P80Ko<C4a1olE5AD7obh^;POo
9RHV1_lS8b<6ooooo`OoDU9B1ole=CD6oadM7@OoJFUY1olN7Qh7oa@D50OoS8b<1_l00006ooooo`Oo
9BDU1_ln?Sh>o`l?3`OoMGEe1ol00007o`X:2PKoNWYj3_ooool000cooooo1omQHF47oeADE0Oo;bl_
1on:RXX7oeeMG@KoCTi>1omkNg/6ofMWI`Kooooo1olI6AT7oaDE5@Oo3`l?1ol51@D7o`/;2`Ko0000
1ol51@D6oa4A4@Kooooo1olT92@7oeADE0OoW9bL1olj>SX6ohJ6QPOoFe]K1on9RHT6oeIFEPKooooo
1olB4Q87odY:BPOoM7Ad1olN7Qh6ocTi>@OoFe]K1olQ8B46o`0000Kooooo1olT92@7oa0@40Oo:2PX
1_l61PH7oc4a<@OoGUiN1onNWYh6od92@PKooooo1olA4A47oaTI6@Oo820P1_la<C47oaDE5@Oo;Rh^
1olV9RH6ob<S8`Kooooo1omBDU87ocDe=@Ko7AdM1omYJFT7oahN7POo51@D1on<S8`6o`0000Kooooo
1olU9BD6ochn?Pko3`l?1omeMGD7o`0000Oo2PX:1_mjNWX>ooooo`003?ooool7of5QH@OoE5AD1ol_
;bl7ohZ:RPOoGEeM1_m>CTh7og]kN`KoIfMW1_ooool7oaTI6@Oo5ADE1ol?3`l7o`D51@Oo2`/;1_l0
0007o`D51@Ko4A4A1_ooool7ob@T90OoE5AD1onLW9`7ocXj>PKoQXJ61omKFe/7ohV9R@KoEUIF1_oo
ool7oa8B4POoBTY:1omdM7@7oahN7PKo>CTi1omKFe/7ob4Q8@Ko00001_ooool7ob@T90Oo410@1olX
:2P6o`H61POo<C4a1omNGUh7oijNWPKo@T921_ooool7oa4A4@Oo6ATI1olP8206oc4a<@Oo5ADE1ol^
;Rh7obHV9PKo8b<S1_ooool7oe9BDPOo=CDe1_lM7Ad7ofUYJ@Oo7QhN1olD51@7ohb<S0Ko00001_oo
ool7obDU9@Ko?Shn3_l?3`l7ogEeM@Oo00001ol:2PX6ogYjNPkooooo000<ooooo`OoHF5Q1omDE5@7
obl_;`OoRXZ:1omMGEd6odi>CPOoNg]k1_mWIfL6ooooo`Oo6ATI1olE5AD7o`l?3`Oo1@D51ol;2`/6
o`0000Oo1@D51_lA4A46ooooo`Oo92@T1omDE5@7oibLW0Oo>SXj1_n6QXH7oe]KF`OoRHV91_mFEUH6
ooooo`Oo4Q8B1om:BTX7ogAdM0Oo7QhN1_li>CT7oe]KF`Oo8B4Q1_l00006ooooo`Oo92@T1ol@4107
obPX:0Ko1PH61ola<C47oeiNGPOoWYjN1_m2@T86ooooo`Oo4A4A1olI6AT7ob0P80Ko<C4a1olE5AD7
obh^;POo9RHV1_lS8b<6ooooo`OoDU9B1ole=CD6oadM7@OoJFUY1olN7Qh7oa@D50OoS8b<1_l00006
ooooo`Oo9BDU1_ln?Sh>o`l?3`OoMGEe1ol00007o`X:2PKoNWYj3_ooool000cooooo1omQHF47oeAD
E0Oo;bl_1on:RXX7oeeMG@KoCTi>1omkNg/6ofMWI`Kooooo1olI6AT7oaDE5@Oo3`l?1ol51@D7o`/;
2`Ko00001ol51@D6oa4A4@Kooooo1olT92@7oeADE0OoW9bL1olj>SX6ohJ6QPOoFe]K1on9RHT6oeIF
EPKooooo1olB4Q87odY:BPOoM7Ad1olN7Qh6ocTi>@OoFe]K1olQ8B46o`0000Kooooo1olT92@7oa0@
40Oo:2PX1_l61PH7oc4a<@OoGUiN1onNWYh6od92@PKooooo1olA4A47oaTI6@Oo820P1_la<C47oaDE
5@Oo;Rh^1olV9RH6ob<S8`Kooooo1omBDU87ocDe=@Ko7AdM1omYJFT7oahN7POo51@D1on<S8`6o`00
00Kooooo1olU9BD6ochn?Pko3`l?1omeMGD7o`0000Oo2PX:1_mjNWX>ooooo`003?ooool7of5QH@Oo
E5AD1ol_;bl7ohZ:RPOoGEeM1_m>CTh7og]kN`KoIfMW1_ooool7oaTI6@Oo5ADE1ol?3`l7o`D51@Oo
2`/;1_l00007o`D51@Ko4A4A1_ooool7ob@T90OoE5AD1onLW9`7ocXj>PKoQXJ61omKFe/7ohV9R@Ko
EUIF1_ooool7oa8B4POoBTY:1omdM7@7oahN7PKo>CTi1omKFe/7ob4Q8@Ko00001_ooool7ob@T90Oo
410@1olX:2P6o`H61POo<C4a1omNGUh7oijNWPKo@T921_ooool7oa4A4@Oo6ATI1olP8206oc4a<@Oo
5ADE1ol^;Rh7obHV9PKo8b<S1_ooool7oe9BDPOo=CDe1_lM7Ad7ofUYJ@Oo7QhN1olD51@7ohb<S0Ko
00001_ooool7obDU9@Ko?Shn3_l?3`l7ogEeM@Oo00001ol:2PX6ogYjNPkooooo000<ooooo`OoHF5Q
1omDE5@7obl_;`OoRXZ:1omMGEd6odi>CPOoNg]k1_mWIfL6ooooo`Oo6ATI1olE5AD7o`l?3`Oo1@D5
1ol;2`/6o`0000Oo1@D51_lA4A46ooooo`Oo92@T1omDE5@7oibLW0Oo>SXj1_n6QXH7oe]KF`OoRHV9
1_mFEUH6ooooo`Oo4Q8B1om:BTX7ogAdM0Oo7QhN1_li>CT7oe]KF`Oo8B4Q1_l00006ooooo`Oo92@T
1ol@4107obPX:0Ko1PH61ola<C47oeiNGPOoWYjN1_m2@T86ooooo`Oo4A4A1olI6AT7ob0P80Ko<C4a
1olE5AD7obh^;POo9RHV1_lS8b<6ooooo`OoDU9B1ole=CD6oadM7@OoJFUY1olN7Qh7oa@D50OoS8b<
1_l00006ooooo`Oo9BDU1_ln?Sh>o`l?3`OoMGEe1ol00007o`X:2PKoNWYj3_ooool000cooooo1omS
Hf<7ogQhN0OoOWin1onCTi<7oj:RXPKoTi>C1ond];@6okbl_0Kooooo1om1@D47ochn?POoCDe=1olf
=SH7od];B`KoQXJ61oooool6ojZZZPKooooo1olB4Q87ocDe=@Oo820P1olY:BT6ob4Q8@Oo92@T1omK
Fe/6o`0000Kooooo1omMGEd7oiZJVPOo20P81on:RXX6oeYJFPOo9bLW1on2PX86oalO7`Kooooo1olj
>SX7oc`l?0Oo;Bd]1_lL71`7ofa/K0OoEEEE1onYZJT6oeaLG0Kooooo1oogmoL7ooooo`OoPH611_m:
BTX7oeIFEPOo>SXj1om4A4@6odM7A`Kooooo1ol];Bd7oalO7`KoVYZJ1olF5QH7ob4Q8@OoNg]k1ole
=CD6o`0000Kooooo1on2PX86oa@D50Oo1`L71om]KFd7oc0`<0Oo4A4A1omCDe<6odE5A@kooooo000<
ooooo`OoHf=S1omhN7P7oginOPOoTi>C1onRXZ86oi>CT`Oo];Bd1_nl_;`6ooooo`Oo@D511oln?Sh7
ode=C@Oo=SHf1om;Bd/6ohJ6QPOooooo1_nZZZX6ooooo`Oo4Q8B1ole=CD7ob0P80Oo:BTY1_lQ8B47
ob@T90OoFe]K1_l00006ooooo`OoGEeM1onJVYX7o`P820OoRXZ:1_mJFUX7obLW9`OoPX:21_lO7al6
ooooo`Oo>SXj1oll?3`7obd];@Ko71`L1om/K6`7oeEEE@OoZJVY1_mLG5`6ooooo`OomoOg1oooool7
oh61P@KoBTY:1omFEUH7ocXj>POoA4A41_m7AdL6ooooo`Oo;Bd]1olO7al6oiZJVPOo5QHF1olQ8B47
og]kN`Oo=CDe1_l00006ooooo`OoPX:21_lD51@7o`L71`OoKFe]1ol`<307oa4A4@OoDe=C1_m5ADD>
ooooo`003?ooool7of=SH`OoN7Qh1omnOWh7oi>CT`OoXZ:R1_nCTi<7okBd]0Ko_;bl1_ooool7od51
@@Oo?Shn1om=CDd7ocHf=POoBd];1_n6QXH7ooooo`KoZZZZ1_ooool7oa8B4POo=CDe1olP8207obTY
:@Ko8B4Q1olT92@7oe]KF`Ko00001_ooool7oeeMG@OoVYZJ1ol820P7ohZ:RPKoFUYJ1olW9bL7oh:2
PPKo7alO1_ooool7ocXj>POo?3`l1ol];Bd6oa`L70OoK6a/1omEEED7ojVYZ@KoG5aL1_ooool7ooOg
m`Oooooo1on1PH46odY:BPOoEUIF1olj>SX7odA4A0KoAdM71_ooool7obd];@Oo7alO1_nJVYX7oaHF
5POo8B4Q1omkNg/7ocDe=@Ko00001_ooool7oh:2PPKo51@D1ol71`L7ofe]K@Oo<30`1olA4A47oe=C
D`KoADE53_ooool000cooooo1omSHf<7ogQhN0OoOWin1onCTi<7oj:RXPKoTi>C1ond];@6okbl_0Ko
oooo1om1@D47ochn?POoCDe=1olf=SH7od];B`KoQXJ61oooool6ojZZZPKooooo1olB4Q87ocDe=@Oo
820P1olY:BT6ob4Q8@Oo92@T1omKFe/6o`0000Kooooo1omMGEd7oiZJVPOo20P81on:RXX6oeYJFPOo
9bLW1on2PX86oalO7`Kooooo1olj>SX7oc`l?0Oo;Bd]1_lL71`7ofa/K0OoEEEE1onYZJT6oeaLG0Ko
oooo1oogmoL7ooooo`OoPH611_m:BTX7oeIFEPOo>SXj1om4A4@6odM7A`Kooooo1ol];Bd7oalO7`Ko
VYZJ1olF5QH7ob4Q8@OoNg]k1ole=CD6o`0000Kooooo1on2PX86oa@D50Oo1`L71om]KFd7oc0`<0Oo
4A4A1omCDe<6odE5A@kooooo000<ooooo`OoHf=S1omhN7P7oginOPOoTi>C1onRXZ86oi>CT`Oo];Bd
1_nl_;`6ooooo`Oo@D511oln?Sh7ode=C@Oo=SHf1om;Bd/6ohJ6QPOooooo1_nZZZX6ooooo`Oo4Q8B
1ole=CD7ob0P80Oo:BTY1_lQ8B47ob@T90OoFe]K1_l00006ooooo`OoGEeM1onJVYX7o`P820OoRXZ:
1_mJFUX7obLW9`OoPX:21_lO7al6ooooo`Oo>SXj1oll?3`7obd];@Ko71`L1om/K6`7oeEEE@OoZJVY
1_mLG5`6ooooo`OomoOg1oooool7oh61P@KoBTY:1omFEUH7ocXj>POoA4A41_m7AdL6ooooo`Oo;Bd]
1olO7al6oiZJVPOo5QHF1olQ8B47og]kN`Oo=CDe1_l00006ooooo`OoPX:21_lD51@7o`L71`OoKFe]
1ol`<307oa4A4@OoDe=C1_m5ADD>ooooo`003?ooool7of=SH`OoN7Qh1omnOWh7oi>CT`OoXZ:R1_nC
Ti<7okBd]0Ko_;bl1_ooool7od51@@Oo?Shn1om=CDd7ocHf=POoBd];1_n6QXH7ooooo`KoZZZZ1_oo
ool7oa8B4POo=CDe1olP8207obTY:@Ko8B4Q1olT92@7oe]KF`Ko00001_ooool7oeeMG@OoVYZJ1ol8
20P7ohZ:RPKoFUYJ1olW9bL7oh:2PPKo7alO1_ooool7ocXj>POo?3`l1ol];Bd6oa`L70OoK6a/1omE
EED7ojVYZ@KoG5aL1_ooool7ooOgm`Oooooo1on1PH46odY:BPOoEUIF1olj>SX7odA4A0KoAdM71_oo
ool7obd];@Oo7alO1_nJVYX7oaHF5POo8B4Q1omkNg/7ocDe=@Ko00001_ooool7oh:2PPKo51@D1ol7
1`L7ofe]K@Oo<30`1olA4A47oe=CD`KoADE53_ooool000cooooo1omSHf<7ogQhN0OoOWin1onCTi<7
oj:RXPKoTi>C1ond];@6okbl_0Kooooo1om1@D47ochn?POoCDe=1olf=SH7od];B`KoQXJ61oooool6
ojZZZPKooooo1olB4Q87ocDe=@Oo820P1olY:BT6ob4Q8@Oo92@T1omKFe/6o`0000Kooooo1omMGEd7
oiZJVPOo20P81on:RXX6oeYJFPOo9bLW1on2PX86oalO7`Kooooo1olj>SX7oc`l?0Oo;Bd]1_lL71`7
ofa/K0OoEEEE1onYZJT6oeaLG0Kooooo1oogmoL7ooooo`OoPH611_m:BTX7oeIFEPOo>SXj1om4A4@6
odM7A`Kooooo1ol];Bd7oalO7`KoVYZJ1olF5QH7ob4Q8@OoNg]k1ole=CD6o`0000Kooooo1on2PX86
oa@D50Oo1`L71om]KFd7oc0`<0Oo4A4A1omCDe<6odE5A@kooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000<ooooo`Oo
];Bd1ooEeMD7ofQXJ0Oo>SXj1old=3@6ocLg=`Oo2@T91_lS8b<6ooooo`OoW9bL1olc<c<7ohN7Q`Oo
I6AT1omcLg<6okfm_@Oo:BTY1_mnOWh6ooooo`Oo:RXZ1olO7al7o`X:2POo2`/;1_l410@7o`l?3`Oo
8b<S1_l[:b/6ooooo`Oo6ATI1omEEED7o`l?3`Oo51@D1_n6QXH7oaXJ6POo7AdM1_mkNg/6ooooo`Oo
71`L1olW9bL7oaDE5@Ko6a/K1olD51@7ob`/;0Oo7AdM1_m7AdL6ooooo`Oo7alO1olC4a<7obDU9@Ko
;2`/1olc<c<7ocLg=`Oo8B4Q1_lD51@6ooooo`Oo<C4a1om/K6`6oiNGU`OoHF5Q1omOGel7ocTi>@Oo
Ph>31_l>3Ph6ooooo`Oo@T921_m3@d<7obDU9@OoA4A41olM7Ad7obl_;`OoGUiN1_l30`<>ooooo`00
3?ooool7okBd]0OoeMGE1omXJ6P7ocXj>POo=3@d1_lg=cL7o`T92@Ko8b<S1_ooool7oibLW0Oo<c<c
1on7QhL7ofATI0OoLg=c1_nm_Kd7obTY:@KoOWin1_ooool7obXZ:POo7alO1ol:2PX7o`/;2`Ko10@4
1ol?3`l7ob<S8`Ko:b/[1_ooool7oaTI6@OoEEEE1ol?3`l7oa@D50KoQXJ61olJ6QX7oadM7@KoNg]k
1_ooool7oa`L70Oo9bLW1olE5AD6oa/K6`Oo51@D1ol/;2`7oadM7@KoAdM71_ooool7oalO7`Oo4a<C
1olU9BD6ob`/;0Oo<c<c1olg=cL7ob4Q8@Ko51@D1_ooool7oc4a<@OoK6a/1_nGUiL7of5QH@OoGemO
1oli>CT7oh>3P`Ko3Ph>1_ooool7od92@PKo@d=31olU9BD7odA4A0Oo7AdM1ol_;bl7oeiNGPKo0`<3
3_ooool000cooooo1ond];@7omGEe@OoJ6QX1olj>SX7oc@d=0Ko=cLg1ol92@T6ob<S8`Kooooo1onL
W9`7oc<c<`OoQhN71omTI6@7og=cL`Ko_Kfm1olY:BT6oginOPKooooo1olZ:RX7oalO7`Oo2PX:1ol;
2`/6o`@410Oo3`l?1olS8b<6ob/[:`Kooooo1olI6AT7oeEEE@Oo3`l?1olD51@6ohJ6QPOo6QXJ1olM
7Ad6og]kN`Kooooo1olL71`7obLW9`Oo5ADE1_lK6a/7oa@D50Oo;2`/1olM7Ad6odM7A`Kooooo1olO
7al7oa<C4`Oo9BDU1_l/;2`7oc<c<`Oo=cLg1olQ8B46oa@D50Kooooo1ola<C47ofa/K0KoUiNG1omQ
HF47oemOG`Oo>CTi1on3Ph<6o`h>3PKooooo1om2@T86od=3@`Oo9BDU1om4A4@7oadM7@Oo;bl_1omN
GUh6o`<30`kooooo000<ooooo`Oo];Bd1ooEeMD7ofQXJ0Oo>SXj1old=3@6ocLg=`Oo2@T91_lS8b<6
ooooo`OoW9bL1olc<c<7ohN7Q`OoI6AT1omcLg<6okfm_@Oo:BTY1_mnOWh6ooooo`Oo:RXZ1olO7al7
o`X:2POo2`/;1_l410@7o`l?3`Oo8b<S1_l[:b/6ooooo`Oo6ATI1omEEED7o`l?3`Oo51@D1_n6QXH7
oaXJ6POo7AdM1_mkNg/6ooooo`Oo71`L1olW9bL7oaDE5@Ko6a/K1olD51@7ob`/;0Oo7AdM1_m7AdL6
ooooo`Oo7alO1olC4a<7obDU9@Ko;2`/1olc<c<7ocLg=`Oo8B4Q1_lD51@6ooooo`Oo<C4a1om/K6`6
oiNGU`OoHF5Q1omOGel7ocTi>@OoPh>31_l>3Ph6ooooo`Oo@T921_m3@d<7obDU9@OoA4A41olM7Ad7
obl_;`OoGUiN1_l30`<>ooooo`003?ooool7okBd]0OoeMGE1omXJ6P7ocXj>POo=3@d1_lg=cL7o`T9
2@Ko8b<S1_ooool7oibLW0Oo<c<c1on7QhL7ofATI0OoLg=c1_nm_Kd7obTY:@KoOWin1_ooool7obXZ
:POo7alO1ol:2PX7o`/;2`Ko10@41ol?3`l7ob<S8`Ko:b/[1_ooool7oaTI6@OoEEEE1ol?3`l7oa@D
50KoQXJ61olJ6QX7oadM7@KoNg]k1_ooool7oa`L70Oo9bLW1olE5AD6oa/K6`Oo51@D1ol/;2`7oadM
7@KoAdM71_ooool7oalO7`Oo4a<C1olU9BD6ob`/;0Oo<c<c1olg=cL7ob4Q8@Ko51@D1_ooool7oc4a
<@OoK6a/1_nGUiL7of5QH@OoGemO1oli>CT7oh>3P`Ko3Ph>1_ooool7od92@PKo@d=31olU9BD7odA4
A0Oo7AdM1ol_;bl7oeiNGPKo0`<33_ooool000cooooo1ond];@7omGEe@OoJ6QX1olj>SX7oc@d=0Ko
=cLg1ol92@T6ob<S8`Kooooo1onLW9`7oc<c<`OoQhN71omTI6@7og=cL`Ko_Kfm1olY:BT6oginOPKo
oooo1olZ:RX7oalO7`Oo2PX:1ol;2`/6o`@410Oo3`l?1olS8b<6ob/[:`Kooooo1olI6AT7oeEEE@Oo
3`l?1olD51@6ohJ6QPOo6QXJ1olM7Ad6og]kN`Kooooo1olL71`7obLW9`Oo5ADE1_lK6a/7oa@D50Oo
;2`/1olM7Ad6odM7A`Kooooo1olO7al7oa<C4`Oo9BDU1_l/;2`7oc<c<`Oo=cLg1olQ8B46oa@D50Ko
oooo1ola<C47ofa/K0KoUiNG1omQHF47oemOG`Oo>CTi1on3Ph<6o`h>3PKooooo1om2@T86od=3@`Oo
9BDU1om4A4@7oadM7@Oo;bl_1omNGUh6o`<30`kooooo000<ooooo`Oo];Bd1ooEeMD7ofQXJ0Oo>SXj
1old=3@6ocLg=`Oo2@T91_lS8b<6ooooo`OoW9bL1olc<c<7ohN7Q`OoI6AT1omcLg<6okfm_@Oo:BTY
1_mnOWh6ooooo`Oo:RXZ1olO7al7o`X:2POo2`/;1_l410@7o`l?3`Oo8b<S1_l[:b/6ooooo`Oo6ATI
1omEEED7o`l?3`Oo51@D1_n6QXH7oaXJ6POo7AdM1_mkNg/6ooooo`Oo71`L1olW9bL7oaDE5@Ko6a/K
1olD51@7ob`/;0Oo7AdM1_m7AdL6ooooo`Oo7alO1olC4a<7obDU9@Ko;2`/1olc<c<7ocLg=`Oo8B4Q
1_lD51@6ooooo`Oo<C4a1om/K6`6oiNGU`OoHF5Q1omOGel7ocTi>@OoPh>31_l>3Ph6ooooo`Oo@T92
1_m3@d<7obDU9@OoA4A41olM7Ad7obl_;`OoGUiN1_l30`<>ooooo`003?ooool7ol_;b`OoTY:B1ol[
:b/7ochn?POo3@d=1_lN7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oD
e=@7oa0@40KoXj>S1_ooool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_oo
ool7oalO7`OoNGUi1olQ8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omV
IVH6oginOPOoIVIV1omcLg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI
6AT6oaLG5`Kooooo1olL71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooM
gMd=oa`L70OoVIVI1olB4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7
ochn?POo3@d=1_lN7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7
oa0@40KoXj>S1_ooool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7
oalO7`OoNGUi1olQ8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6
oginOPOoIVIV1omcLg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6
oaLG5`Kooooo1olL71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=
oa`L70OoVIVI1olB4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7ochn
?POo3@d=1_lN7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7oa0@
40KoXj>S1_ooool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7oalO
7`OoNGUi1olQ8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6ogin
OPOoIVIV1omcLg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6oaLG
5`Kooooo1olL71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=oa`L
70OoVIVI1olB4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7ochn?POo
3@d=1_lN7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7oa0@40Ko
Xj>S1_ooool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7oalO7`Oo
NGUi1olQ8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6oginOPOo
IVIV1omcLg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6oaLG5`Ko
oooo1olL71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=oa`L70Oo
VIVI1olB4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7ochn?POo3@d=
1_lN7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7oa0@40KoXj>S
1_ooool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7oalO7`OoNGUi
1olQ8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6oginOPOoIVIV
1omcLg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6oaLG5`Kooooo
1olL71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=oa`L70OoVIVI
1olB4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7ochn?POo3@d=1_lN
7Qh7oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7oa0@40KoXj>S1_oo
ool7ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7oalO7`OoNGUi1olQ
8B47obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6oginOPOoIVIV1omc
Lg<7og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6oaLG5`Kooooo1olL
71`7ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=oa`L70OoVIVI1olB
4Q87obTY:@OoBd];1_lF5QH>ooooo`003?ooool7ol_;b`OoTY:B1ol[:b/7ochn?POo3@d=1_lN7Qh7
oa@D50Ko92@T1_ooool7o`/;2`Oo0`<31onk^k/7o`0000Oo?Cdm1_oDe=@7oa0@40KoXj>S1_ooool7
ob@T90Oo3`l?1ol10@47o`0000Ko1`L71ol820P7oa8B4PKo7QhN1_ooool7oalO7`OoNGUi1olQ8B47
obDU9@Ko?clo1olX:2P7oe9BDPKo5ADE1_ooool7oeUIF@OoNGUi1omVIVH6oginOPOoIVIV1omcLg<7
og9bLPKoRHV91_ooool7oaDE5@Oo51@D1olF5QH=oa8B4POo6a/K1olI6AT6oaLG5`Kooooo1olL71`7
ooooo`Ko@T921old=3@7oogmo@Oo5ADE1om5ADD6oeaLG0Kooooo1ooMgMd=oa`L70OoVIVI1olB4Q87
obTY:@OoBd];1_lF5QH>ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`00
00Ko6a/K1_ooool7ob<S8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn
?Pko:2PX1olg=cL6oc<c<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c
<`Oo6ATI1om2@T86oc0`<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3
P`Kooooo3_l?3`l7o`820PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn
?POoSXj>1onMWId7oa@D50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno
_`Oo9bLW1_lB4Q8>ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`0000Ko
6a/K1_ooool7ob<S8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn?Pko
:2PX1olg=cL6oc<c<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c<`Oo
6ATI1om2@T86oc0`<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3P`Ko
oooo3_l?3`l7o`820PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn?POo
SXj>1onMWId7oa@D50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno_`Oo
9bLW1_lB4Q8>ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`0000Ko6a/K
1_ooool7ob<S8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn?Pko:2PX
1olg=cL6oc<c<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c<`Oo6ATI
1om2@T86oc0`<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3P`Kooooo
3_l?3`l7o`820PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn?POoSXj>
1onMWId7oa@D50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno_`Oo9bLW
1_lB4Q8>ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`0000Ko6a/K1_oo
ool7ob<S8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn?Pko:2PX1olg
=cL6oc<c<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c<`Oo6ATI1om2
@T86oc0`<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3P`Kooooo3_l?
3`l7o`820PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn?POoSXj>1onM
WId7oa@D50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno_`Oo9bLW1_lB
4Q8>ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`0000Ko6a/K1_ooool7
ob<S8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn?Pko:2PX1olg=cL6
oc<c<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c<`Oo6ATI1om2@T86
oc0`<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3P`Kooooo3_l?3`l7
o`820PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn?POoSXj>1onMWId7
oa@D50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno_`Oo9bLW1_lB4Q8>
ooooo`003?ooool7oiJFUPOoYZJV1omgMgL7obd];@Oo7alO1_l/;2`7o`0000Ko6a/K1_ooool7ob<S
8`Oo@T921olH61P7oa8B4POoUYJF1_lb<S87o`L71`KoVYZJ1_ooool7ochn?Pko:2PX1olg=cL6oc<c
<`Oo;bl_1ole=CD6odQ8B0Kooooo1on8R8P7ocLg=`Oo4A4A1omnOWh6oc<c<`Oo6ATI1om2@T86oc0`
<0Kooooo1ooCdm<7onOWi`Oohn?S1_oHf=P7om3@d0OoX:2P1onBTY86oh>3P`Kooooo3_l?3`l7o`82
0PKo4a<C1ol>3Ph7oa4A4@Oo2PX:1_l@4106ooooo`Oo8R8R1onf][H6ochn?POoSXj>1onMWId7oa@D
50OolO7a1_lC4a<6ooooo`OoShn?1_lY:BT7ol30`0OoB4Q81ol00007okno_`Oo9bLW1_lB4Q8>oooo
o`003?ooool7omSHf0Ooe=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo
=CDe1ol`<307o`410@Oo;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`Ko
Lg=c1omhN7P7ofe]K@KoK6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKo
oooo1onf][H7okno_`OoXJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko
00001ol92@T7o`/;2`Oo4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo
/K6a1_lT92@6ooooo`Oofm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`00
3?ooool7omSHf0Ooe=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe
1ol`<307o`410@Oo;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c
1omhN7P7ofe]K@KoK6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo
1onf][H7okno_`OoXJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko0000
1ol92@T7o`/;2`Oo4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a
1_lT92@6ooooo`Oofm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?oo
ool7omSHf0Ooe=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe1ol`
<307o`410@Oo;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c1omh
N7P7ofe]K@KoK6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo1onf
][H7okno_`OoXJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko00001ol9
2@T7o`/;2`Oo4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a1_lT
92@6ooooo`Oofm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?ooool7
omSHf0Ooe=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe1ol`<307
o`410@Oo;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c1omhN7P7
ofe]K@KoK6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo1onf][H7
okno_`OoXJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko00001ol92@T7
o`/;2`Oo4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a1_lT92@6
ooooo`Oofm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?ooool7omSH
f0Ooe=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe1ol`<307o`41
0@Oo;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c1omhN7P7ofe]
K@KoK6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo1onf][H7okno
_`OoXJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko00001ol92@T7o`/;
2`Oo4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a1_lT92@6oooo
o`Oofm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?ooool7omSHf0Oo
e=CD1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe1ol`<307o`410@Oo
;bl_1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c1omhN7P7ofe]K@Ko
K6a/1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo1onf][H7okno_`Oo
XJ6Q1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko00001ol92@T7o`/;2`Oo
4Q8B1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a1_lT92@6ooooo`Oo
fm_K1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?ooool7omSHf0Ooe=CD
1ol];Bd7ocdm?@Oo<30`1_lY:BT7o`h>3PKo:b/[1_ooool7o`/;2`Oo=CDe1ol`<307o`410@Oo;bl_
1_m>CTh7obd];@Ko6ATI1_ooool7ogYjNPOoQXJ61omlO7`7ogMgM`KoLg=c1omhN7P7ofe]K@KoK6a/
1_ooool7oeYJFPOoT92@1omADE4=odY:BPOoI6AT1olf=SH6oahN7PKooooo1onf][H7okno_`OoXJ6Q
1_nk^k/7onSXj0Oooooo1ooHf=P6okFe]@Kooooo3_l410@7o`<30`Ko00001ol92@T7o`/;2`Oo4Q8B
1_lD51@6ooooo`OoATI61om`L706ocPh>0OoRXZ:1onHV9P7oa8B4POo/K6a1_lT92@6ooooo`Oofm_K
1_lG5aL7ogUiN@OoUIFE1om@D507og5aL@OoBDU91_n@T90>ooooo`003?ooool7oijNWPOoP8201omW
IfL7od10@0Oo:2PX1_l`<307o`D51@Ko71`L1_ooool7oc`l?0Oo=3@d1olE5AD7oc0`<0OoADE51_l0
0007o`/;2`Ko?Cdm1_ooool7oiVIV@Oo[jn_1onTY:@7ol[:bPKoZJVY1oo9bLT7ojFUY@Ko/;2`1_oo
ool7onc/k0OoAdM71olQ8B47ooooo`Ko5aLG1ola<C47ohF5Q@Ko?Shn1_ooool7og]kN`OoMgMg1on9
RHT6ogmoO`OoQHF51ond];@7ojVYZ@KoUYJF1_ooool>o`T92@Oo0`<31_l92@T7o`0001Co2`/;1_oo
ool7oalO7`Oo[Zj^1_l92@T7oemOG`OoZ:RX1olT92@7ok2`/0Ko6a/K1_ooool7ol[:bPKo51@D1oo@
d=07oeeMG@Oo;bl_1oooool7obHV9PKoB4Q83_ooool000cooooo1onNWYh7oh20P0OoIfMW1om0@407
obPX:0Ko<30`1ol51@D6oa`L70Kooooo1oll?3`7oc@d=0Oo5ADE1ol`<307odE5A@Ko00001ol;2`/6
ocdm?@Kooooo1onIVIT7ojn_[`OoY:BT1oo:b/X6ojVYZ@OobLW91onUYJD6ok2`/0Kooooo1oo/k>`7
odM7A`Oo8B4Q1oooool6oaLG5`Oo<C4a1on5QHD6ochn?PKooooo1omkNg/7ogMgM`OoRHV91_moOgl7
ohF5Q@Oo];Bd1onYZJT6oiJFUPKooooo3_l92@T7o`<30`Ko2@T91ol0000Do`/;2`Kooooo1olO7al7
ojj^[PKo2@T91omOGel7ojRXZ0Oo92@T1on`/;06oa/K6`Kooooo1oo:b/X6oa@D50Ood=3@1omMGEd7
obl_;`Oooooo1olV9RH6odQ8B0kooooo000<ooooo`OoWYjN1on0P807ofMWI`Oo@4101olX:2P6oc0`
<0Oo1@D51_lL71`6ooooo`Oo?3`l1old=3@7oaDE5@Oo<30`1om5ADD6o`0000Oo2`/;1_lm?Cd6oooo
o`OoVIVI1on_[jl7ojBTY0Oob/[:1_nYZJT7olW9b@OoYJFU1_n`/;06ooooo`Ook>c/1om7AdL7ob4Q
8@Oooooo1_lG5aL7oc4a<@OoQHF51_ln?Sh6ooooo`OoNg]k1omgMgL7ohV9R@KoOgmo1on5QHD7okBd
]0OoZJVY1_nFUYH6ooooo`ko2@T91ol30`<6o`T92@Oo00005?l;2`/6ooooo`Oo7alO1on^[Zh6o`T9
2@OoGemO1onXZ:P7ob@T90Oo/;2`1_lK6a/6ooooo`Oob/[:1_lD51@7om3@d0OoGEeM1ol_;bl7oooo
o`Oo9RHV1_m8B4P>ooooo`003?ooool7oijNWPOoP8201omWIfL7od10@0Oo:2PX1_l`<307o`D51@Ko
71`L1_ooool7oc`l?0Oo=3@d1olE5AD7oc0`<0OoADE51_l00007o`/;2`Ko?Cdm1_ooool7oiVIV@Oo
[jn_1onTY:@7ol[:bPKoZJVY1oo9bLT7ojFUY@Ko/;2`1_ooool7onc/k0OoAdM71olQ8B47ooooo`Ko
5aLG1ola<C47ohF5Q@Ko?Shn1_ooool7og]kN`OoMgMg1on9RHT6ogmoO`OoQHF51ond];@7ojVYZ@Ko
UYJF1_ooool>o`T92@Oo0`<31_l92@T7o`0001Co2`/;1_ooool7oalO7`Oo[Zj^1_l92@T7oemOG`Oo
Z:RX1olT92@7ok2`/0Ko6a/K1_ooool7ol[:bPKo51@D1oo@d=07oeeMG@Oo;bl_1oooool7obHV9PKo
B4Q83_ooool000cooooo1onNWYh7oh20P0OoIfMW1om0@407obPX:0Ko<30`1ol51@D6oa`L70Kooooo
1oll?3`7oc@d=0Oo5ADE1ol`<307odE5A@Ko00001ol;2`/6ocdm?@Kooooo1onIVIT7ojn_[`OoY:BT
1oo:b/X6ojVYZ@OobLW91onUYJD6ok2`/0Kooooo1oo/k>`7odM7A`Oo8B4Q1oooool6oaLG5`Oo<C4a
1on5QHD6ochn?PKooooo1omkNg/7ogMgM`OoRHV91_moOgl7ohF5Q@Oo];Bd1onYZJT6oiJFUPKooooo
3_l92@T7o`<30`Ko2@T91ol0000Do`/;2`Kooooo1olO7al7ojj^[PKo2@T91omOGel7ojRXZ0Oo92@T
1on`/;06oa/K6`Kooooo1oo:b/X6oa@D50Ood=3@1omMGEd7obl_;`Oooooo1olV9RH6odQ8B0kooooo
000<ooooo`OoWYjN1on0P807ofMWI`Oo@4101olX:2P6oc0`<0Oo1@D51_lL71`6ooooo`Oo?3`l1old
=3@7oaDE5@Oo<30`1om5ADD6o`0000Oo2`/;1_lm?Cd6ooooo`OoVIVI1on_[jl7ojBTY0Oob/[:1_nY
ZJT7olW9b@OoYJFU1_n`/;06ooooo`Ook>c/1om7AdL7ob4Q8@Oooooo1_lG5aL7oc4a<@OoQHF51_ln
?Sh6ooooo`OoNg]k1omgMgL7ohV9R@KoOgmo1on5QHD7okBd]0OoZJVY1_nFUYH6ooooo`ko2@T91ol3
0`<6o`T92@Oo00005?l;2`/6ooooo`Oo7alO1on^[Zh6o`T92@OoGemO1onXZ:P7ob@T90Oo/;2`1_lK
6a/6ooooo`Oob/[:1_lD51@7om3@d0OoGEeM1ol_;bl7ooooo`Oo9RHV1_m8B4P>ooooo`003?ooool7
oijNWPOoP8201omWIfL7od10@0Oo:2PX1_l`<307o`D51@Ko71`L1_ooool7oc`l?0Oo=3@d1olE5AD7
oc0`<0OoADE51_l00007o`/;2`Ko?Cdm1_ooool7oiVIV@Oo[jn_1onTY:@7ol[:bPKoZJVY1oo9bLT7
ojFUY@Ko/;2`1_ooool7onc/k0OoAdM71olQ8B47ooooo`Ko5aLG1ola<C47ohF5Q@Ko?Shn1_ooool7
og]kN`OoMgMg1on9RHT6ogmoO`OoQHF51ond];@7ojVYZ@KoUYJF1_ooool>o`T92@Oo0`<31_l92@T7
o`0001Co2`/;1_ooool7oalO7`Oo[Zj^1_l92@T7oemOG`OoZ:RX1olT92@7ok2`/0Ko6a/K1_ooool7
ol[:bPKo51@D1oo@d=07oeeMG@Oo;bl_1oooool7obHV9PKoB4Q83_ooool001?ooooo1oo6a/H7oc@d
=0Oo@T921olD51@6ocXj>POo4A4A1_lJ6QX6ooooo`Oo@T921one]KD7oa8B4POo;Bd]1omEEED6ob4Q
8@Oo=3@d1_lF5QH6ooooo`Oo[Jf]1oo0`<07om7Ad@OoinOW1_oIfMT7om;BdPOo/;2`1_ni^KT6oooo
o`Oo]KFe1om;Bd/7oi6AT@OoSHf=1_lV9RH7on_[j`Oo;Bd]1_lO7al6ooooo`Oo?3`l1old=3@7oc<c
<`Ko?clo1om<C4`7oeADE0OoGUiN1_m:BTX6ooooo`Oo51@D1ol92@T7o`h>3PKo3`l?1ol=3@d7oaHF
5POo6QXJ1_l:2PX6ooooo`OoHf=S1olF5QH6oa4A4@OoZZZZ1olE5AD7oaPH60OocLg=1_l00006oooo
o`OoHF5Q1_lK6a/7on;RhPOo>3Ph1om^KVh7okRh^0Oo5ADE1_o6a/H>ooooo`004oooool7olK6aPOo
=3@d1om2@T87oa@D50Ko>SXj1olA4A46oaXJ6PKooooo1om2@T87okFe]@Oo4Q8B1ol];Bd7oeEEE@Ko
8B4Q1old=3@6oaHF5PKooooo1on][Jd7ol30`0OodM7A1ooWinL6omWIf@Ood];B1on`/;06okVi^@Ko
oooo1one]KD7od];B`OoTI6A1on=SHd6obHV9POojn_[1ol];Bd6oalO7`Kooooo1oll?3`7oc@d=0Oo
<c<c1_lo?cl7oda<C0OoE5AD1omNGUh6odY:BPKooooo1olD51@7o`T92@Oo3Ph>1_l?3`l7o`d=3@Oo
5QHF1olJ6QX6o`X:2PKooooo1omSHf<7oaHF5PKo4A4A1onZZZX7oaDE5@Oo61PH1oo=cLd6o`0000Ko
oooo1omQHF46oa/K6`Ooh^;R1olh>3P7ofi^KPOo^;Rh1olE5AD6olK6aPkooooo000Cooooo`Ooa/K6
1old=3@7od92@POo51@D1_lj>SX7oa4A4@Ko6QXJ1_ooool7od92@POo]KFe1olB4Q87obd];@OoEEEE
1_lQ8B47oc@d=0Ko5QHF1_ooool7ojf][@Oo`<301ooAdM47onOWi`KofMWI1ooBd]87ok2`/0Ko^KVi
1_ooool7okFe]@OoBd];1onATI47ohf=S@Ko9RHV1oo[jn/7obd];@Ko7alO1_ooool7oc`l?0Oo=3@d
1olc<c<6oclo?`OoC4a<1omDE5@7oeiNGPKoBTY:1_ooool7oa@D50Oo2@T91ol>3Ph6o`l?3`Oo3@d=
1olF5QH7oaXJ6PKo2PX:1_ooool7of=SH`Oo5QHF1_lA4A47ojZZZPOo5ADE1olH61P7olg=c@Ko0000
1_ooool7of5QH@Ko6a/K1ooRh^87ocPh>0OoKVi^1onh^;P7oaDE5@Koa/K63_ooool001?ooooo1oo6
a/H7oc@d=0Oo@T921olD51@6ocXj>POo4A4A1_lJ6QX6ooooo`Oo@T921one]KD7oa8B4POo;Bd]1omE
EED6ob4Q8@Oo=3@d1_lF5QH6ooooo`Oo[Jf]1oo0`<07om7Ad@OoinOW1_oIfMT7om;BdPOo/;2`1_ni
^KT6ooooo`Oo]KFe1om;Bd/7oi6AT@OoSHf=1_lV9RH7on_[j`Oo;Bd]1_lO7al6ooooo`Oo?3`l1old
=3@7oc<c<`Ko?clo1om<C4`7oeADE0OoGUiN1_m:BTX6ooooo`Oo51@D1ol92@T7o`h>3PKo3`l?1ol=
3@d7oaHF5POo6QXJ1_l:2PX6ooooo`OoHf=S1olF5QH6oa4A4@OoZZZZ1olE5AD7oaPH60OocLg=1_l0
0006ooooo`OoHF5Q1_lK6a/7on;RhPOo>3Ph1om^KVh7okRh^0Oo5ADE1_o6a/H>ooooo`004oooool7
olK6aPOo=3@d1om2@T87oa@D50Ko>SXj1olA4A46oaXJ6PKooooo1om2@T87okFe]@Oo4Q8B1ol];Bd7
oeEEE@Ko8B4Q1old=3@6oaHF5PKooooo1on][Jd7ol30`0OodM7A1ooWinL6omWIf@Ood];B1on`/;06
okVi^@Kooooo1one]KD7od];B`OoTI6A1on=SHd6obHV9POojn_[1ol];Bd6oalO7`Kooooo1oll?3`7
oc@d=0Oo<c<c1_lo?cl7oda<C0OoE5AD1omNGUh6odY:BPKooooo1olD51@7o`T92@Oo3Ph>1_l?3`l7
o`d=3@Oo5QHF1olJ6QX6o`X:2PKooooo1omSHf<7oaHF5PKo4A4A1onZZZX7oaDE5@Oo61PH1oo=cLd6
o`0000Kooooo1omQHF46oa/K6`Ooh^;R1olh>3P7ofi^KPOo^;Rh1olE5AD6olK6aPkooooo000Coooo
o`Ooa/K61old=3@7od92@POo51@D1_lj>SX7oa4A4@Ko6QXJ1_ooool7od92@POo]KFe1olB4Q87obd]
;@OoEEEE1_lQ8B47oc@d=0Ko5QHF1_ooool7ojf][@Oo`<301ooAdM47onOWi`KofMWI1ooBd]87ok2`
/0Ko^KVi1_ooool7okFe]@OoBd];1onATI47ohf=S@Ko9RHV1oo[jn/7obd];@Ko7alO1_ooool7oc`l
?0Oo=3@d1olc<c<6oclo?`OoC4a<1omDE5@7oeiNGPKoBTY:1_ooool7oa@D50Oo2@T91ol>3Ph6o`l?
3`Oo3@d=1olF5QH7oaXJ6PKo2PX:1_ooool7of=SH`Oo5QHF1_lA4A47ojZZZPOo5ADE1olH61P7olg=
c@Ko00001_ooool7of5QH@Ko6a/K1ooRh^87ocPh>0OoKVi^1onh^;P7oaDE5@Koa/K63_ooool000co
oooo1oo:b/X7omOGe`OoOGem1omGEeL7ocLg=`KoBTY:1olP8206oc<c<`Kooooo1oo^k^h7oeIFEPOo
71`L1oooool7oalO7`Ko7AdM1omeMGD6oa<C4`Kooooo1onTY:@7ol_;b`Oo_kno1oo<c<`6okRh^0Oo
_;bl1onTY:@6oijNWPKooooo1onFUYH7odE5A@OoMGEe1onb/[86obh^;POoPh>31omlO7`6ohf=S@Ko
oooo1olM7Ad7obXZ:POo00001_lB4Q87oa@D50Oo5ADE1ol=3@d6obd];@Kooooo1olI6AT7oaPH60Oo
8B4Q1_lI6AT7o`X:2POo71`L1olK6a/6oa<C4`Kooooo1om4A4@7od92@PKo<S8b1olX:2P7odA4A0Oo
GemO1olk>c/6oa0@40Kooooo1on5QHD6ocHf=POoNWYj1om>CTh7oh>3P`OoTI6A1olP8206ohn?S`ko
oooo000<ooooo`Oob/[:1ooGemL7ogemO@OoEeMG1olg=cL6odY:BPOo820P1_lc<c<6ooooo`Ook^k^
1omFEUH7oa`L70Oooooo1olO7al6oadM7@OoMGEe1_lC4a<6ooooo`OoY:BT1oo;bl/7okno_`Ooc<c<
1_nh^;P7okbl_0OoY:BT1_nNWYh6ooooo`OoUYJF1om5ADD7ogEeM@Oo/[:b1_l^;Rh7oh>3P`OoO7al
1_n=SHd6ooooo`Oo7AdM1olZ:RX7o`0000Ko4Q8B1olD51@7oaDE5@Oo3@d=1_l];Bd6ooooo`Oo6ATI
1olH61P7ob4Q8@Ko6ATI1ol:2PX7oa`L70Oo6a/K1_lC4a<6ooooo`OoA4A41om2@T86oc8b<POo:2PX
1om4A4@7oemOG`Oo>c/k1_l@4106ooooo`OoQHF51_lf=SH7ogYjNPOoCTi>1on3Ph<7oi6AT@Oo820P
1_n?Shl>ooooo`003?ooool7ol[:bPOoemOG1ommOGd7oeMGE`Oo=cLg1_m:BTX7ob0P80Ko<c<c1_oo
ool7onk^kPOoEUIF1olL71`7ooooo`Oo7alO1_lM7Ad7ogEeM@Ko4a<C1_ooool7ojBTY0Oobl_;1ono
_kl7olc<c0Ko^;Rh1onl_;`7ojBTY0KoWYjN1_ooool7oiJFUPOoADE51omeMGD7ok:b/PKo;Rh^1on3
Ph<7ogalO0KoSHf=1_ooool7oadM7@Oo:RXZ1ol00006oa8B4POo51@D1olE5AD7o`d=3@Ko;Bd]1_oo
ool7oaTI6@Oo61PH1olQ8B46oaTI6@Oo2PX:1olL71`7oa/K6`Ko4a<C1_ooool7odA4A0Oo@T921_lb
<S87obPX:0OoA4A41omOGel7oc/k>`Ko410@1_ooool7ohF5Q@Ko=SHf1omjNWX7odi>CPOoPh>31onA
TI47ob0P80KoShn?3_ooool000cooooo1oo:b/X7omOGe`OoOGem1omGEeL7ocLg=`KoBTY:1olP8206
oc<c<`Kooooo1oo^k^h7oeIFEPOo71`L1oooool7oalO7`Ko7AdM1omeMGD6oa<C4`Kooooo1onTY:@7
ol_;b`Oo_kno1oo<c<`6okRh^0Oo_;bl1onTY:@6oijNWPKooooo1onFUYH7odE5A@OoMGEe1onb/[86
obh^;POoPh>31omlO7`6ohf=S@Kooooo1olM7Ad7obXZ:POo00001_lB4Q87oa@D50Oo5ADE1ol=3@d6
obd];@Kooooo1olI6AT7oaPH60Oo8B4Q1_lI6AT7o`X:2POo71`L1olK6a/6oa<C4`Kooooo1om4A4@7
od92@PKo<S8b1olX:2P7odA4A0OoGemO1olk>c/6oa0@40Kooooo1on5QHD6ocHf=POoNWYj1om>CTh7
oh>3P`OoTI6A1olP8206ohn?S`kooooo000<ooooo`Oob/[:1ooGemL7ogemO@OoEeMG1olg=cL6odY:
BPOo820P1_lc<c<6ooooo`Ook^k^1omFEUH7oa`L70Oooooo1olO7al6oadM7@OoMGEe1_lC4a<6oooo
o`OoY:BT1oo;bl/7okno_`Ooc<c<1_nh^;P7okbl_0OoY:BT1_nNWYh6ooooo`OoUYJF1om5ADD7ogEe
M@Oo/[:b1_l^;Rh7oh>3P`OoO7al1_n=SHd6ooooo`Oo7AdM1olZ:RX7o`0000Ko4Q8B1olD51@7oaDE
5@Oo3@d=1_l];Bd6ooooo`Oo6ATI1olH61P7ob4Q8@Ko6ATI1ol:2PX7oa`L70Oo6a/K1_lC4a<6oooo
o`OoA4A41om2@T86oc8b<POo:2PX1om4A4@7oemOG`Oo>c/k1_l@4106ooooo`OoQHF51_lf=SH7ogYj
NPOoCTi>1on3Ph<7oi6AT@Oo820P1_n?Shl>ooooo`003?ooool7ol[:bPOoemOG1ommOGd7oeMGE`Oo
=cLg1_m:BTX7ob0P80Ko<c<c1_ooool7onk^kPOoEUIF1olL71`7ooooo`Oo7alO1_lM7Ad7ogEeM@Ko
4a<C1_ooool7ojBTY0Oobl_;1ono_kl7olc<c0Ko^;Rh1onl_;`7ojBTY0KoWYjN1_ooool7oiJFUPOo
ADE51omeMGD7ok:b/PKo;Rh^1on3Ph<7ogalO0KoSHf=1_ooool7oadM7@Oo:RXZ1ol00006oa8B4POo
51@D1olE5AD7o`d=3@Ko;Bd]1_ooool7oaTI6@Oo61PH1olQ8B46oaTI6@Oo2PX:1olL71`7oa/K6`Ko
4a<C1_ooool7odA4A0Oo@T921_lb<S87obPX:0OoA4A41omOGel7oc/k>`Ko410@1_ooool7ohF5Q@Ko
=SHf1omjNWX7odi>CPOoPh>31onATI47ob0P80KoShn?3_ooool000cooooo1oo:b/X7omOGe`OoOGem
1omGEeL7ocLg=`KoBTY:1olP8206oc<c<`Kooooo1oo^k^h7oeIFEPOo71`L1oooool7oalO7`Ko7AdM
1omeMGD6oa<C4`Kooooo1onTY:@7ol_;b`Oo_kno1oo<c<`6okRh^0Oo_;bl1onTY:@6oijNWPKooooo
1onFUYH7odE5A@OoMGEe1onb/[86obh^;POoPh>31omlO7`6ohf=S@Kooooo1olM7Ad7obXZ:POo0000
1_lB4Q87oa@D50Oo5ADE1ol=3@d6obd];@Kooooo1olI6AT7oaPH60Oo8B4Q1_lI6AT7o`X:2POo71`L
1olK6a/6oa<C4`Kooooo1om4A4@7od92@PKo<S8b1olX:2P7odA4A0OoGemO1olk>c/6oa0@40Kooooo
1on5QHD6ocHf=POoNWYj1om>CTh7oh>3P`OoTI6A1olP8206ohn?S`kooooo000<ooooo`Ooj^[Z1ooY
jNT7of][J`OoP8201ol_;bl6odA4A0Oo>c/k1_ll?3`6ooooo`OoD51@1olX:2P7ohR8R0Oo>c/k1om1
@D46ohF5Q@Oo>c/k1_n5QHD6ooooo`Oo_[jn1oo5aLD7ok2`/0OoaLG51_ni^KT7ooooo`Oodm?C1_o>
c/h6ooooo`Oo20P81olL71`7ohB4Q0Oo00001_li>CT7oiFEU@Oo4a<C1_lW9bL6ooooo`OoNGUi1omR
HV87oeMGE`KoJVYZ1omKFe/7ohV9R@OoIfMW1_mlO7`6ooooo`OoC4a<1olm?Cd7ocPh>0KoHV9R1ooo
ool7oj6QX@Oo=SHf1_lh>3P6ooooo`Oo=SHf1om/K6`6oaHF5POo4Q8B1ole=CD7oa8B4POo1PH61_lQ
8B46ooooo`Oo5ADE1_lO7al7o`h>3POo8b<S1omDE5@7o`H61POo>c/k1_m9BDT>ooooo`003?ooool7
on[ZjPOojNWY1om[Jf/7oh20P0Oo;bl_1_m4A4@7oc/k>`Ko?3`l1_ooool7oe1@D0Oo:2PX1on8R8P7
oc/k>`Oo@D511_n5QHD7oc/k>`KoQHF51_ooool7okjn_POoaLG51on`/;07olG5a@Ko^KVi1oooool7
om?Cd`Koc/k>1_ooool7o`P820Oo71`L1on4Q8@7o`0000Ko>CTi1onEUID7oa<C4`Ko9bLW1_ooool7
ogUiN@OoHV9R1omGEeL6ofYZJPOoFe]K1on9RHT7ofMWI`KoO7al1_ooool7oda<C0Oo?Cdm1olh>3P6
of9RHPOooooo1onQXJ47ocHf=PKo>3Ph1_ooool7ocHf=POoK6a/1_lF5QH7oa8B4POo=CDe1olB4Q87
o`H61PKo8B4Q1_ooool7oaDE5@Ko7alO1ol>3Ph7ob<S8`OoE5AD1ol61PH7oc/k>`KoBDU93_ooool0
00cooooo1ooZj^X7onWYj@OoJf][1on0P807obl_;`KoA4A41olk>c/6oc`l?0Kooooo1om@D507obPX
:0OoR8R81olk>c/7od51@@KoQHF51olk>c/6ohF5Q@Kooooo1onn_[h7olG5a@Oo/;2`1oo5aLD6okVi
^@Oooooo1ooCdm<6olk>cPKooooo1ol820P7oa`L70OoQ8B41ol00006ocTi>@OoUIFE1olC4a<6obLW
9`Kooooo1omiNGT7of9RHPOoEeMG1_mZJVX7oe]KF`OoRHV91omWIfL6ogalO0Kooooo1om<C4`7ocdm
?@Oo>3Ph1_mRHV87ooooo`OoXJ6Q1olf=SH6ocPh>0Kooooo1olf=SH7ofa/K0Ko5QHF1olB4Q87ocDe
=@Oo4Q8B1ol61PH6ob4Q8@Kooooo1olE5AD6oalO7`Oo3Ph>1olS8b<7oeADE0Oo1PH61olk>c/6odU9
B@kooooo000<ooooo`Ooj^[Z1ooYjNT7of][J`OoP8201ol_;bl6odA4A0Oo>c/k1_ll?3`6ooooo`Oo
D51@1olX:2P7ohR8R0Oo>c/k1om1@D46ohF5Q@Oo>c/k1_n5QHD6ooooo`Oo_[jn1oo5aLD7ok2`/0Oo
aLG51_ni^KT7ooooo`Oodm?C1_o>c/h6ooooo`Oo20P81olL71`7ohB4Q0Oo00001_li>CT7oiFEU@Oo
4a<C1_lW9bL6ooooo`OoNGUi1omRHV87oeMGE`KoJVYZ1omKFe/7ohV9R@OoIfMW1_mlO7`6ooooo`Oo
C4a<1olm?Cd7ocPh>0KoHV9R1oooool7oj6QX@Oo=SHf1_lh>3P6ooooo`Oo=SHf1om/K6`6oaHF5POo
4Q8B1ole=CD7oa8B4POo1PH61_lQ8B46ooooo`Oo5ADE1_lO7al7o`h>3POo8b<S1omDE5@7o`H61POo
>c/k1_m9BDT>ooooo`003?ooool7on[ZjPOojNWY1om[Jf/7oh20P0Oo;bl_1_m4A4@7oc/k>`Ko?3`l
1_ooool7oe1@D0Oo:2PX1on8R8P7oc/k>`Oo@D511_n5QHD7oc/k>`KoQHF51_ooool7okjn_POoaLG5
1on`/;07olG5a@Ko^KVi1oooool7om?Cd`Koc/k>1_ooool7o`P820Oo71`L1on4Q8@7o`0000Ko>CTi
1onEUID7oa<C4`Ko9bLW1_ooool7ogUiN@OoHV9R1omGEeL6ofYZJPOoFe]K1on9RHT7ofMWI`KoO7al
1_ooool7oda<C0Oo?Cdm1olh>3P6of9RHPOooooo1onQXJ47ocHf=PKo>3Ph1_ooool7ocHf=POoK6a/
1_lF5QH7oa8B4POo=CDe1olB4Q87o`H61PKo8B4Q1_ooool7oaDE5@Ko7alO1ol>3Ph7ob<S8`OoE5AD
1ol61PH7oc/k>`KoBDU93_ooool000cooooo1ooZj^X7onWYj@OoJf][1on0P807obl_;`KoA4A41olk
>c/6oc`l?0Kooooo1om@D507obPX:0OoR8R81olk>c/7od51@@KoQHF51olk>c/6ohF5Q@Kooooo1onn
_[h7olG5a@Oo/;2`1oo5aLD6okVi^@Oooooo1ooCdm<6olk>cPKooooo1ol820P7oa`L70OoQ8B41ol0
0006ocTi>@OoUIFE1olC4a<6obLW9`Kooooo1omiNGT7of9RHPOoEeMG1_mZJVX7oe]KF`OoRHV91omW
IfL6ogalO0Kooooo1om<C4`7ocdm?@Oo>3Ph1_mRHV87ooooo`OoXJ6Q1olf=SH6ocPh>0Kooooo1olf
=SH7ofa/K0Ko5QHF1olB4Q87ocDe=@Oo4Q8B1ol61PH6ob4Q8@Kooooo1olE5AD6oalO7`Oo3Ph>1olS
8b<7oeADE0Oo1PH61olk>c/6odU9B@kooooo000<ooooo`Ooj^[Z1ooYjNT7of][J`OoP8201ol_;bl6
odA4A0Oo>c/k1_ll?3`6ooooo`OoD51@1olX:2P7ohR8R0Oo>c/k1om1@D46ohF5Q@Oo>c/k1_n5QHD6
ooooo`Oo_[jn1oo5aLD7ok2`/0OoaLG51_ni^KT7ooooo`Oodm?C1_o>c/h6ooooo`Oo20P81olL71`7
ohB4Q0Oo00001_li>CT7oiFEU@Oo4a<C1_lW9bL6ooooo`OoNGUi1omRHV87oeMGE`KoJVYZ1omKFe/7
ohV9R@OoIfMW1_mlO7`6ooooo`OoC4a<1olm?Cd7ocPh>0KoHV9R1oooool7oj6QX@Oo=SHf1_lh>3P6
ooooo`Oo=SHf1om/K6`6oaHF5POo4Q8B1ole=CD7oa8B4POo1PH61_lQ8B46ooooo`Oo5ADE1_lO7al7
o`h>3POo8b<S1omDE5@7o`H61POo>c/k1_m9BDT>ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003?ooool7of1PH0Oo
U9BD1omeMGD7oeEEE@OoS8b<1_mVIVH7ojNWY`KoIfMW1_ooool7odA4A0OoDe=C1om9BDT7od51@@Oo
=CDe1_m1@D47oe5AD@KoCdm?1_ooool7oahN7POo<C4a1omXJ6P7oaLG5`Ko9BDU1on7QhL7obTY:@Ko
5aLG1_ooool7ocHf=POol_;b1olX:2P7oh>3P`Koh^;R1olO7al7onKViPKo:BTY1_ooool7ob0P80Oo
=cLg1om]KFd6odA4A0OoJVYZ1onh^;P7oeQHF0Ko=SHf1_ooool7oclo?`OoDE5A1oli>CT6oeEEE@Oo
<C4a1olS8b<7oa/K6`Ko8b<S1_ooool7obHV9POo4a<C1_ln?Sh7oda<C0Oo7QhN1olj>SX7oe1@D0Ko
:2PX1_ooool7oiBDU0Ko9RHV1ooMgMd7okJf]POoA4A41oooool7ofMWI`KonOWi3_ooool000cooooo
1omPH607oiBDU0OoMGEe1omEEED7ohb<S0KoIVIV1onWYjL6ofMWI`Kooooo1om4A4@7oe=CD`OoBDU9
1om1@D47ocDe=@Ko@D511omADE46odm?C`Kooooo1olN7Qh7oc4a<@OoJ6QX1olG5aL6obDU9@OoQhN7
1olY:BT6oaLG5`Kooooo1olf=SH7oo;blPOo:2PX1on3Ph<6on;RhPOo7alO1ooVi^H6obTY:@Kooooo
1olP8207ocLg=`OoKFe]1_m4A4@7ofYZJPOo^;Rh1omHF5P6ocHf=PKooooo1olo?cl7oe5AD@Oo>CTi
1_mEEED7oc4a<@Oo8b<S1olK6a/6ob<S8`Kooooo1olV9RH7oa<C4`Ko?Shn1om<C4`7oahN7POo>SXj
1om@D506obPX:0Kooooo1onDU9@6obHV9POogMgM1onf][H7odA4A0Oooooo1omWIfL6ooWin@kooooo
000<ooooo`OoH61P1onDU9@7ogEeM@OoEEEE1on<S8`6ofIVIPOoYjNW1_mWIfL6ooooo`OoA4A41omC
De<7odU9B@Oo@D511ole=CD6od51@@OoDE5A1_m?Cdl6ooooo`Oo7QhN1ola<C47ofQXJ0Oo5aLG1_lU
9BD7ohN7Q`Oo:BTY1_lG5aL6ooooo`Oo=SHf1oobl_87obPX:0OoPh>31_oRh^87oalO7`Ooi^KV1_lY
:BT6ooooo`Oo820P1olg=cL7ofe]K@KoA4A41omZJVX7okRh^0OoF5QH1_lf=SH6ooooo`Oo?clo1omA
DE47ocTi>@KoEEEE1ola<C47ob<S8`Oo6a/K1_lS8b<6ooooo`Oo9RHV1olC4a<6ochn?POoC4a<1olN
7Qh7ocXj>POoD51@1_lX:2P6ooooo`OoU9BD1_lV9RH7omgMg@Oo][Jf1om4A4@7ooooo`OoIfMW1_oi
nOT>ooooo`003?ooool7of1PH0OoU9BD1omeMGD7oeEEE@OoS8b<1_mVIVH7ojNWY`KoIfMW1_ooool7
odA4A0OoDe=C1om9BDT7od51@@Oo=CDe1_m1@D47oe5AD@KoCdm?1_ooool7oahN7POo<C4a1omXJ6P7
oaLG5`Ko9BDU1on7QhL7obTY:@Ko5aLG1_ooool7ocHf=POol_;b1olX:2P7oh>3P`Koh^;R1olO7al7
onKViPKo:BTY1_ooool7ob0P80Oo=cLg1om]KFd6odA4A0OoJVYZ1onh^;P7oeQHF0Ko=SHf1_ooool7
oclo?`OoDE5A1oli>CT6oeEEE@Oo<C4a1olS8b<7oa/K6`Ko8b<S1_ooool7obHV9POo4a<C1_ln?Sh7
oda<C0Oo7QhN1olj>SX7oe1@D0Ko:2PX1_ooool7oiBDU0Ko9RHV1ooMgMd7okJf]POoA4A41oooool7
ofMWI`KonOWi3_ooool000cooooo1omPH607oiBDU0OoMGEe1omEEED7ohb<S0KoIVIV1onWYjL6ofMW
I`Kooooo1om4A4@7oe=CD`OoBDU91om1@D47ocDe=@Ko@D511omADE46odm?C`Kooooo1olN7Qh7oc4a
<@OoJ6QX1olG5aL6obDU9@OoQhN71olY:BT6oaLG5`Kooooo1olf=SH7oo;blPOo:2PX1on3Ph<6on;R
hPOo7alO1ooVi^H6obTY:@Kooooo1olP8207ocLg=`OoKFe]1_m4A4@7ofYZJPOo^;Rh1omHF5P6ocHf
=PKooooo1olo?cl7oe5AD@Oo>CTi1_mEEED7oc4a<@Oo8b<S1olK6a/6ob<S8`Kooooo1olV9RH7oa<C
4`Ko?Shn1om<C4`7oahN7POo>SXj1om@D506obPX:0Kooooo1onDU9@6obHV9POogMgM1onf][H7odA4
A0Oooooo1omWIfL6ooWin@kooooo000<ooooo`OoH61P1onDU9@7ogEeM@OoEEEE1on<S8`6ofIVIPOo
YjNW1_mWIfL6ooooo`OoA4A41omCDe<7odU9B@Oo@D511ole=CD6od51@@OoDE5A1_m?Cdl6ooooo`Oo
7QhN1ola<C47ofQXJ0Oo5aLG1_lU9BD7ohN7Q`Oo:BTY1_lG5aL6ooooo`Oo=SHf1oobl_87obPX:0Oo
Ph>31_oRh^87oalO7`Ooi^KV1_lY:BT6ooooo`Oo820P1olg=cL7ofe]K@KoA4A41omZJVX7okRh^0Oo
F5QH1_lf=SH6ooooo`Oo?clo1omADE47ocTi>@KoEEEE1ola<C47ob<S8`Oo6a/K1_lS8b<6ooooo`Oo
9RHV1olC4a<6ochn?POoC4a<1olN7Qh7ocXj>POoD51@1_lX:2P6ooooo`OoU9BD1_lV9RH7omgMg@Oo
][Jf1om4A4@7ooooo`OoIfMW1_oinOT>ooooo`003?ooool7of1PH0OoU9BD1omeMGD7oeEEE@OoS8b<
1_mVIVH7ojNWY`KoIfMW1_ooool7odA4A0OoDe=C1om9BDT7od51@@Oo=CDe1_m1@D47oe5AD@KoCdm?
1_ooool7oahN7POo<C4a1omXJ6P7oaLG5`Ko9BDU1on7QhL7obTY:@Ko5aLG1_ooool7ocHf=POol_;b
1olX:2P7oh>3P`Koh^;R1olO7al7onKViPKo:BTY1_ooool7ob0P80Oo=cLg1om]KFd6odA4A0OoJVYZ
1onh^;P7oeQHF0Ko=SHf1_ooool7oclo?`OoDE5A1oli>CT6oeEEE@Oo<C4a1olS8b<7oa/K6`Ko8b<S
1_ooool7obHV9POo4a<C1_ln?Sh7oda<C0Oo7QhN1olj>SX7oe1@D0Ko:2PX1_ooool7oiBDU0Ko9RHV
1ooMgMd7okJf]POoA4A41oooool7ofMWI`KonOWi3_ooool000cooooo1onJVYX7ohf=S@OoUiNG1onN
WYh7odi>CPKoQ8B41onc/k<6ode=C@Kooooo1omIFET7ofEUI@Oo@D511olc<c<7ob<S8`Ko=CDe1oln
?Sh6oc/k>`Kooooo1olT92@7o``<30Oo>3Ph1om>CTh6oahN7POo:b/[1omGEeL6ob`/;0Kooooo1omU
IFD7ocHf=POo92@T1oo7alL6oeUIF@Oo5aLG1oooool6o`/;2`Kooooo1olJ6QX7ocHf=POoCdm?1_m9
BDT7ooooo`OoOWin1om0@406oeMGE`Kooooo1oli>CT7oc<c<`Oo?clo1_lh>3P7ocXj>POo8b<S1olY
:BT6ob/[:`Kooooo1olb<S87ofe]K@Ko>3Ph1ol<30`7oc`l?0OoATI61ol71`L6o`T92@Kooooo1ooA
dM46o``<30OoShn?1onMWId7oe]KF`Ool?3`1olg=cL6ojJVYPkooooo000<ooooo`OoVYZJ1on=SHd7
oiNGU`OoWYjN1om>CTh6ohB4Q0Oo/k>c1_m=CDd6ooooo`OoFEUI1omUIFD7od51@@Oo<c<c1olS8b<6
ocDe=@Oo?Shn1_lk>c/6ooooo`Oo92@T1ol<30`7ocPh>0OoCTi>1_lN7Qh7ob/[:`OoEeMG1_l/;2`6
ooooo`OoIFEU1olf=SH7ob@T90OoalO71_mIFET7oaLG5`Oooooo1_l;2`/6ooooo`Oo6QXJ1olf=SH7
odm?C`KoBDU91oooool7oginOPOo@4101_mGEeL6ooooo`Oo>CTi1olc<c<7oclo?`Ko>3Ph1olj>SX7
ob<S8`Oo:BTY1_l[:b/6ooooo`Oo<S8b1om]KFd6ocPh>0Oo30`<1oll?3`7odI6APOo1`L71_l92@T6
ooooo`OodM7A1_l<30`7ohn?S`OoWIfM1omKFe/7oo3`l0Oo=cLg1_nVYZH>ooooo`003?ooool7oiZJ
VPOoSHf=1onGUiL7oijNWPOoCTi>1_n4Q8@7ok>c/`KoCDe=1_ooool7oeUIF@OoIFEU1om1@D47oc<c
<`Oo8b<S1_le=CD7ochn?PKo>c/k1_ooool7ob@T90Oo30`<1olh>3P7odi>CPKo7QhN1ol[:b/7oeMG
E`Ko;2`/1_ooool7ofEUI@Oo=SHf1olT92@7olO7a`KoFEUI1olG5aL7ooooo`Ko2`/;1_ooool7oaXJ
6POo=SHf1om?Cdl6odU9B@Oooooo1omnOWh7od10@0KoEeMG1_ooool7ocTi>@Oo<c<c1olo?cl6ocPh
>0Oo>SXj1olS8b<7obTY:@Ko:b/[1_ooool7oc8b<POoKFe]1_lh>3P7o``<30Oo?3`l1om6ATH7o`L7
1`Ko2@T91_ooool7om7Ad@Ko30`<1on?Shl7oifMW@OoFe]K1oo`l?07ocLg=`KoYZJV3_ooool000co
oooo1onJVYX7ohf=S@OoUiNG1onNWYh7odi>CPKoQ8B41onc/k<6ode=C@Kooooo1omIFET7ofEUI@Oo
@D511olc<c<7ob<S8`Ko=CDe1oln?Sh6oc/k>`Kooooo1olT92@7o``<30Oo>3Ph1om>CTh6oahN7POo
:b/[1omGEeL6ob`/;0Kooooo1omUIFD7ocHf=POo92@T1oo7alL6oeUIF@Oo5aLG1oooool6o`/;2`Ko
oooo1olJ6QX7ocHf=POoCdm?1_m9BDT7ooooo`OoOWin1om0@406oeMGE`Kooooo1oli>CT7oc<c<`Oo
?clo1_lh>3P7ocXj>POo8b<S1olY:BT6ob/[:`Kooooo1olb<S87ofe]K@Ko>3Ph1ol<30`7oc`l?0Oo
ATI61ol71`L6o`T92@Kooooo1ooAdM46o``<30OoShn?1onMWId7oe]KF`Ool?3`1olg=cL6ojJVYPko
oooo000<ooooo`OoVYZJ1on=SHd7oiNGU`OoWYjN1om>CTh6ohB4Q0Oo/k>c1_m=CDd6ooooo`OoFEUI
1omUIFD7od51@@Oo<c<c1olS8b<6ocDe=@Oo?Shn1_lk>c/6ooooo`Oo92@T1ol<30`7ocPh>0OoCTi>
1_lN7Qh7ob/[:`OoEeMG1_l/;2`6ooooo`OoIFEU1olf=SH7ob@T90OoalO71_mIFET7oaLG5`Oooooo
1_l;2`/6ooooo`Oo6QXJ1olf=SH7odm?C`KoBDU91oooool7oginOPOo@4101_mGEeL6ooooo`Oo>CTi
1olc<c<7oclo?`Ko>3Ph1olj>SX7ob<S8`Oo:BTY1_l[:b/6ooooo`Oo<S8b1om]KFd6ocPh>0Oo30`<
1oll?3`7odI6APOo1`L71_l92@T6ooooo`OodM7A1_l<30`7ohn?S`OoWIfM1omKFe/7oo3`l0Oo=cLg
1_nVYZH>ooooo`003?ooool7oiZJVPOoSHf=1onGUiL7oijNWPOoCTi>1_n4Q8@7ok>c/`KoCDe=1_oo
ool7oeUIF@OoIFEU1om1@D47oc<c<`Oo8b<S1_le=CD7ochn?PKo>c/k1_ooool7ob@T90Oo30`<1olh
>3P7odi>CPKo7QhN1ol[:b/7oeMGE`Ko;2`/1_ooool7ofEUI@Oo=SHf1olT92@7olO7a`KoFEUI1olG
5aL7ooooo`Ko2`/;1_ooool7oaXJ6POo=SHf1om?Cdl6odU9B@Oooooo1omnOWh7od10@0KoEeMG1_oo
ool7ocTi>@Oo<c<c1olo?cl6ocPh>0Oo>SXj1olS8b<7obTY:@Ko:b/[1_ooool7oc8b<POoKFe]1_lh
>3P7o``<30Oo?3`l1om6ATH7o`L71`Ko2@T91_ooool7om7Ad@Ko30`<1on?Shl7oifMW@OoFe]K1oo`
l?07ocLg=`KoYZJV3_ooool000cooooo1onJVYX7ohf=S@OoUiNG1onNWYh7odi>CPKoQ8B41onc/k<6
ode=C@Kooooo1omIFET7ofEUI@Oo@D511olc<c<7ob<S8`Ko=CDe1oln?Sh6oc/k>`Kooooo1olT92@7
o``<30Oo>3Ph1om>CTh6oahN7POo:b/[1omGEeL6ob`/;0Kooooo1omUIFD7ocHf=POo92@T1oo7alL6
oeUIF@Oo5aLG1oooool6o`/;2`Kooooo1olJ6QX7ocHf=POoCdm?1_m9BDT7ooooo`OoOWin1om0@406
oeMGE`Kooooo1oli>CT7oc<c<`Oo?clo1_lh>3P7ocXj>POo8b<S1olY:BT6ob/[:`Kooooo1olb<S87
ofe]K@Ko>3Ph1ol<30`7oc`l?0OoATI61ol71`L6o`T92@Kooooo1ooAdM46o``<30OoShn?1onMWId7
oe]KF`Ool?3`1olg=cL6ojJVYPkooooo000<ooooo`Oo?Shn1olo?cl7ofm_K`Oo00001om/K6`6oeIF
EPOoDe=C1_m0@406ooooo`Oo<S8b1om6ATH7oaTI6@Oo820P1ol410@6o``<30Oo2PX:1_lF5QH6oooo
o`Oo=SHf1om3@d<7odm?C`Oo51@D1_lJ6QX7oemOG`Oo5aLG1_l=3@d6ooooo`Oo;bl_1ommOGd7ob<S
8`OoBDU91_n<S8`7oclo?`OoJ6QX1_l/;2`6ooooo`Oo1PH61olF5QH7ocXj>PKo6a/K1om9BDT7od];
B`Oo=SHf1_l71`L6ooooo`Oo6QXJ1ola<C47obl_;`Ko<C4a1olb<S87odA4A0Oo@T921_lf=SH6oooo
o`Oo61PH1olh>3P6ogEeM@Oo;bl_1olj>SX7ocPh>0Oo<S8b1_l20P86ooooo`Oo5aLG1_lC4a<7onk^
kPOo<30`1olO7al7ono_k`Oo6a/K1_nEUID>ooooo`003?ooool7ochn?POo?clo1om_Kfl7o`0000Oo
K6a/1_mFEUH7oe=CD`Ko@4101_ooool7oc8b<POoATI61olI6AT7ob0P80Oo10@41_l<30`7o`X:2PKo
5QHF1_ooool7ocHf=POo@d=31om?Cdl7oa@D50Ko6QXJ1omOGel7oaLG5`Ko3@d=1_ooool7obl_;`Oo
OGem1olS8b<7odU9B@KoS8b<1olo?cl7ofQXJ0Ko;2`/1_ooool7o`H61POo5QHF1olj>SX6oa/K6`Oo
BDU91om;Bd/7ocHf=PKo1`L71_ooool7oaXJ6POo<C4a1ol_;bl6oc4a<@Oo<S8b1om4A4@7od92@PKo
=SHf1_ooool7oaPH60Oo>3Ph1_meMGD7obl_;`Oo>SXj1olh>3P7oc8b<PKo0P821_ooool7oaLG5`Ko
4a<C1oo^k^h7oc0`<0Oo7alO1oo_knl7oa/K6`KoUIFE3_ooool000cooooo1oln?Sh7oclo?`OoKfm_
1ol00007ofa/K0KoEUIF1omCDe<6od10@0Kooooo1olb<S87odI6APOo6ATI1olP8207o`@410Ko30`<
1ol:2PX6oaHF5PKooooo1olf=SH7od=3@`OoCdm?1olD51@6oaXJ6POoGemO1olG5aL6o`d=3@Kooooo
1ol_;bl7ogemO@Oo8b<S1om9BDT6ohb<S0Oo?clo1omXJ6P6ob`/;0Kooooo1ol61PH7oaHF5POo>SXj
1_lK6a/7odU9B@OoBd];1olf=SH6o`L71`Kooooo1olJ6QX7oc4a<@Oo;bl_1_la<C47oc8b<POoA4A4
1om2@T86ocHf=PKooooo1olH61P7ocPh>0KoMGEe1ol_;bl7ocXj>POo>3Ph1olb<S86o`820PKooooo
1olG5aL6oa<C4`Ook^k^1ol`<307oalO7`Ookno_1olK6a/6oiFEU@kooooo000<ooooo`Oo?Shn1olo
?cl7ofm_K`Oo00001om/K6`6oeIFEPOoDe=C1_m0@406ooooo`Oo<S8b1om6ATH7oaTI6@Oo820P1ol4
10@6o``<30Oo2PX:1_lF5QH6ooooo`Oo=SHf1om3@d<7odm?C`Oo51@D1_lJ6QX7oemOG`Oo5aLG1_l=
3@d6ooooo`Oo;bl_1ommOGd7ob<S8`OoBDU91_n<S8`7oclo?`OoJ6QX1_l/;2`6ooooo`Oo1PH61olF
5QH7ocXj>PKo6a/K1om9BDT7od];B`Oo=SHf1_l71`L6ooooo`Oo6QXJ1ola<C47obl_;`Ko<C4a1olb
<S87odA4A0Oo@T921_lf=SH6ooooo`Oo61PH1olh>3P6ogEeM@Oo;bl_1olj>SX7ocPh>0Oo<S8b1_l2
0P86ooooo`Oo5aLG1_lC4a<7onk^kPOo<30`1olO7al7ono_k`Oo6a/K1_nEUID>ooooo`003?ooool7
ochn?POo?clo1om_Kfl7o`0000OoK6a/1_mFEUH7oe=CD`Ko@4101_ooool7oc8b<POoATI61olI6AT7
ob0P80Oo10@41_l<30`7o`X:2PKo5QHF1_ooool7ocHf=POo@d=31om?Cdl7oa@D50Ko6QXJ1omOGel7
oaLG5`Ko3@d=1_ooool7obl_;`OoOGem1olS8b<7odU9B@KoS8b<1olo?cl7ofQXJ0Ko;2`/1_ooool7
o`H61POo5QHF1olj>SX6oa/K6`OoBDU91om;Bd/7ocHf=PKo1`L71_ooool7oaXJ6POo<C4a1ol_;bl6
oc4a<@Oo<S8b1om4A4@7od92@PKo=SHf1_ooool7oaPH60Oo>3Ph1_meMGD7obl_;`Oo>SXj1olh>3P7
oc8b<PKo0P821_ooool7oaLG5`Ko4a<C1oo^k^h7oc0`<0Oo7alO1oo_knl7oa/K6`KoUIFE3_ooool0
00cooooo1oln?Sh7oclo?`OoKfm_1ol00007ofa/K0KoEUIF1omCDe<6od10@0Kooooo1olb<S87odI6
APOo6ATI1olP8207o`@410Ko30`<1ol:2PX6oaHF5PKooooo1olf=SH7od=3@`OoCdm?1olD51@6oaXJ
6POoGemO1olG5aL6o`d=3@Kooooo1ol_;bl7ogemO@Oo8b<S1om9BDT6ohb<S0Oo?clo1omXJ6P6ob`/
;0Kooooo1ol61PH7oaHF5POo>SXj1_lK6a/7odU9B@OoBd];1olf=SH6o`L71`Kooooo1olJ6QX7oc4a
<@Oo;bl_1_la<C47oc8b<POoA4A41om2@T86ocHf=PKooooo1olH61P7ocPh>0KoMGEe1ol_;bl7ocXj
>POo>3Ph1olb<S86o`820PKooooo1olG5aL6oa<C4`Ook^k^1ol`<307oalO7`Ookno_1olK6a/6oiFE
U@kooooo000<ooooo`Oo^KVi1on^[Zh7ol30`0OoZ:RX1onYZJT6oifMW@Ook>c/1_mhN7P6ooooo`Oo
<30`1olV9RH7o`l?3`Oo1PH61ol00006o`<30`Oo10@41_l20P86ooooo`Oo4Q8B1ol`<307oi6AT@Oo
4A4A1_l];Bd7oemOG`Oo3@d=1_lC4a<6ooooo`OoATI61olA4A47o`d=3@OoNg]k1_lC4a<7oa`L70Oo
YjNW1_l61PH6ooooo`Oo6QXJ1olC4a<7ocdm?@Ko=cLg1omQHF47oeaLG0Oo5aLG1_lV9RH6ooooo`Oo
00001ol;2`/7oa<C4`Ko5ADE1olJ6QX7oahN7POo;2`/1_lS8b<6ooooo`Oo8B4Q1oooool6ob<S8`Oo
410@1oo5aLD7oalO7`Oo3`l?1_m2@T86ooooo`Oo@4101_lR8R87odE5A@Oo=SHf1omkNg/7obh^;POo
9RHV1_o<c<`>ooooo`003?ooool7okVi^@Oo[Zj^1oo0`<07ojRXZ0OoZJVY1_nMWId7onc/k0KoN7Qh
1_ooool7oc0`<0Oo9RHV1ol?3`l7o`H61POo00001_l30`<7o`@410Ko0P821_ooool7oa8B4POo<30`
1onATI47oa4A4@Ko;Bd]1omOGel7o`d=3@Ko4a<C1_ooool7odI6APOo4A4A1ol=3@d7og]kN`Ko4a<C
1olL71`7ojNWY`Ko1PH61_ooool7oaXJ6POo4a<C1olm?Cd6ocLg=`OoHF5Q1omLG5`7oaLG5`Ko9RHV
1_ooool7o`0000Oo2`/;1olC4a<6oaDE5@Oo6QXJ1olN7Qh7ob`/;0Ko8b<S1_ooool7ob4Q8@Oooooo
1_lS8b<7oa0@40OoaLG51olO7al7o`l?3`Ko@T921_ooool7od10@0Ko8R8R1om5ADD7ocHf=POoNg]k
1ol^;Rh7obHV9PKoc<c<3_ooool000cooooo1oni^KT7ojj^[POo`<301onXZ:P7ojVYZ@KoWIfM1oo/
k>`6ogQhN0Kooooo1ol`<307obHV9POo3`l?1ol61PH7o`0000Ko0`<31ol410@6o`820PKooooo1olB
4Q87oc0`<0OoTI6A1olA4A46obd];@OoGemO1ol=3@d6oa<C4`Kooooo1om6ATH7oa4A4@Oo3@d=1omk
Ng/6oa<C4`Oo71`L1onWYjL6o`H61PKooooo1olJ6QX7oa<C4`Oo?Cdm1_lg=cL7of5QH@OoG5aL1olG
5aL6obHV9PKooooo1ol00007o`/;2`Oo4a<C1_lE5AD7oaXJ6POo7QhN1ol/;2`6ob<S8`Kooooo1olQ
8B47ooooo`Ko8b<S1ol@4107olG5a@Oo7alO1ol?3`l6od92@PKooooo1om0@406ob8R8POoADE51olf
=SH7og]kN`Oo;Rh^1olV9RH6olc<c0kooooo000<ooooo`Oo^KVi1on^[Zh7ol30`0OoZ:RX1onYZJT6
oifMW@Ook>c/1_mhN7P6ooooo`Oo<30`1olV9RH7o`l?3`Oo1PH61ol00006o`<30`Oo10@41_l20P86
ooooo`Oo4Q8B1ol`<307oi6AT@Oo4A4A1_l];Bd7oemOG`Oo3@d=1_lC4a<6ooooo`OoATI61olA4A47
o`d=3@OoNg]k1_lC4a<7oa`L70OoYjNW1_l61PH6ooooo`Oo6QXJ1olC4a<7ocdm?@Ko=cLg1omQHF47
oeaLG0Oo5aLG1_lV9RH6ooooo`Oo00001ol;2`/7oa<C4`Ko5ADE1olJ6QX7oahN7POo;2`/1_lS8b<6
ooooo`Oo8B4Q1oooool6ob<S8`Oo410@1oo5aLD7oalO7`Oo3`l?1_m2@T86ooooo`Oo@4101_lR8R87
odE5A@Oo=SHf1omkNg/7obh^;POo9RHV1_o<c<`>ooooo`003?ooool7okVi^@Oo[Zj^1oo0`<07ojRX
Z0OoZJVY1_nMWId7onc/k0KoN7Qh1_ooool7oc0`<0Oo9RHV1ol?3`l7o`H61POo00001_l30`<7o`@4
10Ko0P821_ooool7oa8B4POo<30`1onATI47oa4A4@Ko;Bd]1omOGel7o`d=3@Ko4a<C1_ooool7odI6
APOo4A4A1ol=3@d7og]kN`Ko4a<C1olL71`7ojNWY`Ko1PH61_ooool7oaXJ6POo4a<C1olm?Cd6ocLg
=`OoHF5Q1omLG5`7oaLG5`Ko9RHV1_ooool7o`0000Oo2`/;1olC4a<6oaDE5@Oo6QXJ1olN7Qh7ob`/
;0Ko8b<S1_ooool7ob4Q8@Oooooo1_lS8b<7oa0@40OoaLG51olO7al7o`l?3`Ko@T921_ooool7od10
@0Ko8R8R1om5ADD7ocHf=POoNg]k1ol^;Rh7obHV9PKoc<c<3_ooool000cooooo1oni^KT7ojj^[POo
`<301onXZ:P7ojVYZ@KoWIfM1oo/k>`6ogQhN0Kooooo1ol`<307obHV9POo3`l?1ol61PH7o`0000Ko
0`<31ol410@6o`820PKooooo1olB4Q87oc0`<0OoTI6A1olA4A46obd];@OoGemO1ol=3@d6oa<C4`Ko
oooo1om6ATH7oa4A4@Oo3@d=1omkNg/6oa<C4`Oo71`L1onWYjL6o`H61PKooooo1olJ6QX7oa<C4`Oo
?Cdm1_lg=cL7of5QH@OoG5aL1olG5aL6obHV9PKooooo1ol00007o`/;2`Oo4a<C1_lE5AD7oaXJ6POo
7QhN1ol/;2`6ob<S8`Kooooo1olQ8B47ooooo`Ko8b<S1ol@4107olG5a@Oo7alO1ol?3`l6od92@PKo
oooo1om0@406ob8R8POoADE51olf=SH7og]kN`Oo;Rh^1olV9RH6olc<c0kooooo000<ooooo`Oo^KVi
1on^[Zh7ol30`0OoZ:RX1onYZJT6oifMW@Ook>c/1_mhN7P6ooooo`Oo<30`1olV9RH7o`l?3`Oo1PH6
1ol00006o`<30`Oo10@41_l20P86ooooo`Oo4Q8B1ol`<307oi6AT@Oo4A4A1_l];Bd7oemOG`Oo3@d=
1_lC4a<6ooooo`OoATI61olA4A47o`d=3@OoNg]k1_lC4a<7oa`L70OoYjNW1_l61PH6ooooo`Oo6QXJ
1olC4a<7ocdm?@Ko=cLg1omQHF47oeaLG0Oo5aLG1_lV9RH6ooooo`Oo00001ol;2`/7oa<C4`Ko5ADE
1olJ6QX7oahN7POo;2`/1_lS8b<6ooooo`Oo8B4Q1oooool6ob<S8`Oo410@1oo5aLD7oalO7`Oo3`l?
1_m2@T86ooooo`Oo@4101_lR8R87odE5A@Oo=SHf1omkNg/7obh^;POo9RHV1_o<c<`>ooooo`003?oo
ool7oe5AD@Oo?clo1om^KVh7o`l?3`OoH61P1_mVIVH7og9bLPKo51@D1_ooool7oa/K6`Oo7QhN1ol:
2PX7oa<C4`Oo20P81_lE5AD7o`/;2`Ko5QHF1_ooool7ocdm?@Oooooo1omGEeL7oa`L70Ko[Zj^1olW
9bL7o`T92@KoBTY:1_ooool7ofi^KPOo;Rh^1olj>SX7obd];@Ko9bLW1omKFe/7oaPH60Ko4a<C1_oo
ool7o`0000Oo5QHF1om8B4P6oaPH60OoEEEE1olj>SX7ob@T90Ko7AdM1_ooool>o`H61POo10@41_l8
20P7o`820POo1`L71ol820P6o`d=3@Kooooo1olV9RH7ohB4Q0KoN7Qh1omkNg/7ogEeM@Oo:RXZ1ond
];@6o`0000Kooooo1ol410@6odm?C`OoFEUI1ol51@D7ocLg=`OoO7al1ol/;2`6odI6APkooooo000<
ooooo`OoDE5A1olo?cl7ofi^KPOo3`l?1omPH606ofIVIPOoLW9b1_lD51@6ooooo`Oo6a/K1olN7Qh7
o`X:2POo4a<C1ol820P6oaDE5@Oo2`/;1_lF5QH6ooooo`Oo?Cdm1oooool7oeMGE`Oo71`L1_n^[Zh7
obLW9`Oo2@T91_m:BTX6ooooo`OoKVi^1ol^;Rh7ocXj>POo;Bd]1_lW9bL7oe]KF`Oo61PH1_lC4a<6
ooooo`Oo00001olF5QH7odQ8B0Ko61PH1omEEED7ocXj>POo92@T1_lM7Ad6ooooo`ko1PH61ol410@6
o`P820Oo0P821ol71`L7o`P820Ko3@d=1_ooool7obHV9POoQ8B41_mhN7P7og]kN`OoMGEe1olZ:RX7
okBd]0Ko00001_ooool7o`@410KoCdm?1omIFET7o`D51@Oo=cLg1omlO7`7ob`/;0KoATI63_ooool0
00cooooo1omADE47oclo?`OoKVi^1ol?3`l7of1PH0KoIVIV1ombLW86oa@D50Kooooo1olK6a/7oahN
7POo2PX:1olC4a<7o`P820Ko5ADE1ol;2`/6oaHF5PKooooo1olm?Cd7ooooo`OoEeMG1olL71`6ojj^
[POo9bLW1ol92@T6odY:BPKooooo1om^KVh7obh^;POo>SXj1ol];Bd6obLW9`OoFe]K1olH61P6oa<C
4`Kooooo1ol00007oaHF5POoB4Q81_lH61P7oeEEE@Oo>SXj1olT92@6oadM7@Kooooo3_l61PH7o`@4
10Ko20P81ol20P87o`L71`Oo20P81_l=3@d6ooooo`Oo9RHV1on4Q8@6ogQhN0OoNg]k1omeMGD7obXZ
:POo];Bd1_l00006ooooo`Oo10@41_m?Cdl7oeUIF@Oo1@D51olg=cL7ogalO0Oo;2`/1_m6ATH>oooo
o`003?ooool7oe5AD@Oo?clo1om^KVh7o`l?3`OoH61P1_mVIVH7og9bLPKo51@D1_ooool7oa/K6`Oo
7QhN1ol:2PX7oa<C4`Oo20P81_lE5AD7o`/;2`Ko5QHF1_ooool7ocdm?@Oooooo1omGEeL7oa`L70Ko
[Zj^1olW9bL7o`T92@KoBTY:1_ooool7ofi^KPOo;Rh^1olj>SX7obd];@Ko9bLW1omKFe/7oaPH60Ko
4a<C1_ooool7o`0000Oo5QHF1om8B4P6oaPH60OoEEEE1olj>SX7ob@T90Ko7AdM1_ooool>o`H61POo
10@41_l820P7o`820POo1`L71ol820P6o`d=3@Kooooo1olV9RH7ohB4Q0KoN7Qh1omkNg/7ogEeM@Oo
:RXZ1ond];@6o`0000Kooooo1ol410@6odm?C`OoFEUI1ol51@D7ocLg=`OoO7al1ol/;2`6odI6APko
oooo000<ooooo`OoDE5A1olo?cl7ofi^KPOo3`l?1omPH606ofIVIPOoLW9b1_lD51@6ooooo`Oo6a/K
1olN7Qh7o`X:2POo4a<C1ol820P6oaDE5@Oo2`/;1_lF5QH6ooooo`Oo?Cdm1oooool7oeMGE`Oo71`L
1_n^[Zh7obLW9`Oo2@T91_m:BTX6ooooo`OoKVi^1ol^;Rh7ocXj>POo;Bd]1_lW9bL7oe]KF`Oo61PH
1_lC4a<6ooooo`Oo00001olF5QH7odQ8B0Ko61PH1omEEED7ocXj>POo92@T1_lM7Ad6ooooo`ko1PH6
1ol410@6o`P820Oo0P821ol71`L7o`P820Ko3@d=1_ooool7obHV9POoQ8B41_mhN7P7og]kN`OoMGEe
1olZ:RX7okBd]0Ko00001_ooool7o`@410KoCdm?1omIFET7o`D51@Oo=cLg1omlO7`7ob`/;0KoATI6
3_ooool000cooooo1omADE47oclo?`OoKVi^1ol?3`l7of1PH0KoIVIV1ombLW86oa@D50Kooooo1olK
6a/7oahN7POo2PX:1olC4a<7o`P820Ko5ADE1ol;2`/6oaHF5PKooooo1olm?Cd7ooooo`OoEeMG1olL
71`6ojj^[POo9bLW1ol92@T6odY:BPKooooo1om^KVh7obh^;POo>SXj1ol];Bd6obLW9`OoFe]K1olH
61P6oa<C4`Kooooo1ol00007oaHF5POoB4Q81_lH61P7oeEEE@Oo>SXj1olT92@6oadM7@Kooooo3_l6
1PH7o`@410Ko20P81ol20P87o`L71`Oo20P81_l=3@d6ooooo`Oo9RHV1on4Q8@6ogQhN0OoNg]k1ome
MGD7obXZ:POo];Bd1_l00006ooooo`Oo10@41_m?Cdl7oeUIF@Oo1@D51olg=cL7ogalO0Oo;2`/1_m6
ATH>ooooo`003?ooool7oe5AD@Oo?clo1om^KVh7o`l?3`OoH61P1_mVIVH7og9bLPKo51@D1_ooool7
oa/K6`Oo7QhN1ol:2PX7oa<C4`Oo20P81_lE5AD7o`/;2`Ko5QHF1_ooool7ocdm?@Oooooo1omGEeL7
oa`L70Ko[Zj^1olW9bL7o`T92@KoBTY:1_ooool7ofi^KPOo;Rh^1olj>SX7obd];@Ko9bLW1omKFe/7
oaPH60Ko4a<C1_ooool7o`0000Oo5QHF1om8B4P6oaPH60OoEEEE1olj>SX7ob@T90Ko7AdM1_ooool>
o`H61POo10@41_l820P7o`820POo1`L71ol820P6o`d=3@Kooooo1olV9RH7ohB4Q0KoN7Qh1omkNg/7
ogEeM@Oo:RXZ1ond];@6o`0000Kooooo1ol410@6odm?C`OoFEUI1ol51@D7ocLg=`OoO7al1ol/;2`6
odI6APkooooo000<ooooo`Oo^[Zj1onHV9P7om3@d0OoUIFE1onb/[86ofi^KPOonOWi1_n0P806oooo
o`Oo8R8R3_lS8b<7obTY:@go9BDU1olT92@6ocHf=PKooooo1oll?3`7ogIfMPOoT92@1omOGel6odQ8
B0OoCTi>1omdM7@6oahN7PKooooo1oli>CT7obDU9@Oo[jn_1ol^;Rh6o`/;2`OoI6AT1olb<S86o`00
00Kooooo1olE5AD7obXZ:POo>CTi1_l[:b/7ol;2`POoP8201olY:BT6ocHf=PKooooo1olG5aL7o`T9
2@Oo2PX:1_l;2`/7o`X:2POo0`<31ol=3@d6oa`L70Kooooo1olU9BD7ol_;b`KoBd];1omLG5`7onc/
k0Oo4Q8B1omCDe<6ocdm?@Kooooo3Om4A4@7obd];@Oo<S8b1om?Cdl7o`0000Oo4a<C1_m?Cdl>oooo
o`003?ooool7okZj^POoV9RH1oo@d=07oiFEU@Oo/[:b1_m^KVh7ooWin@KoP8201_ooool7ob8R8Pko
8b<S1olY:BT=obDU9@Oo92@T1_lf=SH6ooooo`Oo?3`l1omfMWH7oi2@T0OoGemO1_m8B4P7odi>CPOo
M7Ad1_lN7Qh6ooooo`Oo>CTi1olU9BD7ojn_[`Oo;Rh^1_l;2`/7ofATI0Oo<S8b1_l00006ooooo`Oo
5ADE1olZ:RX7ocTi>@Ko:b/[1oo2`/87oh20P0Oo:BTY1_lf=SH6ooooo`Oo5aLG1ol92@T7o`X:2PKo
2`/;1ol:2PX7o`<30`Oo3@d=1_lL71`6ooooo`Oo9BDU1oo;bl/6od];B`OoG5aL1oo/k>`7oa8B4POo
De=C1_lm?Cd6ooooo`goA4A41ol];Bd7oc8b<POoCdm?1ol00007oa<C4`KoCdm?3_ooool000cooooo
1onj^[X7oiRHV0Ood=3@1onEUID7ok:b/PKoKVi^1ooinOT6oh20P0Kooooo1olR8R8>ob<S8`Oo:BTY
3OlU9BD7ob@T90Ko=SHf1_ooool7oc`l?0OoMWIf1on@T907oemOG`KoB4Q81om>CTh7ogAdM0Ko7QhN
1_ooool7ocTi>@Oo9BDU1on_[jl7obh^;PKo2`/;1omTI6@7oc8b<PKo00001_ooool7oaDE5@Oo:RXZ
1oli>CT6ob/[:`Oo`/;21on0P807obTY:@Ko=SHf1_ooool7oaLG5`Oo2@T91ol:2PX6o`/;2`Oo2PX:
1ol30`<7o`d=3@Ko71`L1_ooool7obDU9@Oobl_;1_m;Bd/7oeaLG0Ook>c/1olB4Q87oe=CD`Ko?Cdm
1_ooool=odA4A0Oo;Bd]1olb<S87odm?C`Oo00001olC4a<6odm?C`kooooo000<ooooo`Oo^[Zj1onH
V9P7om3@d0OoUIFE1onb/[86ofi^KPOonOWi1_n0P806ooooo`Oo8R8R3_lS8b<7obTY:@go9BDU1olT
92@6ocHf=PKooooo1oll?3`7ogIfMPOoT92@1omOGel6odQ8B0OoCTi>1omdM7@6oahN7PKooooo1oli
>CT7obDU9@Oo[jn_1ol^;Rh6o`/;2`OoI6AT1olb<S86o`0000Kooooo1olE5AD7obXZ:POo>CTi1_l[
:b/7ol;2`POoP8201olY:BT6ocHf=PKooooo1olG5aL7o`T92@Oo2PX:1_l;2`/7o`X:2POo0`<31ol=
3@d6oa`L70Kooooo1olU9BD7ol_;b`KoBd];1omLG5`7onc/k0Oo4Q8B1omCDe<6ocdm?@Kooooo3Om4
A4@7obd];@Oo<S8b1om?Cdl7o`0000Oo4a<C1_m?Cdl>ooooo`003?ooool7okZj^POoV9RH1oo@d=07
oiFEU@Oo/[:b1_m^KVh7ooWin@KoP8201_ooool7ob8R8Pko8b<S1olY:BT=obDU9@Oo92@T1_lf=SH6
ooooo`Oo?3`l1omfMWH7oi2@T0OoGemO1_m8B4P7odi>CPOoM7Ad1_lN7Qh6ooooo`Oo>CTi1olU9BD7
ojn_[`Oo;Rh^1_l;2`/7ofATI0Oo<S8b1_l00006ooooo`Oo5ADE1olZ:RX7ocTi>@Ko:b/[1oo2`/87
oh20P0Oo:BTY1_lf=SH6ooooo`Oo5aLG1ol92@T7o`X:2PKo2`/;1ol:2PX7o`<30`Oo3@d=1_lL71`6
ooooo`Oo9BDU1oo;bl/6od];B`OoG5aL1oo/k>`7oa8B4POoDe=C1_lm?Cd6ooooo`goA4A41ol];Bd7
oc8b<POoCdm?1ol00007oa<C4`KoCdm?3_ooool000cooooo1onj^[X7oiRHV0Ood=3@1onEUID7ok:b
/PKoKVi^1ooinOT6oh20P0Kooooo1olR8R8>ob<S8`Oo:BTY3OlU9BD7ob@T90Ko=SHf1_ooool7oc`l
?0OoMWIf1on@T907oemOG`KoB4Q81om>CTh7ogAdM0Ko7QhN1_ooool7ocTi>@Oo9BDU1on_[jl7obh^
;PKo2`/;1omTI6@7oc8b<PKo00001_ooool7oaDE5@Oo:RXZ1oli>CT6ob/[:`Oo`/;21on0P807obTY
:@Ko=SHf1_ooool7oaLG5`Oo2@T91ol:2PX6o`/;2`Oo2PX:1ol30`<7o`d=3@Ko71`L1_ooool7obDU
9@Oobl_;1_m;Bd/7oeaLG0Ook>c/1olB4Q87oe=CD`Ko?Cdm1_ooool=odA4A0Oo;Bd]1olb<S87odm?
C`Oo00001olC4a<6odm?C`kooooo000<ooooo`OoEUIF1omYJFT7ogemO@Oo8b<S1ol`<306ohB4Q0Oo
RXZ:1_mLG5`6ooooo`Oo8R8R1old=3@7obd];@Oo:RXZ1om9BDT6odY:BPOoEUIF1_mWIfL6ooooo`Oo
9BDU1oo7alL7oeeMG@Oo;bl_1_oRh^87oclo?`Oo@D511_mXJ6P6ooooo`OoU9BD1on=SHd7oginOPOo
?Shn1_n5QHD7oclo?`Oo5ADE1_m5ADD6ooooo`Oo=CDe1ola<C47oeeMG@KoJVYZ1onn_[h7ofe]K@Oo
Cdm?1_ll?3`6ooooo`Oo9RHV1olS8b<7ob0P80Ko;Bd]1ol_;bl7ob<S8`Oo820P1_lH61P6ooooo`Oo
4Q8B1oo@d=06ob@T90OoQ8B41on[Zj/7oaDE5@Oog=cL1_l@4106ooooo`Oo:RXZ1_oZj^X7oaXJ6POo
:RXZ1omPH607oc<c<`Oo=CDe1_l=3@d>ooooo`003?ooool7oeIFEPOoJFUY1ommOGd7ob<S8`Oo<30`
1_n4Q8@7ohZ:RPKoG5aL1_ooool7ob8R8POo=3@d1ol];Bd7obXZ:POoBDU91_m:BTX7oeIFEPKoIfMW
1_ooool7obDU9@OoalO71omMGEd7obl_;`Koh^;R1olo?cl7od51@@KoJ6QX1_ooool7oiBDU0OoSHf=
1omnOWh7ochn?PKoQHF51olo?cl7oaDE5@KoADE51_ooool7ocDe=@Oo<C4a1omMGEd6ofYZJPOo_[jn
1om]KFd7odm?C`Ko?3`l1_ooool7obHV9POo8b<S1olP8206obd];@Oo;bl_1olS8b<7ob0P80Ko61PH
1_ooool7oa8B4POod=3@1_lT92@7ohB4Q0OoZj^[1olE5AD7omcLg0Ko410@1_ooool7obXZ:PKoj^[Z
1olJ6QX7obXZ:POoH61P1olc<c<7ocDe=@Ko3@d=3_ooool000cooooo1omFEUH7ofUYJ@OoOGem1olS
8b<7oc0`<0KoQ8B41on:RXX6oeaLG0Kooooo1olR8R87oc@d=0Oo;Bd]1olZ:RX7odU9B@KoBTY:1omF
EUH6ofMWI`Kooooo1olU9BD7olO7a`OoGEeM1ol_;bl6on;RhPOo?clo1om1@D46ofQXJ0Kooooo1onD
U9@7ohf=S@OoOWin1oln?Sh6ohF5Q@Oo?clo1olE5AD6odE5A@Kooooo1ole=CD7oc4a<@OoGEeM1_mZ
JVX7okjn_POoKFe]1om?Cdl6oc`l?0Kooooo1olV9RH7ob<S8`Oo820P1_l];Bd7obl_;`Oo8b<S1olP
8206oaPH60Kooooo1olB4Q87om3@d0Ko92@T1on4Q8@7oj^[Z`Oo5ADE1ooLg=`6oa0@40Kooooo1olZ
:RX6on[ZjPOo6QXJ1olZ:RX7of1PH0Oo<c<c1ole=CD6o`d=3@kooooo000<ooooo`OoEUIF1omYJFT7
ogemO@Oo8b<S1ol`<306ohB4Q0OoRXZ:1_mLG5`6ooooo`Oo8R8R1old=3@7obd];@Oo:RXZ1om9BDT6
odY:BPOoEUIF1_mWIfL6ooooo`Oo9BDU1oo7alL7oeeMG@Oo;bl_1_oRh^87oclo?`Oo@D511_mXJ6P6
ooooo`OoU9BD1on=SHd7oginOPOo?Shn1_n5QHD7oclo?`Oo5ADE1_m5ADD6ooooo`Oo=CDe1ola<C47
oeeMG@KoJVYZ1onn_[h7ofe]K@OoCdm?1_ll?3`6ooooo`Oo9RHV1olS8b<7ob0P80Ko;Bd]1ol_;bl7
ob<S8`Oo820P1_lH61P6ooooo`Oo4Q8B1oo@d=06ob@T90OoQ8B41on[Zj/7oaDE5@Oog=cL1_l@4106
ooooo`Oo:RXZ1_oZj^X7oaXJ6POo:RXZ1omPH607oc<c<`Oo=CDe1_l=3@d>ooooo`003?ooool7oeIF
EPOoJFUY1ommOGd7ob<S8`Oo<30`1_n4Q8@7ohZ:RPKoG5aL1_ooool7ob8R8POo=3@d1ol];Bd7obXZ
:POoBDU91_m:BTX7oeIFEPKoIfMW1_ooool7obDU9@OoalO71omMGEd7obl_;`Koh^;R1olo?cl7od51
@@KoJ6QX1_ooool7oiBDU0OoSHf=1omnOWh7ochn?PKoQHF51olo?cl7oaDE5@KoADE51_ooool7ocDe
=@Oo<C4a1omMGEd6ofYZJPOo_[jn1om]KFd7odm?C`Ko?3`l1_ooool7obHV9POo8b<S1olP8206obd]
;@Oo;bl_1olS8b<7ob0P80Ko61PH1_ooool7oa8B4POod=3@1_lT92@7ohB4Q0OoZj^[1olE5AD7omcL
g0Ko410@1_ooool7obXZ:PKoj^[Z1olJ6QX7obXZ:POoH61P1olc<c<7ocDe=@Ko3@d=3_ooool000co
oooo1omFEUH7ofUYJ@OoOGem1olS8b<7oc0`<0KoQ8B41on:RXX6oeaLG0Kooooo1olR8R87oc@d=0Oo
;Bd]1olZ:RX7odU9B@KoBTY:1omFEUH6ofMWI`Kooooo1olU9BD7olO7a`OoGEeM1ol_;bl6on;RhPOo
?clo1om1@D46ofQXJ0Kooooo1onDU9@7ohf=S@OoOWin1oln?Sh6ohF5Q@Oo?clo1olE5AD6odE5A@Ko
oooo1ole=CD7oc4a<@OoGEeM1_mZJVX7okjn_POoKFe]1om?Cdl6oc`l?0Kooooo1olV9RH7ob<S8`Oo
820P1_l];Bd7obl_;`Oo8b<S1olP8206oaPH60Kooooo1olB4Q87om3@d0Ko92@T1on4Q8@7oj^[Z`Oo
5ADE1ooLg=`6oa0@40Kooooo1olZ:RX6on[ZjPOo6QXJ1olZ:RX7of1PH0Oo<c<c1ole=CD6o`d=3@ko
oooo000<ooooo`OoEUIF1omYJFT7ogemO@Oo8b<S1ol`<306ohB4Q0OoRXZ:1_mLG5`6ooooo`Oo8R8R
1old=3@7obd];@Oo:RXZ1om9BDT6odY:BPOoEUIF1_mWIfL6ooooo`Oo9BDU1oo7alL7oeeMG@Oo;bl_
1_oRh^87oclo?`Oo@D511_mXJ6P6ooooo`OoU9BD1on=SHd7oginOPOo?Shn1_n5QHD7oclo?`Oo5ADE
1_m5ADD6ooooo`Oo=CDe1ola<C47oeeMG@KoJVYZ1onn_[h7ofe]K@OoCdm?1_ll?3`6ooooo`Oo9RHV
1olS8b<7ob0P80Ko;Bd]1ol_;bl7ob<S8`Oo820P1_lH61P6ooooo`Oo4Q8B1oo@d=06ob@T90OoQ8B4
1on[Zj/7oaDE5@Oog=cL1_l@4106ooooo`Oo:RXZ1_oZj^X7oaXJ6POo:RXZ1omPH607oc<c<`Oo=CDe
1_l=3@d>ooooo`003?ooool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_oo
ool7ohj>SPOoFEUI1omSHf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onH
V9P6o`/;2`Oo:BTY1onCTi<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omF
EUH6ob@T90Kooooo1ol];Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omd
M7@7olk>cPOooooo1_no_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb
<S87od92@POo3`l?1_lD51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM
7Ad>ooooo`003?ooool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7
ohj>SPOoFEUI1omSHf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6
o`/;2`Oo:BTY1onCTi<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6
ob@T90Kooooo1ol];Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7
olk>cPOooooo1_no_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87
od92@POo3`l?1_lD51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>
ooooo`003?ooool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7ohj>
SPOoFEUI1omSHf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6o`/;
2`Oo:BTY1onCTi<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6ob@T
90Kooooo1ol];Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7olk>
cPOooooo1_no_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87od92
@POo3`l?1_lD51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>oooo
o`003?ooool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7ohj>SPOo
FEUI1omSHf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6o`/;2`Oo
:BTY1onCTi<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6ob@T90Ko
oooo1ol];Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7olk>cPOo
oooo1_no_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87od92@POo
3`l?1_lD51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>ooooo`00
3?ooool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7ohj>SPOoFEUI
1omSHf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6o`/;2`Oo:BTY
1onCTi<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6ob@T90Kooooo
1ol];Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7olk>cPOooooo
1_no_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87od92@POo3`l?
1_lD51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>ooooo`003?oo
ool7ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7ohj>SPOoFEUI1omS
Hf<7ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6o`/;2`Oo:BTY1onC
Ti<6o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6ob@T90Kooooo1ol]
;Bd7ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7olk>cPOooooo1_no
_kl>ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87od92@POo3`l?1_lD
51@6ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>ooooo`003?ooool7
ojFUY@Ooj>SX1ooPh>07ooooo`OoYZJV1_o[jn/7olC4a0KoZZZZ1_ooool7ohj>SPOoFEUI1omSHf<7
ogUiN@OoIfMW1_mkNg/7olC4a0cooooo1om8B4P7o`0000Oo<30`1onHV9P6o`/;2`Oo:BTY1onCTi<6
o`X:2PKooooo1olE5AD7og]kN`OoCdm?1ol`<306oi2@T0Oo9RHV1omFEUH6ob@T90Kooooo1ol];Bd7
ocDe=@Oo@4101_m9BDT7ogYjNPOoOWin1ola<C46ochn?PKooooo1omdM7@7olk>cPOooooo1_no_kl>
ode=C@Oo<30`1_li>CT6ooooo`OoA4A41omDE5@6o`H61POo2`/;1olb<S87od92@POo3`l?1_lD51@6
ooooo`OohN7Q1_l^;Rh7ohf=S@OoQ8B41olE5AD7okjn_POo6ATI1_lM7Ad>ooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-1.81198, \
-0.862434, 0.14679, 0.14679}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-10.6148, -0.862434, 0.14679, 0.14679}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-19.4177, -0.862434, 0.14679, 0.14679}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-28.2205, -0.862434, 0.14679, 0.14679}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-37.0188, -0.862434, 0.14679, 0.14679}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-45.8262, -0.862434, 0.14679, \
0.14679}, {{372.125, 426.625}, {240.25, 185.75}} -> {-54.6244, -0.862434, \
0.14679, 0.14679}, {{432.062, 486.625}, {240.25, 185.75}} -> {-63.4273, \
-0.862434, 0.14679, 0.14679}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-1.81198, -9.66986, 0.14679, 0.14679}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-10.6148, -9.66986, 0.14679, 0.14679}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-19.4177, -9.66986, 0.14679, 0.14679}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-28.2205, -9.66986, 0.14679, 0.14679}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-37.0188, -9.66986, 0.14679, \
0.14679}, {{312.188, 366.688}, {180.25, 125.75}} -> {-45.8262, -9.66986, \
0.14679, 0.14679}, {{372.125, 426.625}, {180.25, 125.75}} -> {-54.6244, \
-9.66986, 0.14679, 0.14679}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-63.4273, -9.66986, 0.14679, 0.14679}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-1.81198, -18.4681, 0.14679, 0.14679}, {{72.3125, 126.812}, \
{120.312, 65.8125}} -> {-10.6148, -18.4681, 0.14679, 0.14679}, {{132.25, \
186.812}, {120.312, 65.8125}} -> {-19.4177, -18.4681, 0.14679, 0.14679}, \
{{192.25, 246.75}, {120.312, 65.8125}} -> {-28.2205, -18.4681, 0.14679, \
0.14679}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-37.0188, -18.4681, \
0.14679, 0.14679}, {{312.188, 366.688}, {120.312, 65.8125}} -> {-45.8262, \
-18.4681, 0.14679, 0.14679}, {{372.125, 426.625}, {120.312, 65.8125}} -> \
{-54.6244, -18.4681, 0.14679, 0.14679}, {{432.062, 486.625}, {120.312, \
65.8125}} -> {-63.4273, -18.4681, 0.14679, 0.14679}, {{12.3125, 66.875}, \
{60.3125, 5.8125}} -> {-1.81198, -27.2755, 0.14679, 0.14679}, {{72.3125, \
126.812}, {60.3125, 5.8125}} -> {-10.6148, -27.2755, 0.14679, 0.14679}, \
{{132.25, 186.812}, {60.3125, 5.8125}} -> {-19.4177, -27.2755, 0.14679, \
0.14679}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-28.2205, -27.2755, \
0.14679, 0.14679}, {{252.188, 306.688}, {60.3125, 5.8125}} -> {-37.0188, \
-27.2755, 0.14679, 0.14679}, {{312.188, 366.688}, {60.3125, 5.8125}} -> \
{-45.8262, -27.2755, 0.14679, 0.14679}, {{372.125, 426.625}, {60.3125, \
5.8125}} -> {-54.6244, -27.2755, 0.14679, 0.14679}, {{432.062, 486.625}, \
{60.3125, 5.8125}} -> {-63.4273, -27.2755, 0.14679, 0.14679}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
281A485050DB5564
0C0F3D5649DC5945
11093C544AF2496A
03093A5C51F76259
01042E594DFF5A5E
000A33685DE96669
02072D5C55E9635A
0D16365D57BF5C58
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
47DE6242138EA22C
CBBA79050D52C255
59E44E173AC69B30
F1A4460C285DCC7A
7ED137006BE5953A
FF77131D4C78B79F
8BA326108EE97556
F154043C576296C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
500F6AAE7E4726FE
121C245C95561F45
370997A7612425FF
0020416F8444132E
222E9A96421523DC
00246178712D2C1C
1F64947E2C1B20A0
0A265E605F213C14
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E0E0B3430ACF025
0D19123734C5F82B
0516053D42E6FE1D
00200A4143EEF01E
00270E5356FFE615
04241B5255EFC40A
12371C686AFBAF13
1125235959C98F03
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D382C1E0C1D29CF
23262A0E121529DE
0E2B2617150E23EF
0B1C290F151121F6
00221D0D121221FF
0D1A180B1D141FF7
001A180E23171FEE
080F10071C101BCD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3731CADE3A925852
2229E7E32A89645A
2125F8E91B91535A
1027FFDB098A5159
0F2AFFD20D8E5261
063DEDB60081505C
0E38EB9E0B7B4962
014CD1830575495F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
773807004C797B51
9F55084463744C98
6D1C04056D876548
8E3700746B693AD4
4C0C021E8E8E4B43
6D171A85735027EE
29070E449A7F2E4E
650D2E98683121FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9FA5EA368638C953
A8B8F7248A42D156
BFB9FA37A245D85F
C4B6FF209A5AD86C
D5BFF62AAB4BD16E
C99EE40F9455CB74
C792D614933CB585
AF70B200783DB364
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4BAF369420252A8A
33BB2F9108212F7C
35D23C9615141E61
29D625A5071D0E6B
3DED459B1504106B
3FEC2BAD031D025C
4DFF509C20111058
49C9368A12260065
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9CE3719B32191435
A2E96E82390C1237
B6FF649C290B0737
BAED52772B000D32
D0F051901C050B3A
C7CC40761902183A
D9C64A7E0D08174C
B298386809011E40
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B2788B78C442130
28A2A6C25514009A
1A40B7DA75295B28
2FD5B7A32E100060
2C5BDCC6451B8E30
52EBC16D05151732
4983E6A02233AD32
77FFAD3A1C211A38
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
89892E355376448D
734C1A187787902D
8A651A564A6C48CF
6842061BA5827129
7F33276445644BFF
533E0034BD7A4D30
71123C684C5147F4
3644063ACB73341C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C3662C30172243F5
E05C312E071639EA
F06B201F071C3AF8
F86A341D001136FF
E1853210021F36FF
E1793E1A031C3BF2
CA7C421E1B284CD9
B564342D1A3342CB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
688AE640132CB93F
30D8E15A0061A932
8B9AC91B1138E331
53F7C6281184B51D
9BAC960E184EEE4A
7EFF9D073AA8BD30
ADBC6A10427AE564
8CE87D0D50C7A154
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
374B3C19DC47383E
40321A18D02D2D37
334C2113FB2E372D
3D2B0626F113312B
3A3A1923FF0F3332
3B1D0231E5002D20
3E2D1641DE053C36
36120B3BB200311E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C4348ADE8313900
123F45C1EE094110
0A4B5BE3FB17450C
0B4E5BEAEF004B14
146272FFEB124513
1B5E75F2D2084816
1C788EECBD19401F
236A7FCCA012321E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3129160D3253D065
301E190C254FDF79
241C0C032B4CF16A
271A0E042652FF70
21110800264BF565
281710092D4CFA60
2E1213103749D868
331812133441C973
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DE4B54233D1D3412
BE3B3B2538322A04
F9413F20381D2907
DA2D311D313A2800
FF2D3324332D2D16
D91C29312E4F3305
DC252A33303A392A
AB172A343052351A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26221FC5450E1425
2F181EE33516100F
252020E2360B0811
2F1419FF2C080D07
262628E52B070809
331B22FF2B021300
2F2635CB280D1110
311C2BD721052008
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C2D0D493810B239
262A08482212AB28
3321065A1A07E03C
2422114F0F16E732
2A1911510B1CFF42
211520450230F641
1F1523420345F144
0D062129003DCE31
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F0C1B1F170D12D3
180C112121190DFC
19041B1C181817FF
12090E22261D14C9
18071220291A1491
0805051C1B110A6D
130C0E2327110853
06000519220C0547
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1533C4363F432436
0C36DA163B3E1B25
1639F31A4849162D
1442FA07433C1325
1C4FFF044C490E1D
175AED00463C1B17
2B69E0004A3D1A14
2166B4043D341F14
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3708106AA488337E
67015CBEA4451FFF
1B092193A5782179
410089B8962915FD
10054BB9995A1971
2422B1B0721B0BEC
180F77C280263965
185DC49F452013D2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D52E3A1E2A46705B
F015331B333E795B
F519421B2E46797B
FF00362241447A76
F007411A37477A9C
E402421E504E7E93
C50C3C1F4C5573A3
AC003419504C6893
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7D1B40498A83BFB6
79281A307696BAE2
6E0111054564A7AE
7C2914216D7FB2E0
6C001E0B5060B59A
6F1B26136D75B4E3
81122B1B696DCBA3
713F4533757ABFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28DC4E143029123A
2BE5390E21231434
2DF73714261C1334
2DFF2C001E1E192C
37F92B12201D1938
31F92A0024171D2B
41DB2D181F271D3B
36CF2107221B222C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2937D24514191749
1A30E63C12130C30
2B26EB3D10140734
1F21FF380B110038
2E23EC3B0A130531
221BF13511270F39
2C24D33A0D161542
1B1DC4370C211F45
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E342D1529A4594A
322721051BDE4664
3E291D153BBF444C
251B2C0029FF2F5A
34271A2C53B22B4E
1E19390A46E52450
2F22223764922054
130E301252C3213D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B160C08110B1065
0013090311071155
0A190F0B10020C69
050A02070F020C7E
11071313100008BA
130604090D0A0CDC
1A060E09090D0EFF
1411090A00090CC1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2F9992CC26082A9C
2229C7A55A067C27
44DB929F081A2A5C
3544E68D221ABE32
62F48D61072C342E
496BD86A0047DE31
78F27F22133E511C
565CC05E006BFF38
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
160E3237D436114C
1512173EEE360330
050B2D3CFF340928
021B1E3CEF290020
0A16283FF33A0C31
09212B43F8300D28
13142D4CD63E0D2B
11232841C2340D33
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7D64343BDDDD3046
7D6B353EF0DB1C39
7F6D2338FBE71741
84741845FCD61235
79721149FFC81833
77730067ECAA0E26
6B5E115DE493202F
635E0570CB77111C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Ko
oooo1om7AdL7omkNgPOoHV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`Oo
JVYZ1on^[Zh6oginOPOoAdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Oo
l?3`1_lU9BD6ooooo`Oo;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo
=cLg1ola<C47ol[:bPKog]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo
00001om<C4`7ogUiN@OoNg]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0Oo
bLW91_mCDe<>ooooo`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo
1om7AdL7omkNgPOoHV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ
1on^[Zh6oginOPOoAdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`
1_lU9BD6ooooo`Oo;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg
1ola<C47ol[:bPKog]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo0000
1om<C4`7ogUiN@OoNg]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW9
1_mCDe<>ooooo`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo1om7
AdL7omkNgPOoHV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ1on^
[Zh6oginOPOoAdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`1_lU
9BD6ooooo`Oo;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg1ola
<C47ol[:bPKog]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo00001om<
C4`7ogUiN@OoNg]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW91_mC
De<>ooooo`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo1om7AdL7
omkNgPOoHV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ1on^[Zh6
oginOPOoAdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`1_lU9BD6
ooooo`Oo;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg1ola<C47
ol[:bPKog]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo00001om<C4`7
ogUiN@OoNg]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW91_mCDe<>
ooooo`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo1om7AdL7omkN
gPOoHV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ1on^[Zh6ogin
OPOoAdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`1_lU9BD6oooo
o`Oo;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg1ola<C47ol[:
bPKog]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo00001om<C4`7ogUi
N@OoNg]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW91_mCDe<>oooo
o`003?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo1om7AdL7omkNgPOo
HV9R1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ1on^[Zh6oginOPOo
AdM71olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`1_lU9BD6ooooo`Oo
;Bd]1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg1ola<C47ol[:bPKo
g]kN1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo00001om<C4`7ogUiN@Oo
Ng]k1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW91_mCDe<>ooooo`00
3?ooool7obPX:0Oo6QXJ1om8B4P>oe1@D0Kofm_K1omEEED6ofATI0Kooooo1om7AdL7omkNgPOoHV9R
1om2@T87oa<C4`KoSXj>1onRXZ86ob`/;0Kooooo1om@D507o`l?3`OoJVYZ1on^[Zh6oginOPOoAdM7
1olV9RH6ooknoPKooooo3_l>3Ph7o`/;2`Oo=3@d1_l`<307ojb/[0Ool?3`1_lU9BD6ooooo`Oo;Bd]
1olh>3P7ob`/;0Ko7QhN1ol<30`7oadM7@Oo:BTY1_o?cll6ooooo`Oo=cLg1ola<C47ol[:bPKog]kN
1olj>SX7oi:BTPOoF5QH1_mBDU86ooooo`OoMgMg1olh>3P6o`L71`Oo00001om<C4`7ogUiN@OoNg]k
1_mADE46ooooo`OoWinO1_nUYJD7on[ZjPOo=SHf1on6QXH7ocPh>0OobLW91_mCDe<>ooooo`003?oo
ool7o``<30Oo3`l?1olm?Cd7oeIFEPOoBDU91_oLg=`7oeUIF@KoADE51_ooool7ol_;b`Oo^[Zj1omi
NGT7o`D51@Oo3@d=1_mBDU87ol;2`PKoEEEE1_ooool7oa8B4POo71`L1olT92@7oeaLG0KoUIFE1omF
EUH7oalO7`KoADE51_ooool7o`d=3@Oo6ATI1olB4Q87ocLg=`Ko=3@d1oo5aLD7ooShn0Ko:b/[1_oo
ool7ob<S8`Oo9RHV1olZ:RX6o`h>3POo4Q8B1olE5AD7obTY:@Kog]kN1_ooool7ob8R8POo:BTY1ooW
inL6on?Sh`Oo:RXZ1on9RHT7ofATI0KoFUYJ1_ooool7oinOW`OoEEEE1_l820P7odA4A0OoHf=S1omd
M7@7oda<C0KoV9RH1_ooool7ojRXZ0Ko^;Rh1oogmoL7ob@T90OoRXZ:1om2@T87om7Ad@KoEUIF3_oo
ool000cooooo1ol<30`7o`l?3`Oo?Cdm1omFEUH7odU9B@Kog=cL1omIFET6odE5A@Kooooo1oo;bl/7
okZj^POoNGUi1ol51@D7o`d=3@KoDU9B1oo2`/86oeEEE@Kooooo1olB4Q87oa`L70Oo92@T1omLG5`6
oiFEU@OoEUIF1olO7al6odE5A@Kooooo1ol=3@d7oaTI6@Oo4Q8B1olg=cL6oc@d=0OoaLG51oohn?P6
ob/[:`Kooooo1olS8b<7obHV9POo:RXZ1_l>3Ph7oa8B4POo5ADE1olY:BT6omkNgPKooooo1olR8R87
obTY:@OoinOW1_oShn<7obXZ:POoRHV91omTI6@6oeYJFPKooooo1onOWil7oeEEE@Ko20P81om4A4@7
of=SH`OoM7Ad1om<C4`6oiRHV0Kooooo1onXZ:P6okRh^0OomoOg1olT92@7ohZ:RPOo@T921ooAdM46
oeIFEPkooooo000<ooooo`Oo30`<1ol?3`l7ocdm?@OoEUIF1om9BDT6omcLg0OoFEUI1_m5ADD6oooo
o`Oobl_;1onj^[X7ogUiN@Oo1@D51ol=3@d6oe9BDPOo`/;21_mEEED6ooooo`Oo4Q8B1olL71`7ob@T
90OoG5aL1_nEUID7oeIFEPOo7alO1_m5ADD6ooooo`Oo3@d=1olI6AT7oa8B4POo=cLg1_ld=3@7olG5
a@Oon?Sh1_l[:b/6ooooo`Oo8b<S1olV9RH7obXZ:PKo3Ph>1olB4Q87oaDE5@Oo:BTY1_oNg]h6oooo
o`Oo8R8R1olY:BT7onOWi`Kohn?S1olZ:RX7ohV9R@OoI6AT1_mJFUX6ooooo`OoWinO1omEEED6o`P8
20OoA4A41omSHf<7ogAdM0OoC4a<1_nHV9P6ooooo`OoZ:RX1_nh^;P7ooOgm`Oo92@T1on:RXX7od92
@POodM7A1_mFEUH>ooooo`003?ooool7o``<30Oo3`l?1olm?Cd7oeIFEPOoBDU91_oLg=`7oeUIF@Ko
ADE51_ooool7ol_;b`Oo^[Zj1omiNGT7o`D51@Oo3@d=1_mBDU87ol;2`PKoEEEE1_ooool7oa8B4POo
71`L1olT92@7oeaLG0KoUIFE1omFEUH7oalO7`KoADE51_ooool7o`d=3@Oo6ATI1olB4Q87ocLg=`Ko
=3@d1oo5aLD7ooShn0Ko:b/[1_ooool7ob<S8`Oo9RHV1olZ:RX6o`h>3POo4Q8B1olE5AD7obTY:@Ko
g]kN1_ooool7ob8R8POo:BTY1ooWinL6on?Sh`Oo:RXZ1on9RHT7ofATI0KoFUYJ1_ooool7oinOW`Oo
EEEE1_l820P7odA4A0OoHf=S1omdM7@7oda<C0KoV9RH1_ooool7ojRXZ0Ko^;Rh1oogmoL7ob@T90Oo
RXZ:1om2@T87om7Ad@KoEUIF3_ooool000cooooo1ol<30`7o`l?3`Oo?Cdm1omFEUH7odU9B@Kog=cL
1omIFET6odE5A@Kooooo1oo;bl/7okZj^POoNGUi1ol51@D7o`d=3@KoDU9B1oo2`/86oeEEE@Kooooo
1olB4Q87oa`L70Oo92@T1omLG5`6oiFEU@OoEUIF1olO7al6odE5A@Kooooo1ol=3@d7oaTI6@Oo4Q8B
1olg=cL6oc@d=0OoaLG51oohn?P6ob/[:`Kooooo1olS8b<7obHV9POo:RXZ1_l>3Ph7oa8B4POo5ADE
1olY:BT6omkNgPKooooo1olR8R87obTY:@OoinOW1_oShn<7obXZ:POoRHV91omTI6@6oeYJFPKooooo
1onOWil7oeEEE@Ko20P81om4A4@7of=SH`OoM7Ad1om<C4`6oiRHV0Kooooo1onXZ:P6okRh^0OomoOg
1olT92@7ohZ:RPOo@T921ooAdM46oeIFEPkooooo000<ooooo`Oo30`<1ol?3`l7ocdm?@OoEUIF1om9
BDT6omcLg0OoFEUI1_m5ADD6ooooo`Oobl_;1onj^[X7ogUiN@Oo1@D51ol=3@d6oe9BDPOo`/;21_mE
EED6ooooo`Oo4Q8B1olL71`7ob@T90OoG5aL1_nEUID7oeIFEPOo7alO1_m5ADD6ooooo`Oo3@d=1olI
6AT7oa8B4POo=cLg1_ld=3@7olG5a@Oon?Sh1_l[:b/6ooooo`Oo8b<S1olV9RH7obXZ:PKo3Ph>1olB
4Q87oaDE5@Oo:BTY1_oNg]h6ooooo`Oo8R8R1olY:BT7onOWi`Kohn?S1olZ:RX7ohV9R@OoI6AT1_mJ
FUX6ooooo`OoWinO1omEEED6o`P820OoA4A41omSHf<7ogAdM0OoC4a<1_nHV9P6ooooo`OoZ:RX1_nh
^;P7ooOgm`Oo92@T1on:RXX7od92@POodM7A1_mFEUH>ooooo`003?ooool7o``<30Oo3`l?1olm?Cd7
oeIFEPOoBDU91_oLg=`7oeUIF@KoADE51_ooool7ol_;b`Oo^[Zj1omiNGT7o`D51@Oo3@d=1_mBDU87
ol;2`PKoEEEE1_ooool7oa8B4POo71`L1olT92@7oeaLG0KoUIFE1omFEUH7oalO7`KoADE51_ooool7
o`d=3@Oo6ATI1olB4Q87ocLg=`Ko=3@d1oo5aLD7ooShn0Ko:b/[1_ooool7ob<S8`Oo9RHV1olZ:RX6
o`h>3POo4Q8B1olE5AD7obTY:@Kog]kN1_ooool7ob8R8POo:BTY1ooWinL6on?Sh`Oo:RXZ1on9RHT7
ofATI0KoFUYJ1_ooool7oinOW`OoEEEE1_l820P7odA4A0OoHf=S1omdM7@7oda<C0KoV9RH1_ooool7
ojRXZ0Ko^;Rh1oogmoL7ob@T90OoRXZ:1om2@T87om7Ad@KoEUIF3_ooool000cooooo1olA4A47o`T9
2@Oo?3`l1omDE5@7odY:BPKol_;b1om9BDT6ofYZJPKooooo1omIFET7onCTi0OoCTi>1olG5aL7ocXj
>PKoa/K61onKVi/6oc0`<0Kooooo1olg=cL7o`T92@OoUiNG1onWYjL6of5QH@Oo92@T1olU9BD<oooo
o`Oo1@D51olF5QH7o`D51@Oo?Cdm1_m2@T87onKViPOoo_kn1_lM7Ad6ooooo`Oo3Ph>1ol[:b/7obHV
9PKo5aLG1olE5AD7o`h>3POo8b<S1_o_knl6ooooo`Oo8B4Q1olU9BD7ooShn0KojNWY1olK6a/7oi6A
T@OoDe=C1_mJFUX6ooooo`OoKFe]1olL71`6o`@410Oo1@D51om]KFd7ohN7Q`OoIFEU1_m8B4P6oooo
o`Oo_kno1_ni^KT7oo[jnPOo=cLg1onRXZ87odE5A@Oof=SH1_mOGel>ooooo`003?ooool7oa4A4@Oo
2@T91oll?3`7oeADE0OoBTY:1_obl_87odU9B@KoJVYZ1_ooool7oeUIF@Ooi>CT1om>CTh7oaLG5`Oo
>SXj1_o6a/H7oi^KV`Ko<30`1_ooool7ocLg=`Oo2@T91onGUiL7ojNWY`KoHF5Q1olT92@7obDU9@co
oooo1ol51@D7oaHF5POo1@D51olm?Cd6od92@POoi^KV1oono_h6oadM7@Kooooo1ol>3Ph7ob/[:`Oo
9RHV1_lG5aL7oaDE5@Oo3Ph>1olS8b<6ono_k`Kooooo1olQ8B47obDU9@Oon?Sh1_oYjNT7oa/K6`Oo
TI6A1omCDe<6oeYJFPKooooo1om]KFd7oa`L70Ko10@41ol51@D7ofe]K@OoQhN71omUIFD6odQ8B0Ko
oooo1ono_kl6okVi^@Oon_[j1olg=cL7oj:RXPOoADE51ooHf=P6oemOG`kooooo000<ooooo`Oo4A4A
1ol92@T7oc`l?0OoE5AD1om:BTX6oo;blPOoBDU91_mZJVX6ooooo`OoFEUI1ooTi>@7odi>CPOo5aLG
1olj>SX6olK6aPOoVi^K1_l`<306ooooo`Oo=cLg1ol92@T7oiNGU`OoYjNW1_mQHF47ob@T90Oo9BDU
3?ooool7o`D51@Oo5QHF1ol51@D7ocdm?@Ko@T921ooVi^H7ooknoPKo7AdM1_ooool7o`h>3POo:b/[
1olV9RH6oaLG5`Oo5ADE1ol>3Ph7ob<S8`Kokno_1_ooool7ob4Q8@Oo9BDU1oohn?P6onWYj@Oo6a/K
1onATI47oe=CD`KoFUYJ1_ooool7ofe]K@Oo71`L1_l410@7o`D51@OoKFe]1on7QhL7ofEUI@KoB4Q8
1_ooool7okno_`Ko^KVi1oojn_X7ocLg=`OoXZ:R1om5ADD7omSHf0KoGemO3_ooool000cooooo1olA
4A47o`T92@Oo?3`l1omDE5@7odY:BPKol_;b1om9BDT6ofYZJPKooooo1omIFET7onCTi0OoCTi>1olG
5aL7ocXj>PKoa/K61onKVi/6oc0`<0Kooooo1olg=cL7o`T92@OoUiNG1onWYjL6of5QH@Oo92@T1olU
9BD<ooooo`Oo1@D51olF5QH7o`D51@Oo?Cdm1_m2@T87onKViPOoo_kn1_lM7Ad6ooooo`Oo3Ph>1ol[
:b/7obHV9PKo5aLG1olE5AD7o`h>3POo8b<S1_o_knl6ooooo`Oo8B4Q1olU9BD7ooShn0KojNWY1olK
6a/7oi6AT@OoDe=C1_mJFUX6ooooo`OoKFe]1olL71`6o`@410Oo1@D51om]KFd7ohN7Q`OoIFEU1_m8
B4P6ooooo`Oo_kno1_ni^KT7oo[jnPOo=cLg1onRXZ87odE5A@Oof=SH1_mOGel>ooooo`003?ooool7
oa4A4@Oo2@T91oll?3`7oeADE0OoBTY:1_obl_87odU9B@KoJVYZ1_ooool7oeUIF@Ooi>CT1om>CTh7
oaLG5`Oo>SXj1_o6a/H7oi^KV`Ko<30`1_ooool7ocLg=`Oo2@T91onGUiL7ojNWY`KoHF5Q1olT92@7
obDU9@cooooo1ol51@D7oaHF5POo1@D51olm?Cd6od92@POoi^KV1oono_h6oadM7@Kooooo1ol>3Ph7
ob/[:`Oo9RHV1_lG5aL7oaDE5@Oo3Ph>1olS8b<6ono_k`Kooooo1olQ8B47obDU9@Oon?Sh1_oYjNT7
oa/K6`OoTI6A1omCDe<6oeYJFPKooooo1om]KFd7oa`L70Ko10@41ol51@D7ofe]K@OoQhN71omUIFD6
odQ8B0Kooooo1ono_kl6okVi^@Oon_[j1olg=cL7oj:RXPOoADE51ooHf=P6oemOG`kooooo000<oooo
o`Oo4A4A1ol92@T7oc`l?0OoE5AD1om:BTX6oo;blPOoBDU91_mZJVX6ooooo`OoFEUI1ooTi>@7odi>
CPOo5aLG1olj>SX6olK6aPOoVi^K1_l`<306ooooo`Oo=cLg1ol92@T7oiNGU`OoYjNW1_mQHF47ob@T
90Oo9BDU3?ooool7o`D51@Oo5QHF1ol51@D7ocdm?@Ko@T921ooVi^H7ooknoPKo7AdM1_ooool7o`h>
3POo:b/[1olV9RH6oaLG5`Oo5ADE1ol>3Ph7ob<S8`Kokno_1_ooool7ob4Q8@Oo9BDU1oohn?P6onWY
j@Oo6a/K1onATI47oe=CD`KoFUYJ1_ooool7ofe]K@Oo71`L1_l410@7o`D51@OoKFe]1on7QhL7ofEU
I@KoB4Q81_ooool7okno_`Ko^KVi1oojn_X7ocLg=`OoXZ:R1om5ADD7omSHf0KoGemO3_ooool000co
oooo1ol30`<7o`T92@Oo>SXj1omLG5`7oe5AD@KomoOg1omRHV86oeUIF@Kooooo1ooalO47ojBTY0Oo
ATI61ol<30`7obPX:0KoGEeM1oo<c<`6ogYjNPKooooo1ol00007ob0P80Oo@D511om_Kfl6ohB4Q0Oo
A4A41olC4a<6obh^;PKooooo1ol00007ob0P80Oo2PX:1om1@D46od=3@`Ook^k^1oo`l?06oahN7PKo
oooo1ol;2`/7oa`L70Oo:BTY1_l?3`l7oaDE5@Oo4A4A1olQ8B46ooKfmPKooooo1ol@4107obLW9`Oo
oooo1_oKfm/7o`T92@OoRXZ:1omADE46oeUIF@Kooooo1on>SXh7ocLg=`Ko00001omdM7@7of][J`Oo
JFUY1olj>SX6omCDe0Kooooo1oo4a<@6okJf]POooooo1olP8207oiZJVPOoFUYJ1ooHf=P6ofa/K0ko
oooo000<ooooo`Oo0`<31ol92@T7ocXj>POoG5aL1omADE46ooOgm`OoHV9R1_mIFET6ooooo`OolO7a
1onTY:@7odI6APOo30`<1olX:2P6oeeMG@Ooc<c<1_mjNWX6ooooo`Oo00001olP8207od51@@OoKfm_
1_n4Q8@7odA4A0Oo4a<C1_l^;Rh6ooooo`Oo00001olP8207o`X:2POo@D511_m3@d<7onk^kPOol?3`
1_lN7Qh6ooooo`Oo2`/;1olL71`7obTY:@Ko3`l?1olE5AD7oa4A4@Oo8B4Q1_ofm_H6ooooo`Oo410@
1olW9bL7ooooo`Kofm_K1ol92@T7ohZ:RPOoDE5A1_mIFET6ooooo`OoSXj>1olg=cL6o`0000OoM7Ad
1om[Jf/7ofUYJ@Oo>SXj1_oDe=@6ooooo`Ooa<C41_nf][H7ooooo`Oo820P1onJVYX7oeYJFPOof=SH
1_m/K6`>ooooo`003?ooool7o`<30`Oo2@T91olj>SX7oeaLG0OoDE5A1_ogmoL7of9RHPKoFEUI1_oo
ool7oo7al@OoY:BT1om6ATH7o``<30Oo:2PX1_mMGEd7olc<c0KoNWYj1_ooool7o`0000Oo820P1om1
@D47ofm_K`KoQ8B41om4A4@7oa<C4`Ko;Rh^1_ooool7o`0000Oo820P1ol:2PX7od51@@Ko@d=31oo^
k^h7oo3`l0Ko7QhN1_ooool7o`/;2`Oo71`L1olY:BT6o`l?3`Oo5ADE1olA4A47ob4Q8@Kom_Kf1_oo
ool7oa0@40Oo9bLW1oooool6om_Kf`Oo2@T91on:RXX7oe5AD@KoFEUI1_ooool7ohj>SPOo=cLg1_l0
0007ogAdM0OoJf][1omYJFT7ocXj>PKoe=CD1_ooool7olC4a0Ko][Jf1oooool7ob0P80OoVYZJ1omJ
FUX7omSHf0KoK6a/3_ooool000cooooo1ol30`<7o`T92@Oo>SXj1omLG5`7oe5AD@KomoOg1omRHV86
oeUIF@Kooooo1ooalO47ojBTY0OoATI61ol<30`7obPX:0KoGEeM1oo<c<`6ogYjNPKooooo1ol00007
ob0P80Oo@D511om_Kfl6ohB4Q0OoA4A41olC4a<6obh^;PKooooo1ol00007ob0P80Oo2PX:1om1@D46
od=3@`Ook^k^1oo`l?06oahN7PKooooo1ol;2`/7oa`L70Oo:BTY1_l?3`l7oaDE5@Oo4A4A1olQ8B46
ooKfmPKooooo1ol@4107obLW9`Oooooo1_oKfm/7o`T92@OoRXZ:1omADE46oeUIF@Kooooo1on>SXh7
ocLg=`Ko00001omdM7@7of][J`OoJFUY1olj>SX6omCDe0Kooooo1oo4a<@6okJf]POooooo1olP8207
oiZJVPOoFUYJ1ooHf=P6ofa/K0kooooo000<ooooo`Oo0`<31ol92@T7ocXj>POoG5aL1omADE46ooOg
m`OoHV9R1_mIFET6ooooo`OolO7a1onTY:@7odI6APOo30`<1olX:2P6oeeMG@Ooc<c<1_mjNWX6oooo
o`Oo00001olP8207od51@@OoKfm_1_n4Q8@7odA4A0Oo4a<C1_l^;Rh6ooooo`Oo00001olP8207o`X:
2POo@D511_m3@d<7onk^kPOol?3`1_lN7Qh6ooooo`Oo2`/;1olL71`7obTY:@Ko3`l?1olE5AD7oa4A
4@Oo8B4Q1_ofm_H6ooooo`Oo410@1olW9bL7ooooo`Kofm_K1ol92@T7ohZ:RPOoDE5A1_mIFET6oooo
o`OoSXj>1olg=cL6o`0000OoM7Ad1om[Jf/7ofUYJ@Oo>SXj1_oDe=@6ooooo`Ooa<C41_nf][H7oooo
o`Oo820P1onJVYX7oeYJFPOof=SH1_m/K6`>ooooo`003?ooool7o`<30`Oo2@T91olj>SX7oeaLG0Oo
DE5A1_ogmoL7of9RHPKoFEUI1_ooool7oo7al@OoY:BT1om6ATH7o``<30Oo:2PX1_mMGEd7olc<c0Ko
NWYj1_ooool7o`0000Oo820P1om1@D47ofm_K`KoQ8B41om4A4@7oa<C4`Ko;Rh^1_ooool7o`0000Oo
820P1ol:2PX7od51@@Ko@d=31oo^k^h7oo3`l0Ko7QhN1_ooool7o`/;2`Oo71`L1olY:BT6o`l?3`Oo
5ADE1olA4A47ob4Q8@Kom_Kf1_ooool7oa0@40Oo9bLW1oooool6om_Kf`Oo2@T91on:RXX7oe5AD@Ko
FEUI1_ooool7ohj>SPOo=cLg1_l00007ogAdM0OoJf][1omYJFT7ocXj>PKoe=CD1_ooool7olC4a0Ko
][Jf1oooool7ob0P80OoVYZJ1omJFUX7omSHf0KoK6a/3_ooool000cooooo1ol30`<7o`T92@Oo>SXj
1omLG5`7oe5AD@KomoOg1omRHV86oeUIF@Kooooo1ooalO47ojBTY0OoATI61ol<30`7obPX:0KoGEeM
1oo<c<`6ogYjNPKooooo1ol00007ob0P80Oo@D511om_Kfl6ohB4Q0OoA4A41olC4a<6obh^;PKooooo
1ol00007ob0P80Oo2PX:1om1@D46od=3@`Ook^k^1oo`l?06oahN7PKooooo1ol;2`/7oa`L70Oo:BTY
1_l?3`l7oaDE5@Oo4A4A1olQ8B46ooKfmPKooooo1ol@4107obLW9`Oooooo1_oKfm/7o`T92@OoRXZ:
1omADE46oeUIF@Kooooo1on>SXh7ocLg=`Ko00001omdM7@7of][J`OoJFUY1olj>SX6omCDe0Kooooo
1oo4a<@6okJf]POooooo1olP8207oiZJVPOoFUYJ1ooHf=P6ofa/K0kooooo000<ooooo`Oo0@411ol4
10@7obh^;POoFEUI1om=CDd6ooooo`OoFUYJ1_mNGUh6ooooo`OoOWin1ooAdM47ocLg=`Oo00001om[
Jf/6onGUi@OoUIFE1_lj>SX6ooooo`Oo8R8R1ol^;Rh7oiZJVPOoUYJF1_m2@T87oaDE5@Oo8b<S1_oL
g=`6ooooo`Oo00001olW9bL7o`h>3POoDe=C1_mFEUH7ooooo`Ooi^KV1_lE5AD6ooooo`Oo00001olR
8R87oadM7@Ko3@d=3_lB4Q87ob4Q8@cooooo1ol?3`l7obXZ:POooooo1_oBd]87o`d=3@OoSXj>1omB
DU86of5QH@Kooooo1om<C4`7o``<30Ko0P821olN7Qh>ohj>SPOoBd];1_m3@d<6ooooo`OoeMGE1_no
_kl7ooKfmPOo:RXZ1on[Zj/7od];B`OodM7A1_m^KVh>ooooo`003?ooool7o`410@Oo10@41ol^;Rh7
oeUIF@OoCDe=1_ooool7oeYJFPKoGUiN1_ooool7oginOPOodM7A1olg=cL7o`0000OoJf][1_oUiND7
oiFEU@Ko>SXj1_ooool7ob8R8POo;Rh^1onJVYX7oiJFUPKo@T921olE5AD7ob<S8`Kog=cL1_ooool7
o`0000Oo9bLW1ol>3Ph7oe=CD`KoEUIF1oooool7onKViPKo5ADE1_ooool7o`0000Oo8R8R1olM7Ad6
o`d=3@ko4Q8B1olQ8B4<ooooo`Oo3`l?1olZ:RX7ooooo`Kod];B1ol=3@d7ohj>SPOoDU9B1_mQHF46
ooooo`OoC4a<1ol<30`6o`820POo7QhN3_n>SXh7od];B`Ko@d=31_ooool7omGEe@Ko_kno1oofm_H7
obXZ:POoZj^[1om;Bd/7om7Ad@KoKVi^3_ooool000cooooo1ol10@47o`@410Oo;Rh^1omIFET7ode=
C@Kooooo1omJFUX6oeiNGPKooooo1omnOWh7om7Ad@Oo=cLg1ol00007of][J`KoiNGU1onEUID6ocXj
>PKooooo1olR8R87obh^;POoVYZJ1onFUYH6od92@POo5ADE1olS8b<6omcLg0Kooooo1ol00007obLW
9`Oo3Ph>1omCDe<6oeIFEPOooooo1ooVi^H6oaDE5@Kooooo1ol00007ob8R8POo7AdM1_l=3@d>oa8B
4POo8B4Q3?ooool7o`l?3`Oo:RXZ1oooool6om;BdPOo3@d=1on>SXh7oe9BDPKoHF5Q1_ooool7oda<
C0Oo30`<1_l20P87oahN7PkoSXj>1om;Bd/6od=3@`Kooooo1ooEeMD6okno_`Oom_Kf1olZ:RX7oj^[
Z`OoBd];1ooAdM46ofi^KPkooooo000<ooooo`Oo0@411ol410@7obh^;POoFEUI1om=CDd6ooooo`Oo
FUYJ1_mNGUh6ooooo`OoOWin1ooAdM47ocLg=`Oo00001om[Jf/6onGUi@OoUIFE1_lj>SX6ooooo`Oo
8R8R1ol^;Rh7oiZJVPOoUYJF1_m2@T87oaDE5@Oo8b<S1_oLg=`6ooooo`Oo00001olW9bL7o`h>3POo
De=C1_mFEUH7ooooo`Ooi^KV1_lE5AD6ooooo`Oo00001olR8R87oadM7@Ko3@d=3_lB4Q87ob4Q8@co
oooo1ol?3`l7obXZ:POooooo1_oBd]87o`d=3@OoSXj>1omBDU86of5QH@Kooooo1om<C4`7o``<30Ko
0P821olN7Qh>ohj>SPOoBd];1_m3@d<6ooooo`OoeMGE1_no_kl7ooKfmPOo:RXZ1on[Zj/7od];B`Oo
dM7A1_m^KVh>ooooo`003?ooool7o`410@Oo10@41ol^;Rh7oeUIF@OoCDe=1_ooool7oeYJFPKoGUiN
1_ooool7oginOPOodM7A1olg=cL7o`0000OoJf][1_oUiND7oiFEU@Ko>SXj1_ooool7ob8R8POo;Rh^
1onJVYX7oiJFUPKo@T921olE5AD7ob<S8`Kog=cL1_ooool7o`0000Oo9bLW1ol>3Ph7oe=CD`KoEUIF
1oooool7onKViPKo5ADE1_ooool7o`0000Oo8R8R1olM7Ad6o`d=3@ko4Q8B1olQ8B4<ooooo`Oo3`l?
1olZ:RX7ooooo`Kod];B1ol=3@d7ohj>SPOoDU9B1_mQHF46ooooo`OoC4a<1ol<30`6o`820POo7QhN
3_n>SXh7od];B`Ko@d=31_ooool7omGEe@Ko_kno1oofm_H7obXZ:POoZj^[1om;Bd/7om7Ad@KoKVi^
3_ooool000cooooo1ol10@47o`@410Oo;Rh^1omIFET7ode=C@Kooooo1omJFUX6oeiNGPKooooo1omn
OWh7om7Ad@Oo=cLg1ol00007of][J`KoiNGU1onEUID6ocXj>PKooooo1olR8R87obh^;POoVYZJ1onF
UYH6od92@POo5ADE1olS8b<6omcLg0Kooooo1ol00007obLW9`Oo3Ph>1omCDe<6oeIFEPOooooo1ooV
i^H6oaDE5@Kooooo1ol00007ob8R8POo7AdM1_l=3@d>oa8B4POo8B4Q3?ooool7o`l?3`Oo:RXZ1ooo
ool6om;BdPOo3@d=1on>SXh7oe9BDPKoHF5Q1_ooool7oda<C0Oo30`<1_l20P87oahN7PkoSXj>1om;
Bd/6od=3@`Kooooo1ooEeMD6okno_`Oom_Kf1olZ:RX7oj^[Z`OoBd];1ooAdM46ofi^KPkooooo000<
ooooo`Oo0@411ol410@7obh^;POoFEUI1om=CDd6ooooo`OoFUYJ1_mNGUh6ooooo`OoOWin1ooAdM47
ocLg=`Oo00001om[Jf/6onGUi@OoUIFE1_lj>SX6ooooo`Oo8R8R1ol^;Rh7oiZJVPOoUYJF1_m2@T87
oaDE5@Oo8b<S1_oLg=`6ooooo`Oo00001olW9bL7o`h>3POoDe=C1_mFEUH7ooooo`Ooi^KV1_lE5AD6
ooooo`Oo00001olR8R87oadM7@Ko3@d=3_lB4Q87ob4Q8@cooooo1ol?3`l7obXZ:POooooo1_oBd]87
o`d=3@OoSXj>1omBDU86of5QH@Kooooo1om<C4`7o``<30Ko0P821olN7Qh>ohj>SPOoBd];1_m3@d<6
ooooo`OoeMGE1_no_kl7ooKfmPOo:RXZ1on[Zj/7od];B`OodM7A1_m^KVh>ooooo`003?ooool7o`00
00Oo2PX:1olc<c<7ofQXJ0OoGEeM1_oYjNT7ofIVIPKoJFUY3Oooool7ogMgM`Oo4a<C1olM7Ad7oda<
C0KoN7Qh1ong]kL6oinOW`Kooooo1ol00007ob@T90OoHF5Q1omhN7P6og5aL@Oo;Bd]1ol/;2`6oa`L
70Kooooo1ol410@7ob@T90Oo6a/K1omBDU86oeEEE@Ookno_1oo4a<@6o`X:2PKooooo1ol=3@d7oaXJ
6POo61PH1_l;2`/7oadM7@Oo51@D1olO7al6ooOgm`Kooooo1ol61PH7ocdm?@OokNg]1_nf][H7o`00
00OoPH611om@D506oeaLG0Kooooo1om]KFd7oaLG5`Ko6QXJ1on5QHD7og=cL`OoD51@1olW9bL6onk^
kPKooooo1oo9bLT6oijNWPOoi>CT1ol?3`l7oiBDU0OoEEEE1oo;bl/6ogAdM0kooooo000<ooooo`Oo
00001ol:2PX7oc<c<`OoJ6QX1omMGEd6onWYj@OoIVIV1_mYJFT=ooooo`OoMgMg1olC4a<7oadM7@Oo
C4a<1_mhN7P7okNg]`KoWinO1_ooool7o`0000Oo92@T1omQHF47ogQhN0KoLG5a1ol];Bd7ob`/;0Ko
71`L1_ooool7o`@410Oo92@T1olK6a/7oe9BDPKoEEEE1oo_knl7olC4a0Ko2PX:1_ooool7o`d=3@Oo
6QXJ1olH61P6o`/;2`Oo7AdM1olD51@7oalO7`KomoOg1_ooool7o`H61POo?Cdm1oo]kNd6okJf]POo
00001on1PH47oe1@D0KoG5aL1_ooool7ofe]K@Oo5aLG1_lJ6QX7ohF5Q@OoLg=c1om@D507obLW9`Ko
k^k^1_ooool7olW9b@KoWYjN1ooTi>@7o`l?3`OoU9BD1omEEED7ol_;b`KoM7Ad3_ooool000cooooo
1ol00007o`X:2POo<c<c1omXJ6P7oeeMG@KojNWY1omVIVH6ofUYJ@gooooo1omgMgL7oa<C4`Oo7AdM
1om<C4`6ogQhN0Oo]kNg1_nOWil6ooooo`Oo00001olT92@7of5QH@OoN7Qh1_maLG47obd];@Oo;2`/
1_lL71`6ooooo`Oo10@41olT92@7oa/K6`OoDU9B1_mEEED7ono_k`Ooa<C41_l:2PX6ooooo`Oo3@d=
1olJ6QX7oaPH60Ko2`/;1olM7Ad7oa@D50Oo7alO1_ogmoL6ooooo`Oo1PH61olm?Cd7ong]k@Ko][Jf
1ol00007oh61P@OoD51@1_mLG5`6ooooo`OoKFe]1olG5aL6oaXJ6POoQHF51omcLg<7oe1@D0Oo9bLW
1_o^k^h6ooooo`OobLW91_nNWYh7onCTi0Oo3`l?1onDU9@7oeEEE@Oobl_;1_mdM7@>ooooo`003?oo
ool7o`0000Oo2PX:1olc<c<7ofQXJ0OoGEeM1_oYjNT7ofIVIPKoJFUY3Oooool7ogMgM`Oo4a<C1olM
7Ad7oda<C0KoN7Qh1ong]kL6oinOW`Kooooo1ol00007ob@T90OoHF5Q1omhN7P6og5aL@Oo;Bd]1ol/
;2`6oa`L70Kooooo1ol410@7ob@T90Oo6a/K1omBDU86oeEEE@Ookno_1oo4a<@6o`X:2PKooooo1ol=
3@d7oaXJ6POo61PH1_l;2`/7oadM7@Oo51@D1olO7al6ooOgm`Kooooo1ol61PH7ocdm?@OokNg]1_nf
][H7o`0000OoPH611om@D506oeaLG0Kooooo1om]KFd7oaLG5`Ko6QXJ1on5QHD7og=cL`OoD51@1olW
9bL6onk^kPKooooo1oo9bLT6oijNWPOoi>CT1ol?3`l7oiBDU0OoEEEE1oo;bl/6ogAdM0kooooo000<
ooooo`Oo00001ol:2PX7oc<c<`OoJ6QX1omMGEd6onWYj@OoIVIV1_mYJFT=ooooo`OoMgMg1olC4a<7
oadM7@OoC4a<1_mhN7P7okNg]`KoWinO1_ooool7o`0000Oo92@T1omQHF47ogQhN0KoLG5a1ol];Bd7
ob`/;0Ko71`L1_ooool7o`@410Oo92@T1olK6a/7oe9BDPKoEEEE1oo_knl7olC4a0Ko2PX:1_ooool7
o`d=3@Oo6QXJ1olH61P6o`/;2`Oo7AdM1olD51@7oalO7`KomoOg1_ooool7o`H61POo?Cdm1oo]kNd6
okJf]POo00001on1PH47oe1@D0KoG5aL1_ooool7ofe]K@Oo5aLG1_lJ6QX7ohF5Q@OoLg=c1om@D507
obLW9`Kok^k^1_ooool7olW9b@KoWYjN1ooTi>@7o`l?3`OoU9BD1omEEED7ol_;b`KoM7Ad3_ooool0
00cooooo1ol00007o`X:2POo<c<c1omXJ6P7oeeMG@KojNWY1omVIVH6ofUYJ@gooooo1omgMgL7oa<C
4`Oo7AdM1om<C4`6ogQhN0Oo]kNg1_nOWil6ooooo`Oo00001olT92@7of5QH@OoN7Qh1_maLG47obd]
;@Oo;2`/1_lL71`6ooooo`Oo10@41olT92@7oa/K6`OoDU9B1_mEEED7ono_k`Ooa<C41_l:2PX6oooo
o`Oo3@d=1olJ6QX7oaPH60Ko2`/;1olM7Ad7oa@D50Oo7alO1_ogmoL6ooooo`Oo1PH61olm?Cd7ong]
k@Ko][Jf1ol00007oh61P@OoD51@1_mLG5`6ooooo`OoKFe]1olG5aL6oaXJ6POoQHF51omcLg<7oe1@
D0Oo9bLW1_o^k^h6ooooo`OobLW91_nNWYh7onCTi0Oo3`l?1onDU9@7oeEEE@Oobl_;1_mdM7@>oooo
o`003?ooool7o`820POo1`L71ol];Bd7oeaLG0OoEEEE1_oYjNT7of=SH`KoFUYJ1_ooool7oh^;R`Oo
Xj>S1olV9RH7oa0@40OoSXj>1_oYjNT7ogEeM@KoEUIF1_ooool7oalO7`OoI6AT1onDU9@7oginOPKo
;2`/1olK6a/7ob0P80KoX:2P1_ooool7oa8B4POo=cLg1olL71`7ofQXJ0KoJVYZ1ookno/7ojn_[`Ko
4a<C1_ooool7o`0000Oo6QXJ1olH61P6o`h>3POo8b<S1olG5aL7oalO7`Kok^k^1_ooool7o`h>3POo
>3Ph1oo[jn/6oijNWPOo2`/;1omkNg/7odU9B@KoHV9R1_ooool7obTY:@Oo1`L71_l>3Ph7odA4A0Oo
VYZJ1omoOgl7obh^;PKoCTi>1_ooool7olO7a`KoTY:B1ooFe]H7oa@D50OoTi>C1oll?3`7okFe]@Ko
QHF53_ooool000cooooo1ol20P87o`L71`Oo;Bd]1omLG5`7oeEEE@KojNWY1omSHf<6oeYJFPKooooo
1on;Rh/7oj>SX`Oo9RHV1ol@4107ohj>SPKojNWY1omeMGD6oeIFEPKooooo1olO7al7ofATI0OoU9BD
1omnOWh6ob`/;0Oo6a/K1olP8206oj2PX0Kooooo1olB4Q87ocLg=`Oo71`L1omXJ6P6ofYZJPOono_k
1on_[jl6oa<C4`Kooooo1ol00007oaXJ6POo61PH1_l>3Ph7ob<S8`Oo5aLG1olO7al6onk^kPKooooo
1ol>3Ph7ocPh>0Oojn_[1_nNWYh7o`/;2`OoNg]k1om9BDT6of9RHPKooooo1olY:BT7o`L71`Ko3Ph>
1om4A4@7oiZJVPOoOgmo1ol^;Rh6odi>CPKooooo1oo7alL6oi:BTPOoe]KF1olD51@7oi>CT`Oo?3`l
1one]KD6ohF5Q@kooooo000<ooooo`Oo0P821ol71`L7obd];@OoG5aL1omEEED6onWYj@OoHf=S1_mJ
FUX6ooooo`OoRh^;1onSXj<7obHV9POo410@1on>SXh6onWYj@OoMGEe1_mFEUH6ooooo`Oo7alO1omT
I6@7oiBDU0OoOWin1_l/;2`7oa/K6`Oo820P1_nPX:06ooooo`Oo4Q8B1olg=cL7oa`L70OoJ6QX1_mZ
JVX7oo_kn`Oo[jn_1_lC4a<6ooooo`Oo00001olJ6QX7oaPH60Ko3Ph>1olS8b<7oaLG5`Oo7alO1_o^
k^h6ooooo`Oo3Ph>1olh>3P7on_[j`KoWYjN1ol;2`/7og]kN`OoBDU91_mRHV86ooooo`Oo:BTY1ol7
1`L6o`h>3POoA4A41onJVYX7ogmoO`Oo;Rh^1_m>CTh6ooooo`OoalO71_nBTY87omKFePOo51@D1onC
Ti<7oc`l?0Oo]KFe1_n5QHD>ooooo`003?ooool7o`820POo1`L71ol];Bd7oeaLG0OoEEEE1_oYjNT7
of=SH`KoFUYJ1_ooool7oh^;R`OoXj>S1olV9RH7oa0@40OoSXj>1_oYjNT7ogEeM@KoEUIF1_ooool7
oalO7`OoI6AT1onDU9@7oginOPKo;2`/1olK6a/7ob0P80KoX:2P1_ooool7oa8B4POo=cLg1olL71`7
ofQXJ0KoJVYZ1ookno/7ojn_[`Ko4a<C1_ooool7o`0000Oo6QXJ1olH61P6o`h>3POo8b<S1olG5aL7
oalO7`Kok^k^1_ooool7o`h>3POo>3Ph1oo[jn/6oijNWPOo2`/;1omkNg/7odU9B@KoHV9R1_ooool7
obTY:@Oo1`L71_l>3Ph7odA4A0OoVYZJ1omoOgl7obh^;PKoCTi>1_ooool7olO7a`KoTY:B1ooFe]H7
oa@D50OoTi>C1oll?3`7okFe]@KoQHF53_ooool000cooooo1ol20P87o`L71`Oo;Bd]1omLG5`7oeEE
E@KojNWY1omSHf<6oeYJFPKooooo1on;Rh/7oj>SX`Oo9RHV1ol@4107ohj>SPKojNWY1omeMGD6oeIF
EPKooooo1olO7al7ofATI0OoU9BD1omnOWh6ob`/;0Oo6a/K1olP8206oj2PX0Kooooo1olB4Q87ocLg
=`Oo71`L1omXJ6P6ofYZJPOono_k1on_[jl6oa<C4`Kooooo1ol00007oaXJ6POo61PH1_l>3Ph7ob<S
8`Oo5aLG1olO7al6onk^kPKooooo1ol>3Ph7ocPh>0Oojn_[1_nNWYh7o`/;2`OoNg]k1om9BDT6of9R
HPKooooo1olY:BT7o`L71`Ko3Ph>1om4A4@7oiZJVPOoOgmo1ol^;Rh6odi>CPKooooo1oo7alL6oi:B
TPOoe]KF1olD51@7oi>CT`Oo?3`l1one]KD6ohF5Q@kooooo000<ooooo`Oo0P821ol71`L7obd];@Oo
G5aL1omEEED6onWYj@OoHf=S1_mJFUX6ooooo`OoRh^;1onSXj<7obHV9POo410@1on>SXh6onWYj@Oo
MGEe1_mFEUH6ooooo`Oo7alO1omTI6@7oiBDU0OoOWin1_l/;2`7oa/K6`Oo820P1_nPX:06ooooo`Oo
4Q8B1olg=cL7oa`L70OoJ6QX1_mZJVX7oo_kn`Oo[jn_1_lC4a<6ooooo`Oo00001olJ6QX7oaPH60Ko
3Ph>1olS8b<7oaLG5`Oo7alO1_o^k^h6ooooo`Oo3Ph>1olh>3P7on_[j`KoWYjN1ol;2`/7og]kN`Oo
BDU91_mRHV86ooooo`Oo:BTY1ol71`L6o`h>3POoA4A41onJVYX7ogmoO`Oo;Rh^1_m>CTh6ooooo`Oo
alO71_nBTY87omKFePOo51@D1onCTi<7oc`l?0Oo]KFe1_n5QHD>ooooo`003?ooool7o`820POo1`L7
1ol];Bd7oeaLG0OoEEEE1_oYjNT7of=SH`KoFUYJ1_ooool7oh^;R`OoXj>S1olV9RH7oa0@40OoSXj>
1_oYjNT7ogEeM@KoEUIF1_ooool7oalO7`OoI6AT1onDU9@7oginOPKo;2`/1olK6a/7ob0P80KoX:2P
1_ooool7oa8B4POo=cLg1olL71`7ofQXJ0KoJVYZ1ookno/7ojn_[`Ko4a<C1_ooool7o`0000Oo6QXJ
1olH61P6o`h>3POo8b<S1olG5aL7oalO7`Kok^k^1_ooool7o`h>3POo>3Ph1oo[jn/6oijNWPOo2`/;
1omkNg/7odU9B@KoHV9R1_ooool7obTY:@Oo1`L71_l>3Ph7odA4A0OoVYZJ1omoOgl7obh^;PKoCTi>
1_ooool7olO7a`KoTY:B1ooFe]H7oa@D50OoTi>C1oll?3`7okFe]@KoQHF53_ooool000cooooo1ol=
3@d7oaHF5POo=SHf1omMGEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll
?3`7oeMGE`KoHV9R1onFUYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll
?3`6oa@D50Kooooo1olA4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?
3`l7oa0@40Ko1`L71olL71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol5
1@D7ogEeM@OoBDU91_mOGel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?oo
ool7ojn_[`KoL71`1onb/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7
oaHF5POo=SHf1omMGEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7
oeMGE`KoHV9R1onFUYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6
oa@D50Kooooo1olA4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7
oa0@40Ko1`L71olL71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7
ogEeM@OoBDU91_mOGel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7
ojn_[`KoL71`1onb/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7oaHF
5POo=SHf1omMGEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7oeMG
E`KoHV9R1onFUYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6oa@D
50Kooooo1olA4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7oa0@
40Ko1`L71olL71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7ogEe
M@OoBDU91_mOGel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7ojn_
[`KoL71`1onb/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7oaHF5POo
=SHf1omMGEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7oeMGE`Ko
HV9R1onFUYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6oa@D50Ko
oooo1olA4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7oa0@40Ko
1`L71olL71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7ogEeM@Oo
BDU91_mOGel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7ojn_[`Ko
L71`1onb/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7oaHF5POo=SHf
1omMGEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7oeMGE`KoHV9R
1onFUYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6oa@D50Kooooo
1olA4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7oa0@40Ko1`L7
1olL71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7ogEeM@OoBDU9
1_mOGel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7ojn_[`KoL71`
1onb/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7oaHF5POo=SHf1omM
GEd7oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7oeMGE`KoHV9R1onF
UYH6ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6oa@D50Kooooo1olA
4A47obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7oa0@40Ko1`L71olL
71`7oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7ogEeM@OoBDU91_mO
Gel6ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7ojn_[`KoL71`1onb
/[87o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool000cooooo1ol=3@d7oaHF5POo=SHf1omMGEd7
oeMGE`Ko_kno1omLG5`6oeQHF0Kooooo1ooalO47oeADE0Oo10@41oll?3`7oeMGE`KoHV9R1onFUYH6
ol30`0Kooooo1ol:2PX7obHV9POoGUiN1omPH606oemOG`Oo8B4Q1oll?3`6oa@D50Kooooo1olA4A47
obDU9@Oo8b<S3OmIFET7olW9b@OoShn?1_l30`<6ooooo`Oo20P81ol?3`l7oa0@40Ko1`L71olL71`7
oa0@40Oo6a/K1_o=cLd6ooooo`Oo0@411om<C4`7om7Ad@KoPh>31ol51@D7ogEeM@OoBDU91_mOGel6
ooooo`OoIFEU1ol=3@d6obh^;POoV9RH1omXJ6P7oc4a<@Oo8B4Q3?ooool7ojn_[`KoL71`1onb/[87
o`0000OoN7Qh1olm?Cd7ok>c/`KoI6AT3_ooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool000cooooo1om;Bd/7ojn_[`Oo
=SHf1onDU9@7ob0P80Ko9BDU1olZ:RX6ohZ:RPKooooo1onLW9`7on?Sh`OoLG5a1onKVi/7oc8b<PKo
6ATI1olD51@6ocDe=@Kooooo1olK6a/7obLW9`OoR8R81ong]kL6ohb<S0OoA4A41olQ8B46oc0`<0Ko
oooo3_n9RHT7obh^;POo=CDe1_mCDe<7ogIfMPOoA4A41_n=SHd6ooooo`Oo`l?31omVIVH7ob`/;0Ko
<30`1olG5aL7ob8R8POo@d=31_oemOD6ooooo`OoJ6QX1on:RXX7onKViPKo@4101olC4a<7ob`/;0Oo
^KVi1_lo?cl6ooooo`Oo=cLg1om;Bd/6oc`l?0Oo6ATI1ooLg=`7odM7A`Oo>3Ph1_ln?Sh6ooooo`Oo
30`<1_m3@d<7odQ8B0Oo[Jf]1ooXj>P7oc4a<@Oo>CTi1_l0000>ooooo`003?ooool7od];B`Oo[jn_
1olf=SH7oiBDU0Oo820P1_lU9BD7obXZ:PKoRXZ:1_ooool7oibLW0Oohn?S1omaLG47oi^KV`Oo<S8b
1_lI6AT7oa@D50Ko=CDe1_ooool7oa/K6`Oo9bLW1on8R8P7okNg]`KoS8b<1om4A4@7ob4Q8@Ko<30`
1_ooool>ohV9R@Oo;Rh^1ole=CD6oe=CD`OoMWIf1om4A4@6ohf=S@Kooooo1oo3`l<7ofIVIPOo;2`/
1_l`<307oaLG5`Oo8R8R1om3@d<6ooGem@Kooooo1omXJ6P7ohZ:RPOoi^KV1_m0@407oa<C4`Oo;2`/
1oni^KT6oclo?`Kooooo1olg=cL7od];B`Ko?3`l1olI6AT7omcLg0OoAdM71olh>3P6ochn?PKooooo
1ol<30`6od=3@`OoB4Q81on][Jd7onSXj0Oo<C4a1oli>CT6o`0000kooooo000<ooooo`OoBd];1on_
[jl7ocHf=POoU9BD1olP8206obDU9@Oo:RXZ1_n:RXX6ooooo`OoW9bL1ooShn<7og5aL@OoVi^K1olb
<S86oaTI6@Oo51@D1_le=CD6ooooo`Oo6a/K1olW9bL7ohR8R0Oo]kNg1_n<S8`7odA4A0Oo8B4Q1_l`
<306ooooo`koRHV91ol^;Rh7ocDe=@KoDe=C1omfMWH7odA4A0KoSHf=1_ooool7ol?3``OoIVIV1ol/
;2`6oc0`<0Oo5aLG1olR8R87od=3@`KomOGe1_ooool7ofQXJ0OoRXZ:1ooVi^H6od10@0Oo4a<C1ol/
;2`7okVi^@Ko?clo1_ooool7ocLg=`OoBd];1_ll?3`7oaTI6@Oog=cL1om7AdL7ocPh>0Ko?Shn1_oo
ool7o``<30Ko@d=31om8B4P7ojf][@Ooj>SX1ola<C47ocTi>@Ko00003_ooool000cooooo1om;Bd/7
ojn_[`Oo=SHf1onDU9@7ob0P80Ko9BDU1olZ:RX6ohZ:RPKooooo1onLW9`7on?Sh`OoLG5a1onKVi/7
oc8b<PKo6ATI1olD51@6ocDe=@Kooooo1olK6a/7obLW9`OoR8R81ong]kL6ohb<S0OoA4A41olQ8B46
oc0`<0Kooooo3_n9RHT7obh^;POo=CDe1_mCDe<7ogIfMPOoA4A41_n=SHd6ooooo`Oo`l?31omVIVH7
ob`/;0Ko<30`1olG5aL7ob8R8POo@d=31_oemOD6ooooo`OoJ6QX1on:RXX7onKViPKo@4101olC4a<7
ob`/;0Oo^KVi1_lo?cl6ooooo`Oo=cLg1om;Bd/6oc`l?0Oo6ATI1ooLg=`7odM7A`Oo>3Ph1_ln?Sh6
ooooo`Oo30`<1_m3@d<7odQ8B0Oo[Jf]1ooXj>P7oc4a<@Oo>CTi1_l0000>ooooo`003?ooool7od];
B`Oo[jn_1olf=SH7oiBDU0Oo820P1_lU9BD7obXZ:PKoRXZ:1_ooool7oibLW0Oohn?S1omaLG47oi^K
V`Oo<S8b1_lI6AT7oa@D50Ko=CDe1_ooool7oa/K6`Oo9bLW1on8R8P7okNg]`KoS8b<1om4A4@7ob4Q
8@Ko<30`1_ooool>ohV9R@Oo;Rh^1ole=CD6oe=CD`OoMWIf1om4A4@6ohf=S@Kooooo1oo3`l<7ofIV
IPOo;2`/1_l`<307oaLG5`Oo8R8R1om3@d<6ooGem@Kooooo1omXJ6P7ohZ:RPOoi^KV1_m0@407oa<C
4`Oo;2`/1oni^KT6oclo?`Kooooo1olg=cL7od];B`Ko?3`l1olI6AT7omcLg0OoAdM71olh>3P6ochn
?PKooooo1ol<30`6od=3@`OoB4Q81on][Jd7onSXj0Oo<C4a1oli>CT6o`0000kooooo000<ooooo`Oo
Bd];1on_[jl7ocHf=POoU9BD1olP8206obDU9@Oo:RXZ1_n:RXX6ooooo`OoW9bL1ooShn<7og5aL@Oo
Vi^K1olb<S86oaTI6@Oo51@D1_le=CD6ooooo`Oo6a/K1olW9bL7ohR8R0Oo]kNg1_n<S8`7odA4A0Oo
8B4Q1_l`<306ooooo`koRHV91ol^;Rh7ocDe=@KoDe=C1omfMWH7odA4A0KoSHf=1_ooool7ol?3``Oo
IVIV1ol/;2`6oc0`<0Oo5aLG1olR8R87od=3@`KomOGe1_ooool7ofQXJ0OoRXZ:1ooVi^H6od10@0Oo
4a<C1ol/;2`7okVi^@Ko?clo1_ooool7ocLg=`OoBd];1_ll?3`7oaTI6@Oog=cL1om7AdL7ocPh>0Ko
?Shn1_ooool7o``<30Ko@d=31om8B4P7ojf][@Ooj>SX1ola<C47ocTi>@Ko00003_ooool000cooooo
1om;Bd/7ojn_[`Oo=SHf1onDU9@7ob0P80Ko9BDU1olZ:RX6ohZ:RPKooooo1onLW9`7on?Sh`OoLG5a
1onKVi/7oc8b<PKo6ATI1olD51@6ocDe=@Kooooo1olK6a/7obLW9`OoR8R81ong]kL6ohb<S0OoA4A4
1olQ8B46oc0`<0Kooooo3_n9RHT7obh^;POo=CDe1_mCDe<7ogIfMPOoA4A41_n=SHd6ooooo`Oo`l?3
1omVIVH7ob`/;0Ko<30`1olG5aL7ob8R8POo@d=31_oemOD6ooooo`OoJ6QX1on:RXX7onKViPKo@410
1olC4a<7ob`/;0Oo^KVi1_lo?cl6ooooo`Oo=cLg1om;Bd/6oc`l?0Oo6ATI1ooLg=`7odM7A`Oo>3Ph
1_ln?Sh6ooooo`Oo30`<1_m3@d<7odQ8B0Oo[Jf]1ooXj>P7oc4a<@Oo>CTi1_l0000>ooooo`003?oo
ool7oc<c<`Oo^k^k1ol_;bl7oi6AT@Oo20P81_lQ8B47obl_;`KoO7al1_ooool7oj:RXPOojNWY1om^
KVh7oh:2PPOo>CTi1_l<30`7oa8B4PKo=cLg1_ooool7obPX:0OoXZ:R1onVYZH7ol;2`PKoEEEE1olD
51@7o`0000KoVYZJ1_ooool7og=cL`OoC4a<1olJ6QX7oaPH60KoMgMg1on7QhL7oi2@T0Ko;Bd]1_oo
ool7on3Ph0OoG5aL1ola<C46obh^;POo1`L71olF5QH7ocTi>@Koj^[Z1_ooool7oc0`<0Oof=SH1ooQ
hN46oeYJFPOo00001omQHF47ojVYZ@Ko<S8b1_ooool7od10@0Oo<S8b1_lJ6QX7oaPH60Ood=3@3_l]
;Bd6ocLg=`Kooooo1olB4Q86oclo?`OoADE51oo1`L47onk^kPOo2@T91om1@D46oa0@40kooooo000<
ooooo`Oo<c<c1onk^k/7obl_;`OoTI6A1ol820P6ob4Q8@Oo;bl_1_mlO7`6ooooo`OoXZ:R1ooYjNT7
ofi^KPOoPX:21oli>CT6o``<30Oo4Q8B1_lg=cL6ooooo`Oo:2PX1onRXZ87ojJVYPOo`/;21_mEEED7
oa@D50Oo00001_nJVYX6ooooo`OoLg=c1om<C4`7oaXJ6POo61PH1_mgMgL7ohN7Q`OoT92@1_l];Bd6
ooooo`Ooh>3P1omLG5`7oc4a<@Ko;Rh^1ol71`L7oaHF5POo>CTi1_oZj^X6ooooo`Oo<30`1ooHf=P7
on7Qh@KoFUYJ1ol00007of5QH@OoZJVY1_lb<S86ooooo`Oo@4101olb<S86oaXJ6POo61PH1oo@d=0>
obd];@Ko=cLg1_ooool7oa8B4PKo?clo1om5ADD7ol71`@Ook^k^1ol92@T7od51@@Ko410@3_ooool0
00cooooo1olc<c<7ok^k^`Oo;bl_1onATI47o`P820Ko8B4Q1ol_;bl6ogalO0Kooooo1onRXZ87onWY
j@OoKVi^1on2PX87ocTi>@Ko30`<1olB4Q86ocLg=`Kooooo1olX:2P7oj:RXPOoYZJV1oo2`/86oeEE
E@Oo51@D1ol00006oiZJVPKooooo1omcLg<7oda<C0Oo6QXJ1olH61P6ogMgM`OoQhN71on@T906obd]
;@Kooooo1ooPh>07oeaLG0Oo<C4a1_l^;Rh7o`L71`Oo5QHF1oli>CT6on[ZjPKooooo1ol`<307omSH
f0OohN7Q1_mJFUX7o`0000OoHF5Q1onYZJT6oc8b<PKooooo1om0@407oc8b<PKo6QXJ1olH61P7om3@
d0ko;Bd]1_lg=cL6ooooo`Oo4Q8B1_lo?cl7odE5A@Oo`L711oo^k^h7o`T92@Oo@D511_l@410>oooo
o`003?ooool7oc<c<`Oo^k^k1ol_;bl7oi6AT@Oo20P81_lQ8B47obl_;`KoO7al1_ooool7oj:RXPOo
jNWY1om^KVh7oh:2PPOo>CTi1_l<30`7oa8B4PKo=cLg1_ooool7obPX:0OoXZ:R1onVYZH7ol;2`PKo
EEEE1olD51@7o`0000KoVYZJ1_ooool7og=cL`OoC4a<1olJ6QX7oaPH60KoMgMg1on7QhL7oi2@T0Ko
;Bd]1_ooool7on3Ph0OoG5aL1ola<C46obh^;POo1`L71olF5QH7ocTi>@Koj^[Z1_ooool7oc0`<0Oo
f=SH1ooQhN46oeYJFPOo00001omQHF47ojVYZ@Ko<S8b1_ooool7od10@0Oo<S8b1_lJ6QX7oaPH60Oo
d=3@3_l];Bd6ocLg=`Kooooo1olB4Q86oclo?`OoADE51oo1`L47onk^kPOo2@T91om1@D46oa0@40ko
oooo000<ooooo`Oo<c<c1onk^k/7obl_;`OoTI6A1ol820P6ob4Q8@Oo;bl_1_mlO7`6ooooo`OoXZ:R
1ooYjNT7ofi^KPOoPX:21oli>CT6o``<30Oo4Q8B1_lg=cL6ooooo`Oo:2PX1onRXZ87ojJVYPOo`/;2
1_mEEED7oa@D50Oo00001_nJVYX6ooooo`OoLg=c1om<C4`7oaXJ6POo61PH1_mgMgL7ohN7Q`OoT92@
1_l];Bd6ooooo`Ooh>3P1omLG5`7oc4a<@Ko;Rh^1ol71`L7oaHF5POo>CTi1_oZj^X6ooooo`Oo<30`
1ooHf=P7on7Qh@KoFUYJ1ol00007of5QH@OoZJVY1_lb<S86ooooo`Oo@4101olb<S86oaXJ6POo61PH
1oo@d=0>obd];@Ko=cLg1_ooool7oa8B4PKo?clo1om5ADD7ol71`@Ook^k^1ol92@T7od51@@Ko410@
3_ooool000cooooo1olc<c<7ok^k^`Oo;bl_1onATI47o`P820Ko8B4Q1ol_;bl6ogalO0Kooooo1onR
XZ87onWYj@OoKVi^1on2PX87ocTi>@Ko30`<1olB4Q86ocLg=`Kooooo1olX:2P7oj:RXPOoYZJV1oo2
`/86oeEEE@Oo51@D1ol00006oiZJVPKooooo1omcLg<7oda<C0Oo6QXJ1olH61P6ogMgM`OoQhN71on@
T906obd];@Kooooo1ooPh>07oeaLG0Oo<C4a1_l^;Rh7o`L71`Oo5QHF1oli>CT6on[ZjPKooooo1ol`
<307omSHf0OohN7Q1_mJFUX7o`0000OoHF5Q1onYZJT6oc8b<PKooooo1om0@407oc8b<PKo6QXJ1olH
61P7om3@d0ko;Bd]1_lg=cL6ooooo`Oo4Q8B1_lo?cl7odE5A@Oo`L711oo^k^h7o`T92@Oo@D511_l@
410>ooooo`003?ooool7oc<c<`Oo^k^k1ol_;bl7oi6AT@Oo20P81_lQ8B47obl_;`KoO7al1_ooool7
oj:RXPOojNWY1om^KVh7oh:2PPOo>CTi1_l<30`7oa8B4PKo=cLg1_ooool7obPX:0OoXZ:R1onVYZH7
ol;2`PKoEEEE1olD51@7o`0000KoVYZJ1_ooool7og=cL`OoC4a<1olJ6QX7oaPH60KoMgMg1on7QhL7
oi2@T0Ko;Bd]1_ooool7on3Ph0OoG5aL1ola<C46obh^;POo1`L71olF5QH7ocTi>@Koj^[Z1_ooool7
oc0`<0Oof=SH1ooQhN46oeYJFPOo00001omQHF47ojVYZ@Ko<S8b1_ooool7od10@0Oo<S8b1_lJ6QX7
oaPH60Ood=3@3_l];Bd6ocLg=`Kooooo1olB4Q86oclo?`OoADE51oo1`L47onk^kPOo2@T91om1@D46
oa0@40kooooo000<ooooo`Oo=CDe1ooBd]87oc`l?0OoUYJF1olE5AD6oa@D50Oo7QhN1_mQHF46oooo
o`Oo][Jf1oooool7ofATI0OoW9bL1olY:BT6o`/;2`Oo1`L71_lg=cL6ooooo`Oo6QXJ1om0@407okNg
]`Oof][J1_meMGD7obTY:@OoFe]K1_lX:2P6ooooo`OoRXZ:1omUIFD7oaXJ6POoEUIF1_m:BTX7ofa/
K0OoB4Q81_o?cll6ooooo`Ool?3`1om[Jf/7ob0P80Ko7alO1ol71`L7oa`L70Oo>SXj1_ohn?P6oooo
o`OoRh^;1onJVYX7olW9b@Ko6a/K1olA4A47ocPh>0Oohn?S1_la<C46ooooo`Oo<c<c1om<C4`6ob4Q
8@Oo4a<C1ookno/7obh^;POo=cLg1_l];Bd6ooooo`Oo2PX:1_m;Bd/7oe]KF`Oohn?S1ookno/7oaLG
5`OoADE51_l<30`>ooooo`003?ooool7ocDe=@Ood];B1oll?3`7oiJFUPOo5ADE1_lD51@7oahN7PKo
HF5Q1_ooool7okJf]POooooo1omTI6@7oibLW0Oo:BTY1_l;2`/7o`L71`Ko=cLg1_ooool7oaXJ6POo
@4101ong]kL7om[JfPKoMGEe1olY:BT7oe]KF`Ko:2PX1_ooool7ohZ:RPOoIFEU1olJ6QX7oeIFEPKo
BTY:1om/K6`7odQ8B0Koclo?1_ooool7oo3`l0OoJf][1olP8206oalO7`Oo1`L71olL71`7ocXj>PKo
n?Sh1_ooool7oh^;R`OoVYZJ1oo9bLT6oa/K6`Oo4A4A1olh>3P7on?Sh`Ko<C4a1_ooool7oc<c<`Oo
C4a<1_lQ8B47oa<C4`Oono_k1ol^;Rh7ocLg=`Ko;Bd]1_ooool7o`X:2PKoBd];1omKFe/7on?Sh`Oo
no_k1olG5aL7odE5A@Ko30`<3_ooool000cooooo1ole=CD7om;BdPOo?3`l1onFUYH7oaDE5@Ko51@D
1olN7Qh6of5QH@Kooooo1onf][H7ooooo`OoI6AT1onLW9`7obTY:@Ko2`/;1ol71`L6ocLg=`Kooooo
1olJ6QX7od10@0Oo]kNg1ooJf]X6ogEeM@Oo:BTY1omKFe/6obPX:0Kooooo1on:RXX7ofEUI@Oo6QXJ
1omFEUH6odY:BPOoK6a/1om8B4P6olo?c`Kooooo1oo`l?07of][J`Oo820P1_lO7al7o`L71`Oo71`L
1olj>SX6ooShn0Kooooo1on;Rh/7oiZJVPOobLW91_lK6a/7oa4A4@Oo>3Ph1ooShn<6oc4a<@Kooooo
1olc<c<7oda<C0Ko8B4Q1olC4a<7oo_kn`Oo;Rh^1olg=cL6obd];@Kooooo1ol:2PX6od];B`OoFe]K
1ooShn<7oo_kn`Oo5aLG1om5ADD6o``<30kooooo000<ooooo`Oo=CDe1ooBd]87oc`l?0OoUYJF1olE
5AD6oa@D50Oo7QhN1_mQHF46ooooo`Oo][Jf1oooool7ofATI0OoW9bL1olY:BT6o`/;2`Oo1`L71_lg
=cL6ooooo`Oo6QXJ1om0@407okNg]`Oof][J1_meMGD7obTY:@OoFe]K1_lX:2P6ooooo`OoRXZ:1omU
IFD7oaXJ6POoEUIF1_m:BTX7ofa/K0OoB4Q81_o?cll6ooooo`Ool?3`1om[Jf/7ob0P80Ko7alO1ol7
1`L7oa`L70Oo>SXj1_ohn?P6ooooo`OoRh^;1onJVYX7olW9b@Ko6a/K1olA4A47ocPh>0Oohn?S1_la
<C46ooooo`Oo<c<c1om<C4`6ob4Q8@Oo4a<C1ookno/7obh^;POo=cLg1_l];Bd6ooooo`Oo2PX:1_m;
Bd/7oe]KF`Oohn?S1ookno/7oaLG5`OoADE51_l<30`>ooooo`003?ooool7ocDe=@Ood];B1oll?3`7
oiJFUPOo5ADE1_lD51@7oahN7PKoHF5Q1_ooool7okJf]POooooo1omTI6@7oibLW0Oo:BTY1_l;2`/7
o`L71`Ko=cLg1_ooool7oaXJ6POo@4101ong]kL7om[JfPKoMGEe1olY:BT7oe]KF`Ko:2PX1_ooool7
ohZ:RPOoIFEU1olJ6QX7oeIFEPKoBTY:1om/K6`7odQ8B0Koclo?1_ooool7oo3`l0OoJf][1olP8206
oalO7`Oo1`L71olL71`7ocXj>PKon?Sh1_ooool7oh^;R`OoVYZJ1oo9bLT6oa/K6`Oo4A4A1olh>3P7
on?Sh`Ko<C4a1_ooool7oc<c<`OoC4a<1_lQ8B47oa<C4`Oono_k1ol^;Rh7ocLg=`Ko;Bd]1_ooool7
o`X:2PKoBd];1omKFe/7on?Sh`Oono_k1olG5aL7odE5A@Ko30`<3_ooool000cooooo1ole=CD7om;B
dPOo?3`l1onFUYH7oaDE5@Ko51@D1olN7Qh6of5QH@Kooooo1onf][H7ooooo`OoI6AT1onLW9`7obTY
:@Ko2`/;1ol71`L6ocLg=`Kooooo1olJ6QX7od10@0Oo]kNg1ooJf]X6ogEeM@Oo:BTY1omKFe/6obPX
:0Kooooo1on:RXX7ofEUI@Oo6QXJ1omFEUH6odY:BPOoK6a/1om8B4P6olo?c`Kooooo1oo`l?07of][
J`Oo820P1_lO7al7o`L71`Oo71`L1olj>SX6ooShn0Kooooo1on;Rh/7oiZJVPOobLW91_lK6a/7oa4A
4@Oo>3Ph1ooShn<6oc4a<@Kooooo1olc<c<7oda<C0Ko8B4Q1olC4a<7oo_kn`Oo;Rh^1olg=cL6obd]
;@Kooooo1ol:2PX6od];B`OoFe]K1ooShn<7oo_kn`Oo5aLG1om5ADD6o``<30kooooo000<ooooo`Oo
:BTY1ooFe]H7obDU9@OoYJFU1ol71`L6oadM7@Oo3Ph>1_m[Jf/6ooooo`Oo^[Zj1oo]kNd7oe9BDPOo
MgMg1ol[:b/6o`0000Oo3@d=1_lb<S86ooooo`Oo;bl_1ooEeMD7okNg]`OoXj>S1_l^;Rh7oa0@40Oo
00001_mPH606ooooo`OoJ6QX1om2@T87o`H61POo6a/K1_nUYJD7oh:2PPOoLG5a1_lY:BT6ooooo`Oo
n?Sh1omZJVX7oc@d=0Ko7AdM1ol00007oa4A4@Oo=SHf3?ooool7oe=CD`OomoOg1oo6a/H6obPX:0Oo
4A4A1on4Q8@7okFe]@Ko7AdM1_ooool7ocdm?@Oo:b/[1_l61PH7obHV9POolO7a1olC4a<7oc4a<@Ko
:b/[1_ooool7o`/;2`KoCTi>1omKFe/7on[ZjPOokno_1ol00007od];B`Ko51@D3_ooool000cooooo
1olY:BT7omKFePOo9BDU1onUYJD7o`L71`Ko7AdM1ol>3Ph6of][J`Kooooo1onj^[X7ong]k@OoDU9B
1omgMgL7ob/[:`Ko00001ol=3@d6oc8b<PKooooo1ol_;bl7omGEe@Oo]kNg1onSXj<6obh^;POo410@
1ol00006of1PH0Kooooo1omXJ6P7od92@POo1PH61olK6a/6ojFUY@OoPX:21omaLG46obTY:@Kooooo
1oohn?P7ofYZJPOo=3@d1_lM7Ad7o`0000Oo4A4A1olf=SH<ooooo`OoDe=C1oogmoL7olK6aPKo:2PX
1olA4A47ohB4Q0Oo]KFe1_lM7Ad6ooooo`Oo?Cdm1ol[:b/6o`H61POo9RHV1ooalO47oa<C4`Oo<C4a
1_l[:b/6ooooo`Oo2`/;1_m>CTh7oe]KF`Ooj^[Z1oo_knl7o`0000OoBd];1_lD51@>ooooo`003?oo
ool7obTY:@Ooe]KF1olU9BD7ojFUY@Oo1`L71_lM7Ad7o`h>3PKoJf][1_ooool7okZj^POokNg]1omB
DU87ogMgM`Oo:b/[1_l00007o`d=3@Ko<S8b1_ooool7obl_;`OoeMGE1ong]kL7oj>SX`Ko;Rh^1ol@
4107o`0000KoH61P1_ooool7ofQXJ0Oo@T921ol61PH7oa/K6`KoYJFU1on2PX87og5aL@Ko:BTY1_oo
ool7ooShn0OoJVYZ1old=3@6oadM7@Oo00001olA4A47ocHf=Pcooooo1omCDe<7ooOgm`Ooa/K61_lX
:2P7oa4A4@OoQ8B41one]KD6oadM7@Kooooo1olm?Cd7ob/[:`Ko1PH61olV9RH7oo7al@Oo4a<C1ola
<C46ob/[:`Kooooo1ol;2`/6odi>CPOoFe]K1ooZj^X7ono_k`Oo00001om;Bd/6oa@D50kooooo000<
ooooo`Oo:BTY1ooFe]H7obDU9@OoYJFU1ol71`L6oadM7@Oo3Ph>1_m[Jf/6ooooo`Oo^[Zj1oo]kNd7
oe9BDPOoMgMg1ol[:b/6o`0000Oo3@d=1_lb<S86ooooo`Oo;bl_1ooEeMD7okNg]`OoXj>S1_l^;Rh7
oa0@40Oo00001_mPH606ooooo`OoJ6QX1om2@T87o`H61POo6a/K1_nUYJD7oh:2PPOoLG5a1_lY:BT6
ooooo`Oon?Sh1omZJVX7oc@d=0Ko7AdM1ol00007oa4A4@Oo=SHf3?ooool7oe=CD`OomoOg1oo6a/H6
obPX:0Oo4A4A1on4Q8@7okFe]@Ko7AdM1_ooool7ocdm?@Oo:b/[1_l61PH7obHV9POolO7a1olC4a<7
oc4a<@Ko:b/[1_ooool7o`/;2`KoCTi>1omKFe/7on[ZjPOokno_1ol00007od];B`Ko51@D3_ooool0
00cooooo1olY:BT7omKFePOo9BDU1onUYJD7o`L71`Ko7AdM1ol>3Ph6of][J`Kooooo1onj^[X7ong]
k@OoDU9B1omgMgL7ob/[:`Ko00001ol=3@d6oc8b<PKooooo1ol_;bl7omGEe@Oo]kNg1onSXj<6obh^
;POo410@1ol00006of1PH0Kooooo1omXJ6P7od92@POo1PH61olK6a/6ojFUY@OoPX:21omaLG46obTY
:@Kooooo1oohn?P7ofYZJPOo=3@d1_lM7Ad7o`0000Oo4A4A1olf=SH<ooooo`OoDe=C1oogmoL7olK6
aPKo:2PX1olA4A47ohB4Q0Oo]KFe1_lM7Ad6ooooo`Oo?Cdm1ol[:b/6o`H61POo9RHV1ooalO47oa<C
4`Oo<C4a1_l[:b/6ooooo`Oo2`/;1_m>CTh7oe]KF`Ooj^[Z1oo_knl7o`0000OoBd];1_lD51@>oooo
o`003?ooool7obTY:@Ooe]KF1olU9BD7ojFUY@Oo1`L71_lM7Ad7o`h>3PKoJf][1_ooool7okZj^POo
kNg]1omBDU87ogMgM`Oo:b/[1_l00007o`d=3@Ko<S8b1_ooool7obl_;`OoeMGE1ong]kL7oj>SX`Ko
;Rh^1ol@4107o`0000KoH61P1_ooool7ofQXJ0Oo@T921ol61PH7oa/K6`KoYJFU1on2PX87og5aL@Ko
:BTY1_ooool7ooShn0OoJVYZ1old=3@6oadM7@Oo00001olA4A47ocHf=Pcooooo1omCDe<7ooOgm`Oo
a/K61_lX:2P7oa4A4@OoQ8B41one]KD6oadM7@Kooooo1olm?Cd7ob/[:`Ko1PH61olV9RH7oo7al@Oo
4a<C1ola<C46ob/[:`Kooooo1ol;2`/6odi>CPOoFe]K1ooZj^X7ono_k`Oo00001om;Bd/6oa@D50ko
oooo000<ooooo`Oo:BTY1ooFe]H7obDU9@OoYJFU1ol71`L6oadM7@Oo3Ph>1_m[Jf/6ooooo`Oo^[Zj
1oo]kNd7oe9BDPOoMgMg1ol[:b/6o`0000Oo3@d=1_lb<S86ooooo`Oo;bl_1ooEeMD7okNg]`OoXj>S
1_l^;Rh7oa0@40Oo00001_mPH606ooooo`OoJ6QX1om2@T87o`H61POo6a/K1_nUYJD7oh:2PPOoLG5a
1_lY:BT6ooooo`Oon?Sh1omZJVX7oc@d=0Ko7AdM1ol00007oa4A4@Oo=SHf3?ooool7oe=CD`OomoOg
1oo6a/H6obPX:0Oo4A4A1on4Q8@7okFe]@Ko7AdM1_ooool7ocdm?@Oo:b/[1_l61PH7obHV9POolO7a
1olC4a<7oc4a<@Ko:b/[1_ooool7o`/;2`KoCTi>1omKFe/7on[ZjPOokno_1ol00007od];B`Ko51@D
3_ooool000cooooo1olm?Cd7ong]k@OoADE51onKVi/7oaDE5@Ko10@41ol@4106of][J`Kooooo1oo@
d=07oo3`l0OoDE5A1on@T907oa`L70Ko1@D51ol;2`/6ocXj>PKooooo1ol/;2`7oe]KF`Oog=cL1oo6
a/H6odE5A@Oo6a/K1on>SXh6oc0`<0Kooooo1omoOgl7oc<c<`Oo9bLW1omTI6@6odE5A@OoI6AT1om;
Bd/<ooooo`OohN7Q1on5QHD7oc8b<PKo410@1ol20P87oalO7`Oo=SHf3?ooool7oi^KV`Oo[:b/1onF
UYH6o`h>3POo61PH1om>CTh7onk^kPKoBTY:1_ooool>ocXj>PKo6ATI1olS8b<7ooooo`Oo3`l?1olc
<c<6oc8b<PKooooo1olD51@6of9RHPOoLW9b1oooool7on_[j`Oo4Q8B1om5ADD6oa<C4`kooooo000<
ooooo`Oo?Cdm1oo]kNd7odE5A@OoVi^K1olE5AD6o`@410Oo410@1_m[Jf/6ooooo`Ood=3@1oo`l?07
oe5AD@OoT92@1olL71`6o`D51@Oo2`/;1_lj>SX6ooooo`Oo;2`/1omKFe/7omcLg0Ooa/K61_m5ADD7
oa/K6`OoSXj>1_l`<306ooooo`OoOgmo1olc<c<7obLW9`OoI6AT1_m5ADD7ofATI0OoBd];3?ooool7
on7Qh@OoQHF51olb<S86oa0@40Oo0P821olO7al7ocHf=Pcooooo1onKVi/7ojb/[0OoUYJF1_l>3Ph7
oaPH60OoCTi>1oo^k^h6odY:BPKooooo3_lj>SX6oaTI6@Oo8b<S1oooool7o`l?3`Oo<c<c1_lb<S86
ooooo`Oo51@D1_mRHV87og9bLPOooooo1oo[jn/7oa8B4POoADE51_lC4a<>ooooo`003?ooool7ocdm
?@OokNg]1om5ADD7oi^KV`Oo5ADE1_l410@7oa0@40KoJf][1_ooool7om3@d0Ool?3`1omADE47oi2@
T0Oo71`L1_l51@D7o`/;2`Ko>SXj1_ooool7ob`/;0OoFe]K1ooLg=`7olK6aPKoADE51olK6a/7ohj>
SPKo<30`1_ooool7ogmoO`Oo<c<c1olW9bL7ofATI0KoADE51omTI6@7od];B`cooooo1ooQhN47ohF5
Q@Oo<S8b1_l@4107o`820POo7alO1olf=SH<ooooo`OoVi^K1on/[:`7oiJFUPKo3Ph>1olH61P7odi>
CPOok^k^1_m:BTX6ooooo`ko>SXj1_lI6AT7ob<S8`Oooooo1ol?3`l7oc<c<`Ko<S8b1_ooool7oa@D
50KoHV9R1ombLW87ooooo`Oojn_[1olB4Q87odE5A@Ko4a<C3_ooool000cooooo1olm?Cd7ong]k@Oo
ADE51onKVi/7oaDE5@Ko10@41ol@4106of][J`Kooooo1oo@d=07oo3`l0OoDE5A1on@T907oa`L70Ko
1@D51ol;2`/6ocXj>PKooooo1ol/;2`7oe]KF`Oog=cL1oo6a/H6odE5A@Oo6a/K1on>SXh6oc0`<0Ko
oooo1omoOgl7oc<c<`Oo9bLW1omTI6@6odE5A@OoI6AT1om;Bd/<ooooo`OohN7Q1on5QHD7oc8b<PKo
410@1ol20P87oalO7`Oo=SHf3?ooool7oi^KV`Oo[:b/1onFUYH6o`h>3POo61PH1om>CTh7onk^kPKo
BTY:1_ooool>ocXj>PKo6ATI1olS8b<7ooooo`Oo3`l?1olc<c<6oc8b<PKooooo1olD51@6of9RHPOo
LW9b1oooool7on_[j`Oo4Q8B1om5ADD6oa<C4`kooooo000<ooooo`Oo?Cdm1oo]kNd7odE5A@OoVi^K
1olE5AD6o`@410Oo410@1_m[Jf/6ooooo`Ood=3@1oo`l?07oe5AD@OoT92@1olL71`6o`D51@Oo2`/;
1_lj>SX6ooooo`Oo;2`/1omKFe/7omcLg0Ooa/K61_m5ADD7oa/K6`OoSXj>1_l`<306ooooo`OoOgmo
1olc<c<7obLW9`OoI6AT1_m5ADD7ofATI0OoBd];3?ooool7on7Qh@OoQHF51olb<S86oa0@40Oo0P82
1olO7al7ocHf=Pcooooo1onKVi/7ojb/[0OoUYJF1_l>3Ph7oaPH60OoCTi>1oo^k^h6odY:BPKooooo
3_lj>SX6oaTI6@Oo8b<S1oooool7o`l?3`Oo<c<c1_lb<S86ooooo`Oo51@D1_mRHV87og9bLPOooooo
1oo[jn/7oa8B4POoADE51_lC4a<>ooooo`003?ooool7ocdm?@OokNg]1om5ADD7oi^KV`Oo5ADE1_l4
10@7oa0@40KoJf][1_ooool7om3@d0Ool?3`1omADE47oi2@T0Oo71`L1_l51@D7o`/;2`Ko>SXj1_oo
ool7ob`/;0OoFe]K1ooLg=`7olK6aPKoADE51olK6a/7ohj>SPKo<30`1_ooool7ogmoO`Oo<c<c1olW
9bL7ofATI0KoADE51omTI6@7od];B`cooooo1ooQhN47ohF5Q@Oo<S8b1_l@4107o`820POo7alO1olf
=SH<ooooo`OoVi^K1on/[:`7oiJFUPKo3Ph>1olH61P7odi>CPOok^k^1_m:BTX6ooooo`ko>SXj1_lI
6AT7ob<S8`Oooooo1ol?3`l7oc<c<`Ko<S8b1_ooool7oa@D50KoHV9R1ombLW87ooooo`Oojn_[1olB
4Q87odE5A@Ko4a<C3_ooool000cooooo1olm?Cd7ong]k@OoADE51onKVi/7oaDE5@Ko10@41ol@4106
of][J`Kooooo1oo@d=07oo3`l0OoDE5A1on@T907oa`L70Ko1@D51ol;2`/6ocXj>PKooooo1ol/;2`7
oe]KF`Oog=cL1oo6a/H6odE5A@Oo6a/K1on>SXh6oc0`<0Kooooo1omoOgl7oc<c<`Oo9bLW1omTI6@6
odE5A@OoI6AT1om;Bd/<ooooo`OohN7Q1on5QHD7oc8b<PKo410@1ol20P87oalO7`Oo=SHf3?ooool7
oi^KV`Oo[:b/1onFUYH6o`h>3POo61PH1om>CTh7onk^kPKoBTY:1_ooool>ocXj>PKo6ATI1olS8b<7
ooooo`Oo3`l?1olc<c<6oc8b<PKooooo1olD51@6of9RHPOoLW9b1oooool7on_[j`Oo4Q8B1om5ADD6
oa<C4`kooooo000<ooooo`Oo?clo1oo/k>`7ob/[:`Oo[Jf]1ol30`<6oadM7@Oo0P821_mLG5`6oooo
o`OoalO71oo<c<`7od10@0OoMWIf1olI6AT6o`820POo61PH1_lj>SX6ooooo`OoDU9B1oo[jn/7ol71
`@OoKFe]1_l51@D7oaDE5@Oo5aLG1_lb<S86ooooo`OoDe=C1oln?Sh7o`0000Oo=3@d1_nm_Kd7ogYj
NPOoCDe=1_l`<306ooooo`OohN7Q1omiNGT7ochn?PKo6QXJ1ol30`<7oa`L70Oo>c/k1_obl_86oooo
o`OoOWin1oooool7oifMW@Ko1`L71olj>SX7ojRXZ0Oo_Kfm1_l`<306ooooo`Oo>c/k1olM7Ad6o`82
0POo<C4a1ooUiND7o`0000Oo;Bd]1_lP8206ooooo`Oo6a/K1_mNGUh7ogEeM@Ool_;b1ooBd]87o`P8
20OoB4Q81_lF5QH>ooooo`003?ooool7oclo?`Ook>c/1ol[:b/7ojf][@Oo0`<31_lM7Ad7o`820PKo
G5aL1_ooool7olO7a`Ooc<c<1om0@407ogIfMPOo6ATI1_l20P87oaPH60Ko>SXj1_ooool7oe9BDPOo
jn_[1oo1`L47ofe]K@Ko1@D51olE5AD7oaLG5`Ko<S8b1_ooool7oe=CD`Oo?Shn1ol00007oc@d=0Ko
_Kfm1omjNWX7ode=C@Ko<30`1_ooool7on7Qh@OoNGUi1oln?Sh6oaXJ6POo0`<31olL71`7oc/k>`Ko
l_;b1_ooool7oginOPOooooo1onMWId6o`L71`Oo>SXj1onXZ:P7okfm_@Ko<30`1_ooool7oc/k>`Oo
7AdM1_l20P87oc4a<@OoiNGU1ol00007obd];@Ko820P1_ooool7oa/K6`KoGUiN1omeMGD7oo;blPOo
d];B1ol820P7odQ8B0Ko5QHF3_ooool000cooooo1olo?cl7onc/k0Oo:b/[1on][Jd7o`<30`Ko7AdM
1ol20P86oeaLG0Kooooo1oo7alL7olc<c0Oo@4101omfMWH7oaTI6@Ko0P821olH61P6ocXj>PKooooo
1omBDU87on_[j`Oo`L711om]KFd6o`D51@Oo5ADE1olG5aL6oc8b<PKooooo1omCDe<7ochn?POo0000
1old=3@6okfm_@OoNWYj1om=CDd6oc0`<0Kooooo1ooQhN47ogUiN@Oo?Shn1_lJ6QX7o`<30`Oo71`L
1olk>c/6oo;blPKooooo1omnOWh7ooooo`OoWIfM1_l71`L7ocXj>POoZ:RX1onm_Kd6oc0`<0Kooooo
1olk>c/7oadM7@Ko0P821ola<C47onGUi@Oo00001ol];Bd6ob0P80Kooooo1olK6a/6oeiNGPOoMGEe
1oobl_87om;BdPOo20P81om8B4P6oaHF5Pkooooo000<ooooo`Oo?clo1oo/k>`7ob/[:`Oo[Jf]1ol3
0`<6oadM7@Oo0P821_mLG5`6ooooo`OoalO71oo<c<`7od10@0OoMWIf1olI6AT6o`820POo61PH1_lj
>SX6ooooo`OoDU9B1oo[jn/7ol71`@OoKFe]1_l51@D7oaDE5@Oo5aLG1_lb<S86ooooo`OoDe=C1oln
?Sh7o`0000Oo=3@d1_nm_Kd7ogYjNPOoCDe=1_l`<306ooooo`OohN7Q1omiNGT7ochn?PKo6QXJ1ol3
0`<7oa`L70Oo>c/k1_obl_86ooooo`OoOWin1oooool7oifMW@Ko1`L71olj>SX7ojRXZ0Oo_Kfm1_l`
<306ooooo`Oo>c/k1olM7Ad6o`820POo<C4a1ooUiND7o`0000Oo;Bd]1_lP8206ooooo`Oo6a/K1_mN
GUh7ogEeM@Ool_;b1ooBd]87o`P820OoB4Q81_lF5QH>ooooo`003?ooool7oclo?`Ook>c/1ol[:b/7
ojf][@Oo0`<31_lM7Ad7o`820PKoG5aL1_ooool7olO7a`Ooc<c<1om0@407ogIfMPOo6ATI1_l20P87
oaPH60Ko>SXj1_ooool7oe9BDPOojn_[1oo1`L47ofe]K@Ko1@D51olE5AD7oaLG5`Ko<S8b1_ooool7
oe=CD`Oo?Shn1ol00007oc@d=0Ko_Kfm1omjNWX7ode=C@Ko<30`1_ooool7on7Qh@OoNGUi1oln?Sh6
oaXJ6POo0`<31olL71`7oc/k>`Kol_;b1_ooool7oginOPOooooo1onMWId6o`L71`Oo>SXj1onXZ:P7
okfm_@Ko<30`1_ooool7oc/k>`Oo7AdM1_l20P87oc4a<@OoiNGU1ol00007obd];@Ko820P1_ooool7
oa/K6`KoGUiN1omeMGD7oo;blPOod];B1ol820P7odQ8B0Ko5QHF3_ooool000cooooo1olo?cl7onc/
k0Oo:b/[1on][Jd7o`<30`Ko7AdM1ol20P86oeaLG0Kooooo1oo7alL7olc<c0Oo@4101omfMWH7oaTI
6@Ko0P821olH61P6ocXj>PKooooo1omBDU87on_[j`Oo`L711om]KFd6o`D51@Oo5ADE1olG5aL6oc8b
<PKooooo1omCDe<7ochn?POo00001old=3@6okfm_@OoNWYj1om=CDd6oc0`<0Kooooo1ooQhN47ogUi
N@Oo?Shn1_lJ6QX7o`<30`Oo71`L1olk>c/6oo;blPKooooo1omnOWh7ooooo`OoWIfM1_l71`L7ocXj
>POoZ:RX1onm_Kd6oc0`<0Kooooo1olk>c/7oadM7@Ko0P821ola<C47onGUi@Oo00001ol];Bd6ob0P
80Kooooo1olK6a/6oeiNGPOoMGEe1oobl_87om;BdPOo20P81om8B4P6oaHF5Pkooooo000<ooooo`Oo
CDe=1oooool7oe1@D0OoW9bL1olP8206oa4A4@Oo410@1_mHF5P6ooooo`OofMWI1oo6a/H7odY:BPOo
OWin1ol=3@d6o`P820Oo5aLG1_m<C4`6ooooo`OoBDU91on3Ph<7onKViPOoX:2P1_lR8R87oc<c<`Oo
[Jf]1_lb<S86ooooo`OoLG5a1olB4Q87oc`l?0OoJ6QX1_m<C4`7oe5AD@OoAdM71_odm?@6ooooo`Oo
b/[:1omlO7`7od92@PKo7QhN1olK6a/7obPX:0OoC4a<1_oIfMT6ooooo`Oo[Jf]1onl_;`7ofYZJPKo
410@1om2@T87ogYjNPOoiNGU1_mTI6@6ooooo`Oo?Shn1ol];Bd6oaHF5POo@D511ooNg]h7o`D51@Oo
?3`l1_lf=SH6ooooo`Oo71`L1_mhN7P7ohj>SPOok>c/1onm_Kd7oaTI6@Oo@4101_lO7al>ooooo`00
3?ooool7ode=C@Oooooo1om@D507oibLW0Oo820P1_lA4A47oa0@40KoF5QH1_ooool7omWIf@Ooa/K6
1om:BTX7oginOPOo3@d=1_l820P7oaLG5`KoC4a<1_ooool7odU9B@OoPh>31ooVi^H7oj2PX0Ko8R8R
1olc<c<7ojf][@Ko<S8b1_ooool7og5aL@Oo4Q8B1oll?3`7ofQXJ0KoC4a<1omADE47odM7A`Kom?Cd
1_ooool7ol[:bPOoO7al1om2@T86oahN7POo6a/K1olX:2P7oda<C0KofMWI1_ooool7ojf][@Oo_;bl
1omZJVX6oa0@40Oo@T921omjNWX7onGUi@KoI6AT1_ooool7ochn?POo;Bd]1_lF5QH7od51@@Oog]kN
1ol51@D7oc`l?0Ko=SHf1_ooool7oa`L70KoN7Qh1on>SXh7onc/k0Oo_Kfm1olI6AT7od10@0Ko7alO
3_ooool000cooooo1om=CDd7ooooo`OoD51@1onLW9`7ob0P80Ko4A4A1ol@4106oeQHF0Kooooo1ooI
fMT7olK6aPOoBTY:1omnOWh7o`d=3@Ko20P81olG5aL6oda<C0Kooooo1om9BDT7oh>3P`Ooi^KV1onP
X:06ob8R8POo<c<c1on][Jd6oc8b<PKooooo1omaLG47oa8B4POo?3`l1omXJ6P6oda<C0OoDE5A1om7
AdL6ooCdm0Kooooo1oo:b/X7ogalO0Oo@T921_lN7Qh7oa/K6`Oo:2PX1om<C4`6omWIf@Kooooo1on]
[Jd7okbl_0OoJVYZ1_l@4107od92@POoNWYj1ooUiND6ofATI0Kooooo1oln?Sh7obd];@Ko5QHF1om1
@D47omkNgPOo1@D51oll?3`6ocHf=PKooooo1olL71`6ogQhN0OoSXj>1oo/k>`7okfm_@Oo6ATI1om0
@406oalO7`kooooo000<ooooo`OoCDe=1oooool7oe1@D0OoW9bL1olP8206oa4A4@Oo410@1_mHF5P6
ooooo`OofMWI1oo6a/H7odY:BPOoOWin1ol=3@d6o`P820Oo5aLG1_m<C4`6ooooo`OoBDU91on3Ph<7
onKViPOoX:2P1_lR8R87oc<c<`Oo[Jf]1_lb<S86ooooo`OoLG5a1olB4Q87oc`l?0OoJ6QX1_m<C4`7
oe5AD@OoAdM71_odm?@6ooooo`Oob/[:1omlO7`7od92@PKo7QhN1olK6a/7obPX:0OoC4a<1_oIfMT6
ooooo`Oo[Jf]1onl_;`7ofYZJPKo410@1om2@T87ogYjNPOoiNGU1_mTI6@6ooooo`Oo?Shn1ol];Bd6
oaHF5POo@D511ooNg]h7o`D51@Oo?3`l1_lf=SH6ooooo`Oo71`L1_mhN7P7ohj>SPOok>c/1onm_Kd7
oaTI6@Oo@4101_lO7al>ooooo`003?ooool7ode=C@Oooooo1om@D507oibLW0Oo820P1_lA4A47oa0@
40KoF5QH1_ooool7omWIf@Ooa/K61om:BTX7oginOPOo3@d=1_l820P7oaLG5`KoC4a<1_ooool7odU9
B@OoPh>31ooVi^H7oj2PX0Ko8R8R1olc<c<7ojf][@Ko<S8b1_ooool7og5aL@Oo4Q8B1oll?3`7ofQX
J0KoC4a<1omADE47odM7A`Kom?Cd1_ooool7ol[:bPOoO7al1om2@T86oahN7POo6a/K1olX:2P7oda<
C0KofMWI1_ooool7ojf][@Oo_;bl1omZJVX6oa0@40Oo@T921omjNWX7onGUi@KoI6AT1_ooool7ochn
?POo;Bd]1_lF5QH7od51@@Oog]kN1ol51@D7oc`l?0Ko=SHf1_ooool7oa`L70KoN7Qh1on>SXh7onc/
k0Oo_Kfm1olI6AT7od10@0Ko7alO3_ooool000cooooo1om=CDd7ooooo`OoD51@1onLW9`7ob0P80Ko
4A4A1ol@4106oeQHF0Kooooo1ooIfMT7olK6aPOoBTY:1omnOWh7o`d=3@Ko20P81olG5aL6oda<C0Ko
oooo1om9BDT7oh>3P`Ooi^KV1onPX:06ob8R8POo<c<c1on][Jd6oc8b<PKooooo1omaLG47oa8B4POo
?3`l1omXJ6P6oda<C0OoDE5A1om7AdL6ooCdm0Kooooo1oo:b/X7ogalO0Oo@T921_lN7Qh7oa/K6`Oo
:2PX1om<C4`6omWIf@Kooooo1on][Jd7okbl_0OoJVYZ1_l@4107od92@POoNWYj1ooUiND6ofATI0Ko
oooo1oln?Sh7obd];@Ko5QHF1om1@D47omkNgPOo1@D51oll?3`6ocHf=PKooooo1olL71`6ogQhN0Oo
SXj>1oo/k>`7okfm_@Oo6ATI1om0@406oalO7`kooooo000<ooooo`OoCDe=1oooool7oe1@D0OoW9bL
1olP8206oa4A4@Oo410@1_mHF5P6ooooo`OofMWI1oo6a/H7odY:BPOoOWin1ol=3@d6o`P820Oo5aLG
1_m<C4`6ooooo`OoBDU91on3Ph<7onKViPOoX:2P1_lR8R87oc<c<`Oo[Jf]1_lb<S86ooooo`OoLG5a
1olB4Q87oc`l?0OoJ6QX1_m<C4`7oe5AD@OoAdM71_odm?@6ooooo`Oob/[:1omlO7`7od92@PKo7QhN
1olK6a/7obPX:0OoC4a<1_oIfMT6ooooo`Oo[Jf]1onl_;`7ofYZJPKo410@1om2@T87ogYjNPOoiNGU
1_mTI6@6ooooo`Oo?Shn1ol];Bd6oaHF5POo@D511ooNg]h7o`D51@Oo?3`l1_lf=SH6ooooo`Oo71`L
1_mhN7P7ohj>SPOok>c/1onm_Kd7oaTI6@Oo@4101_lO7al>ooooo`003?ooool7odU9B@OobLW91olf
=SH7ohZ:RPOo4Q8B1_lV9RH7o`0000KoIFEU1_ooool7ok:b/POoV9RH1olh>3P7ofQXJ0Oo2@T91_l1
0@47oahN7PKo@4101_ooool7ogMgM`Oooooo1on][Jd7ocXj>PKo71`L1olQ8B47oaXJ6PKo>3Ph1_oo
ool7ocHf=POoA4A41ol61PH7ocXj>PKobl_;1omcLg<7oc@d=0Ko71`L1_ooool7okFe]@OoI6AT1old
=3@6obd];@Oo6QXJ1olc<c<7od92@PKobl_;1_ooool7ohb<S0Ooj>SX1ommOGd6o`d=3@OoD51@1oo7
alL7oj6QX@KoE5AD1_ooool7ocHf=POo4Q8B1_l;2`/7oc/k>`Oo/[:b1ol00007oc4a<@Ko7QhN1_oo
ool7ob<S8`KoJVYZ1omoOgl7olc<c0OoX:2P1olB4Q87oc8b<PKo7QhN3_ooool000cooooo1om9BDT7
olW9b@Oo=SHf1on:RXX7oa8B4PKo9RHV1ol00006ofEUI@Kooooo1onb/[87oiRHV0Oo>3Ph1omXJ6P7
o`T92@Ko0@411olN7Qh6od10@0Kooooo1omgMgL7ooooo`Oo[Jf]1olj>SX6oa`L70Oo8B4Q1olJ6QX6
ocPh>0Kooooo1olf=SH7odA4A0Oo1PH61olj>SX6ol_;b`OoLg=c1old=3@6oa`L70Kooooo1one]KD7
ofATI0Oo=3@d1_l];Bd7oaXJ6POo<c<c1om2@T86ol_;b`Kooooo1on<S8`7onSXj0OoOGem1_l=3@d7
oe1@D0OoalO71onQXJ46oeADE0Kooooo1olf=SH7oa8B4PKo2`/;1olk>c/7ok:b/POo00001ola<C46
oahN7PKooooo1olS8b<6ofYZJPOoOgmo1oo<c<`7oj2PX0Oo4Q8B1olb<S86oahN7Pkooooo000<oooo
o`OoBDU91oo9bLT7ocHf=POoRXZ:1olB4Q86obHV9POo00001_mUIFD6ooooo`Oo/[:b1onHV9P7ocPh
>0OoJ6QX1ol92@T6o`410@Oo7QhN1_m0@406ooooo`OoMgMg1oooool7ojf][@Oo>SXj1_lL71`7ob4Q
8@Oo6QXJ1_lh>3P6ooooo`Oo=SHf1om4A4@7o`H61POo>SXj1_o;bl/7og=cL`Oo=3@d1_lL71`6oooo
o`Oo]KFe1omTI6@7oc@d=0Ko;Bd]1olJ6QX7oc<c<`Oo@T921_o;bl/6ooooo`OoS8b<1ooXj>P7ogem
O@Ko3@d=1om@D507olO7a`OoXJ6Q1_mDE5@6ooooo`Oo=SHf1olB4Q86o`/;2`Oo>c/k1onb/[87o`00
00Oo<C4a1_lN7Qh6ooooo`Oo8b<S1_mZJVX7ogmoO`Ooc<c<1onPX:07oa8B4POo<S8b1_lN7Qh>oooo
o`003?ooool7odU9B@OobLW91olf=SH7ohZ:RPOo4Q8B1_lV9RH7o`0000KoIFEU1_ooool7ok:b/POo
V9RH1olh>3P7ofQXJ0Oo2@T91_l10@47oahN7PKo@4101_ooool7ogMgM`Oooooo1on][Jd7ocXj>PKo
71`L1olQ8B47oaXJ6PKo>3Ph1_ooool7ocHf=POoA4A41ol61PH7ocXj>PKobl_;1omcLg<7oc@d=0Ko
71`L1_ooool7okFe]@OoI6AT1old=3@6obd];@Oo6QXJ1olc<c<7od92@PKobl_;1_ooool7ohb<S0Oo
j>SX1ommOGd6o`d=3@OoD51@1oo7alL7oj6QX@KoE5AD1_ooool7ocHf=POo4Q8B1_l;2`/7oc/k>`Oo
/[:b1ol00007oc4a<@Ko7QhN1_ooool7ob<S8`KoJVYZ1omoOgl7olc<c0OoX:2P1olB4Q87oc8b<PKo
7QhN3_ooool000cooooo1om9BDT7olW9b@Oo=SHf1on:RXX7oa8B4PKo9RHV1ol00006ofEUI@Kooooo
1onb/[87oiRHV0Oo>3Ph1omXJ6P7o`T92@Ko0@411olN7Qh6od10@0Kooooo1omgMgL7ooooo`Oo[Jf]
1olj>SX6oa`L70Oo8B4Q1olJ6QX6ocPh>0Kooooo1olf=SH7odA4A0Oo1PH61olj>SX6ol_;b`OoLg=c
1old=3@6oa`L70Kooooo1one]KD7ofATI0Oo=3@d1_l];Bd7oaXJ6POo<c<c1om2@T86ol_;b`Kooooo
1on<S8`7onSXj0OoOGem1_l=3@d7oe1@D0OoalO71onQXJ46oeADE0Kooooo1olf=SH7oa8B4PKo2`/;
1olk>c/7ok:b/POo00001ola<C46oahN7PKooooo1olS8b<6ofYZJPOoOgmo1oo<c<`7oj2PX0Oo4Q8B
1olb<S86oahN7Pkooooo000<ooooo`OoBDU91oo9bLT7ocHf=POoRXZ:1olB4Q86obHV9POo00001_mU
IFD6ooooo`Oo/[:b1onHV9P7ocPh>0OoJ6QX1ol92@T6o`410@Oo7QhN1_m0@406ooooo`OoMgMg1ooo
ool7ojf][@Oo>SXj1_lL71`7ob4Q8@Oo6QXJ1_lh>3P6ooooo`Oo=SHf1om4A4@7o`H61POo>SXj1_o;
bl/7og=cL`Oo=3@d1_lL71`6ooooo`Oo]KFe1omTI6@7oc@d=0Ko;Bd]1olJ6QX7oc<c<`Oo@T921_o;
bl/6ooooo`OoS8b<1ooXj>P7ogemO@Ko3@d=1om@D507olO7a`OoXJ6Q1_mDE5@6ooooo`Oo=SHf1olB
4Q86o`/;2`Oo>c/k1onb/[87o`0000Oo<C4a1_lN7Qh6ooooo`Oo8b<S1_mZJVX7ogmoO`Ooc<c<1onP
X:07oa8B4POo<S8b1_lN7Qh>ooooo`003?ooool7odU9B@OobLW91olf=SH7ohZ:RPOo4Q8B1_lV9RH7
o`0000KoIFEU1_ooool7ok:b/POoV9RH1olh>3P7ofQXJ0Oo2@T91_l10@47oahN7PKo@4101_ooool7
ogMgM`Oooooo1on][Jd7ocXj>PKo71`L1olQ8B47oaXJ6PKo>3Ph1_ooool7ocHf=POoA4A41ol61PH7
ocXj>PKobl_;1omcLg<7oc@d=0Ko71`L1_ooool7okFe]@OoI6AT1old=3@6obd];@Oo6QXJ1olc<c<7
od92@PKobl_;1_ooool7ohb<S0Ooj>SX1ommOGd6o`d=3@OoD51@1oo7alL7oj6QX@KoE5AD1_ooool7
ocHf=POo4Q8B1_l;2`/7oc/k>`Oo/[:b1ol00007oc4a<@Ko7QhN1_ooool7ob<S8`KoJVYZ1omoOgl7
olc<c0OoX:2P1olB4Q87oc8b<PKo7QhN3_ooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool000cooooo1ola<C47obTY:@Oo
5QHF1ol=3@d7oc8b<PKoDe=C1oo@d=06ofEUI@Kooooo1ooNg]h7od];B`OoE5AD1olS8b<7ocdm?@Ko
7AdM1old=3@6oa8B4PKooooo1olV9RH7ob8R8POo7alO1oo5aLD6odE5A@Oo3Ph>1olD51@6obDU9@Ko
oooo1oll?3`7obd];@Oo3@d=1om9BDT6ocPh>0Oo410@1onb/[86ocTi>@Kooooo1olO7al7o``<30Oo
6a/K1_lO7al7oaLG5`Oo3@d=1olB4Q86om?Cd`Kooooo1olE5AD7oc<c<`Ooa<C41_lf=SH7oclo?`Oo
@d=31olT92@6ocHf=PKooooo1olg=cL7o`P820Ko410@1omZJVX7ojBTY0OoR8R81olc<c<6oginOPKo
oooo1ooEeMD6obh^;POo>SXj1olN7Qh7obXZ:POoATI61om`L706oe]KF`kooooo000<ooooo`Oo<C4a
1olY:BT7oaHF5POo3@d=1olb<S86oe=CD`Ood=3@1_mUIFD6ooooo`Oog]kN1om;Bd/7oeADE0Oo8b<S
1olm?Cd6oadM7@Oo=3@d1_lB4Q86ooooo`Oo9RHV1olR8R87oalO7`OoaLG51_m5ADD7o`h>3POo51@D
1_lU9BD6ooooo`Oo?3`l1ol];Bd7o`d=3@OoBDU91_lh>3P7oa0@40Oo/[:b1_li>CT6ooooo`Oo7alO
1ol<30`7oa/K6`Ko7alO1olG5aL7o`d=3@Oo4Q8B1_oCdm<6ooooo`Oo5ADE1olc<c<7olC4a0Ko=SHf
1olo?cl7od=3@`Oo92@T1_lf=SH6ooooo`Oo=cLg1ol820P6oa0@40OoJVYZ1onTY:@7ohR8R0Oo<c<c
1_mnOWh6ooooo`OoeMGE1_l^;Rh7ocXj>POo7QhN1olZ:RX7odI6APOoL71`1_mKFe/>ooooo`003?oo
ool7oc4a<@Oo:BTY1olF5QH7o`d=3@Oo<S8b1_mCDe<7om3@d0KoIFEU1_ooool7omkNgPOoBd];1omD
E5@7ob<S8`Oo?Cdm1_lM7Ad7oc@d=0Ko4Q8B1_ooool7obHV9POo8R8R1olO7al7olG5a@KoADE51ol>
3Ph7oa@D50Ko9BDU1_ooool7oc`l?0Oo;Bd]1ol=3@d7odU9B@Ko>3Ph1ol@4107ok:b/PKo>CTi1_oo
ool7oalO7`Oo30`<1olK6a/6oalO7`Oo5aLG1ol=3@d7oa8B4PKodm?C1_ooool7oaDE5@Oo<c<c1oo4
a<@6ocHf=POo?clo1om3@d<7ob@T90Ko=SHf1_ooool7ocLg=`Oo20P81_l@4107ofYZJPOoY:BT1on8
R8P7oc<c<`KoOWin1_ooool7omGEe@Ko;Rh^1olj>SX7oahN7POo:RXZ1om6ATH7og1`L0KoFe]K3_oo
ool000cooooo1ola<C47obTY:@Oo5QHF1ol=3@d7oc8b<PKoDe=C1oo@d=06ofEUI@Kooooo1ooNg]h7
od];B`OoE5AD1olS8b<7ocdm?@Ko7AdM1old=3@6oa8B4PKooooo1olV9RH7ob8R8POo7alO1oo5aLD6
odE5A@Oo3Ph>1olD51@6obDU9@Kooooo1oll?3`7obd];@Oo3@d=1om9BDT6ocPh>0Oo410@1onb/[86
ocTi>@Kooooo1olO7al7o``<30Oo6a/K1_lO7al7oaLG5`Oo3@d=1olB4Q86om?Cd`Kooooo1olE5AD7
oc<c<`Ooa<C41_lf=SH7oclo?`Oo@d=31olT92@6ocHf=PKooooo1olg=cL7o`P820Ko410@1omZJVX7
ojBTY0OoR8R81olc<c<6oginOPKooooo1ooEeMD6obh^;POo>SXj1olN7Qh7obXZ:POoATI61om`L706
oe]KF`kooooo000<ooooo`Oo<C4a1olY:BT7oaHF5POo3@d=1olb<S86oe=CD`Ood=3@1_mUIFD6oooo
o`Oog]kN1om;Bd/7oeADE0Oo8b<S1olm?Cd6oadM7@Oo=3@d1_lB4Q86ooooo`Oo9RHV1olR8R87oalO
7`OoaLG51_m5ADD7o`h>3POo51@D1_lU9BD6ooooo`Oo?3`l1ol];Bd7o`d=3@OoBDU91_lh>3P7oa0@
40Oo/[:b1_li>CT6ooooo`Oo7alO1ol<30`7oa/K6`Ko7alO1olG5aL7o`d=3@Oo4Q8B1_oCdm<6oooo
o`Oo5ADE1olc<c<7olC4a0Ko=SHf1olo?cl7od=3@`Oo92@T1_lf=SH6ooooo`Oo=cLg1ol820P6oa0@
40OoJVYZ1onTY:@7ohR8R0Oo<c<c1_mnOWh6ooooo`OoeMGE1_l^;Rh7ocXj>POo7QhN1olZ:RX7odI6
APOoL71`1_mKFe/>ooooo`003?ooool7oc4a<@Oo:BTY1olF5QH7o`d=3@Oo<S8b1_mCDe<7om3@d0Ko
IFEU1_ooool7omkNgPOoBd];1omDE5@7ob<S8`Oo?Cdm1_lM7Ad7oc@d=0Ko4Q8B1_ooool7obHV9POo
8R8R1olO7al7olG5a@KoADE51ol>3Ph7oa@D50Ko9BDU1_ooool7oc`l?0Oo;Bd]1ol=3@d7odU9B@Ko
>3Ph1ol@4107ok:b/PKo>CTi1_ooool7oalO7`Oo30`<1olK6a/6oalO7`Oo5aLG1ol=3@d7oa8B4PKo
dm?C1_ooool7oaDE5@Oo<c<c1oo4a<@6ocHf=POo?clo1om3@d<7ob@T90Ko=SHf1_ooool7ocLg=`Oo
20P81_l@4107ofYZJPOoY:BT1on8R8P7oc<c<`KoOWin1_ooool7omGEe@Ko;Rh^1olj>SX7oahN7POo
:RXZ1om6ATH7og1`L0KoFe]K3_ooool000cooooo1ola<C47obTY:@Oo5QHF1ol=3@d7oc8b<PKoDe=C
1oo@d=06ofEUI@Kooooo1ooNg]h7od];B`OoE5AD1olS8b<7ocdm?@Ko7AdM1old=3@6oa8B4PKooooo
1olV9RH7ob8R8POo7alO1oo5aLD6odE5A@Oo3Ph>1olD51@6obDU9@Kooooo1oll?3`7obd];@Oo3@d=
1om9BDT6ocPh>0Oo410@1onb/[86ocTi>@Kooooo1olO7al7o``<30Oo6a/K1_lO7al7oaLG5`Oo3@d=
1olB4Q86om?Cd`Kooooo1olE5AD7oc<c<`Ooa<C41_lf=SH7oclo?`Oo@d=31olT92@6ocHf=PKooooo
1olg=cL7o`P820Ko410@1omZJVX7ojBTY0OoR8R81olc<c<6oginOPKooooo1ooEeMD6obh^;POo>SXj
1olN7Qh7obXZ:POoATI61om`L706oe]KF`kooooo000<ooooo`Oo<30`1olN7Qh7oaTI6@Oo30`<1olU
9BD6odm?C`OogmoO1_miNGT6ooooo`Oo_[jn3_lk>c/7obDU9@Oo>3Ph1_lb<S87obXZ:PKo10@41_oo
ool7obl_;`Oo61PH1olN7Qh7on?Sh`Ko=CDe1olF5QH7oa0@40Ko3`l?1_ooool7obHV9POo:RXZ1ol8
20P7odQ8B0Ko8R8R1olB4Q87oj^[Z`Ko:2PX1_ooool7oaPH60Oo30`<1olA4A4=ob4Q8@Oo6ATI1ol=
3@d6ooclo0Kooooo1ol<30`7ocHf=POof][J1_lF5QH7oc/k>`Oo?Shn1olK6a/6obDU9@Kooooo1omW
IfL7o`410@KoG5aL1onn_[h7ojBTY0OoADE51olO7al<ooooo`Ool?3`1_lE5AD7oc<c<`Oo6a/K1olc
<c<7ochn?POoNGUi1_mKFe/>ooooo`003?ooool7oc0`<0Oo7QhN1olI6AT7o``<30Oo9BDU1_m?Cdl7
omoOg`KoNGUi1_ooool7okjn_Pko>c/k1olU9BD7ocPh>0Ko<S8b1olZ:RX6o`@410Kooooo1ol_;bl7
oaPH60Oo7QhN1ooShn<6ocDe=@Oo5QHF1ol@4106o`l?3`Kooooo1olV9RH7obXZ:POo20P81om8B4P6
ob8R8POo4Q8B1on[Zj/6obPX:0Kooooo1olH61P7o``<30Oo4A4A3OlQ8B47oaTI6@Oo3@d=1_olo?`6
ooooo`Oo30`<1olf=SH7om[JfPKo5QHF1olk>c/7ochn?POo6a/K1_lU9BD6ooooo`OoIfMW1ol10@46
oeaLG0Oo_[jn1onTY:@7odE5A@Oo7alO3?ooool7oo3`l0Ko5ADE1olc<c<7oa/K6`Oo<c<c1oln?Sh7
ogUiN@KoFe]K3_ooool000cooooo1ol`<307oahN7POo6ATI1ol<30`7obDU9@KoCdm?1ooOgml6ogUi
N@Kooooo1onn_[h>oc/k>`Oo9BDU1olh>3P6oc8b<POo:RXZ1_l410@6ooooo`Oo;bl_1olH61P7oahN
7POohn?S1_le=CD7oaHF5POo410@1_l?3`l6ooooo`Oo9RHV1olZ:RX7o`P820OoB4Q81_lR8R87oa8B
4POoZj^[1_lX:2P6ooooo`Oo61PH1ol<30`7oa4A4@go8B4Q1olI6AT7o`d=3@Koo?cl1_ooool7o``<
30Oo=SHf1ooJf]X6oaHF5POo>c/k1oln?Sh7oa/K6`Ko9BDU1_ooool7ofMWI`Oo0@411_mLG5`7okjn
_POoY:BT1om5ADD7oalO7`cooooo1oo`l?06oaDE5@Oo<c<c1olK6a/7oc<c<`Oo?Shn1omiNGT6oe]K
F`kooooo000<ooooo`Oo<30`1olN7Qh7oaTI6@Oo30`<1olU9BD6odm?C`OogmoO1_miNGT6ooooo`Oo
_[jn3_lk>c/7obDU9@Oo>3Ph1_lb<S87obXZ:PKo10@41_ooool7obl_;`Oo61PH1olN7Qh7on?Sh`Ko
=CDe1olF5QH7oa0@40Ko3`l?1_ooool7obHV9POo:RXZ1ol820P7odQ8B0Ko8R8R1olB4Q87oj^[Z`Ko
:2PX1_ooool7oaPH60Oo30`<1olA4A4=ob4Q8@Oo6ATI1ol=3@d6ooclo0Kooooo1ol<30`7ocHf=POo
f][J1_lF5QH7oc/k>`Oo?Shn1olK6a/6obDU9@Kooooo1omWIfL7o`410@KoG5aL1onn_[h7ojBTY0Oo
ADE51olO7al<ooooo`Ool?3`1_lE5AD7oc<c<`Oo6a/K1olc<c<7ochn?POoNGUi1_mKFe/>ooooo`00
3?ooool7oc0`<0Oo7QhN1olI6AT7o``<30Oo9BDU1_m?Cdl7omoOg`KoNGUi1_ooool7okjn_Pko>c/k
1olU9BD7ocPh>0Ko<S8b1olZ:RX6o`@410Kooooo1ol_;bl7oaPH60Oo7QhN1ooShn<6ocDe=@Oo5QHF
1ol@4106o`l?3`Kooooo1olV9RH7obXZ:POo20P81om8B4P6ob8R8POo4Q8B1on[Zj/6obPX:0Kooooo
1olH61P7o``<30Oo4A4A3OlQ8B47oaTI6@Oo3@d=1_olo?`6ooooo`Oo30`<1olf=SH7om[JfPKo5QHF
1olk>c/7ochn?POo6a/K1_lU9BD6ooooo`OoIfMW1ol10@46oeaLG0Oo_[jn1onTY:@7odE5A@Oo7alO
3?ooool7oo3`l0Ko5ADE1olc<c<7oa/K6`Oo<c<c1oln?Sh7ogUiN@KoFe]K3_ooool000cooooo1ol`
<307oahN7POo6ATI1ol<30`7obDU9@KoCdm?1ooOgml6ogUiN@Kooooo1onn_[h>oc/k>`Oo9BDU1olh
>3P6oc8b<POo:RXZ1_l410@6ooooo`Oo;bl_1olH61P7oahN7POohn?S1_le=CD7oaHF5POo410@1_l?
3`l6ooooo`Oo9RHV1olZ:RX7o`P820OoB4Q81_lR8R87oa8B4POoZj^[1_lX:2P6ooooo`Oo61PH1ol<
30`7oa4A4@go8B4Q1olI6AT7o`d=3@Koo?cl1_ooool7o``<30Oo=SHf1ooJf]X6oaHF5POo>c/k1oln
?Sh7oa/K6`Ko9BDU1_ooool7ofMWI`Oo0@411_mLG5`7okjn_POoY:BT1om5ADD7oalO7`cooooo1oo`
l?06oaDE5@Oo<c<c1olK6a/7oc<c<`Oo?Shn1omiNGT6oe]KF`kooooo000<ooooo`Oo<30`1olN7Qh7
oaTI6@Oo30`<1olU9BD6odm?C`OogmoO1_miNGT6ooooo`Oo_[jn3_lk>c/7obDU9@Oo>3Ph1_lb<S87
obXZ:PKo10@41_ooool7obl_;`Oo61PH1olN7Qh7on?Sh`Ko=CDe1olF5QH7oa0@40Ko3`l?1_ooool7
obHV9POo:RXZ1ol820P7odQ8B0Ko8R8R1olB4Q87oj^[Z`Ko:2PX1_ooool7oaPH60Oo30`<1olA4A4=
ob4Q8@Oo6ATI1ol=3@d6ooclo0Kooooo1ol<30`7ocHf=POof][J1_lF5QH7oc/k>`Oo?Shn1olK6a/6
obDU9@Kooooo1omWIfL7o`410@KoG5aL1onn_[h7ojBTY0OoADE51olO7al<ooooo`Ool?3`1_lE5AD7
oc<c<`Oo6a/K1olc<c<7ochn?POoNGUi1_mKFe/>ooooo`003?ooool7ob@T90Oo71`L1ol<30`7o`<3
0`Oo:b/[1_m<C4`7oo7al@KoJVYZ1_ooool7ooWin@Oo@D511olo?cl7ob0P80Oo>3Ph1_lM7Ad7obTY
:@Ko1`L71_ooool7obDU9@ko820P1ooRh^86ocHf=POo2`/;1ol820P6oa4A4@Kooooo1olc<c<7ob4Q
8@Oo1PH61omJFUX6oaXJ6POo1`L71ooPh>06oc`l?0Kooooo1olI6AT7o`@410Oo6a/K1_lL71`>oaPH
60Oo5aLG3?ooool7oaHF5POo>CTi1ooclo<6oaXJ6POoB4Q81om9BDT7oaHF5PKo;Bd]1_ooool7oa/K
6`Oo2@T91_lQ8B47oi>CT`OoYJFU1omhN7P7ob4Q8@KoNGUi1_ooool7ooGem@Ko6ATI1om2@T87oa/K
6`Oo;Rh^1om6ATH7ogUiN@KoNg]k3_ooool000cooooo1olT92@7oa`L70Oo30`<1ol30`<7ob/[:`Ko
C4a<1ooalO46ofYZJPKooooo1ooinOT7od51@@Oo?clo1olP8207ocPh>0Ko7AdM1olY:BT6o`L71`Ko
oooo1olU9BD>ob0P80Ooh^;R1_lf=SH7o`/;2`Oo20P81_lA4A46ooooo`Oo<c<c1olQ8B47o`H61POo
FUYJ1_lJ6QX7o`L71`Ooh>3P1_ll?3`6ooooo`Oo6ATI1ol410@7oa/K6`Ko71`L3_lH61P7oaLG5`co
oooo1olF5QH7ocTi>@Oolo?c1_lJ6QX7odQ8B0OoBDU91olF5QH6obd];@Kooooo1olK6a/7o`T92@Ko
8B4Q1onCTi<7ojFUY@OoN7Qh1olQ8B46ogUiN@Kooooo1ooemOD6oaTI6@Oo@T921olK6a/7obh^;POo
ATI61omiNGT6og]kN`kooooo000<ooooo`Oo92@T1olL71`7o``<30Oo0`<31ol[:b/6oda<C0OolO7a
1_mZJVX6ooooo`OonOWi1om1@D47oclo?`Oo820P1olh>3P6oadM7@Oo:BTY1_l71`L6ooooo`Oo9BDU
3_lP8207on;RhPKo=SHf1ol;2`/7o`P820Ko4A4A1_ooool7oc<c<`Oo8B4Q1ol61PH7oeYJFPKo6QXJ
1ol71`L7on3Ph0Ko?3`l1_ooool7oaTI6@Oo10@41olK6a/6oa`L70ko61PH1olG5aL<ooooo`Oo5QHF
1oli>CT7oo?cl`Ko6QXJ1om8B4P7odU9B@Oo5QHF1_l];Bd6ooooo`Oo6a/K1ol92@T6ob4Q8@OoTi>C
1onUYJD7ogQhN0Oo8B4Q1_miNGT6ooooo`OomOGe1_lI6AT7od92@POo6a/K1ol^;Rh7odI6APOoNGUi
1_mkNg/>ooooo`003?ooool7ob@T90Oo71`L1ol<30`7o`<30`Oo:b/[1_m<C4`7oo7al@KoJVYZ1_oo
ool7ooWin@Oo@D511olo?cl7ob0P80Oo>3Ph1_lM7Ad7obTY:@Ko1`L71_ooool7obDU9@ko820P1ooR
h^86ocHf=POo2`/;1ol820P6oa4A4@Kooooo1olc<c<7ob4Q8@Oo1PH61omJFUX6oaXJ6POo1`L71ooP
h>06oc`l?0Kooooo1olI6AT7o`@410Oo6a/K1_lL71`>oaPH60Oo5aLG3?ooool7oaHF5POo>CTi1ooc
lo<6oaXJ6POoB4Q81om9BDT7oaHF5PKo;Bd]1_ooool7oa/K6`Oo2@T91_lQ8B47oi>CT`OoYJFU1omh
N7P7ob4Q8@KoNGUi1_ooool7ooGem@Ko6ATI1om2@T87oa/K6`Oo;Rh^1om6ATH7ogUiN@KoNg]k3_oo
ool000cooooo1olT92@7oa`L70Oo30`<1ol30`<7ob/[:`KoC4a<1ooalO46ofYZJPKooooo1ooinOT7
od51@@Oo?clo1olP8207ocPh>0Ko7AdM1olY:BT6o`L71`Kooooo1olU9BD>ob0P80Ooh^;R1_lf=SH7
o`/;2`Oo20P81_lA4A46ooooo`Oo<c<c1olQ8B47o`H61POoFUYJ1_lJ6QX7o`L71`Ooh>3P1_ll?3`6
ooooo`Oo6ATI1ol410@7oa/K6`Ko71`L3_lH61P7oaLG5`cooooo1olF5QH7ocTi>@Oolo?c1_lJ6QX7
odQ8B0OoBDU91olF5QH6obd];@Kooooo1olK6a/7o`T92@Ko8B4Q1onCTi<7ojFUY@OoN7Qh1olQ8B46
ogUiN@Kooooo1ooemOD6oaTI6@Oo@T921olK6a/7obh^;POoATI61omiNGT6og]kN`kooooo000<oooo
o`Oo92@T1olL71`7o``<30Oo0`<31ol[:b/6oda<C0OolO7a1_mZJVX6ooooo`OonOWi1om1@D47oclo
?`Oo820P1olh>3P6oadM7@Oo:BTY1_l71`L6ooooo`Oo9BDU3_lP8207on;RhPKo=SHf1ol;2`/7o`P8
20Ko4A4A1_ooool7oc<c<`Oo8B4Q1ol61PH7oeYJFPKo6QXJ1ol71`L7on3Ph0Ko?3`l1_ooool7oaTI
6@Oo10@41olK6a/6oa`L70ko61PH1olG5aL<ooooo`Oo5QHF1oli>CT7oo?cl`Ko6QXJ1om8B4P7odU9
B@Oo5QHF1_l];Bd6ooooo`Oo6a/K1ol92@T6ob4Q8@OoTi>C1onUYJD7ogQhN0Oo8B4Q1_miNGT6oooo
o`OomOGe1_lI6AT7od92@POo6a/K1ol^;Rh7odI6APOoNGUi1_mkNg/>ooooo`003?ooool7obLW9`Oo
6QXJ1ol>3Ph7o`@410Oo9RHV1_mBDU87ooooo`KoL71`1_ooool7om[JfPOo;Bd]1ola<C47oadM7@Oo
<C4a1_lj>SX7obPX:0Ko00001_ooool7obl_;`Oo51@D1olI6AT7ooooo`Ko;2`/1ol820P7o`d=3@Ko
1`L71_ooool7ob@T90Oo8R8R1olA4A47odm?C`Ko3`l?1olF5QH7onOWi`Ko<S8b1_ooool7oa8B4POo
2@T91ol>3Ph6ob8R8POo9RHV1olM7Ad7oa@D50KobLW91_ooool7oa@D50Oo@T921oojn_X6o`L71`Oo
@d=31oll?3`7oa<C4`Ko9BDU1_ooool7od51@@Oo00001_n9RHT7okRh^0OoUYJF1olY:BT7oaDE5@Ko
oOgm3Oooool6o`0000Oo=SHf1olR8R87od51@@OoA4A41omjNWX6ogIfMPkooooo000<ooooo`Oo9bLW
1olJ6QX7o`h>3POo10@41olV9RH6oe9BDPOooooo1_m`L706ooooo`Oof][J1ol];Bd7oc4a<@Oo7AdM
1ola<C46ocXj>POo:2PX1_l00006ooooo`Oo;bl_1olD51@7oaTI6@Oooooo1_l/;2`7o`P820Oo3@d=
1_l71`L6ooooo`Oo92@T1olR8R87oa4A4@OoCdm?1_l?3`l7oaHF5POoinOW1_lb<S86ooooo`Oo4Q8B
1ol92@T7o`h>3PKo8R8R1olV9RH7oadM7@Oo51@D1_o9bLT6ooooo`Oo51@D1om2@T87oo[jnPKo1`L7
1om3@d<7oc`l?0Oo4a<C1_lU9BD6ooooo`Oo@D511ol00006ohV9R@Oo^;Rh1onFUYH7obTY:@Oo5ADE
1_omoOd=ooooo`Ko00001olf=SH7ob8R8POo@D511om4A4@7ogYjNPKoMWIf3_ooool000cooooo1olW
9bL7oaXJ6POo3Ph>1ol410@7obHV9PKoDU9B1oooool6og1`L0Kooooo1ooJf]X7obd];@Oo<C4a1olM
7Ad7oc4a<@Ko>SXj1olX:2P6o`0000Kooooo1ol_;bl7oa@D50Oo6ATI1oooool6ob`/;0Oo20P81ol=
3@d6o`L71`Kooooo1olT92@7ob8R8POo4A4A1om?Cdl6o`l?3`Oo5QHF1ooWinL6oc8b<PKooooo1olB
4Q87o`T92@Oo3Ph>1_lR8R87obHV9POo7AdM1olD51@6olW9b@Kooooo1olD51@7od92@POon_[j1_l7
1`L7od=3@`Oo?3`l1olC4a<6obDU9@Kooooo1om1@D47o`0000KoRHV91onh^;P7oiJFUPOo:BTY1olE
5AD6oogmo@gooooo1_l00007ocHf=POo8R8R1om1@D47odA4A0OoNWYj1_mfMWH>ooooo`003?ooool7
obLW9`Oo6QXJ1ol>3Ph7o`@410Oo9RHV1_mBDU87ooooo`KoL71`1_ooool7om[JfPOo;Bd]1ola<C47
oadM7@Oo<C4a1_lj>SX7obPX:0Ko00001_ooool7obl_;`Oo51@D1olI6AT7ooooo`Ko;2`/1ol820P7
o`d=3@Ko1`L71_ooool7ob@T90Oo8R8R1olA4A47odm?C`Ko3`l?1olF5QH7onOWi`Ko<S8b1_ooool7
oa8B4POo2@T91ol>3Ph6ob8R8POo9RHV1olM7Ad7oa@D50KobLW91_ooool7oa@D50Oo@T921oojn_X6
o`L71`Oo@d=31oll?3`7oa<C4`Ko9BDU1_ooool7od51@@Oo00001_n9RHT7okRh^0OoUYJF1olY:BT7
oaDE5@KooOgm3Oooool6o`0000Oo=SHf1olR8R87od51@@OoA4A41omjNWX6ogIfMPkooooo000<oooo
o`Oo9bLW1olJ6QX7o`h>3POo10@41olV9RH6oe9BDPOooooo1_m`L706ooooo`Oof][J1ol];Bd7oc4a
<@Oo7AdM1ola<C46ocXj>POo:2PX1_l00006ooooo`Oo;bl_1olD51@7oaTI6@Oooooo1_l/;2`7o`P8
20Oo3@d=1_l71`L6ooooo`Oo92@T1olR8R87oa4A4@OoCdm?1_l?3`l7oaHF5POoinOW1_lb<S86oooo
o`Oo4Q8B1ol92@T7o`h>3PKo8R8R1olV9RH7oadM7@Oo51@D1_o9bLT6ooooo`Oo51@D1om2@T87oo[j
nPKo1`L71om3@d<7oc`l?0Oo4a<C1_lU9BD6ooooo`Oo@D511ol00006ohV9R@Oo^;Rh1onFUYH7obTY
:@Oo5ADE1_omoOd=ooooo`Ko00001olf=SH7ob8R8POo@D511om4A4@7ogYjNPKoMWIf3_ooool000co
oooo1olW9bL7oaXJ6POo3Ph>1ol410@7obHV9PKoDU9B1oooool6og1`L0Kooooo1ooJf]X7obd];@Oo
<C4a1olM7Ad7oc4a<@Ko>SXj1olX:2P6o`0000Kooooo1ol_;bl7oa@D50Oo6ATI1oooool6ob`/;0Oo
20P81ol=3@d6o`L71`Kooooo1olT92@7ob8R8POo4A4A1om?Cdl6o`l?3`Oo5QHF1ooWinL6oc8b<PKo
oooo1olB4Q87o`T92@Oo3Ph>1_lR8R87obHV9POo7AdM1olD51@6olW9b@Kooooo1olD51@7od92@POo
n_[j1_l71`L7od=3@`Oo?3`l1olC4a<6obDU9@Kooooo1om1@D47o`0000KoRHV91onh^;P7oiJFUPOo
:BTY1olE5AD6oogmo@gooooo1_l00007ocHf=POo8R8R1om1@D47odA4A0OoNWYj1_mfMWH>ooooo`00
3?ooool7obLW9`Oo6QXJ1ol>3Ph7o`@410Oo9RHV1_mBDU87ooooo`KoL71`1_ooool7om[JfPOo;Bd]
1ola<C47oadM7@Oo<C4a1_lj>SX7obPX:0Ko00001_ooool7obl_;`Oo51@D1olI6AT7ooooo`Ko;2`/
1ol820P7o`d=3@Ko1`L71_ooool7ob@T90Oo8R8R1olA4A47odm?C`Ko3`l?1olF5QH7onOWi`Ko<S8b
1_ooool7oa8B4POo2@T91ol>3Ph6ob8R8POo9RHV1olM7Ad7oa@D50KobLW91_ooool7oa@D50Oo@T92
1oojn_X6o`L71`Oo@d=31oll?3`7oa<C4`Ko9BDU1_ooool7od51@@Oo00001_n9RHT7okRh^0OoUYJF
1olY:BT7oaDE5@KooOgm3Oooool6o`0000Oo=SHf1olR8R87od51@@OoA4A41omjNWX6ogIfMPkooooo
000<ooooo`Oo8B4Q1olA4A47o`P820Oo00001olV9RH6od];B`OomOGe1_mUIFD=ooooo`Oo;Bd]1olc
<c<7ob@T90Oo<c<c3Ol];Bd6oaHF5PKooooo3_lV9RH7obPX:0OoiNGU1_l[:b/7o`L71`Oo20P81_l9
2@T6ooooo`Oo:RXZ1olI6AT7oa4A4@OoDE5A1_l;2`/7oa`L70Oooooo1_m2@T86ooooo`Oo61PH1ol7
1`L7oa8B4PKo820P1olY:BT7oaXJ6POo51@D1_nATI46ooooo`Oo71`L1om?Cdl7ooooo`Ko10@41om<
C4`7odU9B@Oo3Ph>1_lM7Ad6ooooo`Oo410@1ol51@D6od];B`Oo^KVi1onIVIT7oeYJFPOo6ATI1_ma
LG46ooooo`Ool?3`1_l71`L7od51@@Oo6QXJ1olg=cL7odM7A`OoNWYj1_nLW9`>ooooo`003?ooool7
ob4Q8@Oo4A4A1ol820P7o`0000Oo9RHV1_m;Bd/7ooGem@KoIFEU3Oooool7obd];@Oo<c<c1olT92@7
oc<c<`go;Bd]1_lF5QH6ooooo`ko9RHV1olX:2P7onGUi@Ko:b/[1ol71`L7o`P820Ko2@T91_ooool7
obXZ:POo6ATI1olA4A47oe5AD@Ko2`/;1olL71`7ooooo`Ko@T921_ooool7oaPH60Oo1`L71olB4Q86
ob0P80Oo:BTY1olJ6QX7oa@D50KoTI6A1_ooool7oa`L70OoCdm?1oooool6o`@410OoC4a<1om9BDT7
o`h>3PKo7AdM1_ooool7oa0@40Oo1@D51_m;Bd/7okVi^@OoVIVI1omJFUX7oaTI6@KoLG5a1_ooool7
oo3`l0Ko1`L71om1@D47oaXJ6POo=cLg1om7AdL7ogYjNPKoW9bL3_ooool000cooooo1olQ8B47oa4A
4@Oo20P81ol00007obHV9PKoBd];1ooemOD6ofEUI@gooooo1ol];Bd7oc<c<`Oo92@T1olc<c<=obd]
;@Ko5QHF1_ooool>obHV9POo:2PX1ooUiND6ob/[:`Oo1`L71ol820P6o`T92@Kooooo1olZ:RX7oaTI
6@Oo4A4A1omADE46o`/;2`Oo71`L1oooool6od92@PKooooo1olH61P7o`L71`Oo4Q8B1_lP8207obTY
:@Oo6QXJ1olD51@6oi6AT@Kooooo1olL71`7odm?C`Oooooo1_l410@7oda<C0OoBDU91ol>3Ph6oadM
7@Kooooo1ol@4107o`D51@KoBd];1oni^KT7oiVIV@OoFUYJ1olI6AT6og5aL@Kooooo1oo`l?06o`L7
1`Oo@D511olJ6QX7ocLg=`OoAdM71omjNWX6oibLW0kooooo000<ooooo`Oo8B4Q1olA4A47o`P820Oo
00001olV9RH6od];B`OomOGe1_mUIFD=ooooo`Oo;Bd]1olc<c<7ob@T90Oo<c<c3Ol];Bd6oaHF5PKo
oooo3_lV9RH7obPX:0OoiNGU1_l[:b/7o`L71`Oo20P81_l92@T6ooooo`Oo:RXZ1olI6AT7oa4A4@Oo
DE5A1_l;2`/7oa`L70Oooooo1_m2@T86ooooo`Oo61PH1ol71`L7oa8B4PKo820P1olY:BT7oaXJ6POo
51@D1_nATI46ooooo`Oo71`L1om?Cdl7ooooo`Ko10@41om<C4`7odU9B@Oo3Ph>1_lM7Ad6ooooo`Oo
410@1ol51@D6od];B`Oo^KVi1onIVIT7oeYJFPOo6ATI1_maLG46ooooo`Ool?3`1_l71`L7od51@@Oo
6QXJ1olg=cL7odM7A`OoNWYj1_nLW9`>ooooo`003?ooool7ob4Q8@Oo4A4A1ol820P7o`0000Oo9RHV
1_m;Bd/7ooGem@KoIFEU3Oooool7obd];@Oo<c<c1olT92@7oc<c<`go;Bd]1_lF5QH6ooooo`ko9RHV
1olX:2P7onGUi@Ko:b/[1ol71`L7o`P820Ko2@T91_ooool7obXZ:POo6ATI1olA4A47oe5AD@Ko2`/;
1olL71`7ooooo`Ko@T921_ooool7oaPH60Oo1`L71olB4Q86ob0P80Oo:BTY1olJ6QX7oa@D50KoTI6A
1_ooool7oa`L70OoCdm?1oooool6o`@410OoC4a<1om9BDT7o`h>3PKo7AdM1_ooool7oa0@40Oo1@D5
1_m;Bd/7okVi^@OoVIVI1omJFUX7oaTI6@KoLG5a1_ooool7oo3`l0Ko1`L71om1@D47oaXJ6POo=cLg
1om7AdL7ogYjNPKoW9bL3_ooool000cooooo1olQ8B47oa4A4@Oo20P81ol00007obHV9PKoBd];1ooe
mOD6ofEUI@gooooo1ol];Bd7oc<c<`Oo92@T1olc<c<=obd];@Ko5QHF1_ooool>obHV9POo:2PX1ooU
iND6ob/[:`Oo1`L71ol820P6o`T92@Kooooo1olZ:RX7oaTI6@Oo4A4A1omADE46o`/;2`Oo71`L1ooo
ool6od92@PKooooo1olH61P7o`L71`Oo4Q8B1_lP8207obTY:@Oo6QXJ1olD51@6oi6AT@Kooooo1olL
71`7odm?C`Oooooo1_l410@7oda<C0OoBDU91ol>3Ph6oadM7@Kooooo1ol@4107o`D51@KoBd];1oni
^KT7oiVIV@OoFUYJ1olI6AT6og5aL@Kooooo1oo`l?06o`L71`Oo@D511olJ6QX7ocLg=`OoAdM71omj
NWX6oibLW0kooooo000<ooooo`Oo8B4Q1olA4A47o`P820Oo00001olV9RH6od];B`OomOGe1_mUIFD=
ooooo`Oo;Bd]1olc<c<7ob@T90Oo<c<c3Ol];Bd6oaHF5PKooooo3_lV9RH7obPX:0OoiNGU1_l[:b/7
o`L71`Oo20P81_l92@T6ooooo`Oo:RXZ1olI6AT7oa4A4@OoDE5A1_l;2`/7oa`L70Oooooo1_m2@T86
ooooo`Oo61PH1ol71`L7oa8B4PKo820P1olY:BT7oaXJ6POo51@D1_nATI46ooooo`Oo71`L1om?Cdl7
ooooo`Ko10@41om<C4`7odU9B@Oo3Ph>1_lM7Ad6ooooo`Oo410@1ol51@D6od];B`Oo^KVi1onIVIT7
oeYJFPOo6ATI1_maLG46ooooo`Ool?3`1_l71`L7od51@@Oo6QXJ1olg=cL7odM7A`OoNWYj1_nLW9`>
ooooo`003?ooool7obPX:0Oo5aLG1ol@4107o`T92@Oo;Bd]1_m<C4`7oo[jnPKoH61P1_ooool7omWI
f@Oo71`L1olY:BT7oc4a<@Oo;Rh^1_m?Cdl7oc<c<`Ko1@D51_ooool7oc<c<`Oo6a/K1olR8R87oooo
o`Ko:b/[1ol20P87oa<C4`Ko00001_ooool7ob4Q8@Oo5ADE1olP8207odE5A@Ko0P821ol`<307ooKf
mPKo@D511_ooool7o`P820ko1@D51_lL71`7oa/K6`Oo4A4A1ol:2PX6ofe]K@Kooooo1olG5aL7oeYJ
FPOokNg]1_l00007odI6APOo?3`l1olK6a/6oaLG5`Kooooo1olT92@7ob8R8PKo/K6a1on`/;07og9b
LPOo6a/K1ol;2`/6onc/k0Kooooo1ooTi>@6o`820POo@T921olN7Qh7oe1@D0OoCTi>1omnOWh6oi>C
T`kooooo000<ooooo`Oo:2PX1olG5aL7oa0@40Oo2@T91ol];Bd6oda<C0Oon_[j1_mPH606ooooo`Oo
fMWI1olL71`7obTY:@Oo<C4a1ol^;Rh6odm?C`Oo<c<c1_l51@D6ooooo`Oo<c<c1olK6a/7ob8R8POo
oooo1_l[:b/7o`820POo4a<C1_l00006ooooo`Oo8B4Q1olE5AD7ob0P80OoADE51_l20P87oc0`<0Oo
m_Kf1_m1@D46ooooo`Oo20P83_l51@D6oa`L70Oo6a/K1olA4A47o`X:2PKoKFe]1_ooool7oaLG5`Oo
FUYJ1oo]kNd6o`0000OoATI61oll?3`7oa/K6`Ko5aLG1_ooool7ob@T90Oo8R8R1_na/K47ok2`/0Oo
LW9b1olK6a/7o`/;2`Kok>c/1_ooool7onCTi0Ko0P821om2@T87oahN7POoD51@1om>CTh7oginOPKo
Ti>C3_ooool000cooooo1olX:2P7oaLG5`Oo410@1ol92@T7obd];@KoC4a<1oojn_X6of1PH0Kooooo
1ooIfMT7oa`L70Oo:BTY1ola<C47obh^;PKoCdm?1olc<c<6o`D51@Kooooo1olc<c<7oa/K6`Oo8R8R
1oooool6ob/[:`Oo0P821olC4a<6o`0000Kooooo1olQ8B47oaDE5@Oo820P1om5ADD6o`820POo<30`
1oofm_H6od51@@Kooooo1ol820P>o`D51@Ko71`L1olK6a/7oa4A4@Oo2PX:1_m]KFd6ooooo`Oo5aLG
1omJFUX7ong]k@Ko00001om6ATH7oc`l?0Oo6a/K1_lG5aL6ooooo`Oo92@T1olR8R86ok6a/@Oo/;2`
1ombLW87oa/K6`Oo2`/;1_o/k>`6ooooo`Ooi>CT1_l20P87od92@POo7QhN1om@D507odi>CPOoOWin
1_nCTi<>ooooo`003?ooool7obPX:0Oo5aLG1ol@4107o`T92@Oo;Bd]1_m<C4`7oo[jnPKoH61P1_oo
ool7omWIf@Oo71`L1olY:BT7oc4a<@Oo;Rh^1_m?Cdl7oc<c<`Ko1@D51_ooool7oc<c<`Oo6a/K1olR
8R87ooooo`Ko:b/[1ol20P87oa<C4`Ko00001_ooool7ob4Q8@Oo5ADE1olP8207odE5A@Ko0P821ol`
<307ooKfmPKo@D511_ooool7o`P820ko1@D51_lL71`7oa/K6`Oo4A4A1ol:2PX6ofe]K@Kooooo1olG
5aL7oeYJFPOokNg]1_l00007odI6APOo?3`l1olK6a/6oaLG5`Kooooo1olT92@7ob8R8PKo/K6a1on`
/;07og9bLPOo6a/K1ol;2`/6onc/k0Kooooo1ooTi>@6o`820POo@T921olN7Qh7oe1@D0OoCTi>1omn
OWh6oi>CT`kooooo000<ooooo`Oo:2PX1olG5aL7oa0@40Oo2@T91ol];Bd6oda<C0Oon_[j1_mPH606
ooooo`OofMWI1olL71`7obTY:@Oo<C4a1ol^;Rh6odm?C`Oo<c<c1_l51@D6ooooo`Oo<c<c1olK6a/7
ob8R8POooooo1_l[:b/7o`820POo4a<C1_l00006ooooo`Oo8B4Q1olE5AD7ob0P80OoADE51_l20P87
oc0`<0Oom_Kf1_m1@D46ooooo`Oo20P83_l51@D6oa`L70Oo6a/K1olA4A47o`X:2PKoKFe]1_ooool7
oaLG5`OoFUYJ1oo]kNd6o`0000OoATI61oll?3`7oa/K6`Ko5aLG1_ooool7ob@T90Oo8R8R1_na/K47
ok2`/0OoLW9b1olK6a/7o`/;2`Kok>c/1_ooool7onCTi0Ko0P821om2@T87oahN7POoD51@1om>CTh7
oginOPKoTi>C3_ooool000cooooo1olX:2P7oaLG5`Oo410@1ol92@T7obd];@KoC4a<1oojn_X6of1P
H0Kooooo1ooIfMT7oa`L70Oo:BTY1ola<C47obh^;PKoCdm?1olc<c<6o`D51@Kooooo1olc<c<7oa/K
6`Oo8R8R1oooool6ob/[:`Oo0P821olC4a<6o`0000Kooooo1olQ8B47oaDE5@Oo820P1om5ADD6o`82
0POo<30`1oofm_H6od51@@Kooooo1ol820P>o`D51@Ko71`L1olK6a/7oa4A4@Oo2PX:1_m]KFd6oooo
o`Oo5aLG1omJFUX7ong]k@Ko00001om6ATH7oc`l?0Oo6a/K1_lG5aL6ooooo`Oo92@T1olR8R86ok6a
/@Oo/;2`1ombLW87oa/K6`Oo2`/;1_o/k>`6ooooo`Ooi>CT1_l20P87od92@POo7QhN1om@D507odi>
CPOoOWin1_nCTi<>ooooo`003?ooool7obh^;POo4Q8B1olC4a<7oa0@40Oo=cLg1_m9BDT7omSHf0Ko
J6QX1_ooool7omcLg0Oo9BDU1olZ:RX7oc<c<`Oo<30`1_lj>SX7ocTi>@Ko:RXZ1_ooool7obl_;`Oo
9RHV1ole=CD7ol_;b`Ko:2PX1ol=3@d7oa4A4@Ko410@1_ooool7oalO7`Oo5ADE1olS8b<7od92@PKo
0`<31om5ADD7oo7al@KoA4A41_ooool7oa<C4`Oo30`<1ol>3Ph6ob<S8`Oo9bLW1olA4A47o`P820Ko
De=C1_ooool7ob/[:`OoJFUY1ooPh>06o`0000OoBTY:1olm?Cd7oaXJ6PKo51@D1_ooool7oaPH60Oo
3`l?1_mgMgL7ol;2`POoP8201olV9RH7ocTi>@KoIFEU1_ooool7olG5a@Ko30`<1oll?3`7oalO7`Oo
C4a<1omEEED7og=cL`KoXj>S3_ooool000cooooo1ol^;Rh7oa8B4POo4a<C1ol@4107ocLg=`KoBDU9
1ooHf=P6ofQXJ0Kooooo1ooLg=`7obDU9@Oo:RXZ1olc<c<7oc0`<0Ko>SXj1oli>CT6obXZ:PKooooo
1ol_;bl7obHV9POo=CDe1oo;bl/6obPX:0Oo3@d=1olA4A46oa0@40Kooooo1olO7al7oaDE5@Oo8b<S
1om2@T86o`<30`OoADE51ooalO46odA4A0Kooooo1olC4a<7o``<30Oo3Ph>1_lS8b<7obLW9`Oo4A4A
1ol820P6oe=CD`Kooooo1ol[:b/7ofUYJ@Ooh>3P1_l00007odY:BPOo?Cdm1olJ6QX6oa@D50Kooooo
1olH61P7o`l?3`KoMgMg1oo2`/87oh20P0Oo9RHV1oli>CT6ofEUI@Kooooo1oo5aLD6o``<30Oo?3`l
1olO7al7oda<C0OoEEEE1omcLg<6oj>SX`kooooo000<ooooo`Oo;Rh^1olB4Q87oa<C4`Oo410@1olg
=cL6odU9B@Oof=SH1_mXJ6P6ooooo`Oog=cL1olU9BD7obXZ:POo<c<c1ol`<306ocXj>POo>CTi1_lZ
:RX6ooooo`Oo;bl_1olV9RH7ocDe=@Oobl_;1_lX:2P7o`d=3@Oo4A4A1_l@4106ooooo`Oo7alO1olE
5AD7ob<S8`Oo@T921_l30`<7odE5A@OolO7a1_m4A4@6ooooo`Oo4a<C1ol<30`7o`h>3PKo8b<S1olW
9bL7oa4A4@Oo20P81_mCDe<6ooooo`Oo:b/[1omYJFT7on3Ph0Ko00001om:BTX7ocdm?@Oo6QXJ1_lD
51@6ooooo`Oo61PH1ol?3`l6ogMgM`Oo`/;21on0P807obHV9POo>CTi1_mUIFD6ooooo`OoaLG51_l<
30`7oc`l?0Oo7alO1om<C4`7oeEEE@OoLg=c1_nSXj<>ooooo`003?ooool7obh^;POo4Q8B1olC4a<7
oa0@40Oo=cLg1_m9BDT7omSHf0KoJ6QX1_ooool7omcLg0Oo9BDU1olZ:RX7oc<c<`Oo<30`1_lj>SX7
ocTi>@Ko:RXZ1_ooool7obl_;`Oo9RHV1ole=CD7ol_;b`Ko:2PX1ol=3@d7oa4A4@Ko410@1_ooool7
oalO7`Oo5ADE1olS8b<7od92@PKo0`<31om5ADD7oo7al@KoA4A41_ooool7oa<C4`Oo30`<1ol>3Ph6
ob<S8`Oo9bLW1olA4A47o`P820KoDe=C1_ooool7ob/[:`OoJFUY1ooPh>06o`0000OoBTY:1olm?Cd7
oaXJ6PKo51@D1_ooool7oaPH60Oo3`l?1_mgMgL7ol;2`POoP8201olV9RH7ocTi>@KoIFEU1_ooool7
olG5a@Ko30`<1oll?3`7oalO7`OoC4a<1omEEED7og=cL`KoXj>S3_ooool000cooooo1ol^;Rh7oa8B
4POo4a<C1ol@4107ocLg=`KoBDU91ooHf=P6ofQXJ0Kooooo1ooLg=`7obDU9@Oo:RXZ1olc<c<7oc0`
<0Ko>SXj1oli>CT6obXZ:PKooooo1ol_;bl7obHV9POo=CDe1oo;bl/6obPX:0Oo3@d=1olA4A46oa0@
40Kooooo1olO7al7oaDE5@Oo8b<S1om2@T86o`<30`OoADE51ooalO46odA4A0Kooooo1olC4a<7o``<
30Oo3Ph>1_lS8b<7obLW9`Oo4A4A1ol820P6oe=CD`Kooooo1ol[:b/7ofUYJ@Ooh>3P1_l00007odY:
BPOo?Cdm1olJ6QX6oa@D50Kooooo1olH61P7o`l?3`KoMgMg1oo2`/87oh20P0Oo9RHV1oli>CT6ofEU
I@Kooooo1oo5aLD6o``<30Oo?3`l1olO7al7oda<C0OoEEEE1omcLg<6oj>SX`kooooo000<ooooo`Oo
;Rh^1olB4Q87oa<C4`Oo410@1olg=cL6odU9B@Oof=SH1_mXJ6P6ooooo`Oog=cL1olU9BD7obXZ:POo
<c<c1ol`<306ocXj>POo>CTi1_lZ:RX6ooooo`Oo;bl_1olV9RH7ocDe=@Oobl_;1_lX:2P7o`d=3@Oo
4A4A1_l@4106ooooo`Oo7alO1olE5AD7ob<S8`Oo@T921_l30`<7odE5A@OolO7a1_m4A4@6ooooo`Oo
4a<C1ol<30`7o`h>3PKo8b<S1olW9bL7oa4A4@Oo20P81_mCDe<6ooooo`Oo:b/[1omYJFT7on3Ph0Ko
00001om:BTX7ocdm?@Oo6QXJ1_lD51@6ooooo`Oo61PH1ol?3`l6ogMgM`Oo`/;21on0P807obHV9POo
>CTi1_mUIFD6ooooo`OoaLG51_l<30`7oc`l?0Oo7alO1om<C4`7oeEEE@OoLg=c1_nSXj<>ooooo`00
3?ooool7obh^;POo4Q8B1olC4a<7oa0@40Oo=cLg1_m9BDT7omSHf0KoJ6QX1_ooool7omcLg0Oo9BDU
1olZ:RX7oc<c<`Oo<30`1_lj>SX7ocTi>@Ko:RXZ1_ooool7obl_;`Oo9RHV1ole=CD7ol_;b`Ko:2PX
1ol=3@d7oa4A4@Ko410@1_ooool7oalO7`Oo5ADE1olS8b<7od92@PKo0`<31om5ADD7oo7al@KoA4A4
1_ooool7oa<C4`Oo30`<1ol>3Ph6ob<S8`Oo9bLW1olA4A47o`P820KoDe=C1_ooool7ob/[:`OoJFUY
1ooPh>06o`0000OoBTY:1olm?Cd7oaXJ6PKo51@D1_ooool7oaPH60Oo3`l?1_mgMgL7ol;2`POoP820
1olV9RH7ocTi>@KoIFEU1_ooool7olG5a@Ko30`<1oll?3`7oalO7`OoC4a<1omEEED7og=cL`KoXj>S
3_ooool000cooooo1olc<c<7oaPH60Oo4Q8B1olC4a<7oc@d=0Ko@D511oo9bLT6og=cL`Kooooo1on[
Zj/7oaLG5`Oo:RXZ1old=3@7oc0`<0KoDU9B1ole=CD6oaXJ6PKooooo1ola<C47oa`L70Oo:b/[1ooG
emL6ob4Q8@Oo1@D51olP8206o`P820Kooooo1ol=3@d7o`H61POo8B4Q1olY:BT6o`0000Oo?Cdm1oo>
c/h6oc4a<@Kooooo1ol61PH7o`0000Oo1@D51_lI6AT7ob8R8POo30`<1ol51@D6odM7A`Kooooo1olQ
8B47ofIVIPOo];Bd1_l410@7ocdm?@Oo=3@d1olO7al6oa@D50Kooooo1olH61P7oeeMG@Koa<C41onO
Wil7odE5A@Oo820P1olC4a<6om;BdPKooooo1on/[:`6o`0000Oo=3@d1olI6AT7oe1@D0OoC4a<1omX
J6P6oi>CT`kooooo000<ooooo`Oo<c<c1olH61P7oa8B4POo4a<C1old=3@6od51@@OobLW91_mcLg<6
ooooo`OoZj^[1olG5aL7obXZ:POo=3@d1ol`<306oe9BDPOo=CDe1_lJ6QX6ooooo`Oo<C4a1olL71`7
ob/[:`OoemOG1_lQ8B47o`D51@Oo820P1_l820P6ooooo`Oo3@d=1ol61PH7ob4Q8@Oo:BTY1_l00007
ocdm?@Ooc/k>1_la<C46ooooo`Oo1PH61ol00007o`D51@Ko6ATI1olR8R87o``<30Oo1@D51_m7AdL6
ooooo`Oo8B4Q1omVIVH7okBd]0Ko10@41olm?Cd7oc@d=0Oo7alO1_lD51@6ooooo`Oo61PH1omMGEd6
olC4a0OoWinO1om5ADD7ob0P80Oo4a<C1_oBd]86ooooo`Oo[:b/1_l00007oc@d=0Oo6ATI1om@D507
oda<C0OoJ6QX1_nCTi<>ooooo`003?ooool7oc<c<`Oo61PH1olB4Q87oa<C4`Oo=3@d1_m1@D47olW9
b@KoLg=c1_ooool7oj^[Z`Oo5aLG1olZ:RX7oc@d=0Oo<30`1_mBDU87ocDe=@Ko6QXJ1_ooool7oc4a
<@Oo71`L1ol[:b/7omOGe`Ko8B4Q1ol51@D7ob0P80Ko20P81_ooool7o`d=3@Oo1PH61olQ8B47obTY
:@Ko00001olm?Cd7olk>cPKo<C4a1_ooool7o`H61POo00001ol51@D6oaTI6@Oo8R8R1ol<30`7o`D5
1@KoAdM71_ooool7ob4Q8@OoIVIV1ond];@6o`@410Oo?Cdm1old=3@7oalO7`Ko51@D1_ooool7oaPH
60OoGEeM1_o4a<@7oinOW`OoADE51olP8207oa<C4`Kod];B1_ooool7ojb/[0Ko00001old=3@7oaTI
6@OoD51@1om<C4`7ofQXJ0KoTi>C3_ooool000cooooo1olc<c<7oaPH60Oo4Q8B1olC4a<7oc@d=0Ko
@D511oo9bLT6og=cL`Kooooo1on[Zj/7oaLG5`Oo:RXZ1old=3@7oc0`<0KoDU9B1ole=CD6oaXJ6PKo
oooo1ola<C47oa`L70Oo:b/[1ooGemL6ob4Q8@Oo1@D51olP8206o`P820Kooooo1ol=3@d7o`H61POo
8B4Q1olY:BT6o`0000Oo?Cdm1oo>c/h6oc4a<@Kooooo1ol61PH7o`0000Oo1@D51_lI6AT7ob8R8POo
30`<1ol51@D6odM7A`Kooooo1olQ8B47ofIVIPOo];Bd1_l410@7ocdm?@Oo=3@d1olO7al6oa@D50Ko
oooo1olH61P7oeeMG@Koa<C41onOWil7odE5A@Oo820P1olC4a<6om;BdPKooooo1on/[:`6o`0000Oo
=3@d1olI6AT7oe1@D0OoC4a<1omXJ6P6oi>CT`kooooo000<ooooo`Oo<c<c1olH61P7oa8B4POo4a<C
1old=3@6od51@@OobLW91_mcLg<6ooooo`OoZj^[1olG5aL7obXZ:POo=3@d1ol`<306oe9BDPOo=CDe
1_lJ6QX6ooooo`Oo<C4a1olL71`7ob/[:`OoemOG1_lQ8B47o`D51@Oo820P1_l820P6ooooo`Oo3@d=
1ol61PH7ob4Q8@Oo:BTY1_l00007ocdm?@Ooc/k>1_la<C46ooooo`Oo1PH61ol00007o`D51@Ko6ATI
1olR8R87o``<30Oo1@D51_m7AdL6ooooo`Oo8B4Q1omVIVH7okBd]0Ko10@41olm?Cd7oc@d=0Oo7alO
1_lD51@6ooooo`Oo61PH1omMGEd6olC4a0OoWinO1om5ADD7ob0P80Oo4a<C1_oBd]86ooooo`Oo[:b/
1_l00007oc@d=0Oo6ATI1om@D507oda<C0OoJ6QX1_nCTi<>ooooo`003?ooool7oc<c<`Oo61PH1olB
4Q87oa<C4`Oo=3@d1_m1@D47olW9b@KoLg=c1_ooool7oj^[Z`Oo5aLG1olZ:RX7oc@d=0Oo<30`1_mB
DU87ocDe=@Ko6QXJ1_ooool7oc4a<@Oo71`L1ol[:b/7omOGe`Ko8B4Q1ol51@D7ob0P80Ko20P81_oo
ool7o`d=3@Oo1PH61olQ8B47obTY:@Ko00001olm?Cd7olk>cPKo<C4a1_ooool7o`H61POo00001ol5
1@D6oaTI6@Oo8R8R1ol<30`7o`D51@KoAdM71_ooool7ob4Q8@OoIVIV1ond];@6o`@410Oo?Cdm1old
=3@7oalO7`Ko51@D1_ooool7oaPH60OoGEeM1_o4a<@7oinOW`OoADE51olP8207oa<C4`Kod];B1_oo
ool7ojb/[0Ko00001old=3@7oaTI6@OoD51@1om<C4`7ofQXJ0KoTi>C3_ooool000cooooo1olc<c<7
oaPH60Oo4Q8B1olC4a<7oc@d=0Ko@D511oo9bLT6og=cL`Kooooo1on[Zj/7oaLG5`Oo:RXZ1old=3@7
oc0`<0KoDU9B1ole=CD6oaXJ6PKooooo1ola<C47oa`L70Oo:b/[1ooGemL6ob4Q8@Oo1@D51olP8206
o`P820Kooooo1ol=3@d7o`H61POo8B4Q1olY:BT6o`0000Oo?Cdm1oo>c/h6oc4a<@Kooooo1ol61PH7
o`0000Oo1@D51_lI6AT7ob8R8POo30`<1ol51@D6odM7A`Kooooo1olQ8B47ofIVIPOo];Bd1_l410@7
ocdm?@Oo=3@d1olO7al6oa@D50Kooooo1olH61P7oeeMG@Koa<C41onOWil7odE5A@Oo820P1olC4a<6
om;BdPKooooo1on/[:`6o`0000Oo=3@d1olI6AT7oe1@D0OoC4a<1omXJ6P6oi>CT`kooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo000<ooooo`OoOGem1olK6a/7od10@0OoBDU91on:RXX6oh>3P`Oo_kno1_nf][H6ooooo`Oo
:2PX1ooLg=`7odi>CPOo51@D1ol`<306obTY:@Oo4Q8B1_lj>SX6ooooo`Oo:BTY1olg=cL7om;BdPOo
ADE51_lD51@7oaTI6@Oo5aLG1_m9BDT6ooooo`Oo?Shn1old=3@7obd];@Oo5ADE1_lY:BT7ojBTY0Oo
FEUI1_m:BTX6ooooo`Oo2`/;1olF5QH7o``<30Ko20P81olA4A47o`/;2`Oo410@1_mUIFD6ooooo`Oo
;bl_1onIVIT7oi:BTPKoc<c<1olV9RH7o`P820Oo:RXZ1_nLW9`6ooooo`Oo5QHF1ol>3Ph6oc8b<POo
=cLg1ooDe=@7ocHf=POo4A4A1_m<C4`6ooooo`OoOGem1_mTI6@7oc@d=0Oo>c/k3_oMgMd7oc0`<0Ko
ATI63_ooool000cooooo1ommOGd7oa/K6`Oo@4101om9BDT7ohZ:RPKoPh>31ono_kl6okJf]PKooooo
1olX:2P7omcLg0OoCTi>1olD51@7oc0`<0Ko:BTY1olB4Q86ocXj>PKooooo1olY:BT7ocLg=`Ood];B
1om5ADD6oa@D50Oo6ATI1olG5aL6odU9B@Kooooo1oln?Sh7oc@d=0Oo;Bd]1olE5AD6obTY:@OoY:BT
1omIFET6odY:BPKooooo1ol;2`/7oaHF5POo30`<1_l820P7oa4A4@Oo2`/;1ol@4106ofEUI@Kooooo
1ol_;bl7oiVIV@OoTY:B1_o<c<`7obHV9POo20P81olZ:RX6oibLW0Kooooo1olF5QH7o`h>3PKo<S8b
1olg=cL7omCDe0Oo=SHf1olA4A46oda<C0Kooooo1ommOGd6ofATI0Oo=3@d1olk>c/>omgMg@Oo<30`
1_m6ATH>ooooo`003?ooool7ogemO@Oo6a/K1om0@407odU9B@OoRXZ:1_n3Ph<7okno_`Ko][Jf1_oo
ool7obPX:0Oog=cL1om>CTh7oa@D50Oo<30`1_lY:BT7oa8B4PKo>SXj1_ooool7obTY:@Oo=cLg1ooB
d]87odE5A@Ko51@D1olI6AT7oaLG5`KoBDU91_ooool7ochn?POo=3@d1ol];Bd7oaDE5@Ko:BTY1onT
Y:@7oeUIF@KoBTY:1_ooool7o`/;2`Oo5QHF1ol<30`6o`P820Oo4A4A1ol;2`/7oa0@40KoIFEU1_oo
ool7obl_;`OoVIVI1onBTY86olc<c0Oo9RHV1ol820P7obXZ:PKoW9bL1_ooool7oaHF5POo3Ph>1_lb
<S87ocLg=`Ooe=CD1olf=SH7oa4A4@KoC4a<1_ooool7ogemO@KoI6AT1old=3@7oc/k>`kogMgM1ol`
<306odI6APkooooo000<ooooo`OoOGem1olK6a/7od10@0OoBDU91on:RXX6oh>3P`Oo_kno1_nf][H6
ooooo`Oo:2PX1ooLg=`7odi>CPOo51@D1ol`<306obTY:@Oo4Q8B1_lj>SX6ooooo`Oo:BTY1olg=cL7
om;BdPOoADE51_lD51@7oaTI6@Oo5aLG1_m9BDT6ooooo`Oo?Shn1old=3@7obd];@Oo5ADE1_lY:BT7
ojBTY0OoFEUI1_m:BTX6ooooo`Oo2`/;1olF5QH7o``<30Ko20P81olA4A47o`/;2`Oo410@1_mUIFD6
ooooo`Oo;bl_1onIVIT7oi:BTPKoc<c<1olV9RH7o`P820Oo:RXZ1_nLW9`6ooooo`Oo5QHF1ol>3Ph6
oc8b<POo=cLg1ooDe=@7ocHf=POo4A4A1_m<C4`6ooooo`OoOGem1_mTI6@7oc@d=0Oo>c/k3_oMgMd7
oc0`<0KoATI63_ooool000cooooo1ommOGd7oa/K6`Oo@4101om9BDT7ohZ:RPKoPh>31ono_kl6okJf
]PKooooo1olX:2P7omcLg0OoCTi>1olD51@7oc0`<0Ko:BTY1olB4Q86ocXj>PKooooo1olY:BT7ocLg
=`Ood];B1om5ADD6oa@D50Oo6ATI1olG5aL6odU9B@Kooooo1oln?Sh7oc@d=0Oo;Bd]1olE5AD6obTY
:@OoY:BT1omIFET6odY:BPKooooo1ol;2`/7oaHF5POo30`<1_l820P7oa4A4@Oo2`/;1ol@4106ofEU
I@Kooooo1ol_;bl7oiVIV@OoTY:B1_o<c<`7obHV9POo20P81olZ:RX6oibLW0Kooooo1olF5QH7o`h>
3PKo<S8b1olg=cL7omCDe0Oo=SHf1olA4A46oda<C0Kooooo1ommOGd6ofATI0Oo=3@d1olk>c/>omgM
g@Oo<30`1_m6ATH>ooooo`003?ooool7ogemO@Oo6a/K1om0@407odU9B@OoRXZ:1_n3Ph<7okno_`Ko
][Jf1_ooool7obPX:0Oog=cL1om>CTh7oa@D50Oo<30`1_lY:BT7oa8B4PKo>SXj1_ooool7obTY:@Oo
=cLg1ooBd]87odE5A@Ko51@D1olI6AT7oaLG5`KoBDU91_ooool7ochn?POo=3@d1ol];Bd7oaDE5@Ko
:BTY1onTY:@7oeUIF@KoBTY:1_ooool7o`/;2`Oo5QHF1ol<30`6o`P820Oo4A4A1ol;2`/7oa0@40Ko
IFEU1_ooool7obl_;`OoVIVI1onBTY86olc<c0Oo9RHV1ol820P7obXZ:PKoW9bL1_ooool7oaHF5POo
3Ph>1_lb<S87ocLg=`Ooe=CD1olf=SH7oa4A4@KoC4a<1_ooool7ogemO@KoI6AT1old=3@7oc/k>`ko
gMgM1ol`<306odI6APkooooo000<ooooo`OoOGem1olK6a/7od10@0OoBDU91on:RXX6oh>3P`Oo_kno
1_nf][H6ooooo`Oo:2PX1ooLg=`7odi>CPOo51@D1ol`<306obTY:@Oo4Q8B1_lj>SX6ooooo`Oo:BTY
1olg=cL7om;BdPOoADE51_lD51@7oaTI6@Oo5aLG1_m9BDT6ooooo`Oo?Shn1old=3@7obd];@Oo5ADE
1_lY:BT7ojBTY0OoFEUI1_m:BTX6ooooo`Oo2`/;1olF5QH7o``<30Ko20P81olA4A47o`/;2`Oo410@
1_mUIFD6ooooo`Oo;bl_1onIVIT7oi:BTPKoc<c<1olV9RH7o`P820Oo:RXZ1_nLW9`6ooooo`Oo5QHF
1ol>3Ph6oc8b<POo=cLg1ooDe=@7ocHf=POo4A4A1_m<C4`6ooooo`OoOGem1_mTI6@7oc@d=0Oo>c/k
3_oMgMd7oc0`<0KoATI63_ooool000cooooo1omiNGT7obPX:0Oo6QXJ1ol`<307ogIfMPKoUYJF1onj
^[X6on;RhPKooooo1ol[:b/7onGUi@Oo>CTi1ol>3Ph7ob4Q8@Ko8b<S1olD51@6oc@d=0Kooooo1olJ
6QX7oc0`<0Ooi^KV1oll?3`6oa8B4POo4a<C1ol<30`6oc0`<0Kooooo1olb<S87obLW9`Oo8B4Q1ol5
1@D6oa/K6`Oog]kN1om6ATH6ofATI0Kooooo1ol00007oa<C4`Oo2@T91_l30`<7oa4A4@Oo1`L71olA
4A46oeEEE@Kooooo1olR8R87obTY:@OoalO71_nUYJD7oeYJFPOo1PH61omlO7`6obLW9`Kooooo1olE
5AD7oa8B4PKo5aLG1oln?Sh7onk^kPOo=SHf1ol30`<6oc0`<0Kooooo1ommOGd6of][J`Oo=CDe1oln
?Sh7oo3`l0Oofm_K1olL71`6ocTi>@kooooo000<ooooo`OoNGUi1olX:2P7oaXJ6POo<30`1omfMWH6
oiJFUPOo^[Zj1_oRh^86ooooo`Oo:b/[1ooUiND7ocTi>@Oo3Ph>1olQ8B46ob<S8`Oo51@D1_ld=3@6
ooooo`Oo6QXJ1ol`<307onKViPOo?3`l1_lB4Q87oa<C4`Oo30`<1_l`<306ooooo`Oo<S8b1olW9bL7
ob4Q8@Oo1@D51_lK6a/7omkNgPOoATI61_mTI6@6ooooo`Oo00001olC4a<7o`T92@Ko0`<31olA4A47
o`L71`Oo4A4A1_mEEED6ooooo`Oo8R8R1olY:BT7olO7a`KoYJFU1omJFUX7o`H61POoO7al1_lW9bL6
ooooo`Oo5ADE1olB4Q86oaLG5`Oo?Shn1oo^k^h7ocHf=POo0`<31_l`<306ooooo`OoOGem1_m[Jf/7
ocDe=@Oo?Shn1oo`l?07om_Kf`Oo71`L1_li>CT>ooooo`003?ooool7ogUiN@Oo:2PX1olJ6QX7oc0`
<0OoMWIf1_nFUYH7okZj^PKoh^;R1_ooool7ob/[:`OoiNGU1oli>CT7o`h>3POo8B4Q1_lS8b<7oa@D
50Ko=3@d1_ooool7oaXJ6POo<30`1ooVi^H7oc`l?0Ko4Q8B1olC4a<7o``<30Ko<30`1_ooool7oc8b
<POo9bLW1olQ8B47o`D51@Ko6a/K1ooNg]h7odI6APKoI6AT1_ooool7o`0000Oo4a<C1ol92@T6o`<3
0`Oo4A4A1ol71`L7oa4A4@KoEEEE1_ooool7ob8R8POo:BTY1oo7alL6ojFUY@OoFUYJ1ol61PH7ogal
O0Ko9bLW1_ooool7oaDE5@Oo4Q8B1_lG5aL7ochn?POok^k^1olf=SH7o`<30`Ko<30`1_ooool7ogem
O@KoJf][1ole=CD7ochn?POol?3`1ooKfm/7oa`L70Ko>CTi3_ooool000cooooo1omiNGT7obPX:0Oo
6QXJ1ol`<307ogIfMPKoUYJF1onj^[X6on;RhPKooooo1ol[:b/7onGUi@Oo>CTi1ol>3Ph7ob4Q8@Ko
8b<S1olD51@6oc@d=0Kooooo1olJ6QX7oc0`<0Ooi^KV1oll?3`6oa8B4POo4a<C1ol<30`6oc0`<0Ko
oooo1olb<S87obLW9`Oo8B4Q1ol51@D6oa/K6`Oog]kN1om6ATH6ofATI0Kooooo1ol00007oa<C4`Oo
2@T91_l30`<7oa4A4@Oo1`L71olA4A46oeEEE@Kooooo1olR8R87obTY:@OoalO71_nUYJD7oeYJFPOo
1PH61omlO7`6obLW9`Kooooo1olE5AD7oa8B4PKo5aLG1oln?Sh7onk^kPOo=SHf1ol30`<6oc0`<0Ko
oooo1ommOGd6of][J`Oo=CDe1oln?Sh7oo3`l0Oofm_K1olL71`6ocTi>@kooooo000<ooooo`OoNGUi
1olX:2P7oaXJ6POo<30`1omfMWH6oiJFUPOo^[Zj1_oRh^86ooooo`Oo:b/[1ooUiND7ocTi>@Oo3Ph>
1olQ8B46ob<S8`Oo51@D1_ld=3@6ooooo`Oo6QXJ1ol`<307onKViPOo?3`l1_lB4Q87oa<C4`Oo30`<
1_l`<306ooooo`Oo<S8b1olW9bL7ob4Q8@Oo1@D51_lK6a/7omkNgPOoATI61_mTI6@6ooooo`Oo0000
1olC4a<7o`T92@Ko0`<31olA4A47o`L71`Oo4A4A1_mEEED6ooooo`Oo8R8R1olY:BT7olO7a`KoYJFU
1omJFUX7o`H61POoO7al1_lW9bL6ooooo`Oo5ADE1olB4Q86oaLG5`Oo?Shn1oo^k^h7ocHf=POo0`<3
1_l`<306ooooo`OoOGem1_m[Jf/7ocDe=@Oo?Shn1oo`l?07om_Kf`Oo71`L1_li>CT>ooooo`003?oo
ool7ogUiN@Oo:2PX1olJ6QX7oc0`<0OoMWIf1_nFUYH7okZj^PKoh^;R1_ooool7ob/[:`OoiNGU1oli
>CT7o`h>3POo8B4Q1_lS8b<7oa@D50Ko=3@d1_ooool7oaXJ6POo<30`1ooVi^H7oc`l?0Ko4Q8B1olC
4a<7o``<30Ko<30`1_ooool7oc8b<POo9bLW1olQ8B47o`D51@Ko6a/K1ooNg]h7odI6APKoI6AT1_oo
ool7o`0000Oo4a<C1ol92@T6o`<30`Oo4A4A1ol71`L7oa4A4@KoEEEE1_ooool7ob8R8POo:BTY1oo7
alL6ojFUY@OoFUYJ1ol61PH7ogalO0Ko9bLW1_ooool7oaDE5@Oo4Q8B1_lG5aL7ochn?POok^k^1olf
=SH7o`<30`Ko<30`1_ooool7ogemO@KoJf][1ole=CD7ochn?POol?3`1ooKfm/7oa`L70Ko>CTi3_oo
ool000cooooo1omiNGT7obPX:0Oo6QXJ1ol`<307ogIfMPKoUYJF1onj^[X6on;RhPKooooo1ol[:b/7
onGUi@Oo>CTi1ol>3Ph7ob4Q8@Ko8b<S1olD51@6oc@d=0Kooooo1olJ6QX7oc0`<0Ooi^KV1oll?3`6
oa8B4POo4a<C1ol<30`6oc0`<0Kooooo1olb<S87obLW9`Oo8B4Q1ol51@D6oa/K6`Oog]kN1om6ATH6
ofATI0Kooooo1ol00007oa<C4`Oo2@T91_l30`<7oa4A4@Oo1`L71olA4A46oeEEE@Kooooo1olR8R87
obTY:@OoalO71_nUYJD7oeYJFPOo1PH61omlO7`6obLW9`Kooooo1olE5AD7oa8B4PKo5aLG1oln?Sh7
onk^kPOo=SHf1ol30`<6oc0`<0Kooooo1ommOGd6of][J`Oo=CDe1oln?Sh7oo3`l0Oofm_K1olL71`6
ocTi>@kooooo000<ooooo`OoKVi^1ol10@47oa4A4@Oo1@D51om5ADD6ofATI0OoYjNW1_n^[Zh6oooo
o`Oo;Bd]1oogmoL7ocLg=`Oo51@D1olV9RH6oa`L70Oo4a<C1_ld=3@6ooooo`Oo:b/[1olV9RH7on_[
j`Oo?Cdm1_l@4107oa@D50Oo1`L71_ld=3@6ooooo`Oo?Shn1olY:BT7oadM7@Oo5ADE1_lk>c/7okno
_`OoA4A41_m<C4`6ooooo`Oo2PX:1olI6AT7o`l?3`Ko2`/;1ol@4107o`820POo30`<1_mYJFT6oooo
o`OoA4A41ooKfm/7oi:BTPKoWinO1ol820P7oaXJ6POo:RXZ1_mLG5`6ooooo`Oo1@D51ol;2`/6obd]
;@Oo?3`l1oooool7oc@d=0Oo2@T91_lX:2P6ooooo`OoOgmo1_m]KFd7ob<S8`Oo>3Ph1ookno/7onOW
i`Oo5aLG1_m1@D4>ooooo`003?ooool7ofi^KPOo0@411olA4A47o`D51@OoADE51_mTI6@7ojNWY`Ko
[Zj^1_ooool7obd];@OomoOg1olg=cL7oa@D50Oo9RHV1_lL71`7oa<C4`Ko=3@d1_ooool7ob/[:`Oo
9RHV1oo[jn/7ocdm?@Ko410@1olD51@7o`L71`Ko=3@d1_ooool7ochn?POo:BTY1olM7Ad7oaDE5@Ko
>c/k1ono_kl7odA4A0KoC4a<1_ooool7o`X:2POo6ATI1ol?3`l6o`/;2`Oo410@1ol20P87o``<30Ko
JFUY1_ooool7odA4A0Oofm_K1onBTY86oinOW`Oo20P81olJ6QX7obXZ:PKoG5aL1_ooool7o`D51@Oo
2`/;1_l];Bd7oc`l?0Oooooo1old=3@7o`T92@Ko:2PX1_ooool7ogmoO`KoKFe]1olS8b<7ocPh>0Oo
no_k1ooWinL7oaLG5`Ko@D513_ooool000cooooo1om^KVh7o`410@Oo4A4A1ol51@D7odE5A@KoI6AT
1onWYjL6ojj^[PKooooo1ol];Bd7ooOgm`Oo=cLg1olD51@7obHV9PKo71`L1olC4a<6oc@d=0Kooooo
1ol[:b/7obHV9POojn_[1olm?Cd6oa0@40Oo51@D1ol71`L6oc@d=0Kooooo1oln?Sh7obTY:@Oo7AdM
1olE5AD6oc/k>`Oo_kno1om4A4@6oda<C0Kooooo1ol:2PX7oaTI6@Oo3`l?1_l;2`/7oa0@40Oo0P82
1ol<30`6ofUYJ@Kooooo1om4A4@7om_Kf`OoTY:B1_nOWil7o`P820Oo6QXJ1olZ:RX6oeaLG0Kooooo
1ol51@D7o`/;2`Ko;Bd]1oll?3`7ooooo`Oo=3@d1ol92@T6obPX:0Kooooo1omoOgl6ofe]K@Oo8b<S
1olh>3P7oo_kn`OoinOW1olG5aL6od51@@kooooo000<ooooo`OoKVi^1ol10@47oa4A4@Oo1@D51om5
ADD6ofATI0OoYjNW1_n^[Zh6ooooo`Oo;Bd]1oogmoL7ocLg=`Oo51@D1olV9RH6oa`L70Oo4a<C1_ld
=3@6ooooo`Oo:b/[1olV9RH7on_[j`Oo?Cdm1_l@4107oa@D50Oo1`L71_ld=3@6ooooo`Oo?Shn1olY
:BT7oadM7@Oo5ADE1_lk>c/7okno_`OoA4A41_m<C4`6ooooo`Oo2PX:1olI6AT7o`l?3`Ko2`/;1ol@
4107o`820POo30`<1_mYJFT6ooooo`OoA4A41ooKfm/7oi:BTPKoWinO1ol820P7oaXJ6POo:RXZ1_mL
G5`6ooooo`Oo1@D51ol;2`/6obd];@Oo?3`l1oooool7oc@d=0Oo2@T91_lX:2P6ooooo`OoOgmo1_m]
KFd7ob<S8`Oo>3Ph1ookno/7onOWi`Oo5aLG1_m1@D4>ooooo`003?ooool7ofi^KPOo0@411olA4A47
o`D51@OoADE51_mTI6@7ojNWY`Ko[Zj^1_ooool7obd];@OomoOg1olg=cL7oa@D50Oo9RHV1_lL71`7
oa<C4`Ko=3@d1_ooool7ob/[:`Oo9RHV1oo[jn/7ocdm?@Ko410@1olD51@7o`L71`Ko=3@d1_ooool7
ochn?POo:BTY1olM7Ad7oaDE5@Ko>c/k1ono_kl7odA4A0KoC4a<1_ooool7o`X:2POo6ATI1ol?3`l6
o`/;2`Oo410@1ol20P87o``<30KoJFUY1_ooool7odA4A0Oofm_K1onBTY86oinOW`Oo20P81olJ6QX7
obXZ:PKoG5aL1_ooool7o`D51@Oo2`/;1_l];Bd7oc`l?0Oooooo1old=3@7o`T92@Ko:2PX1_ooool7
ogmoO`KoKFe]1olS8b<7ocPh>0Oono_k1ooWinL7oaLG5`Ko@D513_ooool000cooooo1om^KVh7o`41
0@Oo4A4A1ol51@D7odE5A@KoI6AT1onWYjL6ojj^[PKooooo1ol];Bd7ooOgm`Oo=cLg1olD51@7obHV
9PKo71`L1olC4a<6oc@d=0Kooooo1ol[:b/7obHV9POojn_[1olm?Cd6oa0@40Oo51@D1ol71`L6oc@d
=0Kooooo1oln?Sh7obTY:@Oo7AdM1olE5AD6oc/k>`Oo_kno1om4A4@6oda<C0Kooooo1ol:2PX7oaTI
6@Oo3`l?1_l;2`/7oa0@40Oo0P821ol<30`6ofUYJ@Kooooo1om4A4@7om_Kf`OoTY:B1_nOWil7o`P8
20Oo6QXJ1olZ:RX6oeaLG0Kooooo1ol51@D7o`/;2`Ko;Bd]1oll?3`7ooooo`Oo=3@d1ol92@T6obPX
:0Kooooo1omoOgl6ofe]K@Oo8b<S1olh>3P7oo_kn`OoinOW1olG5aL6od51@@kooooo000<ooooo`Oo
O7al1olY:BT7oa@D50Oo8B4Q1om]KFd6ogmoO`Oo/[:b1_oPh>06ooooo`Oo;Bd]1oooool7ob`/;0Oo
00003OlN7Qh7oaTI6@Ko;2`/1_ooool7oalO7`Oo8B4Q1oooool7ocPh>0Ko2`/;1olA4A47o`0000Ko
>3Ph1_ooool7obDU9@Oo6a/K1ol/;2`7o`0000Ko:BTY1oooool7obl_;`KoFUYJ1_ooool7o`D51@Oo
2PX:1ol20P86o`L71`Oo3`l?1ol20P87o``<30KoOWin1_ooool7ocDe=@OoA4A41ooVi^H6ohf=S@Oo
8R8R1olJ6QX7okjn_PKo<S8b1_ooool7o`820POo6a/K1_lN7Qh7oc`l?0Ookno_1olY:BT7o`0000Ko
820P1_ooool7ohB4Q0KoM7Ad1olH61P7odE5A@Ooo?cl1ooFe]H7oa8B4PKo=CDe3_ooool000cooooo
1omlO7`7obTY:@Oo51@D1olQ8B47ofe]K@KoOgmo1onb/[86on3Ph0Kooooo1ol];Bd7ooooo`Oo;2`/
1ol0000=oahN7POo6ATI1_l/;2`6ooooo`Oo7alO1olQ8B47ooooo`Oo>3Ph1_l;2`/7oa4A4@Oo0000
1_lh>3P6ooooo`Oo9BDU1olK6a/7ob`/;0Oo00001_lY:BT7ooooo`Oo;bl_1_mJFUX6ooooo`Oo1@D5
1ol:2PX7o`820PKo1`L71ol?3`l7o`820POo30`<1_mnOWh6ooooo`Oo=CDe1om4A4@7onKViPKoSHf=
1olR8R87oaXJ6POo_[jn1_lb<S86ooooo`Oo0P821olK6a/6oahN7POo?3`l1oo_knl7obTY:@Oo0000
1_lP8206ooooo`OoQ8B41_mdM7@7oaPH60OoADE51oolo?`7omKFePOo4Q8B1_le=CD>ooooo`003?oo
ool7ogalO0Oo:BTY1olD51@7ob4Q8@OoKFe]1_moOgl7ok:b/PKoh>3P1_ooool7obd];@Oooooo1ol/
;2`7o`0000go7QhN1olI6AT6ob`/;0Kooooo1olO7al7ob4Q8@Oooooo1olh>3P6o`/;2`Oo4A4A1ol0
0006ocPh>0Kooooo1olU9BD7oa/K6`Oo;2`/1ol00006obTY:@Oooooo1ol_;bl6oeYJFPKooooo1ol5
1@D7o`X:2POo0P821_l71`L7o`l?3`Oo0P821ol<30`6oginOPKooooo1ole=CD7odA4A0Ooi^KV1_n=
SHd7ob8R8POo6QXJ1onn_[h6oc8b<PKooooo1ol20P87oa/K6`Ko7QhN1oll?3`7ono_k`Oo:BTY1ol0
0006ob0P80Kooooo1on4Q8@6ogAdM0Oo61PH1om5ADD7ooclo0Ooe]KF1olB4Q86ocDe=@kooooo000<
ooooo`OoO7al1olY:BT7oa@D50Oo8B4Q1om]KFd6ogmoO`Oo/[:b1_oPh>06ooooo`Oo;Bd]1oooool7
ob`/;0Oo00003OlN7Qh7oaTI6@Ko;2`/1_ooool7oalO7`Oo8B4Q1oooool7ocPh>0Ko2`/;1olA4A47
o`0000Ko>3Ph1_ooool7obDU9@Oo6a/K1ol/;2`7o`0000Ko:BTY1oooool7obl_;`KoFUYJ1_ooool7
o`D51@Oo2PX:1ol20P86o`L71`Oo3`l?1ol20P87o``<30KoOWin1_ooool7ocDe=@OoA4A41ooVi^H6
ohf=S@Oo8R8R1olJ6QX7okjn_PKo<S8b1_ooool7o`820POo6a/K1_lN7Qh7oc`l?0Ookno_1olY:BT7
o`0000Ko820P1_ooool7ohB4Q0KoM7Ad1olH61P7odE5A@Ooo?cl1ooFe]H7oa8B4PKo=CDe3_ooool0
00cooooo1omlO7`7obTY:@Oo51@D1olQ8B47ofe]K@KoOgmo1onb/[86on3Ph0Kooooo1ol];Bd7oooo
o`Oo;2`/1ol0000=oahN7POo6ATI1_l/;2`6ooooo`Oo7alO1olQ8B47ooooo`Oo>3Ph1_l;2`/7oa4A
4@Oo00001_lh>3P6ooooo`Oo9BDU1olK6a/7ob`/;0Oo00001_lY:BT7ooooo`Oo;bl_1_mJFUX6oooo
o`Oo1@D51ol:2PX7o`820PKo1`L71ol?3`l7o`820POo30`<1_mnOWh6ooooo`Oo=CDe1om4A4@7onKV
iPKoSHf=1olR8R87oaXJ6POo_[jn1_lb<S86ooooo`Oo0P821olK6a/6oahN7POo?3`l1oo_knl7obTY
:@Oo00001_lP8206ooooo`OoQ8B41_mdM7@7oaPH60OoADE51oolo?`7omKFePOo4Q8B1_le=CD>oooo
o`003?ooool7ogalO0Oo:BTY1olD51@7ob4Q8@OoKFe]1_moOgl7ok:b/PKoh>3P1_ooool7obd];@Oo
oooo1ol/;2`7o`0000go7QhN1olI6AT6ob`/;0Kooooo1olO7al7ob4Q8@Oooooo1olh>3P6o`/;2`Oo
4A4A1ol00006ocPh>0Kooooo1olU9BD7oa/K6`Oo;2`/1ol00006obTY:@Oooooo1ol_;bl6oeYJFPKo
oooo1ol51@D7o`X:2POo0P821_l71`L7o`l?3`Oo0P821ol<30`6oginOPKooooo1ole=CD7odA4A0Oo
i^KV1_n=SHd7ob8R8POo6QXJ1onn_[h6oc8b<PKooooo1ol20P87oa/K6`Ko7QhN1oll?3`7ono_k`Oo
:BTY1ol00006ob0P80Kooooo1on4Q8@6ogAdM0Oo61PH1om5ADD7ooclo0Ooe]KF1olB4Q86ocDe=@ko
oooo000<ooooo`OoO7al1olY:BT7oa@D50Oo8B4Q1om]KFd6ogmoO`Oo/[:b1_oPh>06ooooo`Oo;Bd]
1oooool7ob`/;0Oo00003OlN7Qh7oaTI6@Ko;2`/1_ooool7oalO7`Oo8B4Q1oooool7ocPh>0Ko2`/;
1olA4A47o`0000Ko>3Ph1_ooool7obDU9@Oo6a/K1ol/;2`7o`0000Ko:BTY1oooool7obl_;`KoFUYJ
1_ooool7o`D51@Oo2PX:1ol20P86o`L71`Oo3`l?1ol20P87o``<30KoOWin1_ooool7ocDe=@OoA4A4
1ooVi^H6ohf=S@Oo8R8R1olJ6QX7okjn_PKo<S8b1_ooool7o`820POo6a/K1_lN7Qh7oc`l?0Ookno_
1olY:BT7o`0000Ko820P1_ooool7ohB4Q0KoM7Ad1olH61P7odE5A@Ooo?cl1ooFe]H7oa8B4PKo=CDe
3_ooool000cooooo1om/K6`7o`0000Oo7QhN1ol;2`/7oe1@D0KoH61P1one]KD6oiZJVPKooooo1olg
=cL7ooWin@Oo:b/[1olB4Q87ob0P80Ko7AdM1olI6AT6ocPh>0Kooooo1ol^;Rh7ob<S8`Ook>c/1olk
>c/6o`X:2POo4a<C1ol51@D6oc4a<@Kooooo1old=3@7obLW9`Oo6QXJ1ol/;2`6oe=CD`Oo/[:b1ol[
:b/6odi>CPKooooo1olA4A47o`L71`go4a<C1ol@4107o`0000Oo20P81_nj^[X6ooooo`OoHV9R1ood
m?@7ohf=S@KoHF5Q1ol71`L7ob`/;0Oo=3@d1_l^;Rh6ooooo`Oo2PX:1olF5QH6obPX:0Oo?clo1ooc
lo<7ocXj>POo30`<1_la<C46ooooo`OoNGUi1_mbLW87oa4A4@OoBDU91oooool7olS8b0Oo61PH1_lc
<c<>ooooo`003?ooool7ofa/K0Oo00001olN7Qh7o`/;2`OoD51@1_mPH607okFe]@KoVYZJ1_ooool7
ocLg=`OonOWi1ol[:b/7oa8B4POo820P1_lM7Ad7oaTI6@Ko>3Ph1_ooool7obh^;POo8b<S1oo/k>`7
oc/k>`Ko2PX:1olC4a<7o`D51@Ko<C4a1_ooool7oc@d=0Oo9bLW1olJ6QX7ob`/;0KoDe=C1onb/[87
ob/[:`KoCTi>1_ooool7oa4A4@Oo1`L73OlC4a<7oa0@40Oo00001ol820P6okZj^PKooooo1omRHV87
ooCdm0OoSHf=1_mQHF47o`L71`Oo;2`/1old=3@6obh^;PKooooo1ol:2PX7oaHF5PKo:2PX1olo?cl7
oo?cl`Oo>SXj1ol<30`6oc4a<@Kooooo1omiNGT6og9bLPOo4A4A1om9BDT7ooooo`Oob<S81olH61P6
oc<c<`kooooo000<ooooo`OoK6a/1ol00007oahN7POo2`/;1om@D506of1PH0Oo]KFe1_nJVYX6oooo
o`Oo=cLg1ooinOT7ob/[:`Oo4Q8B1olP8206oadM7@Oo6ATI1_lh>3P6ooooo`Oo;Rh^1olS8b<7onc/
k0Oo>c/k1_l:2PX7oa<C4`Oo1@D51_la<C46ooooo`Oo=3@d1olW9bL7oaXJ6POo;2`/1_mCDe<7ok:b
/POo:b/[1_m>CTh6ooooo`Oo4A4A1ol71`L=oa<C4`Oo410@1ol00007o`P820Ko^[Zj1_ooool7of9R
HPOom?Cd1on=SHd6of5QH@Oo1`L71ol/;2`7oc@d=0Ko;Rh^1_ooool7o`X:2POo5QHF1_lX:2P7oclo
?`Oolo?c1olj>SX7o``<30Ko<C4a1_ooool7ogUiN@KoLW9b1olA4A47odU9B@Oooooo1oo8b<P7oaPH
60Ko<c<c3_ooool000cooooo1om/K6`7o`0000Oo7QhN1ol;2`/7oe1@D0KoH61P1one]KD6oiZJVPKo
oooo1olg=cL7ooWin@Oo:b/[1olB4Q87ob0P80Ko7AdM1olI6AT6ocPh>0Kooooo1ol^;Rh7ob<S8`Oo
k>c/1olk>c/6o`X:2POo4a<C1ol51@D6oc4a<@Kooooo1old=3@7obLW9`Oo6QXJ1ol/;2`6oe=CD`Oo
/[:b1ol[:b/6odi>CPKooooo1olA4A47o`L71`go4a<C1ol@4107o`0000Oo20P81_nj^[X6ooooo`Oo
HV9R1oodm?@7ohf=S@KoHF5Q1ol71`L7ob`/;0Oo=3@d1_l^;Rh6ooooo`Oo2PX:1olF5QH6obPX:0Oo
?clo1ooclo<7ocXj>POo30`<1_la<C46ooooo`OoNGUi1_mbLW87oa4A4@OoBDU91oooool7olS8b0Oo
61PH1_lc<c<>ooooo`003?ooool7ofa/K0Oo00001olN7Qh7o`/;2`OoD51@1_mPH607okFe]@KoVYZJ
1_ooool7ocLg=`OonOWi1ol[:b/7oa8B4POo820P1_lM7Ad7oaTI6@Ko>3Ph1_ooool7obh^;POo8b<S
1oo/k>`7oc/k>`Ko2PX:1olC4a<7o`D51@Ko<C4a1_ooool7oc@d=0Oo9bLW1olJ6QX7ob`/;0KoDe=C
1onb/[87ob/[:`KoCTi>1_ooool7oa4A4@Oo1`L73OlC4a<7oa0@40Oo00001ol820P6okZj^PKooooo
1omRHV87ooCdm0OoSHf=1_mQHF47o`L71`Oo;2`/1old=3@6obh^;PKooooo1ol:2PX7oaHF5PKo:2PX
1olo?cl7oo?cl`Oo>SXj1ol<30`6oc4a<@Kooooo1omiNGT6og9bLPOo4A4A1om9BDT7ooooo`Oob<S8
1olH61P6oc<c<`kooooo000<ooooo`OoK6a/1ol00007oahN7POo2`/;1om@D506of1PH0Oo]KFe1_nJ
VYX6ooooo`Oo=cLg1ooinOT7ob/[:`Oo4Q8B1olP8206oadM7@Oo6ATI1_lh>3P6ooooo`Oo;Rh^1olS
8b<7onc/k0Oo>c/k1_l:2PX7oa<C4`Oo1@D51_la<C46ooooo`Oo=3@d1olW9bL7oaXJ6POo;2`/1_mC
De<7ok:b/POo:b/[1_m>CTh6ooooo`Oo4A4A1ol71`L=oa<C4`Oo410@1ol00007o`P820Ko^[Zj1_oo
ool7of9RHPOom?Cd1on=SHd6of5QH@Oo1`L71ol/;2`7oc@d=0Ko;Rh^1_ooool7o`X:2POo5QHF1_lX
:2P7oclo?`Oolo?c1olj>SX7o``<30Ko<C4a1_ooool7ogUiN@KoLW9b1olA4A47odU9B@Oooooo1oo8
b<P7oaPH60Ko<c<c3_ooool000cooooo1om/K6`7o`0000Oo7QhN1ol;2`/7oe1@D0KoH61P1one]KD6
oiZJVPKooooo1olg=cL7ooWin@Oo:b/[1olB4Q87ob0P80Ko7AdM1olI6AT6ocPh>0Kooooo1ol^;Rh7
ob<S8`Ook>c/1olk>c/6o`X:2POo4a<C1ol51@D6oc4a<@Kooooo1old=3@7obLW9`Oo6QXJ1ol/;2`6
oe=CD`Oo/[:b1ol[:b/6odi>CPKooooo1olA4A47o`L71`go4a<C1ol@4107o`0000Oo20P81_nj^[X6
ooooo`OoHV9R1oodm?@7ohf=S@KoHF5Q1ol71`L7ob`/;0Oo=3@d1_l^;Rh6ooooo`Oo2PX:1olF5QH6
obPX:0Oo?clo1ooclo<7ocXj>POo30`<1_la<C46ooooo`OoNGUi1_mbLW87oa4A4@OoBDU91oooool7
olS8b0Oo61PH1_lc<c<>ooooo`003?ooool7ofm_K`Oo6a/K1olV9RH7oa<C4`OoKFe]1_meMGD7okBd
]0Kohn?S1_ooool7oc4a<@OonOWi1olZ:RX7o`0000Oo92@T1_lG5aL7oadM7@Ko:b/[1_ooool7ob8R
8POo6a/K1ooalO47ocDe=@Ko4A4A1olW9bL7o`l?3`Ko>CTi1_ooool7oahN7POo6ATI1oli>CT7o`X:
2PKoATI61ooUiND7ob@T90KoD51@1_ooool7oa<C4`Oo1PH61ol410@6o`T92@Oo3@d=1ol:2PX7o``<
30Kog=cL1_ooool7odU9B@OoJf][1ooHf=P6ofYZJPOo00001om7AdL7omkNgPKo<C4a1_ooool7o`T9
2@Oo8B4Q1_l[:b/7od=3@`Oon?Sh1ol`<307o`d=3@Ko:2PX1_ooool7ogMgM`KoLg=c1ol00007ofMW
I`Ook>c/1onZZZX7o`h>3PKo9RHV3_ooool000cooooo1om_Kfl7oa/K6`Oo9RHV1olC4a<7ofe]K@Ko
MGEe1ond];@6on?Sh`Kooooo1ola<C47ooWin@Oo:RXZ1ol00007ob@T90Ko5aLG1olM7Ad6ob/[:`Ko
oooo1olR8R87oa/K6`OolO7a1ole=CD6oa4A4@Oo9bLW1ol?3`l6ocTi>@Kooooo1olN7Qh7oaTI6@Oo
>CTi1ol:2PX6odI6APOoiNGU1olT92@6oe1@D0Kooooo1olC4a<7o`H61POo10@41_l92@T7o`d=3@Oo
2PX:1ol<30`6omcLg0Kooooo1om9BDT7of][J`Oof=SH1_mZJVX7o`0000OoAdM71ooNg]h6oc4a<@Ko
oooo1ol92@T7ob4Q8@Ko:b/[1om3@d<7ooShn0Oo<30`1ol=3@d6obPX:0Kooooo1omgMgL6og=cL`Oo
00001omWIfL7onc/k0OoZZZZ1ol>3Ph6obHV9Pkooooo000<ooooo`OoKfm_1olK6a/7obHV9POo4a<C
1om]KFd6ogEeM@Oo];Bd1_oShn<6ooooo`Oo<C4a1ooinOT7obXZ:POo00001olT92@6oaLG5`Oo7AdM
1_l[:b/6ooooo`Oo8R8R1olK6a/7oo7al@Oo=CDe1_lA4A47obLW9`Oo3`l?1_li>CT6ooooo`Oo7QhN
1olI6AT7ocTi>@Oo2PX:1_m6ATH7onGUi@Oo92@T1_m@D506ooooo`Oo4a<C1ol61PH7o`@410Ko2@T9
1ol=3@d7o`X:2POo30`<1_oLg=`6ooooo`OoBDU91om[Jf/7omSHf0KoJVYZ1ol00007odM7A`Oog]kN
1_la<C46ooooo`Oo2@T91olQ8B46ob/[:`Oo@d=31oohn?P7oc0`<0Oo3@d=1_lX:2P6ooooo`OoMgMg
1_mcLg<7o`0000OoIfMW1oo/k>`7ojZZZPOo3Ph>1_lV9RH>ooooo`003?ooool7ofm_K`Oo6a/K1olV
9RH7oa<C4`OoKFe]1_meMGD7okBd]0Kohn?S1_ooool7oc4a<@OonOWi1olZ:RX7o`0000Oo92@T1_lG
5aL7oadM7@Ko:b/[1_ooool7ob8R8POo6a/K1ooalO47ocDe=@Ko4A4A1olW9bL7o`l?3`Ko>CTi1_oo
ool7oahN7POo6ATI1oli>CT7o`X:2PKoATI61ooUiND7ob@T90KoD51@1_ooool7oa<C4`Oo1PH61ol4
10@6o`T92@Oo3@d=1ol:2PX7o``<30Kog=cL1_ooool7odU9B@OoJf][1ooHf=P6ofYZJPOo00001om7
AdL7omkNgPKo<C4a1_ooool7o`T92@Oo8B4Q1_l[:b/7od=3@`Oon?Sh1ol`<307o`d=3@Ko:2PX1_oo
ool7ogMgM`KoLg=c1ol00007ofMWI`Ook>c/1onZZZX7o`h>3PKo9RHV3_ooool000cooooo1om_Kfl7
oa/K6`Oo9RHV1olC4a<7ofe]K@KoMGEe1ond];@6on?Sh`Kooooo1ola<C47ooWin@Oo:RXZ1ol00007
ob@T90Ko5aLG1olM7Ad6ob/[:`Kooooo1olR8R87oa/K6`OolO7a1ole=CD6oa4A4@Oo9bLW1ol?3`l6
ocTi>@Kooooo1olN7Qh7oaTI6@Oo>CTi1ol:2PX6odI6APOoiNGU1olT92@6oe1@D0Kooooo1olC4a<7
o`H61POo10@41_l92@T7o`d=3@Oo2PX:1ol<30`6omcLg0Kooooo1om9BDT7of][J`Oof=SH1_mZJVX7
o`0000OoAdM71ooNg]h6oc4a<@Kooooo1ol92@T7ob4Q8@Ko:b/[1om3@d<7ooShn0Oo<30`1ol=3@d6
obPX:0Kooooo1omgMgL6og=cL`Oo00001omWIfL7onc/k0OoZZZZ1ol>3Ph6obHV9Pkooooo000<oooo
o`OoKfm_1olK6a/7obHV9POo4a<C1om]KFd6ogEeM@Oo];Bd1_oShn<6ooooo`Oo<C4a1ooinOT7obXZ
:POo00001olT92@6oaLG5`Oo7AdM1_l[:b/6ooooo`Oo8R8R1olK6a/7oo7al@Oo=CDe1_lA4A47obLW
9`Oo3`l?1_li>CT6ooooo`Oo7QhN1olI6AT7ocTi>@Oo2PX:1_m6ATH7onGUi@Oo92@T1_m@D506oooo
o`Oo4a<C1ol61PH7o`@410Ko2@T91ol=3@d7o`X:2POo30`<1_oLg=`6ooooo`OoBDU91om[Jf/7omSH
f0KoJVYZ1ol00007odM7A`Oog]kN1_la<C46ooooo`Oo2@T91olQ8B46ob/[:`Oo@d=31oohn?P7oc0`
<0Oo3@d=1_lX:2P6ooooo`OoMgMg1_mcLg<7o`0000OoIfMW1oo/k>`7ojZZZPOo3Ph>1_lV9RH>oooo
o`003?ooool7oh61P@Oo4Q8B1ol[:b/7oa/K6`OoJFUY1_m]KFd7ol_;b`KoXj>S1_ooool7od51@@Oo
fm_K1ol];Bd7oaPH60Oo7alO1_lW9bL7oadM7@Ko>c/k1_ooool7ob`/;0Oo92@T1ooCdm<7ocXj>PKo
3@d=1olF5QH7oaDE5@Ko@T921_ooool7obl_;`ko8R8R1olg=cL6ofATI0OoTY:B1olP8206oeADE0Ko
oooo1olJ6QX7o`H61POo3Ph>3Ol92@T7o`d=3@Oo3Ph>3?ooool7ogQhN0Ool_;b1omoOgl6ob8R8POo
4a<C1oln?Sh7oe5AD@Ko71`L1_ooool7oa<C4`Oo51@D1_l];Bd7oda<C0Ooe]KF1oln?Sh7o`d=3@Ko
:b/[1_ooool7of][J`KoGUiN1olA4A47oeeMG@Ooi>CT1onCTi<7ob0P80Ko;bl_3_ooool000cooooo
1on1PH47oa8B4POo:b/[1olK6a/7ofUYJ@KoKFe]1oo;bl/6oj>SX`Kooooo1om1@D47om_Kf`Oo;Bd]
1olH61P7oalO7`Ko9bLW1olM7Ad6oc/k>`Kooooo1ol/;2`7ob@T90Oodm?C1olj>SX6o`d=3@Oo5QHF
1olE5AD6od92@PKooooo1ol_;bl>ob8R8POo=cLg1_mTI6@7oi:BTPOo820P1_mDE5@6ooooo`Oo6QXJ
1ol61PH7o`h>3Pgo2@T91ol=3@d7o`h>3Pcooooo1omhN7P7oo;blPOoOgmo1_lR8R87oa<C4`Oo?Shn
1omADE46oa`L70Kooooo1olC4a<7oa@D50Ko;Bd]1om<C4`7omKFePOo?Shn1ol=3@d6ob/[:`Kooooo
1om[Jf/6oeiNGPOo4A4A1omMGEd7onCTi0OoTi>C1olP8206obl_;`kooooo000<ooooo`OoPH611olB
4Q87ob/[:`Oo6a/K1omYJFT6ofe]K@Oobl_;1_nSXj<6ooooo`Oo@D511ooKfm/7obd];@Oo61PH1olO
7al6obLW9`Oo7AdM1_lk>c/6ooooo`Oo;2`/1olT92@7om?Cd`Oo>SXj1_l=3@d7oaHF5POo5ADE1_m2
@T86ooooo`Oo;bl_3_lR8R87ocLg=`KoI6AT1onBTY87ob0P80KoE5AD1_ooool7oaXJ6POo1PH61ol>
3Ph=o`T92@Oo3@d=1ol>3Ph<ooooo`OoN7Qh1oobl_87ogmoO`Ko8R8R1olC4a<7ochn?POoDE5A1_lL
71`6ooooo`Oo4a<C1olD51@6obd];@OoC4a<1ooFe]H7ochn?POo3@d=1_l[:b/6ooooo`OoJf][1_mN
GUh7oa4A4@OoGEeM1ooTi>@7oi>CT`Oo820P1_l_;bl>ooooo`003?ooool7oh61P@Oo4Q8B1ol[:b/7
oa/K6`OoJFUY1_m]KFd7ol_;b`KoXj>S1_ooool7od51@@Oofm_K1ol];Bd7oaPH60Oo7alO1_lW9bL7
oadM7@Ko>c/k1_ooool7ob`/;0Oo92@T1ooCdm<7ocXj>PKo3@d=1olF5QH7oaDE5@Ko@T921_ooool7
obl_;`ko8R8R1olg=cL6ofATI0OoTY:B1olP8206oeADE0Kooooo1olJ6QX7o`H61POo3Ph>3Ol92@T7
o`d=3@Oo3Ph>3?ooool7ogQhN0Ool_;b1omoOgl6ob8R8POo4a<C1oln?Sh7oe5AD@Ko71`L1_ooool7
oa<C4`Oo51@D1_l];Bd7oda<C0Ooe]KF1oln?Sh7o`d=3@Ko:b/[1_ooool7of][J`KoGUiN1olA4A47
oeeMG@Ooi>CT1onCTi<7ob0P80Ko;bl_3_ooool000cooooo1on1PH47oa8B4POo:b/[1olK6a/7ofUY
J@KoKFe]1oo;bl/6oj>SX`Kooooo1om1@D47om_Kf`Oo;Bd]1olH61P7oalO7`Ko9bLW1olM7Ad6oc/k
>`Kooooo1ol/;2`7ob@T90Oodm?C1olj>SX6o`d=3@Oo5QHF1olE5AD6od92@PKooooo1ol_;bl>ob8R
8POo=cLg1_mTI6@7oi:BTPOo820P1_mDE5@6ooooo`Oo6QXJ1ol61PH7o`h>3Pgo2@T91ol=3@d7o`h>
3Pcooooo1omhN7P7oo;blPOoOgmo1_lR8R87oa<C4`Oo?Shn1omADE46oa`L70Kooooo1olC4a<7oa@D
50Ko;Bd]1om<C4`7omKFePOo?Shn1ol=3@d6ob/[:`Kooooo1om[Jf/6oeiNGPOo4A4A1omMGEd7onCT
i0OoTi>C1olP8206obl_;`kooooo000<ooooo`OoPH611olB4Q87ob/[:`Oo6a/K1omYJFT6ofe]K@Oo
bl_;1_nSXj<6ooooo`Oo@D511ooKfm/7obd];@Oo61PH1olO7al6obLW9`Oo7AdM1_lk>c/6ooooo`Oo
;2`/1olT92@7om?Cd`Oo>SXj1_l=3@d7oaHF5POo5ADE1_m2@T86ooooo`Oo;bl_3_lR8R87ocLg=`Ko
I6AT1onBTY87ob0P80KoE5AD1_ooool7oaXJ6POo1PH61ol>3Ph=o`T92@Oo3@d=1ol>3Ph<ooooo`Oo
N7Qh1oobl_87ogmoO`Ko8R8R1olC4a<7ochn?POoDE5A1_lL71`6ooooo`Oo4a<C1olD51@6obd];@Oo
C4a<1ooFe]H7ochn?POo3@d=1_l[:b/6ooooo`OoJf][1_mNGUh7oa4A4@OoGEeM1ooTi>@7oi>CT`Oo
820P1_l_;bl>ooooo`003?ooool7oh61P@Oo4Q8B1ol[:b/7oa/K6`OoJFUY1_m]KFd7ol_;b`KoXj>S
1_ooool7od51@@Oofm_K1ol];Bd7oaPH60Oo7alO1_lW9bL7oadM7@Ko>c/k1_ooool7ob`/;0Oo92@T
1ooCdm<7ocXj>PKo3@d=1olF5QH7oaDE5@Ko@T921_ooool7obl_;`ko8R8R1olg=cL6ofATI0OoTY:B
1olP8206oeADE0Kooooo1olJ6QX7o`H61POo3Ph>3Ol92@T7o`d=3@Oo3Ph>3?ooool7ogQhN0Ool_;b
1omoOgl6ob8R8POo4a<C1oln?Sh7oe5AD@Ko71`L1_ooool7oa<C4`Oo51@D1_l];Bd7oda<C0Ooe]KF
1oln?Sh7o`d=3@Ko:b/[1_ooool7of][J`KoGUiN1olA4A47oeeMG@Ooi>CT1onCTi<7ob0P80Ko;bl_
3_ooool000cooooo1omaLG47oclo?`OoADE51olc<c<7ogEeM@KoNWYj1ono_kl<ooooo`Oo=SHf1oo?
cll7ob4Q8@Oo1`L71olR8R86oa/K6`Oo8R8R1_l/;2`6ooooo`Oo6a/K1olM7Ad7olC4a0Oo=cLg1_l<
30`7ob4Q8@Oo7alO1_m5ADD6ooooo`Oo4a<C1ol>3Ph7oc0`<0Oo4Q8B1_mBDU87ol?3``Oo8B4Q1_lm
?Cd6ooooo`Oo51@D1olA4A47o`T92@Ko2PX:1ol00007o`T92@Oo30`<1_o1`L46ooooo`OoEUIF1omL
G5`7ol30`0KoGUiN1ol00007of][J`Oooooo1_lh>3P6ooooo`Oo4A4A1olS8b<6obPX:0Oo@D511oo2
`/87oc@d=0Oo3@d=1_lc<c<6ooooo`OoHf=S1_mNGUh7o`D51@OoL71`1oo;bl/7ogMgM`Oo4A4A1_lL
71`>ooooo`003?ooool7og5aL@Oo?clo1om5ADD7oc<c<`OoMGEe1_mjNWX7okno_`cooooo1olf=SH7
olo?c`Oo8B4Q1ol71`L7ob8R8PKo6a/K1olR8R86ob`/;0Kooooo1olK6a/7oadM7@Ooa<C41olg=cL6
o``<30Oo8B4Q1olO7al6odE5A@Kooooo1olC4a<7o`h>3POo<30`1olB4Q86oe9BDPOo`l?31olQ8B46
ocdm?@Kooooo1olD51@7oa4A4@Oo2@T91_l:2PX7o`0000Oo2@T91ol<30`6ol71`@Kooooo1omFEUH7
oeaLG0Oo`<301_mNGUh7o`0000OoJf][1oooool6ocPh>0Kooooo1olA4A47ob<S8`Ko:2PX1om1@D47
ol;2`POo=3@d1ol=3@d6oc<c<`Kooooo1omSHf<6oeiNGPOo1@D51om`L707ol_;b`OoMgMg1olA4A46
oa`L70kooooo000<ooooo`OoLG5a1olo?cl7odE5A@Oo<c<c1omeMGD6ogYjNPOo_kno3?ooool7ocHf
=POoclo?1olQ8B47o`L71`Oo8R8R1_lK6a/7ob8R8PKo;2`/1_ooool7oa/K6`Oo7AdM1oo4a<@7ocLg
=`Ko30`<1olQ8B47oalO7`KoADE51_ooool7oa<C4`Oo3Ph>1ol`<307oa8B4PKoDU9B1oo3`l<7ob4Q
8@Ko?Cdm1_ooool7oa@D50Oo4A4A1ol92@T6o`X:2POo00001ol92@T7o``<30Ko`L711_ooool7oeIF
EPOoG5aL1oo0`<06oeiNGPOo00001om[Jf/7ooooo`Ko>3Ph1_ooool7oa4A4@Oo8b<S1_lX:2P7od51
@@Oo`/;21old=3@7o`d=3@Ko<c<c1_ooool7of=SH`KoGUiN1ol51@D7og1`L0Oobl_;1omgMgL7oa4A
4@Ko71`L3_ooool000cooooo1omaLG47oclo?`OoADE51olc<c<7ogEeM@KoNWYj1ono_kl<ooooo`Oo
=SHf1oo?cll7ob4Q8@Oo1`L71olR8R86oa/K6`Oo8R8R1_l/;2`6ooooo`Oo6a/K1olM7Ad7olC4a0Oo
=cLg1_l<30`7ob4Q8@Oo7alO1_m5ADD6ooooo`Oo4a<C1ol>3Ph7oc0`<0Oo4Q8B1_mBDU87ol?3``Oo
8B4Q1_lm?Cd6ooooo`Oo51@D1olA4A47o`T92@Ko2PX:1ol00007o`T92@Oo30`<1_o1`L46ooooo`Oo
EUIF1omLG5`7ol30`0KoGUiN1ol00007of][J`Oooooo1_lh>3P6ooooo`Oo4A4A1olS8b<6obPX:0Oo
@D511oo2`/87oc@d=0Oo3@d=1_lc<c<6ooooo`OoHf=S1_mNGUh7o`D51@OoL71`1oo;bl/7ogMgM`Oo
4A4A1_lL71`>ooooo`003?ooool7og5aL@Oo?clo1om5ADD7oc<c<`OoMGEe1_mjNWX7okno_`cooooo
1olf=SH7olo?c`Oo8B4Q1ol71`L7ob8R8PKo6a/K1olR8R86ob`/;0Kooooo1olK6a/7oadM7@Ooa<C4
1olg=cL6o``<30Oo8B4Q1olO7al6odE5A@Kooooo1olC4a<7o`h>3POo<30`1olB4Q86oe9BDPOo`l?3
1olQ8B46ocdm?@Kooooo1olD51@7oa4A4@Oo2@T91_l:2PX7o`0000Oo2@T91ol<30`6ol71`@Kooooo
1omFEUH7oeaLG0Oo`<301_mNGUh7o`0000OoJf][1oooool6ocPh>0Kooooo1olA4A47ob<S8`Ko:2PX
1om1@D47ol;2`POo=3@d1ol=3@d6oc<c<`Kooooo1omSHf<6oeiNGPOo1@D51om`L707ol_;b`OoMgMg
1olA4A46oa`L70kooooo000<ooooo`OoLG5a1olo?cl7odE5A@Oo<c<c1omeMGD6ogYjNPOo_kno3?oo
ool7ocHf=POoclo?1olQ8B47o`L71`Oo8R8R1_lK6a/7ob8R8PKo;2`/1_ooool7oa/K6`Oo7AdM1oo4
a<@7ocLg=`Ko30`<1olQ8B47oalO7`KoADE51_ooool7oa<C4`Oo3Ph>1ol`<307oa8B4PKoDU9B1oo3
`l<7ob4Q8@Ko?Cdm1_ooool7oa@D50Oo4A4A1ol92@T6o`X:2POo00001ol92@T7o``<30Ko`L711_oo
ool7oeIFEPOoG5aL1oo0`<06oeiNGPOo00001om[Jf/7ooooo`Ko>3Ph1_ooool7oa4A4@Oo8b<S1_lX
:2P7od51@@Oo`/;21old=3@7o`d=3@Ko<c<c1_ooool7of=SH`KoGUiN1ol51@D7og1`L0Oobl_;1omg
MgL7oa4A4@Ko71`L3_ooool000cooooo1omaLG47oclo?`OoADE51olc<c<7ogEeM@KoNWYj1ono_kl<
ooooo`Oo=SHf1oo?cll7ob4Q8@Oo1`L71olR8R86oa/K6`Oo8R8R1_l/;2`6ooooo`Oo6a/K1olM7Ad7
olC4a0Oo=cLg1_l<30`7ob4Q8@Oo7alO1_m5ADD6ooooo`Oo4a<C1ol>3Ph7oc0`<0Oo4Q8B1_mBDU87
ol?3``Oo8B4Q1_lm?Cd6ooooo`Oo51@D1olA4A47o`T92@Ko2PX:1ol00007o`T92@Oo30`<1_o1`L46
ooooo`OoEUIF1omLG5`7ol30`0KoGUiN1ol00007of][J`Oooooo1_lh>3P6ooooo`Oo4A4A1olS8b<6
obPX:0Oo@D511oo2`/87oc@d=0Oo3@d=1_lc<c<6ooooo`OoHf=S1_mNGUh7o`D51@OoL71`1oo;bl/7
ogMgM`Oo4A4A1_lL71`>ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-1.81198, \
-0.862434, 0.14679, 0.14679}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-10.6148, -0.862434, 0.14679, 0.14679}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-19.4177, -0.862434, 0.14679, 0.14679}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-28.2205, -0.862434, 0.14679, 0.14679}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-37.0188, -0.862434, 0.14679, 0.14679}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-45.8262, -0.862434, 0.14679, \
0.14679}, {{372.125, 426.625}, {240.25, 185.75}} -> {-54.6244, -0.862434, \
0.14679, 0.14679}, {{432.062, 486.625}, {240.25, 185.75}} -> {-63.4273, \
-0.862434, 0.14679, 0.14679}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-1.81198, -9.66986, 0.14679, 0.14679}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-10.6148, -9.66986, 0.14679, 0.14679}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-19.4177, -9.66986, 0.14679, 0.14679}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-28.2205, -9.66986, 0.14679, 0.14679}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-37.0188, -9.66986, 0.14679, \
0.14679}, {{312.188, 366.688}, {180.25, 125.75}} -> {-45.8262, -9.66986, \
0.14679, 0.14679}, {{372.125, 426.625}, {180.25, 125.75}} -> {-54.6244, \
-9.66986, 0.14679, 0.14679}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-63.4273, -9.66986, 0.14679, 0.14679}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-1.81198, -18.4681, 0.14679, 0.14679}, {{72.3125, 126.812}, \
{120.312, 65.8125}} -> {-10.6148, -18.4681, 0.14679, 0.14679}, {{132.25, \
186.812}, {120.312, 65.8125}} -> {-19.4177, -18.4681, 0.14679, 0.14679}, \
{{192.25, 246.75}, {120.312, 65.8125}} -> {-28.2205, -18.4681, 0.14679, \
0.14679}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-37.0188, -18.4681, \
0.14679, 0.14679}, {{312.188, 366.688}, {120.312, 65.8125}} -> {-45.8262, \
-18.4681, 0.14679, 0.14679}, {{372.125, 426.625}, {120.312, 65.8125}} -> \
{-54.6244, -18.4681, 0.14679, 0.14679}, {{432.062, 486.625}, {120.312, \
65.8125}} -> {-63.4273, -18.4681, 0.14679, 0.14679}, {{12.3125, 66.875}, \
{60.3125, 5.8125}} -> {-1.81198, -27.2755, 0.14679, 0.14679}, {{72.3125, \
126.812}, {60.3125, 5.8125}} -> {-10.6148, -27.2755, 0.14679, 0.14679}, \
{{132.25, 186.812}, {60.3125, 5.8125}} -> {-19.4177, -27.2755, 0.14679, \
0.14679}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-28.2205, -27.2755, \
0.14679, 0.14679}, {{252.188, 306.688}, {60.3125, 5.8125}} -> {-37.0188, \
-27.2755, 0.14679, 0.14679}, {{312.188, 366.688}, {60.3125, 5.8125}} -> \
{-45.8262, -27.2755, 0.14679, 0.14679}, {{372.125, 426.625}, {60.3125, \
5.8125}} -> {-54.6244, -27.2755, 0.14679, 0.14679}, {{432.062, 486.625}, \
{60.3125, 5.8125}} -> {-63.4273, -27.2755, 0.14679, 0.14679}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
10665C86550D0155
004E477A3D1C3649
0A5946653F220B34
031F18351C060F48
1F36402F3412302F
50B6944C611B2072
62EEFFE26E353681
253935524006323D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
41039A3B116A0A4E
5C1F977221531D39
7117A3C81A661425
5D2B9DFA1D441728
7F4877FF00733729
524C51B602454214
722F1EDE034F692D
422557531A3F2D51
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
21130E0009040040
0F2216090204100E
0F222014110D1521
0F0E16151611181F
0F2017121D101035
2635120E10120A30
0619130F0C0A1218
462A2612171A06FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A43F154F0064214A
A073233409951A6C
95D7204C10965664
80BA0B5118997A7A
51D70B573375BC93
2786083C3A70FF58
0D87103A3A53D646
413B14351454471B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D17315A83314436
000B276ACC503E3A
05171C7ACF7A5053
0A10287AFFB97256
1C170D589D906988
14261F4C9F767170
1218303C5A58473D
20193486AC795665
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
912B3F03C338184B
FB2E6112B0672657
B90D6B1DACCD1C18
F714423CC2AC206F
8A1771396DFF0B48
82063B4575910783
3E0A721D20C0006E
4D013E36282E1BB9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
13481B623A1D3AFF
0B3D1C5161154EF8
0439394A721B4AF2
0E343431761555B5
042A31165E0F4F81
0C2B17114D003057
01371A0540063041
142A124F250E2365
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A6D490A20113F87
066756103A2633BE
1764630F2C3143B1
0B2A6C1433473AFF
053767143A4225DB
11195C08294E35D9
14223D0047361296
0E6E370431270E3B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
18271C598CE28987
192C175967FA843D
242C2C8196FF7E97
0C1B265634D86453
001722819BD57159
16152F704FD18228
1C202C7F92F5846C
4129203C8EE87B42
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
06493C0143063F44
1152530135044937
274C81063E036552
2653DC0546136B31
492EE4003620775E
3D3DFF0A3D295750
351FB30A3B2B487C
223B2D0D49292B3F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A211F2235061838
6E3A2E22261B196E
9257443B2B2025FF
9882553D232926A6
4A493D37181A2167
362D2D3612000B3B
25282F13140B1233
2E3426282B122659
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
57E71F622F91B46B
45B51056216CFF5F
1EC9124A466AE449
268017563A42D72A
224D084D42219328
3152126F11097251
385C00742C153FA4
756C37491F976D5F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F29231A11101330
090D080E090D0D1A
0018170E12060720
04180E16140E0813
0B11101312141025
090B100C11081219
0F12140C100F111A
54FF864065413831
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A1196E4071CD215D
860C514855FF0E7D
6F1B5A4141DC0DAF
2C00542725B51E73
28005F330C550DA0
1D077D3617581663
3C1574420F480847
8E287A2E7577134B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3319642348442EE4
110555002E3D29F9
350A36084E2212CB
4B0934166E181EAF
9B10421FB643134B
FF20442A96583E4A
DA25653CB497253E
723892386156519E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B65022A571F4E23
0E540D1830194F28
0B5406272400383B
14620E3E23123382
1C5D14342E0F3BCB
0C4C363E41163AFF
0D4C463C571A44FC
1C4A202D47275E62
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7B69CF424926474C
5F67C2485B002B3F
9382FF505C243A4D
94A2F67F9A2C5C4A
A8BBF5786632445C
4359724749313B34
62486E3C3A274441
7269F42C5A444753
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4E2356FF1B422B23
322759DD1C3C2D11
441D30A808414926
3D211C60133C3527
5C160E4800324624
62322536184C2157
7C3211330536273E
4A31637C1D34221B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C0E02050706101F
0805040706020729
0900040205040A26
030E04030607012B
010808030D070E12
03020802070A0121
1210100C11081115
4B233319242E2AFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
271400411009591B
2A28042D1A1E302A
5E37012303153419
5B910A16201A2A39
5AFF1D3E26293237
61EF273935312149
35BD1B34602C4B4F
3B6123483828433F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C2910252E58AD64
2C0E17182E59A872
46240A201B60AB5D
2D18000A21589268
3E20080612568634
2910061027498A57
2E240F03274A6F42
421F40292F85FF77
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5702161D194C1B62
7C0E1A2422382169
9115162B394F002F
DB163918319E1956
FF272D2F3FAB1F69
C44B544A28E6373E
A05B3A6825A93549
3825253B386F3D37
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D282C40851431FF
1B233D2C811833A7
0C221A1757143249
0636100E33092134
003B1916320C3326
044612061F0E3237
185E331B2613424B
253F30486219419E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A230138010F324E
1B2300720204237F
132D006C280F27F1
0A23046542022EC7
0A2B2564630E37FF
0C311C578A174FBA
001F2C396F0D52A3
0C1F0E2B310E3E2A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
355C2543282C477E
542C30193D1A4B91
315400241F385592
3F241D103719587A
37481725243A5376
6743482657165C83
534D2A253830559D
FFE4B062B480E9F9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
351F36172011116A
361B4E0009200071
2F376E17291C2139
3588E169401E2144
2144E4C0594C193D
2014A4FF9A773241
243E86A46B73273A
2933506630483569
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A20171310210DA8
4A2F050009020F81
311E101205080F6E
411E0503120B0E75
54280C120A0E0EFF
521E0C06081218AC
331F05060C0E18A0
672D292B2A16195A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5BCB382719081A37
6CFF564D48180741
2C72243149251837
0320132741122219
001F07215C1D241B
0809012233270E22
191E00122C221C23
6E772B27141B2631
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D020C1F180B0A10
08010915070B0314
0B070B1C130B0E0E
0900000E01040E1E
0E090B10000B0909
0509060F0407061E
0D050D12150A0E11
583563FF9291954B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
341512125BFF364D
1C1A1F1B4893412E
0A1B3419273E1C3B
1C283B2E060E1024
121B2F16000D081E
191E2E13070A0E27
1C0F2F2708261A17
38151F3E738A373C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4131FF1F2A16635B
251BB03B360D4262
1B0F79082A1A2D5D
0A0A37070F250F7C
030E1F102118025D
00061C001916064A
2B0B23082E261036
2D3FB52F4C264B44
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0711000B060E161C
0814061011141222
17110B110B0A1B29
1A0E061A02120D22
130C1120241C1540
2518132E1E1B1353
49181A3629201FFF
1C1E131F272C313F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool7oa0@40OoIVIV1omLG5`7ohJ6QPOoEEEE1_l=3@d7o`410@Ko
EEEE1_ooool7od51@@Oo0`<31onJVYX7oc/k>`Oo4A4A1_mZJVX7o`X:2PKoCTi>1_ooool7ob4Q8@Oo
4a<C1ol>3Ph7o`0000Ko2@T91ol410@7o`0000Ko@4101_ooool7ojBTY0Oo?clo1olE5AD7odm?C`Ko
00001omTI6@7ob4Q8@KoBTY:1_ooool7o`d=3@Oo5aLG1ola<C46oeYJFPOoPh>31ola<C47odA4A0Ko
=SHf1_ooool7oi6AT@Oo:b/[1olo?cl6o`<30`Oo`l?31olh>3P7oaPH60KoBd];1_ooool7oa<C4`Oo
B4Q81_lK6a/7of9RHPOo>SXj1olM7Ad7ocXj>Pcooooo1ol:2PX6ofe]K@OoBDU91ol:2PX7ob0P80Oo
4A4A1olo?cl6ohN7Q`kooooo000<ooooo`Oo410@1omVIVH7oeaLG0OoQXJ61omEEED6o`d=3@Oo0@41
1_mEEED6ooooo`Oo@D511ol30`<7oiZJVPOo>c/k1olA4A46ofYZJPOo2PX:1_m>CTh6ooooo`Oo8B4Q
1olC4a<7o`h>3POo00001_l92@T7o`@410Oo00001_m0@406ooooo`OoY:BT1olo?cl7oaDE5@OoCdm?
1_l00007ofATI0Oo8B4Q1_m:BTX6ooooo`Oo3@d=1olG5aL7oc4a<@KoFUYJ1on3Ph<7oc4a<@OoA4A4
1_lf=SH6ooooo`OoTI6A1ol[:b/7oclo?`Ko0`<31oo3`l<7ocPh>0Oo61PH1_m;Bd/6ooooo`Oo4a<C
1om8B4P6oa/K6`OoHV9R1olj>SX7oadM7@Oo>SXj3?ooool7o`X:2PKoKFe]1om9BDT7o`X:2POo820P
1olA4A47oclo?`KoQhN73_ooool000cooooo1ol@4107ofIVIPOoG5aL1on6QXH7oeEEE@Ko3@d=1ol1
0@46oeEEE@Kooooo1om1@D47o`<30`OoVYZJ1olk>c/7oa4A4@KoJVYZ1ol:2PX6odi>CPKooooo1olQ
8B47oa<C4`Oo3Ph>1ol00006o`T92@Oo10@41ol00006od10@0Kooooo1onTY:@7oclo?`Oo5ADE1om?
Cdl6o`0000OoI6AT1olQ8B46odY:BPKooooo1ol=3@d7oaLG5`Oo<C4a1_mJFUX7oh>3P`Oo<C4a1om4
A4@6ocHf=PKooooo1onATI47ob/[:`Oo?clo1_l30`<7ol?3``Oo>3Ph1olH61P6od];B`Kooooo1olC
4a<7odQ8B0Ko6a/K1omRHV87ocXj>POo7AdM1olj>SX<ooooo`Oo2PX:1_m]KFd7odU9B@Oo2PX:1olP
8207oa4A4@Oo?clo1_n7QhL>ooooo`003?ooool7oa0@40OoIVIV1omLG5`7ohJ6QPOoEEEE1_l=3@d7
o`410@KoEEEE1_ooool7od51@@Oo0`<31onJVYX7oc/k>`Oo4A4A1_mZJVX7o`X:2PKoCTi>1_ooool7
ob4Q8@Oo4a<C1ol>3Ph7o`0000Ko2@T91ol410@7o`0000Ko@4101_ooool7ojBTY0Oo?clo1olE5AD7
odm?C`Ko00001omTI6@7ob4Q8@KoBTY:1_ooool7o`d=3@Oo5aLG1ola<C46oeYJFPOoPh>31ola<C47
odA4A0Ko=SHf1_ooool7oi6AT@Oo:b/[1olo?cl6o`<30`Oo`l?31olh>3P7oaPH60KoBd];1_ooool7
oa<C4`OoB4Q81_lK6a/7of9RHPOo>SXj1olM7Ad7ocXj>Pcooooo1ol:2PX6ofe]K@OoBDU91ol:2PX7
ob0P80Oo4A4A1olo?cl6ohN7Q`kooooo000<ooooo`Oo410@1omVIVH7oeaLG0OoQXJ61omEEED6o`d=
3@Oo0@411_mEEED6ooooo`Oo@D511ol30`<7oiZJVPOo>c/k1olA4A46ofYZJPOo2PX:1_m>CTh6oooo
o`Oo8B4Q1olC4a<7o`h>3POo00001_l92@T7o`@410Oo00001_m0@406ooooo`OoY:BT1olo?cl7oaDE
5@OoCdm?1_l00007ofATI0Oo8B4Q1_m:BTX6ooooo`Oo3@d=1olG5aL7oc4a<@KoFUYJ1on3Ph<7oc4a
<@OoA4A41_lf=SH6ooooo`OoTI6A1ol[:b/7oclo?`Ko0`<31oo3`l<7ocPh>0Oo61PH1_m;Bd/6oooo
o`Oo4a<C1om8B4P6oa/K6`OoHV9R1olj>SX7oadM7@Oo>SXj3?ooool7o`X:2PKoKFe]1om9BDT7o`X:
2POo820P1olA4A47oclo?`KoQhN73_ooool000cooooo1ol@4107ofIVIPOoG5aL1on6QXH7oeEEE@Ko
3@d=1ol10@46oeEEE@Kooooo1om1@D47o`<30`OoVYZJ1olk>c/7oa4A4@KoJVYZ1ol:2PX6odi>CPKo
oooo1olQ8B47oa<C4`Oo3Ph>1ol00006o`T92@Oo10@41ol00006od10@0Kooooo1onTY:@7oclo?`Oo
5ADE1om?Cdl6o`0000OoI6AT1olQ8B46odY:BPKooooo1ol=3@d7oaLG5`Oo<C4a1_mJFUX7oh>3P`Oo
<C4a1om4A4@6ocHf=PKooooo1onATI47ob/[:`Oo?clo1_l30`<7ol?3``Oo>3Ph1olH61P6od];B`Ko
oooo1olC4a<7odQ8B0Ko6a/K1omRHV87ocXj>POo7AdM1olj>SX<ooooo`Oo2PX:1_m]KFd7odU9B@Oo
2PX:1olP8207oa4A4@Oo?clo1_n7QhL>ooooo`003?ooool7oa0@40OoIVIV1omLG5`7ohJ6QPOoEEEE
1_l=3@d7o`410@KoEEEE1_ooool7od51@@Oo0`<31onJVYX7oc/k>`Oo4A4A1_mZJVX7o`X:2PKoCTi>
1_ooool7ob4Q8@Oo4a<C1ol>3Ph7o`0000Ko2@T91ol410@7o`0000Ko@4101_ooool7ojBTY0Oo?clo
1olE5AD7odm?C`Ko00001omTI6@7ob4Q8@KoBTY:1_ooool7o`d=3@Oo5aLG1ola<C46oeYJFPOoPh>3
1ola<C47odA4A0Ko=SHf1_ooool7oi6AT@Oo:b/[1olo?cl6o`<30`Oo`l?31olh>3P7oaPH60KoBd];
1_ooool7oa<C4`OoB4Q81_lK6a/7of9RHPOo>SXj1olM7Ad7ocXj>Pcooooo1ol:2PX6ofe]K@OoBDU9
1ol:2PX7ob0P80Oo4A4A1olo?cl6ohN7Q`kooooo000<ooooo`Oo00001om>CTh7odM7A`OoNWYj1olm
?Cd6oa`L70Oo=SHf1_m9BDT6ooooo`OoG5aL1olO7al7oiNGU`OoLW9b1olQ8B46oe=CD`Oo7AdM1_li
>CT6ooooo`Oo3`l?1olR8R87oaHF5POo2@T91_l20P87o`@410Oo410@1_l>3Ph6ooooo`OoX:2P1omc
Lg<7ob<S8`Oo=3@d1_l92@T7oiFEU@Oo6QXJ1_m/K6`6ooooo`Oo00001ol;2`/7obLW9`KoJVYZ1oo<
c<`7oe1@D0Oo?Shn1_lj>SX6ooooo`Oono_k1ol^;Rh7of5QH@Ko4Q8B1on`/;07ofMWI`Oo9RHV1_mG
EeL6ooooo`Oo2`/;1olm?Cd6oa`L70OoDE5A1omQHF47oaDE5@OoCTi>1_ohn?P6ooooo`Oo1PH61_mW
IfL7oeIFEPOo410@1olj>SX7obHV9POo<c<c1_nn_[h>ooooo`003?ooool7o`0000OoCTi>1om7AdL7
ogYjNPOo?Cdm1_lL71`7ocHf=PKoBDU91_ooool7oeaLG0Oo7alO1onGUiL7og9bLPOo8B4Q1_mCDe<7
oadM7@Ko>CTi1_ooool7o`l?3`Oo8R8R1olF5QH7o`T92@Ko0P821ol410@7oa0@40Ko3Ph>1_ooool7
oj2PX0OoLg=c1olS8b<7oc@d=0Ko2@T91onEUID7oaXJ6PKoK6a/1_ooool7o`0000Oo2`/;1olW9bL6
ofYZJPOoc<c<1om@D507ochn?PKo>SXj1_ooool7oo_kn`Oo;Rh^1omQHF46oa8B4POo/;2`1omWIfL7
obHV9PKoEeMG1_ooool7o`/;2`Oo?Cdm1_lL71`7oe5AD@OoHF5Q1olE5AD7odi>CPKon?Sh1_ooool7
o`H61PKoIfMW1omFEUH7oa0@40Oo>SXj1olV9RH7oc<c<`Ko_[jn3_ooool000cooooo1ol00007odi>
CPOoAdM71omjNWX7ocdm?@Ko71`L1olf=SH6odU9B@Kooooo1omLG5`7oalO7`OoUiNG1ombLW87ob4Q
8@KoDe=C1olM7Ad6ocTi>@Kooooo1ol?3`l7ob8R8POo5QHF1ol92@T6o`820POo10@41ol@4106o`h>
3PKooooo1onPX:07og=cL`Oo8b<S1old=3@6o`T92@OoUIFE1olJ6QX6ofa/K0Kooooo1ol00007o`/;
2`Oo9bLW1_mZJVX7olc<c0OoD51@1oln?Sh6ocXj>PKooooo1ookno/7obh^;POoHF5Q1_lB4Q87ok2`
/0OoIfMW1olV9RH6oeMGE`Kooooo1ol;2`/7ocdm?@Ko71`L1omADE47of5QH@Oo5ADE1om>CTh6ooSh
n0Kooooo1ol61PH6ofMWI`OoEUIF1ol@4107ocXj>POo9RHV1olc<c<6okjn_Pkooooo000<ooooo`Oo
00001om>CTh7odM7A`OoNWYj1olm?Cd6oa`L70Oo=SHf1_m9BDT6ooooo`OoG5aL1olO7al7oiNGU`Oo
LW9b1olQ8B46oe=CD`Oo7AdM1_li>CT6ooooo`Oo3`l?1olR8R87oaHF5POo2@T91_l20P87o`@410Oo
410@1_l>3Ph6ooooo`OoX:2P1omcLg<7ob<S8`Oo=3@d1_l92@T7oiFEU@Oo6QXJ1_m/K6`6ooooo`Oo
00001ol;2`/7obLW9`KoJVYZ1oo<c<`7oe1@D0Oo?Shn1_lj>SX6ooooo`Oono_k1ol^;Rh7of5QH@Ko
4Q8B1on`/;07ofMWI`Oo9RHV1_mGEeL6ooooo`Oo2`/;1olm?Cd6oa`L70OoDE5A1omQHF47oaDE5@Oo
CTi>1_ohn?P6ooooo`Oo1PH61_mWIfL7oeIFEPOo410@1olj>SX7obHV9POo<c<c1_nn_[h>ooooo`00
3?ooool7o`0000OoCTi>1om7AdL7ogYjNPOo?Cdm1_lL71`7ocHf=PKoBDU91_ooool7oeaLG0Oo7alO
1onGUiL7og9bLPOo8B4Q1_mCDe<7oadM7@Ko>CTi1_ooool7o`l?3`Oo8R8R1olF5QH7o`T92@Ko0P82
1ol410@7oa0@40Ko3Ph>1_ooool7oj2PX0OoLg=c1olS8b<7oc@d=0Ko2@T91onEUID7oaXJ6PKoK6a/
1_ooool7o`0000Oo2`/;1olW9bL6ofYZJPOoc<c<1om@D507ochn?PKo>SXj1_ooool7oo_kn`Oo;Rh^
1omQHF46oa8B4POo/;2`1omWIfL7obHV9PKoEeMG1_ooool7o`/;2`Oo?Cdm1_lL71`7oe5AD@OoHF5Q
1olE5AD7odi>CPKon?Sh1_ooool7o`H61PKoIfMW1omFEUH7oa0@40Oo>SXj1olV9RH7oc<c<`Ko_[jn
3_ooool000cooooo1ol00007odi>CPOoAdM71omjNWX7ocdm?@Ko71`L1olf=SH6odU9B@Kooooo1omL
G5`7oalO7`OoUiNG1ombLW87ob4Q8@KoDe=C1olM7Ad6ocTi>@Kooooo1ol?3`l7ob8R8POo5QHF1ol9
2@T6o`820POo10@41ol@4106o`h>3PKooooo1onPX:07og=cL`Oo8b<S1old=3@6o`T92@OoUIFE1olJ
6QX6ofa/K0Kooooo1ol00007o`/;2`Oo9bLW1_mZJVX7olc<c0OoD51@1oln?Sh6ocXj>PKooooo1ook
no/7obh^;POoHF5Q1_lB4Q87ok2`/0OoIfMW1olV9RH6oeMGE`Kooooo1ol;2`/7ocdm?@Ko71`L1omA
DE47of5QH@Oo5ADE1om>CTh6ooShn0Kooooo1ol61PH6ofMWI`OoEUIF1ol@4107ocXj>POo9RHV1olc
<c<6okjn_Pkooooo000<ooooo`Oo00001om>CTh7odM7A`OoNWYj1olm?Cd6oa`L70Oo=SHf1_m9BDT6
ooooo`OoG5aL1olO7al7oiNGU`OoLW9b1olQ8B46oe=CD`Oo7AdM1_li>CT6ooooo`Oo3`l?1olR8R87
oaHF5POo2@T91_l20P87o`@410Oo410@1_l>3Ph6ooooo`OoX:2P1omcLg<7ob<S8`Oo=3@d1_l92@T7
oiFEU@Oo6QXJ1_m/K6`6ooooo`Oo00001ol;2`/7obLW9`KoJVYZ1oo<c<`7oe1@D0Oo?Shn1_lj>SX6
ooooo`Oono_k1ol^;Rh7of5QH@Ko4Q8B1on`/;07ofMWI`Oo9RHV1_mGEeL6ooooo`Oo2`/;1olm?Cd6
oa`L70OoDE5A1omQHF47oaDE5@OoCTi>1_ohn?P6ooooo`Oo1PH61_mWIfL7oeIFEPOo410@1olj>SX7
obHV9POo<c<c1_nn_[h>ooooo`003?ooool7o`X:2POoFEUI1om6ATH7ofEUI@Oo?clo1_lR8R87o`/;
2`Ko=3@d1_ooool7og5aL@Oo5aLG1onSXj<7olS8b0Oo6QXJ1_mVIVH7oa@D50Ko9BDU1_ooool7o`l?
3`Oo8R8R1olP8207oa@D50Ko4A4A1ol=3@d7oaDE5@Ko8B4Q1_ooool7oiFEU@OoemOG1olP8207oda<
C0Ko410@1onFUYH7oeIFEPKoI6AT1_ooool7o`D51@Oo5aLG1olL71`6ogYjNPOoclo?1omjNWX7oe1@
D0KoDe=C1_ooool7okVi^@Oo3@d=1om[Jf/6oadM7@Oo[:b/1oo=cLd7oa`L70Ko61PH1_ooool7o`@4
10go>CTi1om:BTX7og9bLPOo6a/K1om:BTX6oo;blPKooooo1olG5aL6ofATI0OoHf=S1ol?3`l7ob`/
;0Oo<C4a1om3@d<6ok6a/@kooooo000<ooooo`Oo2PX:1omIFET7odI6APOoIFEU1olo?cl6ob8R8POo
2`/;1_ld=3@6ooooo`OoLG5a1olG5aL7oj>SX`Oob<S81olJ6QX6ofIVIPOo51@D1_lU9BD6ooooo`Oo
3`l?1olR8R87ob0P80Oo51@D1_lA4A47o`d=3@Oo5ADE1_lQ8B46ooooo`OoUIFE1ooGemL7ob0P80Oo
C4a<1_l@4107oiJFUPOoEUIF1_mTI6@6ooooo`Oo1@D51olG5aL7oa`L70KoNWYj1oo?cll7ogYjNPOo
D51@1_mCDe<6ooooo`Oo^KVi1ol=3@d7of][J`Ko7AdM1on/[:`7olg=c@Oo71`L1_lH61P6ooooo`Oo
10@43Oli>CT7odY:BPOoLW9b1olK6a/7odY:BPKol_;b1_ooool7oaLG5`KoI6AT1omSHf<7o`l?3`Oo
;2`/1ola<C47od=3@`Ko/K6a3_ooool000cooooo1ol:2PX7oeUIF@OoATI61omUIFD7oclo?`Ko8R8R
1ol;2`/6oc@d=0Kooooo1omaLG47oaLG5`OoXj>S1oo8b<P7oaXJ6PKoIVIV1olD51@6obDU9@Kooooo
1ol?3`l7ob8R8POo820P1olD51@6oa4A4@Oo3@d=1olE5AD6ob4Q8@Kooooo1onEUID7omOGe`Oo820P
1om<C4`6oa0@40OoUYJF1omFEUH6ofATI0Kooooo1ol51@D7oaLG5`Oo71`L1_mjNWX7olo?c`OoNWYj
1om@D506oe=CD`Kooooo1oni^KT7o`d=3@OoJf][1_lM7Ad7ojb/[0OocLg=1olL71`6oaPH60Kooooo
1ol410@=ocTi>@OoBTY:1ombLW87oa/K6`OoBTY:1_obl_86ooooo`Oo5aLG1_mTI6@7of=SH`Oo3`l?
1ol/;2`7oc4a<@Oo@d=31_na/K4>ooooo`003?ooool7o`X:2POoFEUI1om6ATH7ofEUI@Oo?clo1_lR
8R87o`/;2`Ko=3@d1_ooool7og5aL@Oo5aLG1onSXj<7olS8b0Oo6QXJ1_mVIVH7oa@D50Ko9BDU1_oo
ool7o`l?3`Oo8R8R1olP8207oa@D50Ko4A4A1ol=3@d7oaDE5@Ko8B4Q1_ooool7oiFEU@OoemOG1olP
8207oda<C0Ko410@1onFUYH7oeIFEPKoI6AT1_ooool7o`D51@Oo5aLG1olL71`6ogYjNPOoclo?1omj
NWX7oe1@D0KoDe=C1_ooool7okVi^@Oo3@d=1om[Jf/6oadM7@Oo[:b/1oo=cLd7oa`L70Ko61PH1_oo
ool7o`@410go>CTi1om:BTX7og9bLPOo6a/K1om:BTX6oo;blPKooooo1olG5aL6ofATI0OoHf=S1ol?
3`l7ob`/;0Oo<C4a1om3@d<6ok6a/@kooooo000<ooooo`Oo2PX:1omIFET7odI6APOoIFEU1olo?cl6
ob8R8POo2`/;1_ld=3@6ooooo`OoLG5a1olG5aL7oj>SX`Oob<S81olJ6QX6ofIVIPOo51@D1_lU9BD6
ooooo`Oo3`l?1olR8R87ob0P80Oo51@D1_lA4A47o`d=3@Oo5ADE1_lQ8B46ooooo`OoUIFE1ooGemL7
ob0P80OoC4a<1_l@4107oiJFUPOoEUIF1_mTI6@6ooooo`Oo1@D51olG5aL7oa`L70KoNWYj1oo?cll7
ogYjNPOoD51@1_mCDe<6ooooo`Oo^KVi1ol=3@d7of][J`Ko7AdM1on/[:`7olg=c@Oo71`L1_lH61P6
ooooo`Oo10@43Oli>CT7odY:BPOoLW9b1olK6a/7odY:BPKol_;b1_ooool7oaLG5`KoI6AT1omSHf<7
o`l?3`Oo;2`/1ola<C47od=3@`Ko/K6a3_ooool000cooooo1ol:2PX7oeUIF@OoATI61omUIFD7oclo
?`Ko8R8R1ol;2`/6oc@d=0Kooooo1omaLG47oaLG5`OoXj>S1oo8b<P7oaXJ6PKoIVIV1olD51@6obDU
9@Kooooo1ol?3`l7ob8R8POo820P1olD51@6oa4A4@Oo3@d=1olE5AD6ob4Q8@Kooooo1onEUID7omOG
e`Oo820P1om<C4`6oa0@40OoUYJF1omFEUH6ofATI0Kooooo1ol51@D7oaLG5`Oo71`L1_mjNWX7olo?
c`OoNWYj1om@D506oe=CD`Kooooo1oni^KT7o`d=3@OoJf][1_lM7Ad7ojb/[0OocLg=1olL71`6oaPH
60Kooooo1ol410@=ocTi>@OoBTY:1ombLW87oa/K6`OoBTY:1_obl_86ooooo`Oo5aLG1_mTI6@7of=S
H`Oo3`l?1ol/;2`7oc4a<@Oo@d=31_na/K4>ooooo`003?ooool7o`<30`Oo7alO1olH61P7ocDe=@Oo
71`L1_l61PH7o`l?3`KoB4Q81_ooool7oeeMG@Oo:b/[1onMWId7oo[jnPOo7AdM1_m4A4@7oaLG5`Ko
:2PX1_ooool7o`l?3`Oo3Ph>1olF5QH7oaDE5@Ko5QHF1olA4A47oaPH60Ko7alO1_ooool7oh20P0Oo
^[Zj1ol;2`/7oe5AD@Ko61PH1onIVIT=ogYjNPKooooo1ol:2PX7oa0@40Oo:2PX1_mjNWX7ooooo`Oo
^KVi1ombLW86oeIFEPKooooo1oogmoL7oa@D50Oo@T921_ll?3`7ol;2`POo[:b/1olP8206ofm_K`Ko
oooo1ol>3Ph=oc@d=0Oo<C4a1omfMWH7oaDE5@OoEEEE1_ne]KD6ooooo`Oo2`/;1_lZ:RX7ofa/K0Oo
51@D1olc<c<7odM7A`Oo>SXj5?ooool000cooooo1ol30`<7oalO7`Oo61PH1ole=CD7oa`L70Ko1PH6
1ol?3`l6odQ8B0Kooooo1omMGEd7ob/[:`OoWIfM1oojn_X7oadM7@KoA4A41olG5aL6obPX:0Kooooo
1ol?3`l7o`h>3POo5QHF1olE5AD6oaHF5POo4A4A1olH61P6oalO7`Kooooo1on0P807okZj^POo2`/;
1omADE46oaPH60OoVIVI3OmjNWX6ooooo`Oo2PX:1ol@4107obPX:0KoNWYj1oooool7okVi^@OoLW9b
1_mFEUH6ooooo`OomoOg1olD51@7od92@PKo?3`l1oo2`/87ojb/[0Oo820P1_m_Kfl6ooooo`Oo3Ph>
3Old=3@7oc4a<@OoMWIf1olE5AD7oeEEE@Ko]KFe1_ooool7o`/;2`Ko:RXZ1om/K6`7oa@D50Oo<c<c
1om7AdL7ocXj>QCooooo000<ooooo`Oo0`<31olO7al7oaPH60Oo=CDe1olL71`6o`H61POo3`l?1_m8
B4P6ooooo`OoGEeM1ol[:b/7oifMW@Oon_[j1olM7Ad6odA4A0Oo5aLG1_lX:2P6ooooo`Oo3`l?1ol>
3Ph7oaHF5POo5ADE1_lF5QH7oa4A4@Oo61PH1_lO7al6ooooo`OoP8201onj^[X7o`/;2`OoDE5A1_lH
61P7oiVIV@goNWYj1_ooool7o`X:2POo410@1olX:2P6ogYjNPOooooo1oni^KT7og9bLPKoEUIF1_oo
ool7ooOgm`Oo51@D1om2@T86oc`l?0Oo`/;21on/[:`7ob0P80KoKfm_1_ooool7o`h>3Pgo=3@d1ola
<C47ogIfMPOo5ADE1omEEED6okFe]@Kooooo1ol;2`/6obXZ:POoK6a/1olD51@7oc<c<`OoAdM71olj
>SXDooooo`003?ooool7o`<30`Oo7alO1olH61P7ocDe=@Oo71`L1_l61PH7o`l?3`KoB4Q81_ooool7
oeeMG@Oo:b/[1onMWId7oo[jnPOo7AdM1_m4A4@7oaLG5`Ko:2PX1_ooool7o`l?3`Oo3Ph>1olF5QH7
oaDE5@Ko5QHF1olA4A47oaPH60Ko7alO1_ooool7oh20P0Oo^[Zj1ol;2`/7oe5AD@Ko61PH1onIVIT=
ogYjNPKooooo1ol:2PX7oa0@40Oo:2PX1_mjNWX7ooooo`Oo^KVi1ombLW86oeIFEPKooooo1oogmoL7
oa@D50Oo@T921_ll?3`7ol;2`POo[:b/1olP8206ofm_K`Kooooo1ol>3Ph=oc@d=0Oo<C4a1omfMWH7
oaDE5@OoEEEE1_ne]KD6ooooo`Oo2`/;1_lZ:RX7ofa/K0Oo51@D1olc<c<7odM7A`Oo>SXj5?ooool0
00cooooo1ol30`<7oalO7`Oo61PH1ole=CD7oa`L70Ko1PH61ol?3`l6odQ8B0Kooooo1omMGEd7ob/[
:`OoWIfM1oojn_X7oadM7@KoA4A41olG5aL6obPX:0Kooooo1ol?3`l7o`h>3POo5QHF1olE5AD6oaHF
5POo4A4A1olH61P6oalO7`Kooooo1on0P807okZj^POo2`/;1omADE46oaPH60OoVIVI3OmjNWX6oooo
o`Oo2PX:1ol@4107obPX:0KoNWYj1oooool7okVi^@OoLW9b1_mFEUH6ooooo`OomoOg1olD51@7od92
@PKo?3`l1oo2`/87ojb/[0Oo820P1_m_Kfl6ooooo`Oo3Ph>3Old=3@7oc4a<@OoMWIf1olE5AD7oeEE
E@Ko]KFe1_ooool7o`/;2`Ko:RXZ1om/K6`7oa@D50Oo<c<c1om7AdL7ocXj>QCooooo000<ooooo`Oo
0`<31olO7al7oaPH60Oo=CDe1olL71`6o`H61POo3`l?1_m8B4P6ooooo`OoGEeM1ol[:b/7oifMW@Oo
n_[j1olM7Ad6odA4A0Oo5aLG1_lX:2P6ooooo`Oo3`l?1ol>3Ph7oaHF5POo5ADE1_lF5QH7oa4A4@Oo
61PH1_lO7al6ooooo`OoP8201onj^[X7o`/;2`OoDE5A1_lH61P7oiVIV@goNWYj1_ooool7o`X:2POo
410@1olX:2P6ogYjNPOooooo1oni^KT7og9bLPKoEUIF1_ooool7ooOgm`Oo51@D1om2@T86oc`l?0Oo
`/;21on/[:`7ob0P80KoKfm_1_ooool7o`h>3Pgo=3@d1ola<C47ogIfMPOo5ADE1omEEED6okFe]@Ko
oooo1ol;2`/6obXZ:POoK6a/1olD51@7oc<c<`OoAdM71olj>SXDooooo`003?ooool7o`<30`Oo7alO
1olH61P7ocDe=@Oo71`L1_l61PH7o`l?3`KoB4Q81_ooool7oeeMG@Oo:b/[1onMWId7oo[jnPOo7AdM
1_m4A4@7oaLG5`Ko:2PX1_ooool7o`l?3`Oo3Ph>1olF5QH7oaDE5@Ko5QHF1olA4A47oaPH60Ko7alO
1_ooool7oh20P0Oo^[Zj1ol;2`/7oe5AD@Ko61PH1onIVIT=ogYjNPKooooo1ol:2PX7oa0@40Oo:2PX
1_mjNWX7ooooo`Oo^KVi1ombLW86oeIFEPKooooo1oogmoL7oa@D50Oo@T921_ll?3`7ol;2`POo[:b/
1olP8206ofm_K`Kooooo1ol>3Ph=oc@d=0Oo<C4a1omfMWH7oaDE5@OoEEEE1_ne]KD6ooooo`Oo2`/;
1_lZ:RX7ofa/K0Oo51@D1olc<c<7odM7A`Oo>SXj5?ooool000cooooo1olO7al7ocHf=POo@4101ol_
;bl7oc@d=0Ko4Q8B1ol`<306obl_;`Kooooo1omoOgl7odQ8B0OoMgMg1oooool7o`0000KoLg=c1olg
=cL6obTY:@Kooooo1ol?3`l7ob0P80Oo5aLG1olB4Q86oadM7@ko410@1_le=CD6ooooo`OoDE5A1ooG
emL7o`/;2`OoEeMG1_lc<c<7ogEeM@Oo_;bl1_nCTi<6ooooo`Oo71`L1olG5aL7o`d=3@KoF5QH1onM
WId7oi2@T0OoJFUY1_n8R8P6ooooo`OoRXZ:1olG5aL7og5aL@Ko>CTi1om]KFd7ooooo`Oo2`/;1_m8
B4P6ooooo`Oo10@41olZ:RX6oc4a<@Oo5QHF1omNGUh7o`l?3`OoCdm?1_n1PH46ooooo`Oo1@D51_lg
=cL7ofMWI`Oo51@D1olj>SX7od92@POo9BDU1_oKfm/>ooooo`003?ooool7oalO7`Oo=SHf1om0@407
obl_;`Oo=3@d1_lB4Q87oc0`<0Ko;bl_1_ooool7ogmoO`OoB4Q81omgMgL7ooooo`Oo00001_mcLg<7
ocLg=`Ko:BTY1_ooool7o`l?3`Oo820P1olG5aL7oa8B4PKo7AdM3_l@4106ocDe=@Kooooo1omADE47
omOGe`Oo2`/;1omGEeL6oc<c<`OoMGEe1onl_;`6oi>CT`Kooooo1olL71`7oaLG5`Oo3@d=1_mHF5P7
oifMW@OoT92@1omYJFT6ohR8R0Kooooo1on:RXX7oaLG5`OoLG5a1_li>CT7ofe]K@Oooooo1ol;2`/6
odQ8B0Kooooo1ol410@7obXZ:PKo<C4a1olF5QH7oeiNGPOo3`l?1om?Cdl6oh61P@Kooooo1ol51@D6
ocLg=`OoIfMW1olD51@7ocXj>POo@T921olU9BD6om_Kf`kooooo000<ooooo`Oo7alO1olf=SH7od10
@0Oo;bl_1old=3@6oa8B4POo<30`1_l_;bl6ooooo`OoOgmo1om8B4P7ogMgM`Oooooo1ol00006og=c
L`Oo=cLg1_lY:BT6ooooo`Oo3`l?1olP8207oaLG5`Oo4Q8B1_lM7Ad>oa0@40Ko=CDe1_ooool7oe5A
D@OoemOG1ol;2`/7oeMGE`Ko<c<c1omeMGD7okbl_0KoTi>C1_ooool7oa`L70Oo5aLG1ol=3@d6oeQH
F0OoWIfM1on@T907ofUYJ@KoR8R81_ooool7ohZ:RPOo5aLG1omaLG46ocTi>@OoKFe]1oooool7o`/;
2`KoB4Q81_ooool7o`@410Oo:RXZ1_la<C47oaHF5POoGUiN1ol?3`l7odm?C`KoPH611_ooool7o`D5
1@Ko=cLg1omWIfL7oa@D50Oo>SXj1om2@T87obDU9@Kofm_K3_ooool000cooooo1olO7al7ocHf=POo
@4101ol_;bl7oc@d=0Ko4Q8B1ol`<306obl_;`Kooooo1omoOgl7odQ8B0OoMgMg1oooool7o`0000Ko
Lg=c1olg=cL6obTY:@Kooooo1ol?3`l7ob0P80Oo5aLG1olB4Q86oadM7@ko410@1_le=CD6ooooo`Oo
DE5A1ooGemL7o`/;2`OoEeMG1_lc<c<7ogEeM@Oo_;bl1_nCTi<6ooooo`Oo71`L1olG5aL7o`d=3@Ko
F5QH1onMWId7oi2@T0OoJFUY1_n8R8P6ooooo`OoRXZ:1olG5aL7og5aL@Ko>CTi1om]KFd7ooooo`Oo
2`/;1_m8B4P6ooooo`Oo10@41olZ:RX6oc4a<@Oo5QHF1omNGUh7o`l?3`OoCdm?1_n1PH46ooooo`Oo
1@D51_lg=cL7ofMWI`Oo51@D1olj>SX7od92@POo9BDU1_oKfm/>ooooo`003?ooool7oalO7`Oo=SHf
1om0@407obl_;`Oo=3@d1_lB4Q87oc0`<0Ko;bl_1_ooool7ogmoO`OoB4Q81omgMgL7ooooo`Oo0000
1_mcLg<7ocLg=`Ko:BTY1_ooool7o`l?3`Oo820P1olG5aL7oa8B4PKo7AdM3_l@4106ocDe=@Kooooo
1omADE47omOGe`Oo2`/;1omGEeL6oc<c<`OoMGEe1onl_;`6oi>CT`Kooooo1olL71`7oaLG5`Oo3@d=
1_mHF5P7oifMW@OoT92@1omYJFT6ohR8R0Kooooo1on:RXX7oaLG5`OoLG5a1_li>CT7ofe]K@Oooooo
1ol;2`/6odQ8B0Kooooo1ol410@7obXZ:PKo<C4a1olF5QH7oeiNGPOo3`l?1om?Cdl6oh61P@Kooooo
1ol51@D6ocLg=`OoIfMW1olD51@7ocXj>POo@T921olU9BD6om_Kf`kooooo000<ooooo`Oo7alO1olf
=SH7od10@0Oo;bl_1old=3@6oa8B4POo<30`1_l_;bl6ooooo`OoOgmo1om8B4P7ogMgM`Oooooo1ol0
0006og=cL`Oo=cLg1_lY:BT6ooooo`Oo3`l?1olP8207oaLG5`Oo4Q8B1_lM7Ad>oa0@40Ko=CDe1_oo
ool7oe5AD@OoemOG1ol;2`/7oeMGE`Ko<c<c1omeMGD7okbl_0KoTi>C1_ooool7oa`L70Oo5aLG1ol=
3@d6oeQHF0OoWIfM1on@T907ofUYJ@KoR8R81_ooool7ohZ:RPOo5aLG1omaLG46ocTi>@OoKFe]1ooo
ool7o`/;2`KoB4Q81_ooool7o`@410Oo:RXZ1_la<C47oaHF5POoGUiN1ol?3`l7odm?C`KoPH611_oo
ool7o`D51@Ko=cLg1omWIfL7oa@D50Oo>SXj1om2@T87obDU9@Kofm_K3_ooool000cooooo1olO7al7
ocHf=POo@4101ol_;bl7oc@d=0Ko4Q8B1ol`<306obl_;`Kooooo1omoOgl7odQ8B0OoMgMg1oooool7
o`0000KoLg=c1olg=cL6obTY:@Kooooo1ol?3`l7ob0P80Oo5aLG1olB4Q86oadM7@ko410@1_le=CD6
ooooo`OoDE5A1ooGemL7o`/;2`OoEeMG1_lc<c<7ogEeM@Oo_;bl1_nCTi<6ooooo`Oo71`L1olG5aL7
o`d=3@KoF5QH1onMWId7oi2@T0OoJFUY1_n8R8P6ooooo`OoRXZ:1olG5aL7og5aL@Ko>CTi1om]KFd7
ooooo`Oo2`/;1_m8B4P6ooooo`Oo10@41olZ:RX6oc4a<@Oo5QHF1omNGUh7o`l?3`OoCdm?1_n1PH46
ooooo`Oo1@D51_lg=cL7ofMWI`Oo51@D1olj>SX7od92@POo9BDU1_oKfm/>ooooo`003?ooool7oe1@
D0Oo][Jf1onDU9@7oda<C0OoHF5Q1_lK6a/7ob0P80KoLW9b1_ooool7oe9BDPOoC4a<1omADE47okJf
]POo0P821_m5ADD7od92@PKo51@D1_ooool7obHV9POo=CDe1olB4Q87o`h>3PKo410@1olB4Q87o`X:
2PKo<30`1_ooool7obLW9`OoQXJ61ol820P7oc`l?0Ko>SXj1om`L707ooooo`KoF5QH1_ooool7oa@D
50Oo9RHV1olO7al6oda<C0OoWinO1omfMWH7og5aL@KoL71`1_ooool7oh:2PPOo1PH61olk>c/6odE5
A@OoMGEe1onATI47o`L71`KoPh>31_ooool7o``<30Oo:b/[1_lG5aL7oa4A4@OoCDe=1ol00007oc0`
<0KoEeMG1_ooool7oa4A4@Ko6ATI1omLG5`7o`P820Oo:BTY1om>CTh7ocDe=@KofMWI3_ooool000co
oooo1om@D507okJf]POoU9BD1om<C4`7of5QH@Ko6a/K1olP8206og9bLPKooooo1omBDU87oda<C0Oo
DE5A1onf][H7o`820PKoADE51om2@T86oa@D50Kooooo1olV9RH7ocDe=@Oo4Q8B1ol>3Ph6oa0@40Oo
4Q8B1ol:2PX6oc0`<0Kooooo1olW9bL7ohJ6QPOo20P81oll?3`6ocXj>POoL71`1oooool6oeQHF0Ko
oooo1olD51@7obHV9POo7alO1_m<C4`7oinOW`OoMWIf1omaLG46og1`L0Kooooo1on2PX87o`H61POo
>c/k1_m5ADD7ogEeM@OoTI6A1ol71`L6oh>3P`Kooooo1ol<30`7ob/[:`Ko5aLG1olA4A47ode=C@Oo
00001ol`<306oeMGE`Kooooo1olA4A46oaTI6@OoG5aL1ol820P7obTY:@OoCTi>1ole=CD6omWIf@ko
oooo000<ooooo`OoD51@1onf][H7oiBDU0OoC4a<1omQHF46oa/K6`Oo820P1_mbLW86ooooo`OoDU9B
1om<C4`7oe5AD@Oo][Jf1ol20P86odE5A@Oo@T921_lD51@6ooooo`Oo9RHV1ole=CD7oa8B4POo3Ph>
1_l@4107oa8B4POo2PX:1_l`<306ooooo`Oo9bLW1on6QXH7o`P820Oo?3`l1_lj>SX7og1`L0Oooooo
1_mHF5P6ooooo`Oo51@D1olV9RH7oalO7`KoC4a<1onOWil7ogIfMPOoLG5a1_m`L706ooooo`OoPX:2
1ol61PH7oc/k>`KoADE51omeMGD7oi6AT@Oo1`L71_n3Ph<6ooooo`Oo30`<1ol[:b/6oaLG5`Oo4A4A
1om=CDd7o`0000Oo<30`1_mGEeL6ooooo`Oo4A4A1_lI6AT7oeaLG0Oo20P81olY:BT7odi>CPOo=CDe
1_oIfMT>ooooo`003?ooool7oe1@D0Oo][Jf1onDU9@7oda<C0OoHF5Q1_lK6a/7ob0P80KoLW9b1_oo
ool7oe9BDPOoC4a<1omADE47okJf]POo0P821_m5ADD7od92@PKo51@D1_ooool7obHV9POo=CDe1olB
4Q87o`h>3PKo410@1olB4Q87o`X:2PKo<30`1_ooool7obLW9`OoQXJ61ol820P7oc`l?0Ko>SXj1om`
L707ooooo`KoF5QH1_ooool7oa@D50Oo9RHV1olO7al6oda<C0OoWinO1omfMWH7og5aL@KoL71`1_oo
ool7oh:2PPOo1PH61olk>c/6odE5A@OoMGEe1onATI47o`L71`KoPh>31_ooool7o``<30Oo:b/[1_lG
5aL7oa4A4@OoCDe=1ol00007oc0`<0KoEeMG1_ooool7oa4A4@Ko6ATI1omLG5`7o`P820Oo:BTY1om>
CTh7ocDe=@KofMWI3_ooool000cooooo1om@D507okJf]POoU9BD1om<C4`7of5QH@Ko6a/K1olP8206
og9bLPKooooo1omBDU87oda<C0OoDE5A1onf][H7o`820PKoADE51om2@T86oa@D50Kooooo1olV9RH7
ocDe=@Oo4Q8B1ol>3Ph6oa0@40Oo4Q8B1ol:2PX6oc0`<0Kooooo1olW9bL7ohJ6QPOo20P81oll?3`6
ocXj>POoL71`1oooool6oeQHF0Kooooo1olD51@7obHV9POo7alO1_m<C4`7oinOW`OoMWIf1omaLG46
og1`L0Kooooo1on2PX87o`H61POo>c/k1_m5ADD7ogEeM@OoTI6A1ol71`L6oh>3P`Kooooo1ol<30`7
ob/[:`Ko5aLG1olA4A47ode=C@Oo00001ol`<306oeMGE`Kooooo1olA4A46oaTI6@OoG5aL1ol820P7
obTY:@OoCTi>1ole=CD6omWIf@kooooo000<ooooo`OoD51@1onf][H7oiBDU0OoC4a<1omQHF46oa/K
6`Oo820P1_mbLW86ooooo`OoDU9B1om<C4`7oe5AD@Oo][Jf1ol20P86odE5A@Oo@T921_lD51@6oooo
o`Oo9RHV1ole=CD7oa8B4POo3Ph>1_l@4107oa8B4POo2PX:1_l`<306ooooo`Oo9bLW1on6QXH7o`P8
20Oo?3`l1_lj>SX7og1`L0Oooooo1_mHF5P6ooooo`Oo51@D1olV9RH7oalO7`KoC4a<1onOWil7ogIf
MPOoLG5a1_m`L706ooooo`OoPX:21ol61PH7oc/k>`KoADE51omeMGD7oi6AT@Oo1`L71_n3Ph<6oooo
o`Oo30`<1ol[:b/6oaLG5`Oo4A4A1om=CDd7o`0000Oo<30`1_mGEeL6ooooo`Oo4A4A1_lI6AT7oeaL
G0Oo20P81olY:BT7odi>CPOo=CDe1_oIfMT>ooooo`003?ooool7of9RHPOok^k^1oooool7on;RhPOo
KVi^1_le=CD7ocHf=PKoPH611_ooool7og9bLPOo;bl_1olN7Qh7omkNgPOo0`<31_m?Cdl7ofUYJ@Ko
;Bd]1_ooool7o`H61POo6ATI1olC4a<7o`l?3`Ko30`<1ol:2PX7oa8B4PKo61PH1_ooool7o`d=3@Oo
QhN71ol@410=ocXj>POoDe=C1ooFe]H6odI6APKooooo1olB4Q87oaPH60Oo<30`1_ll?3`7oeYJFPOo
F5QH1om7AdL6ocdm?@Kooooo1oln?Sh7o`X:2POoLW9b1_lM7Ad7ob0P80Oo`<301ol00006ofi^KPKo
oooo1ol10@47ocLg=`Ko6QXJ1ol51@D7od10@0Oo1PH61ol`<306od51@@Kooooo1olD51@6ob8R8POo
?Cdm1ol00007odM7A`Oo=SHf1olB4Q86oiJFUPkooooo000<ooooo`OoHV9R1oo^k^h7ooooo`Ooh^;R
1om^KVh6ocDe=@Oo=SHf1_n1PH46ooooo`OoLW9b1ol_;bl7oahN7POog]kN1ol30`<6odm?C`OoJFUY
1_l];Bd6ooooo`Oo1PH61olI6AT7oa<C4`Oo3`l?1_l<30`7o`X:2POo4Q8B1_lH61P6ooooo`Oo3@d=
1on7QhL7oa0@40go>SXj1omCDe<7omKFePKoATI61_ooool7oa8B4POo61PH1ol`<306oc`l?0OoFUYJ
1omHF5P7odM7A`Ko?Cdm1_ooool7ochn?POo2PX:1ombLW86oadM7@Oo820P1oo0`<07o`0000KoKVi^
1_ooool7o`410@Oo=cLg1_lJ6QX7o`D51@Oo@4101ol61PH7oc0`<0Ko@D511_ooool7oa@D50Ko8R8R
1olm?Cd7o`0000OoAdM71olf=SH7oa8B4PKoUYJF3_ooool000cooooo1omRHV87onk^kPOooooo1ooR
h^87ofi^KPKo=CDe1olf=SH6oh61P@Kooooo1ombLW87obl_;`Oo7QhN1ooNg]h7o`<30`KoCdm?1omY
JFT6obd];@Kooooo1ol61PH7oaTI6@Oo4a<C1ol?3`l6o``<30Oo2PX:1olB4Q86oaPH60Kooooo1ol=
3@d7ohN7Q`Oo410@3Olj>SX7oe=CD`Ooe]KF1_m6ATH6ooooo`Oo4Q8B1olH61P7oc0`<0Ko?3`l1omJ
FUX7oeQHF0OoAdM71_lm?Cd6ooooo`Oo?Shn1ol:2PX7og9bLPKo7AdM1olP8207ol30`0Oo00001_m^
KVh6ooooo`Oo0@411olg=cL6oaXJ6POo1@D51om0@407o`H61POo<30`1_m1@D46ooooo`Oo51@D1_lR
8R87ocdm?@Oo00001om7AdL7ocHf=POo4Q8B1_nFUYH>ooooo`003?ooool7of9RHPOok^k^1oooool7
on;RhPOoKVi^1_le=CD7ocHf=PKoPH611_ooool7og9bLPOo;bl_1olN7Qh7omkNgPOo0`<31_m?Cdl7
ofUYJ@Ko;Bd]1_ooool7o`H61POo6ATI1olC4a<7o`l?3`Ko30`<1ol:2PX7oa8B4PKo61PH1_ooool7
o`d=3@OoQhN71ol@410=ocXj>POoDe=C1ooFe]H6odI6APKooooo1olB4Q87oaPH60Oo<30`1_ll?3`7
oeYJFPOoF5QH1om7AdL6ocdm?@Kooooo1oln?Sh7o`X:2POoLW9b1_lM7Ad7ob0P80Oo`<301ol00006
ofi^KPKooooo1ol10@47ocLg=`Ko6QXJ1ol51@D7od10@0Oo1PH61ol`<306od51@@Kooooo1olD51@6
ob8R8POo?Cdm1ol00007odM7A`Oo=SHf1olB4Q86oiJFUPkooooo000<ooooo`OoHV9R1oo^k^h7oooo
o`Ooh^;R1om^KVh6ocDe=@Oo=SHf1_n1PH46ooooo`OoLW9b1ol_;bl7oahN7POog]kN1ol30`<6odm?
C`OoJFUY1_l];Bd6ooooo`Oo1PH61olI6AT7oa<C4`Oo3`l?1_l<30`7o`X:2POo4Q8B1_lH61P6oooo
o`Oo3@d=1on7QhL7oa0@40go>SXj1omCDe<7omKFePKoATI61_ooool7oa8B4POo61PH1ol`<306oc`l
?0OoFUYJ1omHF5P7odM7A`Ko?Cdm1_ooool7ochn?POo2PX:1ombLW86oadM7@Oo820P1oo0`<07o`00
00KoKVi^1_ooool7o`410@Oo=cLg1_lJ6QX7o`D51@Oo@4101ol61PH7oc0`<0Ko@D511_ooool7oa@D
50Ko8R8R1olm?Cd7o`0000OoAdM71olf=SH7oa8B4PKoUYJF3_ooool000cooooo1omRHV87onk^kPOo
oooo1ooRh^87ofi^KPKo=CDe1olf=SH6oh61P@Kooooo1ombLW87obl_;`Oo7QhN1ooNg]h7o`<30`Ko
Cdm?1omYJFT6obd];@Kooooo1ol61PH7oaTI6@Oo4a<C1ol?3`l6o``<30Oo2PX:1olB4Q86oaPH60Ko
oooo1ol=3@d7ohN7Q`Oo410@3Olj>SX7oe=CD`Ooe]KF1_m6ATH6ooooo`Oo4Q8B1olH61P7oc0`<0Ko
?3`l1omJFUX7oeQHF0OoAdM71_lm?Cd6ooooo`Oo?Shn1ol:2PX7og9bLPKo7AdM1olP8207ol30`0Oo
00001_m^KVh6ooooo`Oo0@411olg=cL6oaXJ6POo1@D51om0@407o`H61POo<30`1_m1@D46ooooo`Oo
51@D1_lR8R87ocdm?@Oo00001om7AdL7ocHf=POo4Q8B1_nFUYH>ooooo`003?ooool7of9RHPOok^k^
1oooool7on;RhPOoKVi^1_le=CD7ocHf=PKoPH611_ooool7og9bLPOo;bl_1olN7Qh7omkNgPOo0`<3
1_m?Cdl7ofUYJ@Ko;Bd]1_ooool7o`H61POo6ATI1olC4a<7o`l?3`Ko30`<1ol:2PX7oa8B4PKo61PH
1_ooool7o`d=3@OoQhN71ol@410=ocXj>POoDe=C1ooFe]H6odI6APKooooo1olB4Q87oaPH60Oo<30`
1_ll?3`7oeYJFPOoF5QH1om7AdL6ocdm?@Kooooo1oln?Sh7o`X:2POoLW9b1_lM7Ad7ob0P80Oo`<30
1ol00006ofi^KPKooooo1ol10@47ocLg=`Ko6QXJ1ol51@D7od10@0Oo1PH61ol`<306od51@@Kooooo
1olD51@6ob8R8POo?Cdm1ol00007odM7A`Oo=SHf1olB4Q86oiJFUPkooooo000<ooooo`Oo9BDU1oli
>CT7ocDe=@OoDU9B1om0@406o`H61POo<S8b1_lm?Cd6ooooo`Oo@T921olU9BD7oeMGE`OoDe=C1olJ
6QX6oclo?`Oo;Bd]1_mADE46ooooo`OoATI61olZ:RX7obHV9POo4Q8B1_lG5aL7oaXJ6POo1PH63?oo
ool7od51@@Oo>c/k1olD51@7ocDe=@Ko51@D1omDE5@7odM7A`Ko6a/K1_ooool7ob0P80Oo6ATI1old
=3@6ohJ6QPOo[:b/1omiNGT7oeIFEPKoIFEU1_ooool7ode=C@Oo0@411oln?Sh6ocHf=POo:2PX1ol^
;Rh7oa/K6`Ko^KVi1_ooool7oa@D50Oo:RXZ1_lB4Q87odm?C`Oo9BDU1ol>3Ph7ob<S8`KoIFEU1_oo
ool7o`h>3PKoKVi^1olg=cL7o`@410Oo<C4a1olW9bL7o`h>3PKo>c/k3_ooool000cooooo1olU9BD7
ocTi>@Oo=CDe1omBDU87od10@0Ko1PH61olb<S86ocdm?@Kooooo1om2@T87obDU9@OoEeMG1omCDe<7
oaXJ6PKo?clo1ol];Bd6oe5AD@Kooooo1om6ATH7obXZ:POo9RHV1olB4Q86oaLG5`Oo6QXJ1ol61PH<
ooooo`Oo@D511olk>c/7oa@D50Oo=CDe1_lD51@7oeADE0OoAdM71_lK6a/6ooooo`Oo820P1olI6AT7
oc@d=0KoQXJ61on/[:`7ogUiN@OoEUIF1_mUIFD6ooooo`OoCDe=1ol10@47ochn?PKo=SHf1olX:2P7
obh^;POo6a/K1_ni^KT6ooooo`Oo51@D1olZ:RX6oa8B4POoCdm?1olU9BD7o`h>3POo8b<S1_mUIFD6
ooooo`Oo3Ph>1_m^KVh7ocLg=`Oo10@41ola<C47obLW9`Oo3Ph>1_lk>c/>ooooo`003?ooool7obDU
9@Oo>CTi1ole=CD7oe9BDPOo@4101_l61PH7oc8b<PKo?Cdm1_ooool7od92@POo9BDU1omGEeL7oe=C
D`Oo6QXJ1_lo?cl7obd];@KoDE5A1_ooool7odI6APOo:RXZ1olV9RH7oa8B4PKo5aLG1olJ6QX7o`H6
1Pcooooo1om1@D47oc/k>`Oo51@D1ole=CD6oa@D50OoE5AD1om7AdL6oa/K6`Kooooo1olP8207oaTI
6@Oo=3@d1_n6QXH7ojb/[0OoNGUi1omFEUH6ofEUI@Kooooo1om=CDd7o`410@Oo?Shn1_lf=SH7obPX
:0Oo;Rh^1olK6a/6okVi^@Kooooo1olD51@7obXZ:PKo4Q8B1om?Cdl7obDU9@Oo3Ph>1olS8b<6ofEU
I@Kooooo1ol>3Ph6ofi^KPOo=cLg1ol410@7oc4a<@Oo9bLW1ol>3Ph6oc/k>`kooooo000<ooooo`Oo
9BDU1oli>CT7ocDe=@OoDU9B1om0@406o`H61POo<S8b1_lm?Cd6ooooo`Oo@T921olU9BD7oeMGE`Oo
De=C1olJ6QX6oclo?`Oo;Bd]1_mADE46ooooo`OoATI61olZ:RX7obHV9POo4Q8B1_lG5aL7oaXJ6POo
1PH63?ooool7od51@@Oo>c/k1olD51@7ocDe=@Ko51@D1omDE5@7odM7A`Ko6a/K1_ooool7ob0P80Oo
6ATI1old=3@6ohJ6QPOo[:b/1omiNGT7oeIFEPKoIFEU1_ooool7ode=C@Oo0@411oln?Sh6ocHf=POo
:2PX1ol^;Rh7oa/K6`Ko^KVi1_ooool7oa@D50Oo:RXZ1_lB4Q87odm?C`Oo9BDU1ol>3Ph7ob<S8`Ko
IFEU1_ooool7o`h>3PKoKVi^1olg=cL7o`@410Oo<C4a1olW9bL7o`h>3PKo>c/k3_ooool000cooooo
1olU9BD7ocTi>@Oo=CDe1omBDU87od10@0Ko1PH61olb<S86ocdm?@Kooooo1om2@T87obDU9@OoEeMG
1omCDe<7oaXJ6PKo?clo1ol];Bd6oe5AD@Kooooo1om6ATH7obXZ:POo9RHV1olB4Q86oaLG5`Oo6QXJ
1ol61PH<ooooo`Oo@D511olk>c/7oa@D50Oo=CDe1_lD51@7oeADE0OoAdM71_lK6a/6ooooo`Oo820P
1olI6AT7oc@d=0KoQXJ61on/[:`7ogUiN@OoEUIF1_mUIFD6ooooo`OoCDe=1ol10@47ochn?PKo=SHf
1olX:2P7obh^;POo6a/K1_ni^KT6ooooo`Oo51@D1olZ:RX6oa8B4POoCdm?1olU9BD7o`h>3POo8b<S
1_mUIFD6ooooo`Oo3Ph>1_m^KVh7ocLg=`Oo10@41ola<C47obLW9`Oo3Ph>1_lk>c/>ooooo`003?oo
ool7obDU9@Oo>CTi1ole=CD7oe9BDPOo@4101_l61PH7oc8b<PKo?Cdm1_ooool7od92@POo9BDU1omG
EeL7oe=CD`Oo6QXJ1_lo?cl7obd];@KoDE5A1_ooool7odI6APOo:RXZ1olV9RH7oa8B4PKo5aLG1olJ
6QX7o`H61Pcooooo1om1@D47oc/k>`Oo51@D1ole=CD6oa@D50OoE5AD1om7AdL6oa/K6`Kooooo1olP
8207oaTI6@Oo=3@d1_n6QXH7ojb/[0OoNGUi1omFEUH6ofEUI@Kooooo1om=CDd7o`410@Oo?Shn1_lf
=SH7obPX:0Oo;Rh^1olK6a/6okVi^@Kooooo1olD51@7obXZ:PKo4Q8B1om?Cdl7obDU9@Oo3Ph>1olS
8b<6ofEUI@Kooooo1ol>3Ph6ofi^KPOo=cLg1ol410@7oc4a<@Oo9bLW1ol>3Ph6oc/k>`kooooo000<
ooooo`Oo9BDU1oli>CT7ocDe=@OoDU9B1om0@406o`H61POo<S8b1_lm?Cd6ooooo`Oo@T921olU9BD7
oeMGE`OoDe=C1olJ6QX6oclo?`Oo;Bd]1_mADE46ooooo`OoATI61olZ:RX7obHV9POo4Q8B1_lG5aL7
oaXJ6POo1PH63?ooool7od51@@Oo>c/k1olD51@7ocDe=@Ko51@D1omDE5@7odM7A`Ko6a/K1_ooool7
ob0P80Oo6ATI1old=3@6ohJ6QPOo[:b/1omiNGT7oeIFEPKoIFEU1_ooool7ode=C@Oo0@411oln?Sh6
ocHf=POo:2PX1ol^;Rh7oa/K6`Ko^KVi1_ooool7oa@D50Oo:RXZ1_lB4Q87odm?C`Oo9BDU1ol>3Ph7
ob<S8`KoIFEU1_ooool7o`h>3PKoKVi^1olg=cL7o`@410Oo<C4a1olW9bL7o`h>3PKo>c/k3_ooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool000cooooo1olH61P7obLW9`Oo71`L1omIFET7ohb<S0Koh^;R1on9RHT6ohN7Q`Ko
oooo1ol61PH7odU9B@Oo?3`l1ol10@47od=3@`Ko1PH61olo?cl6odA4A0Kooooo1olJ6QX7ob4Q8@Oo
7alO1olR8R86ocDe=@Oo1PH61olH61P6ocPh>0Kooooo1omGEeL7onOWi`Oo7alO1omRHV86obl_;`Oo
TI6A1ond];@6of][J`Kooooo1ol?3`l7obTY:@Oo8b<S1_lJ6QX7oa4A4@Oo410@1olC4a<6oc0`<0Ko
oooo1onQXJ47oaTI6@OoKVi^1_m0@407og5aL@OocLg=1olQ8B46oeeMG@Kooooo1olc<c<7oaTI6@Ko
I6AT1olS8b<7odQ8B0OoA4A41ol^;Rh6onCTi0Kooooo1ol;2`/6ofEUI@Oo0P821olZ:RX7oeMGE`Oo
7alO1om>CTh6ob<S8`kooooo000<ooooo`Oo61PH1olW9bL7oa`L70OoFEUI1on<S8`6on;RhPOoRHV9
1_n7QhL6ooooo`Oo1PH61om9BDT7oc`l?0Oo0@411om3@d<6o`H61POo?clo1_m4A4@6ooooo`Oo6QXJ
1olQ8B47oalO7`Oo8R8R1_le=CD7o`H61POo61PH1_lh>3P6ooooo`OoEeMG1ooWinL7oalO7`OoHV9R
1_l_;bl7oi6AT@Oo];Bd1_m[Jf/6ooooo`Oo3`l?1olY:BT7ob<S8`Ko6QXJ1olA4A47oa0@40Oo4a<C
1_l`<306ooooo`OoXJ6Q1olI6AT7ofi^KPKo@4101omaLG47olg=c@Oo8B4Q1_mMGEd6ooooo`Oo<c<c
1olI6AT6ofATI0Oo8b<S1om8B4P7odA4A0Oo;Rh^1_oTi>@6ooooo`Oo2`/;1_mUIFD7o`820POo:RXZ
1omGEeL7oalO7`OoCTi>1_lS8b<>ooooo`003?ooool7oaPH60Oo9bLW1olL71`7oeUIF@OoS8b<1_oR
h^87ohV9R@KoQhN71_ooool7o`H61POoBDU91oll?3`7o`410@Oo@d=31_l61PH7oclo?`KoA4A41_oo
ool7oaXJ6POo8B4Q1olO7al7ob8R8PKo=CDe1ol61PH7oaPH60Ko>3Ph1_ooool7oeMGE`OoinOW1olO
7al7of9RHPKo;bl_1onATI47okBd]0KoJf][1_ooool7o`l?3`Oo:BTY1olS8b<6oaXJ6POo4A4A1ol@
4107oa<C4`Ko<30`1_ooool7oj6QX@Oo6ATI1om^KVh6od10@0OoLG5a1oo=cLd7ob4Q8@KoGEeM1_oo
ool7oc<c<`Oo6ATI1_mTI6@7ob<S8`OoB4Q81om4A4@7obh^;PKoi>CT1_ooool7o`/;2`KoIFEU1ol2
0P87obXZ:POoEeMG1olO7al7odi>CPKo8b<S3_ooool000cooooo1olH61P7obLW9`Oo71`L1omIFET7
ohb<S0Koh^;R1on9RHT6ohN7Q`Kooooo1ol61PH7odU9B@Oo?3`l1ol10@47od=3@`Ko1PH61olo?cl6
odA4A0Kooooo1olJ6QX7ob4Q8@Oo7alO1olR8R86ocDe=@Oo1PH61olH61P6ocPh>0Kooooo1omGEeL7
onOWi`Oo7alO1omRHV86obl_;`OoTI6A1ond];@6of][J`Kooooo1ol?3`l7obTY:@Oo8b<S1_lJ6QX7
oa4A4@Oo410@1olC4a<6oc0`<0Kooooo1onQXJ47oaTI6@OoKVi^1_m0@407og5aL@OocLg=1olQ8B46
oeeMG@Kooooo1olc<c<7oaTI6@KoI6AT1olS8b<7odQ8B0OoA4A41ol^;Rh6onCTi0Kooooo1ol;2`/6
ofEUI@Oo0P821olZ:RX7oeMGE`Oo7alO1om>CTh6ob<S8`kooooo000<ooooo`Oo61PH1olW9bL7oa`L
70OoFEUI1on<S8`6on;RhPOoRHV91_n7QhL6ooooo`Oo1PH61om9BDT7oc`l?0Oo0@411om3@d<6o`H6
1POo?clo1_m4A4@6ooooo`Oo6QXJ1olQ8B47oalO7`Oo8R8R1_le=CD7o`H61POo61PH1_lh>3P6oooo
o`OoEeMG1ooWinL7oalO7`OoHV9R1_l_;bl7oi6AT@Oo];Bd1_m[Jf/6ooooo`Oo3`l?1olY:BT7ob<S
8`Ko6QXJ1olA4A47oa0@40Oo4a<C1_l`<306ooooo`OoXJ6Q1olI6AT7ofi^KPKo@4101omaLG47olg=
c@Oo8B4Q1_mMGEd6ooooo`Oo<c<c1olI6AT6ofATI0Oo8b<S1om8B4P7odA4A0Oo;Rh^1_oTi>@6oooo
o`Oo2`/;1_mUIFD7o`820POo:RXZ1omGEeL7oalO7`OoCTi>1_lS8b<>ooooo`003?ooool7oaPH60Oo
9bLW1olL71`7oeUIF@OoS8b<1_oRh^87ohV9R@KoQhN71_ooool7o`H61POoBDU91oll?3`7o`410@Oo
@d=31_l61PH7oclo?`KoA4A41_ooool7oaXJ6POo8B4Q1olO7al7ob8R8PKo=CDe1ol61PH7oaPH60Ko
>3Ph1_ooool7oeMGE`OoinOW1olO7al7of9RHPKo;bl_1onATI47okBd]0KoJf][1_ooool7o`l?3`Oo
:BTY1olS8b<6oaXJ6POo4A4A1ol@4107oa<C4`Ko<30`1_ooool7oj6QX@Oo6ATI1om^KVh6od10@0Oo
LG5a1oo=cLd7ob4Q8@KoGEeM1_ooool7oc<c<`Oo6ATI1_mTI6@7ob<S8`OoB4Q81om4A4@7obh^;PKo
i>CT1_ooool7o`/;2`KoIFEU1ol20P87obXZ:POoEeMG1olO7al7odi>CPKo8b<S3_ooool000cooooo
1olH61P7obLW9`Oo71`L1omIFET7ohb<S0Koh^;R1on9RHT6ohN7Q`Kooooo1ol61PH7odU9B@Oo?3`l
1ol10@47od=3@`Ko1PH61olo?cl6odA4A0Kooooo1olJ6QX7ob4Q8@Oo7alO1olR8R86ocDe=@Oo1PH6
1olH61P6ocPh>0Kooooo1omGEeL7onOWi`Oo7alO1omRHV86obl_;`OoTI6A1ond];@6of][J`Kooooo
1ol?3`l7obTY:@Oo8b<S1_lJ6QX7oa4A4@Oo410@1olC4a<6oc0`<0Kooooo1onQXJ47oaTI6@OoKVi^
1_m0@407og5aL@OocLg=1olQ8B46oeeMG@Kooooo1olc<c<7oaTI6@KoI6AT1olS8b<7odQ8B0OoA4A4
1ol^;Rh6onCTi0Kooooo1ol;2`/6ofEUI@Oo0P821olZ:RX7oeMGE`Oo7alO1om>CTh6ob<S8`kooooo
000<ooooo`Oo6ATI1ol/;2`7oaLG5`OoFEUI1omWIfL6oo[jnPOoQ8B41_lm?Cd6ooooo`Oo4A4A1omB
DU87oe=CD`Oo0@411ole=CD6o`@410OoBDU91_lg=cL6ooooo`OoKVi^1olj>SX7obh^;POo8R8R1_lV
9RH7oa/K6`Oo6ATI1_m^KVh6ooooo`OoADE51one]KD7oa0@40OoEUIF1_lQ8B47ofa/K0Oooooo1_mO
Gel6ooooo`Oo2@T91ol=3@d7o`P820Ko3Ph>1ol92@T>o`d=3@Ko6QXJ1_ooool7ohJ6QPOo30`<1omA
DE46odQ8B0OoEEEE1oooool7o`h>3PKoOGem1_ooool7oa4A4@Oo1@D51_mEEED7o`0000Oo;Rh^1olm
?Cd7obTY:@KonOWi1_ooool7o`h>3PKoE5AD1ol=3@d7oaPH60Oo<30`1olI6AT7odm?C`Ko:2PX3_oo
ool000cooooo1olI6AT7ob`/;0Oo5aLG1omIFET7ofMWI`Kon_[j1on4Q8@6ocdm?@Kooooo1olA4A47
oe9BDPOoDe=C1ol10@47ocDe=@Ko10@41om9BDT6ocLg=`Kooooo1om^KVh7ocXj>POo;Rh^1olR8R86
obHV9POo6a/K1olI6AT6ofi^KPKooooo1om5ADD7okFe]@Oo410@1omFEUH6ob4Q8@OoK6a/1oooool6
oemOG`Kooooo1ol92@T7o`d=3@Oo20P81_l>3Ph7o`T92@ko3@d=1_lJ6QX6ooooo`OoQXJ61ol<30`7
oe5AD@KoB4Q81omEEED7ooooo`Oo3Ph>1_mmOGd6ooooo`Oo4A4A1ol51@D6oeEEE@Oo00001ol^;Rh7
ocdm?@Oo:BTY1_oinOT6ooooo`Oo3Ph>1_mDE5@7o`d=3@Oo61PH1ol`<307oaTI6@OoCdm?1_lX:2P>
ooooo`003?ooool7oaTI6@Oo;2`/1olG5aL7oeUIF@OoIfMW1_ojn_X7ohB4Q0Ko?Cdm1_ooool7oa4A
4@OoDU9B1omCDe<7o`410@Oo=CDe1_l410@7odU9B@Ko=cLg1_ooool7ofi^KPOo>SXj1ol^;Rh7ob8R
8PKo9RHV1olK6a/7oaTI6@KoKVi^1_ooool7odE5A@Oo]KFe1ol@4107oeIFEPKo8B4Q1om/K6`7oooo
o`KoGemO1_ooool7o`T92@Oo3@d=1ol820P6o`h>3POo2@T93_l=3@d6oaXJ6PKooooo1on6QXH7o``<
30OoDE5A1_m8B4P7oeEEE@Oooooo1ol>3Ph6ogemO@Kooooo1olA4A47o`D51@KoEEEE1ol00007obh^
;POo?Cdm1olY:BT6ooWin@Kooooo1ol>3Ph6oeADE0Oo3@d=1olH61P7oc0`<0Oo6ATI1om?Cdl6obPX
:0kooooo000<ooooo`Oo6ATI1ol/;2`7oaLG5`OoFEUI1omWIfL6oo[jnPOoQ8B41_lm?Cd6ooooo`Oo
4A4A1omBDU87oe=CD`Oo0@411ole=CD6o`@410OoBDU91_lg=cL6ooooo`OoKVi^1olj>SX7obh^;POo
8R8R1_lV9RH7oa/K6`Oo6ATI1_m^KVh6ooooo`OoADE51one]KD7oa0@40OoEUIF1_lQ8B47ofa/K0Oo
oooo1_mOGel6ooooo`Oo2@T91ol=3@d7o`P820Ko3Ph>1ol92@T>o`d=3@Ko6QXJ1_ooool7ohJ6QPOo
30`<1omADE46odQ8B0OoEEEE1oooool7o`h>3PKoOGem1_ooool7oa4A4@Oo1@D51_mEEED7o`0000Oo
;Rh^1olm?Cd7obTY:@KonOWi1_ooool7o`h>3PKoE5AD1ol=3@d7oaPH60Oo<30`1olI6AT7odm?C`Ko
:2PX3_ooool000cooooo1olI6AT7ob`/;0Oo5aLG1omIFET7ofMWI`Kon_[j1on4Q8@6ocdm?@Kooooo
1olA4A47oe9BDPOoDe=C1ol10@47ocDe=@Ko10@41om9BDT6ocLg=`Kooooo1om^KVh7ocXj>POo;Rh^
1olR8R86obHV9POo6a/K1olI6AT6ofi^KPKooooo1om5ADD7okFe]@Oo410@1omFEUH6ob4Q8@OoK6a/
1oooool6oemOG`Kooooo1ol92@T7o`d=3@Oo20P81_l>3Ph7o`T92@ko3@d=1_lJ6QX6ooooo`OoQXJ6
1ol<30`7oe5AD@KoB4Q81omEEED7ooooo`Oo3Ph>1_mmOGd6ooooo`Oo4A4A1ol51@D6oeEEE@Oo0000
1ol^;Rh7ocdm?@Oo:BTY1_oinOT6ooooo`Oo3Ph>1_mDE5@7o`d=3@Oo61PH1ol`<307oaTI6@OoCdm?
1_lX:2P>ooooo`003?ooool7oaTI6@Oo;2`/1olG5aL7oeUIF@OoIfMW1_ojn_X7ohB4Q0Ko?Cdm1_oo
ool7oa4A4@OoDU9B1omCDe<7o`410@Oo=CDe1_l410@7odU9B@Ko=cLg1_ooool7ofi^KPOo>SXj1ol^
;Rh7ob8R8PKo9RHV1olK6a/7oaTI6@KoKVi^1_ooool7odE5A@Oo]KFe1ol@4107oeIFEPKo8B4Q1om/
K6`7ooooo`KoGemO1_ooool7o`T92@Oo3@d=1ol820P6o`h>3POo2@T93_l=3@d6oaXJ6PKooooo1on6
QXH7o``<30OoDE5A1_m8B4P7oeEEE@Oooooo1ol>3Ph6ogemO@Kooooo1olA4A47o`D51@KoEEEE1ol0
0007obh^;POo?Cdm1olY:BT6ooWin@Kooooo1ol>3Ph6oeADE0Oo3@d=1olH61P7oc0`<0Oo6ATI1om?
Cdl6obPX:0kooooo000<ooooo`Oo6ATI1ol/;2`7oaLG5`OoFEUI1omWIfL6oo[jnPOoQ8B41_lm?Cd6
ooooo`Oo4A4A1omBDU87oe=CD`Oo0@411ole=CD6o`@410OoBDU91_lg=cL6ooooo`OoKVi^1olj>SX7
obh^;POo8R8R1_lV9RH7oa/K6`Oo6ATI1_m^KVh6ooooo`OoADE51one]KD7oa0@40OoEUIF1_lQ8B47
ofa/K0Oooooo1_mOGel6ooooo`Oo2@T91ol=3@d7o`P820Ko3Ph>1ol92@T>o`d=3@Ko6QXJ1_ooool7
ohJ6QPOo30`<1omADE46odQ8B0OoEEEE1oooool7o`h>3PKoOGem1_ooool7oa4A4@Oo1@D51_mEEED7
o`0000Oo;Rh^1olm?Cd7obTY:@KonOWi1_ooool7o`h>3PKoE5AD1ol=3@d7oaPH60Oo<30`1olI6AT7
odm?C`Ko:2PX3_ooool000cooooo1olT92@>ob`/;0OoPH611onFUYH6ooooo`OoOWin1_nGUiL6oooo
o`Oo9bLW1om<C4`7oh61P@Oo1PH61oln?Sh6o`<30`OoIFEU1_mBDU86ooooo`OoTY:B1omGEeL7odA4
A0Oo>c/k1_l[:b/7ob0P80Oo9BDU3?ooool7oahN7POobLW91olB4Q87odY:BPKoATI61omZJVX7onCT
i0KoBDU91_ooool7o`0000Oo61PH1olG5aL6o`h>3POo4Q8B1ol61PH7o`L71`Ko820P1_ooool7ofm_
K`Oo6a/K1omJFUX=od51@@Oog=cL1ol=3@d6ojn_[`Kooooo1ole=CD7o`X:2PKo=SHf1ol820P7odi>
CPOo8R8R1olB4Q86ol_;b`Kooooo1ol;2`/6oeADE0Oo1PH61olW9bL7ob@T90Oo00001olh>3P6oc/k
>`kooooo000<ooooo`Oo92@T3_l/;2`7oh61P@OoUYJF1_ooool7oginOPKoUiNG1_ooool7obLW9`Oo
C4a<1on1PH47o`H61POo?Shn1_l30`<7ofEUI@KoDU9B1_ooool7oi:BTPOoEeMG1om4A4@7oc/k>`Ko
:b/[1olP8207obDU9@cooooo1olN7Qh7olW9b@Oo4Q8B1om:BTX6odI6APOoJVYZ1ooTi>@6odU9B@Ko
oooo1ol00007oaPH60Oo5aLG1_l>3Ph7oa8B4POo1PH61ol71`L6ob0P80Kooooo1om_Kfl7oa/K6`Oo
FUYJ3Om1@D47omcLg0Oo3@d=1_n_[jl6ooooo`Oo=CDe1ol:2PX6ocHf=POo20P81om>CTh7ob8R8POo
4Q8B1_o;bl/6ooooo`Oo2`/;1_mDE5@7o`H61POo9bLW1olT92@7o`0000Oo>3Ph1_lk>c/>ooooo`00
3?ooool7ob@T90ko;2`/1on1PH47oiJFUPKooooo1omnOWh6oiNGU`Kooooo1olW9bL7oda<C0OoPH61
1ol61PH7ochn?PKo0`<31omUIFD6oe9BDPKooooo1onBTY87oeMGE`OoA4A41olk>c/6ob/[:`Oo820P
1olU9BD<ooooo`Oo7QhN1oo9bLT7oa8B4POoBTY:1_m6ATH7ofYZJPOoi>CT1_m9BDT6ooooo`Oo0000
1olH61P7oaLG5`Ko3Ph>1olB4Q87o`H61POo1`L71_lP8206ooooo`OoKfm_1olK6a/7oeYJFPgo@D51
1ooLg=`7o`d=3@Ko[jn_1_ooool7ocDe=@Oo2PX:1_lf=SH7o`P820OoCTi>1olR8R87oa8B4PKobl_;
1_ooool7o`/;2`KoE5AD1ol61PH7obLW9`Oo92@T1ol00007ocPh>0Ko>c/k3_ooool000cooooo1olT
92@>ob`/;0OoPH611onFUYH6ooooo`OoOWin1_nGUiL6ooooo`Oo9bLW1om<C4`7oh61P@Oo1PH61oln
?Sh6o`<30`OoIFEU1_mBDU86ooooo`OoTY:B1omGEeL7odA4A0Oo>c/k1_l[:b/7ob0P80Oo9BDU3?oo
ool7oahN7POobLW91olB4Q87odY:BPKoATI61omZJVX7onCTi0KoBDU91_ooool7o`0000Oo61PH1olG
5aL6o`h>3POo4Q8B1ol61PH7o`L71`Ko820P1_ooool7ofm_K`Oo6a/K1omJFUX=od51@@Oog=cL1ol=
3@d6ojn_[`Kooooo1ole=CD7o`X:2PKo=SHf1ol820P7odi>CPOo8R8R1olB4Q86ol_;b`Kooooo1ol;
2`/6oeADE0Oo1PH61olW9bL7ob@T90Oo00001olh>3P6oc/k>`kooooo000<ooooo`Oo92@T3_l/;2`7
oh61P@OoUYJF1_ooool7oginOPKoUiNG1_ooool7obLW9`OoC4a<1on1PH47o`H61POo?Shn1_l30`<7
ofEUI@KoDU9B1_ooool7oi:BTPOoEeMG1om4A4@7oc/k>`Ko:b/[1olP8207obDU9@cooooo1olN7Qh7
olW9b@Oo4Q8B1om:BTX6odI6APOoJVYZ1ooTi>@6odU9B@Kooooo1ol00007oaPH60Oo5aLG1_l>3Ph7
oa8B4POo1PH61ol71`L6ob0P80Kooooo1om_Kfl7oa/K6`OoFUYJ3Om1@D47omcLg0Oo3@d=1_n_[jl6
ooooo`Oo=CDe1ol:2PX6ocHf=POo20P81om>CTh7ob8R8POo4Q8B1_o;bl/6ooooo`Oo2`/;1_mDE5@7
o`H61POo9bLW1olT92@7o`0000Oo>3Ph1_lk>c/>ooooo`003?ooool7ob@T90ko;2`/1on1PH47oiJF
UPKooooo1omnOWh6oiNGU`Kooooo1olW9bL7oda<C0OoPH611ol61PH7ochn?PKo0`<31omUIFD6oe9B
DPKooooo1onBTY87oeMGE`OoA4A41olk>c/6ob/[:`Oo820P1olU9BD<ooooo`Oo7QhN1oo9bLT7oa8B
4POoBTY:1_m6ATH7ofYZJPOoi>CT1_m9BDT6ooooo`Oo00001olH61P7oaLG5`Ko3Ph>1olB4Q87o`H6
1POo1`L71_lP8206ooooo`OoKfm_1olK6a/7oeYJFPgo@D511ooLg=`7o`d=3@Ko[jn_1_ooool7ocDe
=@Oo2PX:1_lf=SH7o`P820OoCTi>1olR8R87oa8B4PKobl_;1_ooool7o`/;2`KoE5AD1ol61PH7obLW
9`Oo92@T1ol00007ocPh>0Ko>c/k3_ooool000cooooo1ol<30`7oa/K6`Oo9RHV1omFEUH7oc@d=0Ko
f=SH1omTI6@6oe=CD`Kooooo1olV9RH7oe=CD`Oog=cL1ol51@D7odI6APKo4a<C1om[Jf/6oc4a<@Ko
oooo1onHV9P7oh:2PPOoEEEE1olm?Cd6ob<S8`Oo:BTY1olV9RH6ojJVYPKooooo1olV9RH7oh20P0Oo
5aLG1omFEUH6ocXj>POo@T921ooGemL6obXZ:PKooooo1ol410@7oaPH60Oo3Ph>1_lF5QH7oa@D50Oo
3Ph>1ol820P6oa<C4`Kooooo1ol/;2`7o`0000OoE5AD1_lW9bL7obDU9@Oo]KFe1olN7Qh6og=cL`Ko
oooo1om;Bd/7o`T92@Ko=3@d1olF5QH7ofi^KPOo61PH1olN7Qh6ojn_[`Kooooo1olD51@6of9RHPOo
3Ph>1oln?Sh7ob<S8`Oo4Q8B1olc<c<6oh:2PPkooooo000<ooooo`Oo30`<1olK6a/7obHV9POoEUIF
1old=3@6omSHf0OoI6AT1_mCDe<6ooooo`Oo9RHV1omCDe<7omcLg0Oo1@D51om6ATH6oa<C4`OoJf][
1_la<C46ooooo`OoV9RH1on2PX87oeEEE@Oo?Cdm1_lS8b<7obTY:@Oo9RHV1_nVYZH6ooooo`Oo9RHV
1on0P807oaLG5`OoEUIF1_lj>SX7od92@POoemOG1_lZ:RX6ooooo`Oo10@41olH61P7o`h>3PKo5QHF
1olD51@7o`h>3POo20P81_lC4a<6ooooo`Oo;2`/1ol00007oeADE0Ko9bLW1olU9BD7okFe]@Oo7QhN
1_mcLg<6ooooo`OoBd];1ol92@T6oc@d=0Oo5QHF1om^KVh7oaPH60Oo7QhN1_n_[jl6ooooo`Oo51@D
1_mRHV87o`h>3POo?Shn1olS8b<7oa8B4POo<c<c1_n2PX8>ooooo`003?ooool7o``<30Oo6a/K1olV
9RH7oeIFEPOo=3@d1_oHf=P7ofATI0KoDe=C1_ooool7obHV9POoDe=C1ooLg=`7o`D51@OoATI61_lC
4a<7of][J`Ko<C4a1_ooool7oiRHV0OoPX:21omEEED7ocdm?@Ko8b<S1olY:BT7obHV9PKoYZJV1_oo
ool7obHV9POoP8201olG5aL7oeIFEPKo>SXj1om2@T87omOGe`Ko:RXZ1_ooool7o`@410Oo61PH1ol>
3Ph6oaHF5POo51@D1ol>3Ph7o`P820Ko4a<C1_ooool7ob`/;0Oo00001omDE5@6obLW9`Oo9BDU1one
]KD7oahN7PKoLg=c1_ooool7od];B`Oo2@T91_ld=3@7oaHF5POoKVi^1olH61P7oahN7PKo[jn_1_oo
ool7oa@D50KoHV9R1ol>3Ph7ochn?POo8b<S1olB4Q87oc<c<`KoPX:23_ooool000cooooo1ol<30`7
oa/K6`Oo9RHV1omFEUH7oc@d=0Kof=SH1omTI6@6oe=CD`Kooooo1olV9RH7oe=CD`Oog=cL1ol51@D7
odI6APKo4a<C1om[Jf/6oc4a<@Kooooo1onHV9P7oh:2PPOoEEEE1olm?Cd6ob<S8`Oo:BTY1olV9RH6
ojJVYPKooooo1olV9RH7oh20P0Oo5aLG1omFEUH6ocXj>POo@T921ooGemL6obXZ:PKooooo1ol410@7
oaPH60Oo3Ph>1_lF5QH7oa@D50Oo3Ph>1ol820P6oa<C4`Kooooo1ol/;2`7o`0000OoE5AD1_lW9bL7
obDU9@Oo]KFe1olN7Qh6og=cL`Kooooo1om;Bd/7o`T92@Ko=3@d1olF5QH7ofi^KPOo61PH1olN7Qh6
ojn_[`Kooooo1olD51@6of9RHPOo3Ph>1oln?Sh7ob<S8`Oo4Q8B1olc<c<6oh:2PPkooooo000<oooo
o`Oo30`<1olK6a/7obHV9POoEUIF1old=3@6omSHf0OoI6AT1_mCDe<6ooooo`Oo9RHV1omCDe<7omcL
g0Oo1@D51om6ATH6oa<C4`OoJf][1_la<C46ooooo`OoV9RH1on2PX87oeEEE@Oo?Cdm1_lS8b<7obTY
:@Oo9RHV1_nVYZH6ooooo`Oo9RHV1on0P807oaLG5`OoEUIF1_lj>SX7od92@POoemOG1_lZ:RX6oooo
o`Oo10@41olH61P7o`h>3PKo5QHF1olD51@7o`h>3POo20P81_lC4a<6ooooo`Oo;2`/1ol00007oeAD
E0Ko9bLW1olU9BD7okFe]@Oo7QhN1_mcLg<6ooooo`OoBd];1ol92@T6oc@d=0Oo5QHF1om^KVh7oaPH
60Oo7QhN1_n_[jl6ooooo`Oo51@D1_mRHV87o`h>3POo?Shn1olS8b<7oa8B4POo<c<c1_n2PX8>oooo
o`003?ooool7o``<30Oo6a/K1olV9RH7oeIFEPOo=3@d1_oHf=P7ofATI0KoDe=C1_ooool7obHV9POo
De=C1ooLg=`7o`D51@OoATI61_lC4a<7of][J`Ko<C4a1_ooool7oiRHV0OoPX:21omEEED7ocdm?@Ko
8b<S1olY:BT7obHV9PKoYZJV1_ooool7obHV9POoP8201olG5aL7oeIFEPKo>SXj1om2@T87omOGe`Ko
:RXZ1_ooool7o`@410Oo61PH1ol>3Ph6oaHF5POo51@D1ol>3Ph7o`P820Ko4a<C1_ooool7ob`/;0Oo
00001omDE5@6obLW9`Oo9BDU1one]KD7oahN7PKoLg=c1_ooool7od];B`Oo2@T91_ld=3@7oaHF5POo
KVi^1olH61P7oahN7PKo[jn_1_ooool7oa@D50KoHV9R1ol>3Ph7ochn?POo8b<S1olB4Q87oc<c<`Ko
PX:23_ooool000cooooo1ol<30`7oa/K6`Oo9RHV1omFEUH7oc@d=0Kof=SH1omTI6@6oe=CD`Kooooo
1olV9RH7oe=CD`Oog=cL1ol51@D7odI6APKo4a<C1om[Jf/6oc4a<@Kooooo1onHV9P7oh:2PPOoEEEE
1olm?Cd6ob<S8`Oo:BTY1olV9RH6ojJVYPKooooo1olV9RH7oh20P0Oo5aLG1omFEUH6ocXj>POo@T92
1ooGemL6obXZ:PKooooo1ol410@7oaPH60Oo3Ph>1_lF5QH7oa@D50Oo3Ph>1ol820P6oa<C4`Kooooo
1ol/;2`7o`0000OoE5AD1_lW9bL7obDU9@Oo]KFe1olN7Qh6og=cL`Kooooo1om;Bd/7o`T92@Ko=3@d
1olF5QH7ofi^KPOo61PH1olN7Qh6ojn_[`Kooooo1olD51@6of9RHPOo3Ph>1oln?Sh7ob<S8`Oo4Q8B
1olc<c<6oh:2PPkooooo000<ooooo`Oo00001olG5aL7ob8R8POoPH611onKVi/6omGEe@OoLG5a1_mI
FET6ooooo`OoBDU91ol^;Rh7onCTi0Oo00001olf=SH6ob0P80OoMgMg1_mNGUh6ooooo`OoBTY:1om9
BDT7ocdm?@Oo=cLg1_lH61P7oaXJ6POo8B4Q1_mWIfL6ooooo`Oo8R8R1om=CDd7o`P820OoCDe=1_m2
@T87ob4Q8@OoTi>C1_lX:2P6ooooo`Oo2`/;1olA4A47oa0@40Ko4a<C1olB4Q87oa@D50Oo410@1_lU
9BD6ooooo`Oo:2PX1ol00007oemOG`Ko<c<c1ol<30`7oeEEE@Oo3@d=1_nPX:06ooooo`OoVi^K1ol@
4106od92@POo7alO1onf][H7od=3@`Oo4a<C1_m;Bd/6ooooo`Oo71`L1_mMGEd7oa@D50Oo=3@d1ol^
;Rh7o`l?3`Oo>c/k1_o;bl/>ooooo`003?ooool7o`0000Oo5aLG1olR8R87oh61P@OoVi^K1_oEeMD7
og5aL@KoFEUI1_ooool7odU9B@Oo;Rh^1ooTi>@7o`0000Oo=SHf1_lP8207ogMgM`KoGUiN1_ooool7
odY:BPOoBDU91olm?Cd7ocLg=`Ko61PH1olJ6QX7ob4Q8@KoIfMW1_ooool7ob8R8POoCDe=1ol820P7
ode=C@Ko@T921olQ8B47oi>CT`Ko:2PX1_ooool7o`/;2`Oo4A4A1ol@4106oa<C4`Oo4Q8B1olD51@7
oa0@40Ko9BDU1_ooool7obPX:0Oo00001omOGel6oc<c<`Oo30`<1omEEED7o`d=3@KoX:2P1_ooool7
oi^KV`Oo410@1_m2@T87oalO7`Oo][Jf1om3@d<7oa<C4`KoBd];1_ooool7oa`L70KoGEeM1olD51@7
oc@d=0Oo;Rh^1ol?3`l7oc/k>`Kobl_;3_ooool000cooooo1ol00007oaLG5`Oo8R8R1on1PH47oi^K
V`KoeMGE1omaLG46oeUIF@Kooooo1om9BDT7obh^;POoi>CT1ol00007ocHf=PKo820P1omgMgL6oeiN
GPKooooo1om:BTX7odU9B@Oo?Cdm1olg=cL6oaPH60Oo6QXJ1olQ8B46ofMWI`Kooooo1olR8R87ode=
C@Oo20P81om=CDd6od92@POo8B4Q1onCTi<6obPX:0Kooooo1ol;2`/7oa4A4@Oo410@1_lC4a<7oa8B
4POo51@D1ol@4106obDU9@Kooooo1olX:2P7o`0000OoGemO1_lc<c<7o``<30OoEEEE1ol=3@d6oj2P
X0Kooooo1onKVi/7oa0@40Ko@T921olO7al7okJf]POo@d=31olC4a<6od];B`Kooooo1olL71`6oeeM
G@Oo51@D1old=3@7obh^;POo3`l?1olk>c/6ol_;b`kooooo000<ooooo`Oo00001olG5aL7ob8R8POo
PH611onKVi/6omGEe@OoLG5a1_mIFET6ooooo`OoBDU91ol^;Rh7onCTi0Oo00001olf=SH6ob0P80Oo
MgMg1_mNGUh6ooooo`OoBTY:1om9BDT7ocdm?@Oo=cLg1_lH61P7oaXJ6POo8B4Q1_mWIfL6ooooo`Oo
8R8R1om=CDd7o`P820OoCDe=1_m2@T87ob4Q8@OoTi>C1_lX:2P6ooooo`Oo2`/;1olA4A47oa0@40Ko
4a<C1olB4Q87oa@D50Oo410@1_lU9BD6ooooo`Oo:2PX1ol00007oemOG`Ko<c<c1ol<30`7oeEEE@Oo
3@d=1_nPX:06ooooo`OoVi^K1ol@4106od92@POo7alO1onf][H7od=3@`Oo4a<C1_m;Bd/6ooooo`Oo
71`L1_mMGEd7oa@D50Oo=3@d1ol^;Rh7o`l?3`Oo>c/k1_o;bl/>ooooo`003?ooool7o`0000Oo5aLG
1olR8R87oh61P@OoVi^K1_oEeMD7og5aL@KoFEUI1_ooool7odU9B@Oo;Rh^1ooTi>@7o`0000Oo=SHf
1_lP8207ogMgM`KoGUiN1_ooool7odY:BPOoBDU91olm?Cd7ocLg=`Ko61PH1olJ6QX7ob4Q8@KoIfMW
1_ooool7ob8R8POoCDe=1ol820P7ode=C@Ko@T921olQ8B47oi>CT`Ko:2PX1_ooool7o`/;2`Oo4A4A
1ol@4106oa<C4`Oo4Q8B1olD51@7oa0@40Ko9BDU1_ooool7obPX:0Oo00001omOGel6oc<c<`Oo30`<
1omEEED7o`d=3@KoX:2P1_ooool7oi^KV`Oo410@1_m2@T87oalO7`Oo][Jf1om3@d<7oa<C4`KoBd];
1_ooool7oa`L70KoGEeM1olD51@7oc@d=0Oo;Rh^1ol?3`l7oc/k>`Kobl_;3_ooool000cooooo1ol0
0007oaLG5`Oo8R8R1on1PH47oi^KV`KoeMGE1omaLG46oeUIF@Kooooo1om9BDT7obh^;POoi>CT1ol0
0007ocHf=PKo820P1omgMgL6oeiNGPKooooo1om:BTX7odU9B@Oo?Cdm1olg=cL6oaPH60Oo6QXJ1olQ
8B46ofMWI`Kooooo1olR8R87ode=C@Oo20P81om=CDd6od92@POo8B4Q1onCTi<6obPX:0Kooooo1ol;
2`/7oa4A4@Oo410@1_lC4a<7oa8B4POo51@D1ol@4106obDU9@Kooooo1olX:2P7o`0000OoGemO1_lc
<c<7o``<30OoEEEE1ol=3@d6oj2PX0Kooooo1onKVi/7oa0@40Ko@T921olO7al7okJf]POo@d=31olC
4a<6od];B`Kooooo1olL71`6oeeMG@Oo51@D1old=3@7obh^;POo3`l?1olk>c/6ol_;b`kooooo000<
ooooo`Oo00001olG5aL7ob8R8POoPH611onKVi/6omGEe@OoLG5a1_mIFET6ooooo`OoBDU91ol^;Rh7
onCTi0Oo00001olf=SH6ob0P80OoMgMg1_mNGUh6ooooo`OoBTY:1om9BDT7ocdm?@Oo=cLg1_lH61P7
oaXJ6POo8B4Q1_mWIfL6ooooo`Oo8R8R1om=CDd7o`P820OoCDe=1_m2@T87ob4Q8@OoTi>C1_lX:2P6
ooooo`Oo2`/;1olA4A47oa0@40Ko4a<C1olB4Q87oa@D50Oo410@1_lU9BD6ooooo`Oo:2PX1ol00007
oemOG`Ko<c<c1ol<30`7oeEEE@Oo3@d=1_nPX:06ooooo`OoVi^K1ol@4106od92@POo7alO1onf][H7
od=3@`Oo4a<C1_m;Bd/6ooooo`Oo71`L1_mMGEd7oa@D50Oo=3@d1ol^;Rh7o`l?3`Oo>c/k1_o;bl/>
ooooo`003?ooool7oaHF5POo5ADE1ol_;bl7og1`L0OoCdm?1_oAdM47oh:2PPKo:2PX1_ooool>ocdm
?@Oooooo1ol:2PX7ocdm?@Ko:BTY1omGEeL6oe1@D0Kooooo1olf=SH>obd];@Oo=SHf1_lB4Q87o`00
00Oo2`/;1_lk>c/6ooooo`Oo<C4a1omBDU87oa8B4POoKfm_1_lA4A47o`T92@OoLW9b1_mADE46oooo
o`Oo2@T91ol;2`/7oa0@40Ko30`<1olA4A47o`P820Oo4Q8B1_lI6AT6ooooo`Oo7AdM1ol71`L7ogem
O@Ko=SHf1olG5aL7oeQHF0Oo5QHF1_mSHf<=ooooo`Oo820P1_m4A4@7obXZ:POoUYJF1omHF5P7ochn
?PKoBTY:1_ooool7o``<30KoC4a<1olf=SH7ochn?POo@D511olF5QH7ocXj>QCooooo000<ooooo`Oo
5QHF1olE5AD7obl_;`OoL71`1om?Cdl6om7Ad@OoPX:21_lX:2P6ooooo`ko?Cdm1oooool7o`X:2POo
?Cdm1_lY:BT7oeMGE`KoD51@1_ooool7ocHf=Pko;Bd]1olf=SH6oa8B4POo00001ol;2`/6oc/k>`Ko
oooo1ola<C47oe9BDPOo4Q8B1om_Kfl6oa4A4@Oo2@T91ombLW86oe5AD@Kooooo1ol92@T7o`/;2`Oo
410@1_l<30`7oa4A4@Oo20P81olB4Q86oaTI6@Kooooo1olM7Ad7o`L71`OoOGem1_lf=SH7oaLG5`Oo
F5QH1olF5QH6of=SH`gooooo1olP8206odA4A0Oo:RXZ1onFUYH7oeQHF0Oo?Shn1_m:BTX6ooooo`Oo
30`<1_m<C4`7ocHf=POo?Shn1om1@D47oaHF5POo>SXj5?ooool000cooooo1olF5QH7oaDE5@Oo;bl_
1om`L707odm?C`KodM7A1on2PX86obPX:0Kooooo3_lm?Cd7ooooo`Oo2PX:1olm?Cd6obTY:@OoEeMG
1_m@D506ooooo`Oo=SHf3_l];Bd7ocHf=PKo4Q8B1ol00007o`/;2`Ko>c/k1_ooool7oc4a<@OoDU9B
1olB4Q87ofm_K`Ko4A4A1ol92@T7og9bLPKoDE5A1_ooool7o`T92@Oo2`/;1ol@4106o``<30Oo4A4A
1ol820P7oa8B4PKo6ATI1_ooool7oadM7@Oo1`L71ommOGd6ocHf=POo5aLG1omHF5P7oaHF5PKoHf=S
3Oooool7ob0P80KoA4A41olZ:RX7oiJFUPOoF5QH1oln?Sh6odY:BPKooooo1ol<30`6oda<C0Oo=SHf
1oln?Sh7od51@@Oo5QHF1olj>SXDooooo`003?ooool7oaHF5POo5ADE1ol_;bl7og1`L0OoCdm?1_oA
dM47oh:2PPKo:2PX1_ooool>ocdm?@Oooooo1ol:2PX7ocdm?@Ko:BTY1omGEeL6oe1@D0Kooooo1olf
=SH>obd];@Oo=SHf1_lB4Q87o`0000Oo2`/;1_lk>c/6ooooo`Oo<C4a1omBDU87oa8B4POoKfm_1_lA
4A47o`T92@OoLW9b1_mADE46ooooo`Oo2@T91ol;2`/7oa0@40Ko30`<1olA4A47o`P820Oo4Q8B1_lI
6AT6ooooo`Oo7AdM1ol71`L7ogemO@Ko=SHf1olG5aL7oeQHF0Oo5QHF1_mSHf<=ooooo`Oo820P1_m4
A4@7obXZ:POoUYJF1omHF5P7ochn?PKoBTY:1_ooool7o``<30KoC4a<1olf=SH7ochn?POo@D511olF
5QH7ocXj>QCooooo000<ooooo`Oo5QHF1olE5AD7obl_;`OoL71`1om?Cdl6om7Ad@OoPX:21_lX:2P6
ooooo`ko?Cdm1oooool7o`X:2POo?Cdm1_lY:BT7oeMGE`KoD51@1_ooool7ocHf=Pko;Bd]1olf=SH6
oa8B4POo00001ol;2`/6oc/k>`Kooooo1ola<C47oe9BDPOo4Q8B1om_Kfl6oa4A4@Oo2@T91ombLW86
oe5AD@Kooooo1ol92@T7o`/;2`Oo410@1_l<30`7oa4A4@Oo20P81olB4Q86oaTI6@Kooooo1olM7Ad7
o`L71`OoOGem1_lf=SH7oaLG5`OoF5QH1olF5QH6of=SH`gooooo1olP8206odA4A0Oo:RXZ1onFUYH7
oeQHF0Oo?Shn1_m:BTX6ooooo`Oo30`<1_m<C4`7ocHf=POo?Shn1om1@D47oaHF5POo>SXj5?ooool0
00cooooo1olF5QH7oaDE5@Oo;bl_1om`L707odm?C`KodM7A1on2PX86obPX:0Kooooo3_lm?Cd7oooo
o`Oo2PX:1olm?Cd6obTY:@OoEeMG1_m@D506ooooo`Oo=SHf3_l];Bd7ocHf=PKo4Q8B1ol00007o`/;
2`Ko>c/k1_ooool7oc4a<@OoDU9B1olB4Q87ofm_K`Ko4A4A1ol92@T7og9bLPKoDE5A1_ooool7o`T9
2@Oo2`/;1ol@4106o``<30Oo4A4A1ol820P7oa8B4PKo6ATI1_ooool7oadM7@Oo1`L71ommOGd6ocHf
=POo5aLG1omHF5P7oaHF5PKoHf=S3Oooool7ob0P80KoA4A41olZ:RX7oiJFUPOoF5QH1oln?Sh6odY:
BPKooooo1ol<30`6oda<C0Oo=SHf1oln?Sh7od51@@Oo5QHF1olj>SXDooooo`003?ooool7oa`L70Oo
820P1ol/;2`7ogmoO`OoTY:B1_oemOD7ohB4Q0KoK6a/1_ooool7ocDe=@Oo7alO1onc/k<7o`X:2POo
>c/k1_l[:b/7odQ8B0KoO7al1_ooool7obDU9@Oo:2PX1ol_;bl7oa<C4`Ko51@D1ol;2`/7oa8B4PKo
<c<c1_ooool7ocPh>0OoG5aL1ol00007ogAdM0Ko;2`/1olE5AD7oclo?`KoY:BT1_ooool7o`l?3`Oo
4Q8B1olD51@6o``<30Oo410@1ol?3`l7oa4A4@Ko6QXJ1_ooool7oc`l?0Oo5ADE1omdM7@6od92@POo
3`l?1om8B4P7o`P820KoAdM71_ooool7om[JfPOo9BDU1_mUIFD7oc`l?0Oo];Bd1onGUiL7obDU9@Ko
?Shn1_ooool7o`d=3@KoC4a<1om6ATH7oc`l?0OoEeMG1olJ6QX7odA4A0Koo?cl3_ooool000cooooo
1olL71`7ob0P80Oo;2`/1omoOgl7oi:BTPKomOGe1on4Q8@6ofa/K0Kooooo1ole=CD7oalO7`Oo/k>c
1ol:2PX7oc/k>`Ko:b/[1om8B4P6ogalO0Kooooo1olU9BD7obPX:0Oo;bl_1olC4a<6oa@D50Oo2`/;
1olB4Q86oc<c<`Kooooo1olh>3P7oeaLG0Oo00001omdM7@6ob`/;0Oo5ADE1olo?cl6ojBTY0Kooooo
1ol?3`l7oa8B4POo51@D1_l<30`7oa0@40Oo3`l?1olA4A46oaXJ6PKooooo1oll?3`7oaDE5@OoM7Ad
1_m2@T87o`l?3`OoB4Q81ol820P6odM7A`Kooooo1ooJf]X7obDU9@KoIFEU1oll?3`7okBd]0OoUiNG
1olU9BD6ochn?PKooooo1ol=3@d6oda<C0OoATI61oll?3`7oeMGE`Oo6QXJ1om4A4@6ooclo0kooooo
000<ooooo`Oo71`L1olP8207ob`/;0OoOgmo1onBTY86ooGem@OoQ8B41_m/K6`6ooooo`Oo=CDe1olO
7al7ok>c/`Oo2PX:1olk>c/6ob/[:`OoB4Q81_mlO7`6ooooo`Oo9BDU1olX:2P7obl_;`Oo4a<C1_lD
51@7o`/;2`Oo4Q8B1_lc<c<6ooooo`Oo>3Ph1omLG5`7o`0000OoM7Ad1_l/;2`7oaDE5@Oo?clo1_nT
Y:@6ooooo`Oo3`l?1olB4Q87oa@D50Ko30`<1ol@4107o`l?3`Oo4A4A1_lJ6QX6ooooo`Oo?3`l1olE
5AD7ogAdM0Ko@T921ol?3`l7odQ8B0Oo20P81_m7AdL6ooooo`Oof][J1olU9BD6ofEUI@Oo?3`l1ond
];@7oiNGU`Oo9BDU1_ln?Sh6ooooo`Oo3@d=1_m<C4`7odI6APOo?3`l1omGEeL7oaXJ6POoA4A41_ol
o?`>ooooo`003?ooool7oa`L70Oo820P1ol/;2`7ogmoO`OoTY:B1_oemOD7ohB4Q0KoK6a/1_ooool7
ocDe=@Oo7alO1onc/k<7o`X:2POo>c/k1_l[:b/7odQ8B0KoO7al1_ooool7obDU9@Oo:2PX1ol_;bl7
oa<C4`Ko51@D1ol;2`/7oa8B4PKo<c<c1_ooool7ocPh>0OoG5aL1ol00007ogAdM0Ko;2`/1olE5AD7
oclo?`KoY:BT1_ooool7o`l?3`Oo4Q8B1olD51@6o``<30Oo410@1ol?3`l7oa4A4@Ko6QXJ1_ooool7
oc`l?0Oo5ADE1omdM7@6od92@POo3`l?1om8B4P7o`P820KoAdM71_ooool7om[JfPOo9BDU1_mUIFD7
oc`l?0Oo];Bd1onGUiL7obDU9@Ko?Shn1_ooool7o`d=3@KoC4a<1om6ATH7oc`l?0OoEeMG1olJ6QX7
odA4A0Koo?cl3_ooool000cooooo1olL71`7ob0P80Oo;2`/1omoOgl7oi:BTPKomOGe1on4Q8@6ofa/
K0Kooooo1ole=CD7oalO7`Oo/k>c1ol:2PX7oc/k>`Ko:b/[1om8B4P6ogalO0Kooooo1olU9BD7obPX
:0Oo;bl_1olC4a<6oa@D50Oo2`/;1olB4Q86oc<c<`Kooooo1olh>3P7oeaLG0Oo00001omdM7@6ob`/
;0Oo5ADE1olo?cl6ojBTY0Kooooo1ol?3`l7oa8B4POo51@D1_l<30`7oa0@40Oo3`l?1olA4A46oaXJ
6PKooooo1oll?3`7oaDE5@OoM7Ad1_m2@T87o`l?3`OoB4Q81ol820P6odM7A`Kooooo1ooJf]X7obDU
9@KoIFEU1oll?3`7okBd]0OoUiNG1olU9BD6ochn?PKooooo1ol=3@d6oda<C0OoATI61oll?3`7oeMG
E`Oo6QXJ1om4A4@6ooclo0kooooo000<ooooo`Oo71`L1olP8207ob`/;0OoOgmo1onBTY86ooGem@Oo
Q8B41_m/K6`6ooooo`Oo=CDe1olO7al7ok>c/`Oo2PX:1olk>c/6ob/[:`OoB4Q81_mlO7`6ooooo`Oo
9BDU1olX:2P7obl_;`Oo4a<C1_lD51@7o`/;2`Oo4Q8B1_lc<c<6ooooo`Oo>3Ph1omLG5`7o`0000Oo
M7Ad1_l/;2`7oaDE5@Oo?clo1_nTY:@6ooooo`Oo3`l?1olB4Q87oa@D50Ko30`<1ol@4107o`l?3`Oo
4A4A1_lJ6QX6ooooo`Oo?3`l1olE5AD7ogAdM0Ko@T921ol?3`l7odQ8B0Oo20P81_m7AdL6ooooo`Oo
f][J1olU9BD6ofEUI@Oo?3`l1ond];@7oiNGU`Oo9BDU1_ln?Sh6ooooo`Oo3@d=1_m<C4`7odI6APOo
?3`l1omGEeL7oaXJ6POoA4A41_olo?`>ooooo`003?ooool7oa`L70Oo820P1ol/;2`7ogmoO`OoTY:B
1_oemOD7ohB4Q0KoK6a/1_ooool7ocDe=@Oo7alO1onc/k<7o`X:2POo>c/k1_l[:b/7odQ8B0KoO7al
1_ooool7obDU9@Oo:2PX1ol_;bl7oa<C4`Ko51@D1ol;2`/7oa8B4PKo<c<c1_ooool7ocPh>0OoG5aL
1ol00007ogAdM0Ko;2`/1olE5AD7oclo?`KoY:BT1_ooool7o`l?3`Oo4Q8B1olD51@6o``<30Oo410@
1ol?3`l7oa4A4@Ko6QXJ1_ooool7oc`l?0Oo5ADE1omdM7@6od92@POo3`l?1om8B4P7o`P820KoAdM7
1_ooool7om[JfPOo9BDU1_mUIFD7oc`l?0Oo];Bd1onGUiL7obDU9@Ko?Shn1_ooool7o`d=3@KoC4a<
1om6ATH7oc`l?0OoEeMG1olJ6QX7odA4A0Koo?cl3_ooool000cooooo1om1@D47obTY:@Oo820P1oll
?3`7ohj>SPKoj>SX1omkNg/6od92@PKooooo1olR8R87oc/k>`Oo;Bd]1ol=3@d7odU9B@Ko:BTY1ol[
:b/6oclo?`Kooooo1ol^;Rh7oc@d=0Oo9RHV1olX:2P6ob/[:`Oo4Q8B1olV9RH6oeUIF@Kooooo1ome
MGD7ofa/K0Oo=cLg1om9BDT6oalO7`OoUiNG1om]KFd6oemOG`Kooooo1omDE5@7ooooo`OoQXJ61_m0
@407ofEUI@Oo@D511olh>3P6oc4a<@Kooooo1on>SXh7obPX:0OoNWYj1_l^;Rh7ogEeM@OoMgMg1olC
4a<6od];B`Kooooo1ombLW87ocPh>0KoTY:B1olh>3P7of5QH@OoEUIF1omADE46oijNWPKooooo1olL
71`6odY:BPOo820P1ol];Bd7odM7A`Oo9bLW1omNGUh6of9RHPkooooo000<ooooo`Oo@D511olY:BT7
ob0P80Oo?3`l1on>SXh6onSXj0OoNg]k1_m2@T86ooooo`Oo8R8R1olk>c/7obd];@Oo3@d=1om9BDT6
obTY:@Oo:b/[1_lo?cl6ooooo`Oo;Rh^1old=3@7obHV9POo:2PX1_l[:b/7oa8B4POo9RHV1_mIFET6
ooooo`OoMGEe1om/K6`7ocLg=`OoBDU91_lO7al7oiNGU`OoKFe]1_mOGel6ooooo`OoE5AD1oooool7
ohJ6QPKo@4101omUIFD7od51@@Oo>3Ph1_la<C46ooooo`OoSXj>1olX:2P7ogYjNPKo;Rh^1omeMGD7
ogMgM`Oo4a<C1_m;Bd/6ooooo`OoLW9b1olh>3P6oi:BTPOo>3Ph1omQHF47oeIFEPOoDE5A1_nNWYh6
ooooo`Oo71`L1_m:BTX7ob0P80Oo;Bd]1om7AdL7obLW9`OoGUiN1_mRHV8>ooooo`003?ooool7od51
@@Oo:BTY1olP8207oc`l?0OoSXj>1_oXj>P7og]kN`Ko@T921_ooool7ob8R8POo>c/k1ol];Bd7o`d=
3@OoBDU91_lY:BT7ob/[:`Ko?clo1_ooool7obh^;POo=3@d1olV9RH7obPX:0Ko:b/[1olB4Q87obHV
9PKoFEUI1_ooool7ogEeM@OoK6a/1olg=cL7odU9B@Ko7alO1onGUiL7ofe]K@KoGemO1_ooool7oeAD
E0Oooooo1on6QXH6od10@0OoIFEU1om1@D47ocPh>0Ko<C4a1_ooool7ohj>SPOo:2PX1omjNWX6obh^
;POoMGEe1omgMgL7oa<C4`KoBd];1_ooool7og9bLPOo>3Ph1_nBTY87ocPh>0OoHF5Q1omFEUH7oe5A
D@KoWYjN1_ooool7oa`L70KoBTY:1olP8207obd];@OoAdM71olW9bL7oeiNGPKoHV9R3_ooool000co
oooo1om1@D47obTY:@Oo820P1oll?3`7ohj>SPKoj>SX1omkNg/6od92@PKooooo1olR8R87oc/k>`Oo
;Bd]1ol=3@d7odU9B@Ko:BTY1ol[:b/6oclo?`Kooooo1ol^;Rh7oc@d=0Oo9RHV1olX:2P6ob/[:`Oo
4Q8B1olV9RH6oeUIF@Kooooo1omeMGD7ofa/K0Oo=cLg1om9BDT6oalO7`OoUiNG1om]KFd6oemOG`Ko
oooo1omDE5@7ooooo`OoQXJ61_m0@407ofEUI@Oo@D511olh>3P6oc4a<@Kooooo1on>SXh7obPX:0Oo
NWYj1_l^;Rh7ogEeM@OoMgMg1olC4a<6od];B`Kooooo1ombLW87ocPh>0KoTY:B1olh>3P7of5QH@Oo
EUIF1omADE46oijNWPKooooo1olL71`6odY:BPOo820P1ol];Bd7odM7A`Oo9bLW1omNGUh6of9RHPko
oooo000<ooooo`Oo@D511olY:BT7ob0P80Oo?3`l1on>SXh6onSXj0OoNg]k1_m2@T86ooooo`Oo8R8R
1olk>c/7obd];@Oo3@d=1om9BDT6obTY:@Oo:b/[1_lo?cl6ooooo`Oo;Rh^1old=3@7obHV9POo:2PX
1_l[:b/7oa8B4POo9RHV1_mIFET6ooooo`OoMGEe1om/K6`7ocLg=`OoBDU91_lO7al7oiNGU`OoKFe]
1_mOGel6ooooo`OoE5AD1oooool7ohJ6QPKo@4101omUIFD7od51@@Oo>3Ph1_la<C46ooooo`OoSXj>
1olX:2P7ogYjNPKo;Rh^1omeMGD7ogMgM`Oo4a<C1_m;Bd/6ooooo`OoLW9b1olh>3P6oi:BTPOo>3Ph
1omQHF47oeIFEPOoDE5A1_nNWYh6ooooo`Oo71`L1_m:BTX7ob0P80Oo;Bd]1om7AdL7obLW9`OoGUiN
1_mRHV8>ooooo`003?ooool7od51@@Oo:BTY1olP8207oc`l?0OoSXj>1_oXj>P7og]kN`Ko@T921_oo
ool7ob8R8POo>c/k1ol];Bd7o`d=3@OoBDU91_lY:BT7ob/[:`Ko?clo1_ooool7obh^;POo=3@d1olV
9RH7obPX:0Ko:b/[1olB4Q87obHV9PKoFEUI1_ooool7ogEeM@OoK6a/1olg=cL7odU9B@Ko7alO1onG
UiL7ofe]K@KoGemO1_ooool7oeADE0Oooooo1on6QXH6od10@0OoIFEU1om1@D47ocPh>0Ko<C4a1_oo
ool7ohj>SPOo:2PX1omjNWX6obh^;POoMGEe1omgMgL7oa<C4`KoBd];1_ooool7og9bLPOo>3Ph1_nB
TY87ocPh>0OoHF5Q1omFEUH7oe5AD@KoWYjN1_ooool7oa`L70KoBTY:1olP8207obd];@OoAdM71olW
9bL7oeiNGPKoHV9R3_ooool000cooooo1om1@D47obTY:@Oo820P1oll?3`7ohj>SPKoj>SX1omkNg/6
od92@PKooooo1olR8R87oc/k>`Oo;Bd]1ol=3@d7odU9B@Ko:BTY1ol[:b/6oclo?`Kooooo1ol^;Rh7
oc@d=0Oo9RHV1olX:2P6ob/[:`Oo4Q8B1olV9RH6oeUIF@Kooooo1omeMGD7ofa/K0Oo=cLg1om9BDT6
oalO7`OoUiNG1om]KFd6oemOG`Kooooo1omDE5@7ooooo`OoQXJ61_m0@407ofEUI@Oo@D511olh>3P6
oc4a<@Kooooo1on>SXh7obPX:0OoNWYj1_l^;Rh7ogEeM@OoMgMg1olC4a<6od];B`Kooooo1ombLW87
ocPh>0KoTY:B1olh>3P7of5QH@OoEUIF1omADE46oijNWPKooooo1olL71`6odY:BPOo820P1ol];Bd7
odM7A`Oo9bLW1omNGUh6of9RHPkooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000<ooooo`OoNg]k1omYJFT7olo?c`Oo
@T921om9BDT6obHV9POoAdM71_m<C4`6ooooo`OoCTi>1olS8b<7oeIFEPOooooo1olK6a/6od92@POo
:b/[1_lS8b<6ooooo`Oo30`<1ol>3Ph7o`820POo1@D51_l71`L7o`H61POo410@1_lO7al6ooooo`Oo
9bLW1olD51@7o`0000Oo@D511_l@4107o`T92@OoFEUI1_lK6a/6ooooo`Oo?3`l1olY:BT7oa0@40Ko
9BDU1ol^;Rh7oeQHF0Oo[Jf]1_mTI6@6ooooo`OoEeMG1ol20P87oaHF5PKo7AdM1olI6AT7oda<C0Oo
6a/K1_mRHV86ooooo`Oo7AdM1olX:2P6ob`/;0Oo@4101on5QHD7oa@D50Oo<C4a3?ooool7o`X:2PKo
8b<S1ol10@47ocPh>0Oo0@411ol?3`l7oc8b<PKoCTi>3_ooool000cooooo1omkNg/7ofUYJ@Ooclo?
1om2@T87odU9B@Ko9RHV1om7AdL6oda<C0Kooooo1om>CTh7ob<S8`OoEUIF1oooool7oa/K6`Ko@T92
1ol[:b/6ob<S8`Kooooo1ol<30`7o`h>3POo0P821ol51@D6o`L71`Oo1PH61ol@4106oalO7`Kooooo
1olW9bL7oa@D50Oo00001om1@D46oa0@40Oo2@T91omIFET6oa/K6`Kooooo1oll?3`7obTY:@Oo410@
1_lU9BD7obh^;POoF5QH1on][Jd6ofATI0Kooooo1omGEeL7o`820POo5QHF1_lM7Ad7oaTI6@OoC4a<
1olK6a/6of9RHPKooooo1olM7Ad7obPX:0Ko;2`/1om0@407ohF5Q@Oo51@D1ola<C4<ooooo`Oo2PX:
1_lS8b<7o`410@Oo>3Ph1ol10@47o`l?3`Oo<S8b1_m>CTh>ooooo`003?ooool7og]kN`OoJFUY1oo?
cll7od92@POoBDU91_lV9RH7odM7A`KoC4a<1_ooool7odi>CPOo8b<S1omFEUH7ooooo`Oo6a/K1_m2
@T87ob/[:`Ko8b<S1_ooool7o``<30Oo3Ph>1ol20P87o`D51@Ko1`L71ol61PH7oa0@40Ko7alO1_oo
ool7obLW9`Oo51@D1ol00007od51@@Ko410@1ol92@T7oeUIF@Ko6a/K1_ooool7oc`l?0Oo:BTY1ol@
4106obDU9@Oo;Rh^1omHF5P7ojf][@KoI6AT1_ooool7oeMGE`Oo0P821olF5QH6oadM7@Oo6ATI1om<
C4`7oa/K6`KoHV9R1_ooool7oadM7@Oo:2PX1_l/;2`7od10@0OoQHF51olD51@7oc4a<@cooooo1ol:
2PX6ob<S8`Oo0@411olh>3P7o`410@Oo3`l?1olb<S86odi>CPkooooo000<ooooo`OoNg]k1omYJFT7
olo?c`Oo@T921om9BDT6obHV9POoAdM71_m<C4`6ooooo`OoCTi>1olS8b<7oeIFEPOooooo1olK6a/6
od92@POo:b/[1_lS8b<6ooooo`Oo30`<1ol>3Ph7o`820POo1@D51_l71`L7o`H61POo410@1_lO7al6
ooooo`Oo9bLW1olD51@7o`0000Oo@D511_l@4107o`T92@OoFEUI1_lK6a/6ooooo`Oo?3`l1olY:BT7
oa0@40Ko9BDU1ol^;Rh7oeQHF0Oo[Jf]1_mTI6@6ooooo`OoEeMG1ol20P87oaHF5PKo7AdM1olI6AT7
oda<C0Oo6a/K1_mRHV86ooooo`Oo7AdM1olX:2P6ob`/;0Oo@4101on5QHD7oa@D50Oo<C4a3?ooool7
o`X:2PKo8b<S1ol10@47ocPh>0Oo0@411ol?3`l7oc8b<PKoCTi>3_ooool000cooooo1omkNg/7ofUY
J@Ooclo?1om2@T87odU9B@Ko9RHV1om7AdL6oda<C0Kooooo1om>CTh7ob<S8`OoEUIF1oooool7oa/K
6`Ko@T921ol[:b/6ob<S8`Kooooo1ol<30`7o`h>3POo0P821ol51@D6o`L71`Oo1PH61ol@4106oalO
7`Kooooo1olW9bL7oa@D50Oo00001om1@D46oa0@40Oo2@T91omIFET6oa/K6`Kooooo1oll?3`7obTY
:@Oo410@1_lU9BD7obh^;POoF5QH1on][Jd6ofATI0Kooooo1omGEeL7o`820POo5QHF1_lM7Ad7oaTI
6@OoC4a<1olK6a/6of9RHPKooooo1olM7Ad7obPX:0Ko;2`/1om0@407ohF5Q@Oo51@D1ola<C4<oooo
o`Oo2PX:1_lS8b<7o`410@Oo>3Ph1ol10@47o`l?3`Oo<S8b1_m>CTh>ooooo`003?ooool7og]kN`Oo
JFUY1oo?cll7od92@POoBDU91_lV9RH7odM7A`KoC4a<1_ooool7odi>CPOo8b<S1omFEUH7ooooo`Oo
6a/K1_m2@T87ob/[:`Ko8b<S1_ooool7o``<30Oo3Ph>1ol20P87o`D51@Ko1`L71ol61PH7oa0@40Ko
7alO1_ooool7obLW9`Oo51@D1ol00007od51@@Ko410@1ol92@T7oeUIF@Ko6a/K1_ooool7oc`l?0Oo
:BTY1ol@4106obDU9@Oo;Rh^1omHF5P7ojf][@KoI6AT1_ooool7oeMGE`Oo0P821olF5QH6oadM7@Oo
6ATI1om<C4`7oa/K6`KoHV9R1_ooool7oadM7@Oo:2PX1_l/;2`7od10@0OoQHF51olD51@7oc4a<@co
oooo1ol:2PX6ob<S8`Oo0@411olh>3P7o`410@Oo3`l?1olb<S86odi>CPkooooo000<ooooo`OoNg]k
1omYJFT7olo?c`Oo@T921om9BDT6obHV9POoAdM71_m<C4`6ooooo`OoCTi>1olS8b<7oeIFEPOooooo
1olK6a/6od92@POo:b/[1_lS8b<6ooooo`Oo30`<1ol>3Ph7o`820POo1@D51_l71`L7o`H61POo410@
1_lO7al6ooooo`Oo9bLW1olD51@7o`0000Oo@D511_l@4107o`T92@OoFEUI1_lK6a/6ooooo`Oo?3`l
1olY:BT7oa0@40Ko9BDU1ol^;Rh7oeQHF0Oo[Jf]1_mTI6@6ooooo`OoEeMG1ol20P87oaHF5PKo7AdM
1olI6AT7oda<C0Oo6a/K1_mRHV86ooooo`Oo7AdM1olX:2P6ob`/;0Oo@4101on5QHD7oa@D50Oo<C4a
3?ooool7o`X:2PKo8b<S1ol10@47ocPh>0Oo0@411ol?3`l7oc8b<PKoCTi>3_ooool000cooooo1omO
Gel7ofMWI`Oo`/;21om8B4P7oe]KF`Ko00001ol[:b/6oclo?`Kooooo1olb<S87obLW9`OoFEUI1ooM
gMd7oa`L70Ko?3`l1ol];Bd6oa4A4@Kooooo1ol820P7o`D51@Oo10@41ol71`L6o`H61POo0P821ol7
1`L6obTY:@Kooooo1olZ:RX7obPX:0Oo10@41ol];Bd6oaXJ6POo7QhN1ol`<306obXZ:PKooooo1ol/
;2`7o`h>3POo5aLG1_lH61P7obh^;POoFEUI1onXZ:P6og9bLPKooooo1omlO7`7o`h>3POo6QXJ1_lT
92@7ob8R8POo>3Ph1olQ8B46ofUYJ@Kooooo1olK6a/7ob<S8`Ko?Cdm1ol/;2`7oh61P@Oo61PH1olc
<c<6ojNWY`Kooooo1olK6a/6ob<S8`Oo00001ombLW87o`820POo10@41olS8b<6ogmoO`kooooo000<
ooooo`OoGemO1omWIfL7ol;2`POoB4Q81omKFe/6o`0000Oo:b/[1_lo?cl6ooooo`Oo<S8b1olW9bL7
oeUIF@OogMgM1olL71`6oc`l?0Oo;Bd]1_lA4A46ooooo`Oo20P81ol51@D7o`@410Oo1`L71_l61PH7
o`820POo1`L71_lY:BT6ooooo`Oo:RXZ1olX:2P7o`@410Oo;Bd]1_lJ6QX7oahN7POo<30`1_lZ:RX6
ooooo`Oo;2`/1ol>3Ph7oaLG5`Ko61PH1ol^;Rh7oeUIF@OoZ:RX1_mbLW86ooooo`OoO7al1ol>3Ph7
oaXJ6PKo92@T1olR8R87ocPh>0Oo8B4Q1_mYJFT6ooooo`Oo6a/K1olS8b<6ocdm?@Oo;2`/1on1PH47
oaPH60Oo<c<c1_nWYjL6ooooo`Oo6a/K1_lS8b<7o`0000OoLW9b1ol20P87o`@410Oo8b<S1_moOgl>
ooooo`003?ooool7oemOG`OoIfMW1oo2`/87odQ8B0OoFe]K1_l00007ob/[:`Ko?clo1_ooool7oc8b
<POo9bLW1omIFET7omgMg@Oo71`L1_ll?3`7obd];@Ko4A4A1_ooool7o`P820Oo1@D51ol410@7o`L7
1`Ko1PH61ol20P87o`L71`Ko:BTY1_ooool7obXZ:POo:2PX1ol410@7obd];@Ko6QXJ1olN7Qh7oc0`
<0Ko:RXZ1_ooool7ob`/;0Oo3Ph>1olG5aL6oaPH60Oo;Rh^1omIFET7ojRXZ0KoLW9b1_ooool7ogal
O0Oo3Ph>1olJ6QX6ob@T90Oo8R8R1olh>3P7ob4Q8@KoJFUY1_ooool7oa/K6`Oo8b<S1_lm?Cd7ob`/
;0OoPH611olH61P7oc<c<`KoYjNW1_ooool7oa/K6`Ko8b<S1ol00007og9bLPOo0P821ol410@7ob<S
8`KoOgmo3_ooool000cooooo1omOGel7ofMWI`Oo`/;21om8B4P7oe]KF`Ko00001ol[:b/6oclo?`Ko
oooo1olb<S87obLW9`OoFEUI1ooMgMd7oa`L70Ko?3`l1ol];Bd6oa4A4@Kooooo1ol820P7o`D51@Oo
10@41ol71`L6o`H61POo0P821ol71`L6obTY:@Kooooo1olZ:RX7obPX:0Oo10@41ol];Bd6oaXJ6POo
7QhN1ol`<306obXZ:PKooooo1ol/;2`7o`h>3POo5aLG1_lH61P7obh^;POoFEUI1onXZ:P6og9bLPKo
oooo1omlO7`7o`h>3POo6QXJ1_lT92@7ob8R8POo>3Ph1olQ8B46ofUYJ@Kooooo1olK6a/7ob<S8`Ko
?Cdm1ol/;2`7oh61P@Oo61PH1olc<c<6ojNWY`Kooooo1olK6a/6ob<S8`Oo00001ombLW87o`820POo
10@41olS8b<6ogmoO`kooooo000<ooooo`OoGemO1omWIfL7ol;2`POoB4Q81omKFe/6o`0000Oo:b/[
1_lo?cl6ooooo`Oo<S8b1olW9bL7oeUIF@OogMgM1olL71`6oc`l?0Oo;Bd]1_lA4A46ooooo`Oo20P8
1ol51@D7o`@410Oo1`L71_l61PH7o`820POo1`L71_lY:BT6ooooo`Oo:RXZ1olX:2P7o`@410Oo;Bd]
1_lJ6QX7oahN7POo<30`1_lZ:RX6ooooo`Oo;2`/1ol>3Ph7oaLG5`Ko61PH1ol^;Rh7oeUIF@OoZ:RX
1_mbLW86ooooo`OoO7al1ol>3Ph7oaXJ6PKo92@T1olR8R87ocPh>0Oo8B4Q1_mYJFT6ooooo`Oo6a/K
1olS8b<6ocdm?@Oo;2`/1on1PH47oaPH60Oo<c<c1_nWYjL6ooooo`Oo6a/K1_lS8b<7o`0000OoLW9b
1ol20P87o`@410Oo8b<S1_moOgl>ooooo`003?ooool7oemOG`OoIfMW1oo2`/87odQ8B0OoFe]K1_l0
0007ob/[:`Ko?clo1_ooool7oc8b<POo9bLW1omIFET7omgMg@Oo71`L1_ll?3`7obd];@Ko4A4A1_oo
ool7o`P820Oo1@D51ol410@7o`L71`Ko1PH61ol20P87o`L71`Ko:BTY1_ooool7obXZ:POo:2PX1ol4
10@7obd];@Ko6QXJ1olN7Qh7oc0`<0Ko:RXZ1_ooool7ob`/;0Oo3Ph>1olG5aL6oaPH60Oo;Rh^1omI
FET7ojRXZ0KoLW9b1_ooool7ogalO0Oo3Ph>1olJ6QX6ob@T90Oo8R8R1olh>3P7ob4Q8@KoJFUY1_oo
ool7oa/K6`Oo8b<S1_lm?Cd7ob`/;0OoPH611olH61P7oc<c<`KoYjNW1_ooool7oa/K6`Ko8b<S1ol0
0007og9bLPOo0P821ol410@7ob<S8`KoOgmo3_ooool000cooooo1omOGel7ofMWI`Oo`/;21om8B4P7
oe]KF`Ko00001ol[:b/6oclo?`Kooooo1olb<S87obLW9`OoFEUI1ooMgMd7oa`L70Ko?3`l1ol];Bd6
oa4A4@Kooooo1ol820P7o`D51@Oo10@41ol71`L6o`H61POo0P821ol71`L6obTY:@Kooooo1olZ:RX7
obPX:0Oo10@41ol];Bd6oaXJ6POo7QhN1ol`<306obXZ:PKooooo1ol/;2`7o`h>3POo5aLG1_lH61P7
obh^;POoFEUI1onXZ:P6og9bLPKooooo1omlO7`7o`h>3POo6QXJ1_lT92@7ob8R8POo>3Ph1olQ8B46
ofUYJ@Kooooo1olK6a/7ob<S8`Ko?Cdm1ol/;2`7oh61P@Oo61PH1olc<c<6ojNWY`Kooooo1olK6a/6
ob<S8`Oo00001ombLW87o`820POo10@41olS8b<6ogmoO`kooooo000<ooooo`OoTi>C1on2PX87oooo
o`OoD51@1omLG5`6ob@T90Oo>SXj1_m=CDd6ooooo`OoA4A41olM7Ad7oc0`<0OoZ:RX1ol820P6od51
@@OoBDU91_lV9RH6ooooo`Oo2@T91ol00007o`@410Oo0P821_l51@D7o`@410Oo2PX:1_lV9RH6oooo
o`OoGUiN1olg=cL7o`410@Oo8b<S1_l30`<7oaDE5@Oo=3@d1_lI6AT6ooooo`OoATI61olT92@7o`X:
2PKo820P1olK6a/7of1PH0OoZj^[1_mMGEd6ooooo`OoTI6A1olE5AD7oaHF5PKo:b/[1oli>CT7odm?
C`Oo00001_l_;bl6ooooo`Oo30`<1olR8R86oaXJ6POo5aLG1omGEeL7oa@D50Oo<S8b1_m9BDT6oooo
o`Oo4a<C1_l];Bd7o`0000OoK6a/1olX:2P7o`l?3`Oo9bLW1_oalO4>ooooo`003?ooool7oi>CT`Oo
PX:21oooool7oe1@D0OoG5aL1_lT92@7ocXj>PKoCDe=1_ooool7odA4A0Oo7AdM1ol`<307ojRXZ0Oo
20P81_m1@D47odU9B@Ko9RHV1_ooool7o`T92@Oo00001ol410@7o`820PKo1@D51ol410@7o`X:2PKo
9RHV1_ooool7oeiNGPOo=cLg1ol10@47ob<S8`Ko0`<31olE5AD7oc@d=0Ko6ATI1_ooool7odI6APOo
92@T1ol:2PX6ob0P80Oo6a/K1omPH607oj^[Z`KoGEeM1_ooool7oi6AT@Oo5ADE1olF5QH6ob/[:`Oo
>CTi1om?Cdl7o`0000Ko;bl_1_ooool7o``<30Oo8R8R1_lJ6QX7oaLG5`OoEeMG1olD51@7oc8b<PKo
BDU91_ooool7oa<C4`Ko;Bd]1ol00007ofa/K0Oo:2PX1ol?3`l7obLW9`KolO7a3_ooool000cooooo
1onCTi<7oh:2PPOooooo1om@D507oeaLG0Ko92@T1olj>SX6ode=C@Kooooo1om4A4@7oadM7@Oo<30`
1onXZ:P7o`P820Ko@D511om9BDT6obHV9PKooooo1ol92@T7o`0000Oo10@41ol20P86o`D51@Oo10@4
1ol:2PX6obHV9PKooooo1omNGUh7ocLg=`Oo0@411olS8b<6o`<30`Oo5ADE1old=3@6oaTI6@Kooooo
1om6ATH7ob@T90Oo2PX:1_lP8207oa/K6`OoH61P1on[Zj/6oeeMG@Kooooo1onATI47oaDE5@Oo5QHF
1_l[:b/7ocTi>@OoCdm?1ol00006obl_;`Kooooo1ol<30`7ob8R8PKo6QXJ1olG5aL7oeMGE`Oo51@D
1olb<S86odU9B@Kooooo1olC4a<6obd];@Oo00001om/K6`7obPX:0Oo3`l?1olW9bL6oo7al@kooooo
000<ooooo`OoTi>C1on2PX87ooooo`OoD51@1omLG5`6ob@T90Oo>SXj1_m=CDd6ooooo`OoA4A41olM
7Ad7oc0`<0OoZ:RX1ol820P6od51@@OoBDU91_lV9RH6ooooo`Oo2@T91ol00007o`@410Oo0P821_l5
1@D7o`@410Oo2PX:1_lV9RH6ooooo`OoGUiN1olg=cL7o`410@Oo8b<S1_l30`<7oaDE5@Oo=3@d1_lI
6AT6ooooo`OoATI61olT92@7o`X:2PKo820P1olK6a/7of1PH0OoZj^[1_mMGEd6ooooo`OoTI6A1olE
5AD7oaHF5PKo:b/[1oli>CT7odm?C`Oo00001_l_;bl6ooooo`Oo30`<1olR8R86oaXJ6POo5aLG1omG
EeL7oa@D50Oo<S8b1_m9BDT6ooooo`Oo4a<C1_l];Bd7o`0000OoK6a/1olX:2P7o`l?3`Oo9bLW1_oa
lO4>ooooo`003?ooool7oi>CT`OoPX:21oooool7oe1@D0OoG5aL1_lT92@7ocXj>PKoCDe=1_ooool7
odA4A0Oo7AdM1ol`<307ojRXZ0Oo20P81_m1@D47odU9B@Ko9RHV1_ooool7o`T92@Oo00001ol410@7
o`820PKo1@D51ol410@7o`X:2PKo9RHV1_ooool7oeiNGPOo=cLg1ol10@47ob<S8`Ko0`<31olE5AD7
oc@d=0Ko6ATI1_ooool7odI6APOo92@T1ol:2PX6ob0P80Oo6a/K1omPH607oj^[Z`KoGEeM1_ooool7
oi6AT@Oo5ADE1olF5QH6ob/[:`Oo>CTi1om?Cdl7o`0000Ko;bl_1_ooool7o``<30Oo8R8R1_lJ6QX7
oaLG5`OoEeMG1olD51@7oc8b<PKoBDU91_ooool7oa<C4`Ko;Bd]1ol00007ofa/K0Oo:2PX1ol?3`l7
obLW9`KolO7a3_ooool000cooooo1onCTi<7oh:2PPOooooo1om@D507oeaLG0Ko92@T1olj>SX6ode=
C@Kooooo1om4A4@7oadM7@Oo<30`1onXZ:P7o`P820Ko@D511om9BDT6obHV9PKooooo1ol92@T7o`00
00Oo10@41ol20P86o`D51@Oo10@41ol:2PX6obHV9PKooooo1omNGUh7ocLg=`Oo0@411olS8b<6o`<3
0`Oo5ADE1old=3@6oaTI6@Kooooo1om6ATH7ob@T90Oo2PX:1_lP8207oa/K6`OoH61P1on[Zj/6oeeM
G@Kooooo1onATI47oaDE5@Oo5QHF1_l[:b/7ocTi>@OoCdm?1ol00006obl_;`Kooooo1ol<30`7ob8R
8PKo6QXJ1olG5aL7oeMGE`Oo51@D1olb<S86odU9B@Kooooo1olC4a<6obd];@Oo00001om/K6`7obPX
:0Oo3`l?1olW9bL6oo7al@kooooo000<ooooo`OoU9BD1onRXZ87ooKfmPOoOgmo1onJVYX6ob`/;0Oo
G5aL1_m:BTX6ooooo`Oo?Cdm1olQ8B47oa`L70OoH61P1olC4a<6oc`l?0Oo=CDe1_lW9bL6ooooo`Oo
0`<31ol>3Ph7o`@410Oo0`<31_l61PH7o`L71`Oo0@411_l[:b/6ooooo`OoFe]K1onATI47o`X:2POo
5QHF1_lP8207oaXJ6POo:RXZ1_li>CT6ooooo`Oo;Bd]1olH61P7o`0000Ko2PX:1olQ8B47oeQHF0Oo
TY:B1_mXJ6P6ooooo`Oofm_K1olF5QH7ocTi>@Ko61PH1ola<C47oijNWPOo6ATI1_mFEUH6ooooo`Oo
1PH61olf=SH6oa0@40Oo3Ph>1olc<c<7o`T92@Oo8B4Q1_ld=3@6ooooo`Oo2PX:1_lS8b<7o`@410Oo
IFEU1om2@T87o`820POo;Rh^1_o7alL>ooooo`003?ooool7oiBDU0OoXZ:R1oofm_H7ogmoO`OoVYZJ
1_l/;2`7oeaLG0KoBTY:1_ooool7ocdm?@Oo8B4Q1olL71`7of1PH0Oo4a<C1_ll?3`7ocDe=@Ko9bLW
1_ooool7o`<30`Oo3Ph>1ol410@7o`<30`Ko1PH61ol71`L7o`410@Ko:b/[1_ooool7oe]KF`OoTI6A
1ol:2PX7oaHF5PKo820P1olJ6QX7obXZ:PKo>CTi1_ooool7obd];@Oo61PH1ol00006o`X:2POo8B4Q
1omHF5P7oi:BTPKoJ6QX1_ooool7om_Kf`Oo5QHF1oli>CT6oaPH60Oo<C4a1onNWYh7oaTI6@KoEUIF
1_ooool7o`H61POo=SHf1_l@4107o`h>3POo<c<c1ol92@T7ob4Q8@Ko=3@d1_ooool7o`X:2PKo8b<S
1ol410@7ofEUI@Oo@T921ol20P87obh^;PKoalO73_ooool000cooooo1onDU9@7oj:RXPOom_Kf1omo
Ogl7oiZJVPKo;2`/1omLG5`6odY:BPKooooo1olm?Cd7ob4Q8@Oo71`L1omPH607oa<C4`Ko?3`l1ole
=CD6obLW9`Kooooo1ol30`<7o`h>3POo10@41ol30`<6o`H61POo1`L71ol10@46ob/[:`Kooooo1omK
Fe/7oi6AT@Oo2PX:1olF5QH6ob0P80Oo6QXJ1olZ:RX6ocTi>@Kooooo1ol];Bd7oaPH60Oo00001_l:
2PX7ob4Q8@OoF5QH1onBTY86ofQXJ0Kooooo1ooKfm/7oaHF5POo>CTi1_lH61P7oc4a<@OoWYjN1olI
6AT6oeIFEPKooooo1ol61PH7ocHf=PKo410@1ol>3Ph7oc<c<`Oo2@T91olQ8B46oc@d=0Kooooo1ol:
2PX6ob<S8`Oo10@41omUIFD7od92@POo0P821ol^;Rh6olO7a`kooooo000<ooooo`OoU9BD1onRXZ87
ooKfmPOoOgmo1onJVYX6ob`/;0OoG5aL1_m:BTX6ooooo`Oo?Cdm1olQ8B47oa`L70OoH61P1olC4a<6
oc`l?0Oo=CDe1_lW9bL6ooooo`Oo0`<31ol>3Ph7o`@410Oo0`<31_l61PH7o`L71`Oo0@411_l[:b/6
ooooo`OoFe]K1onATI47o`X:2POo5QHF1_lP8207oaXJ6POo:RXZ1_li>CT6ooooo`Oo;Bd]1olH61P7
o`0000Ko2PX:1olQ8B47oeQHF0OoTY:B1_mXJ6P6ooooo`Oofm_K1olF5QH7ocTi>@Ko61PH1ola<C47
oijNWPOo6ATI1_mFEUH6ooooo`Oo1PH61olf=SH6oa0@40Oo3Ph>1olc<c<7o`T92@Oo8B4Q1_ld=3@6
ooooo`Oo2PX:1_lS8b<7o`@410OoIFEU1om2@T87o`820POo;Rh^1_o7alL>ooooo`003?ooool7oiBD
U0OoXZ:R1oofm_H7ogmoO`OoVYZJ1_l/;2`7oeaLG0KoBTY:1_ooool7ocdm?@Oo8B4Q1olL71`7of1P
H0Oo4a<C1_ll?3`7ocDe=@Ko9bLW1_ooool7o`<30`Oo3Ph>1ol410@7o`<30`Ko1PH61ol71`L7o`41
0@Ko:b/[1_ooool7oe]KF`OoTI6A1ol:2PX7oaHF5PKo820P1olJ6QX7obXZ:PKo>CTi1_ooool7obd]
;@Oo61PH1ol00006o`X:2POo8B4Q1omHF5P7oi:BTPKoJ6QX1_ooool7om_Kf`Oo5QHF1oli>CT6oaPH
60Oo<C4a1onNWYh7oaTI6@KoEUIF1_ooool7o`H61POo=SHf1_l@4107o`h>3POo<c<c1ol92@T7ob4Q
8@Ko=3@d1_ooool7o`X:2PKo8b<S1ol410@7ofEUI@Oo@T921ol20P87obh^;PKoalO73_ooool000co
oooo1onDU9@7oj:RXPOom_Kf1omoOgl7oiZJVPKo;2`/1omLG5`6odY:BPKooooo1olm?Cd7ob4Q8@Oo
71`L1omPH607oa<C4`Ko?3`l1ole=CD6obLW9`Kooooo1ol30`<7o`h>3POo10@41ol30`<6o`H61POo
1`L71ol10@46ob/[:`Kooooo1omKFe/7oi6AT@Oo2PX:1olF5QH6ob0P80Oo6QXJ1olZ:RX6ocTi>@Ko
oooo1ol];Bd7oaPH60Oo00001_l:2PX7ob4Q8@OoF5QH1onBTY86ofQXJ0Kooooo1ooKfm/7oaHF5POo
>CTi1_lH61P7oc4a<@OoWYjN1olI6AT6oeIFEPKooooo1ol61PH7ocHf=PKo410@1ol>3Ph7oc<c<`Oo
2@T91olQ8B46oc@d=0Kooooo1ol:2PX6ob<S8`Oo10@41omUIFD7od92@POo0P821ol^;Rh6olO7a`ko
oooo000<ooooo`OoU9BD1onRXZ87ooKfmPOoOgmo1onJVYX6ob`/;0OoG5aL1_m:BTX6ooooo`Oo?Cdm
1olQ8B47oa`L70OoH61P1olC4a<6oc`l?0Oo=CDe1_lW9bL6ooooo`Oo0`<31ol>3Ph7o`@410Oo0`<3
1_l61PH7o`L71`Oo0@411_l[:b/6ooooo`OoFe]K1onATI47o`X:2POo5QHF1_lP8207oaXJ6POo:RXZ
1_li>CT6ooooo`Oo;Bd]1olH61P7o`0000Ko2PX:1olQ8B47oeQHF0OoTY:B1_mXJ6P6ooooo`Oofm_K
1olF5QH7ocTi>@Ko61PH1ola<C47oijNWPOo6ATI1_mFEUH6ooooo`Oo1PH61olf=SH6oa0@40Oo3Ph>
1olc<c<7o`T92@Oo8B4Q1_ld=3@6ooooo`Oo2PX:1_lS8b<7o`@410OoIFEU1om2@T87o`820POo;Rh^
1_o7alL>ooooo`003?ooool7ojRXZ0Oo^k^k1ooemOD7ogQhN0OoIVIV1_lb<S87odA4A0KoG5aL1_oo
ool7oeaLG0Oo5QHF1ol>3Ph7odQ8B0Oo00001_lb<S87odI6APKo92@T1_ooool7o`410@ko20P81ol3
0`<6o`d=3@Oo1`L71ol>3Ph6oa8B4PKooooo1omJFUX7ooooo`Oo7AdM1oln?Sh6obHV9POo:BTY1olb
<S86ocLg=`Kooooo1oln?Sh7ob0P80Oo20P81_l61PH7oa8B4POoEUIF1on6QXH6oc@d=0gooooo1olW
9bL7obd];@Ko;bl_1olo?cl7oj^[Z`Oo7alO1_mYJFT6ooooo`Oo00001olk>c/6oaTI6@Oo5QHF1olb
<S87o``<30Oo<c<c1_lV9RH6ooooo`Oo2PX:1_l[:b/7obDU9@OoI6AT1omSHf<7o`h>3POo=cLg5?oo
ool000cooooo1onXZ:P7ok^k^`OomOGe1omhN7P7ofIVIPKo<S8b1om4A4@6oeaLG0Kooooo1omLG5`7
oaHF5POo3Ph>1om8B4P7o`0000Ko<S8b1om6ATH6ob@T90Kooooo1ol10@4>o`P820Oo0`<31_l=3@d7
o`L71`Oo3Ph>1_lB4Q86ooooo`OoFUYJ1oooool7oadM7@Oo?Shn1_lV9RH7obTY:@Oo<S8b1_lg=cL6
ooooo`Oo?Shn1olP8207o`P820Ko1PH61olB4Q87oeIFEPOoQXJ61_ld=3@=ooooo`Oo9bLW1ol];Bd6
obl_;`Oo?clo1on[Zj/7oalO7`KoJFUY1_ooool7o`0000Oo>c/k1_lI6AT7oaHF5POo<S8b1ol<30`7
oc<c<`Ko9RHV1_ooool7o`X:2PKo:b/[1olU9BD7ofATI0OoHf=S1ol>3Ph7ocLg=aCooooo000<oooo
o`OoZ:RX1onk^k/7ooGem@OoN7Qh1omVIVH6oc8b<POoA4A41_mLG5`6ooooo`OoG5aL1olF5QH7o`h>
3POoB4Q81ol00006oc8b<POoATI61_lT92@6ooooo`Oo0@413_l820P7o`<30`Ko3@d=1ol71`L7o`h>
3PKo4Q8B1_ooool7oeYJFPOooooo1olM7Ad7ochn?PKo9RHV1olY:BT7oc8b<PKo=cLg1_ooool7ochn
?POo820P1ol820P6o`H61POo4Q8B1omFEUH7ohJ6QPKo=3@d3Oooool7obLW9`Oo;Bd]1_l_;bl7oclo
?`OoZj^[1olO7al6ofUYJ@Kooooo1ol00007oc/k>`Ko6ATI1olF5QH7oc8b<POo30`<1olc<c<6obHV
9PKooooo1ol:2PX6ob/[:`Oo9BDU1omTI6@7of=SH`Oo3Ph>1olg=cLDooooo`003?ooool7ojRXZ0Oo
^k^k1ooemOD7ogQhN0OoIVIV1_lb<S87odA4A0KoG5aL1_ooool7oeaLG0Oo5QHF1ol>3Ph7odQ8B0Oo
00001_lb<S87odI6APKo92@T1_ooool7o`410@ko20P81ol30`<6o`d=3@Oo1`L71ol>3Ph6oa8B4PKo
oooo1omJFUX7ooooo`Oo7AdM1oln?Sh6obHV9POo:BTY1olb<S86ocLg=`Kooooo1oln?Sh7ob0P80Oo
20P81_l61PH7oa8B4POoEUIF1on6QXH6oc@d=0gooooo1olW9bL7obd];@Ko;bl_1olo?cl7oj^[Z`Oo
7alO1_mYJFT6ooooo`Oo00001olk>c/6oaTI6@Oo5QHF1olb<S87o``<30Oo<c<c1_lV9RH6ooooo`Oo
2PX:1_l[:b/7obDU9@OoI6AT1omSHf<7o`h>3POo=cLg5?ooool000cooooo1onXZ:P7ok^k^`OomOGe
1omhN7P7ofIVIPKo<S8b1om4A4@6oeaLG0Kooooo1omLG5`7oaHF5POo3Ph>1om8B4P7o`0000Ko<S8b
1om6ATH6ob@T90Kooooo1ol10@4>o`P820Oo0`<31_l=3@d7o`L71`Oo3Ph>1_lB4Q86ooooo`OoFUYJ
1oooool7oadM7@Oo?Shn1_lV9RH7obTY:@Oo<S8b1_lg=cL6ooooo`Oo?Shn1olP8207o`P820Ko1PH6
1olB4Q87oeIFEPOoQXJ61_ld=3@=ooooo`Oo9bLW1ol];Bd6obl_;`Oo?clo1on[Zj/7oalO7`KoJFUY
1_ooool7o`0000Oo>c/k1_lI6AT7oaHF5POo<S8b1ol<30`7oc<c<`Ko9RHV1_ooool7o`X:2PKo:b/[
1olU9BD7ofATI0OoHf=S1ol>3Ph7ocLg=aCooooo000<ooooo`OoZ:RX1onk^k/7ooGem@OoN7Qh1omV
IVH6oc8b<POoA4A41_mLG5`6ooooo`OoG5aL1olF5QH7o`h>3POoB4Q81ol00006oc8b<POoATI61_lT
92@6ooooo`Oo0@413_l820P7o`<30`Ko3@d=1ol71`L7o`h>3PKo4Q8B1_ooool7oeYJFPOooooo1olM
7Ad7ochn?PKo9RHV1olY:BT7oc8b<PKo=cLg1_ooool7ochn?POo820P1ol820P6o`H61POo4Q8B1omF
EUH7ohJ6QPKo=3@d3Oooool7obLW9`Oo;Bd]1_l_;bl7oclo?`OoZj^[1olO7al6ofUYJ@Kooooo1ol0
0007oc/k>`Ko6ATI1olF5QH7oc8b<POo30`<1olc<c<6obHV9PKooooo1ol:2PX6ob/[:`Oo9BDU1omT
I6@7of=SH`Oo3Ph>1olg=cLDooooo`003?ooool7ojRXZ0Oo^k^k1ooemOD7ogQhN0OoIVIV1_lb<S87
odA4A0KoG5aL1_ooool7oeaLG0Oo5QHF1ol>3Ph7odQ8B0Oo00001_lb<S87odI6APKo92@T1_ooool7
o`410@ko20P81ol30`<6o`d=3@Oo1`L71ol>3Ph6oa8B4PKooooo1omJFUX7ooooo`Oo7AdM1oln?Sh6
obHV9POo:BTY1olb<S86ocLg=`Kooooo1oln?Sh7ob0P80Oo20P81_l61PH7oa8B4POoEUIF1on6QXH6
oc@d=0gooooo1olW9bL7obd];@Ko;bl_1olo?cl7oj^[Z`Oo7alO1_mYJFT6ooooo`Oo00001olk>c/6
oaTI6@Oo5QHF1olb<S87o``<30Oo<c<c1_lV9RH6ooooo`Oo2PX:1_l[:b/7obDU9@OoI6AT1omSHf<7
o`h>3POo=cLg5?ooool000cooooo1om3@d<7oeUIF@OoLW9b1om7AdL7odU9B@Ko<C4a1olk>c/6oc@d
=0Kooooo1omRHV87oc8b<POo9BDU1olf=SH7oaPH60KoC4a<1olQ8B46oeMGE`Kooooo1ol30`<7o`82
0POo20P81ol20P86o`L71`Oo2PX:1ol10@46ob4Q8@Kooooo1omQHF47ono_k`Oo9bLW1oli>CT6ocDe
=@Oo<C4a1olQ8B46odU9B@Kooooo1olY:BT7oa0@40Oo1PH61_l@4107obLW9`OoBDU91on:RXX6oeMG
E`Kooooo1oo4a<@7od];B`OoE5AD1_m:BTX7obPX:0Ooi^KV1olg=cL6ochn?PKooooo1ol410@7odI6
APKo4Q8B1ol61PH7oalO7`Oo3Ph>1olb<S86ocLg=`Kooooo1ol<30`6oc4a<@Oo71`L1omGEeL7ohZ:
RPOo5aLG1om?Cdl6okZj^Pkooooo000<ooooo`Oo@d=31omIFET7og9bLPOoAdM71om9BDT6oc4a<@Oo
>c/k1_ld=3@6ooooo`OoHV9R1olb<S87obDU9@Oo=SHf1olH61P6oda<C0Oo8B4Q1_mGEeL6ooooo`Oo
0`<31ol20P87o`P820Oo0P821_l71`L7o`X:2POo0@411_lQ8B46ooooo`OoHF5Q1oo_knl7obLW9`Oo
>CTi1_le=CD7oc4a<@Oo8B4Q1_m9BDT6ooooo`Oo:BTY1ol@4107o`H61PKo410@1olW9bL7odU9B@Oo
RXZ:1_mGEeL6ooooo`Ooa<C41om;Bd/7oeADE0KoBTY:1olX:2P7onKViPOo=cLg1_ln?Sh6ooooo`Oo
10@41om6ATH6oa8B4POo1PH61olO7al7o`h>3POo<S8b1_lg=cL6ooooo`Oo30`<1_la<C47oa`L70Oo
EeMG1on:RXX7oaLG5`OoCdm?1_nj^[X>ooooo`003?ooool7od=3@`OoFEUI1ombLW87odM7A`OoBDU9
1_la<C47oc/k>`Ko=3@d1_ooool7of9RHPOo<S8b1olU9BD7ocHf=POo61PH1_m<C4`7ob4Q8@KoEeMG
1_ooool7o`<30`Oo0P821ol820P7o`820PKo1`L71ol:2PX7o`410@Ko8B4Q1_ooool7of5QH@Ookno_
1olW9bL7ocTi>@Ko=CDe1ola<C47ob4Q8@KoBDU91_ooool7obTY:@Oo410@1ol61PH6oa0@40Oo9bLW
1om9BDT7ohZ:RPKoEeMG1_ooool7olC4a0OoBd];1omDE5@6odY:BPOo:2PX1ooVi^H7ocLg=`Ko?Shn
1_ooool7o`@410OoATI61_lB4Q87o`H61POo7alO1ol>3Ph7oc8b<PKo=cLg1_ooool7o``<30Ko<C4a
1olL71`7oeMGE`OoRXZ:1olG5aL7odm?C`Ko^[Zj3_ooool000cooooo1om3@d<7oeUIF@OoLW9b1om7
AdL7odU9B@Ko<C4a1olk>c/6oc@d=0Kooooo1omRHV87oc8b<POo9BDU1olf=SH7oaPH60KoC4a<1olQ
8B46oeMGE`Kooooo1ol30`<7o`820POo20P81ol20P86o`L71`Oo2PX:1ol10@46ob4Q8@Kooooo1omQ
HF47ono_k`Oo9bLW1oli>CT6ocDe=@Oo<C4a1olQ8B46odU9B@Kooooo1olY:BT7oa0@40Oo1PH61_l@
4107obLW9`OoBDU91on:RXX6oeMGE`Kooooo1oo4a<@7od];B`OoE5AD1_m:BTX7obPX:0Ooi^KV1olg
=cL6ochn?PKooooo1ol410@7odI6APKo4Q8B1ol61PH7oalO7`Oo3Ph>1olb<S86ocLg=`Kooooo1ol<
30`6oc4a<@Oo71`L1omGEeL7ohZ:RPOo5aLG1om?Cdl6okZj^Pkooooo000<ooooo`Oo@d=31omIFET7
og9bLPOoAdM71om9BDT6oc4a<@Oo>c/k1_ld=3@6ooooo`OoHV9R1olb<S87obDU9@Oo=SHf1olH61P6
oda<C0Oo8B4Q1_mGEeL6ooooo`Oo0`<31ol20P87o`P820Oo0P821_l71`L7o`X:2POo0@411_lQ8B46
ooooo`OoHF5Q1oo_knl7obLW9`Oo>CTi1_le=CD7oc4a<@Oo8B4Q1_m9BDT6ooooo`Oo:BTY1ol@4107
o`H61PKo410@1olW9bL7odU9B@OoRXZ:1_mGEeL6ooooo`Ooa<C41om;Bd/7oeADE0KoBTY:1olX:2P7
onKViPOo=cLg1_ln?Sh6ooooo`Oo10@41om6ATH6oa8B4POo1PH61olO7al7o`h>3POo<S8b1_lg=cL6
ooooo`Oo30`<1_la<C47oa`L70OoEeMG1on:RXX7oaLG5`OoCdm?1_nj^[X>ooooo`003?ooool7od=3
@`OoFEUI1ombLW87odM7A`OoBDU91_la<C47oc/k>`Ko=3@d1_ooool7of9RHPOo<S8b1olU9BD7ocHf
=POo61PH1_m<C4`7ob4Q8@KoEeMG1_ooool7o`<30`Oo0P821ol820P7o`820PKo1`L71ol:2PX7o`41
0@Ko8B4Q1_ooool7of5QH@Ookno_1olW9bL7ocTi>@Ko=CDe1ola<C47ob4Q8@KoBDU91_ooool7obTY
:@Oo410@1ol61PH6oa0@40Oo9bLW1om9BDT7ohZ:RPKoEeMG1_ooool7olC4a0OoBd];1omDE5@6odY:
BPOo:2PX1ooVi^H7ocLg=`Ko?Shn1_ooool7o`@410OoATI61_lB4Q87o`H61POo7alO1ol>3Ph7oc8b
<PKo=cLg1_ooool7o``<30Ko<C4a1olL71`7oeMGE`OoRXZ:1olG5aL7odm?C`Ko^[Zj3_ooool000co
oooo1omRHV87odQ8B0OoKVi^1oll?3`7ocXj>PKo9bLW1om4A4@6od51@@Kooooo1omlO7`7oc8b<POo
4A4A1olc<c<7o`D51@Ko=SHf1olW9bL6ochn?PKooooo1olB4Q8>oa0@40Oo30`<1_lA4A47o`P820Oo
4A4A1_lE5AD6ooooo`Oo=CDe1onm_Kd7oa/K6`Oo=3@d1_mPH607ob`/;0OoBd];1_m?Cdl6ooooo`Oo
;Rh^1olT92@7o`l?3`Ko0`<31olW9bL7odY:BPOoKfm_1_m2@T86ooooo`OoX:2P1omKFe/7ocXj>PKo
J6QX1olU9BD7ojVYZ@Oo=CDe1_m9BDT6ooooo`Oo61PH1omNGUh6oc<c<`Oo6a/K1olV9RH7oa<C4`Oo
@T921_m;Bd/6ooooo`Oo00001_lO7al7ob`/;0Oo>CTi1om_Kfl7o`d=3@OoDU9B1_nSXj<>ooooo`00
3?ooool7of9RHPOoB4Q81om^KVh7oc`l?0Oo>SXj1_lW9bL7odA4A0Ko@D511_ooool7ogalO0Oo<S8b
1olA4A47oc<c<`Oo1@D51_lf=SH7obLW9`Ko?Shn1_ooool7oa8B4Pko410@1ol<30`6oa4A4@Oo20P8
1olA4A46oaDE5@Kooooo1ole=CD7okfm_@Oo6a/K1old=3@6of1PH0Oo;2`/1om;Bd/6odm?C`Kooooo
1ol^;Rh7ob@T90Oo3`l?1_l30`<7obLW9`OoBTY:1om_Kfl6od92@PKooooo1onPX:07oe]KF`Oo>SXj
1_mXJ6P7obDU9@OoZJVY1ole=CD6odU9B@Kooooo1olH61P7oeiNGPKo<c<c1olK6a/7obHV9POo4a<C
1om2@T86od];B`Kooooo1ol00006oalO7`Oo;2`/1oli>CT7ofm_K`Oo3@d=1omBDU86oj>SX`kooooo
000<ooooo`OoHV9R1om8B4P7ofi^KPOo?3`l1olj>SX6obLW9`OoA4A41_m1@D46ooooo`OoO7al1olb
<S87oa4A4@Oo<c<c1ol51@D6ocHf=POo9bLW1_ln?Sh6ooooo`Oo4Q8B3_l@4107o``<30Ko4A4A1ol8
20P7oa4A4@Ko5ADE1_ooool7ocDe=@Oo_Kfm1olK6a/7oc@d=0KoH61P1ol/;2`7od];B`KoCdm?1_oo
ool7obh^;POo92@T1ol?3`l6o`<30`Oo9bLW1om:BTX7ofm_K`Ko@T921_ooool7oj2PX0OoFe]K1olj
>SX6ofQXJ0Oo9BDU1onYZJT7ocDe=@KoBDU91_ooool7oaPH60OoGUiN1_lc<c<7oa/K6`Oo9RHV1olC
4a<7od92@PKoBd];1_ooool7o`0000Ko7alO1ol/;2`7ocTi>@OoKfm_1ol=3@d7oe9BDPKoXj>S3_oo
ool000cooooo1omRHV87odQ8B0OoKVi^1oll?3`7ocXj>PKo9bLW1om4A4@6od51@@Kooooo1omlO7`7
oc8b<POo4A4A1olc<c<7o`D51@Ko=SHf1olW9bL6ochn?PKooooo1olB4Q8>oa0@40Oo30`<1_lA4A47
o`P820Oo4A4A1_lE5AD6ooooo`Oo=CDe1onm_Kd7oa/K6`Oo=3@d1_mPH607ob`/;0OoBd];1_m?Cdl6
ooooo`Oo;Rh^1olT92@7o`l?3`Ko0`<31olW9bL7odY:BPOoKfm_1_m2@T86ooooo`OoX:2P1omKFe/7
ocXj>PKoJ6QX1olU9BD7ojVYZ@Oo=CDe1_m9BDT6ooooo`Oo61PH1omNGUh6oc<c<`Oo6a/K1olV9RH7
oa<C4`Oo@T921_m;Bd/6ooooo`Oo00001_lO7al7ob`/;0Oo>CTi1om_Kfl7o`d=3@OoDU9B1_nSXj<>
ooooo`003?ooool7of9RHPOoB4Q81om^KVh7oc`l?0Oo>SXj1_lW9bL7odA4A0Ko@D511_ooool7ogal
O0Oo<S8b1olA4A47oc<c<`Oo1@D51_lf=SH7obLW9`Ko?Shn1_ooool7oa8B4Pko410@1ol<30`6oa4A
4@Oo20P81olA4A46oaDE5@Kooooo1ole=CD7okfm_@Oo6a/K1old=3@6of1PH0Oo;2`/1om;Bd/6odm?
C`Kooooo1ol^;Rh7ob@T90Oo3`l?1_l30`<7obLW9`OoBTY:1om_Kfl6od92@PKooooo1onPX:07oe]K
F`Oo>SXj1_mXJ6P7obDU9@OoZJVY1ole=CD6odU9B@Kooooo1olH61P7oeiNGPKo<c<c1olK6a/7obHV
9POo4a<C1om2@T86od];B`Kooooo1ol00006oalO7`Oo;2`/1oli>CT7ofm_K`Oo3@d=1omBDU86oj>S
X`kooooo000<ooooo`OoHV9R1om8B4P7ofi^KPOo?3`l1olj>SX6obLW9`OoA4A41_m1@D46ooooo`Oo
O7al1olb<S87oa4A4@Oo<c<c1ol51@D6ocHf=POo9bLW1_ln?Sh6ooooo`Oo4Q8B3_l@4107o``<30Ko
4A4A1ol820P7oa4A4@Ko5ADE1_ooool7ocDe=@Oo_Kfm1olK6a/7oc@d=0KoH61P1ol/;2`7od];B`Ko
Cdm?1_ooool7obh^;POo92@T1ol?3`l6o`<30`Oo9bLW1om:BTX7ofm_K`Ko@T921_ooool7oj2PX0Oo
Fe]K1olj>SX6ofQXJ0Oo9BDU1onYZJT7ocDe=@KoBDU91_ooool7oaPH60OoGUiN1_lc<c<7oa/K6`Oo
9RHV1olC4a<7od92@PKoBd];1_ooool7o`0000Ko7alO1ol/;2`7ocTi>@OoKfm_1ol=3@d7oe9BDPKo
Xj>S3_ooool000cooooo1omRHV87odQ8B0OoKVi^1oll?3`7ocXj>PKo9bLW1om4A4@6od51@@Kooooo
1omlO7`7oc8b<POo4A4A1olc<c<7o`D51@Ko=SHf1olW9bL6ochn?PKooooo1olB4Q8>oa0@40Oo30`<
1_lA4A47o`P820Oo4A4A1_lE5AD6ooooo`Oo=CDe1onm_Kd7oa/K6`Oo=3@d1_mPH607ob`/;0OoBd];
1_m?Cdl6ooooo`Oo;Rh^1olT92@7o`l?3`Ko0`<31olW9bL7odY:BPOoKfm_1_m2@T86ooooo`OoX:2P
1omKFe/7ocXj>PKoJ6QX1olU9BD7ojVYZ@Oo=CDe1_m9BDT6ooooo`Oo61PH1omNGUh6oc<c<`Oo6a/K
1olV9RH7oa<C4`Oo@T921_m;Bd/6ooooo`Oo00001_lO7al7ob`/;0Oo>CTi1om_Kfl7o`d=3@OoDU9B
1_nSXj<>ooooo`003?ooool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_oo
ool7odY:BPOo<C4a1omSHf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc
<c<7oaTI6@Ko92@T1ol^;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3
@d<6oclo?`Kooooo1om2@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh
>3P>obDU9@Ko>c/k1olh>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omR
HV87oaTI6@Oo@D511_nNWYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ
:RX>ooooo`003?ooool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7
odY:BPOo<C4a1omSHf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7
oaTI6@Ko92@T1ol^;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6
oclo?`Kooooo1om2@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>
obDU9@Ko>c/k1olh>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87
oaTI6@Oo@D511_nNWYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>
ooooo`003?ooool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7odY:
BPOo<C4a1omSHf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7oaTI
6@Ko92@T1ol^;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6oclo
?`Kooooo1om2@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>obDU
9@Ko>c/k1olh>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87oaTI
6@Oo@D511_nNWYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>oooo
o`003?ooool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7odY:BPOo
<C4a1omSHf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7oaTI6@Ko
92@T1ol^;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6oclo?`Ko
oooo1om2@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>obDU9@Ko
>c/k1olh>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87oaTI6@Oo
@D511_nNWYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>ooooo`00
3?ooool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7odY:BPOo<C4a
1omSHf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7oaTI6@Ko92@T
1ol^;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6oclo?`Kooooo
1om2@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>obDU9@Ko>c/k
1olh>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87oaTI6@Oo@D51
1_nNWYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>ooooo`003?oo
ool7og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7odY:BPOo<C4a1omS
Hf<7ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7oaTI6@Ko92@T1ol^
;Rh7obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6oclo?`Kooooo1om2
@T87oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>obDU9@Ko>c/k1olh
>3P7ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87oaTI6@Oo@D511_nN
WYh6ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>ooooo`003?ooool7
og9bLPOoJFUY1oodm?@7ob`/;0OoFUYJ1_m4A4@7odM7A`KoDe=C1_ooool7odY:BPOo<C4a1omSHf<7
ogalO0Oo7AdM1_ld=3@7ob8R8PKo6a/K1_ooool7od];B`Oo8b<S1olc<c<7oaTI6@Ko92@T1ol^;Rh7
obXZ:Pcooooo1olk>c/7of5QH@Oo8b<S1om8B4P6ocPh>0Oo:2PX1om3@d<6oclo?`Kooooo1om2@T87
oalO7`Oo@4101_lY:BT7obl_;`OoQHF51oooool6ogMgM`Kooooo1olh>3P>obDU9@Ko>c/k1olh>3P7
ofm_K`Oo?Cdm1_lg=cL6ooooo`Oo9BDU1olo?cl6oc0`<0OoB4Q81omRHV87oaTI6@Oo@D511_nNWYh6
ooooo`Oo30`<1_lO7al7o`h>3POo:b/[1ola<C47o`h>3POo?Shn1_lZ:RX>ooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`003?ooool7ocDe=@OoG5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo
7alO1olf=SH7oaLG5`Oo820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo
8B4Q1ol=3@d6ojRXZ0Kooooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Ko
oooo1ol=3@d7o`820POo30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go
4Q8B1omKFe/7ooooo`Oo=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POo
Hf=S1_mKFe/6ooooo`Oo1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`00
3?ooool7ocDe=@OoG5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO
1olf=SH7oaLG5`Oo820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q
1ol=3@d6ojRXZ0Kooooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo
1ol=3@d7o`820POo30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B
1omKFe/7ooooo`Oo=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S
1_mKFe/6ooooo`Oo1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?oo
ool7ocDe=@OoG5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO1olf
=SH7oaLG5`Oo820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q1ol=
3@d6ojRXZ0Kooooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo1ol=
3@d7o`820POo30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B1omK
Fe/7ooooo`Oo=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S1_mK
Fe/6ooooo`Oo1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?ooool7
ocDe=@OoG5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO1olf=SH7
oaLG5`Oo820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q1ol=3@d6
ojRXZ0Kooooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo1ol=3@d7
o`820POo30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B1omKFe/7
ooooo`Oo=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S1_mKFe/6
ooooo`Oo1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?ooool7ocDe
=@OoG5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO1olf=SH7oaLG
5`Oo820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q1ol=3@d6ojRX
Z0Kooooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo1ol=3@d7o`82
0POo30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B1omKFe/7oooo
o`Oo=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S1_mKFe/6oooo
o`Oo1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?ooool7ocDe=@Oo
G5aL1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO1olf=SH7oaLG5`Oo
820P3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q1ol=3@d6ojRXZ0Ko
oooo1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo1ol=3@d7o`820POo
30`<1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B1omKFe/7ooooo`Oo
=SHf1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S1_mKFe/6ooooo`Oo
1`L71_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?ooool7ocDe=@OoG5aL
1olU9BD7od=3@`Oo:2PX1_l/;2`7odM7A`KoOWin1_ooool7ocDe=@Oo7alO1olf=SH7oaLG5`Oo820P
3OlA4A46ofYZJPKooooo1omJFUX7ob0P80Oo5aLG1olC4a<6oa0@40Oo8B4Q1ol=3@d6ojRXZ0Kooooo
1omKFe/7ol_;b`Oo>3Ph1olW9bL6oaTI6@Oo20P81olJ6QX6ocLg=`Kooooo1ol=3@d7o`820POo30`<
1_lO7al7oaPH60Oo2`/;1ol:2PX6oa0@40Kooooo1old=3@7oaDE5@go4Q8B1omKFe/7ooooo`Oo=SHf
1_m=CDd6ooooo`Oo@D511ola<C46ooooo`Oo7alO1olZ:RX7oaHF5POoHf=S1_mKFe/6ooooo`Oo1`L7
1_lA4A47o`0000Oo2`/;1ol61PH7o`h>3POo5QHF1_lL71`>ooooo`003?ooool7oeADE0Oo;2`/1ol`
<307oaTI6@Oo?Cdm1_lJ6QX7od];B`KoTI6A1_ooool7ocHf=POo6a/K1om>CTh7o`0000Oo2@T91_lP
8207o`0000KoLG5a1_ooool7odY:BPOo;bl_1ol51@D7o`0000Ko2@T91ol20P87o`l?3`KoPH611_oo
ool7ofa/K0Oooooo1omFEUH7ode=C@KoB4Q81olH61P7o`L71`Ko@D511_ooool7o`P820Oo0@411ol9
2@T6oaDE5@Oo1`L71ol;2`/7o`<30`Ko51@D1_ooool7oa`L70Oo6QXJ1olO7al6oa/K6`OoB4Q81onC
Ti<7od51@@Ko;Rh^1_ooool7obDU9@Oo6a/K1_n`/;07oc/k>`Oo=SHf1ol=3@d7od92@PKoHV9R1_oo
ool7o`P820Ko51@D1ol61PH7oa0@40Oo4A4A1olD51@7oa8B4PKo8R8R3_ooool000cooooo1omDE5@7
ob`/;0Oo<30`1olI6AT7ocdm?@Ko6QXJ1om;Bd/6oi6AT@Kooooo1olf=SH7oa/K6`OoCTi>1ol00007
o`T92@Ko820P1ol00006og5aL@Kooooo1om:BTX7obl_;`Oo1@D51ol00006o`T92@Oo0P821ol?3`l6
oh61P@Kooooo1om/K6`7ooooo`OoEUIF1om=CDd6odQ8B0Oo61PH1ol71`L6od51@@Kooooo1ol820P7
o`410@Oo2@T91_lE5AD7o`L71`Oo2`/;1ol30`<6oa@D50Kooooo1olL71`7oaXJ6POo7alO1_lK6a/7
odQ8B0OoTi>C1om1@D46obh^;PKooooo1olU9BD7oa/K6`Ko/;2`1olk>c/7ocHf=POo3@d=1om2@T86
of9RHPKooooo1ol820P6oa@D50Oo1PH61ol@4107oa4A4@Oo51@D1olB4Q86ob8R8Pkooooo000<oooo
o`OoE5AD1ol/;2`7oc0`<0Oo6ATI1olm?Cd6oaXJ6POoBd];1_nATI46ooooo`Oo=SHf1olK6a/7odi>
CPOo00001ol92@T6ob0P80Oo00001_maLG46ooooo`OoBTY:1ol_;bl7o`D51@Oo00001_l92@T7o`82
0POo3`l?1_n1PH46ooooo`OoK6a/1oooool7oeIFEPOoCDe=1_m8B4P7oaPH60Oo1`L71_m1@D46oooo
o`Oo20P81ol10@47o`T92@Ko5ADE1ol71`L7o`/;2`Oo0`<31_lD51@6ooooo`Oo71`L1olJ6QX7oalO
7`Ko6a/K1om8B4P7oi>CT`Oo@D511_l^;Rh6ooooo`Oo9BDU1olK6a/6ok2`/0Oo>c/k1olf=SH7o`d=
3@Oo@T921_mRHV86ooooo`Oo20P81_lD51@7o`H61POo410@1olA4A47oa@D50Oo4Q8B1_lR8R8>oooo
o`003?ooool7oeADE0Oo;2`/1ol`<307oaTI6@Oo?Cdm1_lJ6QX7od];B`KoTI6A1_ooool7ocHf=POo
6a/K1om>CTh7o`0000Oo2@T91_lP8207o`0000KoLG5a1_ooool7odY:BPOo;bl_1ol51@D7o`0000Ko
2@T91ol20P87o`l?3`KoPH611_ooool7ofa/K0Oooooo1omFEUH7ode=C@KoB4Q81olH61P7o`L71`Ko
@D511_ooool7o`P820Oo0@411ol92@T6oaDE5@Oo1`L71ol;2`/7o`<30`Ko51@D1_ooool7oa`L70Oo
6QXJ1olO7al6oa/K6`OoB4Q81onCTi<7od51@@Ko;Rh^1_ooool7obDU9@Oo6a/K1_n`/;07oc/k>`Oo
=SHf1ol=3@d7od92@PKoHV9R1_ooool7o`P820Ko51@D1ol61PH7oa0@40Oo4A4A1olD51@7oa8B4PKo
8R8R3_ooool000cooooo1omDE5@7ob`/;0Oo<30`1olI6AT7ocdm?@Ko6QXJ1om;Bd/6oi6AT@Kooooo
1olf=SH7oa/K6`OoCTi>1ol00007o`T92@Ko820P1ol00006og5aL@Kooooo1om:BTX7obl_;`Oo1@D5
1ol00006o`T92@Oo0P821ol?3`l6oh61P@Kooooo1om/K6`7ooooo`OoEUIF1om=CDd6odQ8B0Oo61PH
1ol71`L6od51@@Kooooo1ol820P7o`410@Oo2@T91_lE5AD7o`L71`Oo2`/;1ol30`<6oa@D50Kooooo
1olL71`7oaXJ6POo7alO1_lK6a/7odQ8B0OoTi>C1om1@D46obh^;PKooooo1olU9BD7oa/K6`Ko/;2`
1olk>c/7ocHf=POo3@d=1om2@T86of9RHPKooooo1ol820P6oa@D50Oo1PH61ol@4107oa4A4@Oo51@D
1olB4Q86ob8R8Pkooooo000<ooooo`OoE5AD1ol/;2`7oc0`<0Oo6ATI1olm?Cd6oaXJ6POoBd];1_nA
TI46ooooo`Oo=SHf1olK6a/7odi>CPOo00001ol92@T6ob0P80Oo00001_maLG46ooooo`OoBTY:1ol_
;bl7o`D51@Oo00001_l92@T7o`820POo3`l?1_n1PH46ooooo`OoK6a/1oooool7oeIFEPOoCDe=1_m8
B4P7oaPH60Oo1`L71_m1@D46ooooo`Oo20P81ol10@47o`T92@Ko5ADE1ol71`L7o`/;2`Oo0`<31_lD
51@6ooooo`Oo71`L1olJ6QX7oalO7`Ko6a/K1om8B4P7oi>CT`Oo@D511_l^;Rh6ooooo`Oo9BDU1olK
6a/6ok2`/0Oo>c/k1olf=SH7o`d=3@Oo@T921_mRHV86ooooo`Oo20P81_lD51@7o`H61POo410@1olA
4A47oa@D50Oo4Q8B1_lR8R8>ooooo`003?ooool7oeADE0Oo;2`/1ol`<307oaTI6@Oo?Cdm1_lJ6QX7
od];B`KoTI6A1_ooool7ocHf=POo6a/K1om>CTh7o`0000Oo2@T91_lP8207o`0000KoLG5a1_ooool7
odY:BPOo;bl_1ol51@D7o`0000Ko2@T91ol20P87o`l?3`KoPH611_ooool7ofa/K0Oooooo1omFEUH7
ode=C@KoB4Q81olH61P7o`L71`Ko@D511_ooool7o`P820Oo0@411ol92@T6oaDE5@Oo1`L71ol;2`/7
o`<30`Ko51@D1_ooool7oa`L70Oo6QXJ1olO7al6oa/K6`OoB4Q81onCTi<7od51@@Ko;Rh^1_ooool7
obDU9@Oo6a/K1_n`/;07oc/k>`Oo=SHf1ol=3@d7od92@PKoHV9R1_ooool7o`P820Ko51@D1ol61PH7
oa0@40Oo4A4A1olD51@7oa8B4PKo8R8R3_ooool000cooooo1ola<C47oeADE0Oo00001olT92@7oalO
7`Ko>3Ph1omEEED6oi:BTPKooooo1ol_;bl7ocLg=`OoKVi^1olG5aL7obTY:@Ko71`L1olQ8B46ocTi
>@Kooooo1ola<C47oahN7POo410@1olB4Q86o`D51@Oo20P81ol?3`l6ofi^KPKooooo1ol/;2`7og9b
LPOo92@T1ola<C46odU9B@Oo9BDU1olH61P6ocLg=`Kooooo1ol;2`/7o`L71`Oo2`/;1_lL71`7oa<C
4`Oo2`/;3Ol>3Ph6ooooo`Oo2PX:1olK6a/7oc@d=0Ko6ATI1olW9bL7ochn?POo71`L1_lk>c/6oooo
o`Oo6a/K1ol?3`l6ogUiN@Oo20P81olZ:RX7oaXJ6POo;Bd]1_mMGEd6ooooo`Oo5aLG1_lA4A47o`/;
2`Oo4A4A1ol;2`/7o`X:2POo6a/K1_lY:BT>ooooo`003?ooool7oc4a<@OoE5AD1ol00007ob@T90Oo
7alO1_lh>3P7oeEEE@KoTY:B1_ooool7obl_;`Oo=cLg1om^KVh7oaLG5`Oo:BTY1_lL71`7ob4Q8@Ko
>CTi1_ooool7oc4a<@Oo7QhN1ol@4107oa8B4PKo1@D51ol820P7o`l?3`KoKVi^1_ooool7ob`/;0Oo
LW9b1olT92@7oc4a<@KoBDU91olU9BD7oaPH60Ko=cLg1_ooool7o`/;2`Oo1`L71ol;2`/6oa`L70Oo
4a<C1ol;2`/=o`h>3PKooooo1ol:2PX7oa/K6`Oo=3@d1_lI6AT7obLW9`Oo?Shn1olL71`6oc/k>`Ko
oooo1olK6a/7o`l?3`KoNGUi1ol820P7obXZ:POo6QXJ1ol];Bd6oeeMG@Kooooo1olG5aL6oa4A4@Oo
2`/;1olA4A47o`/;2`Oo2PX:1olK6a/6obTY:@kooooo000<ooooo`Oo<C4a1omDE5@7o`0000Oo92@T
1olO7al6ocPh>0OoEEEE1_nBTY86ooooo`Oo;bl_1olg=cL7ofi^KPOo5aLG1olY:BT6oa`L70Oo8B4Q
1_li>CT6ooooo`Oo<C4a1olN7Qh7oa0@40Oo4Q8B1_l51@D7o`P820Oo3`l?1_m^KVh6ooooo`Oo;2`/
1ombLW87ob@T90Oo<C4a1_m9BDT7obDU9@Oo61PH1_lg=cL6ooooo`Oo2`/;1ol71`L7o`/;2`Ko71`L
1olC4a<7o`/;2`go3Ph>1_ooool7o`X:2POo6a/K1old=3@6oaTI6@Oo9bLW1oln?Sh7oa`L70Ko>c/k
1_ooool7oa/K6`Oo3`l?1_miNGT7o`P820Oo:RXZ1olJ6QX7obd];@KoGEeM1_ooool7oaLG5`Ko4A4A
1ol;2`/7oa4A4@Oo2`/;1ol:2PX7oa/K6`Ko:BTY3_ooool000cooooo1ola<C47oeADE0Oo00001olT
92@7oalO7`Ko>3Ph1omEEED6oi:BTPKooooo1ol_;bl7ocLg=`OoKVi^1olG5aL7obTY:@Ko71`L1olQ
8B46ocTi>@Kooooo1ola<C47oahN7POo410@1olB4Q86o`D51@Oo20P81ol?3`l6ofi^KPKooooo1ol/
;2`7og9bLPOo92@T1ola<C46odU9B@Oo9BDU1olH61P6ocLg=`Kooooo1ol;2`/7o`L71`Oo2`/;1_lL
71`7oa<C4`Oo2`/;3Ol>3Ph6ooooo`Oo2PX:1olK6a/7oc@d=0Ko6ATI1olW9bL7ochn?POo71`L1_lk
>c/6ooooo`Oo6a/K1ol?3`l6ogUiN@Oo20P81olZ:RX7oaXJ6POo;Bd]1_mMGEd6ooooo`Oo5aLG1_lA
4A47o`/;2`Oo4A4A1ol;2`/7o`X:2POo6a/K1_lY:BT>ooooo`003?ooool7oc4a<@OoE5AD1ol00007
ob@T90Oo7alO1_lh>3P7oeEEE@KoTY:B1_ooool7obl_;`Oo=cLg1om^KVh7oaLG5`Oo:BTY1_lL71`7
ob4Q8@Ko>CTi1_ooool7oc4a<@Oo7QhN1ol@4107oa8B4PKo1@D51ol820P7o`l?3`KoKVi^1_ooool7
ob`/;0OoLW9b1olT92@7oc4a<@KoBDU91olU9BD7oaPH60Ko=cLg1_ooool7o`/;2`Oo1`L71ol;2`/6
oa`L70Oo4a<C1ol;2`/=o`h>3PKooooo1ol:2PX7oa/K6`Oo=3@d1_lI6AT7obLW9`Oo?Shn1olL71`6
oc/k>`Kooooo1olK6a/7o`l?3`KoNGUi1ol820P7obXZ:POo6QXJ1ol];Bd6oeeMG@Kooooo1olG5aL6
oa4A4@Oo2`/;1olA4A47o`/;2`Oo2PX:1olK6a/6obTY:@kooooo000<ooooo`Oo<C4a1omDE5@7o`00
00Oo92@T1olO7al6ocPh>0OoEEEE1_nBTY86ooooo`Oo;bl_1olg=cL7ofi^KPOo5aLG1olY:BT6oa`L
70Oo8B4Q1_li>CT6ooooo`Oo<C4a1olN7Qh7oa0@40Oo4Q8B1_l51@D7o`P820Oo3`l?1_m^KVh6oooo
o`Oo;2`/1ombLW87ob@T90Oo<C4a1_m9BDT7obDU9@Oo61PH1_lg=cL6ooooo`Oo2`/;1ol71`L7o`/;
2`Ko71`L1olC4a<7o`/;2`go3Ph>1_ooool7o`X:2POo6a/K1old=3@6oaTI6@Oo9bLW1oln?Sh7oa`L
70Ko>c/k1_ooool7oa/K6`Oo3`l?1_miNGT7o`P820Oo:RXZ1olJ6QX7obd];@KoGEeM1_ooool7oaLG
5`Ko4A4A1ol;2`/7oa4A4@Oo2`/;1ol:2PX7oa/K6`Ko:BTY3_ooool000cooooo1olo?cl7ob@T90Oo
7AdM1ol@4107ocLg=`Ko6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko
7QhN1olQ8B46odA4A0Kooooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Ko
oooo1ol30`<7ob0P80Oo4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko
3Ph>1ol10@47o`@410Oo3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo
410@1_lT92@6ooooo`ko2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo
3Ph>1ol61PH7oaXJ6POo0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM
1ol@4107ocLg=`Ko6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN
1olQ8B46odA4A0Kooooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo
1ol30`<7ob0P80Oo4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>
1ol10@47o`@410Oo3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@
1_lT92@6ooooo`ko2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>
1ol61PH7oaXJ6POo0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM1ol@
4107ocLg=`Ko6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN1olQ
8B46odA4A0Kooooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo1ol3
0`<7ob0P80Oo4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>1ol1
0@47o`@410Oo3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@1_lT
92@6ooooo`ko2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>1ol6
1PH7oaXJ6POo0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM1ol@4107
ocLg=`Ko6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN1olQ8B46
odA4A0Kooooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo1ol30`<7
ob0P80Oo4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>1ol10@47
o`@410Oo3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@1_lT92@6
ooooo`ko2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>1ol61PH7
oaXJ6POo0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM1ol@4107ocLg
=`Ko6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN1olQ8B46odA4
A0Kooooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo1ol30`<7ob0P
80Oo4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>1ol10@47o`@4
10Oo3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@1_lT92@6oooo
o`ko2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>1ol61PH7oaXJ
6POo0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM1ol@4107ocLg=`Ko
6ATI1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN1olQ8B46odA4A0Ko
oooo1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo1ol30`<7ob0P80Oo
4a<C1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>1ol10@47o`@410Oo
3Ph>1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@1_lT92@6ooooo`ko
2PX:1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>1ol61PH7oaXJ6POo
0P821olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olo?cl7ob@T90Oo7AdM1ol@4107ocLg=`Ko6ATI
1omHF5P6ogYjNPKooooo1ole=CD7ohR8R0OohN7Q1omYJFT7od10@0Ko7QhN1olQ8B46odA4A0Kooooo
1om1@D47oahN7POo1@D51ol30`<6oa8B4POo2`/;1ol>3Ph6ogEeM@Kooooo1ol30`<7ob0P80Oo4a<C
1olW9bL6od51@@Oo4Q8B1olR8R86oaTI6@Kooooo1ol92@T>o`0000Ko3Ph>1ol10@47o`@410Oo3Ph>
1_lN7Qh6ooooo`Oo71`L1olX:2P7oc/k>`Ko;Rh^1ol61PH7o`h>3POo410@1_lT92@6ooooo`ko2PX:
1_lg=cL7o`L71`Oo3`l?1olU9BD7o`l?3`KoO7al1_ooool7oaXJ6PKo3Ph>1ol61PH7oaXJ6POo0P82
1olB4Q87o`d=3@Ko8R8R3_ooool000cooooo1olg=cL7odQ8B0Oo5aLG1olU9BD7ob@T90Ko>SXj1omC
De<6ogIfMPKooooo1olQ8B47odA4A0Ooi>CT1oo0`<07oeUIF@KoC4a<1olI6AT6ocdm?@Kooooo1omD
E5@7obPX:0Oo30`<1olB4Q86o`X:2Pko3Ph>3?ooool7o`0000Oo7alO1ol71`L7ob4Q8@KoG5aL1olM
7Ad7ob@T90Ko6a/K1_ooool7o`h>3POo2@T91ol;2`/6oa0@40Oo00001ol;2`/=o`T92@Kooooo1olB
4Q87oa/K6`Oo;bl_1_lF5QH7o`0000Oo3@d=1ol820P6oahN7PKooooo1ol30`<7o`h>3PKo7alO1ol@
4107ob4Q8@Oo61PH1ol20P86oeeMG@Kooooo1olC4a<6o``<30Oo4A4A1olP8207ob@T90Oo71`L1olE
5AD6od10@0kooooo000<ooooo`Oo=cLg1om8B4P7oaLG5`Oo9BDU1olT92@6ocXj>POoDe=C1_mfMWH6
ooooo`Oo8B4Q1om4A4@7onCTi0Oo`<301omIFET6oda<C0Oo6ATI1_lm?Cd6ooooo`OoE5AD1olX:2P7
o``<30Oo4Q8B1_l:2PX>o`h>3Pcooooo1ol00007oalO7`Oo1`L71olQ8B46oeaLG0Oo7AdM1olT92@6
oa/K6`Kooooo1ol>3Ph7o`T92@Oo2`/;1_l@4107o`0000Oo2`/;3Ol92@T6ooooo`Oo4Q8B1olK6a/7
obl_;`Ko5QHF1ol00007o`d=3@Oo20P81_lN7Qh6ooooo`Oo0`<31ol>3Ph6oalO7`Oo410@1olQ8B47
oaPH60Oo0P821_mMGEd6ooooo`Oo4a<C1_l<30`7oa4A4@Oo820P1olT92@7oa`L70Oo5ADE1_m0@40>
ooooo`003?ooool7ocLg=`OoB4Q81olG5aL7obDU9@Oo92@T1_lj>SX7oe=CD`KoMWIf1_ooool7ob4Q
8@OoA4A41ooTi>@7ol30`0OoFEUI1_m<C4`7oaTI6@Ko?Cdm1_ooool7oeADE0Oo:2PX1ol<30`7oa8B
4PKo2PX:3_l>3Ph<ooooo`Oo00001olO7al7o`L71`Oo8B4Q1_mLG5`7oadM7@Oo92@T1_lK6a/6oooo
o`Oo3Ph>1ol92@T7o`/;2`Ko410@1ol00007o`/;2`go2@T91_ooool7oa8B4POo6a/K1ol_;bl6oaHF
5POo00001ol=3@d7o`P820Ko7QhN1_ooool7o`<30`Oo3Ph>1_lO7al7oa0@40Oo8B4Q1olH61P7o`82
0PKoGEeM1_ooool7oa<C4`Ko30`<1olA4A47ob0P80Oo92@T1olL71`7oaDE5@Ko@4103_ooool000co
oooo1olg=cL7odQ8B0Oo5aLG1olU9BD7ob@T90Ko>SXj1omCDe<6ogIfMPKooooo1olQ8B47odA4A0Oo
i>CT1oo0`<07oeUIF@KoC4a<1olI6AT6ocdm?@Kooooo1omDE5@7obPX:0Oo30`<1olB4Q86o`X:2Pko
3Ph>3?ooool7o`0000Oo7alO1ol71`L7ob4Q8@KoG5aL1olM7Ad7ob@T90Ko6a/K1_ooool7o`h>3POo
2@T91ol;2`/6oa0@40Oo00001ol;2`/=o`T92@Kooooo1olB4Q87oa/K6`Oo;bl_1_lF5QH7o`0000Oo
3@d=1ol820P6oahN7PKooooo1ol30`<7o`h>3PKo7alO1ol@4107ob4Q8@Oo61PH1ol20P86oeeMG@Ko
oooo1olC4a<6o``<30Oo4A4A1olP8207ob@T90Oo71`L1olE5AD6od10@0kooooo000<ooooo`Oo=cLg
1om8B4P7oaLG5`Oo9BDU1olT92@6ocXj>POoDe=C1_mfMWH6ooooo`Oo8B4Q1om4A4@7onCTi0Oo`<30
1omIFET6oda<C0Oo6ATI1_lm?Cd6ooooo`OoE5AD1olX:2P7o``<30Oo4Q8B1_l:2PX>o`h>3Pcooooo
1ol00007oalO7`Oo1`L71olQ8B46oeaLG0Oo7AdM1olT92@6oa/K6`Kooooo1ol>3Ph7o`T92@Oo2`/;
1_l@4107o`0000Oo2`/;3Ol92@T6ooooo`Oo4Q8B1olK6a/7obl_;`Ko5QHF1ol00007o`d=3@Oo20P8
1_lN7Qh6ooooo`Oo0`<31ol>3Ph6oalO7`Oo410@1olQ8B47oaPH60Oo0P821_mMGEd6ooooo`Oo4a<C
1_l<30`7oa4A4@Oo820P1olT92@7oa`L70Oo5ADE1_m0@40>ooooo`003?ooool7ocLg=`OoB4Q81olG
5aL7obDU9@Oo92@T1_lj>SX7oe=CD`KoMWIf1_ooool7ob4Q8@OoA4A41ooTi>@7ol30`0OoFEUI1_m<
C4`7oaTI6@Ko?Cdm1_ooool7oeADE0Oo:2PX1ol<30`7oa8B4PKo2PX:3_l>3Ph<ooooo`Oo00001olO
7al7o`L71`Oo8B4Q1_mLG5`7oadM7@Oo92@T1_lK6a/6ooooo`Oo3Ph>1ol92@T7o`/;2`Ko410@1ol0
0007o`/;2`go2@T91_ooool7oa8B4POo6a/K1ol_;bl6oaHF5POo00001ol=3@d7o`P820Ko7QhN1_oo
ool7o`<30`Oo3Ph>1_lO7al7oa0@40Oo8B4Q1olH61P7o`820PKoGEeM1_ooool7oa<C4`Ko30`<1olA
4A47ob0P80Oo92@T1olL71`7oaDE5@Ko@4103_ooool000cooooo1olg=cL7odQ8B0Oo5aLG1olU9BD7
ob@T90Ko>SXj1omCDe<6ogIfMPKooooo1olQ8B47odA4A0Ooi>CT1oo0`<07oeUIF@KoC4a<1olI6AT6
ocdm?@Kooooo1omDE5@7obPX:0Oo30`<1olB4Q86o`X:2Pko3Ph>3?ooool7o`0000Oo7alO1ol71`L7
ob4Q8@KoG5aL1olM7Ad7ob@T90Ko6a/K1_ooool7o`h>3POo2@T91ol;2`/6oa0@40Oo00001ol;2`/=
o`T92@Kooooo1olB4Q87oa/K6`Oo;bl_1_lF5QH7o`0000Oo3@d=1ol820P6oahN7PKooooo1ol30`<7
o`h>3PKo7alO1ol@4107ob4Q8@Oo61PH1ol20P86oeeMG@Kooooo1olC4a<6o``<30Oo4A4A1olP8207
ob@T90Oo71`L1olE5AD6od10@0kooooo000<ooooo`OoIfMW1om3@d<7odQ8B0Oo9RHV1omGEeL6oaHF
5POoG5aL1_n3Ph<6ooooo`Oo820P1olD51@7ojBTY0Oooooo1onJVYX6ogMgM`Oo<S8b1_m1@D46oooo
o`OoDU9B1olN7Qh7o``<30Oo1PH61_l820P7oa8B4POo61PH1_n/[:`6ooooo`Oo20P81ol92@T7o`41
0@Oo8R8R1_lc<c<7obLW9`Oo3Ph>1_lR8R86ooooo`Oo1@D51ol92@T7o`H61PKo3`l?1ol410@7o`L7
1`Oo1PH61_lN7Qh6ooooo`Oo6ATI1olN7Qh7obh^;PKo4a<C1ol71`L7o`X:2POo3Ph>1_lW9bL6oooo
o`Oo00001ol61PH6oa`L70Oo00001olI6AT7oaHF5POo1PH61_m:BTX6ooooo`Oo9BDU1_lH61P7oa<C
4`Oo;Rh^1olN7Qh7oa/K6`Oo4a<C1_mCDe<>ooooo`003?ooool7ofMWI`Oo@d=31om8B4P7obHV9POo
EeMG1_lF5QH7oeaLG0KoPh>31_ooool7ob0P80Oo51@D1onTY:@7ooooo`OoVYZJ1_mgMgL7oc8b<PKo
@D511_ooool7oe9BDPOo7QhN1ol<30`7o`H61PKo20P81olB4Q87oaPH60Ko[:b/1_ooool7o`P820Oo
2@T91ol10@47ob8R8PKo<c<c1olW9bL7o`h>3PKo8R8R1_ooool7o`D51@Oo2@T91ol61PH6o`l?3`Oo
10@41ol71`L7o`H61PKo7QhN1_ooool7oaTI6@Oo7QhN1ol^;Rh6oa<C4`Oo1`L71ol:2PX7o`h>3PKo
9bLW1_ooool7o`0000Oo1PH61_lL71`7o`0000Oo6ATI1olF5QH7o`H61PKoBTY:1_ooool7obDU9@Ko
61PH1olC4a<7obh^;POo7QhN1olK6a/7oa<C4`KoDe=C3_ooool000cooooo1omWIfL7od=3@`OoB4Q8
1olV9RH7oeMGE`Ko5QHF1omLG5`6oh>3P`Kooooo1olP8207oa@D50OoY:BT1oooool7oiZJVPKoMgMg
1olb<S86od51@@Kooooo1omBDU87oahN7POo30`<1ol61PH6o`P820Oo4Q8B1olH61P6ojb/[0Kooooo
1ol820P7o`T92@Oo0@411olR8R86oc<c<`Oo9bLW1ol>3Ph6ob8R8PKooooo1ol51@D7o`T92@Oo1PH6
1_l?3`l7o`@410Oo1`L71ol61PH6oahN7PKooooo1olI6AT7oahN7POo;Rh^1_lC4a<7o`L71`Oo2PX:
1ol>3Ph6obLW9`Kooooo1ol00007o`H61PKo71`L1ol00007oaTI6@Oo5QHF1ol61PH6odY:BPKooooo
1olU9BD6oaPH60Oo4a<C1ol^;Rh7oahN7POo6a/K1olC4a<6oe=CD`kooooo000<ooooo`OoIfMW1om3
@d<7odQ8B0Oo9RHV1omGEeL6oaHF5POoG5aL1_n3Ph<6ooooo`Oo820P1olD51@7ojBTY0Oooooo1onJ
VYX6ogMgM`Oo<S8b1_m1@D46ooooo`OoDU9B1olN7Qh7o``<30Oo1PH61_l820P7oa8B4POo61PH1_n/
[:`6ooooo`Oo20P81ol92@T7o`410@Oo8R8R1_lc<c<7obLW9`Oo3Ph>1_lR8R86ooooo`Oo1@D51ol9
2@T7o`H61PKo3`l?1ol410@7o`L71`Oo1PH61_lN7Qh6ooooo`Oo6ATI1olN7Qh7obh^;PKo4a<C1ol7
1`L7o`X:2POo3Ph>1_lW9bL6ooooo`Oo00001ol61PH6oa`L70Oo00001olI6AT7oaHF5POo1PH61_m:
BTX6ooooo`Oo9BDU1_lH61P7oa<C4`Oo;Rh^1olN7Qh7oa/K6`Oo4a<C1_mCDe<>ooooo`003?ooool7
ofMWI`Oo@d=31om8B4P7obHV9POoEeMG1_lF5QH7oeaLG0KoPh>31_ooool7ob0P80Oo51@D1onTY:@7
ooooo`OoVYZJ1_mgMgL7oc8b<PKo@D511_ooool7oe9BDPOo7QhN1ol<30`7o`H61PKo20P81olB4Q87
oaPH60Ko[:b/1_ooool7o`P820Oo2@T91ol10@47ob8R8PKo<c<c1olW9bL7o`h>3PKo8R8R1_ooool7
o`D51@Oo2@T91ol61PH6o`l?3`Oo10@41ol71`L7o`H61PKo7QhN1_ooool7oaTI6@Oo7QhN1ol^;Rh6
oa<C4`Oo1`L71ol:2PX7o`h>3PKo9bLW1_ooool7o`0000Oo1PH61_lL71`7o`0000Oo6ATI1olF5QH7
o`H61PKoBTY:1_ooool7obDU9@Ko61PH1olC4a<7obh^;POo7QhN1olK6a/7oa<C4`KoDe=C3_ooool0
00cooooo1omWIfL7od=3@`OoB4Q81olV9RH7oeMGE`Ko5QHF1omLG5`6oh>3P`Kooooo1olP8207oa@D
50OoY:BT1oooool7oiZJVPKoMgMg1olb<S86od51@@Kooooo1omBDU87oahN7POo30`<1ol61PH6o`P8
20Oo4Q8B1olH61P6ojb/[0Kooooo1ol820P7o`T92@Oo0@411olR8R86oc<c<`Oo9bLW1ol>3Ph6ob8R
8PKooooo1ol51@D7o`T92@Oo1PH61_l?3`l7o`@410Oo1`L71ol61PH6oahN7PKooooo1olI6AT7oahN
7POo;Rh^1_lC4a<7o`L71`Oo2PX:1ol>3Ph6obLW9`Kooooo1ol00007o`H61PKo71`L1ol00007oaTI
6@Oo5QHF1ol61PH6odY:BPKooooo1olU9BD6oaPH60Oo4a<C1ol^;Rh7oahN7POo6a/K1olC4a<6oe=C
D`kooooo000<ooooo`OoDe=C1om=CDd7obXZ:POo9BDU1olh>3P6oc0`<0OoEEEE1_nMWId6ooooo`Oo
92@T1oln?Sh7ohJ6QPOoY:BT1om[Jf/6og=cL`Oo9bLW1_lj>SX6ooooo`Oo<c<c1olO7al7o`D51@Oo
1PH61_l<30`7o`h>3POo61PH1_nPX:06ooooo`Oo6ATI1olN7Qh7o`0000Oo4Q8B1_l/;2`7ob8R8POo
71`L1_lS8b<6ooooo`Oo3@d=1ol51@D7o`d=3@Ko4Q8B1olE5AD7o`X:2POo3Ph>1_lA4A46ooooo`Oo
71`L1ol?3`l7obl_;`Ko9bLW1ol820P7obHV9POo6QXJ1_lG5aL6ooooo`Oo:b/[1ol;2`/6ob<S8`Oo
20P81ol^;Rh7obHV9POo410@1_lf=SH6ooooo`OoBDU91_lH61P7oaXJ6POo=SHf1olY:BT7ob0P80Oo
7alO5?ooool000cooooo1omCDe<7ode=C@Oo:RXZ1olU9BD7ocPh>0Ko<30`1omEEED6oifMW@Kooooo
1olT92@7ochn?POoQXJ61onTY:@7of][J`KoLg=c1olW9bL6ocXj>PKooooo1olc<c<7oalO7`Oo1@D5
1ol61PH6o``<30Oo3Ph>1olH61P6oj2PX0Kooooo1olI6AT7oahN7POo00001olB4Q86ob`/;0Oo8R8R
1olL71`6ob<S8`Kooooo1ol=3@d7o`D51@Oo3@d=1_lB4Q87oaDE5@Oo2PX:1ol>3Ph6oa4A4@Kooooo
1olL71`7o`l?3`Oo;bl_1_lW9bL7o`P820Oo9RHV1olJ6QX6oaLG5`Kooooo1ol[:b/7o`/;2`Ko8b<S
1ol820P7obh^;POo9RHV1ol@4106ocHf=PKooooo1om9BDT6oaPH60Oo6QXJ1olf=SH7obTY:@Oo820P
1olO7alDooooo`003?ooool7oe=CD`OoCDe=1olZ:RX7obDU9@Oo>3Ph1_l`<307oeEEE@KoWIfM1_oo
ool7ob@T90Oo?Shn1on6QXH7ojBTY0OoJf][1_mcLg<7obLW9`Ko>SXj1_ooool7oc<c<`Oo7alO1ol5
1@D7o`H61PKo30`<1ol>3Ph7oaPH60KoX:2P1_ooool7oaTI6@Oo7QhN1ol00007oa8B4PKo;2`/1olR
8R87oa`L70Ko8b<S1_ooool7o`d=3@Oo1@D51ol=3@d6oa8B4POo5ADE1ol:2PX7o`h>3PKo4A4A1_oo
ool7oa`L70Oo3`l?1ol_;bl6obLW9`Oo20P81olV9RH7oaXJ6PKo5aLG1_ooool7ob/[:`Oo2`/;1_lS
8b<7o`P820Oo;Rh^1olV9RH7oa0@40Ko=SHf1_ooool7odU9B@Ko61PH1olJ6QX7ocHf=POo:BTY1olP
8207oalO7aCooooo000<ooooo`OoDe=C1om=CDd7obXZ:POo9BDU1olh>3P6oc0`<0OoEEEE1_nMWId6
ooooo`Oo92@T1oln?Sh7ohJ6QPOoY:BT1om[Jf/6og=cL`Oo9bLW1_lj>SX6ooooo`Oo<c<c1olO7al7
o`D51@Oo1PH61_l<30`7o`h>3POo61PH1_nPX:06ooooo`Oo6ATI1olN7Qh7o`0000Oo4Q8B1_l/;2`7
ob8R8POo71`L1_lS8b<6ooooo`Oo3@d=1ol51@D7o`d=3@Ko4Q8B1olE5AD7o`X:2POo3Ph>1_lA4A46
ooooo`Oo71`L1ol?3`l7obl_;`Ko9bLW1ol820P7obHV9POo6QXJ1_lG5aL6ooooo`Oo:b/[1ol;2`/6
ob<S8`Oo20P81ol^;Rh7obHV9POo410@1_lf=SH6ooooo`OoBDU91_lH61P7oaXJ6POo=SHf1olY:BT7
ob0P80Oo7alO5?ooool000cooooo1omCDe<7ode=C@Oo:RXZ1olU9BD7ocPh>0Ko<30`1omEEED6oifM
W@Kooooo1olT92@7ochn?POoQXJ61onTY:@7of][J`KoLg=c1olW9bL6ocXj>PKooooo1olc<c<7oalO
7`Oo1@D51ol61PH6o``<30Oo3Ph>1olH61P6oj2PX0Kooooo1olI6AT7oahN7POo00001olB4Q86ob`/
;0Oo8R8R1olL71`6ob<S8`Kooooo1ol=3@d7o`D51@Oo3@d=1_lB4Q87oaDE5@Oo2PX:1ol>3Ph6oa4A
4@Kooooo1olL71`7o`l?3`Oo;bl_1_lW9bL7o`P820Oo9RHV1olJ6QX6oaLG5`Kooooo1ol[:b/7o`/;
2`Ko8b<S1ol820P7obh^;POo9RHV1ol@4106ocHf=PKooooo1om9BDT6oaPH60Oo6QXJ1olf=SH7obTY
:@Oo820P1olO7alDooooo`003?ooool7oe=CD`OoCDe=1olZ:RX7obDU9@Oo>3Ph1_l`<307oeEEE@Ko
WIfM1_ooool7ob@T90Oo?Shn1on6QXH7ojBTY0OoJf][1_mcLg<7obLW9`Ko>SXj1_ooool7oc<c<`Oo
7alO1ol51@D7o`H61PKo30`<1ol>3Ph7oaPH60KoX:2P1_ooool7oaTI6@Oo7QhN1ol00007oa8B4PKo
;2`/1olR8R87oa`L70Ko8b<S1_ooool7o`d=3@Oo1@D51ol=3@d6oa8B4POo5ADE1ol:2PX7o`h>3PKo
4A4A1_ooool7oa`L70Oo3`l?1ol_;bl6obLW9`Oo20P81olV9RH7oaXJ6PKo5aLG1_ooool7ob/[:`Oo
2`/;1_lS8b<7o`P820Oo;Rh^1olV9RH7oa0@40Ko=SHf1_ooool7odU9B@Ko61PH1olJ6QX7ocHf=POo
:BTY1olP8207oalO7aCooooo000<ooooo`OoDe=C1om=CDd7obXZ:POo9BDU1olh>3P6oc0`<0OoEEEE
1_nMWId6ooooo`Oo92@T1oln?Sh7ohJ6QPOoY:BT1om[Jf/6og=cL`Oo9bLW1_lj>SX6ooooo`Oo<c<c
1olO7al7o`D51@Oo1PH61_l<30`7o`h>3POo61PH1_nPX:06ooooo`Oo6ATI1olN7Qh7o`0000Oo4Q8B
1_l/;2`7ob8R8POo71`L1_lS8b<6ooooo`Oo3@d=1ol51@D7o`d=3@Ko4Q8B1olE5AD7o`X:2POo3Ph>
1_lA4A46ooooo`Oo71`L1ol?3`l7obl_;`Ko9bLW1ol820P7obHV9POo6QXJ1_lG5aL6ooooo`Oo:b/[
1ol;2`/6ob<S8`Oo20P81ol^;Rh7obHV9POo410@1_lf=SH6ooooo`OoBDU91_lH61P7oaXJ6POo=SHf
1olY:BT7ob0P80Oo7alO5?ooool001?ooooo1ooTi>@7ok2`/0OoHV9R1ond];@6oh20P0OojNWY1_oi
nOT6ooooo`Oo:BTY1olc<c<7oe1@D0OoIVIV1ol`<306odQ8B0Oo=CDe1_mYJFT6ooooo`OoIfMW1ol]
;Bd7obTY:@Oo:b/[1_lZ:RX7oaHF5POo6ATI1_mJFUX6ooooo`OoKVi^1omgMgL7ob/[:`Oo9bLW1_lD
51@7oa/K6`Oo9RHV1_la<C46ooooo`OoF5QH1ole=CD7of=SH`Kooooo1onBTY87oi6AT@OoUIFE1_m;
Bd/6ooooo`Oo>3Ph1olE5AD7oalO7`Ko?Shn1omcLg<7ohZ:RPOo=cLg1_ll?3`6ooooo`Oo;Bd]1olo
?cl6okFe]@Oo;bl_1om<C4`7obHV9POoBd];1_m4A4@6ooooo`Oo71`L1_lN7Qh7oa<C4`Oo7alO1olW
9bL7ob`/;0Oo<C4a1_lo?cl>ooooo`004oooool7onCTi0Oo/;2`1omRHV87okBd]0KoP8201ooYjNT6
ooWin@Kooooo1olY:BT7oc<c<`OoD51@1omVIVH7oc0`<0KoB4Q81ole=CD6ofUYJ@Kooooo1omWIfL7
obd];@Oo:BTY1ol[:b/6obXZ:POo5QHF1olI6AT6oeYJFPKooooo1om^KVh7ogMgM`Oo:b/[1olW9bL6
oa@D50Oo6a/K1olV9RH6oc4a<@Kooooo1omHF5P7ocDe=@OoHf=S1_ooool7oi:BTPOoTI6A1onEUID6
od];B`Kooooo1olh>3P7oaDE5@Oo7alO1_ln?Sh7og=cL`OoRXZ:1olg=cL6oc`l?0Kooooo1ol];Bd7
oclo?`Ko]KFe1ol_;bl7oda<C0Oo9RHV1om;Bd/6odA4A0Kooooo1olL71`6oahN7POo4a<C1olO7al7
obLW9`Oo;2`/1ola<C46oclo?`kooooo000Cooooo`Ooi>CT1on`/;07of9RHPOo];Bd1_n0P807onWY
j@KonOWi1_ooool7obTY:@Oo<c<c1om@D507ofIVIPOo<30`1_m8B4P7ocDe=@KoJFUY1_ooool7ofMW
I`Oo;Bd]1olY:BT7ob/[:`Ko:RXZ1olF5QH7oaTI6@KoFUYJ1_ooool7ofi^KPOoMgMg1ol[:b/7obLW
9`Ko51@D1olK6a/7obHV9PKo<C4a1_ooool7oeQHF0Oo=CDe1omSHf<6ooooo`OoTY:B1onATI47oiFE
U@KoBd];1_ooool7ocPh>0Oo5ADE1olO7al6ochn?POoLg=c1on:RXX7ocLg=`Ko?3`l1_ooool7obd]
;@Oo?clo1_ne]KD7obl_;`OoC4a<1olV9RH7od];B`KoA4A41_ooool7oa`L70Ko7QhN1olC4a<7oalO
7`Oo9bLW1ol/;2`7oc4a<@Ko?clo3_ooool001?ooooo1ooTi>@7ok2`/0OoHV9R1ond];@6oh20P0Oo
jNWY1_oinOT6ooooo`Oo:BTY1olc<c<7oe1@D0OoIVIV1ol`<306odQ8B0Oo=CDe1_mYJFT6ooooo`Oo
IfMW1ol];Bd7obTY:@Oo:b/[1_lZ:RX7oaHF5POo6ATI1_mJFUX6ooooo`OoKVi^1omgMgL7ob/[:`Oo
9bLW1_lD51@7oa/K6`Oo9RHV1_la<C46ooooo`OoF5QH1ole=CD7of=SH`Kooooo1onBTY87oi6AT@Oo
UIFE1_m;Bd/6ooooo`Oo>3Ph1olE5AD7oalO7`Ko?Shn1omcLg<7ohZ:RPOo=cLg1_ll?3`6ooooo`Oo
;Bd]1olo?cl6okFe]@Oo;bl_1om<C4`7obHV9POoBd];1_m4A4@6ooooo`Oo71`L1_lN7Qh7oa<C4`Oo
7alO1olW9bL7ob`/;0Oo<C4a1_lo?cl>ooooo`004oooool7onCTi0Oo/;2`1omRHV87okBd]0KoP820
1ooYjNT6ooWin@Kooooo1olY:BT7oc<c<`OoD51@1omVIVH7oc0`<0KoB4Q81ole=CD6ofUYJ@Kooooo
1omWIfL7obd];@Oo:BTY1ol[:b/6obXZ:POo5QHF1olI6AT6oeYJFPKooooo1om^KVh7ogMgM`Oo:b/[
1olW9bL6oa@D50Oo6a/K1olV9RH6oc4a<@Kooooo1omHF5P7ocDe=@OoHf=S1_ooool7oi:BTPOoTI6A
1onEUID6od];B`Kooooo1olh>3P7oaDE5@Oo7alO1_ln?Sh7og=cL`OoRXZ:1olg=cL6oc`l?0Kooooo
1ol];Bd7oclo?`Ko]KFe1ol_;bl7oda<C0Oo9RHV1om;Bd/6odA4A0Kooooo1olL71`6oahN7POo4a<C
1olO7al7obLW9`Oo;2`/1ola<C46oclo?`kooooo000Cooooo`Ooi>CT1on`/;07of9RHPOo];Bd1_n0
P807onWYj@KonOWi1_ooool7obTY:@Oo<c<c1om@D507ofIVIPOo<30`1_m8B4P7ocDe=@KoJFUY1_oo
ool7ofMWI`Oo;Bd]1olY:BT7ob/[:`Ko:RXZ1olF5QH7oaTI6@KoFUYJ1_ooool7ofi^KPOoMgMg1ol[
:b/7obLW9`Ko51@D1olK6a/7obHV9PKo<C4a1_ooool7oeQHF0Oo=CDe1omSHf<6ooooo`OoTY:B1onA
TI47oiFEU@KoBd];1_ooool7ocPh>0Oo5ADE1olO7al6ochn?POoLg=c1on:RXX7ocLg=`Ko?3`l1_oo
ool7obd];@Oo?clo1_ne]KD7obl_;`OoC4a<1olV9RH7od];B`KoA4A41_ooool7oa`L70Ko7QhN1olC
4a<7oalO7`Oo9bLW1ol/;2`7oc4a<@Ko?clo3_ooool001?ooooo1ooTi>@7ok2`/0OoHV9R1ond];@6
oh20P0OojNWY1_oinOT6ooooo`Oo:BTY1olc<c<7oe1@D0OoIVIV1ol`<306odQ8B0Oo=CDe1_mYJFT6
ooooo`OoIfMW1ol];Bd7obTY:@Oo:b/[1_lZ:RX7oaHF5POo6ATI1_mJFUX6ooooo`OoKVi^1omgMgL7
ob/[:`Oo9bLW1_lD51@7oa/K6`Oo9RHV1_la<C46ooooo`OoF5QH1ole=CD7of=SH`Kooooo1onBTY87
oi6AT@OoUIFE1_m;Bd/6ooooo`Oo>3Ph1olE5AD7oalO7`Ko?Shn1omcLg<7ohZ:RPOo=cLg1_ll?3`6
ooooo`Oo;Bd]1olo?cl6okFe]@Oo;bl_1om<C4`7obHV9POoBd];1_m4A4@6ooooo`Oo71`L1_lN7Qh7
oa<C4`Oo7alO1olW9bL7ob`/;0Oo<C4a1_lo?cl>ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-1.81198, \
-0.862434, 0.14679, 0.14679}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-10.6148, -0.862434, 0.14679, 0.14679}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-19.4177, -0.862434, 0.14679, 0.14679}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-28.2205, -0.862434, 0.14679, 0.14679}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-37.0188, -0.862434, 0.14679, 0.14679}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-45.8262, -0.862434, 0.14679, \
0.14679}, {{372.125, 426.625}, {240.25, 185.75}} -> {-54.6244, -0.862434, \
0.14679, 0.14679}, {{432.062, 486.625}, {240.25, 185.75}} -> {-63.4273, \
-0.862434, 0.14679, 0.14679}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-1.81198, -9.66986, 0.14679, 0.14679}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-10.6148, -9.66986, 0.14679, 0.14679}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-19.4177, -9.66986, 0.14679, 0.14679}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-28.2205, -9.66986, 0.14679, 0.14679}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-37.0188, -9.66986, 0.14679, \
0.14679}, {{312.188, 366.688}, {180.25, 125.75}} -> {-45.8262, -9.66986, \
0.14679, 0.14679}, {{372.125, 426.625}, {180.25, 125.75}} -> {-54.6244, \
-9.66986, 0.14679, 0.14679}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-63.4273, -9.66986, 0.14679, 0.14679}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-1.81198, -18.4681, 0.14679, 0.14679}, {{72.3125, 126.812}, \
{120.312, 65.8125}} -> {-10.6148, -18.4681, 0.14679, 0.14679}, {{132.25, \
186.812}, {120.312, 65.8125}} -> {-19.4177, -18.4681, 0.14679, 0.14679}, \
{{192.25, 246.75}, {120.312, 65.8125}} -> {-28.2205, -18.4681, 0.14679, \
0.14679}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-37.0188, -18.4681, \
0.14679, 0.14679}, {{312.188, 366.688}, {120.312, 65.8125}} -> {-45.8262, \
-18.4681, 0.14679, 0.14679}, {{372.125, 426.625}, {120.312, 65.8125}} -> \
{-54.6244, -18.4681, 0.14679, 0.14679}, {{432.062, 486.625}, {120.312, \
65.8125}} -> {-63.4273, -18.4681, 0.14679, 0.14679}, {{12.3125, 66.875}, \
{60.3125, 5.8125}} -> {-1.81198, -27.2755, 0.14679, 0.14679}, {{72.3125, \
126.812}, {60.3125, 5.8125}} -> {-10.6148, -27.2755, 0.14679, 0.14679}, \
{{132.25, 186.812}, {60.3125, 5.8125}} -> {-19.4177, -27.2755, 0.14679, \
0.14679}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-28.2205, -27.2755, \
0.14679, 0.14679}, {{252.188, 306.688}, {60.3125, 5.8125}} -> {-37.0188, \
-27.2755, 0.14679, 0.14679}, {{312.188, 366.688}, {60.3125, 5.8125}} -> \
{-45.8262, -27.2755, 0.14679, 0.14679}, {{372.125, 426.625}, {60.3125, \
5.8125}} -> {-54.6244, -27.2755, 0.14679, 0.14679}, {{432.062, 486.625}, \
{60.3125, 5.8125}} -> {-63.4273, -27.2755, 0.14679, 0.14679}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
18481318
0719060A
000E1105
28FF0B23
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1400030A
29231F00
56EEFF5B
382D2719
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36FF453C
0ECA0071
0A3F233D
45492850
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
282A901C
003E9332
113C5031
B246FF5E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
382F0F18
297E468F
209299FF
25000106
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
27FFF438
232E4900
26171E17
1D563A12
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
12123E10
00123209
0905D935
01921DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6A2F293E
471A2529
2618001E
FF2A5F5B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
081B3E1F
0A0A3106
08002B0C
0C10FF14
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B2E151D
BDFF380B
27441800
3E242545
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
07266DCB
1400304B
33131D21
155B7BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0515366B
371D2AA6
25003058
0F24FF0C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
50301011
1B490B00
39FF3C4D
0401020C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00133424
1840FFDA
133C2437
3F2E042C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFBB1600
1021040A
051C4404
3D1C2616
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4D340925
252B000F
1B211702
A8FF1355
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
52141302
18100B05
0C01020E
FF040200
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00030314
16240D1F
FF7E0A17
2D4B2221
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C7D6BF6
003A8BFF
0B136AAE
3C663476
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
241A2D05
1A130500
3D060002
197DFF37
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
141C1953
1D3F4EFF
060052FF
180F0018
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2F19FF59
0004200A
1D160C0D
18392815
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B0F0B4B
21201110
24360009
291D6DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11090002
081C0E11
181F5735
FF210B16
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
51856932
D6938114
FFA0D452
BAF46500
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
38131116
FF000A16
4416050D
14150901
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11001B36
1714140F
14140D18
191828FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05121A10
1C170C00
17493307
4417FF04
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4109061C
BF1E0806
FF180B00
11051749
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11132214
3061FF00
2E135A1F
09190B1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF060803
2B14141F
0119003E
56401722
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
07491300
1C102F15
03071B1F
3AFF4607
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool>oaPH60koB4Q83OlC4a<=oaPH60Kooooo3_lD51@>o`0000go
0`<33Ol:2PX6ooooo`ko=SHf3_ooool=odE5A@go?3`l1_ooool>obPX:0ko:RXZ3On@T90=oa`L70Ko
oooo3_lh>3P=obl_;`ko3`l?3OlH61P6ooooo`ko9bLW3Oooool>ooCdm0go>3Ph1_oooolKoa8B4Pko
?Shn3Ol@4106ooooo`goJVYZ3_l_;bl>obTY:@go?Shn3_ooool000cooooo3_lH61P>odQ8B0go4a<C
3OlH61P6ooooo`ko51@D3_l0000=o`<30`go2PX:1_ooool>ocHf=Pkooooo3Om5ADD=oc`l?0Kooooo
3_lX:2P>obXZ:PgoT92@3OlL71`6ooooo`ko>3Ph3Ol_;bl>o`l?3`go61PH1_ooool>obLW9`gooooo
3_odm?@=ocPh>0Kooooo6olB4Q8>ochn?Pgo410@1_ooool=ofYZJPko;bl_3_lY:BT=ochn?Pkooooo
000<ooooo`ko61PH3_m8B4P=oa<C4`go61PH1_ooool>oa@D50ko00003Ol30`<=o`X:2PKooooo3_lf
=SH>ooooo`goADE53Oll?3`6ooooo`ko:2PX3_lZ:RX=oi2@T0go71`L1_ooool>ocPh>0go;bl_3_l?
3`l=oaPH60Kooooo3_lW9bL=ooooo`kom?Cd3Olh>3P6oooooa_o4Q8B3_ln?Sh=oa0@40Kooooo3OmZ
JVX>obl_;`ko:BTY3Oln?Sh>ooooo`003?ooool>oaPH60koB4Q83OlC4a<=oaPH60Kooooo3_lD51@>
o`0000go0`<33Ol:2PX6ooooo`ko=SHf3_ooool=odE5A@go?3`l1_ooool>obPX:0ko:RXZ3On@T90=
oa`L70Kooooo3_lh>3P=obl_;`ko3`l?3OlH61P6ooooo`ko9bLW3Oooool>ooCdm0go>3Ph1_oooolK
oa8B4Pko?Shn3Ol@4106ooooo`goJVYZ3_l_;bl>obTY:@go?Shn3_ooool000cooooo3_lH61P>odQ8
B0go4a<C3OlH61P6ooooo`ko51@D3_l0000=o`<30`go2PX:1_ooool>ocHf=Pkooooo3Om5ADD=oc`l
?0Kooooo3_lX:2P>obXZ:PgoT92@3OlL71`6ooooo`ko>3Ph3Ol_;bl>o`l?3`go61PH1_ooool>obLW
9`gooooo3_odm?@=ocPh>0Kooooo6olB4Q8>ochn?Pgo410@1_ooool=ofYZJPko;bl_3_lY:BT=ochn
?Pkooooo000<ooooo`ko61PH3_m8B4P=oa<C4`go61PH1_ooool>oa@D50ko00003Ol30`<=o`X:2PKo
oooo3_lf=SH>ooooo`goADE53Oll?3`6ooooo`ko:2PX3_lZ:RX=oi2@T0go71`L1_ooool>ocPh>0go
;bl_3_l?3`l=oaPH60Kooooo3_lW9bL=ooooo`kom?Cd3Olh>3P6oooooa_o4Q8B3_ln?Sh=oa0@40Ko
oooo3OmZJVX>obl_;`ko:BTY3Oln?Sh>ooooo`003?ooool>oaPH60koB4Q83OlC4a<=oaPH60Kooooo
3_lD51@>o`0000go0`<33Ol:2PX6ooooo`ko=SHf3_ooool=odE5A@go?3`l1_ooool>obPX:0ko:RXZ
3On@T90=oa`L70Kooooo3_lh>3P=obl_;`ko3`l?3OlH61P6ooooo`ko9bLW3Oooool>ooCdm0go>3Ph
1_oooolKoa8B4Pko?Shn3Ol@4106ooooo`goJVYZ3_l_;bl>obTY:@go?Shn3_ooool000cooooo3_lH
61P>odQ8B0go4a<C3OlH61P6ooooo`ko51@D3_l0000=o`<30`go2PX:1_ooool>ocHf=Pkooooo3Om5
ADD=oc`l?0Kooooo3_lX:2P>obXZ:PgoT92@3OlL71`6ooooo`ko>3Ph3Ol_;bl>o`l?3`go61PH1_oo
ool>obLW9`gooooo3_odm?@=ocPh>0Kooooo6olB4Q8>ochn?Pgo410@1_ooool=ofYZJPko;bl_3_lY
:BT=ochn?Pkooooo000<ooooo`ko61PH3_m8B4P=oa<C4`go61PH1_ooool>oa@D50ko00003Ol30`<=
o`X:2PKooooo3_lf=SH>ooooo`goADE53Oll?3`6ooooo`ko:2PX3_lZ:RX=oi2@T0go71`L1_ooool>
ocPh>0go;bl_3_l?3`l=oaPH60Kooooo3_lW9bL=ooooo`kom?Cd3Olh>3P6oooooa_o4Q8B3_ln?Sh=
oa0@40Kooooo3OmZJVX>obl_;`ko:BTY3Oln?Sh>ooooo`003?ooool>oaPH60koB4Q83OlC4a<=oaPH
60Kooooo3_lD51@>o`0000go0`<33Ol:2PX6ooooo`ko=SHf3_ooool=odE5A@go?3`l1_ooool>obPX
:0ko:RXZ3On@T90=oa`L70Kooooo3_lh>3P=obl_;`ko3`l?3OlH61P6ooooo`ko9bLW3Oooool>ooCd
m0go>3Ph1_oooolKoa8B4Pko?Shn3Ol@4106ooooo`goJVYZ3_l_;bl>obTY:@go?Shn3_ooool000co
oooo3_lH61P>odQ8B0go4a<C3OlH61P6ooooo`ko51@D3_l0000=o`<30`go2PX:1_ooool>ocHf=Pko
oooo3Om5ADD=oc`l?0Kooooo3_lX:2P>obXZ:PgoT92@3OlL71`6ooooo`ko>3Ph3Ol_;bl>o`l?3`go
61PH1_ooool>obLW9`gooooo3_odm?@=ocPh>0Kooooo6olB4Q8>ochn?Pgo410@1_ooool=ofYZJPko
;bl_3_lY:BT=ochn?Pkooooo000<ooooo`ko61PH3_m8B4P=oa<C4`go61PH1_ooool>oa@D50ko0000
3Ol30`<=o`X:2PKooooo3_lf=SH>ooooo`goADE53Oll?3`6ooooo`ko:2PX3_lZ:RX=oi2@T0go71`L
1_ooool>ocPh>0go;bl_3_l?3`l=oaPH60Kooooo3_lW9bL=ooooo`kom?Cd3Olh>3P6oooooa_o4Q8B
3_ln?Sh=oa0@40Kooooo3OmZJVX>obl_;`ko:BTY3Oln?Sh>ooooo`003?ooool>oaPH60koB4Q83OlC
4a<=oaPH60Kooooo3_lD51@>o`0000go0`<33Ol:2PX6ooooo`ko=SHf3_ooool=odE5A@go?3`l1_oo
ool>obPX:0ko:RXZ3On@T90=oa`L70Kooooo3_lh>3P=obl_;`ko3`l?3OlH61P6ooooo`ko9bLW3Ooo
ool>ooCdm0go>3Ph1_oooolKoa8B4Pko?Shn3Ol@4106ooooo`goJVYZ3_l_;bl>obTY:@go?Shn3_oo
ool000cooooo3_lH61P>odQ8B0go4a<C3OlH61P6ooooo`ko51@D3_l0000=o`<30`go2PX:1_ooool>
ocHf=Pkooooo3Om5ADD=oc`l?0Kooooo3_lX:2P>obXZ:PgoT92@3OlL71`6ooooo`ko>3Ph3Ol_;bl>
o`l?3`go61PH1_ooool>obLW9`gooooo3_odm?@=ocPh>0Kooooo6olB4Q8>ochn?Pgo410@1_ooool=
ofYZJPko;bl_3_lY:BT=ochn?Pkooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY
:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>C
T`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006oooo
o`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko
1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo
00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Ko
oooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko
6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S
3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b
1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko0000
3OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI
6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003Oma
LG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS
8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU
9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=
o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>
obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>
oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H6
1Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46oooo
o`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^
;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY
:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Ko
oooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@go
OWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo
2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:
1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko0000
3_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU9
3Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo
000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>
3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6
ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_oo
ool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>
obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=
oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006
ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<oooo
o`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:
bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?
S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7
A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L73_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko
8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo00003OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go
<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko
00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ3_lU9BD=obTY:@kooooo000<ooooo`ko1`L7
3_lI6AT=o`H61Pgo2PX:1_ooool>obTY:@ko8b<S3OlO7al=o`0000Kooooo3_l>3Ph>ol[:bPgo0000
3OmaLG46ooooo`ko00003_ln?Sh=oi>CT`go<S8b1_ooool>obTY:@goOWin3_m6ATH=ohn?S`Kooooo
3_lS8b<=obh^;PkoBDU93Ol00006ooooo`ko00003OlB4Q8>oc8b<Pgo2@T91_ooool=odM7A`ko6QXJ
3_lU9BD=obTY:@kooooo000<ooooo`ko00003_l>3Ph=oa4A4@go1@D51_ooool>oeIFEPkok^k^3Ooo
ool=oe]KF`Kooooo3_l:2PX>oclo?`go8b<S3Olm?Cd6ooooo`ko4A4A3_ll?3`=oe1@D0go<C4a1_oo
ool>ob0P80goTY:B3_nIVITCooooo`ko9RHV3OlG5aL>oahN7Pgo5aLG1_ooool>o`T92@go1@D53_oI
fMT=ocDe=@Kooooo3OlV9RH>oaPH60ko00003OlN7Qh>ooooo`003?ooool>o`0000ko3Ph>3OlA4A4=
o`D51@Kooooo3_mFEUH>onk^kPgooooo3OmKFe/6ooooo`ko2PX:3_lo?cl=ob<S8`go?Cdm1_ooool>
oa4A4@ko?3`l3Om@D50=oc4a<@Kooooo3_lP820=oi:BTPkoVIVI4oooool>obHV9Pgo5aLG3_lN7Qh=
oaLG5`Kooooo3_l92@T=o`D51@kofMWI3Ole=CD6ooooo`go9RHV3_lH61P>o`0000go7QhN3_ooool0
00cooooo3_l0000>o`h>3Pgo4A4A3Ol51@D6ooooo`koEUIF3_o^k^h=ooooo`goFe]K1_ooool>o`X:
2Pko?clo3OlS8b<=ocdm?@Kooooo3_lA4A4>oc`l?0goD51@3Ola<C46ooooo`ko820P3OnBTY8>oiVI
VA?ooooo3_lV9RH=oaLG5`ko7QhN3OlG5aL6ooooo`ko2@T93Ol51@D>omWIf@go=CDe1_ooool=obHV
9Pko61PH3_l0000=oahN7Pkooooo000<ooooo`ko00003_l>3Ph=oa4A4@go1@D51_ooool>oeIFEPko
k^k^3Oooool=oe]KF`Kooooo3_l:2PX>oclo?`go8b<S3Olm?Cd6ooooo`ko4A4A3_ll?3`=oe1@D0go
<C4a1_ooool>ob0P80goTY:B3_nIVITCooooo`ko9RHV3OlG5aL>oahN7Pgo5aLG1_ooool>o`T92@go
1@D53_oIfMT=ocDe=@Kooooo3OlV9RH>oaPH60ko00003OlN7Qh>ooooo`003?ooool>o`0000ko3Ph>
3OlA4A4=o`D51@Kooooo3_mFEUH>onk^kPgooooo3OmKFe/6ooooo`ko2PX:3_lo?cl=ob<S8`go?Cdm
1_ooool>oa4A4@ko?3`l3Om@D50=oc4a<@Kooooo3_lP820=oi:BTPkoVIVI4oooool>obHV9Pgo5aLG
3_lN7Qh=oaLG5`Kooooo3_l92@T=o`D51@kofMWI3Ole=CD6ooooo`go9RHV3_lH61P>o`0000go7QhN
3_ooool000cooooo3_l0000>o`h>3Pgo4A4A3Ol51@D6ooooo`koEUIF3_o^k^h=ooooo`goFe]K1_oo
ool>o`X:2Pko?clo3OlS8b<=ocdm?@Kooooo3_lA4A4>oc`l?0goD51@3Ola<C46ooooo`ko820P3OnB
TY8>oiVIVA?ooooo3_lV9RH=oaLG5`ko7QhN3OlG5aL6ooooo`ko2@T93Ol51@D>omWIf@go=CDe1_oo
ool=obHV9Pko61PH3_l0000=oahN7Pkooooo000<ooooo`ko00003_l>3Ph=oa4A4@go1@D51_ooool>
oeIFEPkok^k^3Oooool=oe]KF`Kooooo3_l:2PX>oclo?`go8b<S3Olm?Cd6ooooo`ko4A4A3_ll?3`=
oe1@D0go<C4a1_ooool>ob0P80goTY:B3_nIVITCooooo`ko9RHV3OlG5aL>oahN7Pgo5aLG1_ooool>
o`T92@go1@D53_oIfMT=ocDe=@Kooooo3OlV9RH>oaPH60ko00003OlN7Qh>ooooo`003?ooool>o`00
00ko3Ph>3OlA4A4=o`D51@Kooooo3_mFEUH>onk^kPgooooo3OmKFe/6ooooo`ko2PX:3_lo?cl=ob<S
8`go?Cdm1_ooool>oa4A4@ko?3`l3Om@D50=oc4a<@Kooooo3_lP820=oi:BTPkoVIVI4oooool>obHV
9Pgo5aLG3_lN7Qh=oaLG5`Kooooo3_l92@T=o`D51@kofMWI3Ole=CD6ooooo`go9RHV3_lH61P>o`00
00go7QhN3_ooool000cooooo3_l0000>o`h>3Pgo4A4A3Ol51@D6ooooo`koEUIF3_o^k^h=ooooo`go
Fe]K1_ooool>o`X:2Pko?clo3OlS8b<=ocdm?@Kooooo3_lA4A4>oc`l?0goD51@3Ola<C46ooooo`ko
820P3OnBTY8>oiVIVA?ooooo3_lV9RH=oaLG5`ko7QhN3OlG5aL6ooooo`ko2@T93Ol51@D>omWIf@go
=CDe1_ooool=obHV9Pko61PH3_l0000=oahN7Pkooooo000<ooooo`ko00003_l>3Ph=oa4A4@go1@D5
1_ooool>oeIFEPkok^k^3Oooool=oe]KF`Kooooo3_l:2PX>oclo?`go8b<S3Olm?Cd6ooooo`ko4A4A
3_ll?3`=oe1@D0go<C4a1_ooool>ob0P80goTY:B3_nIVITCooooo`ko9RHV3OlG5aL>oahN7Pgo5aLG
1_ooool>o`T92@go1@D53_oIfMT=ocDe=@Kooooo3OlV9RH>oaPH60ko00003OlN7Qh>ooooo`003?oo
ool>o`0000ko3Ph>3OlA4A4=o`D51@Kooooo3_mFEUH>onk^kPgooooo3OmKFe/6ooooo`ko2PX:3_lo
?cl=ob<S8`go?Cdm1_ooool>oa4A4@ko?3`l3Om@D50=oc4a<@Kooooo3_lP820=oi:BTPkoVIVI4ooo
ool>obHV9Pgo5aLG3_lN7Qh=oaLG5`Kooooo3_l92@T=o`D51@kofMWI3Ole=CD6ooooo`go9RHV3_lH
61P>o`0000go7QhN3_ooool000cooooo3_l0000>o`h>3Pgo4A4A3Ol51@D6ooooo`koEUIF3_o^k^h=
ooooo`goFe]K1_ooool>o`X:2Pko?clo3OlS8b<=ocdm?@Kooooo3_lA4A4>oc`l?0goD51@3Ola<C46
ooooo`ko820P3OnBTY8>oiVIVA?ooooo3_lV9RH=oaLG5`ko7QhN3OlG5aL6ooooo`ko2@T93Ol51@D>
omWIf@go=CDe1_ooool=obHV9Pko61PH3_l0000=oahN7Pkooooo000<ooooo`ko00003_l>3Ph=oa4A
4@go1@D51_ooool>oeIFEPkok^k^3Oooool=oe]KF`Kooooo3_l:2PX>oclo?`go8b<S3Olm?Cd6oooo
o`ko4A4A3_ll?3`=oe1@D0go<C4a1_ooool>ob0P80goTY:B3_nIVITCooooo`ko9RHV3OlG5aL>oahN
7Pgo5aLG1_ooool>o`T92@go1@D53_oIfMT=ocDe=@Kooooo3OlV9RH>oaPH60ko00003OlN7Qh>oooo
o`003?ooool>obPX:0kooooo3Ol;2`/=ob<S8`Kooooo3_lh>3P>obd];@go9bLW3OlI6AT6ooooo`ko
ADE53_m9BDT=obPX:0goD51@1_ooool>ok:b/PkoATI63Oooool=oeiNGPKooooo3_lU9BD=o`0000ko
0@413Ol61PH6ooooo`ko7AdM3OmFEUH>ocXj>Pgo4Q8B1_ooool>o`410@goTY:B3_lM7AdPooooo`ko
:RXZ3_mOGel=oe]KF`kooooo000<ooooo`ko:2PX3_ooool=o`/;2`go8b<S1_ooool>ocPh>0ko;Bd]
3OlW9bL=oaTI6@Kooooo3_m5ADD>odU9B@go:2PX3Om@D506ooooo`ko/[:b3_m6ATH=ooooo`goGUiN
1_ooool>obDU9@go00003_l10@4=o`H61PKooooo3_lM7Ad=oeIFEPko>SXj3OlB4Q86ooooo`ko0@41
3OnBTY8>oadM7B3ooooo3_lZ:RX>oemOG`goFe]K3_ooool000cooooo3_lX:2P>ooooo`go2`/;3OlS
8b<6ooooo`ko>3Ph3_l];Bd=obLW9`go6ATI1_ooool>odE5A@koBDU93OlX:2P=oe1@D0Kooooo3_nb
/[8>odI6APgooooo3OmNGUh6ooooo`ko9BDU3Ol0000>o`410@go1PH61_ooool>oadM7@goEUIF3_lj
>SX=oa8B4PKooooo3_l10@4=oi:BTPko7AdM8?ooool>obXZ:PkoGemO3OmKFe/>ooooo`003?ooool>
obPX:0kooooo3Ol;2`/=ob<S8`Kooooo3_lh>3P>obd];@go9bLW3OlI6AT6ooooo`koADE53_m9BDT=
obPX:0goD51@1_ooool>ok:b/PkoATI63Oooool=oeiNGPKooooo3_lU9BD=o`0000ko0@413Ol61PH6
ooooo`ko7AdM3OmFEUH>ocXj>Pgo4Q8B1_ooool>o`410@goTY:B3_lM7AdPooooo`ko:RXZ3_mOGel=
oe]KF`kooooo000<ooooo`ko:2PX3_ooool=o`/;2`go8b<S1_ooool>ocPh>0ko;Bd]3OlW9bL=oaTI
6@Kooooo3_m5ADD>odU9B@go:2PX3Om@D506ooooo`ko/[:b3_m6ATH=ooooo`goGUiN1_ooool>obDU
9@go00003_l10@4=o`H61PKooooo3_lM7Ad=oeIFEPko>SXj3OlB4Q86ooooo`ko0@413OnBTY8>oadM
7B3ooooo3_lZ:RX>oemOG`goFe]K3_ooool000cooooo3_lX:2P>ooooo`go2`/;3OlS8b<6ooooo`ko
>3Ph3_l];Bd=obLW9`go6ATI1_ooool>odE5A@koBDU93OlX:2P=oe1@D0Kooooo3_nb/[8>odI6APgo
oooo3OmNGUh6ooooo`ko9BDU3Ol0000>o`410@go1PH61_ooool>oadM7@goEUIF3_lj>SX=oa8B4PKo
oooo3_l10@4=oi:BTPko7AdM8?ooool>obXZ:PkoGemO3OmKFe/>ooooo`003?ooool>obPX:0kooooo
3Ol;2`/=ob<S8`Kooooo3_lh>3P>obd];@go9bLW3OlI6AT6ooooo`koADE53_m9BDT=obPX:0goD51@
1_ooool>ok:b/PkoATI63Oooool=oeiNGPKooooo3_lU9BD=o`0000ko0@413Ol61PH6ooooo`ko7AdM
3OmFEUH>ocXj>Pgo4Q8B1_ooool>o`410@goTY:B3_lM7AdPooooo`ko:RXZ3_mOGel=oe]KF`kooooo
000<ooooo`ko:2PX3_ooool=o`/;2`go8b<S1_ooool>ocPh>0ko;Bd]3OlW9bL=oaTI6@Kooooo3_m5
ADD>odU9B@go:2PX3Om@D506ooooo`ko/[:b3_m6ATH=ooooo`goGUiN1_ooool>obDU9@go00003_l1
0@4=o`H61PKooooo3_lM7Ad=oeIFEPko>SXj3OlB4Q86ooooo`ko0@413OnBTY8>oadM7B3ooooo3_lZ
:RX>oemOG`goFe]K3_ooool000cooooo3_lX:2P>ooooo`go2`/;3OlS8b<6ooooo`ko>3Ph3_l];Bd=
obLW9`go6ATI1_ooool>odE5A@koBDU93OlX:2P=oe1@D0Kooooo3_nb/[8>odI6APgooooo3OmNGUh6
ooooo`ko9BDU3Ol0000>o`410@go1PH61_ooool>oadM7@goEUIF3_lj>SX=oa8B4PKooooo3_l10@4=
oi:BTPko7AdM8?ooool>obXZ:PkoGemO3OmKFe/>ooooo`003?ooool>obPX:0kooooo3Ol;2`/=ob<S
8`Kooooo3_lh>3P>obd];@go9bLW3OlI6AT6ooooo`koADE53_m9BDT=obPX:0goD51@1_ooool>ok:b
/PkoATI63Oooool=oeiNGPKooooo3_lU9BD=o`0000ko0@413Ol61PH6ooooo`ko7AdM3OmFEUH>ocXj
>Pgo4Q8B1_ooool>o`410@goTY:B3_lM7AdPooooo`ko:RXZ3_mOGel=oe]KF`kooooo000<ooooo`ko
:2PX3_ooool=o`/;2`go8b<S1_ooool>ocPh>0ko;Bd]3OlW9bL=oaTI6@Kooooo3_m5ADD>odU9B@go
:2PX3Om@D506ooooo`ko/[:b3_m6ATH=ooooo`goGUiN1_ooool>obDU9@go00003_l10@4=o`H61PKo
oooo3_lM7Ad=oeIFEPko>SXj3OlB4Q86ooooo`ko0@413OnBTY8>oadM7B3ooooo3_lZ:RX>oemOG`go
Fe]K3_ooool000cooooo3_lX:2P>ooooo`go2`/;3OlS8b<6ooooo`ko>3Ph3_l];Bd=obLW9`go6ATI
1_ooool>odE5A@koBDU93OlX:2P=oe1@D0Kooooo3_nb/[8>odI6APgooooo3OmNGUh6ooooo`ko9BDU
3Ol0000>o`410@go1PH61_ooool>oadM7@goEUIF3_lj>SX=oa8B4PKooooo3_l10@4=oi:BTPko7AdM
8?ooool>obXZ:PkoGemO3OmKFe/>ooooo`003?ooool>obPX:0kooooo3Ol;2`/=ob<S8`Kooooo3_lh
>3P>obd];@go9bLW3OlI6AT6ooooo`koADE53_m9BDT=obPX:0goD51@1_ooool>ok:b/PkoATI63Ooo
ool=oeiNGPKooooo3_lU9BD=o`0000ko0@413Ol61PH6ooooo`ko7AdM3OmFEUH>ocXj>Pgo4Q8B1_oo
ool>o`410@goTY:B3_lM7AdPooooo`ko:RXZ3_mOGel=oe]KF`kooooo000<ooooo`ko:2PX3_ooool=
o`/;2`go8b<S1_ooool>ocPh>0ko;Bd]3OlW9bL=oaTI6@Kooooo3_m5ADD>odU9B@go:2PX3Om@D506
ooooo`ko/[:b3_m6ATH=ooooo`goGUiN1_ooool>obDU9@go00003_l10@4=o`H61PKooooo3_lM7Ad=
oeIFEPko>SXj3OlB4Q86ooooo`ko0@413OnBTY8>oadM7B3ooooo3_lZ:RX>oemOG`goFe]K3_ooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool000cooooo3_l820P>oa/K6`go?Shn3OlO7al6ooooo`ko:b/[3_l^;Rh=oaDE5@go
7AdM1_ooool>o`L71`ko9RHV3Om]KFd=ol_;b`Kooooo3_l51@D>oaDE5@go=SHf3Om[Jf/6ooooo`ko
D51@3Ol`<30>oa0@40go4A4A1_ooool>o`0000go4a<C3_ld=3@=ob@T91Cooooo3Onk^k/>oaHF5Pgo
00001_ooool=ode=C@ko=3@d3_l92@T=obDU9@kooooo000<ooooo`ko20P83_lK6a/=ochn?Pgo7alO
1_ooool>ob/[:`ko;Rh^3OlE5AD=oadM7@Kooooo3_l71`L>obHV9PgoKFe]3Oo;bl/6ooooo`ko1@D5
3_lE5AD=ocHf=PgoJf][1_ooool>oe1@D0go<30`3_l@410=oa4A4@Kooooo3_l0000=oa<C4`ko=3@d
3OlT92@Dooooo`go^k^k3_lF5QH=o`0000Kooooo3Om=CDd>oc@d=0ko2@T93OlU9BD>ooooo`003?oo
ool>o`P820ko6a/K3Oln?Sh=oalO7`Kooooo3_l[:b/>obh^;Pgo5ADE3OlM7Ad6ooooo`ko1`L73_lV
9RH=ofe]K@gobl_;1_ooool>o`D51@ko5ADE3Olf=SH=of][J`Kooooo3_m@D50=oc0`<0ko410@3OlA
4A46ooooo`ko00003OlC4a<>oc@d=0go92@T5?ooool=ok^k^`ko5QHF3Ol00006ooooo`goCDe=3_ld
=3@>o`T92@go9BDU3_ooool000cooooo3_l820P>oa/K6`go?Shn3OlO7al6ooooo`ko:b/[3_l^;Rh=
oaDE5@go7AdM1_ooool>o`L71`ko9RHV3Om]KFd=ol_;b`Kooooo3_l51@D>oaDE5@go=SHf3Om[Jf/6
ooooo`koD51@3Ol`<30>oa0@40go4A4A1_ooool>o`0000go4a<C3_ld=3@=ob@T91Cooooo3Onk^k/>
oaHF5Pgo00001_ooool=ode=C@ko=3@d3_l92@T=obDU9@kooooo000<ooooo`ko20P83_lK6a/=ochn
?Pgo7alO1_ooool>ob/[:`ko;Rh^3OlE5AD=oadM7@Kooooo3_l71`L>obHV9PgoKFe]3Oo;bl/6oooo
o`ko1@D53_lE5AD=ocHf=PgoJf][1_ooool>oe1@D0go<30`3_l@410=oa4A4@Kooooo3_l0000=oa<C
4`ko=3@d3OlT92@Dooooo`go^k^k3_lF5QH=o`0000Kooooo3Om=CDd>oc@d=0ko2@T93OlU9BD>oooo
o`003?ooool>o`P820ko6a/K3Oln?Sh=oalO7`Kooooo3_l[:b/>obh^;Pgo5ADE3OlM7Ad6ooooo`ko
1`L73_lV9RH=ofe]K@gobl_;1_ooool>o`D51@ko5ADE3Olf=SH=of][J`Kooooo3_m@D50=oc0`<0ko
410@3OlA4A46ooooo`ko00003OlC4a<>oc@d=0go92@T5?ooool=ok^k^`ko5QHF3Ol00006ooooo`go
CDe=3_ld=3@>o`T92@go9BDU3_ooool000cooooo3_l820P>oa/K6`go?Shn3OlO7al6ooooo`ko:b/[
3_l^;Rh=oaDE5@go7AdM1_ooool>o`L71`ko9RHV3Om]KFd=ol_;b`Kooooo3_l51@D>oaDE5@go=SHf
3Om[Jf/6ooooo`koD51@3Ol`<30>oa0@40go4A4A1_ooool>o`0000go4a<C3_ld=3@=ob@T91Cooooo
3Onk^k/>oaHF5Pgo00001_ooool=ode=C@ko=3@d3_l92@T=obDU9@kooooo000<ooooo`ko20P83_lK
6a/=ochn?Pgo7alO1_ooool>ob/[:`ko;Rh^3OlE5AD=oadM7@Kooooo3_l71`L>obHV9PgoKFe]3Oo;
bl/6ooooo`ko1@D53_lE5AD=ocHf=PgoJf][1_ooool>oe1@D0go<30`3_l@410=oa4A4@Kooooo3_l0
000=oa<C4`ko=3@d3OlT92@Dooooo`go^k^k3_lF5QH=o`0000Kooooo3Om=CDd>oc@d=0ko2@T93OlU
9BD>ooooo`003?ooool>o`P820ko6a/K3Oln?Sh=oalO7`Kooooo3_l[:b/>obh^;Pgo5ADE3OlM7Ad6
ooooo`ko1`L73_lV9RH=ofe]K@gobl_;1_ooool>o`D51@ko5ADE3Olf=SH=of][J`Kooooo3_m@D50=
oc0`<0ko410@3OlA4A46ooooo`ko00003OlC4a<>oc@d=0go92@T5?ooool=ok^k^`ko5QHF3Ol00006
ooooo`goCDe=3_ld=3@>o`T92@go9BDU3_ooool000cooooo3_l820P>oa/K6`go?Shn3OlO7al6oooo
o`ko:b/[3_l^;Rh=oaDE5@go7AdM1_ooool>o`L71`ko9RHV3Om]KFd=ol_;b`Kooooo3_l51@D>oaDE
5@go=SHf3Om[Jf/6ooooo`koD51@3Ol`<30>oa0@40go4A4A1_ooool>o`0000go4a<C3_ld=3@=ob@T
91Cooooo3Onk^k/>oaHF5Pgo00001_ooool=ode=C@ko=3@d3_l92@T=obDU9@kooooo000<ooooo`ko
20P83_lK6a/=ochn?Pgo7alO1_ooool>ob/[:`ko;Rh^3OlE5AD=oadM7@Kooooo3_l71`L>obHV9Pgo
KFe]3Oo;bl/6ooooo`ko1@D53_lE5AD=ocHf=PgoJf][1_ooool>oe1@D0go<30`3_l@410=oa4A4@Ko
oooo3_l0000=oa<C4`ko=3@d3OlT92@Dooooo`go^k^k3_lF5QH=o`0000Kooooo3Om=CDd>oc@d=0ko
2@T93OlU9BD>ooooo`003?ooool>o`P820ko6a/K3Oln?Sh=oalO7`Kooooo3_l[:b/>obh^;Pgo5ADE
3OlM7Ad6ooooo`ko1`L73_lV9RH=ofe]K@gobl_;1_ooool>o`D51@ko5ADE3Olf=SH=of][J`Kooooo
3_m@D50=oc0`<0ko410@3OlA4A46ooooo`ko00003OlC4a<>oc@d=0go92@T5?ooool=ok^k^`ko5QHF
3Ol00006ooooo`goCDe=3_ld=3@>o`T92@go9BDU3_ooool000cooooo3_l820P>oa/K6`go?Shn3OlO
7al6ooooo`ko:b/[3_l^;Rh=oaDE5@go7AdM1_ooool>o`L71`ko9RHV3Om]KFd=ol_;b`Kooooo3_l5
1@D>oaDE5@go=SHf3Om[Jf/6ooooo`koD51@3Ol`<30>oa0@40go4A4A1_ooool>o`0000go4a<C3_ld
=3@=ob@T91Cooooo3Onk^k/>oaHF5Pgo00001_ooool=ode=C@ko=3@d3_l92@T=obDU9@kooooo000<
ooooo`ko20P83_lK6a/=ochn?Pgo7alO1_ooool>ob/[:`ko;Rh^3OlE5AD=oadM7@Kooooo3_l71`L>
obHV9PgoKFe]3Oo;bl/6ooooo`ko1@D53_lE5AD=ocHf=PgoJf][1_ooool>oe1@D0go<30`3_l@410=
oa4A4@Kooooo3_l0000=oa<C4`ko=3@d3OlT92@Dooooo`go^k^k3_lF5QH=o`0000Kooooo3Om=CDd>
oc@d=0ko2@T93OlU9BD>ooooo`003?oooolLo`X:2Pgo<C4a3Ol61PH6ooooo`ko_Kfm3_ooool=ocPh
>0go2`/;1_ooool>oa@D50ko00003Ol`<30=od];B`Kooooo3_lg=cL>oadM7@go:RXZ3OnVYZH6oooo
o`ko6a/K3Om9BDT>o`/;2`go00001_ooool>oaPH60go@4103_ooool=om[JfPKooooo3_l@410=ob4Q
8@ko10@43Ol:2PX6ooooo`go9BDU3_l[:b/>o`0000go3`l?3_ooool000cooooo7?l:2PX=oc4a<@go
1PH61_ooool>okfm_@kooooo3Olh>3P=o`/;2`Kooooo3_lD51@>o`0000go<30`3Om;Bd/6ooooo`ko
=cLg3_lM7Ad=obXZ:PgoYZJV1_ooool>oa/K6`goBDU93_l;2`/=o`0000Kooooo3_lH61P=od10@0ko
oooo3OoJf]X6ooooo`ko410@3OlQ8B4>o`@410go2PX:1_ooool=obDU9@ko:b/[3_l0000=o`l?3`ko
oooo000<oooooaco2PX:3Ola<C4=o`H61PKooooo3_nm_Kd>ooooo`go>3Ph3Ol;2`/6ooooo`ko51@D
3_l0000=oc0`<0goBd];1_ooool>ocLg=`ko7AdM3OlZ:RX=ojJVYPKooooo3_lK6a/=odU9B@ko2`/;
3Ol00006ooooo`ko61PH3Om0@40>ooooo`gof][J1_ooool>oa0@40go8B4Q3_l410@=o`X:2PKooooo
3OlU9BD>ob/[:`ko00003Ol?3`l>ooooo`003?oooolLo`X:2Pgo<C4a3Ol61PH6ooooo`ko_Kfm3_oo
ool=ocPh>0go2`/;1_ooool>oa@D50ko00003Ol`<30=od];B`Kooooo3_lg=cL>oadM7@go:RXZ3OnV
YZH6ooooo`ko6a/K3Om9BDT>o`/;2`go00001_ooool>oaPH60go@4103_ooool=om[JfPKooooo3_l@
410=ob4Q8@ko10@43Ol:2PX6ooooo`go9BDU3_l[:b/>o`0000go3`l?3_ooool000cooooo7?l:2PX=
oc4a<@go1PH61_ooool>okfm_@kooooo3Olh>3P=o`/;2`Kooooo3_lD51@>o`0000go<30`3Om;Bd/6
ooooo`ko=cLg3_lM7Ad=obXZ:PgoYZJV1_ooool>oa/K6`goBDU93_l;2`/=o`0000Kooooo3_lH61P=
od10@0kooooo3OoJf]X6ooooo`ko410@3OlQ8B4>o`@410go2PX:1_ooool=obDU9@ko:b/[3_l0000=
o`l?3`kooooo000<oooooaco2PX:3Ola<C4=o`H61PKooooo3_nm_Kd>ooooo`go>3Ph3Ol;2`/6oooo
o`ko51@D3_l0000=oc0`<0goBd];1_ooool>ocLg=`ko7AdM3OlZ:RX=ojJVYPKooooo3_lK6a/=odU9
B@ko2`/;3Ol00006ooooo`ko61PH3Om0@40>ooooo`gof][J1_ooool>oa0@40go8B4Q3_l410@=o`X:
2PKooooo3OlU9BD>ob/[:`ko00003Ol?3`l>ooooo`003?oooolLo`X:2Pgo<C4a3Ol61PH6ooooo`ko
_Kfm3_ooool=ocPh>0go2`/;1_ooool>oa@D50ko00003Ol`<30=od];B`Kooooo3_lg=cL>oadM7@go
:RXZ3OnVYZH6ooooo`ko6a/K3Om9BDT>o`/;2`go00001_ooool>oaPH60go@4103_ooool=om[JfPKo
oooo3_l@410=ob4Q8@ko10@43Ol:2PX6ooooo`go9BDU3_l[:b/>o`0000go3`l?3_ooool000cooooo
7?l:2PX=oc4a<@go1PH61_ooool>okfm_@kooooo3Olh>3P=o`/;2`Kooooo3_lD51@>o`0000go<30`
3Om;Bd/6ooooo`ko=cLg3_lM7Ad=obXZ:PgoYZJV1_ooool>oa/K6`goBDU93_l;2`/=o`0000Kooooo
3_lH61P=od10@0kooooo3OoJf]X6ooooo`ko410@3OlQ8B4>o`@410go2PX:1_ooool=obDU9@ko:b/[
3_l0000=o`l?3`kooooo000<oooooaco2PX:3Ola<C4=o`H61PKooooo3_nm_Kd>ooooo`go>3Ph3Ol;
2`/6ooooo`ko51@D3_l0000=oc0`<0goBd];1_ooool>ocLg=`ko7AdM3OlZ:RX=ojJVYPKooooo3_lK
6a/=odU9B@ko2`/;3Ol00006ooooo`ko61PH3Om0@40>ooooo`gof][J1_ooool>oa0@40go8B4Q3_l4
10@=o`X:2PKooooo3OlU9BD>ob/[:`ko00003Ol?3`l>ooooo`003?oooolLo`X:2Pgo<C4a3Ol61PH6
ooooo`ko_Kfm3_ooool=ocPh>0go2`/;1_ooool>oa@D50ko00003Ol`<30=od];B`Kooooo3_lg=cL>
oadM7@go:RXZ3OnVYZH6ooooo`ko6a/K3Om9BDT>o`/;2`go00001_ooool>oaPH60go@4103_ooool=
om[JfPKooooo3_l@410=ob4Q8@ko10@43Ol:2PX6ooooo`go9BDU3_l[:b/>o`0000go3`l?3_ooool0
00cooooo7?l:2PX=oc4a<@go1PH61_ooool>okfm_@kooooo3Olh>3P=o`/;2`Kooooo3_lD51@>o`00
00go<30`3Om;Bd/6ooooo`ko=cLg3_lM7Ad=obXZ:PgoYZJV1_ooool>oa/K6`goBDU93_l;2`/=o`00
00Kooooo3_lH61P=od10@0kooooo3OoJf]X6ooooo`ko410@3OlQ8B4>o`@410go2PX:1_ooool=obDU
9@ko:b/[3_l0000=o`l?3`kooooo000<oooooaco2PX:3Ola<C4=o`H61PKooooo3_nm_Kd>ooooo`go
>3Ph3Ol;2`/6ooooo`ko51@D3_l0000=oc0`<0goBd];1_ooool>ocLg=`ko7AdM3OlZ:RX=ojJVYPKo
oooo3_lK6a/=odU9B@ko2`/;3Ol00006ooooo`ko61PH3Om0@40>ooooo`gof][J1_ooool>oa0@40go
8B4Q3_l410@=o`X:2PKooooo3OlU9BD>ob/[:`ko00003Ol?3`l>ooooo`003?oooolLo`X:2Pgo<C4a
3Ol61PH6ooooo`ko_Kfm3_ooool=ocPh>0go2`/;1_ooool>oa@D50ko00003Ol`<30=od];B`Kooooo
3_lg=cL>oadM7@go:RXZ3OnVYZH6ooooo`ko6a/K3Om9BDT>o`/;2`go00001_ooool>oaPH60go@410
3_ooool=om[JfPKooooo3_l@410=ob4Q8@ko10@43Ol:2PX6ooooo`go9BDU3_l[:b/>o`0000go3`l?
3_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_oo
ool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Ooo
ool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol4
10@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6
ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>
o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=
ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool0
00cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c
<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l
?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6oooo
o`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko
9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go
<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Ko
oooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo
3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C
3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=
1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K
3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4
A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmH
F5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l5
1@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>
o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=
ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>
oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>
oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH
60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6oooo
o`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L
70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go
:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Ko
oooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go
?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go
0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go0000
1_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi
3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A4
3Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<
30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU
9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT
92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_oo
ool000cooooo3_l820P>o`0000go:b/[3Ol<30`6ooooo`ko9bLW3_m4A4@=oaPH60go00001_ooool>
oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`0000go<30`3OmHF5P6ooooo`ko>CTi3Oooool>
oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6
ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000cooooo3_l820P>o`0000go:b/[3Ol<30`6oooo
o`ko9bLW3_m4A4@=oaPH60go00001_ooool>oc<c<`ko4a<C3OlM7Ad=ob4Q8@Kooooo3_lU9BD>o`00
00go<30`3OmHF5P6ooooo`ko>CTi3Oooool>oc`l?0goCDe=1_ooool>oa<C4`go?3`l3_lT92@=ocLg
=`Kooooo3_l51@D=oa`L70koA4A43Ol410@6ooooo`go6a/K3_lQ8B4>oaLG5`go0P823_ooool000co
oooo3_l<30`>oa0@40gooooo3OlD51@6ooooo`ko?Shn3_lT92@=obDU9@goADE51_ooool>oaDE5@ko
Fe]K3OmkNg/Cooooo`ko3`l?3_lT92@=ooooo`go30`<1_ooool>o`@410go0@413_l20P8=o``<30Ko
oooo3_lo?cl=obh^;Pko10@43Ol/;2`6ooooo`ko?Cdm3OlL71`>obHV9Pgo5QHF1_ooool=ojRXZ0ko
oooo3_lC4a<=oeEEE@kooooo000<ooooo`ko30`<3_l@410=ooooo`go51@D1_ooool>ochn?Pko92@T
3OlU9BD=odE5A@Kooooo3_lE5AD>oe]KF`goNg]k4oooool>o`l?3`ko92@T3Oooool=o``<30Kooooo
3_l410@=o`410@ko0P823Ol<30`6ooooo`ko?clo3Ol^;Rh>o`@410go;2`/1_ooool>ocdm?@go71`L
3_lV9RH=oaHF5PKooooo3OnXZ:P>ooooo`ko4a<C3OmEEED>ooooo`003?ooool>o``<30ko410@3Ooo
ool=oa@D50Kooooo3_ln?Sh>ob@T90go9BDU3Om5ADD6ooooo`ko5ADE3_mKFe/=og]kNa?ooooo3_l?
3`l>ob@T90gooooo3Ol<30`6ooooo`ko10@43Ol10@4>o`820Pgo30`<1_ooool>oclo?`go;Rh^3_l4
10@=ob`/;0Kooooo3_lm?Cd=oa`L70ko9RHV3OlF5QH6ooooo`goZ:RX3_ooool>oa<C4`goEEEE3_oo
ool000cooooo3_l<30`>oa0@40gooooo3OlD51@6ooooo`ko?Shn3_lT92@=obDU9@goADE51_ooool>
oaDE5@koFe]K3OmkNg/Cooooo`ko3`l?3_lT92@=ooooo`go30`<1_ooool>o`@410go0@413_l20P8=
o``<30Kooooo3_lo?cl=obh^;Pko10@43Ol/;2`6ooooo`ko?Cdm3OlL71`>obHV9Pgo5QHF1_ooool=
ojRXZ0kooooo3_lC4a<=oeEEE@kooooo000<ooooo`ko30`<3_l@410=ooooo`go51@D1_ooool>ochn
?Pko92@T3OlU9BD=odE5A@Kooooo3_lE5AD>oe]KF`goNg]k4oooool>o`l?3`ko92@T3Oooool=o``<
30Kooooo3_l410@=o`410@ko0P823Ol<30`6ooooo`ko?clo3Ol^;Rh>o`@410go;2`/1_ooool>ocdm
?@go71`L3_lV9RH=oaHF5PKooooo3OnXZ:P>ooooo`ko4a<C3OmEEED>ooooo`003?ooool>o``<30ko
410@3Oooool=oa@D50Kooooo3_ln?Sh>ob@T90go9BDU3Om5ADD6ooooo`ko5ADE3_mKFe/=og]kNa?o
oooo3_l?3`l>ob@T90gooooo3Ol<30`6ooooo`ko10@43Ol10@4>o`820Pgo30`<1_ooool>oclo?`go
;Rh^3_l410@=ob`/;0Kooooo3_lm?Cd=oa`L70ko9RHV3OlF5QH6ooooo`goZ:RX3_ooool>oa<C4`go
EEEE3_ooool000cooooo3_l<30`>oa0@40gooooo3OlD51@6ooooo`ko?Shn3_lT92@=obDU9@goADE5
1_ooool>oaDE5@koFe]K3OmkNg/Cooooo`ko3`l?3_lT92@=ooooo`go30`<1_ooool>o`@410go0@41
3_l20P8=o``<30Kooooo3_lo?cl=obh^;Pko10@43Ol/;2`6ooooo`ko?Cdm3OlL71`>obHV9Pgo5QHF
1_ooool=ojRXZ0kooooo3_lC4a<=oeEEE@kooooo000<ooooo`ko30`<3_l@410=ooooo`go51@D1_oo
ool>ochn?Pko92@T3OlU9BD=odE5A@Kooooo3_lE5AD>oe]KF`goNg]k4oooool>o`l?3`ko92@T3Ooo
ool=o``<30Kooooo3_l410@=o`410@ko0P823Ol<30`6ooooo`ko?clo3Ol^;Rh>o`@410go;2`/1_oo
ool>ocdm?@go71`L3_lV9RH=oaHF5PKooooo3OnXZ:P>ooooo`ko4a<C3OmEEED>ooooo`003?ooool>
o``<30ko410@3Oooool=oa@D50Kooooo3_ln?Sh>ob@T90go9BDU3Om5ADD6ooooo`ko5ADE3_mKFe/=
og]kNa?ooooo3_l?3`l>ob@T90gooooo3Ol<30`6ooooo`ko10@43Ol10@4>o`820Pgo30`<1_ooool>
oclo?`go;Rh^3_l410@=ob`/;0Kooooo3_lm?Cd=oa`L70ko9RHV3OlF5QH6ooooo`goZ:RX3_ooool>
oa<C4`goEEEE3_ooool000cooooo3_l<30`>oa0@40gooooo3OlD51@6ooooo`ko?Shn3_lT92@=obDU
9@goADE51_ooool>oaDE5@koFe]K3OmkNg/Cooooo`ko3`l?3_lT92@=ooooo`go30`<1_ooool>o`@4
10go0@413_l20P8=o``<30Kooooo3_lo?cl=obh^;Pko10@43Ol/;2`6ooooo`ko?Cdm3OlL71`>obHV
9Pgo5QHF1_ooool=ojRXZ0kooooo3_lC4a<=oeEEE@kooooo000<ooooo`ko30`<3_l@410=ooooo`go
51@D1_ooool>ochn?Pko92@T3OlU9BD=odE5A@Kooooo3_lE5AD>oe]KF`goNg]k4oooool>o`l?3`ko
92@T3Oooool=o``<30Kooooo3_l410@=o`410@ko0P823Ol<30`6ooooo`ko?clo3Ol^;Rh>o`@410go
;2`/1_ooool>ocdm?@go71`L3_lV9RH=oaHF5PKooooo3OnXZ:P>ooooo`ko4a<C3OmEEED>ooooo`00
3?ooool>o``<30ko410@3Oooool=oa@D50Kooooo3_ln?Sh>ob@T90go9BDU3Om5ADD6ooooo`ko5ADE
3_mKFe/=og]kNa?ooooo3_l?3`l>ob@T90gooooo3Ol<30`6ooooo`ko10@43Ol10@4>o`820Pgo30`<
1_ooool>oclo?`go;Rh^3_l410@=ob`/;0Kooooo3_lm?Cd=oa`L70ko9RHV3OlF5QH6ooooo`goZ:RX
3_ooool>oa<C4`goEEEE3_ooool000cooooo3_l<30`>oa0@40gooooo3OlD51@6ooooo`ko?Shn3_lT
92@=obDU9@goADE51_ooool>oaDE5@koFe]K3OmkNg/Cooooo`ko3`l?3_lT92@=ooooo`go30`<1_oo
ool>o`@410go0@413_l20P8=o``<30Kooooo3_lo?cl=obh^;Pko10@43Ol/;2`6ooooo`ko?Cdm3OlL
71`>obHV9Pgo5QHF1_ooool=ojRXZ0kooooo3_lC4a<=oeEEE@kooooo000<ooooo`ko30`<3_l@410=
ooooo`go51@D1_ooool>ochn?Pko92@T3OlU9BD=odE5A@Kooooo3_lE5AD>oe]KF`goNg]k4oooool>
o`l?3`ko92@T3Oooool=o``<30Kooooo3_l410@=o`410@ko0P823Ol<30`6ooooo`ko?clo3Ol^;Rh>
o`@410go;2`/1_ooool>ocdm?@go71`L3_lV9RH=oaHF5PKooooo3OnXZ:P>ooooo`ko4a<C3OmEEED>
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool>oe9BDPko51@D3OlC4a<=o`820PKooooo3_l0000Ko`<30`go
51@D1_ooool>oa`L70koOGem3Om[Jf/=ooKfmPKooooo3_lT92@>oaXJ6Pgo;Bd]3Ol51@D6ooooo`ko
51@D3OlL71`>oaTI6@goDe=C1_ooool>obl_;`go6ATI3_ooool=oeUIF@Kooooo3_l;2`/=o`l?3`ko
2`/;3Om;Bd/6ooooo`go4A4A3_l92@T>o`0000go0P823_ooool000cooooo3_mBDU8>oa@D50go4a<C
3Ol20P86ooooo`ko00006ol30`<=oa@D50Kooooo3_lL71`>ogemO@goJf][3Oofm_H6ooooo`ko92@T
3_lJ6QX=obd];@go1@D51_ooool>oa@D50go71`L3_lI6AT=oe=CD`Kooooo3_l_;bl=oaTI6@kooooo
3OmIFET6ooooo`ko2`/;3Ol?3`l>o`/;2`goBd];1_ooool=oa4A4@ko2@T93_l0000=o`820Pkooooo
000<ooooo`koDU9B3_lD51@=oa<C4`go0P821_ooool>o`0001_o0`<33OlD51@6ooooo`ko71`L3_mm
OGd=of][J`gom_Kf1_ooool>ob@T90ko6QXJ3Ol];Bd=o`D51@Kooooo3_lD51@=oa`L70ko6ATI3OmC
De<6ooooo`ko;bl_3OlI6AT>ooooo`goFEUI1_ooool>o`/;2`go3`l?3_l;2`/=od];B`Kooooo3OlA
4A4>o`T92@ko00003Ol20P8>ooooo`003?ooool>oe9BDPko51@D3OlC4a<=o`820PKooooo3_l0000K
o`<30`go51@D1_ooool>oa`L70koOGem3Om[Jf/=ooKfmPKooooo3_lT92@>oaXJ6Pgo;Bd]3Ol51@D6
ooooo`ko51@D3OlL71`>oaTI6@goDe=C1_ooool>obl_;`go6ATI3_ooool=oeUIF@Kooooo3_l;2`/=
o`l?3`ko2`/;3Om;Bd/6ooooo`go4A4A3_l92@T>o`0000go0P823_ooool000cooooo3_mBDU8>oa@D
50go4a<C3Ol20P86ooooo`ko00006ol30`<=oa@D50Kooooo3_lL71`>ogemO@goJf][3Oofm_H6oooo
o`ko92@T3_lJ6QX=obd];@go1@D51_ooool>oa@D50go71`L3_lI6AT=oe=CD`Kooooo3_l_;bl=oaTI
6@kooooo3OmIFET6ooooo`ko2`/;3Ol?3`l>o`/;2`goBd];1_ooool=oa4A4@ko2@T93_l0000=o`82
0Pkooooo000<ooooo`koDU9B3_lD51@=oa<C4`go0P821_ooool>o`0001_o0`<33OlD51@6ooooo`ko
71`L3_mmOGd=of][J`gom_Kf1_ooool>ob@T90ko6QXJ3Ol];Bd=o`D51@Kooooo3_lD51@=oa`L70ko
6ATI3OmCDe<6ooooo`ko;bl_3OlI6AT>ooooo`goFEUI1_ooool>o`/;2`go3`l?3_l;2`/=od];B`Ko
oooo3OlA4A4>o`T92@ko00003Ol20P8>ooooo`003?ooool>oe9BDPko51@D3OlC4a<=o`820PKooooo
3_l0000Ko`<30`go51@D1_ooool>oa`L70koOGem3Om[Jf/=ooKfmPKooooo3_lT92@>oaXJ6Pgo;Bd]
3Ol51@D6ooooo`ko51@D3OlL71`>oaTI6@goDe=C1_ooool>obl_;`go6ATI3_ooool=oeUIF@Kooooo
3_l;2`/=o`l?3`ko2`/;3Om;Bd/6ooooo`go4A4A3_l92@T>o`0000go0P823_ooool000cooooo3_mB
DU8>oa@D50go4a<C3Ol20P86ooooo`ko00006ol30`<=oa@D50Kooooo3_lL71`>ogemO@goJf][3Oof
m_H6ooooo`ko92@T3_lJ6QX=obd];@go1@D51_ooool>oa@D50go71`L3_lI6AT=oe=CD`Kooooo3_l_
;bl=oaTI6@kooooo3OmIFET6ooooo`ko2`/;3Ol?3`l>o`/;2`goBd];1_ooool=oa4A4@ko2@T93_l0
000=o`820Pkooooo000<ooooo`koDU9B3_lD51@=oa<C4`go0P821_ooool>o`0001_o0`<33OlD51@6
ooooo`ko71`L3_mmOGd=of][J`gom_Kf1_ooool>ob@T90ko6QXJ3Ol];Bd=o`D51@Kooooo3_lD51@=
oa`L70ko6ATI3OmCDe<6ooooo`ko;bl_3OlI6AT>ooooo`goFEUI1_ooool>o`/;2`go3`l?3_l;2`/=
od];B`Kooooo3OlA4A4>o`T92@ko00003Ol20P8>ooooo`003?ooool>oe9BDPko51@D3OlC4a<=o`82
0PKooooo3_l0000Ko`<30`go51@D1_ooool>oa`L70koOGem3Om[Jf/=ooKfmPKooooo3_lT92@>oaXJ
6Pgo;Bd]3Ol51@D6ooooo`ko51@D3OlL71`>oaTI6@goDe=C1_ooool>obl_;`go6ATI3_ooool=oeUI
F@Kooooo3_l;2`/=o`l?3`ko2`/;3Om;Bd/6ooooo`go4A4A3_l92@T>o`0000go0P823_ooool000co
oooo3_mBDU8>oa@D50go4a<C3Ol20P86ooooo`ko00006ol30`<=oa@D50Kooooo3_lL71`>ogemO@go
Jf][3Oofm_H6ooooo`ko92@T3_lJ6QX=obd];@go1@D51_ooool>oa@D50go71`L3_lI6AT=oe=CD`Ko
oooo3_l_;bl=oaTI6@kooooo3OmIFET6ooooo`ko2`/;3Ol?3`l>o`/;2`goBd];1_ooool=oa4A4@ko
2@T93_l0000=o`820Pkooooo000<ooooo`koDU9B3_lD51@=oa<C4`go0P821_ooool>o`0001_o0`<3
3OlD51@6ooooo`ko71`L3_mmOGd=of][J`gom_Kf1_ooool>ob@T90ko6QXJ3Ol];Bd=o`D51@Kooooo
3_lD51@=oa`L70ko6ATI3OmCDe<6ooooo`ko;bl_3OlI6AT>ooooo`goFEUI1_ooool>o`/;2`go3`l?
3_l;2`/=od];B`Kooooo3OlA4A4>o`T92@ko00003Ol20P8>ooooo`003?ooool>oe9BDPko51@D3OlC
4a<=o`820PKooooo3_l0000Ko`<30`go51@D1_ooool>oa`L70koOGem3Om[Jf/=ooKfmPKooooo3_lT
92@>oaXJ6Pgo;Bd]3Ol51@D6ooooo`ko51@D3OlL71`>oaTI6@goDe=C1_ooool>obl_;`go6ATI3_oo
ool=oeUIF@Kooooo3_l;2`/=o`l?3`ko2`/;3Om;Bd/6ooooo`go4A4A3_l92@T>o`0000go0P823_oo
ool000cooooo3_mBDU8>oa@D50go4a<C3Ol20P86ooooo`ko00006ol30`<=oa@D50Kooooo3_lL71`>
ogemO@goJf][3Oofm_H6ooooo`ko92@T3_lJ6QX=obd];@go1@D51_ooool>oa@D50go71`L3_lI6AT=
oe=CD`Kooooo3_l_;bl=oaTI6@kooooo3OmIFET6ooooo`ko2`/;3Ol?3`l>o`/;2`goBd];1_ooool=
oa4A4@ko2@T93_l0000=o`820Pkooooo000<ooooo`ko61PH3_l@410=o`/;2`go1@D51_ooool>oaHF
5Pko92@T3Ol=3@d=oalO7`Kooooo3_l0000>ocXj>PgoRh^;4oooool>oaXJ6Pko4a<C3Ol51@D=o`00
00Kooooo3_lM7Ad=oclo?`koCTi>4oooool>o`0000go10@43_lP820=o`X:2PKooooo3_lQ8B4=ob0P
80ko4A4A3Ol@4106ooooo`go20P83_lL71`>o`h>3Pgo4A4A3_ooool000cooooo3_lH61P>oa0@40go
2`/;3Ol51@D6ooooo`ko5QHF3_lT92@=o`d=3@go7alO1_ooool>o`0000ko>SXj3On;Rh/Cooooo`ko
6QXJ3_lC4a<=o`D51@go00001_ooool>oadM7@go?clo3_m>CThCooooo`ko00003Ol410@>ob0P80go
2PX:1_ooool>ob4Q8@go820P3_lA4A4=oa0@40Kooooo3Ol820P>oa`L70ko3Ph>3OlA4A4>ooooo`00
3?ooool>oaPH60ko410@3Ol;2`/=o`D51@Kooooo3_lF5QH>ob@T90go3@d=3OlO7al6ooooo`ko0000
3_lj>SX=oh^;Ra?ooooo3_lJ6QX>oa<C4`go1@D53Ol00006ooooo`ko7AdM3Olo?cl>odi>CQ?ooooo
3_l0000=o`@410ko820P3Ol:2PX6ooooo`ko8B4Q3OlP820>oa4A4@go410@1_ooool=o`P820ko71`L
3_l>3Ph=oa4A4@kooooo000<ooooo`ko61PH3_l@410=o`/;2`go1@D51_ooool>oaHF5Pko92@T3Ol=
3@d=oalO7`Kooooo3_l0000>ocXj>PgoRh^;4oooool>oaXJ6Pko4a<C3Ol51@D=o`0000Kooooo3_lM
7Ad=oclo?`koCTi>4oooool>o`0000go10@43_lP820=o`X:2PKooooo3_lQ8B4=ob0P80ko4A4A3Ol@
4106ooooo`go20P83_lL71`>o`h>3Pgo4A4A3_ooool000cooooo3_lH61P>oa0@40go2`/;3Ol51@D6
ooooo`ko5QHF3_lT92@=o`d=3@go7alO1_ooool>o`0000ko>SXj3On;Rh/Cooooo`ko6QXJ3_lC4a<=
o`D51@go00001_ooool>oadM7@go?clo3_m>CThCooooo`ko00003Ol410@>ob0P80go2PX:1_ooool>
ob4Q8@go820P3_lA4A4=oa0@40Kooooo3Ol820P>oa`L70ko3Ph>3OlA4A4>ooooo`003?ooool>oaPH
60ko410@3Ol;2`/=o`D51@Kooooo3_lF5QH>ob@T90go3@d=3OlO7al6ooooo`ko00003_lj>SX=oh^;
Ra?ooooo3_lJ6QX>oa<C4`go1@D53Ol00006ooooo`ko7AdM3Olo?cl>odi>CQ?ooooo3_l0000=o`@4
10ko820P3Ol:2PX6ooooo`ko8B4Q3OlP820>oa4A4@go410@1_ooool=o`P820ko71`L3_l>3Ph=oa4A
4@kooooo000<ooooo`ko61PH3_l@410=o`/;2`go1@D51_ooool>oaHF5Pko92@T3Ol=3@d=oalO7`Ko
oooo3_l0000>ocXj>PgoRh^;4oooool>oaXJ6Pko4a<C3Ol51@D=o`0000Kooooo3_lM7Ad=oclo?`ko
CTi>4oooool>o`0000go10@43_lP820=o`X:2PKooooo3_lQ8B4=ob0P80ko4A4A3Ol@4106ooooo`go
20P83_lL71`>o`h>3Pgo4A4A3_ooool000cooooo3_lH61P>oa0@40go2`/;3Ol51@D6ooooo`ko5QHF
3_lT92@=o`d=3@go7alO1_ooool>o`0000ko>SXj3On;Rh/Cooooo`ko6QXJ3_lC4a<=o`D51@go0000
1_ooool>oadM7@go?clo3_m>CThCooooo`ko00003Ol410@>ob0P80go2PX:1_ooool>ob4Q8@go820P
3_lA4A4=oa0@40Kooooo3Ol820P>oa`L70ko3Ph>3OlA4A4>ooooo`003?ooool>oaPH60ko410@3Ol;
2`/=o`D51@Kooooo3_lF5QH>ob@T90go3@d=3OlO7al6ooooo`ko00003_lj>SX=oh^;Ra?ooooo3_lJ
6QX>oa<C4`go1@D53Ol00006ooooo`ko7AdM3Olo?cl>odi>CQ?ooooo3_l0000=o`@410ko820P3Ol:
2PX6ooooo`ko8B4Q3OlP820>oa4A4@go410@1_ooool=o`P820ko71`L3_l>3Ph=oa4A4@kooooo000<
ooooo`ko61PH3_l@410=o`/;2`go1@D51_ooool>oaHF5Pko92@T3Ol=3@d=oalO7`Kooooo3_l0000>
ocXj>PgoRh^;4oooool>oaXJ6Pko4a<C3Ol51@D=o`0000Kooooo3_lM7Ad=oclo?`koCTi>4oooool>
o`0000go10@43_lP820=o`X:2PKooooo3_lQ8B4=ob0P80ko4A4A3Ol@4106ooooo`go20P83_lL71`>
o`h>3Pgo4A4A3_ooool000cooooo3_lH61P>oa0@40go2`/;3Ol51@D6ooooo`ko5QHF3_lT92@=o`d=
3@go7alO1_ooool>o`0000ko>SXj3On;Rh/Cooooo`ko6QXJ3_lC4a<=o`D51@go00001_ooool>oadM
7@go?clo3_m>CThCooooo`ko00003Ol410@>ob0P80go2PX:1_ooool>ob4Q8@go820P3_lA4A4=oa0@
40Kooooo3Ol820P>oa`L70ko3Ph>3OlA4A4>ooooo`003?ooool>oaPH60ko410@3Ol;2`/=o`D51@Ko
oooo3_lF5QH>ob@T90go3@d=3OlO7al6ooooo`ko00003_lj>SX=oh^;Ra?ooooo3_lJ6QX>oa<C4`go
1@D53Ol00006ooooo`ko7AdM3Olo?cl>odi>CQ?ooooo3_l0000=o`@410ko820P3Ol:2PX6ooooo`ko
8B4Q3OlP820>oa4A4@go410@1_ooool=o`P820ko71`L3_l>3Ph=oa4A4@kooooo000<ooooo`ko61PH
3_l@410=o`/;2`go1@D51_ooool>oaHF5Pko92@T3Ol=3@d=oalO7`Kooooo3_l0000>ocXj>PgoRh^;
4oooool>oaXJ6Pko4a<C3Ol51@D=o`0000Kooooo3_lM7Ad=oclo?`koCTi>4oooool>o`0000go10@4
3_lP820=o`X:2PKooooo3_lQ8B4=ob0P80ko4A4A3Ol@4106ooooo`go20P83_lL71`>o`h>3Pgo4A4A
3_ooool000cooooo3_l<30`>o`410@go0P823Ol>3PhDooooo`koOWin3Ol:2PX=oaLG5`Kooooo3_l;
2`/>oa<C4`goJVYZ3On^[Zh6ooooo`ko?Cdm3_l61PH=o`0000go0P821_ooool>o`H61Pgo00003_mB
DU8Cooooo`ko7AdM3OlF5QH>o``<30go3@d=1_ooool>ob@T90go=SHf3_l0000=o`T92@Kooooo3OlH
61P>oalO7`koEeMG3Ole=CD>ooooo`003?ooool>o``<30ko0@413Ol20P8=o`h>3QCooooo3_mnOWh=
o`X:2Pgo5aLG1_ooool>o`/;2`ko4a<C3OmZJVX=ojj^[PKooooo3_lm?Cd>o`H61Pgo00003Ol20P86
ooooo`ko1PH63Ol0000>oe9BDQ?ooooo3_lM7Ad=oaHF5Pko30`<3Ol=3@d6ooooo`ko92@T3Olf=SH>
o`0000go2@T91_ooool=oaPH60ko7alO3_mGEeL=ocDe=@kooooo000<ooooo`ko30`<3_l10@4=o`82
0Pgo3Ph>5?ooool>oginOPgo2PX:3OlG5aL6ooooo`ko2`/;3_lC4a<=ofYZJPgo[Zj^1_ooool>ocdm
?@ko1PH63Ol0000=o`820PKooooo3_l61PH=o`0000koDU9B4oooool>oadM7@go5QHF3_l<30`=o`d=
3@Kooooo3_lT92@=ocHf=Pko00003Ol92@T6ooooo`go61PH3_lO7al>oeMGE`go=CDe3_ooool000co
oooo3_l<30`>o`410@go0P823Ol>3PhDooooo`koOWin3Ol:2PX=oaLG5`Kooooo3_l;2`/>oa<C4`go
JVYZ3On^[Zh6ooooo`ko?Cdm3_l61PH=o`0000go0P821_ooool>o`H61Pgo00003_mBDU8Cooooo`ko
7AdM3OlF5QH>o``<30go3@d=1_ooool>ob@T90go=SHf3_l0000=o`T92@Kooooo3OlH61P>oalO7`ko
EeMG3Ole=CD>ooooo`003?ooool>o``<30ko0@413Ol20P8=o`h>3QCooooo3_mnOWh=o`X:2Pgo5aLG
1_ooool>o`/;2`ko4a<C3OmZJVX=ojj^[PKooooo3_lm?Cd>o`H61Pgo00003Ol20P86ooooo`ko1PH6
3Ol0000>oe9BDQ?ooooo3_lM7Ad=oaHF5Pko30`<3Ol=3@d6ooooo`ko92@T3Olf=SH>o`0000go2@T9
1_ooool=oaPH60ko7alO3_mGEeL=ocDe=@kooooo000<ooooo`ko30`<3_l10@4=o`820Pgo3Ph>5?oo
ool>oginOPgo2PX:3OlG5aL6ooooo`ko2`/;3_lC4a<=ofYZJPgo[Zj^1_ooool>ocdm?@ko1PH63Ol0
000=o`820PKooooo3_l61PH=o`0000koDU9B4oooool>oadM7@go5QHF3_l<30`=o`d=3@Kooooo3_lT
92@=ocHf=Pko00003Ol92@T6ooooo`go61PH3_lO7al>oeMGE`go=CDe3_ooool000cooooo3_l<30`>
o`410@go0P823Ol>3PhDooooo`koOWin3Ol:2PX=oaLG5`Kooooo3_l;2`/>oa<C4`goJVYZ3On^[Zh6
ooooo`ko?Cdm3_l61PH=o`0000go0P821_ooool>o`H61Pgo00003_mBDU8Cooooo`ko7AdM3OlF5QH>
o``<30go3@d=1_ooool>ob@T90go=SHf3_l0000=o`T92@Kooooo3OlH61P>oalO7`koEeMG3Ole=CD>
ooooo`003?ooool>o``<30ko0@413Ol20P8=o`h>3QCooooo3_mnOWh=o`X:2Pgo5aLG1_ooool>o`/;
2`ko4a<C3OmZJVX=ojj^[PKooooo3_lm?Cd>o`H61Pgo00003Ol20P86ooooo`ko1PH63Ol0000>oe9B
DQ?ooooo3_lM7Ad=oaHF5Pko30`<3Ol=3@d6ooooo`ko92@T3Olf=SH>o`0000go2@T91_ooool=oaPH
60ko7alO3_mGEeL=ocDe=@kooooo000<ooooo`ko30`<3_l10@4=o`820Pgo3Ph>5?ooool>oginOPgo
2PX:3OlG5aL6ooooo`ko2`/;3_lC4a<=ofYZJPgo[Zj^1_ooool>ocdm?@ko1PH63Ol0000=o`820PKo
oooo3_l61PH=o`0000koDU9B4oooool>oadM7@go5QHF3_l<30`=o`d=3@Kooooo3_lT92@=ocHf=Pko
00003Ol92@T6ooooo`go61PH3_lO7al>oeMGE`go=CDe3_ooool000cooooo3_l<30`>o`410@go0P82
3Ol>3PhDooooo`koOWin3Ol:2PX=oaLG5`Kooooo3_l;2`/>oa<C4`goJVYZ3On^[Zh6ooooo`ko?Cdm
3_l61PH=o`0000go0P821_ooool>o`H61Pgo00003_mBDU8Cooooo`ko7AdM3OlF5QH>o``<30go3@d=
1_ooool>ob@T90go=SHf3_l0000=o`T92@Kooooo3OlH61P>oalO7`koEeMG3Ole=CD>ooooo`003?oo
ool>o``<30ko0@413Ol20P8=o`h>3QCooooo3_mnOWh=o`X:2Pgo5aLG1_ooool>o`/;2`ko4a<C3OmZ
JVX=ojj^[PKooooo3_lm?Cd>o`H61Pgo00003Ol20P86ooooo`ko1PH63Ol0000>oe9BDQ?ooooo3_lM
7Ad=oaHF5Pko30`<3Ol=3@d6ooooo`ko92@T3Olf=SH>o`0000go2@T91_ooool=oaPH60ko7alO3_mG
EeL=ocDe=@kooooo000<ooooo`ko30`<3_l10@4=o`820Pgo3Ph>5?ooool>oginOPgo2PX:3OlG5aL6
ooooo`ko2`/;3_lC4a<=ofYZJPgo[Zj^1_ooool>ocdm?@ko1PH63Ol0000=o`820PKooooo3_l61PH=
o`0000koDU9B4oooool>oadM7@go5QHF3_l<30`=o`d=3@Kooooo3_lT92@=ocHf=Pko00003Ol92@T6
ooooo`go61PH3_lO7al>oeMGE`go=CDe3_ooool000cooooo3_l<30`>o`410@go0P823Ol>3PhDoooo
o`koOWin3Ol:2PX=oaLG5`Kooooo3_l;2`/>oa<C4`goJVYZ3On^[Zh6ooooo`ko?Cdm3_l61PH=o`00
00go0P821_ooool>o`H61Pgo00003_mBDU8Cooooo`ko7AdM3OlF5QH>o``<30go3@d=1_ooool>ob@T
90go=SHf3_l0000=o`T92@Kooooo3OlH61P>oalO7`koEeMG3Ole=CD>ooooo`006_ooool>o`@410go
0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKo
oooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go
>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`00
6_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV
3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH
1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;
3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_oo
ool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?
3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?oo
ool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=
ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6
ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=
oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006oooo
o`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogem
O@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE
5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go
0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKo
oooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go
>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`00
6_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV
3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH
1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;
3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_oo
ool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?
3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?oo
ool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=
ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6
ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=
oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006oooo
o`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogem
O@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE
5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go
0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKo
oooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go
>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`00
6_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV
3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?3`l>o`0000go61PH
1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?ooool>ob4Q8@ko2`/;
3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=ob8R8Pgo8B4Q1_oo
ool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6ooooo`ko61PH3Ol?
3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=oadM7@koKFe]8?oo
ool>ob4Q8@ko2`/;3OlF5QH>ooooo`006_ooool>o`@410go0P823Ol00006ooooo`ko;Bd]3_m;Bd/=
ob8R8Pgo8B4Q1_ooool>oc`l?0koIVIV3Old=3@=ogIfMPKooooo3_lI6AT>ogemO@gooooo3Olg=cL6
ooooo`ko61PH3Ol?3`l>o`0000go61PH1_ooool>oaPH60go>CTi3_lX:2P=oaDE5@Kooooo3_lY:BT=
oadM7@koKFe]8?ooool>ob4Q8@ko2`/;3OlF5QH>ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003?ooool>oe5AD@ko
QHF53OmYJFT=oc8b<PKooooo3_lh>3P>oa<C4`go4A4A3OlF5QH6ooooo`ko4A4A3_l0000=oa/K6`go
=SHf1_ooool>o`D51@ko4Q8B3OlJ6QX=oa0@40Kooooo3_m1@D4=o`T92@ko1PH63OlL71`6ooooo`ko
4A4A3OlC4a<>ob8R8Pgo51@D5?ooool=o`H61Pko20P83Ol30`<6ooooo`go1`L73_m9BDT>oa<C4`go
00003_ooool000cooooo3_mADE4>ohF5Q@goJFUY3Olb<S86ooooo`ko>3Ph3_lC4a<=oa4A4@go5QHF
1_ooool>oa4A4@ko00003OlK6a/=ocHf=PKooooo3_l51@D>oa8B4Pgo6QXJ3Ol@4106ooooo`ko@D51
3Ol92@T>o`H61Pgo71`L1_ooool>oa4A4@go4a<C3_lR8R8=oa@D51Cooooo3Ol61PH>o`P820go0`<3
1_ooool=o`L71`koBDU93_lC4a<=o`0000kooooo000<ooooo`koDE5A3_n5QHD=ofUYJ@go<S8b1_oo
ool>ocPh>0ko4a<C3OlA4A4=oaHF5PKooooo3_lA4A4>o`0000go6a/K3Olf=SH6ooooo`ko1@D53_lB
4Q8=oaXJ6Pgo410@1_ooool>od51@@go2@T93_l61PH=oa`L70Kooooo3_lA4A4=oa<C4`ko8R8R3OlD
51@Dooooo`go1PH63_l820P=o`<30`Kooooo3Ol71`L>odU9B@ko4a<C3Ol0000>ooooo`003?ooool>
oe5AD@koQHF53OmYJFT=oc8b<PKooooo3_lh>3P>oa<C4`go4A4A3OlF5QH6ooooo`ko4A4A3_l0000=
oa/K6`go=SHf1_ooool>o`D51@ko4Q8B3OlJ6QX=oa0@40Kooooo3_m1@D4=o`T92@ko1PH63OlL71`6
ooooo`ko4A4A3OlC4a<>ob8R8Pgo51@D5?ooool=o`H61Pko20P83Ol30`<6ooooo`go1`L73_m9BDT>
oa<C4`go00003_ooool000cooooo3_mADE4>ohF5Q@goJFUY3Olb<S86ooooo`ko>3Ph3_lC4a<=oa4A
4@go5QHF1_ooool>oa4A4@ko00003OlK6a/=ocHf=PKooooo3_l51@D>oa8B4Pgo6QXJ3Ol@4106oooo
o`ko@D513Ol92@T>o`H61Pgo71`L1_ooool>oa4A4@go4a<C3_lR8R8=oa@D51Cooooo3Ol61PH>o`P8
20go0`<31_ooool=o`L71`koBDU93_lC4a<=o`0000kooooo000<ooooo`koDE5A3_n5QHD=ofUYJ@go
<S8b1_ooool>ocPh>0ko4a<C3OlA4A4=oaHF5PKooooo3_lA4A4>o`0000go6a/K3Olf=SH6ooooo`ko
1@D53_lB4Q8=oaXJ6Pgo410@1_ooool>od51@@go2@T93_l61PH=oa`L70Kooooo3_lA4A4=oa<C4`ko
8R8R3OlD51@Dooooo`go1PH63_l820P=o`<30`Kooooo3Ol71`L>odU9B@ko4a<C3Ol0000>ooooo`00
3?ooool>oe5AD@koQHF53OmYJFT=oc8b<PKooooo3_lh>3P>oa<C4`go4A4A3OlF5QH6ooooo`ko4A4A
3_l0000=oa/K6`go=SHf1_ooool>o`D51@ko4Q8B3OlJ6QX=oa0@40Kooooo3_m1@D4=o`T92@ko1PH6
3OlL71`6ooooo`ko4A4A3OlC4a<>ob8R8Pgo51@D5?ooool=o`H61Pko20P83Ol30`<6ooooo`go1`L7
3_m9BDT>oa<C4`go00003_ooool000cooooo3_mADE4>ohF5Q@goJFUY3Olb<S86ooooo`ko>3Ph3_lC
4a<=oa4A4@go5QHF1_ooool>oa4A4@ko00003OlK6a/=ocHf=PKooooo3_l51@D>oa8B4Pgo6QXJ3Ol@
4106ooooo`ko@D513Ol92@T>o`H61Pgo71`L1_ooool>oa4A4@go4a<C3_lR8R8=oa@D51Cooooo3Ol6
1PH>o`P820go0`<31_ooool=o`L71`koBDU93_lC4a<=o`0000kooooo000<ooooo`koDE5A3_n5QHD=
ofUYJ@go<S8b1_ooool>ocPh>0ko4a<C3OlA4A4=oaHF5PKooooo3_lA4A4>o`0000go6a/K3Olf=SH6
ooooo`ko1@D53_lB4Q8=oaXJ6Pgo410@1_ooool>od51@@go2@T93_l61PH=oa`L70Kooooo3_lA4A4=
oa<C4`ko8R8R3OlD51@Dooooo`go1PH63_l820P=o`<30`Kooooo3Ol71`L>odU9B@ko4a<C3Ol0000>
ooooo`003?ooool>oe5AD@koQHF53OmYJFT=oc8b<PKooooo3_lh>3P>oa<C4`go4A4A3OlF5QH6oooo
o`ko4A4A3_l0000=oa/K6`go=SHf1_ooool>o`D51@ko4Q8B3OlJ6QX=oa0@40Kooooo3_m1@D4=o`T9
2@ko1PH63OlL71`6ooooo`ko4A4A3OlC4a<>ob8R8Pgo51@D5?ooool=o`H61Pko20P83Ol30`<6oooo
o`go1`L73_m9BDT>oa<C4`go00003_ooool000cooooo3_mADE4>ohF5Q@goJFUY3Olb<S86ooooo`ko
>3Ph3_lC4a<=oa4A4@go5QHF1_ooool>oa4A4@ko00003OlK6a/=ocHf=PKooooo3_l51@D>oa8B4Pgo
6QXJ3Ol@4106ooooo`ko@D513Ol92@T>o`H61Pgo71`L1_ooool>oa4A4@go4a<C3_lR8R8=oa@D51Co
oooo3Ol61PH>o`P820go0`<31_ooool=o`L71`koBDU93_lC4a<=o`0000kooooo000<ooooo`koDE5A
3_n5QHD=ofUYJ@go<S8b1_ooool>ocPh>0ko4a<C3OlA4A4=oaHF5PKooooo3_lA4A4>o`0000go6a/K
3Olf=SH6ooooo`ko1@D53_lB4Q8=oaXJ6Pgo410@1_ooool>od51@@go2@T93_l61PH=oa`L70Kooooo
3_lA4A4=oa<C4`ko8R8R3OlD51@Dooooo`go1PH63_l820P=o`<30`Kooooo3Ol71`L>odU9B@ko4a<C
3Ol0000>ooooo`003?ooool>oe5AD@koQHF53OmYJFT=oc8b<PKooooo3_lh>3P>oa<C4`go4A4A3OlF
5QH6ooooo`ko4A4A3_l0000=oa/K6`go=SHf1_ooool>o`D51@ko4Q8B3OlJ6QX=oa0@40Kooooo3_m1
@D4=o`T92@ko1PH63OlL71`6ooooo`ko4A4A3OlC4a<>ob8R8Pgo51@D5?ooool=o`H61Pko20P83Ol3
0`<6ooooo`go1`L73_m9BDT>oa<C4`go00003_ooool000cooooo3_mADE4>ohF5Q@goJFUY3Olb<S86
ooooo`ko>3Ph3_lC4a<=oa4A4@go5QHF1_ooool>oa4A4@ko00003OlK6a/=ocHf=PKooooo3_l51@D>
oa8B4Pgo6QXJ3Ol@4106ooooo`ko@D513Ol92@T>o`H61Pgo71`L1_ooool>oa4A4@go4a<C3_lR8R8=
oa@D51Cooooo3Ol61PH>o`P820go0`<31_ooool=o`L71`koBDU93_lC4a<=o`0000kooooo000<oooo
o`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?
3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`
<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE
5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko
5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go
1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko
410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:
3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno
3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO
1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?oo
ool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol0
0006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[
:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=
oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>
oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=
o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<oooo
o`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?
3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`
<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE
5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko
5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go
1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko
410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:
3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno
3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO
1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?oo
ool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol0
0006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[
:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=
oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>
oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=
o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000<oooo
o`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko5aLG6olD51@=o`l?
3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go1PH61_ooool>oc0`
<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko410@3_l_;bl=oaDE
5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:3OlF5QH6ooooo`ko
5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno3OlN7Qh>o`P820go
1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO1_ooool=oa`L70ko
410@3_l_;bl=oaDE5@kooooo000<ooooo`koe]KF3_nCTi<=oh61P@go51@D5?ooool>o`0000go2PX:
3OlF5QH6ooooo`ko5aLG6olD51@=o`l?3`Kooooo3_lL71`>oaLG5`go30`<3Ol00006ooooo`ko_kno
3OlN7Qh>o`P820go1PH61_ooool>oc0`<0goHF5Q3_ooool=o`0000Kooooo3_l[:b/Koa@D50go7alO
1_ooool=oa`L70ko410@3_l_;bl=oaDE5@kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4
A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol7
1`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI
6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=
oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>
odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6
ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Joooo
o`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH
60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C
4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO
7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco
51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Ko
oooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko
1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D5
3Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH
3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn
1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4
A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol7
1`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI
6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=
oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>
odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6
ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Joooo
o`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH
60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C
4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO
7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco
51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Ko
oooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko
1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D5
3Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH
3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn
1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=oe9BDPKooooo3_m4
A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>odU9B@go<c<c3Ol7
1`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6ooooo`ko0@413OlI
6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Jooooo`koX:2P3OoDe=@=
oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH60Kooooo3_lG5aL>
odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C4`koFUYJ3OlO7al6
ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO7`kooooo000Joooo
o`koX:2P3OoDe=@=oe9BDPKooooo3_m4A4@>oaHF5Pgo1@D53Ol=3@d6oooooaco51@D3Ol=3@d=oaPH
60Kooooo3_lG5aL>odU9B@go<c<c3Ol71`LDooooo`go61PH3_l;2`/=o`0000Kooooo3_l^;Rh=oa<C
4`koFUYJ3OlO7al6ooooo`ko0@413OlI6AT>o`0000go?Shn1_ooool=o`<30`ko1`L73_lK6a/=oalO
7`kooooo000<ooooo`ko^[Zj3_odm?@=ofEUI@go00001_ooool>oa@D50ko5ADE3Ol92@T=o`410@Ko
oooo3_lI6AT>oaPH60go:2PX4oooool>odA4A0ko5aLG3Oooool=o`@410Kooooo3_lA4A4=o`D51@ko
5aLG3Om9BDT6ooooo`ko2@T93OlI6AT>o`/;2`go71`L1_ooool>oeIFEPgo@4103_lG5aL=ob8R8PKo
oooo3Olj>SX>ooooo`koATI63Ol71`L>ooooo`003?ooool>okZj^Pkom?Cd3OmUIFD=o`0000Kooooo
3_lD51@>oaDE5@go2@T93Ol10@46ooooo`ko6ATI3_lH61P=obPX:1?ooooo3_m4A4@>oaLG5`gooooo
3Ol410@6ooooo`ko4A4A3Ol51@D>oaLG5`goBDU91_ooool>o`T92@go6ATI3_l;2`/=oa`L70Kooooo
3_mFEUH=od10@0ko5aLG3OlR8R86ooooo`go>SXj3_ooool>odI6APgo1`L73_ooool000cooooo3_nj
^[X>ooCdm0goIFEU3Ol00006ooooo`ko51@D3_lE5AD=o`T92@go0@411_ooool>oaTI6@ko61PH3OlX
:2PCooooo`koA4A43_lG5aL=ooooo`go10@41_ooool>oa4A4@go1@D53_lG5aL=odU9B@Kooooo3_l9
2@T=oaTI6@ko2`/;3OlL71`6ooooo`koEUIF3Om0@40>oaLG5`go8R8R1_ooool=ocXj>Pkooooo3_m6
ATH=o`L71`kooooo000<ooooo`ko^[Zj3_odm?@=ofEUI@go00001_ooool>oa@D50ko5ADE3Ol92@T=
o`410@Kooooo3_lI6AT>oaPH60go:2PX4oooool>odA4A0ko5aLG3Oooool=o`@410Kooooo3_lA4A4=
o`D51@ko5aLG3Om9BDT6ooooo`ko2@T93OlI6AT>o`/;2`go71`L1_ooool>oeIFEPgo@4103_lG5aL=
ob8R8PKooooo3Olj>SX>ooooo`koATI63Ol71`L>ooooo`003?ooool>okZj^Pkom?Cd3OmUIFD=o`00
00Kooooo3_lD51@>oaDE5@go2@T93Ol10@46ooooo`ko6ATI3_lH61P=obPX:1?ooooo3_m4A4@>oaLG
5`gooooo3Ol410@6ooooo`ko4A4A3Ol51@D>oaLG5`goBDU91_ooool>o`T92@go6ATI3_l;2`/=oa`L
70Kooooo3_mFEUH=od10@0ko5aLG3OlR8R86ooooo`go>SXj3_ooool>odI6APgo1`L73_ooool000co
oooo3_nj^[X>ooCdm0goIFEU3Ol00006ooooo`ko51@D3_lE5AD=o`T92@go0@411_ooool>oaTI6@ko
61PH3OlX:2PCooooo`koA4A43_lG5aL=ooooo`go10@41_ooool>oa4A4@go1@D53_lG5aL=odU9B@Ko
oooo3_l92@T=oaTI6@ko2`/;3OlL71`6ooooo`koEUIF3Om0@40>oaLG5`go8R8R1_ooool=ocXj>Pko
oooo3_m6ATH=o`L71`kooooo000<ooooo`ko^[Zj3_odm?@=ofEUI@go00001_ooool>oa@D50ko5ADE
3Ol92@T=o`410@Kooooo3_lI6AT>oaPH60go:2PX4oooool>odA4A0ko5aLG3Oooool=o`@410Kooooo
3_lA4A4=o`D51@ko5aLG3Om9BDT6ooooo`ko2@T93OlI6AT>o`/;2`go71`L1_ooool>oeIFEPgo@410
3_lG5aL=ob8R8PKooooo3Olj>SX>ooooo`koATI63Ol71`L>ooooo`003?ooool>okZj^Pkom?Cd3OmU
IFD=o`0000Kooooo3_lD51@>oaDE5@go2@T93Ol10@46ooooo`ko6ATI3_lH61P=obPX:1?ooooo3_m4
A4@>oaLG5`gooooo3Ol410@6ooooo`ko4A4A3Ol51@D>oaLG5`goBDU91_ooool>o`T92@go6ATI3_l;
2`/=oa`L70Kooooo3_mFEUH=od10@0ko5aLG3OlR8R86ooooo`go>SXj3_ooool>odI6APgo1`L73_oo
ool000cooooo3_nj^[X>ooCdm0goIFEU3Ol00006ooooo`ko51@D3_lE5AD=o`T92@go0@411_ooool>
oaTI6@ko61PH3OlX:2PCooooo`koA4A43_lG5aL=ooooo`go10@41_ooool>oa4A4@go1@D53_lG5aL=
odU9B@Kooooo3_l92@T=oaTI6@ko2`/;3OlL71`6ooooo`koEUIF3Om0@40>oaLG5`go8R8R1_ooool=
ocXj>Pkooooo3_m6ATH=o`L71`kooooo000<ooooo`ko^[Zj3_odm?@=ofEUI@go00001_ooool>oa@D
50ko5ADE3Ol92@T=o`410@Kooooo3_lI6AT>oaPH60go:2PX4oooool>odA4A0ko5aLG3Oooool=o`@4
10Kooooo3_lA4A4=o`D51@ko5aLG3Om9BDT6ooooo`ko2@T93OlI6AT>o`/;2`go71`L1_ooool>oeIF
EPgo@4103_lG5aL=ob8R8PKooooo3Olj>SX>ooooo`koATI63Ol71`L>ooooo`003?ooool>okZj^Pko
m?Cd3OmUIFD=o`0000Kooooo3_lD51@>oaDE5@go2@T93Ol10@46ooooo`ko6ATI3_lH61P=obPX:1?o
oooo3_m4A4@>oaLG5`gooooo3Ol410@6ooooo`ko4A4A3Ol51@D>oaLG5`goBDU91_ooool>o`T92@go
6ATI3_l;2`/=oa`L70Kooooo3_mFEUH=od10@0ko5aLG3OlR8R86ooooo`go>SXj3_ooool>odI6APgo
1`L73_ooool000cooooo3_nj^[X>ooCdm0goIFEU3Ol00006ooooo`ko51@D3_lE5AD=o`T92@go0@41
1_ooool>oaTI6@ko61PH3OlX:2PCooooo`koA4A43_lG5aL=ooooo`go10@41_ooool>oa4A4@go1@D5
3_lG5aL=odU9B@Kooooo3_l92@T=oaTI6@ko2`/;3OlL71`6ooooo`koEUIF3Om0@40>oaLG5`go8R8R
1_ooool=ocXj>Pkooooo3_m6ATH=o`L71`kooooo000<ooooo`ko^[Zj3_odm?@=ofEUI@go00001_oo
ool>oa@D50ko5ADE3Ol92@T=o`410@Kooooo3_lI6AT>oaPH60go:2PX4oooool>odA4A0ko5aLG3Ooo
ool=o`@410Kooooo3_lA4A4=o`D51@ko5aLG3Om9BDT6ooooo`ko2@T93OlI6AT>o`/;2`go71`L1_oo
ool>oeIFEPgo@4103_lG5aL=ob8R8PKooooo3Olj>SX>ooooo`koATI63Ol71`L>ooooo`003?ooool>
okZj^Pkom?Cd3OmUIFD=o`0000Kooooo3_lD51@>oaDE5@go2@T93Ol10@46ooooo`ko6ATI3_lH61P=
obPX:1?ooooo3_m4A4@>oaLG5`gooooo3Ol410@6ooooo`ko4A4A3Ol51@D>oaLG5`goBDU91_ooool>
o`T92@go6ATI3_l;2`/=oa`L70Kooooo3_mFEUH=od10@0ko5aLG3OlR8R86ooooo`go>SXj3_ooool>
odI6APgo1`L73_ooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-0.905992, \
-0.431217, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-5.30741, -0.431217, 0.0733952, 0.0733952}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-9.70883, -0.431217, 0.0733952, 0.0733952}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-14.1103, -0.431217, 0.0733952, 0.0733952}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-18.5094, -0.431217, 0.0733952, 0.0733952}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-22.9131, -0.431217, 0.0733952, \
0.0733952}, {{372.125, 426.625}, {240.25, 185.75}} -> {-27.3122, -0.431217, \
0.0733952, 0.0733952}, {{432.062, 486.625}, {240.25, 185.75}} -> {-31.7136, \
-0.431217, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-0.905992, -4.83493, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-5.30741, -4.83493, 0.0733952, 0.0733952}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-9.70883, -4.83493, 0.0733952, 0.0733952}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-14.1103, -4.83493, 0.0733952, 0.0733952}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-18.5094, -4.83493, 0.0733952, \
0.0733952}, {{312.188, 366.688}, {180.25, 125.75}} -> {-22.9131, -4.83493, \
0.0733952, 0.0733952}, {{372.125, 426.625}, {180.25, 125.75}} -> {-27.3122, \
-4.83493, 0.0733952, 0.0733952}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-31.7136, -4.83493, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-0.905992, -9.23406, 0.0733952, 0.0733952}, {{72.3125, \
126.812}, {120.312, 65.8125}} -> {-5.30741, -9.23406, 0.0733952, 0.0733952}, \
{{132.25, 186.812}, {120.312, 65.8125}} -> {-9.70883, -9.23406, 0.0733952, \
0.0733952}, {{192.25, 246.75}, {120.312, 65.8125}} -> {-14.1103, -9.23406, \
0.0733952, 0.0733952}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-18.5094, \
-9.23406, 0.0733952, 0.0733952}, {{312.188, 366.688}, {120.312, 65.8125}} -> \
{-22.9131, -9.23406, 0.0733952, 0.0733952}, {{372.125, 426.625}, {120.312, \
65.8125}} -> {-27.3122, -9.23406, 0.0733952, 0.0733952}, {{432.062, 486.625}, \
{120.312, 65.8125}} -> {-31.7136, -9.23406, 0.0733952, 0.0733952}, {{12.3125, \
66.875}, {60.3125, 5.8125}} -> {-0.905992, -13.6378, 0.0733952, 0.0733952}, \
{{72.3125, 126.812}, {60.3125, 5.8125}} -> {-5.30741, -13.6378, 0.0733952, \
0.0733952}, {{132.25, 186.812}, {60.3125, 5.8125}} -> {-9.70883, -13.6378, \
0.0733952, 0.0733952}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-14.1103, \
-13.6378, 0.0733952, 0.0733952}, {{252.188, 306.688}, {60.3125, 5.8125}} -> \
{-18.5094, -13.6378, 0.0733952, 0.0733952}, {{312.188, 366.688}, {60.3125, \
5.8125}} -> {-22.9131, -13.6378, 0.0733952, 0.0733952}, {{372.125, 426.625}, \
{60.3125, 5.8125}} -> {-27.3122, -13.6378, 0.0733952, 0.0733952}, {{432.062, \
486.625}, {60.3125, 5.8125}} -> {-31.7136, -13.6378, 0.0733952, 0.0733952}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF3892
00CC2BB8
0F9C1EC3
136E12C1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28100CFF
0D0B2F43
0C222224
0404001D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF520743
49170457
030F0E26
0606003A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ABCFD107
D4F5D200
D6FFD502
99DEAA05
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1019143A
0034202D
3FFF6542
1825244F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6F456292
8A1070DC
7B2679FF
B9005D98
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D5480E42
FE450047
FF3F084D
AD381443
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0492C23A
00AFFF4D
02A3FF5C
107FCD4B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DB461332
ED1F031A
FF120026
C91D0A3C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00150222
290001FF
1E080921
050B0910
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0AABFF3E
00D9FC2F
13E8DC11
2CD7BC05
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1CC11405
17EE110A
18FF0601
1ACD000A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
66FF2B0D
9ECB0F04
C78F0800
C1601613
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B020C1C
14171211
2C030CFF
00060516
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF049930
F000BD3A
D600E763
7B1CE369
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0763FF33
2E1B0D3C
01080323
1200013F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D1721D6
080E1DFF
040924FA
100016DB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C0000FF
2E0D0A46
12040729
1A02280D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
271B4E4B
0C1D5F6C
001FB699
0D12FF76
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1509001D
1D090034
04392F0C
2FFF5B05
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
380C495C
17314561
00892F62
18FF0B6E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
430D04D5
300400FF
290515FC
200B11B2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
23182851
56302C36
F63B1743
FF2A0042
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4A0BA416
4400DA12
4C01FF22
3D0ACE1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7489E8E6
288999AC
0096B3A9
3085C8FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
570526AD
5A0316ED
50000CFF
3D0810D2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1328DE2E
0912FF1A
0026EF0F
101ACE13
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C7A2917
41FF540B
26111B2F
0E000814
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0DDA2B49
06FF0D1D
20FC0004
1EC21001
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
09000A22
20071420
1E0E0D4C
21010FFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E7320011
FF110522
CC031B2E
CE0E2621
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000BE081
0214FF8B
0320A96F
0B286051
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool>o`0000kooooo3Olh>3P=oi:BTPKooooo3_lX:2P>oa0@40go
30`<8Oooool>oe9BDPgo1`L73Om3@d<6ooooo`koZj^[3_o?cll=om7Ad@go1`L71_ooool>oa0@40go
6ATI3_lD51@=ocXj>PKooooo3_m_Kfl=odE5A@koHV9R3OnBTY86ooooo`koeMGE3Om8B4P>o`h>3Pgo
@T921_ooool=o`@410koTY:B3_o2`/8=ocXj>Pkooooo000<ooooo`ko00003_ooool=ocPh>0goTY:B
1_ooool>obPX:0ko410@3Ol<30`Qooooo`koDU9B3Ol71`L=od=3@`Kooooo3_n[Zj/>olo?c`godM7A
3Ol71`L6ooooo`ko410@3OlI6AT>oa@D50go>SXj1_ooool>ofm_K`goADE53_mRHV8=oi:BTPKooooo
3_oEeMD=odQ8B0ko3Ph>3Om2@T86ooooo`go10@43_nBTY8>ol;2`Pgo>SXj3_ooool000cooooo3_l0
000>ooooo`go>3Ph3OnBTY86ooooo`ko:2PX3_l@410=o``<327ooooo3_mBDU8=o`L71`go@d=31_oo
ool>oj^[Z`koclo?3OoAdM4=o`L71`Kooooo3_l@410=oaTI6@ko51@D3Olj>SX6ooooo`koKfm_3Om5
ADD>of9RHPgoTY:B1_ooool>omGEe@goB4Q83_l>3Ph=od92@PKooooo3Ol410@>oi:BTPko`/;23Olj
>SX>ooooo`003?ooool>o`0000kooooo3Olh>3P=oi:BTPKooooo3_lX:2P>oa0@40go30`<8Oooool>
oe9BDPgo1`L73Om3@d<6ooooo`koZj^[3_o?cll=om7Ad@go1`L71_ooool>oa0@40go6ATI3_lD51@=
ocXj>PKooooo3_m_Kfl=odE5A@koHV9R3OnBTY86ooooo`koeMGE3Om8B4P>o`h>3Pgo@T921_ooool=
o`@410koTY:B3_o2`/8=ocXj>Pkooooo000<ooooo`ko00003_ooool=ocPh>0goTY:B1_ooool>obPX
:0ko410@3Ol<30`Qooooo`koDU9B3Ol71`L=od=3@`Kooooo3_n[Zj/>olo?c`godM7A3Ol71`L6oooo
o`ko410@3OlI6AT>oa@D50go>SXj1_ooool>ofm_K`goADE53_mRHV8=oi:BTPKooooo3_oEeMD=odQ8
B0ko3Ph>3Om2@T86ooooo`go10@43_nBTY8>ol;2`Pgo>SXj3_ooool000cooooo3_l0000>ooooo`go
>3Ph3OnBTY86ooooo`ko:2PX3_l@410=o``<327ooooo3_mBDU8=o`L71`go@d=31_ooool>oj^[Z`ko
clo?3OoAdM4=o`L71`Kooooo3_l@410=oaTI6@ko51@D3Olj>SX6ooooo`koKfm_3Om5ADD>of9RHPgo
TY:B1_ooool>omGEe@goB4Q83_l>3Ph=od92@PKooooo3Ol410@>oi:BTPko`/;23Olj>SX>ooooo`00
3?ooool>o`0000kooooo3Olh>3P=oi:BTPKooooo3_lX:2P>oa0@40go30`<8Oooool>oe9BDPgo1`L7
3Om3@d<6ooooo`koZj^[3_o?cll=om7Ad@go1`L71_ooool>oa0@40go6ATI3_lD51@=ocXj>PKooooo
3_m_Kfl=odE5A@koHV9R3OnBTY86ooooo`koeMGE3Om8B4P>o`h>3Pgo@T921_ooool=o`@410koTY:B
3_o2`/8=ocXj>Pkooooo000<ooooo`ko00003_ooool=ocPh>0goTY:B1_ooool>obPX:0ko410@3Ol<
30`Qooooo`koDU9B3Ol71`L=od=3@`Kooooo3_n[Zj/>olo?c`godM7A3Ol71`L6ooooo`ko410@3OlI
6AT>oa@D50go>SXj1_ooool>ofm_K`goADE53_mRHV8=oi:BTPKooooo3_oEeMD=odQ8B0ko3Ph>3Om2
@T86ooooo`go10@43_nBTY8>ol;2`Pgo>SXj3_ooool000cooooo3_l0000>ooooo`go>3Ph3OnBTY86
ooooo`ko:2PX3_l@410=o``<327ooooo3_mBDU8=o`L71`go@d=31_ooool>oj^[Z`koclo?3OoAdM4=
o`L71`Kooooo3_l@410=oaTI6@ko51@D3Olj>SX6ooooo`koKfm_3Om5ADD>of9RHPgoTY:B1_ooool>
omGEe@goB4Q83_l>3Ph=od92@PKooooo3Ol410@>oi:BTPko`/;23Olj>SX>ooooo`003?ooool>o`00
00kooooo3Olh>3P=oi:BTPKooooo3_lX:2P>oa0@40go30`<8Oooool>oe9BDPgo1`L73Om3@d<6oooo
o`koZj^[3_o?cll=om7Ad@go1`L71_ooool>oa0@40go6ATI3_lD51@=ocXj>PKooooo3_m_Kfl=odE5
A@koHV9R3OnBTY86ooooo`koeMGE3Om8B4P>o`h>3Pgo@T921_ooool=o`@410koTY:B3_o2`/8=ocXj
>Pkooooo000<ooooo`ko00003_ooool=ocPh>0goTY:B1_ooool>obPX:0ko410@3Ol<30`Qooooo`ko
DU9B3Ol71`L=od=3@`Kooooo3_n[Zj/>olo?c`godM7A3Ol71`L6ooooo`ko410@3OlI6AT>oa@D50go
>SXj1_ooool>ofm_K`goADE53_mRHV8=oi:BTPKooooo3_oEeMD=odQ8B0ko3Ph>3Om2@T86ooooo`go
10@43_nBTY8>ol;2`Pgo>SXj3_ooool000cooooo3_l0000>ooooo`go>3Ph3OnBTY86ooooo`ko:2PX
3_l@410=o``<327ooooo3_mBDU8=o`L71`go@d=31_ooool>oj^[Z`koclo?3OoAdM4=o`L71`Kooooo
3_l@410=oaTI6@ko51@D3Olj>SX6ooooo`koKfm_3Om5ADD>of9RHPgoTY:B1_ooool>omGEe@goB4Q8
3_l>3Ph=od92@PKooooo3Ol410@>oi:BTPko`/;23Olj>SX>ooooo`003?ooool>o`0000kooooo3Olh
>3P=oi:BTPKooooo3_lX:2P>oa0@40go30`<8Oooool>oe9BDPgo1`L73Om3@d<6ooooo`koZj^[3_o?
cll=om7Ad@go1`L71_ooool>oa0@40go6ATI3_lD51@=ocXj>PKooooo3_m_Kfl=odE5A@koHV9R3OnB
TY86ooooo`koeMGE3Om8B4P>o`h>3Pgo@T921_ooool=o`@410koTY:B3_o2`/8=ocXj>Pkooooo000<
ooooo`ko00003_ooool=ocPh>0goTY:B1_ooool>obPX:0ko410@3Ol<30`Qooooo`koDU9B3Ol71`L=
od=3@`Kooooo3_n[Zj/>olo?c`godM7A3Ol71`L6ooooo`ko410@3OlI6AT>oa@D50go>SXj1_ooool>
ofm_K`goADE53_mRHV8=oi:BTPKooooo3_oEeMD=odQ8B0ko3Ph>3Om2@T86ooooo`go10@43_nBTY8>
ol;2`Pgo>SXj3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_
;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006oooo
o`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5
A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go
:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Ko
oooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo
410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`go
CDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=3
1_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko0000
3Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko0000
3Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh
^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oD
e=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`
L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_oo
ool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>
odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>
ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6
ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6oooo
o`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGe
m@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcL
g0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000co
oooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko
5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go
;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go
00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=
3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B
3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo
3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0
000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol4
10@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_oo
ool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_
[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=
obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006
ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=
odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<
c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMG
E`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:
RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>oooo
o`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go
@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo3_oDe=@>ooGem@god];B3Ol00006ooooo`ko
00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko
00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=3_ooool000cooooo3_l0000>olc<c0go:b/[
3Onh^;P6ooooo`ko3@d=3_l;2`/=obl_;`go@d=31_ooool>odU9B@ko5aLG3Ol410@=oeMGE`Kooooo
3_oDe=@>ooGem@god];B3Ol00006ooooo`ko00003Old=3@>ob0P80go;Bd]1_ooool>ohZ:RPgo410@
3_m`L70=omcLg0Kooooo3_ono_h=odE5A@ko00003Om7AdL6ooooo`go00003_n_[jl>ooooo`goCDe=
3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l3
0`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mU
IFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nS
Xj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=
ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>
oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6
ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6oooo
o`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGE
e@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo
?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go
7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`ko
e]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9Pko
NGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo
3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>
3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo
3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL
3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l3
0`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mU
IFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nS
Xj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=
ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>
oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6
ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6oooo
o`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGE
e@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo
?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go
7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`ko
e]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9Pko
NGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo
3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>
3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo
3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL
3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=ob@T90Kooooo3_l3
0`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>oclo?`gooooo3_mU
IFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6ooooo`go0P823_nS
Xj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6ooooo`ko30`<6olR8R8=
ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGEe@go0P821_ooool>
oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo?`ko20P83Om=CDd6
ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_l?3`l>oibLW0go7QhN3Oo3`l<6oooo
o`ko30`<6olR8R8=ob@T90Kooooo3_l30`<>o`l?3`go3Ph>3OlV9RH6ooooo`koe]KF3_ooool=omGE
e@go0P821_ooool>oclo?`gooooo3_mUIFD=od92@PKooooo3_mkNg/=obHV9PkoNGUi8Oooool=oclo
?`ko20P83Om=CDd6ooooo`go0P823_nSXj<>ooooo`goG5aL3_ooool000cooooo3_lC4a<>ofi^KPgo
4Q8B3Oo1`L46oooooaco10@43Ol0000=oadM7@Kooooo7?l61PH=o`0000go>SXj1_ooool>oiVIV@ko
g]kN3OnZZZX=o`D51@Kooooo3_lH61P=obDU9@ko92@T3Om?Cdl6ooooo`ko^KVi3Ol0000>oeeMG@go
V9RH1_ooool>ojf][@go>3Ph3_lD51@=od=3@`Kooooo3Ol@410>ogmoO`kocLg=3Om;Bd/>ooooo`00
3?ooool>oa<C4`koKVi^3OlB4Q8=ol71`@Kooooo7?l410@=o`0000go7AdM1_oooolLo`H61Pgo0000
3Olj>SX6ooooo`koVIVI3_oNg]h=ojZZZPgo1@D51_ooool>oaPH60go9BDU3_lT92@=odm?C`Kooooo
3_ni^KT=o`0000koGEeM3OnHV9P6ooooo`ko[Jf]3Olh>3P>oa@D50go@d=31_ooool=oa0@40koOgmo
3_o=cLd=od];B`kooooo000<ooooo`ko4a<C3_m^KVh=oa8B4Pgo`L711_oooolLo`@410go00003OlM
7Ad6oooooaco1PH63Ol0000=ocXj>PKooooo3_nIVIT>omkNgPgoZZZZ3Ol51@D6ooooo`ko61PH3OlU
9BD>ob@T90goCdm?1_ooool>okVi^@go00003_mMGEd=oiRHV0Kooooo3_n][Jd=ocPh>0ko51@D3Om3
@d<6ooooo`go410@3_moOgl>olg=c@goBd];3_ooool000cooooo3_lC4a<>ofi^KPgo4Q8B3Oo1`L46
oooooaco10@43Ol0000=oadM7@Kooooo7?l61PH=o`0000go>SXj1_ooool>oiVIV@kog]kN3OnZZZX=
o`D51@Kooooo3_lH61P=obDU9@ko92@T3Om?Cdl6ooooo`ko^KVi3Ol0000>oeeMG@goV9RH1_ooool>
ojf][@go>3Ph3_lD51@=od=3@`Kooooo3Ol@410>ogmoO`kocLg=3Om;Bd/>ooooo`003?ooool>oa<C
4`koKVi^3OlB4Q8=ol71`@Kooooo7?l410@=o`0000go7AdM1_oooolLo`H61Pgo00003Olj>SX6oooo
o`koVIVI3_oNg]h=ojZZZPgo1@D51_ooool>oaPH60go9BDU3_lT92@=odm?C`Kooooo3_ni^KT=o`00
00koGEeM3OnHV9P6ooooo`ko[Jf]3Olh>3P>oa@D50go@d=31_ooool=oa0@40koOgmo3_o=cLd=od];
B`kooooo000<ooooo`ko4a<C3_m^KVh=oa8B4Pgo`L711_oooolLo`@410go00003OlM7Ad6oooooaco
1PH63Ol0000=ocXj>PKooooo3_nIVIT>omkNgPgoZZZZ3Ol51@D6ooooo`ko61PH3OlU9BD>ob@T90go
Cdm?1_ooool>okVi^@go00003_mMGEd=oiRHV0Kooooo3_n][Jd=ocPh>0ko51@D3Om3@d<6ooooo`go
410@3_moOgl>olg=c@goBd];3_ooool000cooooo3_lC4a<>ofi^KPgo4Q8B3Oo1`L46oooooaco10@4
3Ol0000=oadM7@Kooooo7?l61PH=o`0000go>SXj1_ooool>oiVIV@kog]kN3OnZZZX=o`D51@Kooooo
3_lH61P=obDU9@ko92@T3Om?Cdl6ooooo`ko^KVi3Ol0000>oeeMG@goV9RH1_ooool>ojf][@go>3Ph
3_lD51@=od=3@`Kooooo3Ol@410>ogmoO`kocLg=3Om;Bd/>ooooo`003?ooool>oa<C4`koKVi^3OlB
4Q8=ol71`@Kooooo7?l410@=o`0000go7AdM1_oooolLo`H61Pgo00003Olj>SX6ooooo`koVIVI3_oN
g]h=ojZZZPgo1@D51_ooool>oaPH60go9BDU3_lT92@=odm?C`Kooooo3_ni^KT=o`0000koGEeM3OnH
V9P6ooooo`ko[Jf]3Olh>3P>oa@D50go@d=31_ooool=oa0@40koOgmo3_o=cLd=od];B`kooooo000<
ooooo`ko4a<C3_m^KVh=oa8B4Pgo`L711_oooolLo`@410go00003OlM7Ad6oooooaco1PH63Ol0000=
ocXj>PKooooo3_nIVIT>omkNgPgoZZZZ3Ol51@D6ooooo`ko61PH3OlU9BD>ob@T90goCdm?1_ooool>
okVi^@go00003_mMGEd=oiRHV0Kooooo3_n][Jd=ocPh>0ko51@D3Om3@d<6ooooo`go410@3_moOgl>
olg=c@goBd];3_ooool000cooooo3_lC4a<>ofi^KPgo4Q8B3Oo1`L46oooooaco10@43Ol0000=oadM
7@Kooooo7?l61PH=o`0000go>SXj1_ooool>oiVIV@kog]kN3OnZZZX=o`D51@Kooooo3_lH61P=obDU
9@ko92@T3Om?Cdl6ooooo`ko^KVi3Ol0000>oeeMG@goV9RH1_ooool>ojf][@go>3Ph3_lD51@=od=3
@`Kooooo3Ol@410>ogmoO`kocLg=3Om;Bd/>ooooo`003?ooool>oa<C4`koKVi^3OlB4Q8=ol71`@Ko
oooo7?l410@=o`0000go7AdM1_oooolLo`H61Pgo00003Olj>SX6ooooo`koVIVI3_oNg]h=ojZZZPgo
1@D51_ooool>oaPH60go9BDU3_lT92@=odm?C`Kooooo3_ni^KT=o`0000koGEeM3OnHV9P6ooooo`ko
[Jf]3Olh>3P>oa@D50go@d=31_ooool=oa0@40koOgmo3_o=cLd=od];B`kooooo000<ooooo`ko4a<C
3_m^KVh=oa8B4Pgo`L711_oooolLo`@410go00003OlM7Ad6oooooaco1PH63Ol0000=ocXj>PKooooo
3_nIVIT>omkNgPgoZZZZ3Ol51@D6ooooo`ko61PH3OlU9BD>ob@T90goCdm?1_ooool>okVi^@go0000
3_mMGEd=oiRHV0Kooooo3_n][Jd=ocPh>0ko51@D3Om3@d<6ooooo`go410@3_moOgl>olg=c@goBd];
3_ooool000cooooo3_lC4a<>ofi^KPgo4Q8B3Oo1`L46oooooaco10@43Ol0000=oadM7@Kooooo7?l6
1PH=o`0000go>SXj1_ooool>oiVIV@kog]kN3OnZZZX=o`D51@Kooooo3_lH61P=obDU9@ko92@T3Om?
Cdl6ooooo`ko^KVi3Ol0000>oeeMG@goV9RH1_ooool>ojf][@go>3Ph3_lD51@=od=3@`Kooooo3Ol@
410>ogmoO`kocLg=3Om;Bd/>ooooo`003?ooool>oa<C4`koKVi^3OlB4Q8=ol71`@Kooooo7?l410@=
o`0000go7AdM1_oooolLo`H61Pgo00003Olj>SX6ooooo`koVIVI3_oNg]h=ojZZZPgo1@D51_ooool>
oaPH60go9BDU3_lT92@=odm?C`Kooooo3_ni^KT=o`0000koGEeM3OnHV9P6ooooo`ko[Jf]3Olh>3P>
oa@D50go@d=31_ooool=oa0@40koOgmo3_o=cLd=od];B`kooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000<ooooo`ko
fm_K3_m6ATH=oa<C4`go<S8b1_ooool>o`0000ko5ADE3Ol20P8=ob8R8PKooooo3_l:2PX>oj^[Z`go
oooo3Oln?Sh6ooooo`ko71`L3_o1`L4=oa@D50go1@D51_ooool>ofIVIPgooooo3_l[:b/=o`d=3@Ko
oooo3_l;2`/=o`820Pko30`<3OlL71`Dooooo`go10@43_nIVIT=oc0`<0Kooooo3Ol71`L>of=SH`ko
oooo3Olc<c<>ooooo`003?ooool>om_Kf`koATI63OlC4a<=oc8b<PKooooo3_l0000>oaDE5@go0P82
3OlR8R86ooooo`ko2PX:3_n[Zj/=ooooo`go?Shn1_ooool>oa`L70ko`L713OlD51@=o`D51@Kooooo
3_mVIVH=ooooo`ko:b/[3Ol=3@d6ooooo`ko2`/;3Ol20P8>o``<30go71`L5?ooool=o`@410koVIVI
3Ol`<306ooooo`go1`L73_mSHf<>ooooo`go<c<c3_ooool000cooooo3_oKfm/>odI6APgo4a<C3Olb
<S86ooooo`ko00003_lE5AD=o`820Pgo8R8R1_ooool>o`X:2PkoZj^[3Oooool=ochn?PKooooo3_lL
71`>ol71`@go51@D3Ol51@D6ooooo`koIVIV3Oooool>ob/[:`go3@d=1_ooool>o`/;2`go0P823_l<
30`=oa`L71Cooooo3Ol410@>oiVIV@go<30`1_ooool=o`L71`koHf=S3_ooool=oc<c<`kooooo000<
ooooo`kofm_K3_m6ATH=oa<C4`go<S8b1_ooool>o`0000ko5ADE3Ol20P8=ob8R8PKooooo3_l:2PX>
oj^[Z`gooooo3Oln?Sh6ooooo`ko71`L3_o1`L4=oa@D50go1@D51_ooool>ofIVIPgooooo3_l[:b/=
o`d=3@Kooooo3_l;2`/=o`820Pko30`<3OlL71`Dooooo`go10@43_nIVIT=oc0`<0Kooooo3Ol71`L>
of=SH`kooooo3Olc<c<>ooooo`003?ooool>om_Kf`koATI63OlC4a<=oc8b<PKooooo3_l0000>oaDE
5@go0P823OlR8R86ooooo`ko2PX:3_n[Zj/=ooooo`go?Shn1_ooool>oa`L70ko`L713OlD51@=o`D5
1@Kooooo3_mVIVH=ooooo`ko:b/[3Ol=3@d6ooooo`ko2`/;3Ol20P8>o``<30go71`L5?ooool=o`@4
10koVIVI3Ol`<306ooooo`go1`L73_mSHf<>ooooo`go<c<c3_ooool000cooooo3_oKfm/>odI6APgo
4a<C3Olb<S86ooooo`ko00003_lE5AD=o`820Pgo8R8R1_ooool>o`X:2PkoZj^[3Oooool=ochn?PKo
oooo3_lL71`>ol71`@go51@D3Ol51@D6ooooo`koIVIV3Oooool>ob/[:`go3@d=1_ooool>o`/;2`go
0P823_l<30`=oa`L71Cooooo3Ol410@>oiVIV@go<30`1_ooool=o`L71`koHf=S3_ooool=oc<c<`ko
oooo000<ooooo`kofm_K3_m6ATH=oa<C4`go<S8b1_ooool>o`0000ko5ADE3Ol20P8=ob8R8PKooooo
3_l:2PX>oj^[Z`gooooo3Oln?Sh6ooooo`ko71`L3_o1`L4=oa@D50go1@D51_ooool>ofIVIPgooooo
3_l[:b/=o`d=3@Kooooo3_l;2`/=o`820Pko30`<3OlL71`Dooooo`go10@43_nIVIT=oc0`<0Kooooo
3Ol71`L>of=SH`kooooo3Olc<c<>ooooo`003?ooool>om_Kf`koATI63OlC4a<=oc8b<PKooooo3_l0
000>oaDE5@go0P823OlR8R86ooooo`ko2PX:3_n[Zj/=ooooo`go?Shn1_ooool>oa`L70ko`L713OlD
51@=o`D51@Kooooo3_mVIVH=ooooo`ko:b/[3Ol=3@d6ooooo`ko2`/;3Ol20P8>o``<30go71`L5?oo
ool=o`@410koVIVI3Ol`<306ooooo`go1`L73_mSHf<>ooooo`go<c<c3_ooool000cooooo3_oKfm/>
odI6APgo4a<C3Olb<S86ooooo`ko00003_lE5AD=o`820Pgo8R8R1_ooool>o`X:2PkoZj^[3Oooool=
ochn?PKooooo3_lL71`>ol71`@go51@D3Ol51@D6ooooo`koIVIV3Oooool>ob/[:`go3@d=1_ooool>
o`/;2`go0P823_l<30`=oa`L71Cooooo3Ol410@>oiVIV@go<30`1_ooool=o`L71`koHf=S3_ooool=
oc<c<`kooooo000<ooooo`kofm_K3_m6ATH=oa<C4`go<S8b1_ooool>o`0000ko5ADE3Ol20P8=ob8R
8PKooooo3_l:2PX>oj^[Z`gooooo3Oln?Sh6ooooo`ko71`L3_o1`L4=oa@D50go1@D51_ooool>ofIV
IPgooooo3_l[:b/=o`d=3@Kooooo3_l;2`/=o`820Pko30`<3OlL71`Dooooo`go10@43_nIVIT=oc0`
<0Kooooo3Ol71`L>of=SH`kooooo3Olc<c<>ooooo`003?ooool>om_Kf`koATI63OlC4a<=oc8b<PKo
oooo3_l0000>oaDE5@go0P823OlR8R86ooooo`ko2PX:3_n[Zj/=ooooo`go?Shn1_ooool>oa`L70ko
`L713OlD51@=o`D51@Kooooo3_mVIVH=ooooo`ko:b/[3Ol=3@d6ooooo`ko2`/;3Ol20P8>o``<30go
71`L5?ooool=o`@410koVIVI3Ol`<306ooooo`go1`L73_mSHf<>ooooo`go<c<c3_ooool000cooooo
3_oKfm/>odI6APgo4a<C3Olb<S86ooooo`ko00003_lE5AD=o`820Pgo8R8R1_ooool>o`X:2PkoZj^[
3Oooool=ochn?PKooooo3_lL71`>ol71`@go51@D3Ol51@D6ooooo`koIVIV3Oooool>ob/[:`go3@d=
1_ooool>o`/;2`go0P823_l<30`=oa`L71Cooooo3Ol410@>oiVIV@go<30`1_ooool=o`L71`koHf=S
3_ooool=oc<c<`kooooo000<ooooo`kofm_K3_m6ATH=oa<C4`go<S8b1_ooool>o`0000ko5ADE3Ol2
0P8=ob8R8PKooooo3_l:2PX>oj^[Z`gooooo3Oln?Sh6ooooo`ko71`L3_o1`L4=oa@D50go1@D51_oo
ool>ofIVIPgooooo3_l[:b/=o`d=3@Kooooo3_l;2`/=o`820Pko30`<3OlL71`Dooooo`go10@43_nI
VIT=oc0`<0Kooooo3Ol71`L>of=SH`kooooo3Olc<c<>ooooo`003?ooool>om_Kf`koATI63OlC4a<=
oc8b<PKooooo3_l0000>oaDE5@go0P823OlR8R86ooooo`ko2PX:3_n[Zj/=ooooo`go?Shn1_ooool>
oa`L70ko`L713OlD51@=o`D51@Kooooo3_mVIVH=ooooo`ko:b/[3Ol=3@d6ooooo`ko2`/;3Ol20P8>
o``<30go71`L5?ooool=o`@410koVIVI3Ol`<306ooooo`go1`L73_mSHf<>ooooo`go<c<c3_ooool0
00cooooo3_o]kNd>oalO7`go0`<33OlJ6QX6ooooo`ko:BTY3_l0000=o`410A?ooooo3_l0000>omWI
f@goo?cl3Ol_;bl6ooooo`ko5aLG3_o^k^h=oa4A4@go2PX:1_ooool>oijNWPgobl_;3_l?3`l=o`@4
10Kooooo3_lD51@=oaLG5`ko4Q8B3OlA4A46ooooo`kol?3`3Ol0000>okfm_@go>SXj1_ooool=obh^
;Pko6a/K3_l=3@d=oc`l?0kooooo000<ooooo`kokNg]3_lO7al=o`<30`go6QXJ1_ooool>obTY:@ko
00003Ol10@4Cooooo`ko00003_oIfMT=ooclo0go;bl_1_ooool>oaLG5`kok^k^3OlA4A4=o`X:2PKo
oooo3_nNWYh=ol_;b`ko3`l?3Ol410@6ooooo`ko51@D3OlG5aL>oa8B4Pgo4A4A1_ooool>oo3`l0go
00003_nm_Kd=ocXj>PKooooo3Ol^;Rh>oa/K6`ko3@d=3Oll?3`>ooooo`003?ooool>ong]k@ko7alO
3Ol30`<=oaXJ6PKooooo3_lY:BT>o`0000go0@414oooool>o`0000kofMWI3Oolo?`=obl_;`Kooooo
3_lG5aL>onk^kPgo4A4A3Ol:2PX6ooooo`koWYjN3Oo;bl/>o`l?3`go10@41_ooool>oa@D50go5aLG
3_lB4Q8=oa4A4@Kooooo3_o`l?0=o`0000ko_Kfm3Olj>SX6ooooo`go;Rh^3_lK6a/>o`d=3@go?3`l
3_ooool000cooooo3_o]kNd>oalO7`go0`<33OlJ6QX6ooooo`ko:BTY3_l0000=o`410A?ooooo3_l0
000>omWIf@goo?cl3Ol_;bl6ooooo`ko5aLG3_o^k^h=oa4A4@go2PX:1_ooool>oijNWPgobl_;3_l?
3`l=o`@410Kooooo3_lD51@=oaLG5`ko4Q8B3OlA4A46ooooo`kol?3`3Ol0000>okfm_@go>SXj1_oo
ool=obh^;Pko6a/K3_l=3@d=oc`l?0kooooo000<ooooo`kokNg]3_lO7al=o`<30`go6QXJ1_ooool>
obTY:@ko00003Ol10@4Cooooo`ko00003_oIfMT=ooclo0go;bl_1_ooool>oaLG5`kok^k^3OlA4A4=
o`X:2PKooooo3_nNWYh=ol_;b`ko3`l?3Ol410@6ooooo`ko51@D3OlG5aL>oa8B4Pgo4A4A1_ooool>
oo3`l0go00003_nm_Kd=ocXj>PKooooo3Ol^;Rh>oa/K6`ko3@d=3Oll?3`>ooooo`003?ooool>ong]
k@ko7alO3Ol30`<=oaXJ6PKooooo3_lY:BT>o`0000go0@414oooool>o`0000kofMWI3Oolo?`=obl_
;`Kooooo3_lG5aL>onk^kPgo4A4A3Ol:2PX6ooooo`koWYjN3Oo;bl/>o`l?3`go10@41_ooool>oa@D
50go5aLG3_lB4Q8=oa4A4@Kooooo3_o`l?0=o`0000ko_Kfm3Olj>SX6ooooo`go;Rh^3_lK6a/>o`d=
3@go?3`l3_ooool000cooooo3_o]kNd>oalO7`go0`<33OlJ6QX6ooooo`ko:BTY3_l0000=o`410A?o
oooo3_l0000>omWIf@goo?cl3Ol_;bl6ooooo`ko5aLG3_o^k^h=oa4A4@go2PX:1_ooool>oijNWPgo
bl_;3_l?3`l=o`@410Kooooo3_lD51@=oaLG5`ko4Q8B3OlA4A46ooooo`kol?3`3Ol0000>okfm_@go
>SXj1_ooool=obh^;Pko6a/K3_l=3@d=oc`l?0kooooo000<ooooo`kokNg]3_lO7al=o`<30`go6QXJ
1_ooool>obTY:@ko00003Ol10@4Cooooo`ko00003_oIfMT=ooclo0go;bl_1_ooool>oaLG5`kok^k^
3OlA4A4=o`X:2PKooooo3_nNWYh=ol_;b`ko3`l?3Ol410@6ooooo`ko51@D3OlG5aL>oa8B4Pgo4A4A
1_ooool>oo3`l0go00003_nm_Kd=ocXj>PKooooo3Ol^;Rh>oa/K6`ko3@d=3Oll?3`>ooooo`003?oo
ool>ong]k@ko7alO3Ol30`<=oaXJ6PKooooo3_lY:BT>o`0000go0@414oooool>o`0000kofMWI3Ool
o?`=obl_;`Kooooo3_lG5aL>onk^kPgo4A4A3Ol:2PX6ooooo`koWYjN3Oo;bl/>o`l?3`go10@41_oo
ool>oa@D50go5aLG3_lB4Q8=oa4A4@Kooooo3_o`l?0=o`0000ko_Kfm3Olj>SX6ooooo`go;Rh^3_lK
6a/>o`d=3@go?3`l3_ooool000cooooo3_o]kNd>oalO7`go0`<33OlJ6QX6ooooo`ko:BTY3_l0000=
o`410A?ooooo3_l0000>omWIf@goo?cl3Ol_;bl6ooooo`ko5aLG3_o^k^h=oa4A4@go2PX:1_ooool>
oijNWPgobl_;3_l?3`l=o`@410Kooooo3_lD51@=oaLG5`ko4Q8B3OlA4A46ooooo`kol?3`3Ol0000>
okfm_@go>SXj1_ooool=obh^;Pko6a/K3_l=3@d=oc`l?0kooooo000<ooooo`kokNg]3_lO7al=o`<3
0`go6QXJ1_ooool>obTY:@ko00003Ol10@4Cooooo`ko00003_oIfMT=ooclo0go;bl_1_ooool>oaLG
5`kok^k^3OlA4A4=o`X:2PKooooo3_nNWYh=ol_;b`ko3`l?3Ol410@6ooooo`ko51@D3OlG5aL>oa8B
4Pgo4A4A1_ooool>oo3`l0go00003_nm_Kd=ocXj>PKooooo3Ol^;Rh>oa/K6`ko3@d=3Oll?3`>oooo
o`003?ooool>ong]k@ko7alO3Ol30`<=oaXJ6PKooooo3_lY:BT>o`0000go0@414oooool>o`0000ko
fMWI3Oolo?`=obl_;`Kooooo3_lG5aL>onk^kPgo4A4A3Ol:2PX6ooooo`koWYjN3Oo;bl/>o`l?3`go
10@41_ooool>oa@D50go5aLG3_lB4Q8=oa4A4@Kooooo3_o`l?0=o`0000ko_Kfm3Olj>SX6ooooo`go
;Rh^3_lK6a/>o`d=3@go?3`l3_ooool000cooooo3_o]kNd>oalO7`go0`<33OlJ6QX6ooooo`ko:BTY
3_l0000=o`410A?ooooo3_l0000>omWIf@goo?cl3Ol_;bl6ooooo`ko5aLG3_o^k^h=oa4A4@go2PX:
1_ooool>oijNWPgobl_;3_l?3`l=o`@410Kooooo3_lD51@=oaLG5`ko4Q8B3OlA4A46ooooo`kol?3`
3Ol0000>okfm_@go>SXj1_ooool=obh^;Pko6a/K3_l=3@d=oc`l?0kooooo000Jooooo`ko4Q8B3Ol0
000=obHV9PKooooo3_lN7Qh>o`P820go2@T93OlQ8B46ooooo`ko4a<C3_oXj>P=omcLg0go4A4A1_oo
ool>oaPH60kooooo3Ol61PH=o`410@Kooooo3_o7alL=ohn?S`ko20P83Ol00006ooooo`ko;2`/3Ol3
0`<>o``<31?ooooo3_oFe]H=o`0000koinOW3OmSHf<6ooooo`go0@413_l820P>o`<30`go8b<S3_oo
ool001[ooooo3_lB4Q8=o`0000go9RHV1_ooool>oahN7Pko20P83Ol92@T=ob4Q8@Kooooo3_lC4a<>
onSXj0gog=cL3OlA4A46ooooo`ko61PH3_ooool=o`H61Pgo0@411_ooool>olO7a`goShn?3_l820P=
o`0000Kooooo3_l/;2`=o`<30`ko30`<4oooool>omKFePgo00003_oWinL=of=SH`Kooooo3Ol10@4>
o`P820ko0`<33OlS8b<>ooooo`006_ooool>oa8B4Pgo00003OlV9RH6ooooo`ko7QhN3_l820P=o`T9
2@go8B4Q1_ooool>oa<C4`koj>SX3OoLg=`=oa4A4@Kooooo3_lH61P>ooooo`go1PH63Ol10@46oooo
o`koalO73On?Shl>o`P820go00001_ooool>ob`/;0go0`<33_l<30`Cooooo`koe]KF3Ol0000>onOW
i`goHf=S1_ooool=o`410@ko20P83_l30`<=ob<S8`kooooo000Jooooo`ko4Q8B3Ol0000=obHV9PKo
oooo3_lN7Qh>o`P820go2@T93OlQ8B46ooooo`ko4a<C3_oXj>P=omcLg0go4A4A1_ooool>oaPH60ko
oooo3Ol61PH=o`410@Kooooo3_o7alL=ohn?S`ko20P83Ol00006ooooo`ko;2`/3Ol30`<>o``<31?o
oooo3_oFe]H=o`0000koinOW3OmSHf<6ooooo`go0@413_l820P>o`<30`go8b<S3_ooool001[ooooo
3_lB4Q8=o`0000go9RHV1_ooool>oahN7Pko20P83Ol92@T=ob4Q8@Kooooo3_lC4a<>onSXj0gog=cL
3OlA4A46ooooo`ko61PH3_ooool=o`H61Pgo0@411_ooool>olO7a`goShn?3_l820P=o`0000Kooooo
3_l/;2`=o`<30`ko30`<4oooool>omKFePgo00003_oWinL=of=SH`Kooooo3Ol10@4>o`P820ko0`<3
3OlS8b<>ooooo`006_ooool>oa8B4Pgo00003OlV9RH6ooooo`ko7QhN3_l820P=o`T92@go8B4Q1_oo
ool>oa<C4`koj>SX3OoLg=`=oa4A4@Kooooo3_lH61P>ooooo`go1PH63Ol10@46ooooo`koalO73On?
Shl>o`P820go00001_ooool>ob`/;0go0`<33_l<30`Cooooo`koe]KF3Ol0000>onOWi`goHf=S1_oo
ool=o`410@ko20P83_l30`<=ob<S8`kooooo000Jooooo`ko4Q8B3Ol0000=obHV9PKooooo3_lN7Qh>
o`P820go2@T93OlQ8B46ooooo`ko4a<C3_oXj>P=omcLg0go4A4A1_ooool>oaPH60kooooo3Ol61PH=
o`410@Kooooo3_o7alL=ohn?S`ko20P83Ol00006ooooo`ko;2`/3Ol30`<>o``<31?ooooo3_oFe]H=
o`0000koinOW3OmSHf<6ooooo`go0@413_l820P>o`<30`go8b<S3_ooool001[ooooo3_lB4Q8=o`00
00go9RHV1_ooool>oahN7Pko20P83Ol92@T=ob4Q8@Kooooo3_lC4a<>onSXj0gog=cL3OlA4A46oooo
o`ko61PH3_ooool=o`H61Pgo0@411_ooool>olO7a`goShn?3_l820P=o`0000Kooooo3_l/;2`=o`<3
0`ko30`<4oooool>omKFePgo00003_oWinL=of=SH`Kooooo3Ol10@4>o`P820ko0`<33OlS8b<>oooo
o`006_ooool>oa8B4Pgo00003OlV9RH6ooooo`ko7QhN3_l820P=o`T92@go8B4Q1_ooool>oa<C4`ko
j>SX3OoLg=`=oa4A4@Kooooo3_lH61P>ooooo`go1PH63Ol10@46ooooo`koalO73On?Shl>o`P820go
00001_ooool>ob`/;0go0`<33_l<30`Cooooo`koe]KF3Ol0000>onOWi`goHf=S1_ooool=o`410@ko
20P83_l30`<=ob<S8`kooooo000Jooooo`ko4Q8B3Ol0000=obHV9PKooooo3_lN7Qh>o`P820go2@T9
3OlQ8B46ooooo`ko4a<C3_oXj>P=omcLg0go4A4A1_ooool>oaPH60kooooo3Ol61PH=o`410@Kooooo
3_o7alL=ohn?S`ko20P83Ol00006ooooo`ko;2`/3Ol30`<>o``<31?ooooo3_oFe]H=o`0000koinOW
3OmSHf<6ooooo`go0@413_l820P>o`<30`go8b<S3_ooool001[ooooo3_lB4Q8=o`0000go9RHV1_oo
ool>oahN7Pko20P83Ol92@T=ob4Q8@Kooooo3_lC4a<>onSXj0gog=cL3OlA4A46ooooo`ko61PH3_oo
ool=o`H61Pgo0@411_ooool>olO7a`goShn?3_l820P=o`0000Kooooo3_l/;2`=o`<30`ko30`<4ooo
ool>omKFePgo00003_oWinL=of=SH`Kooooo3Ol10@4>o`P820ko0`<33OlS8b<>ooooo`006_ooool>
oa8B4Pgo00003OlV9RH6ooooo`ko7QhN3_l820P=o`T92@go8B4Q1_ooool>oa<C4`koj>SX3OoLg=`=
oa4A4@Kooooo3_lH61P>ooooo`go1PH63Ol10@46ooooo`koalO73On?Shl>o`P820go00001_ooool>
ob`/;0go0`<33_l<30`Cooooo`koe]KF3Ol0000>onOWi`goHf=S1_ooool=o`410@ko20P83_l30`<=
ob<S8`kooooo000Jooooo`ko4Q8B3Ol0000=obHV9PKooooo3_lN7Qh>o`P820go2@T93OlQ8B46oooo
o`ko4a<C3_oXj>P=omcLg0go4A4A1_ooool>oaPH60kooooo3Ol61PH=o`410@Kooooo3_o7alL=ohn?
S`ko20P83Ol00006ooooo`ko;2`/3Ol30`<>o``<31?ooooo3_oFe]H=o`0000koinOW3OmSHf<6oooo
o`go0@413_l820P>o`<30`go8b<S3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko
1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go
00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKo
oooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo
3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG
3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C
1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B
3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;
2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:
2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mk
Ng/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>
oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=
o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>
o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>
o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T9
2@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6oooo
o`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L
70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go
2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Ko
oooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go
1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go
?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@
1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L71
3OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S
3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll
?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ
6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l5
1@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_oo
ool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>
ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>
oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6
ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6oooo
o`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=
c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF
5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000co
oooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0ko
emOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo
4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go
4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D5
3_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go0000
3Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo
3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool000cooooo3_o9
bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=o`T92@go410@1_ooool>ob`/;0koemOG3Onl
_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_oo
ool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0
000>o`410@go?clo3_ooool000cooooo3_o9bLT>oadM7@go2PX:3Oll?3`6ooooo`ko1@D53_l;2`/=
o`T92@go410@1_ooool>ob`/;0koemOG3Onl_;`=o`D51@Kooooo3_lJ6QX>olg=c@go00003Ol:2PX6
ooooo`ko`L713OmPH60>oaHF5Pgo4a<C1_ooool>o`0000go1PH63_l51@D=oaHF5PKooooo3_mkNg/=
oa`L70kohn?S3OmYJFT6ooooo`go4Q8B3_l0000>o`410@go?clo3_ooool00?oooooomOooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool000co
oooo3_l=3@d>oaLG5`go8B4Q3OoFe]H6ooooo`ko;2`/6ol0000Cooooo`ko9bLW3_lK6a/=odi>CPgo
Bd];1_ooool>oaDE5@ko2@T93Ol0000=oadM7@Kooooo3_lh>3P=o``<30koBDU93OmLG5`6ooooo`ko
@d=33Ol=3@d>o`@410goeMGE1_ooool>ob<S8`go61PH3_lX:2P=oe5AD@Kooooo3Om:BTX>o`/;2`ko
Y:BT3OlF5QH>ooooo`003?ooool>o`d=3@ko5aLG3OlQ8B4=omKFePKooooo3_l/;2`Ko`0001?ooooo
3_lW9bL>oa/K6`goCTi>3Om;Bd/6ooooo`ko5ADE3_l92@T=o`0000go7AdM1_ooool>ocPh>0go30`<
3_m9BDT=oeaLG0Kooooo3_m3@d<=o`d=3@ko10@43OoEeMD6ooooo`ko8b<S3OlH61P>obPX:0goDE5A
1_ooool=odY:BPko2`/;3_nTY:@=oaHF5Pkooooo000<ooooo`ko3@d=3_lG5aL=ob4Q8@goe]KF1_oo
ool>ob`/;1_o00004oooool>obLW9`ko6a/K3Om>CTh=od];B`Kooooo3_lE5AD>o`T92@go00003OlM
7Ad6ooooo`ko>3Ph3Ol<30`>odU9B@goG5aL1_ooool>od=3@`go3@d=3_l410@=omGEe@Kooooo3_lS
8b<=oaPH60ko:2PX3OmADE46ooooo`goBTY:3_l;2`/>ojBTY0go5QHF3_ooool000cooooo3_l=3@d>
oaLG5`go8B4Q3OoFe]H6ooooo`ko;2`/6ol0000Cooooo`ko9bLW3_lK6a/=odi>CPgoBd];1_ooool>
oaDE5@ko2@T93Ol0000=oadM7@Kooooo3_lh>3P=o``<30koBDU93OmLG5`6ooooo`ko@d=33Ol=3@d>
o`@410goeMGE1_ooool>ob<S8`go61PH3_lX:2P=oe5AD@Kooooo3Om:BTX>o`/;2`koY:BT3OlF5QH>
ooooo`003?ooool>o`d=3@ko5aLG3OlQ8B4=omKFePKooooo3_l/;2`Ko`0001?ooooo3_lW9bL>oa/K
6`goCTi>3Om;Bd/6ooooo`ko5ADE3_l92@T=o`0000go7AdM1_ooool>ocPh>0go30`<3_m9BDT=oeaL
G0Kooooo3_m3@d<=o`d=3@ko10@43OoEeMD6ooooo`ko8b<S3OlH61P>obPX:0goDE5A1_ooool=odY:
BPko2`/;3_nTY:@=oaHF5Pkooooo000<ooooo`ko3@d=3_lG5aL=ob4Q8@goe]KF1_ooool>ob`/;1_o
00004oooool>obLW9`ko6a/K3Om>CTh=od];B`Kooooo3_lE5AD>o`T92@go00003OlM7Ad6ooooo`ko
>3Ph3Ol<30`>odU9B@goG5aL1_ooool>od=3@`go3@d=3_l410@=omGEe@Kooooo3_lS8b<=oaPH60ko
:2PX3OmADE46ooooo`goBTY:3_l;2`/>ojBTY0go5QHF3_ooool000cooooo3_l=3@d>oaLG5`go8B4Q
3OoFe]H6ooooo`ko;2`/6ol0000Cooooo`ko9bLW3_lK6a/=odi>CPgoBd];1_ooool>oaDE5@ko2@T9
3Ol0000=oadM7@Kooooo3_lh>3P=o``<30koBDU93OmLG5`6ooooo`ko@d=33Ol=3@d>o`@410goeMGE
1_ooool>ob<S8`go61PH3_lX:2P=oe5AD@Kooooo3Om:BTX>o`/;2`koY:BT3OlF5QH>ooooo`003?oo
ool>o`d=3@ko5aLG3OlQ8B4=omKFePKooooo3_l/;2`Ko`0001?ooooo3_lW9bL>oa/K6`goCTi>3Om;
Bd/6ooooo`ko5ADE3_l92@T=o`0000go7AdM1_ooool>ocPh>0go30`<3_m9BDT=oeaLG0Kooooo3_m3
@d<=o`d=3@ko10@43OoEeMD6ooooo`ko8b<S3OlH61P>obPX:0goDE5A1_ooool=odY:BPko2`/;3_nT
Y:@=oaHF5Pkooooo000<ooooo`ko3@d=3_lG5aL=ob4Q8@goe]KF1_ooool>ob`/;1_o00004oooool>
obLW9`ko6a/K3Om>CTh=od];B`Kooooo3_lE5AD>o`T92@go00003OlM7Ad6ooooo`ko>3Ph3Ol<30`>
odU9B@goG5aL1_ooool>od=3@`go3@d=3_l410@=omGEe@Kooooo3_lS8b<=oaPH60ko:2PX3OmADE46
ooooo`goBTY:3_l;2`/>ojBTY0go5QHF3_ooool000cooooo3_l=3@d>oaLG5`go8B4Q3OoFe]H6oooo
o`ko;2`/6ol0000Cooooo`ko9bLW3_lK6a/=odi>CPgoBd];1_ooool>oaDE5@ko2@T93Ol0000=oadM
7@Kooooo3_lh>3P=o``<30koBDU93OmLG5`6ooooo`ko@d=33Ol=3@d>o`@410goeMGE1_ooool>ob<S
8`go61PH3_lX:2P=oe5AD@Kooooo3Om:BTX>o`/;2`koY:BT3OlF5QH>ooooo`003?ooool>o`d=3@ko
5aLG3OlQ8B4=omKFePKooooo3_l/;2`Ko`0001?ooooo3_lW9bL>oa/K6`goCTi>3Om;Bd/6ooooo`ko
5ADE3_l92@T=o`0000go7AdM1_ooool>ocPh>0go30`<3_m9BDT=oeaLG0Kooooo3_m3@d<=o`d=3@ko
10@43OoEeMD6ooooo`ko8b<S3OlH61P>obPX:0goDE5A1_ooool=odY:BPko2`/;3_nTY:@=oaHF5Pko
oooo000<ooooo`ko3@d=3_lG5aL=ob4Q8@goe]KF1_ooool>ob`/;1_o00004oooool>obLW9`ko6a/K
3Om>CTh=od];B`Kooooo3_lE5AD>o`T92@go00003OlM7Ad6ooooo`ko>3Ph3Ol<30`>odU9B@goG5aL
1_ooool>od=3@`go3@d=3_l410@=omGEe@Kooooo3_lS8b<=oaPH60ko:2PX3OmADE46ooooo`goBTY:
3_l;2`/>ojBTY0go5QHF3_ooool000cooooo3_l=3@d>oaLG5`go8B4Q3OoFe]H6ooooo`ko;2`/6ol0
000Cooooo`ko9bLW3_lK6a/=odi>CPgoBd];1_ooool>oaDE5@ko2@T93Ol0000=oadM7@Kooooo3_lh
>3P=o``<30koBDU93OmLG5`6ooooo`ko@d=33Ol=3@d>o`@410goeMGE1_ooool>ob<S8`go61PH3_lX
:2P=oe5AD@Kooooo3Om:BTX>o`/;2`koY:BT3OlF5QH>ooooo`003?ooool>o`d=3@ko5aLG3OlQ8B4=
omKFePKooooo3_l/;2`Ko`0001?ooooo3_lW9bL>oa/K6`goCTi>3Om;Bd/6ooooo`ko5ADE3_l92@T=
o`0000go7AdM1_ooool>ocPh>0go30`<3_m9BDT=oeaLG0Kooooo3_m3@d<=o`d=3@ko10@43OoEeMD6
ooooo`ko8b<S3OlH61P>obPX:0goDE5A1_ooool=odY:BPko2`/;3_nTY:@=oaHF5Pkooooo000<oooo
o`ko20P83_l>3Ph=oadM7A?ooooo3_l^;Rh>o`d=3@go2PX:3Om6ATH6ooooo`ko30`<3_lM7Ad=oemO
G`goK6a/1_ooool>oadM7@ko2@T93Ol0000=oc@d=0Kooooo3_lG5aL=oc4a<@koADE53OmQHF46oooo
o`ko<30`3Ol410@>o`0001?ooooo3_mFEUH=oc0`<0ko;2`/3Olf=SH6ooooo`goA4A43_l0000>om[J
fPgo4Q8B3_ooool000cooooo3_l820P>o`h>3Pgo7AdM4oooool>obh^;Pko3@d=3Ol:2PX=odI6APKo
oooo3_l<30`>oadM7@goGemO3Om/K6`6ooooo`ko7AdM3_l92@T=o`0000go=3@d1_ooool>oaLG5`go
<C4a3_m5ADD=of5QH@Kooooo3_l`<30=o`@410ko00004oooool>oeIFEPgo<30`3_l/;2`=ocHf=PKo
oooo3Om4A4@>o`0000kof][J3OlB4Q8>ooooo`003?ooool>o`P820ko3Ph>3OlM7AdCooooo`ko;Rh^
3_l=3@d=o`X:2PgoATI61_ooool>o``<30ko7AdM3OmOGel=ofa/K0Kooooo3_lM7Ad>o`T92@go0000
3Old=3@6ooooo`ko5aLG3Ola<C4>odE5A@goHF5Q1_ooool>oc0`<0go10@43_l0000Cooooo`koEUIF
3Ol`<30>ob`/;0go=SHf1_ooool=odA4A0ko00003_oJf]X=oa8B4Pkooooo000<ooooo`ko20P83_l>
3Ph=oadM7A?ooooo3_l^;Rh>o`d=3@go2PX:3Om6ATH6ooooo`ko30`<3_lM7Ad=oemOG`goK6a/1_oo
ool>oadM7@ko2@T93Ol0000=oc@d=0Kooooo3_lG5aL=oc4a<@koADE53OmQHF46ooooo`ko<30`3Ol4
10@>o`0001?ooooo3_mFEUH=oc0`<0ko;2`/3Olf=SH6ooooo`goA4A43_l0000>om[JfPgo4Q8B3_oo
ool000cooooo3_l820P>o`h>3Pgo7AdM4oooool>obh^;Pko3@d=3Ol:2PX=odI6APKooooo3_l<30`>
oadM7@goGemO3Om/K6`6ooooo`ko7AdM3_l92@T=o`0000go=3@d1_ooool>oaLG5`go<C4a3_m5ADD=
of5QH@Kooooo3_l`<30=o`@410ko00004oooool>oeIFEPgo<30`3_l/;2`=ocHf=PKooooo3Om4A4@>
o`0000kof][J3OlB4Q8>ooooo`003?ooool>o`P820ko3Ph>3OlM7AdCooooo`ko;Rh^3_l=3@d=o`X:
2PgoATI61_ooool>o``<30ko7AdM3OmOGel=ofa/K0Kooooo3_lM7Ad>o`T92@go00003Old=3@6oooo
o`ko5aLG3Ola<C4>odE5A@goHF5Q1_ooool>oc0`<0go10@43_l0000Cooooo`koEUIF3Ol`<30>ob`/
;0go=SHf1_ooool=odA4A0ko00003_oJf]X=oa8B4Pkooooo000<ooooo`ko20P83_l>3Ph=oadM7A?o
oooo3_l^;Rh>o`d=3@go2PX:3Om6ATH6ooooo`ko30`<3_lM7Ad=oemOG`goK6a/1_ooool>oadM7@ko
2@T93Ol0000=oc@d=0Kooooo3_lG5aL=oc4a<@koADE53OmQHF46ooooo`ko<30`3Ol410@>o`0001?o
oooo3_mFEUH=oc0`<0ko;2`/3Olf=SH6ooooo`goA4A43_l0000>om[JfPgo4Q8B3_ooool000cooooo
3_l820P>o`h>3Pgo7AdM4oooool>obh^;Pko3@d=3Ol:2PX=odI6APKooooo3_l<30`>oadM7@goGemO
3Om/K6`6ooooo`ko7AdM3_l92@T=o`0000go=3@d1_ooool>oaLG5`go<C4a3_m5ADD=of5QH@Kooooo
3_l`<30=o`@410ko00004oooool>oeIFEPgo<30`3_l/;2`=ocHf=PKooooo3Om4A4@>o`0000kof][J
3OlB4Q8>ooooo`003?ooool>o`P820ko3Ph>3OlM7AdCooooo`ko;Rh^3_l=3@d=o`X:2PgoATI61_oo
ool>o``<30ko7AdM3OmOGel=ofa/K0Kooooo3_lM7Ad>o`T92@go00003Old=3@6ooooo`ko5aLG3Ola
<C4>odE5A@goHF5Q1_ooool>oc0`<0go10@43_l0000Cooooo`koEUIF3Ol`<30>ob`/;0go=SHf1_oo
ool=odA4A0ko00003_oJf]X=oa8B4Pkooooo000<ooooo`ko20P83_l>3Ph=oadM7A?ooooo3_l^;Rh>
o`d=3@go2PX:3Om6ATH6ooooo`ko30`<3_lM7Ad=oemOG`goK6a/1_ooool>oadM7@ko2@T93Ol0000=
oc@d=0Kooooo3_lG5aL=oc4a<@koADE53OmQHF46ooooo`ko<30`3Ol410@>o`0001?ooooo3_mFEUH=
oc0`<0ko;2`/3Olf=SH6ooooo`goA4A43_l0000>om[JfPgo4Q8B3_ooool000cooooo3_l820P>o`h>
3Pgo7AdM4oooool>obh^;Pko3@d=3Ol:2PX=odI6APKooooo3_l<30`>oadM7@goGemO3Om/K6`6oooo
o`ko7AdM3_l92@T=o`0000go=3@d1_ooool>oaLG5`go<C4a3_m5ADD=of5QH@Kooooo3_l`<30=o`@4
10ko00004oooool>oeIFEPgo<30`3_l/;2`=ocHf=PKooooo3Om4A4@>o`0000kof][J3OlB4Q8>oooo
o`003?ooool>o`P820ko3Ph>3OlM7AdCooooo`ko;Rh^3_l=3@d=o`X:2PgoATI61_ooool>o``<30ko
7AdM3OmOGel=ofa/K0Kooooo3_lM7Ad>o`T92@go00003Old=3@6ooooo`ko5aLG3Ola<C4>odE5A@go
HF5Q1_ooool>oc0`<0go10@43_l0000Cooooo`koEUIF3Ol`<30>ob`/;0go=SHf1_ooool=odA4A0ko
00003_oJf]X=oa8B4Pkooooo000<ooooo`ko20P83_l>3Ph=oadM7A?ooooo3_l^;Rh>o`d=3@go2PX:
3Om6ATH6ooooo`ko30`<3_lM7Ad=oemOG`goK6a/1_ooool>oadM7@ko2@T93Ol0000=oc@d=0Kooooo
3_lG5aL=oc4a<@koADE53OmQHF46ooooo`ko<30`3Ol410@>o`0001?ooooo3_mFEUH=oc0`<0ko;2`/
3Olf=SH6ooooo`goA4A43_l0000>om[JfPgo4Q8B3_ooool000cooooo3_l410@>o`T92@go92@T3Ooj
n_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l4
10@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE
5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_oo
ool000cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>
o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>
obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6
ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6oooo
o`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi
>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=oocl
o0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000co
oooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko
7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`go
HV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`go
C4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B
3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_
3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo
3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l4
10@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf
][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_oo
ool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l1
0@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=
o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6
ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=
oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T9
2@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVI
V@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY
:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>oooo
o`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go
:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko
00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko
5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T
3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo
3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D5
3_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R
3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_oo
ool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9
RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3
@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l410@>o`T92@go92@T3Oojn_X6
ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`0000ko7alO3Onf][H=oiVIV@Kooooo3_l410@>
ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=
ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6ooooo`goC4a<3_l10@4>ooooo`go8R8R3_ooool0
00cooooo3_l410@>o`T92@go92@T3Oojn_X6ooooo`ko4Q8B3_l410@=o`L71`go:BTY1_ooool>o`00
00ko7alO3Onf][H=oiVIV@Kooooo3_l410@>ocTi>@go;bl_3Ol<30`6ooooo`ko00003On9RHT>obl_
;`goHV9R1_ooool>obTY:@go1@D53_lE5AD=ooclo0Kooooo3_ofm_H=oc/k>`ko5aLG3Om3@d<6oooo
o`goC4a<3_l10@4>ooooo`go8R8R3_ooool000cooooo3_l@410>o`0000go5QHF3OoKfm/6ooooo`ko
6QXJ3_l20P8=obPX:0go3@d=1_ooool>o`d=3@ko4Q8B3Oooool=ogIfMPKooooo3_l_;bl>ooooo`go
Fe]K3Ol51@D6ooooo`ko61PH3Oooool>o`/;2`goKVi^1_ooool>ob0P80go2`/;3_lA4A4=ok:b/QCo
oooo3OlZ:RX>o`0000go@T921_ooool=ocdm?@ko2PX:3_o>c/h=oa`L70kooooo000<ooooo`ko410@
3_l0000=oaHF5Pgofm_K1_ooool>oaXJ6Pko0P823OlX:2P=o`d=3@Kooooo3_l=3@d>oa8B4Pgooooo
3OmfMWH6ooooo`ko;bl_3_ooool=oe]KF`go1@D51_ooool>oaPH60gooooo3_l;2`/=ofi^KPKooooo
3_lP820=o`/;2`ko4A4A3Onb/[8Dooooo`go:RXZ3_l0000=od92@PKooooo3Olm?Cd>o`X:2Pkoc/k>
3OlL71`>ooooo`003?ooool>oa0@40ko00003OlF5QH=om_Kf`Kooooo3_lJ6QX>o`820Pgo:2PX3Ol=
3@d6ooooo`ko3@d=3_lB4Q8=ooooo`goMWIf1_ooool>obl_;`kooooo3OmKFe/=o`D51@Kooooo3_lH
61P=ooooo`ko2`/;3Om^KVh6ooooo`ko820P3Ol;2`/>oa4A4@go/[:b5?ooool=obXZ:Pko00003Om2
@T86ooooo`go?Cdm3_l:2PX>olk>cPgo71`L3_ooool000cooooo3_l@410>o`0000go5QHF3OoKfm/6
ooooo`ko6QXJ3_l20P8=obPX:0go3@d=1_ooool>o`d=3@ko4Q8B3Oooool=ogIfMPKooooo3_l_;bl>
ooooo`goFe]K3Ol51@D6ooooo`ko61PH3Oooool>o`/;2`goKVi^1_ooool>ob0P80go2`/;3_lA4A4=
ok:b/QCooooo3OlZ:RX>o`0000go@T921_ooool=ocdm?@ko2PX:3_o>c/h=oa`L70kooooo000<oooo
o`ko410@3_l0000=oaHF5Pgofm_K1_ooool>oaXJ6Pko0P823OlX:2P=o`d=3@Kooooo3_l=3@d>oa8B
4Pgooooo3OmfMWH6ooooo`ko;bl_3_ooool=oe]KF`go1@D51_ooool>oaPH60gooooo3_l;2`/=ofi^
KPKooooo3_lP820=o`/;2`ko4A4A3Onb/[8Dooooo`go:RXZ3_l0000=od92@PKooooo3Olm?Cd>o`X:
2Pkoc/k>3OlL71`>ooooo`003?ooool>oa0@40ko00003OlF5QH=om_Kf`Kooooo3_lJ6QX>o`820Pgo
:2PX3Ol=3@d6ooooo`ko3@d=3_lB4Q8=ooooo`goMWIf1_ooool>obl_;`kooooo3OmKFe/=o`D51@Ko
oooo3_lH61P=ooooo`ko2`/;3Om^KVh6ooooo`ko820P3Ol;2`/>oa4A4@go/[:b5?ooool=obXZ:Pko
00003Om2@T86ooooo`go?Cdm3_l:2PX>olk>cPgo71`L3_ooool000cooooo3_l@410>o`0000go5QHF
3OoKfm/6ooooo`ko6QXJ3_l20P8=obPX:0go3@d=1_ooool>o`d=3@ko4Q8B3Oooool=ogIfMPKooooo
3_l_;bl>ooooo`goFe]K3Ol51@D6ooooo`ko61PH3Oooool>o`/;2`goKVi^1_ooool>ob0P80go2`/;
3_lA4A4=ok:b/QCooooo3OlZ:RX>o`0000go@T921_ooool=ocdm?@ko2PX:3_o>c/h=oa`L70kooooo
000<ooooo`ko410@3_l0000=oaHF5Pgofm_K1_ooool>oaXJ6Pko0P823OlX:2P=o`d=3@Kooooo3_l=
3@d>oa8B4Pgooooo3OmfMWH6ooooo`ko;bl_3_ooool=oe]KF`go1@D51_ooool>oaPH60gooooo3_l;
2`/=ofi^KPKooooo3_lP820=o`/;2`ko4A4A3Onb/[8Dooooo`go:RXZ3_l0000=od92@PKooooo3Olm
?Cd>o`X:2Pkoc/k>3OlL71`>ooooo`003?ooool>oa0@40ko00003OlF5QH=om_Kf`Kooooo3_lJ6QX>
o`820Pgo:2PX3Ol=3@d6ooooo`ko3@d=3_lB4Q8=ooooo`goMWIf1_ooool>obl_;`kooooo3OmKFe/=
o`D51@Kooooo3_lH61P=ooooo`ko2`/;3Om^KVh6ooooo`ko820P3Ol;2`/>oa4A4@go/[:b5?ooool=
obXZ:Pko00003Om2@T86ooooo`go?Cdm3_l:2PX>olk>cPgo71`L3_ooool000cooooo3_l@410>o`00
00go5QHF3OoKfm/6ooooo`ko6QXJ3_l20P8=obPX:0go3@d=1_ooool>o`d=3@ko4Q8B3Oooool=ogIf
MPKooooo3_l_;bl>ooooo`goFe]K3Ol51@D6ooooo`ko61PH3Oooool>o`/;2`goKVi^1_ooool>ob0P
80go2`/;3_lA4A4=ok:b/QCooooo3OlZ:RX>o`0000go@T921_ooool=ocdm?@ko2PX:3_o>c/h=oa`L
70kooooo000<ooooo`ko410@3_l0000=oaHF5Pgofm_K1_ooool>oaXJ6Pko0P823OlX:2P=o`d=3@Ko
oooo3_l=3@d>oa8B4Pgooooo3OmfMWH6ooooo`ko;bl_3_ooool=oe]KF`go1@D51_ooool>oaPH60go
oooo3_l;2`/=ofi^KPKooooo3_lP820=o`/;2`ko4A4A3Onb/[8Dooooo`go:RXZ3_l0000=od92@PKo
oooo3Olm?Cd>o`X:2Pkoc/k>3OlL71`>ooooo`003?ooool>oa0@40ko00003OlF5QH=om_Kf`Kooooo
3_lJ6QX>o`820Pgo:2PX3Ol=3@d6ooooo`ko3@d=3_lB4Q8=ooooo`goMWIf1_ooool>obl_;`kooooo
3OmKFe/=o`D51@Kooooo3_lH61P=ooooo`ko2`/;3Om^KVh6ooooo`ko820P3Ol;2`/>oa4A4@go/[:b
5?ooool=obXZ:Pko00003Om2@T86ooooo`go?Cdm3_l:2PX>olk>cPgo71`L3_ooool000cooooo3_l@
410>o`0000go5QHF3OoKfm/6ooooo`ko6QXJ3_l20P8=obPX:0go3@d=1_ooool>o`d=3@ko4Q8B3Ooo
ool=ogIfMPKooooo3_l_;bl>ooooo`goFe]K3Ol51@D6ooooo`ko61PH3Oooool>o`/;2`goKVi^1_oo
ool>ob0P80go2`/;3_lA4A4=ok:b/QCooooo3OlZ:RX>o`0000go@T921_ooool=ocdm?@ko2PX:3_o>
c/h=oa`L70kooooo000<ooooo`ko410@3_l0000=oaHF5Pgofm_K1_ooool>oaXJ6Pko0P823OlX:2P=
o`d=3@Kooooo3_l=3@d>oa8B4Pgooooo3OmfMWH6ooooo`ko;bl_3_ooool=oe]KF`go1@D51_ooool>
oaPH60gooooo3_l;2`/=ofi^KPKooooo3_lP820=o`/;2`ko4A4A3Onb/[8Dooooo`go:RXZ3_l0000=
od92@PKooooo3Olm?Cd>o`X:2Pkoc/k>3OlL71`>ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`003?ooool>ogAdM0ko
RHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo
;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko
2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`ko
h>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV
3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo
3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b
3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoX
j>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_oo
ool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0
000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1
PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6
ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=
om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=
oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKV
iPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L
70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:
2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>oooo
o`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko
4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko
:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Ko
oooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo
3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj
3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R
1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?oo
ool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX
:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9
BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0
000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>
o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=
oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>
onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAd
M0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkN
gPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6oooo
o`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;
2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go
9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Ko
oooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go
<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV9
3OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^
1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T9
3Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P
3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=onKViPKooooo3_mGEeL>o`D51@go9RHV3On]
[Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=
3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0
000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>ooooo`003?ooool>ogAdM0koRHV93OoXj>P=
onKViPKooooo3_mGEeL>o`D51@go9RHV3On][Jd6ooooo`ko4a<C3_lX:2P=omkNgPgo;Rh^1_ooool>
oa`L70koNWYj3OlY:BT=oaLG5`Kooooo3_l=3@d=om[JfPko:b/[3Om9BDT6ooooo`ko2@T93Ol0000>
o`X:2Pgo8R8R1_ooool>onOWi`go<S8b3_l0000=oa4A4@Kooooo3Ol0000>o`/;2`koh>3P3On1PH4>
ooooo`003?ooool>obPX:0koRHV93OnIVIT=ojb/[0Kooooo3_mJFUX>o`<30`go5QHF3Oo]kNd6oooo
o`ko2@T93_lB4Q8=ooooo`go6QXJ1_ooool>od51@@kooooo3OmDE5@=o`/;2`Kooooo3_l61PH=oooo
o`ko3@d=3OlM7Ad6ooooo`ko820P3Ol71`L>oa@D50go820P5?ooool=oa4A4@ko1@D53OlR8R86oooo
o`go0P823_lD51@>ooooo`goRh^;3_ooool000cooooo3_lX:2P>ohV9R@goVIVI3On/[:`6ooooo`ko
FUYJ3_l30`<=oaHF5PgokNg]1_ooool>o`T92@ko4Q8B3Oooool=oaXJ6PKooooo3_m1@D4>ooooo`go
E5AD3Ol;2`/6ooooo`ko1PH63Oooool>o`d=3@go7AdM1_ooool>ob0P80go1`L73_lD51@=ob0P81Co
oooo3OlA4A4>o`D51@go8R8R1_ooool=o`820Pko51@D3_ooool=oh^;R`kooooo000<ooooo`ko:2PX
3_n9RHT=oiVIV@go[:b/1_ooool>oeYJFPko0`<33OlF5QH=ong]k@Kooooo3_l92@T>oa8B4Pgooooo
3OlJ6QX6ooooo`ko@D513_ooool=oeADE0go2`/;1_ooool>o`H61Pgooooo3_l=3@d=oadM7@Kooooo
3_lP820=o`L71`ko51@D3OlP820Dooooo`go4A4A3_l51@D=ob8R8PKooooo3Ol20P8>oa@D50kooooo
3On;Rh/>ooooo`003?ooool>obPX:0koRHV93OnIVIT=ojb/[0Kooooo3_mJFUX>o`<30`go5QHF3Oo]
kNd6ooooo`ko2@T93_lB4Q8=ooooo`go6QXJ1_ooool>od51@@kooooo3OmDE5@=o`/;2`Kooooo3_l6
1PH=ooooo`ko3@d=3OlM7Ad6ooooo`ko820P3Ol71`L>oa@D50go820P5?ooool=oa4A4@ko1@D53OlR
8R86ooooo`go0P823_lD51@>ooooo`goRh^;3_ooool000cooooo3_lX:2P>ohV9R@goVIVI3On/[:`6
ooooo`koFUYJ3_l30`<=oaHF5PgokNg]1_ooool>o`T92@ko4Q8B3Oooool=oaXJ6PKooooo3_m1@D4>
ooooo`goE5AD3Ol;2`/6ooooo`ko1PH63Oooool>o`d=3@go7AdM1_ooool>ob0P80go1`L73_lD51@=
ob0P81Cooooo3OlA4A4>o`D51@go8R8R1_ooool=o`820Pko51@D3_ooool=oh^;R`kooooo000<oooo
o`ko:2PX3_n9RHT=oiVIV@go[:b/1_ooool>oeYJFPko0`<33OlF5QH=ong]k@Kooooo3_l92@T>oa8B
4Pgooooo3OlJ6QX6ooooo`ko@D513_ooool=oeADE0go2`/;1_ooool>o`H61Pgooooo3_l=3@d=oadM
7@Kooooo3_lP820=o`L71`ko51@D3OlP820Dooooo`go4A4A3_l51@D=ob8R8PKooooo3Ol20P8>oa@D
50kooooo3On;Rh/>ooooo`003?ooool>obPX:0koRHV93OnIVIT=ojb/[0Kooooo3_mJFUX>o`<30`go
5QHF3Oo]kNd6ooooo`ko2@T93_lB4Q8=ooooo`go6QXJ1_ooool>od51@@kooooo3OmDE5@=o`/;2`Ko
oooo3_l61PH=ooooo`ko3@d=3OlM7Ad6ooooo`ko820P3Ol71`L>oa@D50go820P5?ooool=oa4A4@ko
1@D53OlR8R86ooooo`go0P823_lD51@>ooooo`goRh^;3_ooool000cooooo3_lX:2P>ohV9R@goVIVI
3On/[:`6ooooo`koFUYJ3_l30`<=oaHF5PgokNg]1_ooool>o`T92@ko4Q8B3Oooool=oaXJ6PKooooo
3_m1@D4>ooooo`goE5AD3Ol;2`/6ooooo`ko1PH63Oooool>o`d=3@go7AdM1_ooool>ob0P80go1`L7
3_lD51@=ob0P81Cooooo3OlA4A4>o`D51@go8R8R1_ooool=o`820Pko51@D3_ooool=oh^;R`kooooo
000<ooooo`ko:2PX3_n9RHT=oiVIV@go[:b/1_ooool>oeYJFPko0`<33OlF5QH=ong]k@Kooooo3_l9
2@T>oa8B4Pgooooo3OlJ6QX6ooooo`ko@D513_ooool=oeADE0go2`/;1_ooool>o`H61Pgooooo3_l=
3@d=oadM7@Kooooo3_lP820=o`L71`ko51@D3OlP820Dooooo`go4A4A3_l51@D=ob8R8PKooooo3Ol2
0P8>oa@D50kooooo3On;Rh/>ooooo`003?ooool>obPX:0koRHV93OnIVIT=ojb/[0Kooooo3_mJFUX>
o`<30`go5QHF3Oo]kNd6ooooo`ko2@T93_lB4Q8=ooooo`go6QXJ1_ooool>od51@@kooooo3OmDE5@=
o`/;2`Kooooo3_l61PH=ooooo`ko3@d=3OlM7Ad6ooooo`ko820P3Ol71`L>oa@D50go820P5?ooool=
oa4A4@ko1@D53OlR8R86ooooo`go0P823_lD51@>ooooo`goRh^;3_ooool000cooooo3_lX:2P>ohV9
R@goVIVI3On/[:`6ooooo`koFUYJ3_l30`<=oaHF5PgokNg]1_ooool>o`T92@ko4Q8B3Oooool=oaXJ
6PKooooo3_m1@D4>ooooo`goE5AD3Ol;2`/6ooooo`ko1PH63Oooool>o`d=3@go7AdM1_ooool>ob0P
80go1`L73_lD51@=ob0P81Cooooo3OlA4A4>o`D51@go8R8R1_ooool=o`820Pko51@D3_ooool=oh^;
R`kooooo000<ooooo`ko:2PX3_n9RHT=oiVIV@go[:b/1_ooool>oeYJFPko0`<33OlF5QH=ong]k@Ko
oooo3_l92@T>oa8B4Pgooooo3OlJ6QX6ooooo`ko@D513_ooool=oeADE0go2`/;1_ooool>o`H61Pgo
oooo3_l=3@d=oadM7@Kooooo3_lP820=o`L71`ko51@D3OlP820Dooooo`go4A4A3_l51@D=ob8R8PKo
oooo3Ol20P8>oa@D50kooooo3On;Rh/>ooooo`003?ooool>obPX:0koRHV93OnIVIT=ojb/[0Kooooo
3_mJFUX>o`<30`go5QHF3Oo]kNd6ooooo`ko2@T93_lB4Q8=ooooo`go6QXJ1_ooool>od51@@kooooo
3OmDE5@=o`/;2`Kooooo3_l61PH=ooooo`ko3@d=3OlM7Ad6ooooo`ko820P3Ol71`L>oa@D50go820P
5?ooool=oa4A4@ko1@D53OlR8R86ooooo`go0P823_lD51@>ooooo`goRh^;3_ooool000cooooo3_l0
000>oiJFUPgo/k>c3OnYZJT6ooooo`koD51@3_l0000=o``<31?ooooo3_l0000>obHV9Pgokno_3Ol?
3`l6ooooo`ko9RHV3_lA4A4=oa/K6`go;bl_1_ooool>ob0P80goo?cl3_l0000=o`@410Kooooo3_lN
7Qh=o`h>3Pko3@d=3Om<C4`6ooooo`koc<c<3Ol30`<>oa/K6`go;Rh^1_ooool=o`<30`ko820P3_nY
ZJT=ofm_K`kooooo000<ooooo`ko00003_nFUYH=ok>c/`goZJVY1_ooool>oe1@D0ko00003Ol<30`C
ooooo`ko00003_lV9RH=ono_k`go3`l?1_ooool>obHV9Pko4A4A3OlK6a/=obl_;`Kooooo3_lP820=
ooclo0ko00003Ol410@6ooooo`ko7QhN3Ol>3Ph>o`d=3@goC4a<1_ooool>olc<c0go0`<33_lK6a/=
obh^;PKooooo3Ol30`<>ob0P80koZJVY3Om_Kfl>ooooo`003?ooool>o`0000koUYJF3Onc/k<=ojVY
Z@Kooooo3_m@D50>o`0000go30`<4oooool>o`0000ko9RHV3Oo_knl=o`l?3`Kooooo3_lV9RH>oa4A
4@go6a/K3Ol_;bl6ooooo`ko820P3Oolo?`>o`0000go10@41_ooool>oahN7Pgo3Ph>3_l=3@d=oda<
C0Kooooo3_o<c<`=o`<30`ko6a/K3Ol^;Rh6ooooo`go0`<33_lP820>ojVYZ@goKfm_3_ooool000co
oooo3_l0000>oiJFUPgo/k>c3OnYZJT6ooooo`koD51@3_l0000=o``<31?ooooo3_l0000>obHV9Pgo
kno_3Ol?3`l6ooooo`ko9RHV3_lA4A4=oa/K6`go;bl_1_ooool>ob0P80goo?cl3_l0000=o`@410Ko
oooo3_lN7Qh=o`h>3Pko3@d=3Om<C4`6ooooo`koc<c<3Ol30`<>oa/K6`go;Rh^1_ooool=o`<30`ko
820P3_nYZJT=ofm_K`kooooo000<ooooo`ko00003_nFUYH=ok>c/`goZJVY1_ooool>oe1@D0ko0000
3Ol<30`Cooooo`ko00003_lV9RH=ono_k`go3`l?1_ooool>obHV9Pko4A4A3OlK6a/=obl_;`Kooooo
3_lP820=ooclo0ko00003Ol410@6ooooo`ko7QhN3Ol>3Ph>o`d=3@goC4a<1_ooool>olc<c0go0`<3
3_lK6a/=obh^;PKooooo3Ol30`<>ob0P80koZJVY3Om_Kfl>ooooo`003?ooool>o`0000koUYJF3Onc
/k<=ojVYZ@Kooooo3_m@D50>o`0000go30`<4oooool>o`0000ko9RHV3Oo_knl=o`l?3`Kooooo3_lV
9RH>oa4A4@go6a/K3Ol_;bl6ooooo`ko820P3Oolo?`>o`0000go10@41_ooool>oahN7Pgo3Ph>3_l=
3@d=oda<C0Kooooo3_o<c<`=o`<30`ko6a/K3Ol^;Rh6ooooo`go0`<33_lP820>ojVYZ@goKfm_3_oo
ool000cooooo3_l0000>oiJFUPgo/k>c3OnYZJT6ooooo`koD51@3_l0000=o``<31?ooooo3_l0000>
obHV9Pgokno_3Ol?3`l6ooooo`ko9RHV3_lA4A4=oa/K6`go;bl_1_ooool>ob0P80goo?cl3_l0000=
o`@410Kooooo3_lN7Qh=o`h>3Pko3@d=3Om<C4`6ooooo`koc<c<3Ol30`<>oa/K6`go;Rh^1_ooool=
o`<30`ko820P3_nYZJT=ofm_K`kooooo000<ooooo`ko00003_nFUYH=ok>c/`goZJVY1_ooool>oe1@
D0ko00003Ol<30`Cooooo`ko00003_lV9RH=ono_k`go3`l?1_ooool>obHV9Pko4A4A3OlK6a/=obl_
;`Kooooo3_lP820=ooclo0ko00003Ol410@6ooooo`ko7QhN3Ol>3Ph>o`d=3@goC4a<1_ooool>olc<
c0go0`<33_lK6a/=obh^;PKooooo3Ol30`<>ob0P80koZJVY3Om_Kfl>ooooo`003?ooool>o`0000ko
UYJF3Onc/k<=ojVYZ@Kooooo3_m@D50>o`0000go30`<4oooool>o`0000ko9RHV3Oo_knl=o`l?3`Ko
oooo3_lV9RH>oa4A4@go6a/K3Ol_;bl6ooooo`ko820P3Oolo?`>o`0000go10@41_ooool>oahN7Pgo
3Ph>3_l=3@d=oda<C0Kooooo3_o<c<`=o`<30`ko6a/K3Ol^;Rh6ooooo`go0`<33_lP820>ojVYZ@go
Kfm_3_ooool000cooooo3_l0000>oiJFUPgo/k>c3OnYZJT6ooooo`koD51@3_l0000=o``<31?ooooo
3_l0000>obHV9Pgokno_3Ol?3`l6ooooo`ko9RHV3_lA4A4=oa/K6`go;bl_1_ooool>ob0P80goo?cl
3_l0000=o`@410Kooooo3_lN7Qh=o`h>3Pko3@d=3Om<C4`6ooooo`koc<c<3Ol30`<>oa/K6`go;Rh^
1_ooool=o`<30`ko820P3_nYZJT=ofm_K`kooooo000<ooooo`ko00003_nFUYH=ok>c/`goZJVY1_oo
ool>oe1@D0ko00003Ol<30`Cooooo`ko00003_lV9RH=ono_k`go3`l?1_ooool>obHV9Pko4A4A3OlK
6a/=obl_;`Kooooo3_lP820=ooclo0ko00003Ol410@6ooooo`ko7QhN3Ol>3Ph>o`d=3@goC4a<1_oo
ool>olc<c0go0`<33_lK6a/=obh^;PKooooo3Ol30`<>ob0P80koZJVY3Om_Kfl>ooooo`003?ooool>
o`0000koUYJF3Onc/k<=ojVYZ@Kooooo3_m@D50>o`0000go30`<4oooool>o`0000ko9RHV3Oo_knl=
o`l?3`Kooooo3_lV9RH>oa4A4@go6a/K3Ol_;bl6ooooo`ko820P3Oolo?`>o`0000go10@41_ooool>
oahN7Pgo3Ph>3_l=3@d=oda<C0Kooooo3_o<c<`=o`<30`ko6a/K3Ol^;Rh6ooooo`go0`<33_lP820>
ojVYZ@goKfm_3_ooool000cooooo3_l0000>oiJFUPgo/k>c3OnYZJT6ooooo`koD51@3_l0000=o``<
31?ooooo3_l0000>obHV9Pgokno_3Ol?3`l6ooooo`ko9RHV3_lA4A4=oa/K6`go;bl_1_ooool>ob0P
80goo?cl3_l0000=o`@410Kooooo3_lN7Qh=o`h>3Pko3@d=3Om<C4`6ooooo`koc<c<3Ol30`<>oa/K
6`go;Rh^1_ooool=o`<30`ko820P3_nYZJT=ofm_K`kooooo000<ooooo`ko<30`3_n5QHD=olS8b1?o
oooo3_lm?Cd>o`P820go410@3OoBd]86ooooo`ko410@3_lJ6QX=olk>cPgo4a<C1_ooool>o`h>3Pko
00003Ol820P=oa@D50Kooooo3_lN7Qh=ol;2`Pko410@3Ol10@46ooooo`ko8B4Q3Ol10@4>o`l?3a?o
oooo3_o>c/h=o`h>3Pko9RHV3OlQ8B46ooooo`go2`/;3_lX:2P>of1PH0goDE5A3_ooool000cooooo
3_l`<30>ohF5Q@gob<S84oooool>ocdm?@ko20P83Ol@410=om;BdPKooooo3_l@410>oaXJ6Pgoc/k>
3OlC4a<6ooooo`ko3Ph>3_l0000=o`P820go51@D1_ooool>oahN7Pgo`/;23_l@410=o`410@Kooooo
3_lQ8B4=o`410@ko3`l?4oooool>olk>cPgo3Ph>3_lV9RH=ob4Q8@Kooooo3Ol;2`/>obPX:0koH61P
3OmADE4>ooooo`003?ooool>oc0`<0koQHF53Oo8b<PCooooo`ko?Cdm3_l820P=oa0@40god];B1_oo
ool>oa0@40ko6QXJ3Oo>c/h=oa<C4`Kooooo3_l>3Ph>o`0000go20P83OlD51@6ooooo`ko7QhN3Oo2
`/8>oa0@40go0@411_ooool>ob4Q8@go0@413_l?3`lCooooo`koc/k>3Ol>3Ph>obHV9Pgo8B4Q1_oo
ool=o`/;2`ko:2PX3_mPH60=oe5AD@kooooo000<ooooo`ko<30`3_n5QHD=olS8b1?ooooo3_lm?Cd>
o`P820go410@3OoBd]86ooooo`ko410@3_lJ6QX=olk>cPgo4a<C1_ooool>o`h>3Pko00003Ol820P=
oa@D50Kooooo3_lN7Qh=ol;2`Pko410@3Ol10@46ooooo`ko8B4Q3Ol10@4>o`l?3a?ooooo3_o>c/h=
o`h>3Pko9RHV3OlQ8B46ooooo`go2`/;3_lX:2P>of1PH0goDE5A3_ooool000cooooo3_l`<30>ohF5
Q@gob<S84oooool>ocdm?@ko20P83Ol@410=om;BdPKooooo3_l@410>oaXJ6Pgoc/k>3OlC4a<6oooo
o`ko3Ph>3_l0000=o`P820go51@D1_ooool>oahN7Pgo`/;23_l@410=o`410@Kooooo3_lQ8B4=o`41
0@ko3`l?4oooool>olk>cPgo3Ph>3_lV9RH=ob4Q8@Kooooo3Ol;2`/>obPX:0koH61P3OmADE4>oooo
o`003?ooool>oc0`<0koQHF53Oo8b<PCooooo`ko?Cdm3_l820P=oa0@40god];B1_ooool>oa0@40ko
6QXJ3Oo>c/h=oa<C4`Kooooo3_l>3Ph>o`0000go20P83OlD51@6ooooo`ko7QhN3Oo2`/8>oa0@40go
0@411_ooool>ob4Q8@go0@413_l?3`lCooooo`koc/k>3Ol>3Ph>obHV9Pgo8B4Q1_ooool=o`/;2`ko
:2PX3_mPH60=oe5AD@kooooo000<ooooo`ko<30`3_n5QHD=olS8b1?ooooo3_lm?Cd>o`P820go410@
3OoBd]86ooooo`ko410@3_lJ6QX=olk>cPgo4a<C1_ooool>o`h>3Pko00003Ol820P=oa@D50Kooooo
3_lN7Qh=ol;2`Pko410@3Ol10@46ooooo`ko8B4Q3Ol10@4>o`l?3a?ooooo3_o>c/h=o`h>3Pko9RHV
3OlQ8B46ooooo`go2`/;3_lX:2P>of1PH0goDE5A3_ooool000cooooo3_l`<30>ohF5Q@gob<S84ooo
ool>ocdm?@ko20P83Ol@410=om;BdPKooooo3_l@410>oaXJ6Pgoc/k>3OlC4a<6ooooo`ko3Ph>3_l0
000=o`P820go51@D1_ooool>oahN7Pgo`/;23_l@410=o`410@Kooooo3_lQ8B4=o`410@ko3`l?4ooo
ool>olk>cPgo3Ph>3_lV9RH=ob4Q8@Kooooo3Ol;2`/>obPX:0koH61P3OmADE4>ooooo`003?ooool>
oc0`<0koQHF53Oo8b<PCooooo`ko?Cdm3_l820P=oa0@40god];B1_ooool>oa0@40ko6QXJ3Oo>c/h=
oa<C4`Kooooo3_l>3Ph>o`0000go20P83OlD51@6ooooo`ko7QhN3Oo2`/8>oa0@40go0@411_ooool>
ob4Q8@go0@413_l?3`lCooooo`koc/k>3Ol>3Ph>obHV9Pgo8B4Q1_ooool=o`/;2`ko:2PX3_mPH60=
oe5AD@kooooo000<ooooo`ko<30`3_n5QHD=olS8b1?ooooo3_lm?Cd>o`P820go410@3OoBd]86oooo
o`ko410@3_lJ6QX=olk>cPgo4a<C1_ooool>o`h>3Pko00003Ol820P=oa@D50Kooooo3_lN7Qh=ol;2
`Pko410@3Ol10@46ooooo`ko8B4Q3Ol10@4>o`l?3a?ooooo3_o>c/h=o`h>3Pko9RHV3OlQ8B46oooo
o`go2`/;3_lX:2P>of1PH0goDE5A3_ooool000cooooo3_l`<30>ohF5Q@gob<S84oooool>ocdm?@ko
20P83Ol@410=om;BdPKooooo3_l@410>oaXJ6Pgoc/k>3OlC4a<6ooooo`ko3Ph>3_l0000=o`P820go
51@D1_ooool>oahN7Pgo`/;23_l@410=o`410@Kooooo3_lQ8B4=o`410@ko3`l?4oooool>olk>cPgo
3Ph>3_lV9RH=ob4Q8@Kooooo3Ol;2`/>obPX:0koH61P3OmADE4>ooooo`003?ooool>oc0`<0koQHF5
3Oo8b<PCooooo`ko?Cdm3_l820P=oa0@40god];B1_ooool>oa0@40ko6QXJ3Oo>c/h=oa<C4`Kooooo
3_l>3Ph>o`0000go20P83OlD51@6ooooo`ko7QhN3Oo2`/8>oa0@40go0@411_ooool>ob4Q8@go0@41
3_l?3`lCooooo`koc/k>3Ol>3Ph>obHV9Pgo8B4Q1_ooool=o`/;2`ko:2PX3_mPH60=oe5AD@kooooo
000<ooooo`ko<30`3_n5QHD=olS8b1?ooooo3_lm?Cd>o`P820go410@3OoBd]86ooooo`ko410@3_lJ
6QX=olk>cPgo4a<C1_ooool>o`h>3Pko00003Ol820P=oa@D50Kooooo3_lN7Qh=ol;2`Pko410@3Ol1
0@46ooooo`ko8B4Q3Ol10@4>o`l?3a?ooooo3_o>c/h=o`h>3Pko9RHV3OlQ8B46ooooo`go2`/;3_lX
:2P>of1PH0goDE5A3_ooool000cooooo3_l`<30>ohF5Q@gob<S84oooool>ocdm?@ko20P83Ol@410=
om;BdPKooooo3_l@410>oaXJ6Pgoc/k>3OlC4a<6ooooo`ko3Ph>3_l0000=o`P820go51@D1_ooool>
oahN7Pgo`/;23_l@410=o`410@Kooooo3_lQ8B4=o`410@ko3`l?4oooool>olk>cPgo3Ph>3_lV9RH=
ob4Q8@Kooooo3Ol;2`/>obPX:0koH61P3OmADE4>ooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-0.905992, \
-0.431217, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-5.30741, -0.431217, 0.0733952, 0.0733952}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-9.70883, -0.431217, 0.0733952, 0.0733952}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-14.1103, -0.431217, 0.0733952, 0.0733952}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-18.5094, -0.431217, 0.0733952, 0.0733952}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-22.9131, -0.431217, 0.0733952, \
0.0733952}, {{372.125, 426.625}, {240.25, 185.75}} -> {-27.3122, -0.431217, \
0.0733952, 0.0733952}, {{432.062, 486.625}, {240.25, 185.75}} -> {-31.7136, \
-0.431217, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-0.905992, -4.83493, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-5.30741, -4.83493, 0.0733952, 0.0733952}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-9.70883, -4.83493, 0.0733952, 0.0733952}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-14.1103, -4.83493, 0.0733952, 0.0733952}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-18.5094, -4.83493, 0.0733952, \
0.0733952}, {{312.188, 366.688}, {180.25, 125.75}} -> {-22.9131, -4.83493, \
0.0733952, 0.0733952}, {{372.125, 426.625}, {180.25, 125.75}} -> {-27.3122, \
-4.83493, 0.0733952, 0.0733952}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-31.7136, -4.83493, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-0.905992, -9.23406, 0.0733952, 0.0733952}, {{72.3125, \
126.812}, {120.312, 65.8125}} -> {-5.30741, -9.23406, 0.0733952, 0.0733952}, \
{{132.25, 186.812}, {120.312, 65.8125}} -> {-9.70883, -9.23406, 0.0733952, \
0.0733952}, {{192.25, 246.75}, {120.312, 65.8125}} -> {-14.1103, -9.23406, \
0.0733952, 0.0733952}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-18.5094, \
-9.23406, 0.0733952, 0.0733952}, {{312.188, 366.688}, {120.312, 65.8125}} -> \
{-22.9131, -9.23406, 0.0733952, 0.0733952}, {{372.125, 426.625}, {120.312, \
65.8125}} -> {-27.3122, -9.23406, 0.0733952, 0.0733952}, {{432.062, 486.625}, \
{120.312, 65.8125}} -> {-31.7136, -9.23406, 0.0733952, 0.0733952}, {{12.3125, \
66.875}, {60.3125, 5.8125}} -> {-0.905992, -13.6378, 0.0733952, 0.0733952}, \
{{72.3125, 126.812}, {60.3125, 5.8125}} -> {-5.30741, -13.6378, 0.0733952, \
0.0733952}, {{132.25, 186.812}, {60.3125, 5.8125}} -> {-9.70883, -13.6378, \
0.0733952, 0.0733952}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-14.1103, \
-13.6378, 0.0733952, 0.0733952}, {{252.188, 306.688}, {60.3125, 5.8125}} -> \
{-18.5094, -13.6378, 0.0733952, 0.0733952}, {{312.188, 366.688}, {60.3125, \
5.8125}} -> {-22.9131, -13.6378, 0.0733952, 0.0733952}, {{372.125, 426.625}, \
{60.3125, 5.8125}} -> {-27.3122, -13.6378, 0.0733952, 0.0733952}, {{432.062, \
486.625}, {60.3125, 5.8125}} -> {-31.7136, -13.6378, 0.0733952, 0.0733952}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49425 
%%ImageSize: 500 247.126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0117679 0.119048 [
[ 0 0 0 0 ]
[ 1 .49425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49425 L
0 .49425 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0117679 0.133279 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2325B926
0C62FF49
003DBC27
2304770F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0117679 0.253695 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7703214D
CE790027
FFFB2A10
44046A57
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0117679 0.374111 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11499BD3
6E0FC7C2
A600FF70
13767E93
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0117679 0.494527 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A8FF6C06
1FB2911C
00718C4E
D0CF1B10
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0117679 0.614943 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
441616FF
161B1A44
1408002A
18110E2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0117679 0.735359 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
14140A24
45310089
11130D29
4A0B07FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0117679 0.855774 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
002B1234
0E102420
09140B18
17FF4438
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0117679 0.97619 0.121237 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C18B000A
C6F06C09
6BFFC411
A12F0523
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.132184 0.133279 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A15B183C
FF520065
D64B0C61
0E123D11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.132184 0.253695 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
08303D49
4C00198D
FF5B006B
017A353C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.132184 0.374111 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E1C1016
07001E31
2A0824FF
2E150D16
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.132184 0.494527 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A8D1632
009E7783
0587FF8F
4A630D0C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.132184 0.614943 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19472000
0F111523
12091632
11FF0F32
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.132184 0.735359 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6306FF5B
69113922
70400014
3D15A4C8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.132184 0.855774 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2509213C
190F0B08
0016091B
141DFF19
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.132184 0.97619 0.241653 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B01130C
0C0C0A25
0F00070D
FF370719
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.2526 0.133279 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2909070F
1900060B
2611070C
FF20450B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.2526 0.253695 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4D00144A
FF2C0F35
47180416
0E222035
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.2526 0.374111 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00257B3A
0723FF1C
1B134023
01211F1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.2526 0.494527 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0018060D
1BFF3520
1429163F
0A16212E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.2526 0.614943 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
191C0CFF
0D17004D
1A062024
1A0D034F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.2526 0.735359 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
10201135
0D0D1B00
020A122C
222424FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.2526 0.855774 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05FFF534
002E7A60
48006769
4BD08C1F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.2526 0.97619 0.362069 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF72033D
957A0300
6C710D08
7B20116C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.373016 0.133279 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
341646C3
002C2889
768599FF
B43CFCF7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.373016 0.253695 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00062117
45050C13
FF101329
08132709
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.373016 0.374111 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E051012
1E0014FF
000C0E39
16051713
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.373016 0.494527 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B180900
12440F02
07FF4D2E
231D152C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.373016 0.614943 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E500906
0942020C
00401411
1CFF3518
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.373016 0.735359 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00100724
030E0C16
0F0F0C1D
21192BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.373016 0.855774 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
001D370B
17091206
48242921
0C24FF13
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.373016 0.97619 0.482485 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF580514
403B000C
1F432C3F
DB1D1146
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 247.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000mb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go
8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKo
oooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Ko
oooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo
3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo
3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[
3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni
^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_oo
ool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_oo
ool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>
ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=
oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>
o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>
ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6oooo
o`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF
5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;
R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go
8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKo
oooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Ko
oooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo
3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo
3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[
3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni
^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_oo
ool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_oo
ool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>
ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=
oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>
o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>
ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6oooo
o`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF
5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;
R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go
8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKo
oooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Ko
oooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni^KT=obHV9PKooooo
3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_ooool>ojRXZ0kooooo
3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_ooool>o`0000go:b/[
3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>ob<S8`ko9BDU3Oni
^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=oi^KV`godm?C1_oo
ool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>o`X:2Pgo92@T1_oo
ool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>ooooo`003?ooool>
ob<S8`ko9BDU3Oni^KT=obHV9PKooooo3_mgMgL>o`<30`go8B4Q3Om=CDd6ooooo`ko4A4A3_m9BDT=
oi^KV`godm?C1_ooool>ojRXZ0kooooo3Om/K6`=o`H61PKooooo3_m4A4@KoaHF5Q?ooooo6olD51@>
o`X:2Pgo92@T1_ooool>o`0000go:b/[3_lB4Q8=oc@d=0Kooooo3Oo1`L4>oh^;R`ko00003Ol:2PX>
ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6oooo
o`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K
6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P
80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Ko
oooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko
/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000go
RHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`00
3?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^
3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ
3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo
3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>
c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnA
TI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_oo
ool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>
o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=
olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6
ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>
oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUi
N@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L
70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>
3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30ko
HV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go
`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`ko
ADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0ko
K6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go0000
3OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo
3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@
3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Ooo
ool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_oo
ool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola
<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol9
2@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6
ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=
oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=
ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9
B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO
7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`00
00goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>oooo
o`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo3_o>c/h>ogUiN@go00003OlW9bL6ooooo`ko
KVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko
6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV91_ooool>o`h>3Pgo410@3_lT92@=ob0P80Ko
oooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?ooool>o``<30koHV9R3Oooool=odU9B@Kooooo
3_o>c/h>ogUiN@go00003OlW9bL6ooooo`koKVi^3_l?3`l=olO7a`go`/;21_ooool>oalO7`ko/[:b
3OnATI4=oa`L70Kooooo3_lF5QH=oa/K6`ko6QXJ3Om4A4@6ooooo`koADE53Ola<C4>o`0000goRHV9
1_ooool>o`h>3Pgo410@3_lT92@=ob0P80Kooooo3Oo6a/H>oo3`l0koK6a/3Ol92@T>ooooo`003?oo
ool>o`0000ko?Cdm3Onl_;`=obLW9aCooooo3_okno/=obXZ:Pgo410@1_ooool>ojJVYPko00003Ooo
ool=og1`L0Kooooo3_l0000>og5aL@goS8b<3Om>CTh6ooooo`ko51@D3Ol820P>o`0000go:RXZ1_oo
ool>oa4A4@go4a<C3_l=3@d=obTY:@Kooooo3_l92@T=oa@D50ko2`/;3OlH61P6ooooo`goJf][3_oo
ool>olC4a0go4A4A3_ooool000cooooo3_l0000>ocdm?@go_;bl3OlW9bLDooooo`kono_k3OlZ:RX=
oa0@40Kooooo3_nVYZH>o`0000gooooo3Om`L706ooooo`ko00003_maLG4=ohb<S0goCTi>1_ooool>
oa@D50go20P83_l0000=obXZ:PKooooo3_lA4A4=oa<C4`ko3@d=3OlY:BT6ooooo`ko2@T93OlD51@>
o`/;2`go61PH1_ooool=of][J`kooooo3_o4a<@=oa4A4@kooooo000<ooooo`ko00003_lm?Cd=okbl
_0go9bLW5?ooool>oo_kn`go:RXZ3Ol@4106ooooo`koYZJV3_l0000=ooooo`goL71`1_ooool>o`00
00koLG5a3On<S8`=odi>CPKooooo3_lD51@=o`P820ko00003OlZ:RX6ooooo`ko4A4A3OlC4a<>o`d=
3@go:BTY1_ooool>o`T92@go51@D3_l;2`/=oaPH60Kooooo3Om[Jf/>ooooo`koa<C43OlA4A4>oooo
o`003?ooool>o`0000ko?Cdm3Onl_;`=obLW9aCooooo3_okno/=obXZ:Pgo410@1_ooool>ojJVYPko
00003Oooool=og1`L0Kooooo3_l0000>og5aL@goS8b<3Om>CTh6ooooo`ko51@D3Ol820P>o`0000go
:RXZ1_ooool>oa4A4@go4a<C3_l=3@d=obTY:@Kooooo3_l92@T=oa@D50ko2`/;3OlH61P6ooooo`go
Jf][3_ooool>olC4a0go4A4A3_ooool000cooooo3_l0000>ocdm?@go_;bl3OlW9bLDooooo`kono_k
3OlZ:RX=oa0@40Kooooo3_nVYZH>o`0000gooooo3Om`L706ooooo`ko00003_maLG4=ohb<S0goCTi>
1_ooool>oa@D50go20P83_l0000=obXZ:PKooooo3_lA4A4=oa<C4`ko3@d=3OlY:BT6ooooo`ko2@T9
3OlD51@>o`/;2`go61PH1_ooool=of][J`kooooo3_o4a<@=oa4A4@kooooo000<ooooo`ko00003_lm
?Cd=okbl_0go9bLW5?ooool>oo_kn`go:RXZ3Ol@4106ooooo`koYZJV3_l0000=ooooo`goL71`1_oo
ool>o`0000koLG5a3On<S8`=odi>CPKooooo3_lD51@=o`P820ko00003OlZ:RX6ooooo`ko4A4A3OlC
4a<>o`d=3@go:BTY1_ooool>o`T92@go51@D3_l;2`/=oaPH60Kooooo3Om[Jf/>ooooo`koa<C43OlA
4A4>ooooo`003?ooool>o`0000ko?Cdm3Onl_;`=obLW9aCooooo3_okno/=obXZ:Pgo410@1_ooool>
ojJVYPko00003Oooool=og1`L0Kooooo3_l0000>og5aL@goS8b<3Om>CTh6ooooo`ko51@D3Ol820P>
o`0000go:RXZ1_ooool>oa4A4@go4a<C3_l=3@d=obTY:@Kooooo3_l92@T=oa@D50ko2`/;3OlH61P6
ooooo`goJf][3_ooool>olC4a0go4A4A3_ooool000cooooo3_l0000>ocdm?@go_;bl3OlW9bLDoooo
o`kono_k3OlZ:RX=oa0@40Kooooo3_nVYZH>o`0000gooooo3Om`L706ooooo`ko00003_maLG4=ohb<
S0goCTi>1_ooool>oa@D50go20P83_l0000=obXZ:PKooooo3_lA4A4=oa<C4`ko3@d=3OlY:BT6oooo
o`ko2@T93OlD51@>o`/;2`go61PH1_ooool=of][J`kooooo3_o4a<@=oa4A4@kooooo000<ooooo`ko
00003_lm?Cd=okbl_0go9bLW5?ooool>oo_kn`go:RXZ3Ol@4106ooooo`koYZJV3_l0000=ooooo`go
L71`1_ooool>o`0000koLG5a3On<S8`=odi>CPKooooo3_lD51@=o`P820ko00003OlZ:RX6ooooo`ko
4A4A3OlC4a<>o`d=3@go:BTY1_ooool>o`T92@go51@D3_l;2`/=oaPH60Kooooo3Om[Jf/>ooooo`ko
a<C43OlA4A4>ooooo`003?ooool>o`0000ko?Cdm3Onl_;`=obLW9aCooooo3_okno/=obXZ:Pgo410@
1_ooool>ojJVYPko00003Oooool=og1`L0Kooooo3_l0000>og5aL@goS8b<3Om>CTh6ooooo`ko51@D
3Ol820P>o`0000go:RXZ1_ooool>oa4A4@go4a<C3_l=3@d=obTY:@Kooooo3_l92@T=oa@D50ko2`/;
3OlH61P6ooooo`goJf][3_ooool>olC4a0go4A4A3_ooool000cooooo3_l0000>ocdm?@go_;bl3OlW
9bLDooooo`kono_k3OlZ:RX=oa0@40Kooooo3_nVYZH>o`0000gooooo3Om`L706ooooo`ko00003_ma
LG4=ohb<S0goCTi>1_ooool>oa@D50go20P83_l0000=obXZ:PKooooo3_lA4A4=oa<C4`ko3@d=3OlY
:BT6ooooo`ko2@T93OlD51@>o`/;2`go61PH1_ooool=of][J`kooooo3_o4a<@=oa4A4@kooooo000<
ooooo`ko00003_lm?Cd=okbl_0go9bLW5?ooool>oo_kn`go:RXZ3Ol@4106ooooo`koYZJV3_l0000=
ooooo`goL71`1_ooool>o`0000koLG5a3On<S8`=odi>CPKooooo3_lD51@=o`P820ko00003OlZ:RX6
ooooo`ko4A4A3OlC4a<>o`d=3@go:BTY1_ooool>o`T92@go51@D3_l;2`/=oaPH60Kooooo3Om[Jf/>
ooooo`koa<C43OlA4A4>ooooo`003?ooool>o`0000ko?Cdm3Onl_;`=obLW9aCooooo3_okno/=obXZ
:Pgo410@1_ooool>ojJVYPko00003Oooool=og1`L0Kooooo3_l0000>og5aL@goS8b<3Om>CTh6oooo
o`ko51@D3Ol820P>o`0000go:RXZ1_ooool>oa4A4@go4a<C3_l=3@d=obTY:@Kooooo3_l92@T=oa@D
50ko2`/;3OlH61P6ooooo`goJf][3_ooool>olC4a0go4A4A3_ooool000cooooo3_lS8b<>o`@410go
MgMg3Ol?3`l6ooooo`koA4A43_l410@=ofYZJPgoEeMG1_ooool>oa<C4`koMWIf3OmnOWh=oi>CT`Ko
oooo3_o@d=0>olo?c`go6a/K3Ol@4106ooooo`ko61PH3OlA4A4>o`h>3Pgo;Bd]1_ooool>odY:BPgo
2`/;3_l71`LCooooo`ko5aLG3Oooool>odA4A0go>3Ph1_ooool=oj6QX@ko;bl_3_l51@D=ob<S8`ko
oooo000<ooooo`ko8b<S3_l410@=ogMgM`go3`l?1_ooool>odA4A0ko10@43OmZJVX=oeMGE`Kooooo
3_lC4a<>ogIfMPgoOWin3OnCTi<6ooooo`kod=3@3_o?cll=oa/K6`go410@1_ooool>oaPH60go4A4A
3_l>3Ph=obd];@Kooooo3_m:BTX=o`/;2`ko1`L74oooool>oaLG5`gooooo3_m4A4@=ocPh>0Kooooo
3OnQXJ4>obl_;`ko1@D53OlS8b<>ooooo`003?ooool>ob<S8`ko10@43OmgMgL=o`l?3`Kooooo3_m4
A4@>o`@410goJVYZ3OmGEeL6ooooo`ko4a<C3_mfMWH=oginOPgoTi>C1_ooool>om3@d0koclo?3OlK
6a/=oa0@40Kooooo3_lH61P=oa4A4@ko3Ph>3Ol];Bd6ooooo`koBTY:3Ol;2`/>o`L71a?ooooo3_lG
5aL=ooooo`koA4A43Olh>3P6ooooo`goXJ6Q3_l_;bl>o`D51@go8b<S3_ooool000cooooo3_lS8b<>
o`@410goMgMg3Ol?3`l6ooooo`koA4A43_l410@=ofYZJPgoEeMG1_ooool>oa<C4`koMWIf3OmnOWh=
oi>CT`Kooooo3_o@d=0>olo?c`go6a/K3Ol@4106ooooo`ko61PH3OlA4A4>o`h>3Pgo;Bd]1_ooool>
odY:BPgo2`/;3_l71`LCooooo`ko5aLG3Oooool>odA4A0go>3Ph1_ooool=oj6QX@ko;bl_3_l51@D=
ob<S8`kooooo000<ooooo`ko8b<S3_l410@=ogMgM`go3`l?1_ooool>odA4A0ko10@43OmZJVX=oeMG
E`Kooooo3_lC4a<>ogIfMPgoOWin3OnCTi<6ooooo`kod=3@3_o?cll=oa/K6`go410@1_ooool>oaPH
60go4A4A3_l>3Ph=obd];@Kooooo3_m:BTX=o`/;2`ko1`L74oooool>oaLG5`gooooo3_m4A4@=ocPh
>0Kooooo3OnQXJ4>obl_;`ko1@D53OlS8b<>ooooo`003?ooool>ob<S8`ko10@43OmgMgL=o`l?3`Ko
oooo3_m4A4@>o`@410goJVYZ3OmGEeL6ooooo`ko4a<C3_mfMWH=oginOPgoTi>C1_ooool>om3@d0ko
clo?3OlK6a/=oa0@40Kooooo3_lH61P=oa4A4@ko3Ph>3Ol];Bd6ooooo`koBTY:3Ol;2`/>o`L71a?o
oooo3_lG5aL=ooooo`koA4A43Olh>3P6ooooo`goXJ6Q3_l_;bl>o`D51@go8b<S3_ooool000cooooo
3_lS8b<>o`@410goMgMg3Ol?3`l6ooooo`koA4A43_l410@=ofYZJPgoEeMG1_ooool>oa<C4`koMWIf
3OmnOWh=oi>CT`Kooooo3_o@d=0>olo?c`go6a/K3Ol@4106ooooo`ko61PH3OlA4A4>o`h>3Pgo;Bd]
1_ooool>odY:BPgo2`/;3_l71`LCooooo`ko5aLG3Oooool>odA4A0go>3Ph1_ooool=oj6QX@ko;bl_
3_l51@D=ob<S8`kooooo000<ooooo`ko8b<S3_l410@=ogMgM`go3`l?1_ooool>odA4A0ko10@43OmZ
JVX=oeMGE`Kooooo3_lC4a<>ogIfMPgoOWin3OnCTi<6ooooo`kod=3@3_o?cll=oa/K6`go410@1_oo
ool>oaPH60go4A4A3_l>3Ph=obd];@Kooooo3_m:BTX=o`/;2`ko1`L74oooool>oaLG5`gooooo3_m4
A4@=ocPh>0Kooooo3OnQXJ4>obl_;`ko1@D53OlS8b<>ooooo`003?ooool>ob<S8`ko10@43OmgMgL=
o`l?3`Kooooo3_m4A4@>o`@410goJVYZ3OmGEeL6ooooo`ko4a<C3_mfMWH=oginOPgoTi>C1_ooool>
om3@d0koclo?3OlK6a/=oa0@40Kooooo3_lH61P=oa4A4@ko3Ph>3Ol];Bd6ooooo`koBTY:3Ol;2`/>
o`L71a?ooooo3_lG5aL=ooooo`koA4A43Olh>3P6ooooo`goXJ6Q3_l_;bl>o`D51@go8b<S3_ooool0
00cooooo3_lS8b<>o`@410goMgMg3Ol?3`l6ooooo`koA4A43_l410@=ofYZJPgoEeMG1_ooool>oa<C
4`koMWIf3OmnOWh=oi>CT`Kooooo3_o@d=0>olo?c`go6a/K3Ol@4106ooooo`ko61PH3OlA4A4>o`h>
3Pgo;Bd]1_ooool>odY:BPgo2`/;3_l71`LCooooo`ko5aLG3Oooool>odA4A0go>3Ph1_ooool=oj6Q
X@ko;bl_3_l51@D=ob<S8`kooooo000<ooooo`ko8b<S3_l410@=ogMgM`go3`l?1_ooool>odA4A0ko
10@43OmZJVX=oeMGE`Kooooo3_lC4a<>ogIfMPgoOWin3OnCTi<6ooooo`kod=3@3_o?cll=oa/K6`go
410@1_ooool>oaPH60go4A4A3_l>3Ph=obd];@Kooooo3_m:BTX=o`/;2`ko1`L74oooool>oaLG5`go
oooo3_m4A4@=ocPh>0Kooooo3OnQXJ4>obl_;`ko1@D53OlS8b<>ooooo`003?ooool>ob<S8`ko10@4
3OmgMgL=o`l?3`Kooooo3_m4A4@>o`@410goJVYZ3OmGEeL6ooooo`ko4a<C3_mfMWH=oginOPgoTi>C
1_ooool>om3@d0koclo?3OlK6a/=oa0@40Kooooo3_lH61P=oa4A4@ko3Ph>3Ol];Bd6ooooo`koBTY:
3Ol;2`/>o`L71a?ooooo3_lG5aL=ooooo`koA4A43Olh>3P6ooooo`goXJ6Q3_l_;bl>o`D51@go8b<S
3_ooool000cooooo3_lS8b<>o`@410goMgMg3Ol?3`l6ooooo`koA4A43_l410@=ofYZJPgoEeMG1_oo
ool>oa<C4`koMWIf3OmnOWh=oi>CT`Kooooo3_o@d=0>olo?c`go6a/K3Ol@4106ooooo`ko61PH3OlA
4A4>o`h>3Pgo;Bd]1_ooool>odY:BPgo2`/;3_l71`LCooooo`ko5aLG3Oooool>odA4A0go>3Ph1_oo
ool=oj6QX@ko;bl_3_l51@D=ob<S8`kooooo000<ooooo`ko8b<S3_l410@=ogMgM`go3`l?1_ooool>
odA4A0ko10@43OmZJVX=oeMGE`Kooooo3_lC4a<>ogIfMPgoOWin3OnCTi<6ooooo`kod=3@3_o?cll=
oa/K6`go410@1_ooool>oaPH60go4A4A3_l>3Ph=obd];@Kooooo3_m:BTX=o`/;2`ko1`L74oooool>
oaLG5`gooooo3_m4A4@=ocPh>0Kooooo3OnQXJ4>obl_;`ko1@D53OlS8b<>ooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko
7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko
820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Ko
oooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo
3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=
3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K
1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?oo
ool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL
71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol0
0006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;
2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>
oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=
oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>
obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6Q
X@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@
40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006oooo
o`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`41
0@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go
?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKo
oooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go
2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K
3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF
1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S
3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C
3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9
BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI
6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ
8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=
oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>
obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>
ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>
ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6oooo
o`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7
A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l
?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Ko
oooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:Pko
SHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`go
Fe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`00
3?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN
3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P
3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo
3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l8
20P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF
5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_oo
ool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>o`410@ko4a<C3Ol<30`>ooooo`003?ooool>
oj6QX@koFe]K3OlH61P=oc`l?0Kooooo3_l820P>oc0`<0go?Cdm3Om9BDT6ooooo`ko7QhN3_lL71`=
oa0@40go5QHF1_ooool>obXZ:PkoSHf=3OlF5QH=oc8b<PKooooo3_lI6AT=odM7A`ko820P3Ol00006
ooooo`koHf=S3Ol61PH>ooooo`goFe]K1_ooool>obDU9@go2@T93_lQ8B4=oc`l?0Kooooo3Ol;2`/>
o`410@ko4a<C3Ol<30`>ooooo`006_ooool>oe9BDPgo00003OmUIFD6ooooo`koC4a<3_l0000=oaTI
6@goSHf=1_ooool>o`L71`ko00003OlN7Qh=oc4a<@Kooooo3_l0000>oijNWPgoMgMg3On3Ph<6oooo
o`ko3`l?3OlA4A4>oaDE5@go8b<S1_ooool>ofUYJ@go4A4A3_li>CT=ob8R8PKooooo3_lI6AT=o`l?
3`ko2`/;3Ol820P6oooooa_o30`<3_l:2PX=obDU9@kooooo000Jooooo`koDU9B3Ol0000=ofEUI@Ko
oooo3_m<C4`>o`0000go6ATI3On=SHd6ooooo`ko1`L73_l0000=oahN7Pgo<C4a1_ooool>o`0000ko
WYjN3OmgMgL=oh>3P`Kooooo3_l?3`l=oa4A4@ko5ADE3OlS8b<6ooooo`koJFUY3OlA4A4>ocTi>@go
8R8R1_ooool>oaTI6@go3`l?3_l;2`/=o`P820Kooooo6ol<30`>o`X:2Pgo9BDU3_ooool001[ooooo
3_mBDU8=o`0000goIFEU1_ooool>oda<C0ko00003OlI6AT=ohf=S@Kooooo3_l71`L>o`0000go7QhN
3Ola<C46ooooo`ko00003_nNWYh=ogMgM`goPh>31_ooool>o`l?3`go4A4A3_lE5AD=ob<S8`Kooooo
3_mYJFT=oa4A4@ko>CTi3OlR8R86ooooo`ko6ATI3Ol?3`l>o`/;2`go20P81_oooolKo``<30ko2PX:
3OlU9BD>ooooo`006_ooool>oe9BDPgo00003OmUIFD6ooooo`koC4a<3_l0000=oaTI6@goSHf=1_oo
ool>o`L71`ko00003OlN7Qh=oc4a<@Kooooo3_l0000>oijNWPgoMgMg3On3Ph<6ooooo`ko3`l?3OlA
4A4>oaDE5@go8b<S1_ooool>ofUYJ@go4A4A3_li>CT=ob8R8PKooooo3_lI6AT=o`l?3`ko2`/;3Ol8
20P6oooooa_o30`<3_l:2PX=obDU9@kooooo000Jooooo`koDU9B3Ol0000=ofEUI@Kooooo3_m<C4`>
o`0000go6ATI3On=SHd6ooooo`ko1`L73_l0000=oahN7Pgo<C4a1_ooool>o`0000koWYjN3OmgMgL=
oh>3P`Kooooo3_l?3`l=oa4A4@ko5ADE3OlS8b<6ooooo`koJFUY3OlA4A4>ocTi>@go8R8R1_ooool>
oaTI6@go3`l?3_l;2`/=o`P820Kooooo6ol<30`>o`X:2Pgo9BDU3_ooool001[ooooo3_mBDU8=o`00
00goIFEU1_ooool>oda<C0ko00003OlI6AT=ohf=S@Kooooo3_l71`L>o`0000go7QhN3Ola<C46oooo
o`ko00003_nNWYh=ogMgM`goPh>31_ooool>o`l?3`go4A4A3_lE5AD=ob<S8`Kooooo3_mYJFT=oa4A
4@ko>CTi3OlR8R86ooooo`ko6ATI3Ol?3`l>o`/;2`go20P81_oooolKo``<30ko2PX:3OlU9BD>oooo
o`006_ooool>oe9BDPgo00003OmUIFD6ooooo`koC4a<3_l0000=oaTI6@goSHf=1_ooool>o`L71`ko
00003OlN7Qh=oc4a<@Kooooo3_l0000>oijNWPgoMgMg3On3Ph<6ooooo`ko3`l?3OlA4A4>oaDE5@go
8b<S1_ooool>ofUYJ@go4A4A3_li>CT=ob8R8PKooooo3_lI6AT=o`l?3`ko2`/;3Ol820P6oooooa_o
30`<3_l:2PX=obDU9@kooooo000Jooooo`koDU9B3Ol0000=ofEUI@Kooooo3_m<C4`>o`0000go6ATI
3On=SHd6ooooo`ko1`L73_l0000=oahN7Pgo<C4a1_ooool>o`0000koWYjN3OmgMgL=oh>3P`Kooooo
3_l?3`l=oa4A4@ko5ADE3OlS8b<6ooooo`koJFUY3OlA4A4>ocTi>@go8R8R1_ooool>oaTI6@go3`l?
3_l;2`/=o`P820Kooooo6ol<30`>o`X:2Pgo9BDU3_ooool001[ooooo3_mBDU8=o`0000goIFEU1_oo
ool>oda<C0ko00003OlI6AT=ohf=S@Kooooo3_l71`L>o`0000go7QhN3Ola<C46ooooo`ko00003_nN
WYh=ogMgM`goPh>31_ooool>o`l?3`go4A4A3_lE5AD=ob<S8`Kooooo3_mYJFT=oa4A4@ko>CTi3OlR
8R86ooooo`ko6ATI3Ol?3`l>o`/;2`go20P81_oooolKo``<30ko2PX:3OlU9BD>ooooo`006_ooool>
oe9BDPgo00003OmUIFD6ooooo`koC4a<3_l0000=oaTI6@goSHf=1_ooool>o`L71`ko00003OlN7Qh=
oc4a<@Kooooo3_l0000>oijNWPgoMgMg3On3Ph<6ooooo`ko3`l?3OlA4A4>oaDE5@go8b<S1_ooool>
ofUYJ@go4A4A3_li>CT=ob8R8PKooooo3_lI6AT=o`l?3`ko2`/;3Ol820P6oooooa_o30`<3_l:2PX=
obDU9@kooooo000Jooooo`koDU9B3Ol0000=ofEUI@Kooooo3_m<C4`>o`0000go6ATI3On=SHd6oooo
o`ko1`L73_l0000=oahN7Pgo<C4a1_ooool>o`0000koWYjN3OmgMgL=oh>3P`Kooooo3_l?3`l=oa4A
4@ko5ADE3OlS8b<6ooooo`koJFUY3OlA4A4>ocTi>@go8R8R1_ooool>oaTI6@go3`l?3_l;2`/=o`P8
20Kooooo6ol<30`>o`X:2Pgo9BDU3_ooool001[ooooo3_mBDU8=o`0000goIFEU1_ooool>oda<C0ko
00003OlI6AT=ohf=S@Kooooo3_l71`L>o`0000go7QhN3Ola<C46ooooo`ko00003_nNWYh=ogMgM`go
Ph>31_ooool>o`l?3`go4A4A3_lE5AD=ob<S8`Kooooo3_mYJFT=oa4A4@ko>CTi3OlR8R86ooooo`ko
6ATI3Ol?3`l>o`/;2`go20P81_oooolKo``<30ko2PX:3OlU9BD>ooooo`006_ooool>oe9BDPgo0000
3OmUIFD6ooooo`koC4a<3_l0000=oaTI6@goSHf=1_ooool>o`L71`ko00003OlN7Qh=oc4a<@Kooooo
3_l0000>oijNWPgoMgMg3On3Ph<6ooooo`ko3`l?3OlA4A4>oaDE5@go8b<S1_ooool>ofUYJ@go4A4A
3_li>CT=ob8R8PKooooo3_lI6AT=o`l?3`ko2`/;3Ol820P6oooooa_o30`<3_l:2PX=obDU9@kooooo
000<ooooo`koe]KF3_m;Bd/=o``<30goHF5Q5?ooool>oe]KF`go00003Om[Jf/6ooooo`ko:RXZ3_l8
20P=ob@T91?ooooo3_l51@D>ohN7Q`gooooo3On?Shl6ooooo`ko4Q8B3Ol92@T>oaHF5Pgo<S8b1_oo
ool>og1`L0go@4103_l0000=oa@D50Kooooo3_l0000=oaHF5Pko2@T93OlK6a/6ooooo`go3`l?3_l0
000>o`L71`go3@d=3_ooool000cooooo3_oFe]H>od];B`go30`<3OmQHF4Dooooo`koFe]K3Ol0000=
of][J`Kooooo3_lZ:RX>o`P820go92@T4oooool>o`D51@koQhN73Oooool=ohn?S`Kooooo3_lB4Q8=
o`T92@ko5QHF3Olb<S86ooooo`koL71`3Om0@40>o`0000go51@D1_ooool>o`0000go5QHF3_l92@T=
oa/K6`Kooooo3Ol?3`l>o`0000ko1`L73Ol=3@d>ooooo`003?ooool>omKFePkoBd];3Ol<30`=of5Q
HACooooo3_mKFe/=o`0000goJf][1_ooool>obXZ:Pko20P83OlT92@Cooooo`ko1@D53_n7QhL=oooo
o`goShn?1_ooool>oa8B4Pgo2@T93_lF5QH=oc8b<PKooooo3_m`L70=od10@0ko00003OlD51@6oooo
o`ko00003OlF5QH>o`T92@go6a/K1_ooool=o`l?3`ko00003_l71`L=o`d=3@kooooo000<ooooo`ko
e]KF3_m;Bd/=o``<30goHF5Q5?ooool>oe]KF`go00003Om[Jf/6ooooo`ko:RXZ3_l820P=ob@T91?o
oooo3_l51@D>ohN7Q`gooooo3On?Shl6ooooo`ko4Q8B3Ol92@T>oaHF5Pgo<S8b1_ooool>og1`L0go
@4103_l0000=oa@D50Kooooo3_l0000=oaHF5Pko2@T93OlK6a/6ooooo`go3`l?3_l0000>o`L71`go
3@d=3_ooool000cooooo3_oFe]H>od];B`go30`<3OmQHF4Dooooo`koFe]K3Ol0000=of][J`Kooooo
3_lZ:RX>o`P820go92@T4oooool>o`D51@koQhN73Oooool=ohn?S`Kooooo3_lB4Q8=o`T92@ko5QHF
3Olb<S86ooooo`koL71`3Om0@40>o`0000go51@D1_ooool>o`0000go5QHF3_l92@T=oa/K6`Kooooo
3Ol?3`l>o`0000ko1`L73Ol=3@d>ooooo`003?ooool>omKFePkoBd];3Ol<30`=of5QHACooooo3_mK
Fe/=o`0000goJf][1_ooool>obXZ:Pko20P83OlT92@Cooooo`ko1@D53_n7QhL=ooooo`goShn?1_oo
ool>oa8B4Pgo2@T93_lF5QH=oc8b<PKooooo3_m`L70=od10@0ko00003OlD51@6ooooo`ko00003OlF
5QH>o`T92@go6a/K1_ooool=o`l?3`ko00003_l71`L=o`d=3@kooooo000<ooooo`koe]KF3_m;Bd/=
o``<30goHF5Q5?ooool>oe]KF`go00003Om[Jf/6ooooo`ko:RXZ3_l820P=ob@T91?ooooo3_l51@D>
ohN7Q`gooooo3On?Shl6ooooo`ko4Q8B3Ol92@T>oaHF5Pgo<S8b1_ooool>og1`L0go@4103_l0000=
oa@D50Kooooo3_l0000=oaHF5Pko2@T93OlK6a/6ooooo`go3`l?3_l0000>o`L71`go3@d=3_ooool0
00cooooo3_oFe]H>od];B`go30`<3OmQHF4Dooooo`koFe]K3Ol0000=of][J`Kooooo3_lZ:RX>o`P8
20go92@T4oooool>o`D51@koQhN73Oooool=ohn?S`Kooooo3_lB4Q8=o`T92@ko5QHF3Olb<S86oooo
o`koL71`3Om0@40>o`0000go51@D1_ooool>o`0000go5QHF3_l92@T=oa/K6`Kooooo3Ol?3`l>o`00
00ko1`L73Ol=3@d>ooooo`003?ooool>omKFePkoBd];3Ol<30`=of5QHACooooo3_mKFe/=o`0000go
Jf][1_ooool>obXZ:Pko20P83OlT92@Cooooo`ko1@D53_n7QhL=ooooo`goShn?1_ooool>oa8B4Pgo
2@T93_lF5QH=oc8b<PKooooo3_m`L70=od10@0ko00003OlD51@6ooooo`ko00003OlF5QH>o`T92@go
6a/K1_ooool=o`l?3`ko00003_l71`L=o`d=3@kooooo000<ooooo`koe]KF3_m;Bd/=o``<30goHF5Q
5?ooool>oe]KF`go00003Om[Jf/6ooooo`ko:RXZ3_l820P=ob@T91?ooooo3_l51@D>ohN7Q`gooooo
3On?Shl6ooooo`ko4Q8B3Ol92@T>oaHF5Pgo<S8b1_ooool>og1`L0go@4103_l0000=oa@D50Kooooo
3_l0000=oaHF5Pko2@T93OlK6a/6ooooo`go3`l?3_l0000>o`L71`go3@d=3_ooool000cooooo3_oF
e]H>od];B`go30`<3OmQHF4Dooooo`koFe]K3Ol0000=of][J`Kooooo3_lZ:RX>o`P820go92@T4ooo
ool>o`D51@koQhN73Oooool=ohn?S`Kooooo3_lB4Q8=o`T92@ko5QHF3Olb<S86ooooo`koL71`3Om0
@40>o`0000go51@D1_ooool>o`0000go5QHF3_l92@T=oa/K6`Kooooo3Ol?3`l>o`0000ko1`L73Ol=
3@d>ooooo`003?ooool>omKFePkoBd];3Ol<30`=of5QHACooooo3_mKFe/=o`0000goJf][1_ooool>
obXZ:Pko20P83OlT92@Cooooo`ko1@D53_n7QhL=ooooo`goShn?1_ooool>oa8B4Pgo2@T93_lF5QH=
oc8b<PKooooo3_m`L70=od10@0ko00003OlD51@6ooooo`ko00003OlF5QH>o`T92@go6a/K1_ooool=
o`l?3`ko00003_l71`L=o`d=3@kooooo000<ooooo`koe]KF3_m;Bd/=o``<30goHF5Q5?ooool>oe]K
F`go00003Om[Jf/6ooooo`ko:RXZ3_l820P=ob@T91?ooooo3_l51@D>ohN7Q`gooooo3On?Shl6oooo
o`ko4Q8B3Ol92@T>oaHF5Pgo<S8b1_ooool>og1`L0go@4103_l0000=oa@D50Kooooo3_l0000=oaHF
5Pko2@T93OlK6a/6ooooo`go3`l?3_l0000>o`L71`go3@d=3_ooool000cooooo3_l>3Ph>oa8B4Pgo
?Cdm3OlA4A46ooooo`ko0@413_mjNWX=ocDe=@go?3`l1_ooool>obh^;Pko5ADE3Ol=3@d=oaHF5PKo
oooo3_m:BTX>of=SH`go3@d=3Ol<30`6ooooo`ko4A4A3Oooool>o`l?3`go<S8b1_ooool>ocdm?@go
5ADE3_nTY:@=olS8b0Kooooo3_lD51@=oadM7@kooooo3OlI6ATCooooo`ko=cLg3_l71`L=oaTI6@ko
oooo000<ooooo`ko3Ph>3_lB4Q8=ocdm?@go4A4A1_ooool>o`410@koNWYj3Ole=CD=oc`l?0Kooooo
3_l^;Rh>oaDE5@go3@d=3OlF5QH6ooooo`koBTY:3_mSHf<=o`d=3@go30`<1_ooool>oa4A4@gooooo
3_l?3`l=oc8b<PKooooo3_lm?Cd=oaDE5@koY:BT3Oo8b<P6ooooo`ko51@D3OlM7Ad>ooooo`go6ATI
4oooool>ocLg=`ko1`L73OlI6AT>ooooo`003?ooool>o`h>3Pko4Q8B3Olm?Cd=oa4A4@Kooooo3_l1
0@4>ogYjNPgo=CDe3Oll?3`6ooooo`ko;Rh^3_lE5AD=o`d=3@go5QHF1_ooool>odY:BPkoHf=S3Ol=
3@d=o``<30Kooooo3_lA4A4=ooooo`ko3`l?3Olb<S86ooooo`ko?Cdm3OlE5AD>ojBTY0gob<S81_oo
ool>oa@D50go7AdM3_ooool=oaTI6A?ooooo3_lg=cL>o`L71`go6ATI3_ooool000cooooo3_l>3Ph>
oa8B4Pgo?Cdm3OlA4A46ooooo`ko0@413_mjNWX=ocDe=@go?3`l1_ooool>obh^;Pko5ADE3Ol=3@d=
oaHF5PKooooo3_m:BTX>of=SH`go3@d=3Ol<30`6ooooo`ko4A4A3Oooool>o`l?3`go<S8b1_ooool>
ocdm?@go5ADE3_nTY:@=olS8b0Kooooo3_lD51@=oadM7@kooooo3OlI6ATCooooo`ko=cLg3_l71`L=
oaTI6@kooooo000<ooooo`ko3Ph>3_lB4Q8=ocdm?@go4A4A1_ooool>o`410@koNWYj3Ole=CD=oc`l
?0Kooooo3_l^;Rh>oaDE5@go3@d=3OlF5QH6ooooo`koBTY:3_mSHf<=o`d=3@go30`<1_ooool>oa4A
4@gooooo3_l?3`l=oc8b<PKooooo3_lm?Cd=oaDE5@koY:BT3Oo8b<P6ooooo`ko51@D3OlM7Ad>oooo
o`go6ATI4oooool>ocLg=`ko1`L73OlI6AT>ooooo`003?ooool>o`h>3Pko4Q8B3Olm?Cd=oa4A4@Ko
oooo3_l10@4>ogYjNPgo=CDe3Oll?3`6ooooo`ko;Rh^3_lE5AD=o`d=3@go5QHF1_ooool>odY:BPko
Hf=S3Ol=3@d=o``<30Kooooo3_lA4A4=ooooo`ko3`l?3Olb<S86ooooo`ko?Cdm3OlE5AD>ojBTY0go
b<S81_ooool>oa@D50go7AdM3_ooool=oaTI6A?ooooo3_lg=cL>o`L71`go6ATI3_ooool000cooooo
3_l>3Ph>oa8B4Pgo?Cdm3OlA4A46ooooo`ko0@413_mjNWX=ocDe=@go?3`l1_ooool>obh^;Pko5ADE
3Ol=3@d=oaHF5PKooooo3_m:BTX>of=SH`go3@d=3Ol<30`6ooooo`ko4A4A3Oooool>o`l?3`go<S8b
1_ooool>ocdm?@go5ADE3_nTY:@=olS8b0Kooooo3_lD51@=oadM7@kooooo3OlI6ATCooooo`ko=cLg
3_l71`L=oaTI6@kooooo000<ooooo`ko3Ph>3_lB4Q8=ocdm?@go4A4A1_ooool>o`410@koNWYj3Ole
=CD=oc`l?0Kooooo3_l^;Rh>oaDE5@go3@d=3OlF5QH6ooooo`koBTY:3_mSHf<=o`d=3@go30`<1_oo
ool>oa4A4@gooooo3_l?3`l=oc8b<PKooooo3_lm?Cd=oaDE5@koY:BT3Oo8b<P6ooooo`ko51@D3OlM
7Ad>ooooo`go6ATI4oooool>ocLg=`ko1`L73OlI6AT>ooooo`003?ooool>o`h>3Pko4Q8B3Olm?Cd=
oa4A4@Kooooo3_l10@4>ogYjNPgo=CDe3Oll?3`6ooooo`ko;Rh^3_lE5AD=o`d=3@go5QHF1_ooool>
odY:BPkoHf=S3Ol=3@d=o``<30Kooooo3_lA4A4=ooooo`ko3`l?3Olb<S86ooooo`ko?Cdm3OlE5AD>
ojBTY0gob<S81_ooool>oa@D50go7AdM3_ooool=oaTI6A?ooooo3_lg=cL>o`L71`go6ATI3_ooool0
00cooooo3_l>3Ph>oa8B4Pgo?Cdm3OlA4A46ooooo`ko0@413_mjNWX=ocDe=@go?3`l1_ooool>obh^
;Pko5ADE3Ol=3@d=oaHF5PKooooo3_m:BTX>of=SH`go3@d=3Ol<30`6ooooo`ko4A4A3Oooool>o`l?
3`go<S8b1_ooool>ocdm?@go5ADE3_nTY:@=olS8b0Kooooo3_lD51@=oadM7@kooooo3OlI6ATCoooo
o`ko=cLg3_l71`L=oaTI6@kooooo000<ooooo`ko3Ph>3_lB4Q8=ocdm?@go4A4A1_ooool>o`410@ko
NWYj3Ole=CD=oc`l?0Kooooo3_l^;Rh>oaDE5@go3@d=3OlF5QH6ooooo`koBTY:3_mSHf<=o`d=3@go
30`<1_ooool>oa4A4@gooooo3_l?3`l=oc8b<PKooooo3_lm?Cd=oaDE5@koY:BT3Oo8b<P6ooooo`ko
51@D3OlM7Ad>ooooo`go6ATI4oooool>ocLg=`ko1`L73OlI6AT>ooooo`003?ooool>o`h>3Pko4Q8B
3Olm?Cd=oa4A4@Kooooo3_l10@4>ogYjNPgo=CDe3Oll?3`6ooooo`ko;Rh^3_lE5AD=o`d=3@go5QHF
1_ooool>odY:BPkoHf=S3Ol=3@d=o``<30Kooooo3_lA4A4=ooooo`ko3`l?3Olb<S86ooooo`ko?Cdm
3OlE5AD>ojBTY0gob<S81_ooool>oa@D50go7AdM3_ooool=oaTI6A?ooooo3_lg=cL>o`L71`go6ATI
3_ooool000cooooo3_l>3Ph>oa8B4Pgo?Cdm3OlA4A46ooooo`ko0@413_mjNWX=ocDe=@go?3`l1_oo
ool>obh^;Pko5ADE3Ol=3@d=oaHF5PKooooo3_m:BTX>of=SH`go3@d=3Ol<30`6ooooo`ko4A4A3Ooo
ool>o`l?3`go<S8b1_ooool>ocdm?@go5ADE3_nTY:@=olS8b0Kooooo3_lD51@=oadM7@kooooo3OlI
6ATCooooo`ko=cLg3_l71`L=oaTI6@kooooo000<ooooo`ko3Ph>3_lB4Q8=ocdm?@go4A4A1_ooool>
o`410@koNWYj3Ole=CD=oc`l?0Kooooo3_l^;Rh>oaDE5@go3@d=3OlF5QH6ooooo`koBTY:3_mSHf<=
o`d=3@go30`<1_ooool>oa4A4@gooooo3_l?3`l=oc8b<PKooooo3_lm?Cd=oaDE5@koY:BT3Oo8b<P6
ooooo`ko51@D3OlM7Ad>ooooo`go6ATI4oooool>ocLg=`ko1`L73OlI6AT>ooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`003?ooool>obTY:@ko2@T93Ol71`L=o`l?3`Kooooo3_m=CDd>o`0000go51@D3Om:BTX6ooooo`ko
00003_lU9BD=og]kN`go>SXj1_ooool>o`0000ko61PH3Ol61PH=o`d=3@Kooooo3_lI6AT=oa`L70ko
30`<4oooool>oa0@40go820P3_lA4A4=ocDe=@Kooooo3_l51@D=ooooo`komOGe3Old=3@Cooooo`ko
LW9b3_l30`<=ocdm?@kooooo000<ooooo`ko:BTY3_l92@T=o`L71`go3`l?1_ooool>ode=C@ko0000
3OlD51@=odY:BPKooooo3_l0000>obDU9@goNg]k3Olj>SX6ooooo`ko00003_lH61P=o`H61Pgo3@d=
1_ooool>oaTI6@go71`L3_l<30`Cooooo`ko410@3OlP820>oa4A4@go=CDe1_ooool>o`D51@gooooo
3_oemOD=oc@d=1?ooooo3_mbLW8>o`<30`go?Cdm3_ooool000cooooo3_lY:BT>o`T92@go1`L73Ol?
3`l6ooooo`koCDe=3_l0000=oa@D50goBTY:1_ooool>o`0000ko9BDU3OmkNg/=ocXj>PKooooo3_l0
000>oaPH60go1PH63Ol=3@d6ooooo`ko6ATI3OlL71`>o``<31?ooooo3_l@410=ob0P80ko4A4A3Ole
=CD6ooooo`ko1@D53Oooool>ooGem@go=3@d4oooool>og9bLPko0`<33Olm?Cd>ooooo`003?ooool>
obTY:@ko2@T93Ol71`L=o`l?3`Kooooo3_m=CDd>o`0000go51@D3Om:BTX6ooooo`ko00003_lU9BD=
og]kN`go>SXj1_ooool>o`0000ko61PH3Ol61PH=o`d=3@Kooooo3_lI6AT=oa`L70ko30`<4oooool>
oa0@40go820P3_lA4A4=ocDe=@Kooooo3_l51@D=ooooo`komOGe3Old=3@Cooooo`koLW9b3_l30`<=
ocdm?@kooooo000<ooooo`ko:BTY3_l92@T=o`L71`go3`l?1_ooool>ode=C@ko00003OlD51@=odY:
BPKooooo3_l0000>obDU9@goNg]k3Olj>SX6ooooo`ko00003_lH61P=o`H61Pgo3@d=1_ooool>oaTI
6@go71`L3_l<30`Cooooo`ko410@3OlP820>oa4A4@go=CDe1_ooool>o`D51@gooooo3_oemOD=oc@d
=1?ooooo3_mbLW8>o`<30`go?Cdm3_ooool000cooooo3_lY:BT>o`T92@go1`L73Ol?3`l6ooooo`ko
CDe=3_l0000=oa@D50goBTY:1_ooool>o`0000ko9BDU3OmkNg/=ocXj>PKooooo3_l0000>oaPH60go
1PH63Ol=3@d6ooooo`ko6ATI3OlL71`>o``<31?ooooo3_l@410=ob0P80ko4A4A3Ole=CD6ooooo`ko
1@D53Oooool>ooGem@go=3@d4oooool>og9bLPko0`<33Olm?Cd>ooooo`003?ooool>obTY:@ko2@T9
3Ol71`L=o`l?3`Kooooo3_m=CDd>o`0000go51@D3Om:BTX6ooooo`ko00003_lU9BD=og]kN`go>SXj
1_ooool>o`0000ko61PH3Ol61PH=o`d=3@Kooooo3_lI6AT=oa`L70ko30`<4oooool>oa0@40go820P
3_lA4A4=ocDe=@Kooooo3_l51@D=ooooo`komOGe3Old=3@Cooooo`koLW9b3_l30`<=ocdm?@kooooo
000<ooooo`ko:BTY3_l92@T=o`L71`go3`l?1_ooool>ode=C@ko00003OlD51@=odY:BPKooooo3_l0
000>obDU9@goNg]k3Olj>SX6ooooo`ko00003_lH61P=o`H61Pgo3@d=1_ooool>oaTI6@go71`L3_l<
30`Cooooo`ko410@3OlP820>oa4A4@go=CDe1_ooool>o`D51@gooooo3_oemOD=oc@d=1?ooooo3_mb
LW8>o`<30`go?Cdm3_ooool000cooooo3_lY:BT>o`T92@go1`L73Ol?3`l6ooooo`koCDe=3_l0000=
oa@D50goBTY:1_ooool>o`0000ko9BDU3OmkNg/=ocXj>PKooooo3_l0000>oaPH60go1PH63Ol=3@d6
ooooo`ko6ATI3OlL71`>o``<31?ooooo3_l@410=ob0P80ko4A4A3Ole=CD6ooooo`ko1@D53Oooool>
ooGem@go=3@d4oooool>og9bLPko0`<33Olm?Cd>ooooo`003?ooool>obTY:@ko2@T93Ol71`L=o`l?
3`Kooooo3_m=CDd>o`0000go51@D3Om:BTX6ooooo`ko00003_lU9BD=og]kN`go>SXj1_ooool>o`00
00ko61PH3Ol61PH=o`d=3@Kooooo3_lI6AT=oa`L70ko30`<4oooool>oa0@40go820P3_lA4A4=ocDe
=@Kooooo3_l51@D=ooooo`komOGe3Old=3@Cooooo`koLW9b3_l30`<=ocdm?@kooooo000<ooooo`ko
:BTY3_l92@T=o`L71`go3`l?1_ooool>ode=C@ko00003OlD51@=odY:BPKooooo3_l0000>obDU9@go
Ng]k3Olj>SX6ooooo`ko00003_lH61P=o`H61Pgo3@d=1_ooool>oaTI6@go71`L3_l<30`Cooooo`ko
410@3OlP820>oa4A4@go=CDe1_ooool>o`D51@gooooo3_oemOD=oc@d=1?ooooo3_mbLW8>o`<30`go
?Cdm3_ooool000cooooo3_lY:BT>o`T92@go1`L73Ol?3`l6ooooo`koCDe=3_l0000=oa@D50goBTY:
1_ooool>o`0000ko9BDU3OmkNg/=ocXj>PKooooo3_l0000>oaPH60go1PH63Ol=3@d6ooooo`ko6ATI
3OlL71`>o``<31?ooooo3_l@410=ob0P80ko4A4A3Ole=CD6ooooo`ko1@D53Oooool>ooGem@go=3@d
4oooool>og9bLPko0`<33Olm?Cd>ooooo`003?ooool>obTY:@ko2@T93Ol71`L=o`l?3`Kooooo3_m=
CDd>o`0000go51@D3Om:BTX6ooooo`ko00003_lU9BD=og]kN`go>SXj1_ooool>o`0000ko61PH3Ol6
1PH=o`d=3@Kooooo3_lI6AT=oa`L70ko30`<4oooool>oa0@40go820P3_lA4A4=ocDe=@Kooooo3_l5
1@D=ooooo`komOGe3Old=3@Cooooo`koLW9b3_l30`<=ocdm?@kooooo000<ooooo`ko:BTY3_l92@T=
o`L71`go3`l?1_ooool>ode=C@ko00003OlD51@=odY:BPKooooo3_l0000>obDU9@goNg]k3Olj>SX6
ooooo`ko00003_lH61P=o`H61Pgo3@d=1_ooool>oaTI6@go71`L3_l<30`Cooooo`ko410@3OlP820>
oa4A4@go=CDe1_ooool>o`D51@gooooo3_oemOD=oc@d=1?ooooo3_mbLW8>o`<30`go?Cdm3_ooool0
00cooooo3_lI6AT>o`0000go1PH63Ol;2`/Dooooo`ko;2`/3Ol?3`l=ocDe=@Kooooo3_l71`L>ob<S
8`gooooo3OlL71`6ooooo`ko6a/K3_ooool=ocDe=@go820P1_ooool>o`d=3@go5aLG3_l0000=ode=
C@Kooooo6ol=3@d>oa/K6`go00001_ooool>o`0000go;Rh^3_mjNWX=of1PH0Kooooo3OnEUID>ogYj
NPko0`<33Ol0000>ooooo`003?ooool>oaTI6@ko00003Ol61PH=o`/;2aCooooo3_l/;2`=o`l?3`go
=CDe1_ooool>o`L71`ko8b<S3Oooool=oa`L70Kooooo3_lK6a/>ooooo`go=CDe3OlP8206ooooo`ko
3@d=3OlG5aL>o`0000goCDe=1_oooolKo`d=3@ko6a/K3Ol00006ooooo`ko00003Ol^;Rh>ogYjNPgo
H61P1_ooool=oiFEU@koNWYj3_l30`<=o`0000kooooo000<ooooo`ko6ATI3_l0000=o`H61Pgo2`/;
5?ooool>ob`/;0go3`l?3Ole=CD6ooooo`ko1`L73_lS8b<=ooooo`go71`L1_ooool>oa/K6`kooooo
3Ole=CD=ob0P80Kooooo3_l=3@d=oaLG5`ko00003Om=CDd6oooooa_o3@d=3_lK6a/=o`0000Kooooo
3_l0000=obh^;PkoNWYj3OmPH606ooooo`goUIFE3_mjNWX>o`<30`go00003_ooool000cooooo3_lI
6AT>o`0000go1PH63Ol;2`/Dooooo`ko;2`/3Ol?3`l=ocDe=@Kooooo3_l71`L>ob<S8`gooooo3OlL
71`6ooooo`ko6a/K3_ooool=ocDe=@go820P1_ooool>o`d=3@go5aLG3_l0000=ode=C@Kooooo6ol=
3@d>oa/K6`go00001_ooool>o`0000go;Rh^3_mjNWX=of1PH0Kooooo3OnEUID>ogYjNPko0`<33Ol0
000>ooooo`003?ooool>oaTI6@ko00003Ol61PH=o`/;2aCooooo3_l/;2`=o`l?3`go=CDe1_ooool>
o`L71`ko8b<S3Oooool=oa`L70Kooooo3_lK6a/>ooooo`go=CDe3OlP8206ooooo`ko3@d=3OlG5aL>
o`0000goCDe=1_oooolKo`d=3@ko6a/K3Ol00006ooooo`ko00003Ol^;Rh>ogYjNPgoH61P1_ooool=
oiFEU@koNWYj3_l30`<=o`0000kooooo000<ooooo`ko6ATI3_l0000=o`H61Pgo2`/;5?ooool>ob`/
;0go3`l?3Ole=CD6ooooo`ko1`L73_lS8b<=ooooo`go71`L1_ooool>oa/K6`kooooo3Ole=CD=ob0P
80Kooooo3_l=3@d=oaLG5`ko00003Om=CDd6oooooa_o3@d=3_lK6a/=o`0000Kooooo3_l0000=obh^
;PkoNWYj3OmPH606ooooo`goUIFE3_mjNWX>o`<30`go00003_ooool000cooooo3_lI6AT>o`0000go
1PH63Ol;2`/Dooooo`ko;2`/3Ol?3`l=ocDe=@Kooooo3_l71`L>ob<S8`gooooo3OlL71`6ooooo`ko
6a/K3_ooool=ocDe=@go820P1_ooool>o`d=3@go5aLG3_l0000=ode=C@Kooooo6ol=3@d>oa/K6`go
00001_ooool>o`0000go;Rh^3_mjNWX=of1PH0Kooooo3OnEUID>ogYjNPko0`<33Ol0000>ooooo`00
3?ooool>oaTI6@ko00003Ol61PH=o`/;2aCooooo3_l/;2`=o`l?3`go=CDe1_ooool>o`L71`ko8b<S
3Oooool=oa`L70Kooooo3_lK6a/>ooooo`go=CDe3OlP8206ooooo`ko3@d=3OlG5aL>o`0000goCDe=
1_oooolKo`d=3@ko6a/K3Ol00006ooooo`ko00003Ol^;Rh>ogYjNPgoH61P1_ooool=oiFEU@koNWYj
3_l30`<=o`0000kooooo000<ooooo`ko6ATI3_l0000=o`H61Pgo2`/;5?ooool>ob`/;0go3`l?3Ole
=CD6ooooo`ko1`L73_lS8b<=ooooo`go71`L1_ooool>oa/K6`kooooo3Ole=CD=ob0P80Kooooo3_l=
3@d=oaLG5`ko00003Om=CDd6oooooa_o3@d=3_lK6a/=o`0000Kooooo3_l0000=obh^;PkoNWYj3OmP
H606ooooo`goUIFE3_mjNWX>o`<30`go00003_ooool000cooooo3_lI6AT>o`0000go1PH63Ol;2`/D
ooooo`ko;2`/3Ol?3`l=ocDe=@Kooooo3_l71`L>ob<S8`gooooo3OlL71`6ooooo`ko6a/K3_ooool=
ocDe=@go820P1_ooool>o`d=3@go5aLG3_l0000=ode=C@Kooooo6ol=3@d>oa/K6`go00001_ooool>
o`0000go;Rh^3_mjNWX=of1PH0Kooooo3OnEUID>ogYjNPko0`<33Ol0000>ooooo`003?ooool>oaTI
6@ko00003Ol61PH=o`/;2aCooooo3_l/;2`=o`l?3`go=CDe1_ooool>o`L71`ko8b<S3Oooool=oa`L
70Kooooo3_lK6a/>ooooo`go=CDe3OlP8206ooooo`ko3@d=3OlG5aL>o`0000goCDe=1_oooolKo`d=
3@ko6a/K3Ol00006ooooo`ko00003Ol^;Rh>ogYjNPgoH61P1_ooool=oiFEU@koNWYj3_l30`<=o`00
00kooooo000<ooooo`ko6ATI3_l0000=o`H61Pgo2`/;5?ooool>ob`/;0go3`l?3Ole=CD6ooooo`ko
1`L73_lS8b<=ooooo`go71`L1_ooool>oa/K6`kooooo3Ole=CD=ob0P80Kooooo3_l=3@d=oaLG5`ko
00003Om=CDd6oooooa_o3@d=3_lK6a/=o`0000Kooooo3_l0000=obh^;PkoNWYj3OmPH606ooooo`go
UIFE3_mjNWX>o`<30`go00003_ooool000cooooo3_lI6AT>o`0000go1PH63Ol;2`/Dooooo`ko;2`/
3Ol?3`l=ocDe=@Kooooo3_l71`L>ob<S8`gooooo3OlL71`6ooooo`ko6a/K3_ooool=ocDe=@go820P
1_ooool>o`d=3@go5aLG3_l0000=ode=C@Kooooo6ol=3@d>oa/K6`go00001_ooool>o`0000go;Rh^
3_mjNWX=of1PH0Kooooo3OnEUID>ogYjNPko0`<33Ol0000>ooooo`003?ooool>obHV9Pko4A4A3Ol7
1`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_oo
ool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:
2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol8
20P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6
ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=
o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=
ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<
30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D
50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B
4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>oooo
o`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko
6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko
820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Ko
oooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo
3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY
3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/
1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?oo
ool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC
4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT
92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/
K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>
oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=
oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>
odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV
9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10
@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6oooo
o`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5a
L@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go
10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Ko
oooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go
00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A
3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S
1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P82
3Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=
3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF
5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ
6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mW
IfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=
o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6ooooo`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>
oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H61Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>
oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUYJ@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>
ooooo`003?ooool>obHV9Pko4A4A3Ol71`L=o``<30Kooooo3_m7AdL>oaPH60go10@43OlF5QH6oooo
o`ko6a/K3_lC4a<=od10@0go8b<S1_ooool>oa@D50ko:BTY3OlF5QH=oclo?`Kooooo3_lJ6QX=o`H6
1Pko820P3OlT92@6ooooo`ko0P823Ol:2PX>oa8B4Pgo;2`/1_ooool>odQ8B0go00003_mWIfL=ofUY
J@Kooooo3Om/K6`>og5aL@ko3@d=3Ol820P>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko
3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo
8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`go
d=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE5
3Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo
3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T
4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_oo
ool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO
7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_oo
ool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/
K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>
o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>
o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>
ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P
80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6oooo
o`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO
7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko
3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo
8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`go
d=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE5
3Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo
3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T
4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_oo
ool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO
7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_oo
ool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/
K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>
o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>
o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>
ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P
80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6oooo
o`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO
7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko
3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo
8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`go
d=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_ooool>ob0P80goADE5
3Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO7al=oa`L70Kooooo
3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_ooool>ob8R8Q_o92@T
4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/K6`>ooooo`006_oo
ool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>o`410@ko8B4Q3OlO
7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>o`<30`goCdm?1_oo
ool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>ob0P80ko4A4A3Om/
K6`>ooooo`006_ooool>ob0P80goADE53Ol;2`/6ooooo`ko3Ph>3_lR8R8=ob0P80go=CDe1_ooool>
o`410@ko8B4Q3OlO7al=oa`L70Kooooo3_l:2PX>oaHF5Pgo8B4Q3Ol^;Rh6ooooo`ko6QXJ3Ol=3@d>
o`<30`goCdm?1_ooool>ob8R8Q_o92@T4oooool>od];B`god=3@3_n<S8`=oalO7`Kooooo3OmkNg/>
ob0P80ko4A4A3Om/K6`>ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`003?ooool>oc@d=0ko5QHF3Om6ATH=ol?3``Ko
oooo3_l0000>o`H61Pgo8B4Q3OlG5aL6ooooo`ko3Ph>3_l51@D=oa0@40go4Q8B1_ooool>ob/[:`ko
61PH3Ol92@T=o`0000Kooooo3_l>3Ph=oe1@D0ko2@T93Ol61PH6ooooo`ko00003Ol@410>o`L71`go
92@T1_ooool>o`0000go7AdM3_lg=cL=o`/;2a?ooooo3_mHF5P>o`D51@go51@D3_ooool000cooooo
3_ld=3@>oaHF5PgoATI63Oo3`l<6ooooo`ko00003_l61PH=ob4Q8@go5aLG1_ooool>o`h>3Pko1@D5
3Ol@410=oa8B4PKooooo3_l[:b/>oaPH60go2@T93Ol00006ooooo`ko3Ph>3Om@D50>o`T92@go1PH6
1_ooool>o`0000go410@3_l71`L=ob@T90Kooooo3_l0000=oadM7@ko=cLg3Ol;2`/Cooooo`koF5QH
3_l51@D=oa@D50kooooo000<ooooo`ko=3@d3_lF5QH=odI6APgo`l?31_ooool>o`0000ko1PH63OlQ
8B4=oaLG5`Kooooo3_l>3Ph>o`D51@go410@3OlB4Q86ooooo`ko:b/[3_lH61P=o`T92@go00001_oo
ool>o`h>3PgoD51@3_l92@T=o`H61PKooooo3_l0000=oa0@40ko1`L73OlT92@6ooooo`ko00003OlM
7Ad>ocLg=`go2`/;4oooool>oeQHF0ko1@D53OlD51@>ooooo`003?ooool>oc@d=0ko5QHF3Om6ATH=
ol?3``Kooooo3_l0000>o`H61Pgo8B4Q3OlG5aL6ooooo`ko3Ph>3_l51@D=oa0@40go4Q8B1_ooool>
ob/[:`ko61PH3Ol92@T=o`0000Kooooo3_l>3Ph=oe1@D0ko2@T93Ol61PH6ooooo`ko00003Ol@410>
o`L71`go92@T1_ooool>o`0000go7AdM3_lg=cL=o`/;2a?ooooo3_mHF5P>o`D51@go51@D3_ooool0
00cooooo3_ld=3@>oaHF5PgoATI63Oo3`l<6ooooo`ko00003_l61PH=ob4Q8@go5aLG1_ooool>o`h>
3Pko1@D53Ol@410=oa8B4PKooooo3_l[:b/>oaPH60go2@T93Ol00006ooooo`ko3Ph>3Om@D50>o`T9
2@go1PH61_ooool>o`0000go410@3_l71`L=ob@T90Kooooo3_l0000=oadM7@ko=cLg3Ol;2`/Coooo
o`koF5QH3_l51@D=oa@D50kooooo000<ooooo`ko=3@d3_lF5QH=odI6APgo`l?31_ooool>o`0000ko
1PH63OlQ8B4=oaLG5`Kooooo3_l>3Ph>o`D51@go410@3OlB4Q86ooooo`ko:b/[3_lH61P=o`T92@go
00001_ooool>o`h>3PgoD51@3_l92@T=o`H61PKooooo3_l0000=oa0@40ko1`L73OlT92@6ooooo`ko
00003OlM7Ad>ocLg=`go2`/;4oooool>oeQHF0ko1@D53OlD51@>ooooo`003?ooool>oc@d=0ko5QHF
3Om6ATH=ol?3``Kooooo3_l0000>o`H61Pgo8B4Q3OlG5aL6ooooo`ko3Ph>3_l51@D=oa0@40go4Q8B
1_ooool>ob/[:`ko61PH3Ol92@T=o`0000Kooooo3_l>3Ph=oe1@D0ko2@T93Ol61PH6ooooo`ko0000
3Ol@410>o`L71`go92@T1_ooool>o`0000go7AdM3_lg=cL=o`/;2a?ooooo3_mHF5P>o`D51@go51@D
3_ooool000cooooo3_ld=3@>oaHF5PgoATI63Oo3`l<6ooooo`ko00003_l61PH=ob4Q8@go5aLG1_oo
ool>o`h>3Pko1@D53Ol@410=oa8B4PKooooo3_l[:b/>oaPH60go2@T93Ol00006ooooo`ko3Ph>3Om@
D50>o`T92@go1PH61_ooool>o`0000go410@3_l71`L=ob@T90Kooooo3_l0000=oadM7@ko=cLg3Ol;
2`/Cooooo`koF5QH3_l51@D=oa@D50kooooo000<ooooo`ko=3@d3_lF5QH=odI6APgo`l?31_ooool>
o`0000ko1PH63OlQ8B4=oaLG5`Kooooo3_l>3Ph>o`D51@go410@3OlB4Q86ooooo`ko:b/[3_lH61P=
o`T92@go00001_ooool>o`h>3PgoD51@3_l92@T=o`H61PKooooo3_l0000=oa0@40ko1`L73OlT92@6
ooooo`ko00003OlM7Ad>ocLg=`go2`/;4oooool>oeQHF0ko1@D53OlD51@>ooooo`003?ooool>oc@d
=0ko5QHF3Om6ATH=ol?3``Kooooo3_l0000>o`H61Pgo8B4Q3OlG5aL6ooooo`ko3Ph>3_l51@D=oa0@
40go4Q8B1_ooool>ob/[:`ko61PH3Ol92@T=o`0000Kooooo3_l>3Ph=oe1@D0ko2@T93Ol61PH6oooo
o`ko00003Ol@410>o`L71`go92@T1_ooool>o`0000go7AdM3_lg=cL=o`/;2a?ooooo3_mHF5P>o`D5
1@go51@D3_ooool000cooooo3_ld=3@>oaHF5PgoATI63Oo3`l<6ooooo`ko00003_l61PH=ob4Q8@go
5aLG1_ooool>o`h>3Pko1@D53Ol@410=oa8B4PKooooo3_l[:b/>oaPH60go2@T93Ol00006ooooo`ko
3Ph>3Om@D50>o`T92@go1PH61_ooool>o`0000go410@3_l71`L=ob@T90Kooooo3_l0000=oadM7@ko
=cLg3Ol;2`/Cooooo`koF5QH3_l51@D=oa@D50kooooo000<ooooo`ko=3@d3_lF5QH=odI6APgo`l?3
1_ooool>o`0000ko1PH63OlQ8B4=oaLG5`Kooooo3_l>3Ph>o`D51@go410@3OlB4Q86ooooo`ko:b/[
3_lH61P=o`T92@go00001_ooool>o`h>3PgoD51@3_l92@T=o`H61PKooooo3_l0000=oa0@40ko1`L7
3OlT92@6ooooo`ko00003OlM7Ad>ocLg=`go2`/;4oooool>oeQHF0ko1@D53OlD51@>ooooo`003?oo
ool>oc@d=0ko5QHF3Om6ATH=ol?3``Kooooo3_l0000>o`H61Pgo8B4Q3OlG5aL6ooooo`ko3Ph>3_l5
1@D=oa0@40go4Q8B1_ooool>ob/[:`ko61PH3Ol92@T=o`0000Kooooo3_l>3Ph=oe1@D0ko2@T93Ol6
1PH6ooooo`ko00003Ol@410>o`L71`go92@T1_ooool>o`0000go7AdM3_lg=cL=o`/;2a?ooooo3_mH
F5P>o`D51@go51@D3_ooool000cooooo3_ld=3@>oaHF5PgoATI63Oo3`l<6ooooo`ko00003_l61PH=
ob4Q8@go5aLG1_ooool>o`h>3Pko1@D53Ol@410=oa8B4PKooooo3_l[:b/>oaPH60go2@T93Ol00006
ooooo`ko3Ph>3Om@D50>o`T92@go1PH61_ooool>o`0000go410@3_l71`L=ob@T90Kooooo3_l0000=
oadM7@ko=cLg3Ol;2`/Cooooo`koF5QH3_l51@D=oa@D50kooooo000<ooooo`ko00003_l/;2`=obPX
:0goRHV91_ooool>odE5A@ko1@D53Ol<30`=oa<C4`Kooooo3_lN7Qh>o`0000go51@D4oooool>oa8B
4PkoA4A43Ol?3`l=o`820PKooooo3_l92@T=od92@Pko0P823Ol<30`6ooooo`ko0`<33Ol>3Ph>o``<
30go5QHF1_ooool>oaLG5`go2@T93_lB4Q8=o`H61PKooooo3Om0@40>oc/k>`ko00003Ol<30`>oooo
o`003?ooool>o`0000ko;2`/3OlX:2P=ohV9R@Kooooo3_m5ADD>o`D51@go30`<3OlC4a<6ooooo`ko
7QhN3_l0000=oa@D51?ooooo3_lB4Q8>odA4A0go3`l?3Ol20P86ooooo`ko2@T93Om2@T8>o`820Pgo
30`<1_ooool>o`<30`go3Ph>3_l<30`=oaHF5PKooooo3_lG5aL=o`T92@ko4Q8B3Ol61PH6ooooo`go
@4103_lk>c/>o`0000go30`<3_ooool000cooooo3_l0000>ob`/;0go:2PX3On9RHT6ooooo`koADE5
3_l51@D=o``<30go4a<C1_ooool>oahN7Pko00003OlD51@Cooooo`ko4Q8B3_m4A4@=o`l?3`go0P82
1_ooool>o`T92@go@T923_l20P8=o``<30Kooooo3_l30`<=o`h>3Pko30`<3OlF5QH6ooooo`ko5aLG
3Ol92@T>oa8B4Pgo1PH61_ooool=od10@0ko>c/k3_l0000=o``<30kooooo000<ooooo`ko00003_l/
;2`=obPX:0goRHV91_ooool>odE5A@ko1@D53Ol<30`=oa<C4`Kooooo3_lN7Qh>o`0000go51@D4ooo
ool>oa8B4PkoA4A43Ol?3`l=o`820PKooooo3_l92@T=od92@Pko0P823Ol<30`6ooooo`ko0`<33Ol>
3Ph>o``<30go5QHF1_ooool>oaLG5`go2@T93_lB4Q8=o`H61PKooooo3Om0@40>oc/k>`ko00003Ol<
30`>ooooo`003?ooool>o`0000ko;2`/3OlX:2P=ohV9R@Kooooo3_m5ADD>o`D51@go30`<3OlC4a<6
ooooo`ko7QhN3_l0000=oa@D51?ooooo3_lB4Q8>odA4A0go3`l?3Ol20P86ooooo`ko2@T93Om2@T8>
o`820Pgo30`<1_ooool>o`<30`go3Ph>3_l<30`=oaHF5PKooooo3_lG5aL=o`T92@ko4Q8B3Ol61PH6
ooooo`go@4103_lk>c/>o`0000go30`<3_ooool000cooooo3_l0000>ob`/;0go:2PX3On9RHT6oooo
o`koADE53_l51@D=o``<30go4a<C1_ooool>oahN7Pko00003OlD51@Cooooo`ko4Q8B3_m4A4@=o`l?
3`go0P821_ooool>o`T92@go@T923_l20P8=o``<30Kooooo3_l30`<=o`h>3Pko30`<3OlF5QH6oooo
o`ko5aLG3Ol92@T>oa8B4Pgo1PH61_ooool=od10@0ko>c/k3_l0000=o``<30kooooo000<ooooo`ko
00003_l/;2`=obPX:0goRHV91_ooool>odE5A@ko1@D53Ol<30`=oa<C4`Kooooo3_lN7Qh>o`0000go
51@D4oooool>oa8B4PkoA4A43Ol?3`l=o`820PKooooo3_l92@T=od92@Pko0P823Ol<30`6ooooo`ko
0`<33Ol>3Ph>o``<30go5QHF1_ooool>oaLG5`go2@T93_lB4Q8=o`H61PKooooo3Om0@40>oc/k>`ko
00003Ol<30`>ooooo`003?ooool>o`0000ko;2`/3OlX:2P=ohV9R@Kooooo3_m5ADD>o`D51@go30`<
3OlC4a<6ooooo`ko7QhN3_l0000=oa@D51?ooooo3_lB4Q8>odA4A0go3`l?3Ol20P86ooooo`ko2@T9
3Om2@T8>o`820Pgo30`<1_ooool>o`<30`go3Ph>3_l<30`=oaHF5PKooooo3_lG5aL=o`T92@ko4Q8B
3Ol61PH6ooooo`go@4103_lk>c/>o`0000go30`<3_ooool000cooooo3_l0000>ob`/;0go:2PX3On9
RHT6ooooo`koADE53_l51@D=o``<30go4a<C1_ooool>oahN7Pko00003OlD51@Cooooo`ko4Q8B3_m4
A4@=o`l?3`go0P821_ooool>o`T92@go@T923_l20P8=o``<30Kooooo3_l30`<=o`h>3Pko30`<3OlF
5QH6ooooo`ko5aLG3Ol92@T>oa8B4Pgo1PH61_ooool=od10@0ko>c/k3_l0000=o``<30kooooo000<
ooooo`ko00003_l/;2`=obPX:0goRHV91_ooool>odE5A@ko1@D53Ol<30`=oa<C4`Kooooo3_lN7Qh>
o`0000go51@D4oooool>oa8B4PkoA4A43Ol?3`l=o`820PKooooo3_l92@T=od92@Pko0P823Ol<30`6
ooooo`ko0`<33Ol>3Ph>o``<30go5QHF1_ooool>oaLG5`go2@T93_lB4Q8=o`H61PKooooo3Om0@40>
oc/k>`ko00003Ol<30`>ooooo`003?ooool>o`0000ko;2`/3OlX:2P=ohV9R@Kooooo3_m5ADD>o`D5
1@go30`<3OlC4a<6ooooo`ko7QhN3_l0000=oa@D51?ooooo3_lB4Q8>odA4A0go3`l?3Ol20P86oooo
o`ko2@T93Om2@T8>o`820Pgo30`<1_ooool>o`<30`go3Ph>3_l<30`=oaHF5PKooooo3_lG5aL=o`T9
2@ko4Q8B3Ol61PH6ooooo`go@4103_lk>c/>o`0000go30`<3_ooool000cooooo3_l0000>ob`/;0go
:2PX3On9RHT6ooooo`koADE53_l51@D=o``<30go4a<C1_ooool>oahN7Pko00003OlD51@Cooooo`ko
4Q8B3_m4A4@=o`l?3`go0P821_ooool>o`T92@go@T923_l20P8=o``<30Kooooo3_l30`<=o`h>3Pko
30`<3OlF5QH6ooooo`ko5aLG3Ol92@T>oa8B4Pgo1PH61_ooool=od10@0ko>c/k3_l0000=o``<30ko
oooo000<ooooo`ko00003_l/;2`=obPX:0goRHV91_ooool>odE5A@ko1@D53Ol<30`=oa<C4`Kooooo
3_lN7Qh>o`0000go51@D4oooool>oa8B4PkoA4A43Ol?3`l=o`820PKooooo3_l92@T=od92@Pko0P82
3Ol<30`6ooooo`ko0`<33Ol>3Ph>o``<30go5QHF1_ooool>oaLG5`go2@T93_lB4Q8=o`H61PKooooo
3Om0@40>oc/k>`ko00003Ol<30`>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC
4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_oo
ool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY
:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQ
ooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=
ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>
odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIf
MPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6oooo
o`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<
30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>oooo
o`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go
3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Ko
oooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko
;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo
3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@410
3_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo
3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC
4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_oo
ool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY
:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQ
ooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=
ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>
odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIf
MPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6oooo
o`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<
30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>oooo
o`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go
3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Ko
oooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko
;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo
3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@410
3_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo
3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQooooo`ko410@3OlC
4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=ode=C@go;Rh^1_oo
ool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>odQ8B0go92@T3_lY
:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIfMPkoQHF53OnIVITQ
ooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6ooooo`ko1`L73_ooool=
ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<30go7AdM1_ooool>
odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>ooooo`003?ooool>ogIf
MPkoQHF53OnIVITQooooo`ko410@3OlC4a<=obTY:@Kooooo3_l0000>o``<30go3Ph>3Oli>CT6oooo
o`ko1`L73_ooool=ode=C@go;Rh^1_ooool>o`0000go@4103_lD51@=oa4A4@Kooooo6ol?3`l>o``<
30go7AdM1_ooool>odQ8B0go92@T3_lY:BT=ob4Q8@Kooooo3OlO7al>od=3@`ko;2`/3Olo?cl>oooo
o`003?ooool>okBd]0ko?3`l3Oolo?`=ooOgm`Kooooo3_l820P>oa<C4`go9bLW3Ol92@T6ooooo`ko
5QHF3_l51@D=oaLG5`go4a<C1_ooool>ob<S8`ko7AdM3OlE5AD=ob`/;0Kooooo3_lL71`=ooooo`ko
=CDe3OlH61P6ooooo`ko8B4Q3OlI6AT>ob/[:a?ooooo3_l<30`=ob@T90kooooo3OlC4a<6ooooo`go
fm_K3_lM7Ad>oa4A4@goATI63_ooool000cooooo3_nd];@>oc`l?0goo?cl3OogmoL6ooooo`ko20P8
3_lC4a<=obLW9`go2@T91_ooool>oaHF5Pko1@D53OlG5aL=oa<C4`Kooooo3_lS8b<>oadM7@go5ADE
3Ol/;2`6ooooo`ko71`L3Oooool>ocDe=@go61PH1_ooool>ob4Q8@go6ATI3_l[:b/Cooooo`ko30`<
3OlT92@>ooooo`go4a<C1_ooool=om_Kf`ko7AdM3_lA4A4=odI6APkooooo000<ooooo`ko];Bd3_ll
?3`=ooclo0gomoOg1_ooool>o`P820ko4a<C3OlW9bL=o`T92@Kooooo3_lF5QH>o`D51@go5aLG3OlC
4a<6ooooo`ko8b<S3_lM7Ad=oaDE5@go;2`/1_ooool>oa`L70gooooo3_le=CD=oaPH60Kooooo3_lQ
8B4=oaTI6@ko:b/[4oooool>o``<30go92@T3_ooool=oa<C4`Kooooo3OoKfm/>oadM7@ko4A4A3Om6
ATH>ooooo`003?ooool>okBd]0ko?3`l3Oolo?`=ooOgm`Kooooo3_l820P>oa<C4`go9bLW3Ol92@T6
ooooo`ko5QHF3_l51@D=oaLG5`go4a<C1_ooool>ob<S8`ko7AdM3OlE5AD=ob`/;0Kooooo3_lL71`=
ooooo`ko=CDe3OlH61P6ooooo`ko8B4Q3OlI6AT>ob/[:a?ooooo3_l<30`=ob@T90kooooo3OlC4a<6
ooooo`gofm_K3_lM7Ad>oa4A4@goATI63_ooool000cooooo3_nd];@>oc`l?0goo?cl3OogmoL6oooo
o`ko20P83_lC4a<=obLW9`go2@T91_ooool>oaHF5Pko1@D53OlG5aL=oa<C4`Kooooo3_lS8b<>oadM
7@go5ADE3Ol/;2`6ooooo`ko71`L3Oooool>ocDe=@go61PH1_ooool>ob4Q8@go6ATI3_l[:b/Coooo
o`ko30`<3OlT92@>ooooo`go4a<C1_ooool=om_Kf`ko7AdM3_lA4A4=odI6APkooooo000<ooooo`ko
];Bd3_ll?3`=ooclo0gomoOg1_ooool>o`P820ko4a<C3OlW9bL=o`T92@Kooooo3_lF5QH>o`D51@go
5aLG3OlC4a<6ooooo`ko8b<S3_lM7Ad=oaDE5@go;2`/1_ooool>oa`L70gooooo3_le=CD=oaPH60Ko
oooo3_lQ8B4=oaTI6@ko:b/[4oooool>o``<30go92@T3_ooool=oa<C4`Kooooo3OoKfm/>oadM7@ko
4A4A3Om6ATH>ooooo`003?ooool>okBd]0ko?3`l3Oolo?`=ooOgm`Kooooo3_l820P>oa<C4`go9bLW
3Ol92@T6ooooo`ko5QHF3_l51@D=oaLG5`go4a<C1_ooool>ob<S8`ko7AdM3OlE5AD=ob`/;0Kooooo
3_lL71`=ooooo`ko=CDe3OlH61P6ooooo`ko8B4Q3OlI6AT>ob/[:a?ooooo3_l<30`=ob@T90kooooo
3OlC4a<6ooooo`gofm_K3_lM7Ad>oa4A4@goATI63_ooool000cooooo3_nd];@>oc`l?0goo?cl3Oog
moL6ooooo`ko20P83_lC4a<=obLW9`go2@T91_ooool>oaHF5Pko1@D53OlG5aL=oa<C4`Kooooo3_lS
8b<>oadM7@go5ADE3Ol/;2`6ooooo`ko71`L3Oooool>ocDe=@go61PH1_ooool>ob4Q8@go6ATI3_l[
:b/Cooooo`ko30`<3OlT92@>ooooo`go4a<C1_ooool=om_Kf`ko7AdM3_lA4A4=odI6APkooooo000<
ooooo`ko];Bd3_ll?3`=ooclo0gomoOg1_ooool>o`P820ko4a<C3OlW9bL=o`T92@Kooooo3_lF5QH>
o`D51@go5aLG3OlC4a<6ooooo`ko8b<S3_lM7Ad=oaDE5@go;2`/1_ooool>oa`L70gooooo3_le=CD=
oaPH60Kooooo3_lQ8B4=oaTI6@ko:b/[4oooool>o``<30go92@T3_ooool=oa<C4`Kooooo3OoKfm/>
oadM7@ko4A4A3Om6ATH>ooooo`003?ooool>okBd]0ko?3`l3Oolo?`=ooOgm`Kooooo3_l820P>oa<C
4`go9bLW3Ol92@T6ooooo`ko5QHF3_l51@D=oaLG5`go4a<C1_ooool>ob<S8`ko7AdM3OlE5AD=ob`/
;0Kooooo3_lL71`=ooooo`ko=CDe3OlH61P6ooooo`ko8B4Q3OlI6AT>ob/[:a?ooooo3_l<30`=ob@T
90kooooo3OlC4a<6ooooo`gofm_K3_lM7Ad>oa4A4@goATI63_ooool000cooooo3_nd];@>oc`l?0go
o?cl3OogmoL6ooooo`ko20P83_lC4a<=obLW9`go2@T91_ooool>oaHF5Pko1@D53OlG5aL=oa<C4`Ko
oooo3_lS8b<>oadM7@go5ADE3Ol/;2`6ooooo`ko71`L3Oooool>ocDe=@go61PH1_ooool>ob4Q8@go
6ATI3_l[:b/Cooooo`ko30`<3OlT92@>ooooo`go4a<C1_ooool=om_Kf`ko7AdM3_lA4A4=odI6APko
oooo000<ooooo`ko];Bd3_ll?3`=ooclo0gomoOg1_ooool>o`P820ko4a<C3OlW9bL=o`T92@Kooooo
3_lF5QH>o`D51@go5aLG3OlC4a<6ooooo`ko8b<S3_lM7Ad=oaDE5@go;2`/1_ooool>oa`L70gooooo
3_le=CD=oaPH60Kooooo3_lQ8B4=oaTI6@ko:b/[4oooool>o``<30go92@T3_ooool=oa<C4`Kooooo
3OoKfm/>oadM7@ko4A4A3Om6ATH>ooooo`003?ooool>okBd]0ko?3`l3Oolo?`=ooOgm`Kooooo3_l8
20P>oa<C4`go9bLW3Ol92@T6ooooo`ko5QHF3_l51@D=oaLG5`go4a<C1_ooool>ob<S8`ko7AdM3OlE
5AD=ob`/;0Kooooo3_lL71`=ooooo`ko=CDe3OlH61P6ooooo`ko8B4Q3OlI6AT>ob/[:a?ooooo3_l<
30`=ob@T90kooooo3OlC4a<6ooooo`gofm_K3_lM7Ad>oa4A4@goATI63_ooool000cooooo3_nd];@>
oc`l?0goo?cl3OogmoL6ooooo`ko20P83_lC4a<=obLW9`go2@T91_ooool>oaHF5Pko1@D53OlG5aL=
oa<C4`Kooooo3_lS8b<>oadM7@go5ADE3Ol/;2`6ooooo`ko71`L3Oooool>ocDe=@go61PH1_ooool>
ob4Q8@go6ATI3_l[:b/Cooooo`ko30`<3OlT92@>ooooo`go4a<C1_ooool=om_Kf`ko7AdM3_lA4A4=
odI6APkooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {246.125, 0}} -> {-0.208672, -0.0988708, \
0.0168684, 0.0168684}, {{12.3125, 66.875}, {240.25, 185.75}} -> {-0.905992, \
-0.431217, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {240.25, 185.75}} -> \
{-5.30741, -0.431217, 0.0733952, 0.0733952}, {{132.25, 186.812}, {240.25, \
185.75}} -> {-9.70883, -0.431217, 0.0733952, 0.0733952}, {{192.25, 246.75}, \
{240.25, 185.75}} -> {-14.1103, -0.431217, 0.0733952, 0.0733952}, {{252.188, \
306.688}, {240.25, 185.75}} -> {-18.5094, -0.431217, 0.0733952, 0.0733952}, \
{{312.188, 366.688}, {240.25, 185.75}} -> {-22.9131, -0.431217, 0.0733952, \
0.0733952}, {{372.125, 426.625}, {240.25, 185.75}} -> {-27.3122, -0.431217, \
0.0733952, 0.0733952}, {{432.062, 486.625}, {240.25, 185.75}} -> {-31.7136, \
-0.431217, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {180.25, 125.75}} -> \
{-0.905992, -4.83493, 0.0733952, 0.0733952}, {{72.3125, 126.812}, {180.25, \
125.75}} -> {-5.30741, -4.83493, 0.0733952, 0.0733952}, {{132.25, 186.812}, \
{180.25, 125.75}} -> {-9.70883, -4.83493, 0.0733952, 0.0733952}, {{192.25, \
246.75}, {180.25, 125.75}} -> {-14.1103, -4.83493, 0.0733952, 0.0733952}, \
{{252.188, 306.688}, {180.25, 125.75}} -> {-18.5094, -4.83493, 0.0733952, \
0.0733952}, {{312.188, 366.688}, {180.25, 125.75}} -> {-22.9131, -4.83493, \
0.0733952, 0.0733952}, {{372.125, 426.625}, {180.25, 125.75}} -> {-27.3122, \
-4.83493, 0.0733952, 0.0733952}, {{432.062, 486.625}, {180.25, 125.75}} -> \
{-31.7136, -4.83493, 0.0733952, 0.0733952}, {{12.3125, 66.875}, {120.312, \
65.8125}} -> {-0.905992, -9.23406, 0.0733952, 0.0733952}, {{72.3125, \
126.812}, {120.312, 65.8125}} -> {-5.30741, -9.23406, 0.0733952, 0.0733952}, \
{{132.25, 186.812}, {120.312, 65.8125}} -> {-9.70883, -9.23406, 0.0733952, \
0.0733952}, {{192.25, 246.75}, {120.312, 65.8125}} -> {-14.1103, -9.23406, \
0.0733952, 0.0733952}, {{252.188, 306.688}, {120.312, 65.8125}} -> {-18.5094, \
-9.23406, 0.0733952, 0.0733952}, {{312.188, 366.688}, {120.312, 65.8125}} -> \
{-22.9131, -9.23406, 0.0733952, 0.0733952}, {{372.125, 426.625}, {120.312, \
65.8125}} -> {-27.3122, -9.23406, 0.0733952, 0.0733952}, {{432.062, 486.625}, \
{120.312, 65.8125}} -> {-31.7136, -9.23406, 0.0733952, 0.0733952}, {{12.3125, \
66.875}, {60.3125, 5.8125}} -> {-0.905992, -13.6378, 0.0733952, 0.0733952}, \
{{72.3125, 126.812}, {60.3125, 5.8125}} -> {-5.30741, -13.6378, 0.0733952, \
0.0733952}, {{132.25, 186.812}, {60.3125, 5.8125}} -> {-9.70883, -13.6378, \
0.0733952, 0.0733952}, {{192.25, 246.75}, {60.3125, 5.8125}} -> {-14.1103, \
-13.6378, 0.0733952, 0.0733952}, {{252.188, 306.688}, {60.3125, 5.8125}} -> \
{-18.5094, -13.6378, 0.0733952, 0.0733952}, {{312.188, 366.688}, {60.3125, \
5.8125}} -> {-22.9131, -13.6378, 0.0733952, 0.0733952}, {{372.125, 426.625}, \
{60.3125, 5.8125}} -> {-27.3122, -13.6378, 0.0733952, 0.0733952}, {{432.062, \
486.625}, {60.3125, 5.8125}} -> {-31.7136, -13.6378, 0.0733952, 0.0733952}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 2.04504 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11697 -24 -4.5 ]
[-0.0125 .11697 0 4.5 ]
[-0.0125 .21922 -18 -4.5 ]
[-0.0125 .21922 0 4.5 ]
[-0.0125 .32147 -24 -4.5 ]
[-0.0125 .32147 0 4.5 ]
[-0.0125 .42372 -18 -4.5 ]
[-0.0125 .42372 0 4.5 ]
[-0.0125 .52597 -24 -4.5 ]
[-0.0125 .52597 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11697 m
.00625 .11697 L
s
[(0.05)] -0.0125 .11697 1 0 Mshowa
0 .21922 m
.00625 .21922 L
s
[(0.1)] -0.0125 .21922 1 0 Mshowa
0 .32147 m
.00625 .32147 L
s
[(0.15)] -0.0125 .32147 1 0 Mshowa
0 .42372 m
.00625 .42372 L
s
[(0.2)] -0.0125 .42372 1 0 Mshowa
0 .52597 m
.00625 .52597 L
s
[(0.25)] -0.0125 .52597 1 0 Mshowa
.125 Mabswid
0 .03517 m
.00375 .03517 L
s
0 .05562 m
.00375 .05562 L
s
0 .07607 m
.00375 .07607 L
s
0 .09652 m
.00375 .09652 L
s
0 .13742 m
.00375 .13742 L
s
0 .15787 m
.00375 .15787 L
s
0 .17832 m
.00375 .17832 L
s
0 .19877 m
.00375 .19877 L
s
0 .23967 m
.00375 .23967 L
s
0 .26012 m
.00375 .26012 L
s
0 .28057 m
.00375 .28057 L
s
0 .30102 m
.00375 .30102 L
s
0 .34192 m
.00375 .34192 L
s
0 .36237 m
.00375 .36237 L
s
0 .38282 m
.00375 .38282 L
s
0 .40327 m
.00375 .40327 L
s
0 .44417 m
.00375 .44417 L
s
0 .46462 m
.00375 .46462 L
s
0 .48507 m
.00375 .48507 L
s
0 .50552 m
.00375 .50552 L
s
0 .54643 m
.00375 .54643 L
s
0 .56688 m
.00375 .56688 L
s
0 .58733 m
.00375 .58733 L
s
0 .60778 m
.00375 .60778 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11697 m
1 .11697 L
s
.99375 .21922 m
1 .21922 L
s
.99375 .32147 m
1 .32147 L
s
.99375 .42372 m
1 .42372 L
s
.99375 .52597 m
1 .52597 L
s
.125 Mabswid
.99625 .03517 m
1 .03517 L
s
.99625 .05562 m
1 .05562 L
s
.99625 .07607 m
1 .07607 L
s
.99625 .09652 m
1 .09652 L
s
.99625 .13742 m
1 .13742 L
s
.99625 .15787 m
1 .15787 L
s
.99625 .17832 m
1 .17832 L
s
.99625 .19877 m
1 .19877 L
s
.99625 .23967 m
1 .23967 L
s
.99625 .26012 m
1 .26012 L
s
.99625 .28057 m
1 .28057 L
s
.99625 .30102 m
1 .30102 L
s
.99625 .34192 m
1 .34192 L
s
.99625 .36237 m
1 .36237 L
s
.99625 .38282 m
1 .38282 L
s
.99625 .40327 m
1 .40327 L
s
.99625 .44417 m
1 .44417 L
s
.99625 .46462 m
1 .46462 L
s
.99625 .48507 m
1 .48507 L
s
.99625 .50552 m
1 .50552 L
s
.99625 .54643 m
1 .54643 L
s
.99625 .56688 m
1 .56688 L
s
.99625 .58733 m
1 .58733 L
s
.99625 .60778 m
1 .60778 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .01974 L
.04348 .01974 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .01974 L
.04348 .01974 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .15182 L
.07453 .15182 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .15182 L
.07453 .15182 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .14966 L
.10559 .14966 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .14966 L
.10559 .14966 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .01615 L
.13665 .01615 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .01615 L
.13665 .01615 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .01472 L
.1677 .01472 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .01472 L
.1677 .01472 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .15325 L
.19876 .15325 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .15325 L
.19876 .15325 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .13028 L
.22981 .13028 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .13028 L
.22981 .13028 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .01472 L
.26087 .01472 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .01472 L
.26087 .01472 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .131 L
.29193 .131 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .131 L
.29193 .131 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .0183 L
.32298 .0183 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .0183 L
.32298 .0183 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .14033 L
.35404 .14033 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .14033 L
.35404 .14033 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .01974 L
.38509 .01974 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .01974 L
.38509 .01974 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .01543 L
.41615 .01543 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .01543 L
.41615 .01543 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .15038 L
.4472 .15038 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .15038 L
.4472 .15038 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .14177 L
.47826 .14177 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .14177 L
.47826 .14177 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .01472 L
.50932 .01472 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .01472 L
.50932 .01472 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .01543 L
.54037 .01543 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .01543 L
.54037 .01543 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .12167 L
.57143 .12167 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .12167 L
.57143 .12167 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .15971 L
.60248 .15971 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .15971 L
.60248 .15971 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .01615 L
.63354 .01615 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .01615 L
.63354 .01615 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .01543 L
.6646 .01543 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .01543 L
.6646 .01543 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .131 L
.69565 .131 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .131 L
.69565 .131 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .12598 L
.72671 .12598 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .12598 L
.72671 .12598 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .02405 L
.75776 .02405 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .02405 L
.75776 .02405 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .01687 L
.78882 .01687 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .01687 L
.78882 .01687 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .15541 L
.81988 .15541 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .15541 L
.81988 .15541 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .1432 L
.85093 .1432 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .1432 L
.85093 .1432 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .01472 L
.88199 .01472 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .01472 L
.88199 .01472 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .12669 L
.9441 .12669 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .12669 L
.9441 .12669 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .13818 L
.97516 .13818 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .13818 L
.97516 .13818 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .5703 L
.01863 .5703 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .5703 L
.01863 .5703 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .0341 L
.04969 .0341 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .0341 L
.04969 .0341 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .02333 L
.08075 .02333 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .02333 L
.08075 .02333 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .02118 L
.1118 .02118 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .02118 L
.1118 .02118 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .28246 L
.14286 .28246 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .28246 L
.14286 .28246 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .02046 L
.17391 .02046 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .02046 L
.17391 .02046 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .01687 L
.20497 .01687 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .01687 L
.20497 .01687 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .01615 L
.23602 .01615 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .01615 L
.23602 .01615 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .35209 L
.26708 .35209 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .35209 L
.26708 .35209 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .01543 L
.29814 .01543 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .01543 L
.29814 .01543 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .02046 L
.32919 .02046 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .02046 L
.32919 .02046 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .01543 L
.36025 .01543 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .01543 L
.36025 .01543 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .04343 L
.3913 .04343 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .04343 L
.3913 .04343 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .02189 L
.42236 .02189 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .02189 L
.42236 .02189 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .01543 L
.45342 .01543 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .01543 L
.45342 .01543 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .01543 L
.48447 .01543 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .01543 L
.48447 .01543 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .27456 L
.51553 .27456 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .27456 L
.51553 .27456 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01759 L
.54658 .01759 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01759 L
.54658 .01759 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .01615 L
.57764 .01615 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .01615 L
.57764 .01615 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .02333 L
.6087 .02333 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .02333 L
.6087 .02333 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .26738 L
.63975 .26738 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .26738 L
.63975 .26738 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .0183 L
.67081 .0183 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .0183 L
.67081 .0183 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .01902 L
.70186 .01902 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .01902 L
.70186 .01902 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .26667 L
.76398 .26667 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .26667 L
.76398 .26667 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .01543 L
.79503 .01543 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .01543 L
.79503 .01543 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .0183 L
.82609 .0183 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .0183 L
.82609 .0183 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .01543 L
.85714 .01543 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .01543 L
.85714 .01543 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .01759 L
.8882 .01759 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .01759 L
.8882 .01759 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .01759 L
.95031 .01759 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .01759 L
.95031 .01759 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .60332 L
.02484 .60332 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .60332 L
.02484 .60332 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .02907 L
.0559 .02907 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .02907 L
.0559 .02907 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .01472 L
.08696 .01472 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .01472 L
.08696 .01472 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .01543 L
.11801 .01543 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .01543 L
.11801 .01543 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .2961 L
.14907 .2961 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .2961 L
.14907 .2961 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .01543 L
.18012 .01543 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .01543 L
.18012 .01543 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .01472 L
.21118 .01472 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .01472 L
.21118 .01472 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .01543 L
.24224 .01543 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .01543 L
.24224 .01543 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .32553 L
.27329 .32553 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .32553 L
.27329 .32553 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .01543 L
.30435 .01543 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .01543 L
.30435 .01543 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .01472 L
.3354 .01472 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .01472 L
.3354 .01472 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .01687 L
.39752 .01687 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .01687 L
.39752 .01687 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .0183 L
.42857 .0183 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .0183 L
.42857 .0183 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .49206 L
.52174 .49206 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .49206 L
.52174 .49206 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .01472 L
.58385 .01472 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .01472 L
.58385 .01472 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .01543 L
.61491 .01543 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .01543 L
.61491 .01543 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .21642 L
.64596 .21642 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .21642 L
.64596 .21642 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .17622 L
.77019 .17622 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .17622 L
.77019 .17622 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .01472 L
.89441 .01472 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .01472 L
.89441 .01472 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .17838 L
.06211 .17838 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .17838 L
.06211 .17838 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .04702 L
.09317 .04702 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .04702 L
.09317 .04702 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .04486 L
.12422 .04486 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .04486 L
.12422 .04486 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .02261 L
.15528 .02261 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .02261 L
.15528 .02261 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .16546 L
.18634 .16546 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .16546 L
.18634 .16546 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .02907 L
.21739 .02907 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .02907 L
.21739 .02907 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .05061 L
.24845 .05061 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .05061 L
.24845 .05061 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .03266 L
.2795 .03266 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .03266 L
.2795 .03266 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .05061 L
.31056 .05061 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .05061 L
.31056 .05061 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .24513 L
.34161 .24513 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .24513 L
.34161 .24513 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .03266 L
.37267 .03266 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .03266 L
.37267 .03266 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .19704 L
.40373 .19704 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .19704 L
.40373 .19704 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .15828 L
.43478 .15828 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .15828 L
.43478 .15828 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .02261 L
.46584 .02261 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .02261 L
.46584 .02261 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .03194 L
.49689 .03194 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .03194 L
.49689 .03194 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .02333 L
.52795 .02333 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .02333 L
.52795 .02333 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .17909 L
.55901 .17909 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .17909 L
.55901 .17909 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .03338 L
.59006 .03338 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .03338 L
.59006 .03338 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .06783 L
.62112 .06783 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .06783 L
.62112 .06783 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .05061 L
.65217 .05061 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .05061 L
.65217 .05061 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .15469 L
.68323 .15469 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .15469 L
.68323 .15469 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .03625 L
.71429 .03625 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .03625 L
.71429 .03625 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .03338 L
.74534 .03338 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .03338 L
.74534 .03338 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .05348 L
.7764 .05348 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .05348 L
.7764 .05348 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .15756 L
.80745 .15756 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .15756 L
.80745 .15756 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .04558 L
.83851 .04558 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .04558 L
.83851 .04558 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .02476 L
.86957 .02476 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .02476 L
.86957 .02476 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .14033 L
.90062 .14033 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .14033 L
.90062 .14033 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .1389 L
.93168 .1389 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .1389 L
.93168 .1389 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .02835 L
.96273 .02835 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .02835 L
.96273 .02835 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .02476 L
.99379 .02476 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .02476 L
.99379 .02476 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00;Oooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000>oooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000>ooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo0000013ooooo000^ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03?ooool002gooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00cooooo000^ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0000oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Voooooooo0000aOl0000:
ooooo`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l5oomo0004o`000?oo
003oo`00ool000?o0?l00_l00?l4oomo00;o00000ooo0003o`3o00;o003o1?ooO`02o`0000?oo`00
0ol0o`02o`00o`Coogl00_l00003ool000?o0?l00_l00?l4oomo00;o00000ooo0003o`3o00;o003o
1?ooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o0000
0ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl0
0_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`00
0ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o
0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o0000
0ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl0
0_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`00
0ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o
0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00?o0000
2_ooool001cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?l5ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool3ool000Co0?l000?ooooooomo0?ooO`00
0_ooO`02ooooo`?oo`001?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl0
1Oooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool3ool000Co0?l00_ooool3oomo00;ooooo
1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
0ooo0004o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0003o`3o00?o003o
0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo
0oooO`05ooooo`?o0?l00ol00?l3oomo00Gooooo1?l0o`02ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl01Oooool3o`3o00?o003o0oooO`05ooooo`Co0?l0
0_ooool3oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0004o`3o00;ooooo
0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo1?l0o`02ooooo`?oogl02oooool3oomo00;ooooo
0ooo0004o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo00?o0000ooooooooool0
2?ooool001cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?l5ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool3ool000Co0?l000?ooooooomo0?ooO`00
0_ooO`02ooooo`?oo`001?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl0
1Oooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`Co0?l0
0_ooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l00_ooool3oomo00Gooooo
1?l0o`02ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l0
0_ooool3oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo0ooo0004o`3o00;ooooo
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl0
0_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl0
0_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo00?o0000ooooooooool0
2?ooool001gooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Sooooo0ol0
o`02o`00o`Coogl00_ooool3ool000Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`?oo`001?l0
o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo
0005ooooo`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0ooo
O`05ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`05ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo
0004o`3o00;ooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00_ooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00_ooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l8ooooo`?o0?l00_l00?l4
oomo00;ooooo0ooo0004o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000Cooooo1?ooO`05
ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3
oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_ooool4
ool000Gooooo0oooO`05ooooo`Co0?l00_ooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4
ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3
oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02
ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3
oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3
oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l8oooo
o`?o0?l00_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4ool000Cooooo1?ooO`05oooo
o`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo
00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_ooool4ool0
00Gooooo0oooO`05ooooo`Co0?l00_ooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool0
00Gooooo0oooO`05ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Gooooo0oooO`02oooo
o`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo0005oooo
o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02oooo
o`Coo`001Oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo0005oooo
o`?oogl00_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o2?ooool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00;o
oooo1?oo0004ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo0005ooooo`?o
ogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?o
ogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`0;ooooo`?o
ogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o3Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00_o
oooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o
003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`004oooool3oomo00_o
oooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000:ooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Sooooo1?l0o`000oooooooogl0
oomo0002oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l0
0ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
1?l0o`02ooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo00Gooooo
0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl0
1Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl0
0_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Sooooo1?l0
o`000oooooooogl0oomo0002oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4ool000Cooooo1?oo
O`05ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Ooo
ool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00Gooooo1?l0o`02ooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`001Ooo
ool3oomo00Gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo
0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo
000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool3o`3o00?o003o2?ooool4
o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?ooool4
oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05
ooooo`?o0?l01?l00?l4ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`003Oooool4
o`3o00;ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;
ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Oooool3o`3o00?o003o0oooO`0;
ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02
ooooo`Coo`002_ooool4ool000Wooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?ooool4oomo
00Gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05oooo
o`?o0?l01?l00?l4ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`003Oooool4o`3o
00;ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=oooo
o`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;oooo
o`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02oooo
o`Coo`001Oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:oooo
o`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?l=ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?ooool4oomo00Go
oooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05ooooo`?o
0?l01?l00?l4ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`003Oooool4o`3o00;o
oooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Co
o`001Oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Co
o`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?l=ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?ooool4oomo00Gooooo
0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05ooooo`?o0?l0
1?l00?l4ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`003Oooool4o`3o00;ooooo
0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl0
0_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`00
2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?ooool4oomo00Gooooo0ol0
o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05ooooo`?o0?l01?l0
0?l4ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0ooo
O`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_oo
ool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=
ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4
oomo00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0005
ooooo`?oogl02oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:
ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`001Oooool3
oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3
o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`004oooool3
oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:oooo
o`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo
00Gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl02oooool3oomo00;ooooo1?oo000Coooo
o`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl02oooool3oomo
00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Co
ogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[o
oooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`0;ooooo`?o
ogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o
0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o
003o0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00_o
oooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[o
oooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo
1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl0
0_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o
3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`0;ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`00
2_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00o`gooooo1?oo
O`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0ooo
O`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_oo
ool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo
000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004ooo
ool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000Wooooo0_l0000:ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=
ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4
ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:
ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`001Oooool3
oomo00Gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04
o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4
ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00
o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Coooo
o`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=oooo
o`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl01Oooool3o`3o
00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool0
00[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;o
oooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Co
o`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`go
oooo0oooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05ooooo`?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[o
oooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl0
0_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo
1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl0
2oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo
1?oo000:ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
2_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo
0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0
o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo
0005ooooo`?oogl01Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0ooo
O`02ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3
o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4
ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4
ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`05
ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:
ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=oooo
o`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo
00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o
00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:oooo
o`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;o
oooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Co
o`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_o
oooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Co
o`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000go
oooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o0000
0oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o
3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo
0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo
0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo
0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
2_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo0009ooooo`;o0000
2_ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo
000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0ooo
O`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0
o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_oo
ool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03
o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000C
ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=
ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4
ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=oooo
o`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool0
00[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Coooo
o`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:oooo
o`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo
00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Co
o`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co
003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Co
o`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000go
oooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`go
oooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[o
oooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo
1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl0
0_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo
1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo
000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02ooo
ool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo
000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0ooo
O`02ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3
o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4
ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4
ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04
o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02
ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02oooo
o`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0
01?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=oooo
o`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000Coooo
o`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[o
oooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o
0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;o
oooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Co
o`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co
003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Co
o`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l0
0ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl0
0_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo
1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o
3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo
1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`00
4oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000Wooooo0_l0000:ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo
000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l0
0?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo
000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Ooo
ool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4
oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02
ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04
o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02
ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4
ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02oooo
o`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool0
00gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0;oooo
o`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=oooo
o`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo
00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o
0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Co
o`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Co
o`003Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co
003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo00;o
oooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000[o
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o
3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo
1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`00
4oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo
0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
2_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo
0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo
000;ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Oooooo00?o
0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?oo
ool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0
o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0ooo
O`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo
000:ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o
003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?o
oooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000go
oooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`go
oooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Co
o`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03
o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02oooo
o`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0
01?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=oooo
o`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000Coooo
o`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08oooo
o`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool01?ooool4o`0000;ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4
ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04
o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4
ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=
ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:
ooooo`Coo`001oooool4o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0000Oooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Ooo
ool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo
000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004ooo
ool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0ooo
O`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0ooo
O`0;ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000go
oooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Co
oooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[o
oooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o
0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Co
o`002_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000[ooooo0_l00002ooooo`Go0000
1_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo
1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l0
1?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo
1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo013ooooo1?oo000=ooooo`?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`00
2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo
000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o3Ooo
ool3oomo013ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo
000=ooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000[ooooo1?oo000Cooooo`?oogl02ooo
ool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=
ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4
ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:
ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo013ooooo1?oo000=ooooo`?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool001_ooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4
ool001?ooooo0oooO`0;ooooo`?oogl04?ooool4ool000[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:oooo
o`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o
00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02oooo
o`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0@ooooo`Coo`003Oooool3o`3o
00Co003o3Oooool3oomo00;ooooo1?oo000Kooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000Cooooo`?oogl02oooool3oomo013ooooo1?oo000:ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Co
o`002_ooool4ool000gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`006oooool3o`3o00Co
003o6oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Co
o`003Oooool3o`3o00Co003o3Oooool3oomo013ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?o
ogl08Oooool3o`3o00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`004oooool3oomo00_o
oooo0oooO`0@ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l0
0ol00?l=ooooo`Coogl00_ooool4ool001_ooooo0ol0o`04o`00oa_ooooo0oooO`02ooooo`Coo`00
4oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo
0oooO`0@ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo027ooooo0ol0o`04o`00o`gooooo
0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl04?ooool4ool000[ooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?l=ooooo`Coogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001_ooooo0ol0
o`04o`00oa_ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0@ooooo`Coo`003Oooool3o`3o00Co003o3Ooo
ool3oomo027ooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`002_ooool4ool001?ooooo0ooo
O`0;ooooo`?oogl04?ooool4ool000Wooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=
ooooo`Coogl00_ooool4ool001_ooooo0ol0o`04o`00oa_ooooo0oooO`02ooooo`Coo`004oooool3
oomo00_ooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0@
ooooo`Coo`003Oooool3o`3o00Co003o3Oooool3oomo027ooooo0ol0o`04o`00o`gooooo0oooO`02
ooooo`Coo`002_ooool4ool001?ooooo0oooO`0;ooooo`?oogl07_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool0
00[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001_ooooo0ol0o`04o`00
oa_ooooo0oooO`0Iooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o
00Co003o3Oooool3oomo013ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl08Oooool3o`3o
00Co003o3Oooool3oomo00;ooooo1?oo000:ooooo`Coo`00@_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000[o
oooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001_ooooo0ol0o`04o`00oa_o
oooo0oooO`0Iooooo`?oogl02oooool3oomo00;ooooo1?oo000Kooooo`?o0?l01?l00?l=ooooo`?o
ogl04?ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0Qooooo`?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000[ooooo1?oo0012ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`002_ooool4ool000gooooo
0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`006oooool3o`3o00Co003o6oooool3oomo01Wooooo
0oooO`0;ooooo`?oogl00_ooool4ool001_ooooo0ol0o`04o`00o`gooooo0oooO`0@ooooo`Coo`00
3Oooool3o`3o00Co003o3Oooool3oomo027ooooo0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
D?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l=ooooo`Coogl00_oo
ool4ool001_ooooo0ol0o`04o`00oa_ooooo0oooO`0Iooooo`?oogl02oooool3oomo00;ooooo1?oo
000Kooooo`?o0?l01?l00?l=ooooo`?oogl04?ooool4ool000gooooo0ol0o`04o`00o`gooooo0ooo
O`0Qooooo`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0053ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000:
ooooo`Coo`003Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Kooooo`?o0?l01?l00?lK
ooooo`?oogl06Oooool3oomo00_ooooo0oooO`02ooooo`Coo`006oooool3o`3o00Co003o3Oooool3
oomo013ooooo1?oo000=ooooo`?o0?l01?l00?l=ooooo`?oogl08Oooool3o`3o00Co003o3Oooool3
oomo00;ooooo1?oo001@ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`006oooool3o`3o00?o003o3Oooool4oomo
00;ooooo1?oo000Kooooo`?o0?l01?l00?lKooooo`?oogl06Oooool3oomo00_ooooo0oooO`0Qoooo
o`?o0?l01?l00?l=ooooo`?oogl04?ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0Qoooo
o`?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0053ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo027ooooo0ol0o`03o`00o`go
oooo1?ooO`0Qooooo`?o0?l01?l00?lKooooo`?oogl06Oooool3oomo00_ooooo0oooO`0Qooooo`?o
0?l01?l00?l=ooooo`?oogl04?ooool4ool000gooooo0ol0o`04o`00o`gooooo0oooO`0Qooooo`?o
0?l01?l00?l=ooooo`?oogl00_ooool4ool0053ooooo00?o0000ooooooooool02?ooool002Kooooo
0ol00003ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o3Oooool4oomo027ooooo
0ol0o`04o`00oa_ooooo0oooO`0Iooooo`?oogl02oooool3oomo027ooooo0ol0o`04o`00o`gooooo
0oooO`0@ooooo`Coo`003Oooool3o`3o00Co003o<Oooool3o`3o00Co003o3Oooool3oomo05Gooooo
0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Ooo
ool3o`3o00?o003o3Oooool4oomo027ooooo0ol0o`04o`00oa_ooooo0oooO`0Iooooo`?oogl02ooo
ool3oomo027ooooo0ol0o`04o`00o`gooooo0oooO`0@ooooo`Coo`003Oooool3o`3o00Co003o<Ooo
ool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o3Oooool4oomo027ooooo0ol0o`04
o`00oa_ooooo0oooO`0Iooooo`?oogl0;oooool3o`3o00Co003o3Oooool3oomo027ooooo0ol0o`04
o`00oc7ooooo0ol0o`04o`00ofKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o3Oooool4oomo027ooooo0ol0o`03o`00o`gooooo1?ooO`0Qoooo
o`?o0?l01?l00?lKooooo`?oogl06Oooool3oomo02oooooo0ol0o`04o`00o`gooooo0oooO`0Qoooo
o`?o0?l01?l00?laooooo`?o0?l01?l00?mVooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`0Qooooo`?o0?l00ol00?l=ooooo`Co
ogl08Oooool3o`3o00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?o
ogl08Oooool3o`3o00Co003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o
<_ooool3o`3o00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?oogl0
8Oooool3o`3o00Co003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o<_oo
ool3o`3o00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?oogl08Ooo
ool3o`3o00Co003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o<_ooool3
o`3o00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?oogl08Oooool3
o`3o00Co003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o<_ooool3o`3o
00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?oogl08Oooool3o`3o
00Co003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl08Oooool3o`3o00?o003o<_ooool3o`3o00Co
003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?l=ooooo`?oogl08Oooool3o`3o00Co
003o<Oooool3o`3o00Co003oI_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo
0ol0o`03o`00o`gooooo1?ooO`0Qooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl0
6Oooool3oomo02oooooo0ol0o`04o`00o`gooooo0oooO`0Qooooo`?o0?l01?l00?laooooo`Co0?l0
J?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0
o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`0Iooooo`?oogl0;oooool3o`3o00Co003o<Ooo
ool3o`3o00Co003o<Oooool4o`3o06Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o<_ooool3o`3o00Co003o6oooool3
oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?laooooo`?o0?l01?l00?laooooo`Co0?l0JOooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lboooo
o`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl06Oooool3oomo02oooooo0ol0o`04o`00
oc7ooooo0ol0o`04o`00oc7ooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_o
oooo0oooO`0Iooooo`?oogl0;oooool3o`3o00Co003o<Oooool3o`3o00Co003o<Oooool4o`3o06Wo
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o
<_ooool3o`3o00?o003o<_ooool3o`3o00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l0
1?l00?laooooo`?o0?l01?l00?laooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l0
0?lKooooo`?oogl06Oooool3oomo02oooooo0ol0o`04o`00oc7ooooo0ol0o`04o`00oc7ooooo1?l0
o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`0Iooooo`?oogl0;oooool3
o`3o00Co003o<Oooool3o`3o00Co003o<Oooool4o`3o06Wooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o<_ooool3o`3o
00Co003o6oooool3oomo01Wooooo0oooO`0_ooooo`?o0?l01?l00?laooooo`?o0?l01?l00?laoooo
o`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00oc;o
oooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l00?laooooo`?o
0?l01?l00?laooooo`Co0?l0J?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l0
1?l00?laooooo`?o0?l01?l00?laooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l0
0?lKooooo`?oogl0Boooool3o`3o00Co003o<Oooool3o`3o00Co003o<Oooool4o`3o06Wooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3
o`3o00?o003o<_ooool3o`3o00Co003o6oooool3oomo04_ooooo0ol0o`04o`00oc7ooooo0ol0o`04
o`00oc7ooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;oooo
o`?o0?l01?l00?laooooo`?o0?l01?l00?laooooo`Co0?l0JOooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o
0?l01?l00?lKooooo`?oogl0Boooool3o`3o00Co003o<Oooool3o`3o00Co003o<Oooool4o`3o06Wo
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o
<_ooool3o`3o00?o003o<_ooool3o`3o00Co003o6oooool3oomo04_ooooo0ol0o`04o`00oc7ooooo
0ol0o`04o`00oc7ooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl0Boooool3o`3o00Co003o<Ooo
ool3o`3o00Co003o<Oooool4o`3o06Wooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l0
0?laooooo`?o0?l01?l00?laooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`004?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l00002ooooo`?o0?l00ol0
0?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl0Boooool3o`3o00Co003o<Ooo
ool4o`3o03Cooooo1?l0o`1Vooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0
o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l00?laooooo`Co0?l0=?oo
ool4o`3o06Wooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0
o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l00?laooooo`Co0?l0=?oo
ool4o`3o06Wooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002?oo
ool2o`0000Sooooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o<_oo
ool3o`3o00Co003o6oooool3oomo04_ooooo0ol0o`04o`00oc7ooooo1?l0o`0dooooo`Co0?l0JOoo
ool00ol0003oooooooooo`08ooooo`004Oooool2o`0000[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lK
ooooo`?oogl0Boooool3o`3o00Co003o<Oooool4o`3o03Cooooo1?l0o`1Yooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00
oc;ooooo0ol0o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l00?laooooo`Co0?l0=?ooool4o`3o
06Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003o<_ooool3o`3o00?o003o<_ooool3o`3o00Co003o6oooool3oomo04_ooooo0ol0o`04o`00oc7o
oooo1?l0o`0dooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl0
Boooool3o`3o00Co003o<Oooool4o`3o03Cooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0
o`04o`00oa_ooooo0oooO`1;ooooo`?o0?l01?l00?laooooo`Co0?l0=?ooool4o`3o06Wooooo00?o
0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lb
ooooo`?o0?l01?l00?lKooooo`?oogl0Boooool3o`3o00Co003o<Oooool4o`3o03Cooooo1?l0o`1X
ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o
00?o003o<_ooool3o`3o00Co003o6oooool3oomo04_ooooo0ol0o`04o`00oc7ooooo1?l0o`0doooo
o`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?lKooooo`?oogl0Boooool3o`3o00Co
003o<Oooool4o`3o03Cooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00oa_ooooo
0oooO`1;ooooo`?o0?l01?l00?laooooo`Co0?l0=?ooool4o`3o06Wooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o<_oo
ool3o`3o00Co003oJOooool3o`3o00Co003o<Oooool4o`3o03Cooooo1?l0o`1Yooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03
o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00oc7ooooo1?l0o`0dooooo`Co0?l0JOooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lboooo
o`?o0?l00ol00?lbooooo`?o0?l01?l00?mYooooo`?o0?l01?l00?laooooo`Co0?l0=?ooool4o`3o
06Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003o<_ooool3o`3o00?o003o<_ooool3o`3o00Co003oJOooool3o`3o00Co003o<Oooool4o`3o03Co
oooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00oc7ooooo
1?l0o`0dooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0
o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00oc7ooooo1?l0
o`0dooooo`Co0?l0J?ooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00oc7ooooo1?l0o`0d
ooooo`Co0?l0JOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?mYooooo`?o0?l01?l00?laoooo
o`Co0?l0=?ooool4o`3o06Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o<_ooool3o`3o00Co003oJOooool3o`3o00Co
003o<Oooool4o`3o03Cooooo1?l0o`1Yooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofWooooo
0ol0o`04o`00oc7ooooo1?l0o`2Qooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0
o`04o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o<_ooool3o`3o00?o003o<_ooool3o`3o00Co003oJOooool3o`3o00Co003oe_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lboooo
o`?o0?l00ol00?lbooooo`?o0?l01?l00?mYooooo`?o0?l01?l00?oFooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;o
oooo0ol0o`04o`00ofcooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00oc;ooooo0ol0o`04o`00ofcooooo
1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool3o`3o00?o003o<_oo
ool3o`3o00?o003o<_ooool3o`3o00Co003oK?ooool4o`00omGooooo0_l0000:ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?lbooooo`?o0?l01?l00?m/
ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?leooooo`?o003o<_ooool3o`3o00Co003oK?ooool4o`00omKooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;o
oooo0ol0o`04o`00ofcooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`?o0?l01?l00?m/ooooo`Co003o
e_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?leooooo`?o003o<_ooool3o`3o00Co003oK?ooool4o`00omKooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo0ol0o`04
o`00ofcooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`?o0?l01?l00?m/ooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?mZooooo`?o
0?l01?l00?m/ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo
0ol0o`03o`00of[ooooo0ol0o`04o`00ofcooooo1?l00?oEooooo`;o00002_ooool002Kooooo00?o
0000ooooooooool00oooool3o`3o00?o003oJ_ooool3o`3o00Co003oK?ooool4o`00omKooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003oJ_ooool3
o`3o00Co003oK?ooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003oJ_ooool3o`3o00Co003oK?ooool4o`00omKooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003oJ_ooool3o`3o00Co
003oK?ooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003oJ_ooool3o`3o00Co003oK?ooool4o`00omKooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003oJ_ooool3o`3o00Co003oK?oo
ool4o`00omKooooo00?o0000ooooooooool02?ooool000_ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00003ooooo`?o00001oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?mZ
ooooo`?o0?l01?l00?m/ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0
003oooooooooool00009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00of[ooooo0ol0o`04o`00ofcooooo1?l0
0?oFooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`Co00000_ooool3o`3o00?o003oJ_oo
ool3o`3o00Co003oK?ooool4o`00om?ooooo1?l0000:ooooo`002_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?mZooooo`?o0?l01?l00?m/ooooo`Co003oe_ooool00ol0003ooooooooo
o`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooooooo`Co0000
1oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?mZooooo`?o0?l01?l00?m/ooooo`Co003o
e_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`;o0000
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00of[ooooo
1?l0o`1_ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000[ooooo00Co
0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00of[ooooo
1?l0o`1_ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?mZooooo`Co0?l0Koooool4o`00omKooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003oJ_ooool4o`3o06oooooo1?l00?oF
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
of[ooooo1?l0o`1_ooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?mZooooo`Co0?l0Koooool4o`00omKooooo00?o0000oooooooo
ool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?mZooooo`Co0?l0Koooool4o`00omGooooo
0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?mZooooo`Co0?l0Kooo
ool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003oJ_ooool4o`3o06oooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00of[ooooo1?l0o`1_ooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?mZooooo`Co
0?l0Koooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003oJ_ooool4o`3o06oooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oF
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o0000
0oooool3o`3o00?o003ogOooool4o`00omGooooo0_l0000:ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co
003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00omgooooo1?l00?oEooooo`;o
00002_ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOoo
ool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOoo
ool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003oooo
o`?o0?l00ol00?oMooooo`Co003oeOooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oF
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01_ooool4o`0000;ooooo0ol0o`03o`00omgooooo1?l00?oCoooo
o`Co00002_ooool0013ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo
00Sooooo000@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooo
oooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oo
oooooooo00Sooooo000Aooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool00oooool3
o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ogOoo
ool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?oM
ooooo`Co003oeOooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oF
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00omgooooo1?l00?oFooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`?o00000oooool3o`3o00?o003ogOooool4o`00omGooooo0_l0000:
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co
003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co003oe_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oMooooo`Co
003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oMooooo`Co003oe_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0
o`03o`00omgooooo1?l00?oEooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003ogOooool4o`00omKooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oo
oooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o
00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo
0ol0o`03o`00oooooooo]oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oo
oooooooo00Sooooo000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol0
0007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooooooo
o`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooo
oooo^?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000;ooooo0ol0o`03o`00oooo
oooo]Oooool4o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooo
oooo^?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`06
o`000?ooooooooooooooool0003ooooo1?l00007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007
ooooo`07o`000?ooooooooooooooool0003oooooo`00000:ooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo0ol0
0002ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonh
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool3
o`0000?ooooo0ol0o`03o`00oooooooo]oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhoooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooo
oooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol0
0?oooooookOooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oo
oooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_ooool3o`00
oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`?o
003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Kooooo
0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_oo
ool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06
ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00Kooooo0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool01_ooool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000Kooooo
0ol00?oooooookOooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`06ooooo`?o003ooooo
oonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Kooooo0ol00?oo
oooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_ooool3o`00
oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`?o
003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00Kooooo
0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_oo
ool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06
ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
0?oooooo`Oooool00ol0003oooooooooo`08ooooo`009_ooool3o`000?oooooo`?ooool2o`0000[o
oooo000Vooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`009_ooooooo`000<Go00002_ooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool002gooooo0ol0000:ooooo`Go00002_ooool3o`0000cooooo0ol0000:ooooo`?o00002oooool3
o`0000cooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l00009ooooo`?o00001?ooool2
o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3
o`0000Gooooo0ol00004ooooo`?o00001?ooool3o`0000?ooooo0ol00005ooooo`?o00000oooool3
o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3
o`0000?ooooo0_l00005ooooo`Go00000oooool2o`0000Cooooo1Ol00002ooooo`?o00001?ooool5
o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000oooool3
o`0000?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0ol00004ooooo`Go00000oooool0
0ol0003oooooooooo`03ooooo`Go00000_ooool3o`0000Cooooo1Ol00002ooooo`;o00001_ooool3
o`0000Cooooo0_l00005ooooo`?o00000oooool3o`0000Gooooo0ol00002ooooo`Go00003_ooool0
02kooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009ooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00003_ooool002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo1Ol0000=ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Wooooo00Go0000ooooooooooooooooo`00000@ooooo`00;_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool01oooool4o`0000gooooo00?o0000ooooooooool02Oooool3o`0000_o
oooo1?l00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool4o`0000Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo1?l00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`0000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`?o00001oooool01?l0
003oooooooooooooool4o`0000Gooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00gooooo000^
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000002_ooool4o`0000[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooooooo`Co00001_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000Cooooo00Ko0000oooo
ooooooooooooo`000?ooool4o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oo
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00cooooo000]ooooo`;o00002oooool01Ol0003ooooooooooooooooo000000Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`;o00002_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00005
ooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00?o0000
ooooooooool01Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`07o`000?ooooooooooooooool0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`0000Cooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o00001Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003o
ooooooooo`0<ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`?o00002oooool3o`0000gooooo
00?o0000ooooooooool02?ooool5o`0000_ooooo0_l0000:ooooo`Go00002_ooool3o`0000_ooooo
0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003ooooo
ooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`04
o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0
003oooooooooo`04ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`00
00Gooooo00?o0000ooooooooool00oooool3o`0000;ooooo1Ol00004ooooo`?o00001?ooool2o`00
00Gooooo0ol00002ooooo`Go00001?ooool3o`0000?ooooo0ol00005ooooo`?o00000oooool3o`00
00Gooooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`00
00?ooooo0ol0000?ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-2.06768, -0.0230678, 0.0713992, \
0.00108427}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 2.41285 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13536 -24 -4.5 ]
[-0.0125 .13536 0 4.5 ]
[-0.0125 .256 -18 -4.5 ]
[-0.0125 .256 0 4.5 ]
[-0.0125 .37664 -24 -4.5 ]
[-0.0125 .37664 0 4.5 ]
[-0.0125 .49729 -18 -4.5 ]
[-0.0125 .49729 0 4.5 ]
[-0.0125 .61793 -24 -4.5 ]
[-0.0125 .61793 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13536 m
.00625 .13536 L
s
[(0.05)] -0.0125 .13536 1 0 Mshowa
0 .256 m
.00625 .256 L
s
[(0.1)] -0.0125 .256 1 0 Mshowa
0 .37664 m
.00625 .37664 L
s
[(0.15)] -0.0125 .37664 1 0 Mshowa
0 .49729 m
.00625 .49729 L
s
[(0.2)] -0.0125 .49729 1 0 Mshowa
0 .61793 m
.00625 .61793 L
s
[(0.25)] -0.0125 .61793 1 0 Mshowa
.125 Mabswid
0 .03884 m
.00375 .03884 L
s
0 .06297 m
.00375 .06297 L
s
0 .0871 m
.00375 .0871 L
s
0 .11123 m
.00375 .11123 L
s
0 .15949 m
.00375 .15949 L
s
0 .18361 m
.00375 .18361 L
s
0 .20774 m
.00375 .20774 L
s
0 .23187 m
.00375 .23187 L
s
0 .28013 m
.00375 .28013 L
s
0 .30426 m
.00375 .30426 L
s
0 .32839 m
.00375 .32839 L
s
0 .35251 m
.00375 .35251 L
s
0 .40077 m
.00375 .40077 L
s
0 .4249 m
.00375 .4249 L
s
0 .44903 m
.00375 .44903 L
s
0 .47316 m
.00375 .47316 L
s
0 .52141 m
.00375 .52141 L
s
0 .54554 m
.00375 .54554 L
s
0 .56967 m
.00375 .56967 L
s
0 .5938 m
.00375 .5938 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13536 m
1 .13536 L
s
.99375 .256 m
1 .256 L
s
.99375 .37664 m
1 .37664 L
s
.99375 .49729 m
1 .49729 L
s
.99375 .61793 m
1 .61793 L
s
.125 Mabswid
.99625 .03884 m
1 .03884 L
s
.99625 .06297 m
1 .06297 L
s
.99625 .0871 m
1 .0871 L
s
.99625 .11123 m
1 .11123 L
s
.99625 .15949 m
1 .15949 L
s
.99625 .18361 m
1 .18361 L
s
.99625 .20774 m
1 .20774 L
s
.99625 .23187 m
1 .23187 L
s
.99625 .28013 m
1 .28013 L
s
.99625 .30426 m
1 .30426 L
s
.99625 .32839 m
1 .32839 L
s
.99625 .35251 m
1 .35251 L
s
.99625 .40077 m
1 .40077 L
s
.99625 .4249 m
1 .4249 L
s
.99625 .44903 m
1 .44903 L
s
.99625 .47316 m
1 .47316 L
s
.99625 .52141 m
1 .52141 L
s
.99625 .54554 m
1 .54554 L
s
.99625 .56967 m
1 .56967 L
s
.99625 .5938 m
1 .5938 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .03928 L
.04348 .03928 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .03928 L
.04348 .03928 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .02234 L
.07453 .02234 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .02234 L
.07453 .02234 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .13074 L
.10559 .13074 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .13074 L
.10559 .13074 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .01556 L
.13665 .01556 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .01556 L
.13665 .01556 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .25863 L
.1677 .25863 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .25863 L
.1677 .25863 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .02234 L
.19876 .02234 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .02234 L
.19876 .02234 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .02149 L
.22981 .02149 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .02149 L
.22981 .02149 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .01641 L
.26087 .01641 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .01641 L
.26087 .01641 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .1138 L
.29193 .1138 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .1138 L
.29193 .1138 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .04944 L
.32298 .04944 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .04944 L
.32298 .04944 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .0596 L
.35404 .0596 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .0596 L
.35404 .0596 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .01895 L
.38509 .01895 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .01895 L
.38509 .01895 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .03928 L
.41615 .03928 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .03928 L
.41615 .03928 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .27387 L
.4472 .27387 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .27387 L
.4472 .27387 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .01726 L
.47826 .01726 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .01726 L
.47826 .01726 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .01895 L
.50932 .01895 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .01895 L
.50932 .01895 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .01472 L
.54037 .01472 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .01472 L
.54037 .01472 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .24508 L
.57143 .24508 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .24508 L
.57143 .24508 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .22898 L
.60248 .22898 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .22898 L
.60248 .22898 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .01895 L
.63354 .01895 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .01895 L
.63354 .01895 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .22898 L
.6646 .22898 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .22898 L
.6646 .22898 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .07146 L
.69565 .07146 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .07146 L
.69565 .07146 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .01472 L
.72671 .01472 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .01472 L
.72671 .01472 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .04944 L
.75776 .04944 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .04944 L
.75776 .04944 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .2942 L
.78882 .2942 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .2942 L
.78882 .2942 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .26371 L
.81988 .26371 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .26371 L
.81988 .26371 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .0198 L
.88199 .0198 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .0198 L
.88199 .0198 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .01726 L
.91304 .01726 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .01726 L
.91304 .01726 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .25439 L
.9441 .25439 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .25439 L
.9441 .25439 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .0867 L
.04969 .0867 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .0867 L
.04969 .0867 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .24253 L
.08075 .24253 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .24253 L
.08075 .24253 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .04436 L
.1118 .04436 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .04436 L
.1118 .04436 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .09771 L
.14286 .09771 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .09771 L
.14286 .09771 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .01726 L
.17391 .01726 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .01726 L
.17391 .01726 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .23322 L
.20497 .23322 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .23322 L
.20497 .23322 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .02064 L
.23602 .02064 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .02064 L
.23602 .02064 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .19934 L
.26708 .19934 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .19934 L
.26708 .19934 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .15107 L
.29814 .15107 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .15107 L
.29814 .15107 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .09348 L
.32919 .09348 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .09348 L
.32919 .09348 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .0452 L
.36025 .0452 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .0452 L
.36025 .0452 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .0596 L
.3913 .0596 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .0596 L
.3913 .0596 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .05621 L
.42236 .05621 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .05621 L
.42236 .05621 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .02742 L
.45342 .02742 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .02742 L
.45342 .02742 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .02064 L
.48447 .02064 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .02064 L
.48447 .02064 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .25016 L
.51553 .25016 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .25016 L
.51553 .25016 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .03673 L
.57764 .03673 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .03673 L
.57764 .03673 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .01726 L
.6087 .01726 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .01726 L
.6087 .01726 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .11465 L
.63975 .11465 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .11465 L
.63975 .11465 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .03589 L
.67081 .03589 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .03589 L
.67081 .03589 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .06892 L
.70186 .06892 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .06892 L
.70186 .06892 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01895 L
.73292 .01895 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01895 L
.73292 .01895 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .16885 L
.76398 .16885 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .16885 L
.76398 .16885 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .03165 L
.79503 .03165 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .03165 L
.79503 .03165 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .01641 L
.82609 .01641 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .01641 L
.82609 .01641 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .02149 L
.85714 .02149 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .02149 L
.85714 .02149 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .03589 L
.8882 .03589 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .03589 L
.8882 .03589 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01556 L
.91925 .01556 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01556 L
.91925 .01556 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .02318 L
.95031 .02318 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .02318 L
.95031 .02318 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .01726 L
.02484 .01726 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .01726 L
.02484 .01726 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .14429 L
.0559 .14429 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .14429 L
.0559 .14429 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .04182 L
.08696 .04182 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .04182 L
.08696 .04182 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .14599 L
.11801 .14599 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .14599 L
.11801 .14599 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .02996 L
.14907 .02996 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .02996 L
.14907 .02996 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .03673 L
.18012 .03673 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .03673 L
.18012 .03673 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .04097 L
.21118 .04097 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .04097 L
.21118 .04097 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .13921 L
.24224 .13921 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .13921 L
.24224 .13921 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .05875 L
.27329 .05875 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .05875 L
.27329 .05875 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .1282 L
.30435 .1282 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .1282 L
.30435 .1282 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .16292 L
.3354 .16292 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .16292 L
.3354 .16292 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .17648 L
.36646 .17648 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .17648 L
.36646 .17648 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .04859 L
.39752 .04859 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .04859 L
.39752 .04859 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .17309 L
.42857 .17309 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .17309 L
.42857 .17309 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .06384 L
.45963 .06384 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .06384 L
.45963 .06384 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .14683 L
.49068 .14683 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .14683 L
.49068 .14683 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .04097 L
.52174 .04097 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .04097 L
.52174 .04097 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .1282 L
.5528 .1282 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .1282 L
.5528 .1282 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .04859 L
.58385 .04859 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .04859 L
.58385 .04859 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .02064 L
.61491 .02064 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .02064 L
.61491 .02064 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .04266 L
.64596 .04266 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .04266 L
.64596 .04266 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .09771 L
.67702 .09771 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .09771 L
.67702 .09771 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .14514 L
.70807 .14514 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .14514 L
.70807 .14514 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .1138 L
.73913 .1138 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .1138 L
.73913 .1138 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .08162 L
.77019 .08162 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .08162 L
.77019 .08162 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .05367 L
.80124 .05367 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .05367 L
.80124 .05367 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .02911 L
.8323 .02911 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .02911 L
.8323 .02911 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .11973 L
.86335 .11973 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .11973 L
.86335 .11973 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .13836 L
.89441 .13836 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .13836 L
.89441 .13836 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .13752 L
.92547 .13752 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .13752 L
.92547 .13752 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .04097 L
.95652 .04097 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .04097 L
.95652 .04097 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .09009 L
.98758 .09009 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .09009 L
.98758 .09009 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .15276 L
.03106 .15276 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .15276 L
.03106 .15276 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .05621 L
.06211 .05621 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .05621 L
.06211 .05621 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .18156 L
.09317 .18156 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .18156 L
.09317 .18156 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .03504 L
.12422 .03504 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .03504 L
.12422 .03504 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .39244 L
.15528 .39244 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .39244 L
.15528 .39244 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .02149 L
.18634 .02149 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .02149 L
.18634 .02149 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .18918 L
.21739 .18918 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .18918 L
.21739 .18918 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .01472 L
.24845 .01472 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .01472 L
.24845 .01472 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .22814 L
.2795 .22814 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .22814 L
.2795 .22814 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .03081 L
.31056 .03081 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .03081 L
.31056 .03081 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .04774 L
.34161 .04774 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .04774 L
.34161 .04774 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .02996 L
.37267 .02996 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .02996 L
.37267 .02996 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .33739 L
.40373 .33739 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .33739 L
.40373 .33739 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .02742 L
.43478 .02742 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .02742 L
.43478 .02742 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .05283 L
.46584 .05283 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .05283 L
.46584 .05283 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .01472 L
.49689 .01472 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .01472 L
.49689 .01472 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .25016 L
.52795 .25016 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .25016 L
.52795 .25016 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .01472 L
.55901 .01472 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .01472 L
.55901 .01472 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .04351 L
.59006 .04351 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .04351 L
.59006 .04351 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .02318 L
.62112 .02318 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .02318 L
.62112 .02318 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .29504 L
.65217 .29504 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .29504 L
.65217 .29504 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .02149 L
.68323 .02149 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .02149 L
.68323 .02149 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .03165 L
.71429 .03165 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .03165 L
.71429 .03165 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .01472 L
.74534 .01472 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .01472 L
.74534 .01472 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .20781 L
.7764 .20781 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .20781 L
.7764 .20781 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .02572 L
.80745 .02572 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .02572 L
.80745 .02572 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .04182 L
.83851 .04182 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .04182 L
.83851 .04182 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .01472 L
.86957 .01472 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .01472 L
.86957 .01472 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .03335 L
.90062 .03335 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .03335 L
.90062 .03335 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .01472 L
.93168 .01472 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .01472 L
.93168 .01472 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .02403 L
.96273 .02403 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .02403 L
.96273 .02403 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .01472 L
.99379 .01472 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .01472 L
.99379 .01472 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00;Oooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000>oooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000>ooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo0000013ooooo000^ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03?ooool002gooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00cooooo000^ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0000oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Voooooooo0000aOl0000:
ooooo`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l4oomo00;o00000ooo
0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l00003ool000?o0?l00_l0
0?l4oomo00;o00000ooo0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o1?ooO`001?l0003oo`00ool0
0?oo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl0
0_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`00
0ol0o`03o`00o`Coogl000Co0000ool00?oo003oo`000ol0o`03o`00o`?oogl00_l00003ool000?o
0?l00ol00?l4oomo0004o`000?oo003oo`00ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o
00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo
00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`Coogl000Co0000ool0
0?oo003oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003
o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`Coogl000Co0000ool00?oo003oo`000ol0
o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l4oomo0004o`000?oo003oo`00ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o1?ooO`02o`0000[ooooo000Looooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool00oooool3o`3o00;o003o1?ooO`02ooooo`?oo`00
0ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00;o003o
1?ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?oo`00
0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl0
0_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`00
0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o
0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l4ooooo`?oo`00
0ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`00
0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o
0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00Co003o1?ooool3ool000?o0?l0
0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl0
1Oooool3o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0002ooooo`Co003o
1?ooool3ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo
000Looooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool4o`3o0003oooo
ooooO`3oogl000;oogl00_ooool3ool000?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00;o003o
1?ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`00
0_ooool2o`00o`Coogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o
1oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l0
0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl0
0_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`05ooooo`?o0?l0
1?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o
0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00Co003o
1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`00
0_ooool3o`00o`?oogl01Oooool3o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00Sooooo
1?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo00?o0000ooooooooool0
2?ooool001gooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo
0002oomo00;ooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl00_oo
ool3ool000?o0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000;ooooo0_l0
0?l4oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`000_ooool4o`00o`Oooooo0ol0
o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol0
0?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0ooo
O`05ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00Gooooo0ol0o`04o`00o`Oooooo0ol0
o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`08ooooo`Co003o1?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooo
oomo0?ooO`000_ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool3o`3o00;o003o1?ooO`02
ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`000_ooool3
o`00o`Sooooo0ol0o`03o`00o`?oogl02?ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl00_ooool3
ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03
o`00o`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3
ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l4
ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3
oomo00;ooooo0ooo0003o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l4
ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0002
ooooo`?o003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0oooO`08ooooo`Co003o1?ooool3
ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo0ooo0003o`3o
00;o003o1?ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00;o003o1?ooO`05oooo
o`?o0?l00_l00?l4oomo00;ooooo1?oo0002ooooo`?o003o2?ooool3o`3o00?o003o0oooO`08oooo
o`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool0
00?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`05ooooo`?o0?l00ol00?l3oomo
00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool4o`00
o`Oooooo0ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`02oooo
o`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Cooooo0ooo0003o`3o
00?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o
00?o003o0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02?ooool4o`00o`Oooooo0ol0o`03o`00
o`?oogl02?ooool4o`00o`Cooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;o
ogl00_ooool3ool000?o0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool3ool000?o
0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000;ooooo0ol00?l8ooooo`?o
0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o
003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Go
oooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o
003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o
0?l00ol00?l3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co
003o1?ooool3ool000?o0?l00ol00?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`03o`00o`?o
ogl00_ooool3ool000?o0?l01?l00?l4ooooo`Coo`000_ooool3o`00o`?oogl02?ooool4o`00o`Oo
oooo0ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Co
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003oooo
ooooO`3oogl000;oogl00_ooool3ool000?o0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl0
0_ooool3ool000?o0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000;ooooo
0ol00?l8ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l0
0ol00?l3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l4ooooo`Coo`00
0_ooool3o`00o`?oogl02?ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo
0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`?oo`00
0ol0o`04o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o0?l0
0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1?ooool4ool000Gooooo0oooO`08ooooo`Co003o
1oooool3o`3o00?o003o0oooO`08ooooo`Co003o1?ooool4ool000;ooooo1?l00?l:ooooo`Co003o
1?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?o
oooooomo0?ooO`000_ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool3o`3o00;o003o1?oo
O`02ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool4o`3o0003ooooooooO`3oogl000;oogl00_oo
ool4ool000;ooooo0ol00?l8ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol0
0?l3oomo00;ooooo0ooo0003o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo
0003o`3o00Co003o1oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Cooooo1?oo
0002ooooo`?o003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0oooO`08ooooo`Co003o1?oo
ool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo
0003o`3o00Co003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o1?ooool3ool000?o0?l00ol0
0?l3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool000Gooooo0oooO`08ooooo`Co003o1ooo
ool3o`3o00?o003o0oooO`08ooooo`Co003o1?ooool4ool000;ooooo1?l00?l:ooooo`Co003o1?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooo
oomo0?ooO`000_ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool3o`3o00;o003o1?ooO`02
ooooo`?oo`000ol0o`02o`00o`Coogl01Oooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4
ool000;ooooo0ol00?l8ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3
oomo00;ooooo0ooo0003o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003
o`3o00Co003o1oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Cooooo1?oo0002
ooooo`?o003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0oooO`08ooooo`Co003o1?ooool3
ool000?o0?l00ol00?l3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003
o`3o00Co003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o1?ooool3ool000?o0?l00ol00?l3
oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool000Gooooo0oooO`08ooooo`Co003o1oooool3
o`3o00Co003o2_ooool4o`00o`Cooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl0
00;oogl00_ooool3ool000?o0?l00_l00?l4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool3ool0
00?o0?l00ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00
o`Sooooo0ol0o`03o`00o`?oogl02?ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl00_ooool3ool0
00?o0?l01?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l7oooo
o`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1?ooool4ool000;ooooo0ol00?l3oomo
00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`03o`00
o`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000;ooooo1?l00?l4oooo
o`?oo`000ol0o`04o`00o`[ooooo1?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool0
00;ooooo1?l00?l4ooooo`Coo`001Oooool3oomo00Sooooo1?l00?l:ooooo`Co003o2_ooool4o`00
o`Cooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Ko
oooo0ol00003ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`?oo`000ol0o`02o`00o`Co
ogl01Oooool3o`3o00;o003o1?ooO`02ooooo`?oo`000ol0o`03o`00o`Sooooo1?l0o`000ooooooo
ogl0oomo0002oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00Sooooo1?l00?l7ooooo`?o
0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1?ooool3ool000?o0?l00ol00?l3oomo00;o
oooo0ooo0003o`3o00Co003o1oooool3o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Co
oooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0oooO`08ooooo`Co
003o1?ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;o
oooo1?oo0002ooooo`Co003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o1?ooool3ool000?o
0?l00ol00?l3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool000Gooooo0oooO`08ooooo`Co
003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`000_ooool4o`00o`[ooooo1?l00?l3ooooo`;o
00002_ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl0
1Oooool3o`3o00;o003o1?ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o
2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl0
2?ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l4ooooo`?oo`00
0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l7ooooo`?o0?l00ol00?l3oomo00Gooooo
0ol0o`04o`00o`Cooooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o1oooool3o`3o00?o003o
0oooO`08ooooo`Co003o1?ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo000=ooooo`?o0?l0
0ol00?l3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o
1?ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool000Gooooo
0oooO`08ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`000_ooool4o`00o`[ooooo
1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl01Oooool4o`3o0003oooooooo
O`3oogl000;oogl00_ooool3ool000?o0?l00ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_oo
O`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool3o`3o00?o003o0ooo
O`02ooooo`?oo`000ol0o`04o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`04o`00o`Oooooo0ol0o`03o`00o`?oogl01Oooool3o`3o00Co003o1?ooool4ool000;ooooo0ol0
0?l3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`000_oo
ool3o`00o`?oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000;ooooo1?l0
0?l4ooooo`?oo`000ol0o`04o`00o`[ooooo1?l00?l4ooooo`?oo`000ol0o`03o`00o`?oogl00_oo
ool4ool000;ooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?oo
ool4ool0013ooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl01Oooool4
o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l000?ooooo
oomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool3
o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`02
ooooo`?oo`000ol0o`04o`00o`Oooooo0ol0o`03o`00o`?oogl01Oooool3o`3o00Co003o1?ooool4
ool000;ooooo0ol00?l3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4
ooooo`Coo`000_ooool4o`00o`Cooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002
ooooo`Co003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o1?ooool3ool000?o0?l00ol00?l3
oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4
o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`05ooooo`?o0?l00_l00?l4oomo
00Gooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o
0003ooooooooO`3oogl000;oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00
o`Oooooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l01?l00?l4ooooo`?oo`000ol0o`03o`00
o`?oogl00_ooool4ool000;ooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00Gooooo0ol0o`04o`00
o`Cooooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08oooo
o`Co003o1?ooool4ool000;ooooo1?l00?l4ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02oooo
o`Coo`000_ooool4o`00o`Cooooo0ooo0003o`3o00Co003o2_ooool4o`00o`Cooooo0ooo0003o`3o
00?o003o0oooO`02ooooo`Coo`000_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o2_ooool4o`00
o`[ooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl01Oooool3o`3o00;o
003o1?ooO`05ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00o`So
oooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00So
oooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1oooool3o`3o00Co
003o1?ooool4ool000;ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Gooooo0ol0o`04o`00o`Co
oooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co
003o1?ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002ooooo`Co
003o1?ooool3ool000?o0?l01?l00?l:ooooo`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`Co
o`000_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Co
o`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o0003ooooooooO`3oogl000;oogl01Oooool3o`3o00;o003o1?ooO`05ooooo`Co0?l0
00?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00o`Sooooo1?l0o`000oooooooogl0
oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`?o0?l0
0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1oooool3o`3o00Co003o1?ooool4ool000;ooooo
1?l00?l7ooooo`Co0?l00_ooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0002ooooo`?o003o
0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000[ooooo
1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool3ool000?o0?l0
1?l00?l:ooooo`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`Coo`000_ooool4o`00o`Cooooo
1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Cooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003oooooooo
O`3oogl000;oogl01Oooool3o`3o00;o003o1?ooO`05ooooo`Co0?l000?ooooooomo0?ooO`000_oo
O`02ooooo`Coo`000_ooool3o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo
000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo
0003o`3o00Co003o1oooool3o`3o00Co003o1?ooool4ool000;ooooo1?l00?l7ooooo`Co0?l00_oo
ool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Oooooo1?l0
o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0ooo
O`02ooooo`Coo`000_ooool4o`00o`Cooooo0ooo0003o`3o00Co003o2_ooool4o`00o`Oooooo0ol0
o`03o`00o`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l0
0?l4ooooo`Coo`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl01Oooool3o`3o00?o003o2?ooool4
o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l000?ooooo
oomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool3
o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`Oooooo0ol0o`04o`00o`Cooooo1?oo0002
ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000;ooooo1?l00?l:
ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000=
ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool3ool000?o0?l01?l00?l:
ooooo`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`Coo`002_ooool4ool0013ooooo1?l00?l:
ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`05oooo
o`?o0?l00ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00
o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo
00Sooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o1oooool3o`3o
00Co003o1?ooool4ool000;ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4oooo
o`Coo`000_ooool4o`00o`[ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4oooo
o`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000;ooooo1?l00?l4oooo
o`?oo`000ol0o`04o`00o`[ooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:oooo
o`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool0013ooooo1?l00?l4oooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000ooooooo
ogl0oomo0002oomo00Gooooo0ol0o`03o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;o
oooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000go
oooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool3ool000?o
0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Co
o`000_ooool4o`00o`[ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Co
o`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000;ooooo1?l00?l4ooooo`?o
o`000ol0o`04o`00o`[ooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:ooooo`Co
o`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool0013ooooo1?l00?l4ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o0003ooooooooO`3oogl000;oogl0
1Oooool3o`3o00?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo
0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo
0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`Oooooo
0ol0o`04o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo0002ooooo`Co003o
2_ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`00
3Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`000_ooool4o`00o`Cooooo0ooo0003o`3o00Co003o
2_ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o
2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`?ooooo0_l0000:ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`05ooooo`?o0?l00ol0
0?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00o`Sooooo1?l0
o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l0
0?l7ooooo`Co0?l00_ooool3oomo00;ooooo0ooo0003o`3o00Co003o1oooool3o`3o00Co003o2_oo
ool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l00?l7ooooo`Co0?l00_oo
ool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_oo
ool4ool000;ooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`[ooooo1?l00?l7ooooo`?o0?l00ol0
0?l3oomo00;ooooo1?oo000:ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?oo
ool4ool0013ooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`03o`00o`Sooooo1?l0o`00
0oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3o
ogl000;oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02
ooooo`?oogl00_ooool3ool000?o0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o3Oooool3
oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4
o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`000_ooool4
o`00o`Cooooo0ooo0003o`3o00Co003o2_ooool4o`00o`Oooooo0ol0o`03o`00o`?oogl00_ooool4
ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`004?ooool4
o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o
0003ooooooooO`3oogl000;oogl01Oooool3o`3o00?o003o2?ooool4o`3o0003ooooooooO`3oogl0
00;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02oooo
o`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02oooo
o`?oo`000ol0o`04o`00o`Oooooo0ol0o`04o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00
o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool0
00[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002ooooo`Co003o1?ooool4ool0
00;ooooo1?l00?l:ooooo`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`Coo`002_ooool4ool0
013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?oo
O`000_ooO`05ooooo`?o0?l00ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Co
o`000_ooool3o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co
0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00;ooooo0ooo0003o`3o00Co
003o1oooool3o`3o00Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013o
oooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000go
oooo1?l0o`02ooooo`?oogl00_ooool4ool000;ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Oo
oooo0ol0o`03o`00o`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[o
oooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl01Oooool3o`3o00?o003o
2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l0
00?ooooooomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o
1oooool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`Oooooo0ol0o`04o`00o`[ooooo
1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo
0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo
1?oo0002ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo000:ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool0013ooooo
1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`03o`00o`Sooooo1?l0o`000oooooooogl0oomo
0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_oo
ool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_oo
ool3ool000?o0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l0
0?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo
000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`000_ooool4o`00o`[ooooo1?l0
0?l:ooooo`Co003o1oooool3o`3o00?o003o0oooO`02ooooo`Coo`002_ooool4ool0013ooooo1?l0
0?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`05
ooooo`?o0?l00ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3
o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3
oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00;ooooo0ooo0003o`3o00Co003o1oooool3
o`3o00Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l00?l7
ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000gooooo1?l0o`02
ooooo`?oogl00_ooool4ool000;ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Oooooo0ol0o`03
o`00o`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4
ooooo`Coo`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl01Oooool3o`3o00?o003o2?ooool4o`3o
0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l000?ooooooomo
0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool4o`3o
00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`Oooooo0ol0o`04o`00o`[ooooo1?l00?l=oooo
o`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08oooo
o`Co003o1?ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0002oooo
o`Co003o2_ooool4o`00o`[ooooo1?l00?l7ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:oooo
o`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool0013ooooo1?l00?l4oooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000ooooooo
ogl0oomo0002oomo00Gooooo0ol0o`03o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;o
oooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000go
oooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool3ool000?o
0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Co
o`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000:ooooo`Co
o`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`000_ooool4o`00o`[ooooo1?l00?l:ooooo`Co
003o1oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool0013ooooo1?l00?l:ooooo`Co
003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool00ol0003oooooooooo`08ooooo`00
9_ooool3o`0000?ooooo1?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`03o`00o`Sooooo
1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o0003oooo
ooooO`3oogl000;oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo
1?l0o`02ooooo`?oogl00_ooool3ool000?o0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o
3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl0
2?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`00
0_ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`Coo`00
2_ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o
0oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo
0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_oo
ool3o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo000=ooooo`Co0?l00_oo
ool3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00;ooooo0ooo0003o`3o00Co003o1ooo
ool3o`3o00Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l0
0?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000gooooo1?l0
o`02ooooo`?oogl00_ooool4ool000;ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Oooooo1?l0
o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l0
0?l4ooooo`Coo`004?ooool4o`00o`Cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`Sooooo1?l0o`00
0oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3o
ogl000;oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02
ooooo`?oogl00_ooool3ool000?o0?l01?l00?l7ooooo`?o0?l01?l00?l:ooooo`Co003o3Oooool3
oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4
o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`000_ooool4
o`00o`[ooooo1?l00?l:ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4
ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1?ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo
0?ooO`000_ooO`08ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool0
00;ooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o
00;ooooo0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00
o`Oooooo0ol0o`04o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@oooo
o`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000=oooo
o`Co0?l00_ooool3oomo00;ooooo1?oo0002ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l7oooo
o`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l:oooo
o`Co003o1?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`Sooooo1?l0o`000ooooooo
ogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;o
ogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?o
ogl00_ooool3ool000?o0?l01?l00?l:ooooo`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co
003o1?ooool4ool0013ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Co
o`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000;ooooo1?l00?l:ooooo`Co
003o2_ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co
003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o
2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l8ooooo`Co0?l0
00?ooooooomo0?ooO`000_ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o
1oooool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`[ooooo1?l00?l:ooooo`Co003o
3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl0
2?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`00
0_ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`Coo`00
2_ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000Hooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo
0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_oo
ool3o`00o`gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1ooo
ool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`[ooooo1?l00?l:ooooo`Co003o3Ooo
ool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?oo
ool4o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004?oo
ool4o`00o`[ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`004?oo
ool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool001Sooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3
o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o3Oooool4
oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3
oomo00;ooooo0ooo0003o`3o00Co003o2_ooool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4
o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4
ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000@ooooo`Co003o2_ooool4
o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4
o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o2?ooool4o`3o
0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l=ooooo`Coogl00_ooool4ool0
00gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool3ool0
00?o0?l01?l00?l:ooooo`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0
013ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool0
00gooooo1?l0o`02ooooo`?oogl00_ooool4ool0013ooooo1?l00?l:ooooo`Co003o1oooool4o`3o
00;ooooo0oooO`02ooooo`Coo`002_ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00
o`Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`000oooooooogl0oomo0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?oo
O`000_ooO`02ooooo`Coo`000_ooool3o`00o`gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;o
oooo0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`[o
oooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oo
oooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;o
oooo0oooO`02ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00;o
oooo1?oo000:ooooo`Coo`004?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool001So
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003oooo
ooooO`3oogl000;oogl02?ooool3o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo
1?oo0002ooooo`?o003o3Oooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo
1?l00?l7ooooo`Co0?l00_ooool3oomo00;ooooo0ooo0003o`3o00Co003o2_ooool4o`00o`[ooooo
1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo
0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo
1?oo000@ooooo`Co003o2_ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo
1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`000oooooooogl0oomo0002oomo00Sooooo0ol0
0?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`000_ooool3o`00o`gooooo1?oo
O`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0ooo
O`02ooooo`?oo`000ol0o`04o`00o`[ooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l0
0?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo
000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004?ooool4o`00o`[ooooo1?l0
0?l7ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`004?ooool4o`00o`[ooooo1?l0
0?l:ooooo`Co003o1?ooool4ool001Oooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03
ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o2?ooool4o`3o0003ooooooooO`3o
ogl000;oogl00_ooool4ool000;ooooo0ol00?l=ooooo`Coogl00_ooool4ool000gooooo1?l0o`02
ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl00_ooool3ool000?o0?l01?l00?l:
ooooo`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l00?l7
ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000gooooo1?l0o`02
ooooo`?oogl00_ooool4ool0013ooooo1?l00?l:ooooo`Co003o1oooool4o`3o00;ooooo0oooO`02
ooooo`Coo`002_ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000H
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000ooo
ooooogl0oomo0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02oooo
o`Coo`000_ooool3o`00o`gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08oooo
o`Co003o1oooool4o`3o00;ooooo0oooO`05ooooo`?o0?l01?l00?l:ooooo`Co003o2_ooool4o`00
o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo
00Sooooo1?l00?l4ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool0
013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`004?ooool4o`00
o`[ooooo1?l00?l:ooooo`Co003o1?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`So
oooo1?l0o`000oooooooogl0oomo0002oomo00;ooooo1?oo0002ooooo`?o003o3Oooool4oomo00;o
oooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Go
oooo0ol0o`04o`00o`[ooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Co
o`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000:ooooo`Co
o`004oooool3oomo00;ooooo1?oo000@ooooo`Co003o5Oooool4o`3o00;ooooo0oooO`02ooooo`Co
o`002_ooool4ool0013ooooo1?l00?l:ooooo`Co003o2_ooool4o`00o`Cooooo1?oo000Hooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0
oomo0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`00
0_ooool3o`00o`gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o
1oooool4o`3o00;ooooo0oooO`05ooooo`?o0?l01?l00?l:ooooo`Co003o2_ooool4o`00o`gooooo
0oooO`08ooooo`Co003o1?ooool4ool0013ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo00Sooooo
1?l00?l4ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool4o`00oaGooooo
1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000@ooooo`Co003o2_ooool4o`00o`[ooooo
1?l00?l4ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o2?ooool4o`3o0003oooooooo
O`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l=ooooo`Coogl00_ooool4ool000gooooo1?l0
o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl01Oooool3o`3o00Co003o2_oo
ool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1ooo
ool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_oo
ool4ool0013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`007_oo
ool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o2?ooool4
o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l=ooooo`Coogl00_ooool4
ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl01Oooool3
o`3o00Co003o2_ooool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@
ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool000[ooooo1?oo000C
ooooo`?oogl00_ooool4ool0013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:
ooooo`Coo`007_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08oooo
o`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;ooooo0ol00?l=oooo
o`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oooooo1?l0o`02oooo
o`?oogl01Oooool3o`3o00Co003o2_ooool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00
o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co003o1?ooool4ool0
00[ooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo
00;ooooo1?oo000:ooooo`Coo`007_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?oo
O`000_ooO`08ooooo`?o003o2?ooool4o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000;o
oooo0ol00?l=ooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00o`Oo
oooo1?l0o`02ooooo`?oogl01Oooool3o`3o00Co003o2_ooool4o`00o`[ooooo1?l00?l=ooooo`?o
ogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`08ooooo`Co
003o1?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo1?l00?lEooooo`Co
0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`007_ooool4o`00o`[ooooo1?l00?l4ooooo`Co
o`006?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000?ooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0
oomo0002oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`02ooooo`Coo`00
0_ooool3o`00o`gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`08ooooo`Co003o
1oooool4o`3o00;ooooo0oooO`05ooooo`Co0?l03Oooool4o`00o`[ooooo1?l00?l=ooooo`?oogl0
2?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`00
2_ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool4o`00oaGooooo1?l0o`02ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000Nooooo`Co003o2_ooool4o`00o`Cooooo1?oo000Hooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool4o`3o
0003ooooooooO`3oogl000;oogl02?ooool3o`00o`Sooooo1?l0o`000oooooooogl0oomo0002oomo
00Sooooo0ol00?l=ooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl02?ooool4o`00
o`Oooooo1?l0o`02ooooo`?oogl01Oooool4o`3o00gooooo1?l00?l:ooooo`Co003o3Oooool3oomo
00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl04?ooool4ool0
00[ooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo
00;ooooo1?oo000:ooooo`Coo`007_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`006?ooool00ol0
003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool01?ooool4o`0000;ooooo1?l0o`000oooooooogl0oomo0002
oomo00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o3Oooool4
oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00Sooooo1?l00?l7ooooo`Co0?l00_ooool3
oomo00Gooooo1?l0o`0=ooooo`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4
ool0013ooooo1?l00?l7ooooo`Co0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3
oomo00;ooooo1?oo000@ooooo`Co003o5Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4
ool001kooooo1?l00?l:ooooo`Co003o1?ooool4ool001Gooooo1?l0000:ooooo`002_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o2?oo
ool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`gooooo1?ooO`02ooooo`Coo`003Ooo
ool4o`3o00;ooooo0oooO`08ooooo`Co003o1oooool4o`3o00;ooooo0oooO`05ooooo`Co0?l03Ooo
ool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1ooo
ool4o`3o00;ooooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`004?oo
ool4o`00oaGooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000Nooooo`Co003o2_oo
ool4o`00o`Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Oooooo00?o0000ooooooooool0
0oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`Sooooo1?l0o`000oooooooogl0
oomo0002oomo00Sooooo0ol00?l=ooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl0
2?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl01Oooool4o`3o00gooooo1?l00?l:ooooo`Co003o
3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo1?l0o`02ooooo`?oogl0
4?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo1?l00?lEooooo`Co0?l0
0_ooool3oomo00;ooooo1?oo000:ooooo`Coo`007_ooool4o`00oa;ooooo1?oo000Hooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool0000:ooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo0002oomo
00Sooooo0ol00?l8ooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o3Oooool4oomo
00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0o`02ooooo`?oogl01Oooool4o`3o
00gooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00
o`Oooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool0
013ooooo1?l00?lEooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`00=?ooool4ool0
01Sooooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:ooooo`;o00000_ooool5o`0000Ko
oooo00?o0000ooooooooool00oooool4o`3o0003ooooooooO`3oogl000;oogl02?ooool3o`00o`So
oooo1?l0o`000oooooooogl0oomo0002oomo00Sooooo0ol00?l=ooooo`Coogl00_ooool4ool000go
oooo1?l0o`02ooooo`?oogl04oooool4o`3o00;ooooo0oooO`05ooooo`Co0?l03Oooool4o`00o`[o
oooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000@ooooo`Co003o1oooool4o`3o00;o
oooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool4o`00oaGo
oooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l000?ooooooomo0?ooO`00
0_ooO`0Cooooo`Co0?l000?ooooooomo0?ooO`000_ooO`08ooooo`?o003o3Oooool4oomo00;ooooo
1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0o`02ooooo`?oogl01Oooool4o`3o00gooooo
1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`004?ooool4o`00o`Oooooo
1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo
1?l00?lEooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0003oooooooo
O`3oogl000;oogl04oooool4o`3o0003ooooooooO`3oogl000;oogl06?ooool4oomo00;ooooo1?oo
000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0o`02ooooo`?oogl01Oooool4o`3o00gooooo1?l0
0?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`006oooool4o`3o00;ooooo0ooo
O`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00:Oooool4o`3o00;ooooo0ooo
O`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`000oooooooogl0oomo0002oomo01?ooooo1?l0o`00
0oooooooogl0oomo0002oomo01Sooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`0C
ooooo`Co0?l00_ooool3oomo00Gooooo1?l0o`0=ooooo`Co003o2_ooool4o`00o`gooooo0oooO`08
ooooo`Co003o1?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000C
ooooo`?oogl00_ooool4ool002Wooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000d
ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`Co0?l000?ooooooomo0?ooO`000_ooO`0Cooooo`Co0?l000?ooooooomo0?ooO`000_ooO`0Hoooo
o`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl04oooool4o`3o00;ooooo0oooO`0Foooo
o`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool001_ooooo1?l0o`02oooo
o`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool002Wooooo1?l0o`02oooo
o`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o0003ooooooooO`3oogl000;o
ogl06?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0o`02ooooo`?o
ogl05_ooool4o`00o`[ooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`Cooooo1?oo000Kooooo`Co
0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000Yooooo`Co
0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`000oooooooogl0
oomo0002oomo01Sooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`0Cooooo`Co0?l0
0_ooool3oomo01Kooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`00
6oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00
:Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o01Sooooo1?l0o`000oooooooogl0oomo
0002oomo01Sooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`0Cooooo`Co0?l00_oo
ool3oomo01Kooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`006ooo
ool4o`3o00;ooooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00:Ooo
ool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Gooooo`;o00002_oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`000oooooooogl0oomo0002
oomo01Sooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`0Cooooo`Co0?l00_ooool3
oomo01Kooooo1?l00?l:ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`006oooool4
o`3o00;ooooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00:Oooool4
o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l000?ooooooomo
0?ooO`000_ooO`0Hooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl04oooool4o`3o
00;ooooo0oooO`0Fooooo`Co003o2_ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool0
01_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool0
02Wooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o0003
ooooooooO`3oogl000;oogl06?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?o
oooo1?l0o`02ooooo`?oogl09?ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool001_o
oooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool002Wo
oooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o0003oooo
ooooO`3oogl000;oogl06?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo
1?l0o`02ooooo`?oogl09?ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool001_ooooo
1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool002Wooooo
1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o0003oooooooo
O`3oogl000;oogl06?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0
o`02ooooo`?oogl09?ooool4o`00o`gooooo0oooO`08ooooo`Co003o1?ooool4ool001_ooooo1?l0
o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4ool002oooooo0ooo
O`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l000?ooooooomo0?ooO`000_ooO`0H
ooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl04oooool4o`3o00;ooooo0oooO`0T
ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l4ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@
ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo1?oo000:
ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o01Sooooo1?l0o`000oooooooogl0oomo0002oomo01Sooooo1?ooO`02oooo
o`Coo`003Oooool4o`3o00;ooooo0oooO`0Cooooo`Co0?l00_ooool3oomo02Cooooo1?l00?l=oooo
o`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Coooo
o`?oogl00_ooool4ool002oooooo0oooO`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hoooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co
0?l000?ooooooomo0?ooO`000_ooO`0Hooooo`Coogl00_ooool4ool000gooooo1?l0o`02ooooo`?o
ogl04oooool4o`3o00;ooooo0oooO`0Tooooo`Co003o3Oooool3oomo013ooooo1?oo000Kooooo`Co
0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o0003ooooooooO`3oogl000;oogl0
6?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo01?ooooo1?l0o`02ooooo`?oogl0
=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`00
4oooool3oomo00;ooooo1?oo000_ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`00
6?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?oo
ool4o`3o0003ooooooooO`3oogl000;oogl06?ooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_oo
ool3oomo01?ooooo1?l0o`02ooooo`?oogl0=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l00_oo
ool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?oogl00_oo
ool4ool000[ooooo1?oo000dooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool3
o`0000?ooooo1?l0o`0Hooooo`Co0?l07Oooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3
oomo01?ooooo1?l0o`02ooooo`?oogl0=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l00_ooool3
oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?oogl00_ooool4
ool000[ooooo1?oo000dooooo`Coo`005oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`0Hooooo`Co0?l07Oooool4oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo
01?ooooo1?l0o`02ooooo`?oogl0=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l00_ooool3oomo
013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000dooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`Co0?l06?ooool4o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o00;o
oooo0oooO`0Cooooo`Co0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;o
oooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;o
oooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo
1?l0o`0Hooooo`Co0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo
0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo
1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0
o`0Hooooo`Co0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0ooo
O`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo1?oo
000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0o`0H
ooooo`Co0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@
ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo1?oo000:
ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0o`0Hoooo
o`Co0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@oooo
o`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo1?oo000:oooo
o`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0o`0Hooooo`Co
0?l00_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Co
o`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00;ooooo1?oo000:ooooo`Co
o`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0o`0Nooooo`?oogl0
=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`00
4oooool3oomo00;ooooo1?oo000_ooooo`?oogl00_ooool4ool000[ooooo1?oo000dooooo`Coo`00
6?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?oo
ool4o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o01kooooo0oooO`0eooooo`?oogl04?oo
ool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_oo
ool4ool002oooooo0oooO`02ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l07Oooool4
oomo00;ooooo1?oo000=ooooo`Co0?l07_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4
o`3o00;ooooo0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3
oomo00;ooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool0
02Kooooo0ol00003ooooo`Co0?l06?ooool4o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o
01kooooo0oooO`0eooooo`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool0
00[ooooo1?oo000Cooooo`?oogl00_ooool4ool002oooooo0oooO`02ooooo`Coo`002_ooool4ool0
03Cooooo1?oo000Gooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01So
oooo1?l0o`0Mooooo`Coogl00_ooool4ool000gooooo1?l0o`0Nooooo`?oogl0=Oooool3oomo013o
oooo1?oo000Kooooo`Co0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;o
oooo1?oo000dooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l07Oooool4oomo00;ooooo
1?oo000=ooooo`Co0?l07_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo
0oooO`0@ooooo`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00=?ooool4ool000[ooooo
1?oo000dooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l06?ooool4o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o01kooooo0ooo
O`0eooooo`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo
000Cooooo`?oogl00_ooool4ool003Cooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0M
ooooo`Coogl00_ooool4ool000gooooo1?l0o`0Nooooo`?oogl0=Oooool3oomo013ooooo1?oo000K
ooooo`Co0?l00_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000d
ooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l07Oooool4oomo00;ooooo1?oo000=oooo
o`Co0?l07_ooool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@oooo
o`Coo`002_ooool4ool001?ooooo0oooO`02ooooo`Coo`00=?ooool4ool000[ooooo1?oo000doooo
o`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co
0?l06?ooool4o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o01kooooo0oooO`0eooooo`?o
ogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?o
ogl00_ooool4ool003Cooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl0
0_ooool4ool000gooooo1?l0o`0Nooooo`?oogl0=Oooool3oomo013ooooo1?oo000Kooooo`Co0?l0
0_ooool3oomo013ooooo1?oo000:ooooo`Coo`004oooool3oomo00;ooooo1?oo000dooooo`Coo`00
2_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`0Hooooo`Co0?l07Oooool4oomo00;ooooo1?oo000=ooooo`Co0?l07_oo
ool3oomo03Gooooo0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`002_oo
ool4ool001?ooooo0oooO`02ooooo`Coo`00=?ooool4ool000[ooooo1?oo000dooooo`Coo`006?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4
o`3o01gooooo1?ooO`02ooooo`Coo`003Oooool4o`3o01kooooo0oooO`0eooooo`?oogl04?ooool4
ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool000[ooooo1?oo000Cooooo`?oogl00_ooool4
ool003Cooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool0
00gooooo1?l0o`1Fooooo`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool0
027ooooo0oooO`0jooooo`Coo`002_ooool4ool003Cooooo1?oo000Hooooo`03o`000?oooooooooo
00Sooooo000Vooooo`?o00000oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool000go
oooo1?l0o`1Fooooo`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl04?ooool4ool0027o
oooo0oooO`0jooooo`Coo`002_ooool4ool003Cooooo1?oo000Gooooo`;o00002_ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool006Oooooo
0oooO`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`008Oooool3oomo03[ooooo
1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool006Oooooo0ooo
O`0@ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`008Oooool3oomo03[ooooo1?oo
000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool006Oooooo0oooO`0@
ooooo`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`008Oooool3oomo03[ooooo1?oo000:
ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool006Oooooo0oooO`0@oooo
o`Coo`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`008Oooool3oomo03[ooooo1?oo000:oooo
o`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o01Sooooo1?l0o`0Mooooo`Coogl00_ooool4ool006Oooooo0oooO`0@ooooo`Co
o`006oooool4o`3o00;ooooo0oooO`0@ooooo`Coo`008Oooool3oomo03[ooooo1?oo000:ooooo`Co
o`00=?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o03Wooooo1?ooO`02ooooo`Coo`00Ioooool3oomo013ooooo1?oo000Kooooo`Co0?l0
0_ooool3oomo013ooooo1?oo000Qooooo`?oogl0>_ooool4ool000[ooooo1?oo000dooooo`Coo`00
6?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Ooo
ool4oomo00;ooooo1?oo001Wooooo`?oogl04?ooool4ool001_ooooo1?l0o`02ooooo`?oogl0=Ooo
ool3oomo03[ooooo1?oo000:ooooo`Coo`00=?ooool4ool001Sooooo00?o0000ooooooooool02?oo
ool0017ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooo
oooo00?ooooo1?l0o`0iooooo`Coogl00_ooool4ool006Oooooo0oooO`0@ooooo`Coo`006oooool4
o`3o00;ooooo0oooO`0eooooo`?oogl0>_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`02ooooo`Coo`00Ioooool3
oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`02ooooo`Coo`00Ioooool3
oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4ool000[ooooo1?oo000dooooo`Coo`006?ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo1?l00002ooooo`Co0?l0>Oooool4oomo00;ooooo1?oo001Wooooo`?oogl04?ooool4
ool005Wooooo0oooO`0jooooo`Coo`002_ooool4ool004gooooo1?l0000:ooooo`004?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool4
o`3o03Wooooo1?ooO`02ooooo`Coo`00Ioooool3oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4
ool000[ooooo1?oo001@ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0KOooool3
oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4ool000[ooooo1?oo001@ooooo`03o`000?oooooo
oooo00Sooooo000Aooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4ool0
00[ooooo1?oo001@ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`0iooooo`Coogl0KOooool3oomo013ooooo1?oo001Iooooo`?oogl0>_ooool4ool005ko
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo
1?ooO`1]ooooo`?oogl04?ooool4ool005Wooooo0oooO`0jooooo`Coo`00G_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0ooo
O`0@ooooo`Coo`00FOooool3oomo03[ooooo1?oo001Nooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo013ooooo1?oo001I
ooooo`?oogl0>_ooool4ool005kooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o03Wooooo1?ooO`1]ooooo`?oogl04?ooool4ool005Wooooo0oooO`0joooo
o`Coo`00G_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co
0?l0>Oooool4oomo06gooooo0oooO`1]ooooo`?oogl0>_ooool4ool005kooooo00?o0000oooooooo
ool02?ooool002Kooooo0ol00003ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`1]ooooo`?oogl0
>_ooool4ool005gooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Ooo
ool4oomo06gooooo0oooO`1]ooooo`?oogl0>_ooool4ool005kooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`1]ooooo`?oogl0KOooool3
oomo03[ooooo1?oo001Nooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo06gooooo0oooO`0jooooo`Coo`00G_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06go
oooo0oooO`1]ooooo`?oogl0>_ooool4ool005kooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`1]ooooo`?oogl0KOooool3oomo03[ooooo
1?oo001Nooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`0iooooo`Coogl0KOooool3oomo06gooooo0oooO`0jooooo`Coo`00G_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`1]
ooooo`?oogl0>_ooool4ool005kooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o03Wooooo1?ooO`1]ooooo`?oogl0ooooool=ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo0?oo
oooo3Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0
>Oooool4oomo06gooooo0oooO`3oooooo`gooooo00?o0000ooooooooool02?ooool002Kooooo0ol0
0003ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`3oooooo`cooooo0_l0000:ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`3oooooo`gooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`1]oooo
o`?oogl0ooooool=ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`0iooooo`Coogl0KOooool3oomo0?oooooo3Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`3oooooo`gooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?oo
O`1]ooooo`?oogl0ooooool=ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo0?oooooo3Oooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`3ooooo
o`gooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wo
oooo1?ooO`1]ooooo`?oogl0ooooool=ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0KOooool3oomo0?oooooo3Oooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo06gooooo0ooo
O`3oooooo`gooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`Co0?l0>Oooool4
oomo06gooooo0oooO`3oooooo`cooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03oooo
o`Co0?l0>Oooool4oomo06gooooo0oooO`3oooooo`gooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`1]ooooo`?oogl0ooooool=ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0
KOooool3oomo0?oooooo3Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l0>Oooool4oomo06gooooo0oooO`3oooooo`gooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`3ooooooggooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`3ooooo
oggooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wo
oooo1?ooO`3ooooooggooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o03Wooooo1?ooO`3ooooooggooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o03Wooooo1?ooO`3ooooooggooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`3ooooooggooooo00?o0000
ooooooooool02?ooool002Kooooo0ol00003ooooo`Co0?l0>Oooool4oomo0?ooooooO?ooool2o`00
00[ooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0
oooooommooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`0iooooo`Coogl0oooooommooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0
oooooommooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000oooool3o`0000Oooooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?oo
O`3ooooooggooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0>Oooool4oomo0?ooooooOOooool00ol0003oooooooooo`08ooooo`002_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo0?ooooooOOooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool4o`0000;ooooo1?l0o`0iooooo`Coogl0oooooomjooooo`Co0000
2_ooool000[ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooooooool4o`0000Oo
oooo00?o0000ooooooooool00oooool4o`3o03Wooooo1?ooO`3ooooooggooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`Co0?l0>Oooool4oomo0?ooooooOOooool00ol0003o
ooooooooo`08ooooo`002oooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00006ooooo`03
o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0iooooo`Coogl0oooo
oommooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0i
ooooo`Coogl0oooooommooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`0iooooo`Coogl0oooooommooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo0ol00003ooooo`Co0?l0ooooooniooooo`;o00002_ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08oooo
o`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00So
oooo000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
017ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000:ooooo`004?ooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02?ooool0017ooooo0_l00009ooooo`?o00001oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo0ol00003ooooo`Co0?l0ooooooniooooo`;o00002_ooool002Kooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08oooo
o`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00So
oooo000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo0?oooooo`Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`3o
oooool7ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00000_ooool3o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooooooo`000<Go00002_ooool000[ooooo00Co0000oooooooooooo00001oooool01_l0003ooooo
oooooooooooo0000ooooo`Co0000oooooooFooooo`002_ooool01?l0003oooooooooool00007oooo
o`07o`000?ooooooooooooooool0003oooooo`00003oooooomWooooo000;ooooo`;o00002Oooool3
o`0000;ooooo1Ol0003oooooomGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo000]ooooo`?o00002_ooool5o`0000[ooooo0ol0000<ooooo`?o00002_ooool3
o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00002Oooool3
o`0000Cooooo0_l00005ooooo`?o00000oooool3o`0000Gooooo0ol00002ooooo`Go00001?ooool3
o`0000?ooooo0ol00005ooooo`?o00001?ooool3o`0000Cooooo0ol00003ooooo`?o00001Oooool3
o`0000?ooooo0ol00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o00000oooool3
o`0000Gooooo0ol00003ooooo`;o00001Oooool5o`0000?ooooo0_l00004ooooo`Go00000_ooool3
o`0000Cooooo1Ol000000ooooooo0000o`000003o`0000?ooooo1Ol00002ooooo`?o00001?ooool5
o`0000?ooooo0ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00002ooooo`?o00001?ooool5
o`0000?ooooo00?o0000ooooooooool00oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool2
o`0000Kooooo0ol00004ooooo`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5
o`0000kooooo000^ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000kooooo000^ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`07ooooo`Go00003Oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000004?ooool002kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool01?l0003ooooo
ooooool0000>ooooo`03o`000?oooooooooo00Oooooo1?l0000=ooooo`03o`000?oooooooooo00Wo
oooo0ol0000;ooooo`Co00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1?l00006ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00001_oo
ool00ol0003oooooooooo`02ooooo`Co00001_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
0_l00007ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?l00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool3o`00
00Oooooo00Co0000oooooooooooooooo1?l00005ooooo`;o00000oooool01?l0003oooooooooool0
0005ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooooooo
o`0=ooooo`00;_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000[ooooo1?l0000:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool0
1?l0003oooooooooooooool4o`0000Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003ooooooooooooooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00004oooo
o`06o`000?ooooooooooooooool0003ooooo1?l00004ooooo`07o`000?ooooooooooooooool0003o
ooooo`000007ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`0<ooooo`00;Oooool2o`0000_ooooo00Go0000oooooooooooo
ooooo`000009ooooo`05o`000?ooooooooooooooool000002oooool2o`0000[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002Oooool0
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
1?ooool01?l0003oooooooooool00004ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo0_l00004
ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001Oooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l0
0004ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02o`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?o
oooo00?o0000ooooooooool03?ooool002kooooo00?o0000ooooooooool02_ooool3o`0000_ooooo
0ol0000=ooooo`03o`000?oooooooooo00Sooooo1Ol0000;ooooo`;o00002_ooool5o`0000[ooooo
0ol0000;ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool3o`0000Kooooo
00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`03ooooo`;o
00001_ooool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00_ooool3o`00
00Kooooo00?o0000ooooooooool00_ooool3o`0000Gooooo0ol00004ooooo`;o00001Oooool3o`00
00Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005ooooo`?o00000oooool3o`00
00Gooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`Go00001?ooool3o`00
00Cooooo0_l00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003ooooo`?o00001Oooool3o`00
00?ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo
00Cooooo0ol00003ooooo`?o00003oooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-2.06768, -0.0195514, 0.0713992, \
0.000918983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 2.21231 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12533 -24 -4.5 ]
[-0.0125 .12533 0 4.5 ]
[-0.0125 .23595 -18 -4.5 ]
[-0.0125 .23595 0 4.5 ]
[-0.0125 .34656 -24 -4.5 ]
[-0.0125 .34656 0 4.5 ]
[-0.0125 .45718 -18 -4.5 ]
[-0.0125 .45718 0 4.5 ]
[-0.0125 .56779 -24 -4.5 ]
[-0.0125 .56779 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12533 m
.00625 .12533 L
s
[(0.05)] -0.0125 .12533 1 0 Mshowa
0 .23595 m
.00625 .23595 L
s
[(0.1)] -0.0125 .23595 1 0 Mshowa
0 .34656 m
.00625 .34656 L
s
[(0.15)] -0.0125 .34656 1 0 Mshowa
0 .45718 m
.00625 .45718 L
s
[(0.2)] -0.0125 .45718 1 0 Mshowa
0 .56779 m
.00625 .56779 L
s
[(0.25)] -0.0125 .56779 1 0 Mshowa
.125 Mabswid
0 .03684 m
.00375 .03684 L
s
0 .05896 m
.00375 .05896 L
s
0 .08108 m
.00375 .08108 L
s
0 .10321 m
.00375 .10321 L
s
0 .14745 m
.00375 .14745 L
s
0 .16958 m
.00375 .16958 L
s
0 .1917 m
.00375 .1917 L
s
0 .21382 m
.00375 .21382 L
s
0 .25807 m
.00375 .25807 L
s
0 .28019 m
.00375 .28019 L
s
0 .30232 m
.00375 .30232 L
s
0 .32444 m
.00375 .32444 L
s
0 .36868 m
.00375 .36868 L
s
0 .39081 m
.00375 .39081 L
s
0 .41293 m
.00375 .41293 L
s
0 .43505 m
.00375 .43505 L
s
0 .4793 m
.00375 .4793 L
s
0 .50142 m
.00375 .50142 L
s
0 .52355 m
.00375 .52355 L
s
0 .54567 m
.00375 .54567 L
s
0 .58992 m
.00375 .58992 L
s
0 .61204 m
.00375 .61204 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12533 m
1 .12533 L
s
.99375 .23595 m
1 .23595 L
s
.99375 .34656 m
1 .34656 L
s
.99375 .45718 m
1 .45718 L
s
.99375 .56779 m
1 .56779 L
s
.125 Mabswid
.99625 .03684 m
1 .03684 L
s
.99625 .05896 m
1 .05896 L
s
.99625 .08108 m
1 .08108 L
s
.99625 .10321 m
1 .10321 L
s
.99625 .14745 m
1 .14745 L
s
.99625 .16958 m
1 .16958 L
s
.99625 .1917 m
1 .1917 L
s
.99625 .21382 m
1 .21382 L
s
.99625 .25807 m
1 .25807 L
s
.99625 .28019 m
1 .28019 L
s
.99625 .30232 m
1 .30232 L
s
.99625 .32444 m
1 .32444 L
s
.99625 .36868 m
1 .36868 L
s
.99625 .39081 m
1 .39081 L
s
.99625 .41293 m
1 .41293 L
s
.99625 .43505 m
1 .43505 L
s
.99625 .4793 m
1 .4793 L
s
.99625 .50142 m
1 .50142 L
s
.99625 .52355 m
1 .52355 L
s
.99625 .54567 m
1 .54567 L
s
.99625 .58992 m
1 .58992 L
s
.99625 .61204 m
1 .61204 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .06441 L
.04348 .06441 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .06441 L
.04348 .06441 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .01472 L
.07453 .01472 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .01472 L
.07453 .01472 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .05742 L
.10559 .05742 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .05742 L
.10559 .05742 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .01472 L
.13665 .01472 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .01472 L
.13665 .01472 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .05898 L
.1677 .05898 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .05898 L
.1677 .05898 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .10867 L
.19876 .10867 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .10867 L
.19876 .10867 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .06519 L
.22981 .06519 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .06519 L
.22981 .06519 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .01704 L
.26087 .01704 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .01704 L
.26087 .01704 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .14905 L
.29193 .14905 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .14905 L
.29193 .14905 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .01549 L
.32298 .01549 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .01549 L
.32298 .01549 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .11722 L
.35404 .11722 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .11722 L
.35404 .11722 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .02326 L
.38509 .02326 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .02326 L
.38509 .02326 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .13818 L
.41615 .13818 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .13818 L
.41615 .13818 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .1211 L
.4472 .1211 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .1211 L
.4472 .1211 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .11955 L
.47826 .11955 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .11955 L
.47826 .11955 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .01472 L
.50932 .01472 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .01472 L
.50932 .01472 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .12809 L
.54037 .12809 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .12809 L
.54037 .12809 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .03258 L
.57143 .03258 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .03258 L
.57143 .03258 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .15449 L
.60248 .15449 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .15449 L
.60248 .15449 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .0186 L
.63354 .0186 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .0186 L
.63354 .0186 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .14672 L
.6646 .14672 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .14672 L
.6646 .14672 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .12964 L
.69565 .12964 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .12964 L
.69565 .12964 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .16769 L
.72671 .16769 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .16769 L
.72671 .16769 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .03025 L
.75776 .03025 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .03025 L
.75776 .03025 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .16381 L
.78882 .16381 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .16381 L
.78882 .16381 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .04811 L
.81988 .04811 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .04811 L
.81988 .04811 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .12731 L
.85093 .12731 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .12731 L
.85093 .12731 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .03801 L
.88199 .03801 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .03801 L
.88199 .03801 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .11877 L
.91304 .11877 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .11877 L
.91304 .11877 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .15915 L
.9441 .15915 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .15915 L
.9441 .15915 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .10557 L
.97516 .10557 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .10557 L
.97516 .10557 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .57692 L
.01863 .57692 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .57692 L
.01863 .57692 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .02869 L
.04969 .02869 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .02869 L
.04969 .02869 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .27796 L
.08075 .27796 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .27796 L
.08075 .27796 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .02714 L
.1118 .02714 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .02714 L
.1118 .02714 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .11799 L
.14286 .11799 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .11799 L
.14286 .11799 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .02714 L
.17391 .02714 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .02714 L
.17391 .02714 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .02248 L
.20497 .02248 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .02248 L
.20497 .02248 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .03335 L
.23602 .03335 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .03335 L
.23602 .03335 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .37813 L
.26708 .37813 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .37813 L
.26708 .37813 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .02326 L
.29814 .02326 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .02326 L
.29814 .02326 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .0846 L
.32919 .0846 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .0846 L
.32919 .0846 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .0186 L
.36025 .0186 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .0186 L
.36025 .0186 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .08305 L
.3913 .08305 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .08305 L
.3913 .08305 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .01937 L
.42236 .01937 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .01937 L
.42236 .01937 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .01704 L
.45342 .01704 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .01704 L
.45342 .01704 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .38589 L
.51553 .38589 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .38589 L
.51553 .38589 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01627 L
.54658 .01627 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01627 L
.54658 .01627 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .05509 L
.57764 .05509 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .05509 L
.57764 .05509 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .06519 L
.63975 .06519 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .06519 L
.63975 .06519 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .01549 L
.70186 .01549 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .01549 L
.70186 .01549 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .19642 L
.76398 .19642 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .19642 L
.76398 .19642 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .01782 L
.79503 .01782 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .01782 L
.79503 .01782 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .01782 L
.82609 .01782 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .01782 L
.82609 .01782 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .05975 L
.8882 .05975 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .05975 L
.8882 .05975 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .60332 L
.02484 .60332 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .60332 L
.02484 .60332 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .01627 L
.0559 .01627 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .01627 L
.0559 .01627 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .18011 L
.08696 .18011 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .18011 L
.08696 .18011 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .01549 L
.11801 .01549 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .01549 L
.11801 .01549 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .45811 L
.14907 .45811 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .45811 L
.14907 .45811 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .01937 L
.18012 .01937 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .01937 L
.18012 .01937 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .01627 L
.21118 .01627 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .01627 L
.21118 .01627 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .02792 L
.24224 .02792 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .02792 L
.24224 .02792 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .26941 L
.27329 .26941 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .26941 L
.27329 .26941 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .01472 L
.30435 .01472 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .01472 L
.30435 .01472 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .22282 L
.3354 .22282 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .22282 L
.3354 .22282 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .05742 L
.39752 .05742 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .05742 L
.39752 .05742 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .01472 L
.42857 .01472 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .01472 L
.42857 .01472 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .24379 L
.52174 .24379 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .24379 L
.52174 .24379 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .02248 L
.58385 .02248 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .02248 L
.58385 .02248 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .01472 L
.61491 .01472 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .01472 L
.61491 .01472 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .19487 L
.64596 .19487 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .19487 L
.64596 .19487 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .07994 L
.77019 .07994 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .07994 L
.77019 .07994 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .02015 L
.89441 .02015 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .02015 L
.89441 .02015 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .0217 L
.03106 .0217 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .0217 L
.03106 .0217 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .15604 L
.06211 .15604 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .15604 L
.06211 .15604 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .12032 L
.09317 .12032 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .12032 L
.09317 .12032 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .13741 L
.12422 .13741 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .13741 L
.12422 .13741 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .04733 L
.15528 .04733 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .04733 L
.15528 .04733 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .12653 L
.18634 .12653 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .12653 L
.18634 .12653 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .0978 L
.21739 .0978 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .0978 L
.21739 .0978 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .14595 L
.24845 .14595 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .14595 L
.24845 .14595 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .06131 L
.2795 .06131 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .06131 L
.2795 .06131 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .07062 L
.31056 .07062 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .07062 L
.31056 .07062 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .11644 L
.34161 .11644 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .11644 L
.34161 .11644 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .08848 L
.37267 .08848 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .08848 L
.37267 .08848 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .17313 L
.40373 .17313 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .17313 L
.40373 .17313 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .06985 L
.43478 .06985 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .06985 L
.43478 .06985 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .05432 L
.46584 .05432 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .05432 L
.46584 .05432 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .02636 L
.49689 .02636 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .02636 L
.49689 .02636 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .05975 L
.52795 .05975 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .05975 L
.52795 .05975 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .04189 L
.55901 .04189 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .04189 L
.55901 .04189 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .18167 L
.59006 .18167 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .18167 L
.59006 .18167 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .03801 L
.62112 .03801 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .03801 L
.62112 .03801 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .11489 L
.65217 .11489 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .11489 L
.65217 .11489 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .03335 L
.68323 .03335 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .03335 L
.68323 .03335 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .04733 L
.71429 .04733 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .04733 L
.71429 .04733 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .02636 L
.74534 .02636 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .02636 L
.74534 .02636 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .13352 L
.7764 .13352 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .13352 L
.7764 .13352 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .04966 L
.80745 .04966 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .04966 L
.80745 .04966 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .14672 L
.83851 .14672 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .14672 L
.83851 .14672 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .03646 L
.86957 .03646 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .03646 L
.86957 .03646 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .19409 L
.90062 .19409 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .19409 L
.90062 .19409 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .02326 L
.93168 .02326 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .02326 L
.93168 .02326 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .01937 L
.96273 .01937 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .01937 L
.96273 .01937 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .02326 L
.99379 .02326 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .02326 L
.99379 .02326 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00;Oooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000>oooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000>ooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo0000013ooooo000^ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03?ooool002gooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00cooooo000^ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0000oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Voooooooo0000aOl0000:
ooooo`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l4oomo00;o00000ooo
0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l00003ool000?o0?l00_l0
0?l4oomo00;o00000ooo0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0
o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0ooo
O`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo
0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol0
0?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0
o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0ooo
O`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo
0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol0
0?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`03o`0000[ooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool3o`3o00;o003o1?oo
O`02ooooo`?oo`001?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl00_oo
ool3ool000Co0?l000?ooooooomo0?ooO`000_ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo
0003o`3o00;o003o1?ooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl01Ooo
ool3o`3o00?o003o0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_oo
ool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_oo
ool3ool000Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo00?o0000ooooooooool02?ooool001cooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0004o`3o0003oooooooo
O`3oogl000;oogl01Oooool3o`3o00;o003o1?ooO`02ooooo`?oo`001?l0o`000oooooooogl0oomo
0002oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00;ooooo0ooo
0004o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00?o003o0ooo
O`02ooooo`?oo`001?l0o`02ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`?oo`001?l0
o`02ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0004o`3o00;ooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_oo
ool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo00?o0000ooooooooool02?ooool001gooooo0_l00007
ooooo`03o`000?oooooooooo00?ooooo0ol0o`02o`00o`Coogl00_ooool3ool000Co0?l000?ooooo
oomo0?ooO`000_ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0004o`3o0003ooooooooO`3o
ogl000;oogl01Oooool3o`3o00;o003o1?ooO`02ooooo`?oo`001?l0o`000oooooooogl0oomo0002
oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3
o`3o00?o003o0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02
ooooo`Coo`001Oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3
oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3
oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0005
ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005
ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4
ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3
ool000Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000[ooooo1?oo0005
ooooo`?oogl00_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?l5ooooo`?oo`001?l0o`000oooooooogl0oomo0002oomo00Gooooo0ol0o`02o`00
o`Coogl00_ooool3ool000Co0?l000?ooooooomo0?ooO`000_ooO`05ooooo`?o0?l00_l00?l4oomo
00;ooooo0ooo0004o`3o0003ooooooooO`3oogl000;oogl00_ooool4ool000Gooooo0oooO`02oooo
o`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`?oo`001?l0o`02oooo
o`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0003o`3o
00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool0
00Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool0
00Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02oooo
o`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02oooo
o`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo
00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l00_ooool3oomo00;ooooo1?oo0005oooo
o`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl00_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`?oo`001?l0o`000ooooooo
ogl0oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool3ool000Co0?l000?ooooooomo0?oo
O`000_ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0004o`3o0003ooooooooO`3oogl000;o
ogl00_ooool4ool000Gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00?o
003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Go
oooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Go
oooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Go
oooo0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o
0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Co
o`001Oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`?oo`001?l0o`02ooooo`?o
ogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`?oo`001?l0o`000oooooooogl0
oomo0002oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l0
0_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`?oo`00
0ol0o`03o`00o`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo000:ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l0
0_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool000Cooooo1?oo
O`05ooooo`?o0?l00_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o00;o003o1?oo
O`02ooooo`Coo`001?ooool4oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l00_oo
ool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol0
0?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_oo
ool4ool000Gooooo0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`02ooooo`Coo`002_ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0004o`3o00;ooooo0ooo
O`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo1?oo0004ooooo`Coogl01Oooool3
o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4
ool000Cooooo1?ooO`02ooooo`Coo`001Oooool3oomo00;ooooo0ooo0004o`3o00;ooooo0oooO`05
ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02
ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02
ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005
ooooo`?oogl00_ooool3ool000Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3
o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4
ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3
oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000Co0?l00_ooool3oomo00;ooooo1?oo000:
ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o1Oooool4ool000Cooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo
00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo
00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo
00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo
00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o
00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool0
00[ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool0
00Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool0
00Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000oooo
ooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00Go
oooo0ol0o`02o`00o`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00;o
oooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Go
oooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;o
oooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Go
oooo0oooO`05ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o
003o0oooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Oooool3o`3o00?o
003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Go
oooo0oooO`02ooooo`?oo`001?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Co
o`002Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo
1?oo0004ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00Gooooo
0ol0o`02o`00o`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001Oooool3oomo00;ooooo
1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo1?l0o`02ooooo`?oogl00_ooool4ool000gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Ooo
ool4ool000Cooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl01Ooo
ool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Ooo
ool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_oo
ool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol0
0?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`003Ooo
ool3o`3o00?o003o0oooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Ooo
ool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002_oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5
ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000Cooooo1?ooO`05
ooooo`?o0?l00_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02
ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05
ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02
ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03
o`00o`?oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000gooooo0ol0o`03
o`00o`?oogl00_ooool4ool000[ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03
o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=
ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool0
00Cooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o
00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool0
00Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o
00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool0
00Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`003Oooool4o`3o
00;ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo1?oo0004ooooo`Co
ogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`03o`00o`Go
oooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Go
oooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;o
oooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000go
oooo1?l0o`02ooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000[o
oooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000[o
oooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`02o`00o`Coogl0
0_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo
1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo
0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_ooool4ool000gooooo
1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`Coo`001?oo
ool4oomo00Gooooo0ol0o`02o`00o`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol0
0?l5ooooo`Coo`001?ooool4oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0ooo
O`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0ooo
O`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo
000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo
000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool001?ooooo0ooo
O`02ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo
000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00o`Gooooo1?oo0004ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`02ooooo`Coo`001?ooool4
oomo00Gooooo0ol0o`03o`00o`Gooooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02
ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05
ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02
ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000gooooo0ol0o`03
o`00o`?oogl00_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool000gooooo0ol0o`03
o`00o`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02
ooooo`Coo`004oooool3oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:
ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o1Oooool4ool000Cooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo
00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o00?o003o1Oooool4ool000Cooooo1?ooO`02oooo
o`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02oooo
o`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05oooo
o`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000[ooooo1?oo000=oooo
o`?o0?l00ol00?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000gooooo0ol0o`03o`00
o`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:oooo
o`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o
0?l00ol00?l5ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Go
oooo0ol0o`03o`00o`Gooooo1?oo0004ooooo`Coogl00_ooool4ool000Gooooo0oooO`02ooooo`Co
o`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o
0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Co
o`001Oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`Co
o`004oooool3oomo00;ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:ooooo`Co
o`002_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Co
o`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo0009ooooo`;o
00002_ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool000Cooooo
1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl0
0_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl0
0_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl0
1Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000:ooooo`Coo`00
3Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`003Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo
1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00o`Gooooo1?oo0004ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`0:ooooo`Coogl01Ooo
ool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0ooo
O`05ooooo`?o0?l01?l00?l4ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_oo
ool4ool000Gooooo0oooO`05ooooo`Co0?l00_ooool3oomo00;ooooo1?oo0005ooooo`?oogl00_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo
000=ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0
o`03o`00o`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo
000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4
oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005
ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3
oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3
oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02
ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=
ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`02
ooooo`Coo`002_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo
00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`0;oooo
o`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`001Oooool3oomo
00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02oooo
o`Coo`004?ooool3o`00o`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o
00?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool0
00[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`0:ooooo`Co
ogl01Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00Go
oooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o0oooO`02ooooo`Co
o`001Oooool3oomo00Gooooo1?l0o`02ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Co
o`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013o
oooo0ol00?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`?o
ogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Co
o`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo
0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`05ooooo`?o0?l0
1?l00?l4ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo
1?l0o`02ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o
1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool000[ooooo
1?oo000:ooooo`Coo`003Oooool3o`3o00?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo
1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Ooo
ool3o`3o00;o003o1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo
0005ooooo`?oogl02oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000=ooooo`?o0?l00ol0
0?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo
000@ooooo`?o003o0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`?o0?l00ol0
0?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05
ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl01Oooool3
o`3o00Co003o1?ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05
ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`04
o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo000:
ooooo`Coo`002_ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool001?ooooo0oooO`02
ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo
00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`02oooo
o`Coo`001Oooool3oomo00_ooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`003Oooool3o`3o
00?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo1?l0o`02ooooo`?oogl00_ooool4ool0
00[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02oooo
o`Coo`004?ooool3o`00o`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o
00?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool0
00[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?o
oooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05ooooo`?o
0?l00ol00?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00Co
003o1?ooool4ool000gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`Co
0?l00_ooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Co
oooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo000:ooooo`Co
o`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Co
o`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000Wooooo0_l0000:ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o00;o003o
1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo0005ooooo`?oogl0
2oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000=ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl01Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo
1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000@ooooo`?o003o
0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo
1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo
1?oo000:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00Co003o1?oo
ool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00;ooooo1?oo
000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_oo
ool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo1?l0
o`02ooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo
000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4
oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`05
ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool000Gooooo0oooO`0;
ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4
ool001?ooooo0oooO`02ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool000[ooooo1?oo000:
ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000C
ooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o
00;o003o1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00;ooooo1?oo0005oooo
o`?oogl02oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000@ooooo`?o003o0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00
o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo000:oooo
o`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool001?ooooo0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000[ooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Go
oooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`Co
o`001Oooool3oomo00_ooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool3o`00o`?o
ogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`?o
0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000@ooooo`?o003o0oooO`02ooooo`Co
o`002_ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000Cooooo`?o
ogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000:ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo
1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl0
0_ooool4ool000Gooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013ooooo
0ol00?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`00
3Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool3o`00o`?oogl0
0_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`00
4oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`00
2_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?l=ooooo`Coogl01Oooool3o`3o00;o003o1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Ooo
ool4oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo
000@ooooo`?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol0
0?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_oo
ool4ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_oo
ool4ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo0ol0o`03
o`00o`gooooo1?ooO`02ooooo`Coo`004oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000@
ooooo`?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4
ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3
oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4
ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4
ool000[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o
00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo0ol0o`03o`00
o`gooooo1?ooO`02ooooo`Coo`004oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000@oooo
o`?o003o0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool0
00gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3oomo
00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool0
01?ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool0
00[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?l=ooooo`Co
ogl01Oooool3o`3o00;o003o1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00;o
oooo1?oo000Cooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013ooooo0ol00?l3oomo00;o
oooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co
003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool000[o
oooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004oooool3oomo00;o
oooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`002Oooool2o`0000[o
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l0
0_l00?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001?ooooo
0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool001?ooooo
0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`00
4oooool3oomo00;ooooo1?oo000@ooooo`?o003o0oooO`02ooooo`Coo`002_ooool4ool000[ooooo
1?oo000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo
0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000:ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l0
0?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001?ooooo0ooo
O`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool001?ooooo0ooo
O`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004ooo
ool3oomo00;ooooo1?oo000@ooooo`?o003o0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo
000=ooooo`Co0?l00_ooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0ooo
O`02ooooo`Coo`002_ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4
oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`0Iooooo`?oogl01Oooool3o`3o00Co003o1?ooool4
ool0013ooooo0ol00?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:
ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool3
o`00o`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02
ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000H
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
o`gooooo1?ooO`05ooooo`?o0?l00_l00?l4oomo00[ooooo1?ooO`05ooooo`?o0?l00ol00?l=oooo
o`Coogl06Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000@ooooo`?o003o0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00
o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo000:oooo
o`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool001?ooooo0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`006?ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o00;o
003o1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4oomo01Wooooo0oooO`05ooooo`?o
0?l01?l00?l4ooooo`Coo`004?ooool3o`00o`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Co
o`002_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;o
oooo1?oo000@ooooo`?o003o0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`Co
0?l00_ooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Co
o`002_ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`02o`00o`Coogl02_ooool4oomo00Gooooo
0ol0o`03o`00o`gooooo1?ooO`0Iooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013ooooo
0ol00?l3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000:ooooo`Coo`00
3Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool4o`00o`Cooooo
1?oo000:ooooo`Coo`002_ooool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool001?ooooo
0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000:ooooo`Coo`006?ooool00ol0003ooooo
ooooo`08ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0
0007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00_l0
0?l4oomo00[ooooo1?ooO`08ooooo`?o003o3Oooool4oomo01Wooooo0oooO`05ooooo`?o0?l01?l0
0?l4ooooo`Coo`004?ooool4o`00oa_ooooo0oooO`02ooooo`Coo`002_ooool4ool000[ooooo1?oo
000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?oo
ool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004ooo
ool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool4ool000[ooooo1?oo000Hooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool3o`3o00?o
003o3Oooool4oomo00Gooooo0ol0o`03o`00o`gooooo1?ooO`08ooooo`?o003o3Oooool4oomo01Wo
oooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool4o`00oa_ooooo0oooO`02ooooo`Co
o`002_ooool4ool001_ooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool0013o
oooo1?l00?l4ooooo`Coo`002_ooool4ool000[ooooo1?oo000=ooooo`Co0?l00_ooool3oomo00;o
oooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0@ooooo`Coo`006?ooool00ol0003o
ooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=oooo
o`Coogl01Oooool3o`3o00?o003o3Oooool4oomo00Sooooo0ol00?l=ooooo`Coogl06Oooool3oomo
00Gooooo0ol0o`04o`00o`Cooooo1?oo000@ooooo`Co003o6oooool3oomo00;ooooo1?oo000Yoooo
o`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?ooool4ool0
00[ooooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004oooool3oomo
00;ooooo1?oo000Cooooo`?oogl04?ooool4ool001Sooooo00?o0000ooooooooool02?ooool000[o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00Cooooo1?l00002ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o00?o003o3Oooool4
oomo00Sooooo0ol00?l=ooooo`Coogl06Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000@
ooooo`Co003o6oooool3oomo00;ooooo1?oo000Yooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3
oomo00;ooooo1?oo000@ooooo`Co003o1?ooool4ool000[ooooo1?oo000:ooooo`Coo`003Oooool4
o`3o00;ooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo1?oo000Cooooo`?oogl04?ooool4
ool001Gooooo1?l0000:ooooo`002_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooo`000?ooool01?l00007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?oo
O`05ooooo`?o0?l00ol00?l=ooooo`Coogl02?ooool3o`00ob[ooooo0oooO`05ooooo`?o0?l01?l0
0?l4ooooo`Coo`004?ooool4o`00oa_ooooo0oooO`02ooooo`Coo`00:Oooool3o`3o00Co003o1?oo
ool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool4o`00o`Cooooo1?oo000:ooooo`Coo`002_oo
ool4ool000gooooo1?l0o`02ooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`Coo`004ooo
ool3oomo013ooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00ol00?l=ooooo`Coogl02?ooool3o`00ob[o
oooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool4o`00oa_ooooo0oooO`02ooooo`Co
o`00:Oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?ooool4ool000[o
oooo1?oo000:ooooo`Coo`003Oooool4o`3o00;ooooo0oooO`02ooooo`Coo`004oooool3oomo01Wo
oooo0oooO`0@ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000[ooooo
0_l00002ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl0
1Oooool3o`3o00?o003o3Oooool4oomo00Sooooo0ol00?lZooooo`?oogl01Oooool3o`3o00Co003o
1?ooool4ool0013ooooo1?l00?lKooooo`?oogl00_ooool4ool002Wooooo0ol0o`04o`00oa_ooooo
0oooO`02ooooo`Coo`004?ooool4o`00o`Cooooo1?oo000Hooooo`Coo`003Oooool4o`3o00;ooooo
0oooO`02ooooo`Coo`004oooool3oomo01Wooooo0oooO`0@ooooo`Coo`006?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Ooo
ool3o`3o00?o003o3Oooool4oomo00Sooooo0ol00?lZooooo`?oogl01Oooool3o`3o00Co003o1?oo
ool4ool0013ooooo1?l00?lKooooo`?oogl00_ooool4ool002Wooooo0ol0o`04o`00oa_ooooo0ooo
O`02ooooo`Coo`004?ooool4o`00o`Cooooo1?oo000Hooooo`Coo`003Oooool4o`3o00Oooooo1?oo
000Cooooo`?oogl06Oooool3oomo013ooooo1?oo000Hooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00ol00?l=
ooooo`Coogl02?ooool3o`00ob[ooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`004?ooool4
o`00oa_ooooo0oooO`02ooooo`Coo`00:Oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo000@
ooooo`Co003o1?ooool4ool001Sooooo1?oo000=ooooo`Co0?l01oooool4ool001?ooooo0oooO`0I
ooooo`?oogl04?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`03o`00oaWooooo0ol00?lZoooo
o`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013ooooo1?l00?lKooooo`?oogl0;oooool3o`3o
00Co003o6oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?ooool4ool001Sooooo1?oo000=oooo
o`Co0?l01oooool4ool001?ooooo0oooO`0Iooooo`?oogl04?ooool4ool001Sooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Go
oooo0ol0o`03o`00oaWooooo0ol00?lZooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013o
oooo1?l00?lKooooo`?oogl0;oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo000@ooooo`Co
003o1?ooool4ool001Sooooo1?oo000=ooooo`Co0?l01oooool4ool001?ooooo0oooO`0Iooooo`?o
ogl04?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`03o`00oaWooooo0ol00?lZooooo`?oogl0
1Oooool3o`3o00Co003o1?ooool4ool0013ooooo1?l00?lKooooo`?oogl0;oooool3o`3o00Co003o
6oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?ooool4ool001Sooooo1?oo000=ooooo`Co0?l0
1oooool4ool001?ooooo0oooO`0Iooooo`?oogl04?ooool4ool001Sooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0
o`03o`00oaWooooo0ol00?lZooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool0013ooooo1?l0
0?lKooooo`?oogl0;oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo000@ooooo`Co003o1?oo
ool4ool001Sooooo1?oo000=ooooo`Co0?l01oooool4ool001?ooooo0oooO`0Iooooo`?oogl04?oo
ool4ool001Sooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?l=
ooooo`Coogl01Oooool3o`3o00?o003o6Oooool3o`00oc;ooooo0ol0o`04o`00o`Cooooo1?oo000@
ooooo`Co003o6oooool3oomo02oooooo0ol0o`04o`00oa_ooooo0oooO`02ooooo`Coo`004?ooool4
o`00ob3ooooo1?oo000=ooooo`Co0?l01oooool4ool002oooooo0oooO`0@ooooo`Coo`005oooool2
o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`05oooo
o`?o0?l00ol00?lIooooo`?o003o<_ooool3o`3o00Co003o6?ooool4o`00oa_ooooo0oooO`0_oooo
o`?o0?l01?l00?lKooooo`?oogl00_ooool4ool0013ooooo1?l00?lPooooo`Coo`003Oooool4o`3o
00Oooooo1?oo000_ooooo`?oogl04?ooool4ool001Sooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o3Oooool4oomo00Gooooo0ol0o`03o`00oaWo
oooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003o6oooool3oomo02oooooo0ol0o`04o`00oa_o
oooo0oooO`02ooooo`Coo`004?ooool4o`00ob3ooooo1?oo000=ooooo`Co0?l01oooool4ool002oo
oooo0oooO`0@ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl01Oooool3o`3o00?o003o6Oooool3o`00oc;ooooo
0ol0o`04o`00oaSooooo1?l00?lKooooo`?oogl0;oooool3o`3o00Co003o6oooool3oomo00;ooooo
1?oo000@ooooo`Co003o8?ooool4ool000gooooo1?l0o`07ooooo`Coo`00;oooool3oomo013ooooo
1?oo000Hooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00o`gooooo1?ooO`05ooooo`?o0?l00ol00?lIooooo`?o003o<_ooool3o`3o00Co003o6?oo
ool4o`00oa_ooooo0oooO`0_ooooo`?o0?l01?l00?lKooooo`?oogl05_ooool4o`00ob3ooooo1?oo
000=ooooo`Co0?l01oooool4ool002oooooo0oooO`0@ooooo`Coo`006?ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`?o0?l00ol00?lI
ooooo`?o003o<_ooool3o`3o00Co003o6?ooool4o`00oa_ooooo0oooO`0_ooooo`?o0?l01?l00?lK
ooooo`?oogl05_ooool4o`00ob3ooooo1?oo000=ooooo`Co0?l01oooool4ool002oooooo0oooO`0@
ooooo`Coo`006?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?lFooooo`?o0?l00ol00?lIooooo`?o003o<_ooool3o`3o00Co003o6?ooool4o`00
oa_ooooo0oooO`0_ooooo`?o0?l01?l00?lKooooo`?oogl05_ooool4o`00ob3ooooo1?oo000=oooo
o`Co0?l01oooool4ool002oooooo0oooO`0/ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo0ol0o`03o`00oaWooooo0ol00?lbooooo`?o
0?l01?l00?lHooooo`Co003o6oooool3oomo02oooooo0ol0o`04o`00oa_ooooo0oooO`0Fooooo`Co
003o8?ooool4ool000gooooo1?l0o`07ooooo`Coo`00;oooool3oomo02cooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool3o`3o00?o003o
6Oooool3o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?lKooooo`?oogl0;oooool3o`3o00Co003o
6oooool3oomo01Kooooo1?l00?lPooooo`Coo`003Oooool4o`3o03[ooooo0oooO`0/ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo0ol0
o`03o`00oaWooooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003o6oooool3oomo02oooooo0ol0
o`04o`00oa_ooooo0oooO`0Fooooo`Co003o8?ooool4ool000gooooo1?l0o`0jooooo`?oogl0;?oo
ool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00oaKooooo0ol0o`03
o`00oaWooooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003o6oooool3oomo02oooooo0ol0o`04
o`00oa_ooooo0oooO`0Fooooo`Co003o<Oooool4o`3o03[ooooo0oooO`0[ooooo`;o00002_ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool3o`3o00?o003o6Oooool3o`00
oc;ooooo0ol0o`04o`00oaSooooo1?l00?lKooooo`?oogl0;oooool3o`3o00Co003o6oooool3oomo
01Kooooo1?l00?laooooo`Co0?l0>_ooool3oomo02cooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool3o`3o00?o003o6Oooool3o`00oc;o
oooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?lKooooo`?oogl05_ooool4o`00oc7o
oooo1?l0o`0jooooo`?oogl0;?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?lFooooo`?o0?l00ol00?lIooooo`?o003o<_ooool3o`3o00Co003o
6?ooool4o`00odgooooo0ol0o`04o`00oa_ooooo0oooO`0Fooooo`Co003o<Oooool4o`3o03[ooooo
0oooO`0/ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oaKooooo0ol0o`03o`00oaWooooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003oCOoo
ool3o`3o00Co003o6oooool3oomo01Kooooo1?l00?laooooo`Co0?l0>_ooool3oomo02cooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4
o`3o01_ooooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003o6oooool3
oomo01Kooooo1?l00?laooooo`Co0?l0>_ooool3oomo02cooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lboooo
o`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003o=?ooool4o`00oc7ooooo1?l0o`0joooo
o`?oogl0;?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o
0?l01?l00?ldooooo`Co003o<Oooool4o`3o03[ooooo0oooO`0/ooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o
<_ooool3o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00ocCooooo1?l00?laooooo`Co0?l0
>_ooool3oomo02cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00ooo
ool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003oCOoo
ool3o`3o00Co003o=?ooool4o`00oc7ooooo1?l0o`0jooooo`?oogl0;?ooool00ol0003ooooooooo
o`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o<_ooool3
o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00ocCooooo1?l00?laooooo`Co0?l0>_ooool3
oomo02_ooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFoooo
o`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?ldoooo
o`Co003o<Oooool4o`3o03[ooooo0oooO`0/ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o<_ooool3o`3o00Co
003o6?ooool4o`00odgooooo0ol0o`04o`00ofWooooo1?l0o`1Yooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o
<_ooool3o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00omKooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol0
0?lbooooo`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003oe_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`Co0?l06oooool3
o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?oFooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Koooo
o`?o003o<_ooool3o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00omKooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_o
oooo0ol00?lbooooo`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003oe_ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`Co0?l0
6oooool3o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?oFooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0
o`0Kooooo`?o003o<_ooool3o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00omKooooo00?o
0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?lFooooo`Co0?l06oooool3
o`00oc;ooooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?oEooooo`;o00002_ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lboooo
o`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003oe_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;o
oooo0ol0o`04o`00oaSooooo1?l00?m=ooooo`?o0?l01?l00?oFooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o
<_ooool3o`3o00Co003o6?ooool4o`00odgooooo0ol0o`04o`00omKooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol0
0?lbooooo`?o0?l01?l00?lHooooo`Co003oCOooool3o`3o00Co003oe_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`Co0?l06oooool3
o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00omKooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lboooo
o`?o0?l01?l00?mYooooo`?o0?l01?l00?oFooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00omKo
oooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o
003o<_ooool3o`3o00Co003oJOooool3o`3o00Co003oe_ooool00ol0003oooooooooo`08ooooo`00
4?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`?o0?l01?l00?mYooooo`?o
0?l01?l00?oFooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01_ooool4o`0000;ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o
003o<_ooool3o`3o00Co003oJOooool3o`3o00Co003odoooool4o`0000[ooooo000@ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00ofWooooo0ol0o`04o`00omKo
oooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002?ooool2o`0000So
oooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`?o
0?l01?l00?mYooooo`?o0?l01?l00?oFooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o0000
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo
1?l0o`0Kooooo`?o003o<_ooool3o`3o00Co003oJOooool3o`3o00Co003oe_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`Co0?l06ooo
ool3o`00oc;ooooo0ol0o`04o`00ofWooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o<_ooool3
o`3o00Co003oJOooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`?o0?l01?l00?mYoooo
o`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00ofWooooo1?l0o`3Iooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo
1?l0o`0Kooooo`?o003o<_ooool3o`3o00Co003oJOooool4o`3o0=Wooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol0
0?lbooooo`?o0?l01?l00?mYooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool3
o`0000?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o003o<_ooool3o`3o00Co003oJOooool4
o`3o0=Sooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFoooo
o`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00ofWooooo1?l0o`3Iooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo1?l0o`0Kooooo`?o
003o<_ooool3o`3o00Co003oJOooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`?o0?l0
1?l00?mYooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?lFooooo`Co0?l06oooool3o`00oc;ooooo0ol0o`04o`00ofWooooo1?l0
o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oaKooooo1?l0o`0Kooooo`?o003o<_ooool3o`3o00Co003oJOooool4o`3o0=Wooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o
01_ooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`Co
0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003o5_ooool4o`3o01_ooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?leooooo`?o003o<_oo
ool4o`3o06cooooo1?l0o`3Hooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o
06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo
1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lb
ooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o
003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?leooooo`?o003o<_oo
ool4o`3o06cooooo1?l0o`3Hooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o
06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo
1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lb
ooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o
003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?leooooo`?o003o<_oo
ool4o`3o06cooooo1?l0o`3Hooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3
o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o
06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo
1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lb
ooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0
003oooooooooo`08ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo0ol00007ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co
0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Ioooo
o`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`Co00000_ooool3o`3o00?o003o=Oooool3o`00
oc;ooooo1?l0o`1/ooooo`Co0?l0e_ooool4o`0000[ooooo000:ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000oooo
ooooool02?ooool000[ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooooooool4
o`0000Oooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/
ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008
ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool0
00_ooooo0_l0000:ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lboooo
o`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o
<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3
o`00oc;ooooo1?l0o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool3o`00
00?ooooo0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Sooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06co
oooo1?l0o`3Iooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00ocGooooo0ol00?lbooooo`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00oc;ooooo1?l0
o`1/ooooo`Co0?l0fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?leooooo`?o003o<_ooool4o`3o06cooooo1?l0o`3Iooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?lboooo
o`Co0?l0K?ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o=Oooool3o`00oj;ooooo1?l0o`3Iooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?nRooooo`Co0?l0
fOooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?leooooo`?o003oX_ooool4o`3o0=Wooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08
ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00ocGooooo0ol00?ooooooogoooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo
0ol00?oooooooh3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00ooo
ool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?oooooo
oh3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?oooooooh3ooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3
o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00
ocGooooo0ol00?ooooooogoooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?leooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?oooooooh3ooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00ooooooooP?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?le
ooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00ocGooooo0ol00?oooooooh3ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o
oooooon0ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00ocGooooo0ol00?oooooooh3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08
ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00ocGooooo0ol00?ooooooogoooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo
0ol00?oooooooh3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00ooo
ool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?oooooo
oh3ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?leooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00Sooooo
000Aooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`004?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o=Oooool3o`00ooooooooP?ooool00ol0003oooooooooo`08ooooo`00
4?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo1?l00002ooooo`?o
0?l00ol00?leooooo`?o003ooooooommooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGo
oooo0ol00?oooooooh3ooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool3o`3o
00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`004Oooool2o`0000Wooooo0ol00007oooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oo
oooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o
00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool3o`3o00?o
003ooooooongooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o
oooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooo
okSooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`?o0?l00ol00?oooooookOo
oooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooo
oonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0
003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00oooooooo]oooool2o`0000[o
oooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonh
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo
00Sooooo000Vooooo`?o00000oooool3o`3o00?o003ooooooongooooo`;o00002_ooool002Kooooo
00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhoooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooo
oooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00ooo
ool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool0
1?l0003oooooooooooooool5o`0000;ooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`00
2_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool4o`0000;ooooo0ol0o`03o`00oooooooo]Oooool4o`0000[ooooo000:ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`00
2_ooool01?l0003oooooooooool00007ooooo`06o`000?ooooooooooooooool0003ooooo1?l00007
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`08
ooooo`002_ooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003ooooo
o`00000:ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooo
ooooo`08ooooo`002oooool2o`0000Wooooo0ol00002ooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool01_ooool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`06ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00Kooooo0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool01_ooool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`06ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000V
ooooo`?o00001_ooool3o`00oooooooo]oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo
00Kooooo0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooooooo
ool01_ooool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`06ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00Kooooo0ol00?oooooookSooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool01_ooool3o`00oooooooo^?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`06ooooo`?o003ooooooonhooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00001_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`009_ooooooo`000<Go00002_ooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool002gooooo0ol0000:ooooo`Go00002_ooool3o`0000cooooo0ol0000:oooo
o`?o00002oooool3o`0000cooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l00009oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol00004oooo
o`?o00000oooool3o`0000Gooooo0ol00004ooooo`?o00001?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool3o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00003oooo
o`?o00001Oooool3o`0000?ooooo0_l00005ooooo`Go00000oooool2o`0000Cooooo1Ol00002oooo
o`?o00001?ooool5o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo0ol00004oooo
o`Go00000oooool3o`0000?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go00000oooool00ol0003oooooooooo`03ooooo`Go00000_ooool3o`0000Cooooo1Ol00002oooo
o`;o00001_ooool3o`0000Cooooo0_l00005ooooo`?o00000oooool3o`0000Gooooo0ol00002oooo
o`Go00003_ooool002kooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00003_ooool002kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo1Ol0000=ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`00000@ooooo`00;_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`04o`000?oo
ooooooooo`0000kooooo00?o0000ooooooooool01oooool4o`0000gooooo00?o0000ooooooooool0
2Oooool3o`0000_ooooo1?l00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool4o`0000Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00006
ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool2o`0000Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`?o
00001oooool01?l0003oooooooooooooool4o`0000Gooooo0_l00003ooooo`04o`000?oooooooooo
o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooo
oooo00gooooo000^ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002_ooool4o`0000[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006oooo
o`04o`000?ooooooooooooooo`Co00001_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000Co
oooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Cooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Oooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00cooooo000]ooooo`;o00002oooool01Ol0003ooooooooo
oooooooo000000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00002_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000009oooo
o`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00Cooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`00
00Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`07o`000?oooooo
ooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2
o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;o00001Oooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooooooo`0<ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`?o00002ooo
ool3o`0000gooooo00?o0000ooooooooool02?ooool5o`0000_ooooo0_l0000:ooooo`Go00002_oo
ool3o`0000_ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o00001_oo
ool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00?ooooo
0_l00006ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`?o
00001_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool3o`0000Cooooo0_l00005ooooo`?o
00001?ooool00ol0003oooooooooo`04ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Gooooo00?o0000ooooooooool00oooool3o`0000;ooooo1Ol00004ooooo`?o
00001?ooool2o`0000Gooooo0ol00002ooooo`Go00001?ooool3o`0000?ooooo0ol00005ooooo`?o
00000oooool3o`0000Gooooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo00?o0000oooooooo
ool01?ooool3o`0000?ooooo0ol0000?ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-2.06768, -0.0213237, 0.0713992, \
0.00100229}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 1.01817 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11653 -18 -4.5 ]
[-0.0125 .11653 0 4.5 ]
[-0.0125 .21835 -18 -4.5 ]
[-0.0125 .21835 0 4.5 ]
[-0.0125 .32017 -18 -4.5 ]
[-0.0125 .32017 0 4.5 ]
[-0.0125 .42198 -18 -4.5 ]
[-0.0125 .42198 0 4.5 ]
[-0.0125 .5238 -18 -4.5 ]
[-0.0125 .5238 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11653 m
.00625 .11653 L
s
[(0.1)] -0.0125 .11653 1 0 Mshowa
0 .21835 m
.00625 .21835 L
s
[(0.2)] -0.0125 .21835 1 0 Mshowa
0 .32017 m
.00625 .32017 L
s
[(0.3)] -0.0125 .32017 1 0 Mshowa
0 .42198 m
.00625 .42198 L
s
[(0.4)] -0.0125 .42198 1 0 Mshowa
0 .5238 m
.00625 .5238 L
s
[(0.5)] -0.0125 .5238 1 0 Mshowa
.125 Mabswid
0 .03508 m
.00375 .03508 L
s
0 .05544 m
.00375 .05544 L
s
0 .07581 m
.00375 .07581 L
s
0 .09617 m
.00375 .09617 L
s
0 .1369 m
.00375 .1369 L
s
0 .15726 m
.00375 .15726 L
s
0 .17762 m
.00375 .17762 L
s
0 .19799 m
.00375 .19799 L
s
0 .23871 m
.00375 .23871 L
s
0 .25908 m
.00375 .25908 L
s
0 .27944 m
.00375 .27944 L
s
0 .2998 m
.00375 .2998 L
s
0 .34053 m
.00375 .34053 L
s
0 .36089 m
.00375 .36089 L
s
0 .38126 m
.00375 .38126 L
s
0 .40162 m
.00375 .40162 L
s
0 .44235 m
.00375 .44235 L
s
0 .46271 m
.00375 .46271 L
s
0 .48308 m
.00375 .48308 L
s
0 .50344 m
.00375 .50344 L
s
0 .54417 m
.00375 .54417 L
s
0 .56453 m
.00375 .56453 L
s
0 .58489 m
.00375 .58489 L
s
0 .60526 m
.00375 .60526 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11653 m
1 .11653 L
s
.99375 .21835 m
1 .21835 L
s
.99375 .32017 m
1 .32017 L
s
.99375 .42198 m
1 .42198 L
s
.99375 .5238 m
1 .5238 L
s
.125 Mabswid
.99625 .03508 m
1 .03508 L
s
.99625 .05544 m
1 .05544 L
s
.99625 .07581 m
1 .07581 L
s
.99625 .09617 m
1 .09617 L
s
.99625 .1369 m
1 .1369 L
s
.99625 .15726 m
1 .15726 L
s
.99625 .17762 m
1 .17762 L
s
.99625 .19799 m
1 .19799 L
s
.99625 .23871 m
1 .23871 L
s
.99625 .25908 m
1 .25908 L
s
.99625 .27944 m
1 .27944 L
s
.99625 .2998 m
1 .2998 L
s
.99625 .34053 m
1 .34053 L
s
.99625 .36089 m
1 .36089 L
s
.99625 .38126 m
1 .38126 L
s
.99625 .40162 m
1 .40162 L
s
.99625 .44235 m
1 .44235 L
s
.99625 .46271 m
1 .46271 L
s
.99625 .48308 m
1 .48308 L
s
.99625 .50344 m
1 .50344 L
s
.99625 .54417 m
1 .54417 L
s
.99625 .56453 m
1 .56453 L
s
.99625 .58489 m
1 .58489 L
s
.99625 .60526 m
1 .60526 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .04724 L
.01242 .04724 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .04724 L
.01242 .04724 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .01472 L
.04348 .01472 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .01472 L
.04348 .01472 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .0819 L
.07453 .0819 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .0819 L
.07453 .0819 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .01507 L
.10559 .01507 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .01507 L
.10559 .01507 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .14587 L
.13665 .14587 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .14587 L
.13665 .14587 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .01472 L
.1677 .01472 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .01472 L
.1677 .01472 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .01543 L
.19876 .01543 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .01543 L
.19876 .01543 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .01472 L
.22981 .01472 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .01472 L
.22981 .01472 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .08976 L
.26087 .08976 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .08976 L
.26087 .08976 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .01472 L
.29193 .01472 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .01472 L
.29193 .01472 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .1155 L
.32298 .1155 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .1155 L
.32298 .1155 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .01472 L
.35404 .01472 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .01472 L
.35404 .01472 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .15481 L
.38509 .15481 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .15481 L
.38509 .15481 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .01507 L
.41615 .01507 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .01507 L
.41615 .01507 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .01472 L
.4472 .01472 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .01472 L
.4472 .01472 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .01472 L
.47826 .01472 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .01472 L
.47826 .01472 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .07547 L
.50932 .07547 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .07547 L
.50932 .07547 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .01472 L
.54037 .01472 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .01472 L
.54037 .01472 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .13837 L
.57143 .13837 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .13837 L
.57143 .13837 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .01472 L
.60248 .01472 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .01472 L
.60248 .01472 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .128 L
.63354 .128 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .128 L
.63354 .128 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .01472 L
.6646 .01472 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .01472 L
.6646 .01472 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .01472 L
.69565 .01472 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .01472 L
.69565 .01472 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .01472 L
.72671 .01472 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .01472 L
.72671 .01472 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .0819 L
.75776 .0819 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .0819 L
.75776 .0819 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .01472 L
.78882 .01472 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .01472 L
.78882 .01472 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .01507 L
.81988 .01507 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .01507 L
.81988 .01507 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .11943 L
.88199 .11943 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .11943 L
.88199 .11943 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .01472 L
.9441 .01472 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .01472 L
.9441 .01472 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .01472 L
.04969 .01472 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .01472 L
.04969 .01472 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .09655 L
.08075 .09655 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .09655 L
.08075 .09655 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .01507 L
.1118 .01507 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .01507 L
.1118 .01507 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .04295 L
.14286 .04295 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .04295 L
.14286 .04295 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .01507 L
.17391 .01507 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .01507 L
.17391 .01507 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .01507 L
.20497 .01507 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .01507 L
.20497 .01507 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .01472 L
.23602 .01472 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .01472 L
.23602 .01472 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .08155 L
.26708 .08155 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .08155 L
.26708 .08155 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .01472 L
.29814 .01472 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .01472 L
.29814 .01472 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .01579 L
.32919 .01579 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .01579 L
.32919 .01579 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .01472 L
.36025 .01472 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .01472 L
.36025 .01472 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .06117 L
.3913 .06117 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .06117 L
.3913 .06117 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .01507 L
.42236 .01507 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .01507 L
.42236 .01507 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .01472 L
.45342 .01472 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .01472 L
.45342 .01472 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .09691 L
.51553 .09691 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .09691 L
.51553 .09691 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .02186 L
.57764 .02186 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .02186 L
.57764 .02186 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .06832 L
.63975 .06832 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .06832 L
.63975 .06832 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .01472 L
.70186 .01472 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .01472 L
.70186 .01472 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .07297 L
.76398 .07297 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .07297 L
.76398 .07297 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .01472 L
.82609 .01472 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .01472 L
.82609 .01472 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .01722 L
.8882 .01722 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .01722 L
.8882 .01722 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .331 L
.02484 .331 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .331 L
.02484 .331 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .01472 L
.0559 .01472 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .01472 L
.0559 .01472 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .13301 L
.08696 .13301 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .13301 L
.08696 .13301 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .01472 L
.11801 .01472 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .01472 L
.11801 .01472 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .07047 L
.14907 .07047 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .07047 L
.14907 .07047 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .01472 L
.18012 .01472 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .01472 L
.18012 .01472 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .01472 L
.21118 .01472 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .01472 L
.21118 .01472 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .01472 L
.24224 .01472 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .01472 L
.24224 .01472 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .11478 L
.27329 .11478 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .11478 L
.27329 .11478 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .01472 L
.30435 .01472 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .01472 L
.30435 .01472 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .019 L
.3354 .019 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .019 L
.3354 .019 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .01472 L
.36646 .01472 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .10227 L
.39752 .10227 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .10227 L
.39752 .10227 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .01472 L
.42857 .01472 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .01472 L
.42857 .01472 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .01472 L
.45963 .01472 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .14301 L
.52174 .14301 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .14301 L
.52174 .14301 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .03473 L
.58385 .03473 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .03473 L
.58385 .03473 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .01472 L
.61491 .01472 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .01472 L
.61491 .01472 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .0937 L
.64596 .0937 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .0937 L
.64596 .0937 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .01472 L
.67702 .01472 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .01472 L
.73913 .01472 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .11836 L
.77019 .11836 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .11836 L
.77019 .11836 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .01472 L
.80124 .01472 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .01972 L
.89441 .01972 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .01972 L
.89441 .01972 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .06868 L
.06211 .06868 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .06868 L
.06211 .06868 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .01472 L
.09317 .01472 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .01472 L
.09317 .01472 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .06868 L
.12422 .06868 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .06868 L
.12422 .06868 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .02043 L
.15528 .02043 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .02043 L
.15528 .02043 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .06939 L
.18634 .06939 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .06939 L
.18634 .06939 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .06439 L
.21739 .06439 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .06439 L
.21739 .06439 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .07475 L
.24845 .07475 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .07475 L
.24845 .07475 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .01579 L
.2795 .01579 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .01579 L
.2795 .01579 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .07618 L
.31056 .07618 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .07618 L
.31056 .07618 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .03223 L
.34161 .03223 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .03223 L
.34161 .03223 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .06117 L
.37267 .06117 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .06117 L
.37267 .06117 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .01472 L
.40373 .01472 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .01472 L
.40373 .01472 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .07118 L
.43478 .07118 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .07118 L
.43478 .07118 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .06868 L
.46584 .06868 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .06868 L
.46584 .06868 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .07618 L
.49689 .07618 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .07618 L
.49689 .07618 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .01472 L
.52795 .01472 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .01472 L
.52795 .01472 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .05689 L
.55901 .05689 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .05689 L
.55901 .05689 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .02722 L
.59006 .02722 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .02722 L
.59006 .02722 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .05045 L
.62112 .05045 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .05045 L
.62112 .05045 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .01722 L
.65217 .01722 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .01722 L
.65217 .01722 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .05224 L
.68323 .05224 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .05224 L
.68323 .05224 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .04223 L
.71429 .04223 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .04223 L
.71429 .04223 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .05188 L
.74534 .05188 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .05188 L
.74534 .05188 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .01793 L
.7764 .01793 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .01793 L
.7764 .01793 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .04652 L
.80745 .04652 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .04652 L
.80745 .04652 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .06725 L
.83851 .06725 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .06725 L
.83851 .06725 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .04545 L
.86957 .04545 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .04545 L
.86957 .04545 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .02722 L
.90062 .02722 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .02722 L
.90062 .02722 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .04581 L
.93168 .04581 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .04581 L
.93168 .04581 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .05653 L
.96273 .05653 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .05653 L
.96273 .05653 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .0576 L
.99379 .0576 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .0576 L
.99379 .0576 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:_ooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000Aoooo
o`00:oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Aooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool04?ooool0
02_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03oooool002[ooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0001;ooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=
ooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000I
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l5oomo0004o`000?oo
003oo`00ool000?o0?l00_l00?l4oomo00;o00000ooo0003o`3o00;o003o1OooO`001?l0003oo`00
ool00?oo0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l00003ool000?o
0?l00_l00?l4oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?o
ogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?o
o`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o
003o1?ooO`001?l0003oo`00ool00?oo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00
o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o1?ooO`001?l0
003oo`00ool00?oo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003
ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03
o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02
o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003
o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3
oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003
ool000?o0?l00ol00?l3oomo00?o00003Oooool001Wooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`03ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=
ooooo`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00[ooooo1?ooO`0;ooooo`?oogl02oooool3
oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;
ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02
ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3
oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl02oooool3oomo00_ooooo0oooO`02
ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3
ool000?o0?l00ol00?l3oomo00_ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000
ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3
ool000?o0?l00_l00?l4oomo00[ooooo1?ooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003
o`3o00Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool3
ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04
o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00;ooooo0ooo0003
o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=
ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3
oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`00
00Oooooo00?o0000ooooooooool00ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o
00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;oooo
o`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;oooo
o`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02oooo
o`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo
00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool0
00?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo
00_ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool00ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o
003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?o
ogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?o
ogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?o
o`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;o
oooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o
0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00_o
oooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o
3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?oogl0
0_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl0
0_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`00
0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo
0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo
0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Ooo
ool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?oogl00_oo
ool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_oo
ool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0
o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`?oo`000ol0
o`04o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Ooo
ool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl02ooo
ool3oomo00;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo0003
o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003
o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=
ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02
ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0;
ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;
ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo0003o`3o00?o003o3Oooool4oomo
00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo
00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00Gooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo
00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00
o`gooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo
00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool0
01?ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo00?o0000ooooooooool02oooool002?o
oooo0ol00003ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Co
ogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl02oooool3oomo00_ooooo0oooO`02ooooo`?o
o`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co
003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000;ooooo1?l00?l=ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?o
ogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0;ooooo`?o
ogl02oooool3oomo00;ooooo1?oo000Cooooo`?oogl02oooool3oomo00_ooooo0oooO`000ooooooo
0000o`00000=ooooo`008oooool00ol0003oooooooooo`03ool000?o0?l00ol00?l=ooooo`Coogl0
0_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl0
2oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
4oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl0
0_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`?oo`00
0ol0o`04o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o
3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl0
2oooool3oomo00;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo
0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo
0003o`3o00?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l0
0?l=ooooo`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0ooo
O`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo
000Cooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0ooo
O`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo1?oo
000Cooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03
o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`0;ooooo`?oogl02oooool3
oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool3
ool000?o0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04
o`00o`gooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3
oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02oooool3
oomo00_ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ool000?o0?l00ol00?l=oooo
o`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=oooo
o`Coogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02oooo
o`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;oooo
o`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001?ooooo0oooO`02oooo
o`?oo`000ol0o`04o`00o`gooooo0oooO`0Iooooo`?oogl00_ooool3ool000?o0?l01?l00?l=oooo
o`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`0;oooo
o`?oogl00_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ool000?o
0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000;o
oooo0ol00?l=ooooo`Coogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`go
oooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_o
oooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001?o
oooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0Iooooo`?oogl00_ooool3ool000?o
0?l01?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`004oooool3oomo00_o
oooo0oooO`0;ooooo`?oogl00_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl0
0_ooool4ool000;ooooo0ol00?l=ooooo`Coogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`00
0ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co003o
3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl0
0_ooool4ool001?ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0Iooooo`?oogl0
0_ooool3ool000?o0?l01?l00?lKooooo`?oogl04?ooool4ool0027ooooo0oooO`0;ooooo`?oogl0
0_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000;ooooo0ol0
0?l=ooooo`Coogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0ooo
O`02ooooo`Coo`004oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0ooo
O`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001?ooooo0ooo
O`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0Iooooo`?oogl00_ooool3ool000?o0?l01?l0
0?lKooooo`?oogl04?ooool4ool0027ooooo0oooO`0;ooooo`?oogl00_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l=ooooo`Coogl00_ooool3
ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000;ooooo0ol00?l=ooooo`Coogl02oooool3
oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`004oooool3
oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3
ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001Sooooo0ooo0003o`3o00Co003o3Oooool3
oomo01Wooooo0oooO`02ooooo`?oo`000ol0o`04o`00oa_ooooo0oooO`0@ooooo`Coo`008Oooool3
oomo00_ooooo0oooO`02ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool3o`3o
00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002oooo
o`?o003o3Oooool4oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=oooo
o`?oogl00_ooool4ool001?ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`0;oooo
o`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Hoooo
o`?oo`000ol0o`04o`00obkooooo0ooo0003o`3o00Co003o6oooool3oomo013ooooo1?oo000Qoooo
o`?oogl02oooool3oomo0003ooooool0003o000000gooooo000Sooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Co
o`000_ooool3o`00o`gooooo1?ooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co
003o3Oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?o
ogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Co
o`006?ooool3ool000?o0?l01?l00?l^ooooo`?oo`000ol0o`04o`00oa_ooooo0oooO`0@ooooo`Co
o`008Oooool3oomo00_ooooo0oooO`02ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo
1?ooO`02ooooo`Coo`000_ooool3o`00o`gooooo1?ooO`0;ooooo`?oogl02oooool3oomo00;ooooo
0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00oa;ooooo
1?oo000Hooooo`?oo`000ol0o`04o`00obkooooo0ooo0003o`3o00Co003o6oooool3oomo013ooooo
1?oo000dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`000_oo
ool3o`00o`gooooo1?ooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Ooo
ool3oomo00;ooooo1?oo000Cooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl02ooo
ool3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00oa;ooooo1?oo000Hooooo`?oo`000ol0
o`04o`00obkooooo0ooo0003o`3o00Co003o6oooool3oomo013ooooo1?oo000dooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02
ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`000_ooool3o`00o`gooooo1?ooO`0;
ooooo`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000H
ooooo`Coo`000_ooool4o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo0ooo0003
o`3o00Co003o4_ooool4ool001Sooooo0ooo0003o`3o00Co003o;_ooool3ool000?o0?l01?l00?lK
ooooo`?oogl04?ooool4ool003Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo
00;ooooo1?oo0002ooooo`?o003o3Oooool4oomo01Wooooo0oooO`02ooooo`?oo`000ol0o`04o`00
o`gooooo0oooO`02ooooo`Coo`006?ooool4ool000;ooooo1?l00?l=ooooo`?oogl02oooool3oomo
00_ooooo0oooO`02ooooo`?oo`000ol0o`04o`00oa;ooooo1?oo000Hooooo`?oo`000ol0o`04o`00
obkooooo0ooo0003o`3o00Co003o6oooool3oomo013ooooo1?oo000dooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`gooooo1?ooO`02ooooo`?o
o`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`000_ooool3o`00o`gooooo1?ooO`0Iooooo`?o
ogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001Sooooo1?oo0002ooooo`Co
003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l01?l00?lBooooo`Co
o`006?ooool3ool000?o0?l01?l00?l^ooooo`?oo`000ol0o`04o`00obkooooo1?oo000dooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oa?ooooo
0ooo0003o`3o00?o003o4oooool4ool000;ooooo0ol00?lZooooo`?oogl00_ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool001Sooooo1?oo0002ooooo`Co003o3Oooool3oomo01Wooooo
0oooO`02ooooo`?oo`000ol0o`04o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00obkooooo
0ooo0003o`3o00Co003o;_ooool4ool003Cooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool3o`3o00?o003o4oooool3ool000?o0?l00ol00?lCooooo`Coo`00;ooo
ool3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Hooooo`Coo`000_oo
ool4o`00obWooooo0oooO`02ooooo`?oo`000ol0o`04o`00oa;ooooo1?oo000Hooooo`Coo`000_oo
ool4o`00obkooooo0ooo0003o`3o00Co003o;_ooool4ool003Cooooo00?o0000ooooooooool02ooo
ool002?ooooo0ol00003ooooo`?o0?l00ol00?lCooooo`?oo`000ol0o`03o`00oa?ooooo1?oo000_
ooooo`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool001Sooooo1?oo0002
ooooo`Co003o:Oooool3oomo00;ooooo0ooo0003o`3o00Co003o4_ooool4ool001Sooooo1?oo0002
ooooo`Co003o;_ooool4ool000;ooooo1?l00?l^ooooo`Coo`00<oooool2o`0000gooooo000Soooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00oa?ooooo0ooo0003o`3o00?o003o4oooool4ool0
03Cooooo0ooo0003o`3o00Co003o4_ooool4ool001Sooooo1?oo0002ooooo`Co003o<Oooool3o`3o
00Co003o4_ooool4ool001Sooooo1?oo0002ooooo`Co003o;_ooool4ool000;ooooo1?l00?l^oooo
o`Coo`00=?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?lCooooo`?oo`000ol0o`03o`00oa?ooooo1?oo000dooooo`?oo`000ol0o`04o`00oa;o
oooo1?oo000Hooooo`Coo`000_ooool4o`00oc7ooooo0ol0o`04o`00oa;ooooo1?oo000Hooooo`Co
o`000_ooool4o`00obkooooo1?oo0002ooooo`Co003o;_ooool4ool003Cooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o4oooool3ool000?o0?l0
0ol00?lCooooo`Coo`00=?ooool3ool000?o0?l01?l00?lBooooo`Coo`006?ooool4ool000;ooooo
1?l00?laooooo`?o0?l01?l00?lBooooo`Coo`006?ooool4ool000;ooooo1?l00?l^ooooo`Coo`00
0_ooool4o`00obkooooo1?oo000dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00oaKooooo0ol0o`03o`00oa?ooooo1?oo000dooooo`Coo`000_oo
ool4o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00oc7ooooo0ol0o`04o`00oa;ooooo1?oo
000Hooooo`Coo`000_ooool4o`00ocCooooo1?l00?l^ooooo`Coo`00=?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`?o0?l00ol00?lC
ooooo`Coo`00=?ooool4ool000;ooooo1?l00?lBooooo`Coo`006?ooool4ool000;ooooo1?l00?la
ooooo`?o0?l01?l00?lBooooo`Coo`006?ooool4ool000;ooooo1?l00?ldooooo`Co003o;_ooool4
ool003Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o
00?o003o5_ooool3o`3o00?o003o4oooool4ool003Cooooo1?oo0002ooooo`Co003o4_ooool4ool0
01Sooooo1?oo0002ooooo`Co003o<Oooool3o`3o00Co003o4_ooool4ool001Sooooo1?oo0002oooo
o`Co003o=?ooool4o`00obkooooo1?oo000dooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oaKooooo0ol0o`03o`00oa?ooooo1?oo000dooooo`Co
o`000_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00oc7ooooo0ol0o`04o`00oa;o
oooo1?oo000Hooooo`Coo`000_ooool4o`00ocCooooo1?l00?l^ooooo`Coo`00=?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lFooooo`?o0?l0
0ol00?lCooooo`Coo`00>_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00oc7ooooo
0ol0o`04o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00ocCooooo1?l00?l^ooooo`Coo`00
=?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?lFooooo`?o0?l00ol00?lCooooo`Coo`00>_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`000_oo
ool4o`00oc7ooooo0ol0o`04o`00oa;ooooo1?oo000Hooooo`Coo`00>_ooool4o`00obkooooo1?oo
000dooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool3o`3o00?o003o5_ooool3
o`3o00?o003o4oooool4ool003[ooooo1?l00?lBooooo`Coo`006?ooool4ool000;ooooo1?l00?la
ooooo`?o0?l01?l00?lBooooo`Coo`006?ooool4ool003[ooooo1?l00?l^ooooo`Coo`00<oooool2
o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaWooooo0ol00?lCoooo
o`Coo`00>_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`000_ooool4o`00ocCooooo1?l00?lBoooo
o`Coo`006?ooool4ool003[ooooo1?l00?l^ooooo`Coo`00=?ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lIooooo`?o003o4oooool4ool003[o
oooo1?l00?lBooooo`Coo`006?ooool4ool000;ooooo1?l00?ldooooo`Co003o4_ooool4ool001So
oooo1?oo000jooooo`Co003o;_ooool4ool003Cooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool3o`3o00?o003o6Oooool3o`00oa?ooooo1?oo000jooooo`Co003o
4_ooool4ool001Sooooo1?oo000jooooo`Co003o4_ooool4ool001Sooooo1?oo000jooooo`Co003o
;_ooool4ool003Cooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo
ool3o`3o00?o003o6Oooool3o`00oa?ooooo1?oo000jooooo`Co003o4_ooool4ool001Sooooo1?oo
000jooooo`Co003o4_ooool4ool001Sooooo1?oo000jooooo`Co003o;_ooool4ool003Cooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o6Oooool3
o`00oa?ooooo1?oo000jooooo`Co003o4_ooool4ool001Sooooo1?oo000jooooo`Co003o4_ooool4
ool001Sooooo1?oo000jooooo`Co003o;_ooool4ool003Cooooo00?o0000ooooooooool02oooool0
00kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00oaWooooo0ol00?lCooooo`Coo`00>_ooool4o`00oa;ooooo1?oo000Hoooo
o`Coo`00>_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`00>_ooool4o`00obkooooo1?oo000doooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lIooooo`?o003o4oooool4ool0
03[ooooo1?l00?lBooooo`Coo`006?ooool4ool003[ooooo1?l00?lBooooo`Coo`006?ooool4ool0
03[ooooo1?l00?l^ooooo`Coo`00=?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`3o
00?o003o6Oooool3o`00oa?ooooo1?oo000jooooo`Co003o4_ooool4ool001Sooooo1?oo000joooo
o`Co003o4_ooool4ool001Sooooo1?oo000jooooo`Co003o;_ooool4ool003Cooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06oooo
o`Co00000_ooool3o`3o00?o003o6Oooool3o`00oa?ooooo1?oo001/ooooo`Coo`00>_ooool4o`00
oa;ooooo1?oo000Hooooo`Coo`00>_ooool4o`00obkooooo1?oo000aooooo`Co00003Oooool000go
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00oaWooooo0ol00?lCooooo`Coo`00K?ooool4ool003[ooooo1?l00?lBoooo
o`Coo`006?ooool4ool003[ooooo1?l00?l^ooooo`Coo`00=?ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?lIooooo`?o003o4oooool4ool006cooooo1?oo000jooooo`Co003o4_ooool4ool0
01Sooooo1?oo002Tooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaWooooo0ol00?lCooooo`Co
o`00K?ooool4ool003[ooooo1?l00?lBooooo`Coo`006?ooool4ool00:Cooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o6Oooool3o`00oa?ooooo
1?oo001/ooooo`Coo`00>_ooool4o`00oa;ooooo1?oo000Hooooo`Coo`00Y?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lIooooo`?o003o4ooo
ool4ool006cooooo1?oo000jooooo`Co003o4_ooool4ool001Sooooo1?oo002Tooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oaWooooo0ol00?lC
ooooo`Coo`00K?ooool4ool003[ooooo1?l00?lBooooo`Coo`00`?ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lIooooo`?o003o4oooool4ool0
06cooooo1?oo000jooooo`Co003o4_ooool4ool00<3ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool00oooool3o`3o00?o003o;oooool4ool006cooooo1?oo000jooooo`Co
003o4_ooool4ool00<3ooooo00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`?o0?l0
0ol00?l_ooooo`Coo`00K?ooool4ool003[ooooo1?l00?lBooooo`Coo`00_oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oboooooo1?oo001/ooooo`Coo`00>_oo
ool4o`00oa;ooooo1?oo0030ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00?ooooo0ol0o`03o`00oboooooo1?oo001/ooooo`Coo`00>_ooool4o`00omKooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o;oooool4ool0
06cooooo1?oo000jooooo`Co003oe_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?l_ooooo`Coo`00K?ooool4ool00?oooooo5Oooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?nOooooo`Coo`00
oooooolEooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oioooooo1?oo003ooooooaGooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool3o`3o00?o003oWoooool4ool00?oooooo5Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?nOooooo`Coo`00oooooolEoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool3o`3o00?o003ooooooongooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oo
oooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o
00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;
ooooo`008oooool3o`0000?ooooo0ol0o`03o`00oooooooo]oooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooo
okSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o
003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo0ol00003
ooooo`?o0?l00ol00?oooooookOooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00006oooo
o`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;oooo
o`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`05ooooo`Co00000_ooool3o`3o00?o003ooooooone
ooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`?o00000oooool3o`3o00?o003ooooooongooooo`;o00003Oooool0
02?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooo
oonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0000?ooooo0ol0o`03o`00oooooooo]oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonh
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o
0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`?o0?l0
0ol00?oooooookOooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol0
0?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3
o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool3o`3o00?o003ooooooongooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?oo
oooookSooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o
00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?oooooookSooooo00?o0000ooooooooool02oooool000kooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00oooooooo^?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oooooookSooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo
^?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o0000
1oooool4o`0000;ooooo0ol0o`03o`00oooooooo]Oooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?oooooookSooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool3o`3o00?o
003ooooooonhooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002Oooool3o`0000Oooooo
00?o0000ooooooooool00oooool3o`3o00?o003ooooooonhooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oooooooo^?ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02oooool002?ooooo0ol00003ooooo`Co0?l0ooooooniooooo`;o00003Oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
1Ol00006ooooo`Co00000_ooool4o`3o0?oooooo]oooool4o`0000gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`Co
0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool000kooooo
0_l0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3o
oooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o
0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co
0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`Co0?l0oooo
ooniooooo`;o00003Oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3o
oooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o
0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co
0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oooooo
^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3o
oooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o
0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooookWo
oooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3o
oooook[ooooo00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`Co0?l0oooooonioooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjoooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo1?l00002ooooo`Co
0?l0oooooongooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Oooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Sooooo1Ol00006ooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo
000Sooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000Sooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?o
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`00
8oooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?o
oooo0ol00003ooooo`Co0?l0ooooooniooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o0000ooooooo0ooooo`;o00003Oooool002?ooooo00?o0000ooooooooool0ooooooo1ooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`008oooooooo`000<Go00003Oooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool002[ooooo0ol0000:ooooo`Go00002_ooool3o`0000cooooo0ol0000:
ooooo`?o00002oooool3o`0000cooooo00?o0000ooooooooool02_ooool3o`0000_ooooo0_l00009
ooooo`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol00004
ooooo`?o00000oooool3o`0000Gooooo0ol00004ooooo`?o00001?ooool3o`0000?ooooo0ol00005
ooooo`?o00000oooool3o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00003
ooooo`?o00001Oooool3o`0000?ooooo0_l00005ooooo`Go00000oooool2o`0000Cooooo1Ol00002
ooooo`?o00001?ooool5o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo0ol00004
ooooo`Go00000oooool3o`0000?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0ol00004
ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`Go00000_ooool3o`0000Cooooo1Ol00002
ooooo`;o00001_ooool3o`0000Cooooo0_l00005ooooo`?o00000oooool3o`0000Gooooo0ol00002
ooooo`Go00004Oooool002_ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00004Oooool002_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo1Ol0000=ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`00000Cooooo`00
:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000kooooo00?o0000ooooooooool01oooool4o`0000gooooo00?o0000oooooooo
ool02Oooool3o`0000_ooooo1?l00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool4o`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol0
0006ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool2o`0000Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`?o00001oooool01?l0003oooooooooooooool4o`0000Gooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oo
oooooooo013ooooo000[ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002_ooool4o`0000[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006
ooooo`04o`000?ooooooooooooooo`Co00001_ooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`07o`000?oooooooooooooo
ool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`00
00Cooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Cooooo00Oo0000oooooooooooooooo
o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00oooooo000Zooooo`;o00002oooool01Ol0003ooooo
oooooooooooo000000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00002_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000009
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo
0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000Cooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool2o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;o00001Oooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0:ooooo`?o0000
2oooool3o`0000gooooo00?o0000ooooooooool02?ooool5o`0000_ooooo0_l0000:ooooo`Go0000
2_ooool3o`0000_ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00?o
oooo0_l00006ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02oooo
o`?o00001_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool3o`0000Cooooo0_l00005oooo
o`?o00001?ooool00ol0003oooooooooo`04ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Gooooo00?o0000ooooooooool00oooool3o`0000;ooooo1Ol00004oooo
o`?o00001?ooool2o`0000Gooooo0ol00002ooooo`Go00001?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool3o`0000Gooooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo00?o0000oooo
ooooool01?ooool3o`0000?ooooo0ol0000Booooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-1.85349, -0.0463328, 0.0713992, \
0.0021778}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 1.64566 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .097 -24 -4.5 ]
[-0.0125 .097 0 4.5 ]
[-0.0125 .17928 -18 -4.5 ]
[-0.0125 .17928 0 4.5 ]
[-0.0125 .26156 -24 -4.5 ]
[-0.0125 .26156 0 4.5 ]
[-0.0125 .34385 -18 -4.5 ]
[-0.0125 .34385 0 4.5 ]
[-0.0125 .42613 -24 -4.5 ]
[-0.0125 .42613 0 4.5 ]
[-0.0125 .50841 -18 -4.5 ]
[-0.0125 .50841 0 4.5 ]
[-0.0125 .5907 -24 -4.5 ]
[-0.0125 .5907 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .097 m
.00625 .097 L
s
[(0.05)] -0.0125 .097 1 0 Mshowa
0 .17928 m
.00625 .17928 L
s
[(0.1)] -0.0125 .17928 1 0 Mshowa
0 .26156 m
.00625 .26156 L
s
[(0.15)] -0.0125 .26156 1 0 Mshowa
0 .34385 m
.00625 .34385 L
s
[(0.2)] -0.0125 .34385 1 0 Mshowa
0 .42613 m
.00625 .42613 L
s
[(0.25)] -0.0125 .42613 1 0 Mshowa
0 .50841 m
.00625 .50841 L
s
[(0.3)] -0.0125 .50841 1 0 Mshowa
0 .5907 m
.00625 .5907 L
s
[(0.35)] -0.0125 .5907 1 0 Mshowa
.125 Mabswid
0 .03117 m
.00375 .03117 L
s
0 .04763 m
.00375 .04763 L
s
0 .06409 m
.00375 .06409 L
s
0 .08054 m
.00375 .08054 L
s
0 .11345 m
.00375 .11345 L
s
0 .12991 m
.00375 .12991 L
s
0 .14637 m
.00375 .14637 L
s
0 .16282 m
.00375 .16282 L
s
0 .19574 m
.00375 .19574 L
s
0 .21219 m
.00375 .21219 L
s
0 .22865 m
.00375 .22865 L
s
0 .24511 m
.00375 .24511 L
s
0 .27802 m
.00375 .27802 L
s
0 .29448 m
.00375 .29448 L
s
0 .31093 m
.00375 .31093 L
s
0 .32739 m
.00375 .32739 L
s
0 .3603 m
.00375 .3603 L
s
0 .37676 m
.00375 .37676 L
s
0 .39322 m
.00375 .39322 L
s
0 .40967 m
.00375 .40967 L
s
0 .44259 m
.00375 .44259 L
s
0 .45904 m
.00375 .45904 L
s
0 .4755 m
.00375 .4755 L
s
0 .49196 m
.00375 .49196 L
s
0 .52487 m
.00375 .52487 L
s
0 .54133 m
.00375 .54133 L
s
0 .55778 m
.00375 .55778 L
s
0 .57424 m
.00375 .57424 L
s
0 .60715 m
.00375 .60715 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .097 m
1 .097 L
s
.99375 .17928 m
1 .17928 L
s
.99375 .26156 m
1 .26156 L
s
.99375 .34385 m
1 .34385 L
s
.99375 .42613 m
1 .42613 L
s
.99375 .50841 m
1 .50841 L
s
.99375 .5907 m
1 .5907 L
s
.125 Mabswid
.99625 .03117 m
1 .03117 L
s
.99625 .04763 m
1 .04763 L
s
.99625 .06409 m
1 .06409 L
s
.99625 .08054 m
1 .08054 L
s
.99625 .11345 m
1 .11345 L
s
.99625 .12991 m
1 .12991 L
s
.99625 .14637 m
1 .14637 L
s
.99625 .16282 m
1 .16282 L
s
.99625 .19574 m
1 .19574 L
s
.99625 .21219 m
1 .21219 L
s
.99625 .22865 m
1 .22865 L
s
.99625 .24511 m
1 .24511 L
s
.99625 .27802 m
1 .27802 L
s
.99625 .29448 m
1 .29448 L
s
.99625 .31093 m
1 .31093 L
s
.99625 .32739 m
1 .32739 L
s
.99625 .3603 m
1 .3603 L
s
.99625 .37676 m
1 .37676 L
s
.99625 .39322 m
1 .39322 L
s
.99625 .40967 m
1 .40967 L
s
.99625 .44259 m
1 .44259 L
s
.99625 .45904 m
1 .45904 L
s
.99625 .4755 m
1 .4755 L
s
.99625 .49196 m
1 .49196 L
s
.99625 .52487 m
1 .52487 L
s
.99625 .54133 m
1 .54133 L
s
.99625 .55778 m
1 .55778 L
s
.99625 .57424 m
1 .57424 L
s
.99625 .60715 m
1 .60715 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .03204 L
.01242 .03204 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .03204 L
.01242 .03204 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .04533 L
.04348 .04533 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .04533 L
.04348 .04533 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .13197 L
.07453 .13197 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .13197 L
.07453 .13197 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .0176 L
.10559 .0176 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .0176 L
.10559 .0176 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .16836 L
.13665 .16836 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .16836 L
.13665 .16836 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .01645 L
.1677 .01645 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .01645 L
.1677 .01645 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .13948 L
.19876 .13948 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .13948 L
.19876 .13948 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .05111 L
.22981 .05111 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .05111 L
.22981 .05111 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .08345 L
.26087 .08345 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .08345 L
.26087 .08345 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .0332 L
.29193 .0332 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .0332 L
.29193 .0332 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .12331 L
.32298 .12331 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .12331 L
.32298 .12331 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .01645 L
.35404 .01645 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .01645 L
.35404 .01645 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .17183 L
.38509 .17183 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .17183 L
.38509 .17183 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .01472 L
.41615 .01472 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .01472 L
.41615 .01472 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .02511 L
.4472 .02511 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .02511 L
.4472 .02511 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .01587 L
.47826 .01587 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .01587 L
.47826 .01587 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .14757 L
.50932 .14757 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .14757 L
.50932 .14757 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .01529 L
.54037 .01529 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .01529 L
.54037 .01529 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .15797 L
.57143 .15797 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .15797 L
.57143 .15797 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .01529 L
.60248 .01529 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .01529 L
.60248 .01529 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .22035 L
.63354 .22035 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .22035 L
.63354 .22035 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .01529 L
.6646 .01529 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .01529 L
.6646 .01529 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .23941 L
.69565 .23941 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .23941 L
.69565 .23941 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .01529 L
.72671 .01529 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .01529 L
.72671 .01529 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .09501 L
.75776 .09501 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .09501 L
.75776 .09501 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .01472 L
.78882 .01472 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .01472 L
.78882 .01472 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .01991 L
.81988 .01991 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .01991 L
.81988 .01991 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .01472 L
.85093 .01472 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .01529 L
.88199 .01529 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .01529 L
.88199 .01529 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .01472 L
.91304 .01472 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .01472 L
.9441 .01472 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .01472 L
.9441 .01472 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .01472 L
.97516 .01472 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .06324 L
.04969 .06324 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .06324 L
.04969 .06324 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .20707 L
.08075 .20707 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .20707 L
.08075 .20707 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .01472 L
.1118 .01472 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .01472 L
.1118 .01472 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .14584 L
.14286 .14584 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .14584 L
.14286 .14584 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .01472 L
.17391 .01472 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .01472 L
.17391 .01472 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .04995 L
.20497 .04995 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .04995 L
.20497 .04995 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .02916 L
.23602 .02916 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .02916 L
.23602 .02916 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .2527 L
.26708 .2527 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .2527 L
.26708 .2527 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .0228 L
.29814 .0228 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .0228 L
.29814 .0228 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .03493 L
.32919 .03493 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .03493 L
.32919 .03493 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .01472 L
.36025 .01472 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .01472 L
.36025 .01472 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .03609 L
.3913 .03609 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .03609 L
.3913 .03609 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .01529 L
.42236 .01529 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .01529 L
.42236 .01529 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .02107 L
.45342 .02107 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .02107 L
.45342 .02107 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .01934 L
.48447 .01934 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .01934 L
.48447 .01934 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .23595 L
.51553 .23595 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .23595 L
.51553 .23595 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .04533 L
.57764 .04533 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .04533 L
.57764 .04533 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .02222 L
.6087 .02222 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .02222 L
.6087 .02222 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .05053 L
.63975 .05053 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .05053 L
.63975 .05053 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .02685 L
.70186 .02685 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .02685 L
.70186 .02685 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .03782 L
.76398 .03782 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .03782 L
.76398 .03782 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .01529 L
.82609 .01529 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .01529 L
.82609 .01529 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .01529 L
.8882 .01529 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .01529 L
.8882 .01529 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .01934 L
.95031 .01934 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .01934 L
.95031 .01934 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .06381 L
.02484 .06381 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .06381 L
.02484 .06381 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .08981 L
.0559 .08981 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .08981 L
.0559 .08981 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .10714 L
.08696 .10714 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .10714 L
.08696 .10714 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .03493 L
.11801 .03493 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .03493 L
.11801 .03493 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .10829 L
.14907 .10829 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .10829 L
.14907 .10829 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .028 L
.18012 .028 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .028 L
.18012 .028 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .08576 L
.21118 .08576 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .08576 L
.21118 .08576 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .08807 L
.24224 .08807 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .08807 L
.24224 .08807 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .07652 L
.27329 .07652 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .07652 L
.27329 .07652 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .04995 L
.30435 .04995 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .04995 L
.30435 .04995 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .06381 L
.3354 .06381 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .06381 L
.3354 .06381 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .03435 L
.36646 .03435 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .03435 L
.36646 .03435 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .08692 L
.39752 .08692 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .08692 L
.39752 .08692 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .05861 L
.42857 .05861 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .05861 L
.42857 .05861 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .06324 L
.45963 .06324 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .06324 L
.45963 .06324 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .10598 L
.49068 .10598 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .10598 L
.49068 .10598 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .10309 L
.52174 .10309 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .10309 L
.52174 .10309 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .0176 L
.5528 .0176 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .0176 L
.5528 .0176 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .08172 L
.58385 .08172 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .08172 L
.58385 .08172 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .07421 L
.61491 .07421 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .07421 L
.61491 .07421 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .07999 L
.64596 .07999 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .07999 L
.64596 .07999 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .0176 L
.67702 .0176 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .0176 L
.67702 .0176 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .09212 L
.70807 .09212 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .09212 L
.70807 .09212 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .02685 L
.73913 .02685 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .02685 L
.73913 .02685 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .09154 L
.77019 .09154 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .09154 L
.77019 .09154 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .02685 L
.80124 .02685 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .02685 L
.80124 .02685 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .04244 L
.8323 .04244 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .04244 L
.8323 .04244 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .07306 L
.86335 .07306 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .07306 L
.86335 .07306 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .03031 L
.89441 .03031 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .03031 L
.89441 .03031 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .05919 L
.92547 .05919 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .05919 L
.92547 .05919 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .07941 L
.95652 .07941 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .07941 L
.95652 .07941 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .07537 L
.98758 .07537 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .07537 L
.98758 .07537 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .0176 L
.03106 .0176 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .0176 L
.03106 .0176 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .06901 L
.06211 .06901 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .06901 L
.06211 .06901 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .03435 L
.09317 .03435 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .03435 L
.09317 .03435 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .09558 L
.12422 .09558 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .09558 L
.12422 .09558 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .02453 L
.15528 .02453 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .02453 L
.15528 .02453 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .10945 L
.18634 .10945 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .10945 L
.18634 .10945 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .03955 L
.21739 .03955 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .03955 L
.21739 .03955 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .08056 L
.24845 .08056 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .08056 L
.24845 .08056 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .0332 L
.2795 .0332 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .0332 L
.2795 .0332 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .10714 L
.31056 .10714 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .10714 L
.31056 .10714 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .08519 L
.34161 .08519 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .08519 L
.34161 .08519 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .0823 L
.37267 .0823 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .0823 L
.37267 .0823 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .05861 L
.40373 .05861 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .05861 L
.40373 .05861 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .05688 L
.43478 .05688 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .05688 L
.43478 .05688 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .08519 L
.46584 .08519 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .08519 L
.46584 .08519 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .04533 L
.49689 .04533 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .04533 L
.49689 .04533 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .02627 L
.52795 .02627 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .02627 L
.52795 .02627 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .12793 L
.55901 .12793 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .12793 L
.55901 .12793 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .05399 L
.59006 .05399 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .05399 L
.59006 .05399 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .04244 L
.62112 .04244 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .04244 L
.62112 .04244 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .05688 L
.65217 .05688 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .05688 L
.65217 .05688 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .121 L
.68323 .121 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .121 L
.68323 .121 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .05342 L
.71429 .05342 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .05342 L
.71429 .05342 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .08923 L
.74534 .08923 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .08923 L
.74534 .08923 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .06959 L
.7764 .06959 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .06959 L
.7764 .06959 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .10887 L
.80745 .10887 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .10887 L
.80745 .10887 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .10309 L
.83851 .10309 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .10309 L
.83851 .10309 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .02338 L
.86957 .02338 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .02338 L
.86957 .02338 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .09558 L
.90062 .09558 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .09558 L
.90062 .09558 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .03089 L
.93168 .03089 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .03089 L
.93168 .03089 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .05342 L
.96273 .05342 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .05342 L
.96273 .05342 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .03609 L
.99379 .03609 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .03609 L
.99379 .03609 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00;Oooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000>oooo
o`00;_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000>ooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo0000013ooooo000^ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03?ooool002gooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00cooooo000^ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0000oooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Voooooooo0000aOl0000:
ooooo`009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`007Oooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Sooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l4oomo00;o00000ooo
0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l00003ool000?o0?l00_l0
0?l4oomo00;o00000ooo0003o`3o00;o003o1?ooO`02o`0000?oo`000ol0o`02o`00o`Coogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0
o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0ooo
O`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo
0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol0
0?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0
o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0ooo
O`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo
0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol0
0?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l0
0003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`03o`0000[ooooo000L
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00ooo0003o`3o00;o003o1?oo
O`02ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00;ooooo1?oo
0002ooooo`;o003o1?ooO`02ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool4ool000;ooooo0_l0
0?l4oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_oo
ool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0ooo
O`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl01Oooool3o`3o00?o003o0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol0
0?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00Sooooo0ol0
0?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00Gooooo0ol0o`03o`00o`?oogl02?oo
ool3o`00o`?oogl00_ooool00ol0003oooooooooo`08ooooo`007?ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo00?oo`000ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?oo
O`02ooooo`?oo`000ol0o`02o`00o`Coogl02?ooool2o`00o`Coogl00_ooool3ool000?o0?l00_l0
0?l4oomo00Sooooo0_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0
o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00Sooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`05ooooo`?o0?l00ol0
0?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00_ooooo0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00Sooooo0ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`?o003o0ooo
O`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`05ooooo`?o0?l00ol00?l3oomo00Sooooo0ol0
0?l3oomo00;ooooo00?o0000ooooooooool02?ooool001gooooo0_l00007ooooo`03o`000?oooooo
oooo00?oo`000ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?oo`000ol0o`02
o`00o`Coogl02?ooool2o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00Sooooo0_l00?l4
oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3
ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03
o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol00?l3
oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03
o`00o`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`05ooooo`?o0?l00ol00?l3
oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3
oomo00Sooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`08
ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08
ooooo`?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?oo`000ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?ooO`02oooo
o`?oo`000ol0o`02o`00o`Coogl02?ooool2o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo
00Sooooo0_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`?oo`000ol0o`03o`00
o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`02oooo
o`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo
00Sooooo0ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`?o003o0oooO`02oooo
o`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08oooo
o`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00;ooooo0ooo0003o`3o
00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00
o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00
o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl00_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ool000?o0?l00ol00?l5ooooo`?oo`000ol0o`02o`00o`Co
ogl00_ooool3ool000?o0?l00_l00?l4oomo00Sooooo0_l00?l4oomo00;ooooo0ooo0003o`3o00?o
003o2oooool2o`00o`Coogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo0ooo0003o`3o00?o
003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;o
oooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?o
ogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o
0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?o
ogl00_ooool3ool000?o0?l00ol00?l3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?o
ogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol00?l3oomo00So
oooo0ol00?l3oomo00Sooooo1?l00?l:ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o
003o0oooO`08ooooo`?o003o0oooO`02ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?oo`000ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?oo`00
0ol0o`02o`00o`Coogl02?ooool2o`00o`Coogl00_ooool3ool000?o0?l00ol00?l;ooooo`;o003o
1?ooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool3ool000?o0?l0
0ol00?l3oomo00Sooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o
0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo
0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l0
0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl02?ooool3o`00o`?oogl02?ooool4o`00o`[ooooo
0ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00;ooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ool000?o0?l00ol00?l5ooooo`?oo`000ol0
o`02o`00o`Coogl00_ooool3ool000?o0?l00_l00?l4oomo00Sooooo0_l00?l4oomo00;ooooo0ooo
0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`000_oo
ool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol0
0?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00;ooooo0ooo
0003o`3o00Co003o3Oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0ooo
O`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0ooo
O`0;ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00_ooooo0oooO`08ooooo`?o003o0ooo
O`08ooooo`Co003o2_ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?oo
ool3o`00o`?oogl000?oooooo`000?l000002_ooool002Kooooo00?o0000ooooooooool00ooo0003
o`3o00?o003o1Oooool3ool000?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00;o003o1?ooO`08
ooooo`;o003o1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03
o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`02
ooooo`Coo`000_ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol00?l3
oomo00;ooooo0ooo0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08
ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`03
o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00_ooooo0oooO`02
ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;
ooooo`?oogl02?ooool3o`00o`?oogl02?ooool4o`00o`gooooo0oooO`08ooooo`Co003o2_ooool3
o`00o`?oogl02?ooool3o`00o`?oogl00_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool3ool0
00?o0?l00_l00?l4oomo00Sooooo0_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo
00;ooooo0ooo0003o`3o00?o003o0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool3ool0
00?o0?l01?l00?l:ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool3o`00
o`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo
00Sooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo0ooo0003o`3o
00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo
00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo
00_ooooo0oooO`08ooooo`?o003o0oooO`08ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l:oooo
o`?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?o
o`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?o
o`000ol0o`03o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co
003o2_ooool3o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Co
o`000_ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?o
ogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00So
oooo0ol00?l3oomo00;ooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;o
oooo0ol00?l3oomo00_ooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02oooool3oomo00So
oooo0ol00?l3oomo00Sooooo1?l00?l=ooooo`?oogl02?ooool4o`00o`[ooooo0ol00?l3oomo00So
oooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00o`Gooooo0ooo0003o`3o00;o003o1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo
1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`?oogl0
0_ooool4ool000;ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o2_ooool3o`00o`?oogl0
0_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl0
2?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool3o`00o`?oogl00_ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00Sooooo0ol00?l3oomo00;ooooo
0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00_ooooo
0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00Sooooo0ol00?l3oomo00Sooooo
1?l00?l=ooooo`?oogl02?ooool4o`00o`[ooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo0ooo
0003o`3o00;o003o1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0
o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`04o`00o`Cooooo1?oo0002ooooo`?o003o0ooo
O`02ooooo`?oo`000ol0o`04o`00o`[ooooo0ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0ooo
O`0;ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo0ol0
0?l3oomo00Sooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo0ooo
0003o`3o00?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02ooo
ool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo0ol0
0?l3oomo00_ooooo0oooO`08ooooo`?o003o0oooO`08ooooo`Co003o3Oooool3oomo00Sooooo1?l0
0?l:ooooo`?o003o0oooO`08ooooo`Co003o1?ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`?oo`000ol0o`02o`00o`Coogl00_ooool3
ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3
ool000?o0?l01?l00?l4ooooo`Coo`000_ooool3o`00o`?oogl00_ooool3ool000?o0?l01?l00?l:
ooooo`?o003o0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0002
ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`02
ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl02?ooool4
o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3
oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00_ooooo0oooO`08
ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l:ooooo`?o003o0oooO`08ooooo`Co003o1?ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5oooo
o`?oo`000ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool0
00?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l01?l00?l4ooooo`Coo`000_ooool3o`00
o`?oogl00_ooool3ool000?o0?l01?l00?l:ooooo`?o003o0oooO`02ooooo`Coo`000_ooool3o`00
o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08oooo
o`?o003o0oooO`08ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02oooo
o`?oo`000ol0o`03o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00?o003o0oooO`0;oooo
o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00
o`?oogl02oooool3oomo00_ooooo0oooO`08ooooo`Co003o3Oooool3oomo00Sooooo1?l00?l:oooo
o`?o003o0oooO`08ooooo`Co003o1?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?o
oooo0ol0o`03o`00o`Sooooo0ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Co
ogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l01?l00?l4ooooo`Co
o`000_ooool3o`00o`?oogl00_ooool3ool000?o0?l01?l00?l:ooooo`?o003o0oooO`02ooooo`Co
o`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`?o
003o0oooO`08ooooo`?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o0?l01?l00?l=ooooo`?o
ogl00_ooool4ool000;ooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`03o`00o`?o
ogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;o
oooo0ol00?l3oomo00_ooooo0oooO`0;ooooo`?oogl02?ooool4o`00o`gooooo0oooO`08ooooo`Co
003o2_ooool3o`00o`?oogl02?ooool4o`00o`?ooooo0_l0000:ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`?o0?l00ol00?l8ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o
3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00Co003o
1?ooool4ool000;ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o2_ooool3o`00o`?oogl0
0_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl0
2?ooool3o`00o`?oogl02?ooool3o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o
3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o0?l0
0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo
1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl02oooool3oomo00Sooooo1?l00?l=ooooo`?oogl0
2?ooool4o`00o`[ooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Sooooo0ol0o`02o`00o`Coogl00_oo
ool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_oo
ool4ool000;ooooo1?l00?l:ooooo`?o003o0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0ooo
O`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0ooo
O`08ooooo`?o003o0oooO`08ooooo`?o003o0oooO`08ooooo`Co003o1?ooool3ool000?o0?l01?l0
0?l=ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`Coo`000_oo
ool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_oo
ool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`0;ooooo`?oogl02?ooool4o`00o`gooooo0ooo
O`08ooooo`Co003o2_ooool3o`00o`?oogl02?ooool4o`00o`Cooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool3o`3o00?o003o2?ooool3o`3o00;o003o1?ooO`02
ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02
ooooo`Coo`000_ooool4o`00o`[ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3
oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3
oomo00Sooooo0ol00?l3oomo00Sooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`04
o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`000_ooool3
o`00o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002
ooooo`?o003o0oooO`0;ooooo`?oogl02oooool3oomo00Sooooo1?l00?l=ooooo`?oogl02?ooool4
o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?l8ooooo`?o0?l00_l00?l4oomo00;ooooo0ooo0003o`3o
00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002oooo
o`Co003o2_ooool3o`00o`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool0
00;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02?ooool3o`00
o`?oogl02?ooool3o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo
00;ooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo1?oo0002ooooo`?o003o0oooO`0;oooo
o`?oogl00_ooool4ool000;ooooo1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo
00_ooooo0oooO`0;ooooo`?oogl02?ooool4o`00o`gooooo0oooO`08ooooo`Co003o2_ooool4o`00
o`[ooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00o`Sooooo0ol0o`02o`00o`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Co
ogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000;ooooo1?l00?l:ooooo`?o
003o0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?o
ogl02oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`08ooooo`Co003o2_ooool3o`00o`?o
ogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co
003o2_ooool4o`00o`Cooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co
003o3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl02oooool3oomo00So
oooo1?l00?l=ooooo`?oogl02?ooool4o`00o`[ooooo1?l00?l:ooooo`Co003o1?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l8ooooo`?o0?l0
0_l00?l4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o
3Oooool4oomo00;ooooo1?oo0002ooooo`Co003o2_ooool3o`00o`?oogl00_ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`00
0_ooool4o`00oaSooooo0ol00?l3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`gooooo
0oooO`02ooooo`Coo`000_ooool4o`00o`[ooooo1?l00?l4ooooo`Coo`000_ooool4o`00o`gooooo
0oooO`02ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl0
2oooool3oomo00_ooooo0oooO`08ooooo`Co003o3Oooool3oomo01Kooooo1?l00?l:ooooo`Co003o
1?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo0ol0o`03o`00o`Sooooo0ol0
o`02o`00o`Coogl00_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000;ooooo1?l00?l:ooooo`?o003o0oooO`02ooooo`?oo`000ol0
o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo
0002ooooo`Co003o6?ooool3o`00o`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Ooo
ool3oomo00;ooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo1?oo0002ooooo`Co003o3Ooo
ool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0ooo
O`0;ooooo`?oogl02oooool3oomo00Sooooo1?l00?l=ooooo`?oogl05_ooool4o`00o`[ooooo1?l0
0?l3ooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool4o`3o00gooooo0_l00?l4
oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4
oomo00;ooooo1?oo0002ooooo`Co003o2_ooool3o`00o`?oogl00_ooool3ool000?o0?l01?l00?l=
ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo1?l00?lK
ooooo`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo0002
ooooo`Co003o2_ooool4o`00o`Cooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002
ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl02oooool3
oomo00Sooooo1?l00?l=ooooo`?oogl05_ooool4o`00o`[ooooo1?l00?l4ooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0=ooooo`;o003o1?ooO`02oooo
o`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02oooo
o`Coo`000_ooool4o`00o`[ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo
00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`Co003o6oooool3oomo
00Sooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00
o`[ooooo1?l00?l4ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00
o`gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl02oooool3oomo00_ooooo0oooO`08oooo
o`Co003o3Oooool3oomo01Kooooo1?l00?l:ooooo`Co003o1?ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l03Oooool3o`00o`Gooooo0ooo0003o`3o00?o
003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002ooooo`Co
003o2_ooool3o`00o`?oogl00_ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_ooool4ool000Go
oooo0oooO`0;ooooo`?oogl00_ooool4ool000;ooooo1?l00?lKooooo`?oogl02?ooool4o`00o`Co
oooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Co
oooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00;o
oooo1?oo0002ooooo`?o003o0oooO`0;ooooo`?oogl02oooool3oomo00Sooooo1?l00?l=ooooo`?o
ogl05_ooool4o`00o`[ooooo1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`0=ooooo`?o003o1Oooool3ool000?o0?l00ol00?l=ooooo`Coogl0
0_ooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool000;ooooo1?l00?l:ooooo`?o003o
0oooO`02ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo
0oooO`02ooooo`Coo`000_ooool4o`00oa_ooooo0oooO`08ooooo`Co003o1?ooool3ool000?o0?l0
1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo1?l00?l:ooooo`Co003o1?ooool4ool000;ooooo
1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo
1?l00?l=ooooo`?oogl02oooool3oomo00Sooooo1?l00?l=ooooo`?oogl05_ooool4o`00o`[ooooo
1?l00?l4ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`0=ooooo`?o003o1Oooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool3ool000?o0?l00ol0
0?l=ooooo`Coogl00_ooool4ool000;ooooo1?l00?l:ooooo`?o003o0oooO`02ooooo`?oo`000ol0
o`04o`00o`gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`000_oo
ool4o`00oa_ooooo0oooO`08ooooo`Co003o1?ooool3ool000?o0?l01?l00?l=ooooo`?oogl00_oo
ool4ool000;ooooo1?l00?l:ooooo`Co003o1?ooool4ool000;ooooo1?l00?l=ooooo`?oogl00_oo
ool4ool000;ooooo1?l00?l=ooooo`?oogl00_ooool4ool000;ooooo1?l00?l=ooooo`?oogl02ooo
ool3oomo01Wooooo0oooO`0Fooooo`Co003o2_ooool4o`00o`Cooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o00gooooo0ol00?l5ooooo`?oo`000ol0o`03
o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`000_ooool4
o`00o`[ooooo0ol00?l3oomo00;ooooo0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo0005
ooooo`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`Co003o6oooool3oomo00Sooooo1?l00?l4
ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00oa;ooooo1?oo0002
ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002
ooooo`Co003o3Oooool3oomo00_ooooo0oooO`0Iooooo`?oogl05_ooool4o`00oa;ooooo00?o0000
ooooooooool02?ooool002Kooooo0ol00003ooooo`Co0?l03Oooool3o`00o`Gooooo0ooo0003o`3o
00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002oooo
o`Co003o2_ooool3o`00o`?oogl00_ooool3ool000Co0?l04?ooool3oomo00;ooooo1?oo0005oooo
o`?oogl02oooool3oomo00;ooooo1?oo0002ooooo`Co003o6oooool3oomo00Sooooo1?l00?l4oooo
o`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4o`00oa;ooooo1?oo0002oooo
o`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002oooo
o`Co003o3Oooool3oomo00_ooooo0oooO`0Iooooo`?oogl05_ooool4o`00oa7ooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l03Oooool3o`00o`Gooooo0ooo0003o`3o00?o
003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002ooooo`Co
003o2_ooool4o`00o`Cooooo0ooo0004o`3o013ooooo0oooO`02ooooo`Coo`001Oooool3oomo00_o
oooo0oooO`02ooooo`Coo`000_ooool4o`00oa_ooooo0oooO`08ooooo`Co003o1?ooool3ool000?o
0?l01?l00?l=ooooo`?oogl00_ooool4ool000;ooooo1?l00?lBooooo`Coo`004oooool3oomo00;o
oooo1?oo0002ooooo`Co003o3Oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00_o
oooo0oooO`0Iooooo`?oogl0;?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l03Oooool3o`00o`Gooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo
0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo0002ooooo`Co003o2_ooool4o`00o`Cooooo
0ooo0004o`3o013ooooo0oooO`02ooooo`Coo`001Oooool3oomo013ooooo1?oo0002ooooo`Co003o
6oooool3oomo00Sooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`00
6?ooool4ool001?ooooo0oooO`02ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`Coo`00
0_ooool4o`00o`gooooo0oooO`0;ooooo`?oogl06Oooool3oomo02cooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o00gooooo0ol00?l5ooooo`?oo`000ol0
o`03o`00o`gooooo1?ooO`02ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`000_oo
ool4o`00o`[ooooo1?l00?l7ooooo`Co0?l04?ooool3oomo00;ooooo1?oo0005ooooo`?oogl04?oo
ool4ool000;ooooo1?l00?lKooooo`?oogl02?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Ooo
ool3oomo00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo0002ooooo`Co003o3Ooo
ool3oomo00;ooooo1?oo0002ooooo`Co003o3Oooool3oomo00_ooooo0oooO`0Iooooo`?oogl0;?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l03Oooool3
o`00o`Gooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4
oomo00;ooooo1?oo000@ooooo`Co003o1oooool4o`3o013ooooo0oooO`02ooooo`Coo`006?ooool4
ool002cooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02ooooo`Coo`006?ooool4
ool001?ooooo0oooO`02ooooo`Coo`000_ooool4o`00o`gooooo0oooO`02ooooo`Coo`000_ooool4
o`00o`gooooo0oooO`0;ooooo`?oogl06Oooool3oomo02cooooo00?o0000ooooooooool02?ooool0
00_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001oooool00ol0
003oooooooooo`03ooooo`Co0?l03Oooool3o`00o`Gooooo0ooo0003o`3o00?o003o3Oooool4oomo
00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Kooooo`Co0?l04?ooool3oomo
00;ooooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo0002ooooo`Co003o4_ooool4ool0
00;ooooo1?l00?l=ooooo`?oogl02oooool3oomo01Wooooo0oooO`0/ooooo`03o`000?oooooooooo
00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool4o`3o01Gooooo0ooo
0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo
000Kooooo`Co0?l04?ooool3oomo00;ooooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo0ooo
0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo
0002ooooo`Co003o4_ooool4ool001?ooooo0oooO`0;ooooo`?oogl06Oooool3oomo02cooooo00?o
0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool4o`3o01Gooooo
0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo
1?oo000Kooooo`Co0?l04?ooool3oomo00;ooooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo
0ooo0003o`3o00Co003o3Oooool3oomo00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo
1?oo000Hooooo`Coo`004oooool3oomo00_ooooo0oooO`0Iooooo`?oogl0;?ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool01?ooool4o`0000;ooooo1?l0o`0Eooooo`?oo`000ol0o`03o`00oa?o
oooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Kooooo`Co0?l04?ooool3oomo00;o
oooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo00;o
oooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?oogl02oooool3oomo04Go
oooo1?l0000:ooooo`002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`00
0?ooool01?l00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`0Eooooo`?oo`000ol0o`03o`00
oa?ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Kooooo`Co0?l04?ooool3oomo
00;ooooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo0ooo0003o`3o00Co003o3Oooool3oomo
00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo000_ooooo`?oogl02oooool3oomo
04Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000[ooooo00?o0000ooooooooool00oooool4o`3o01Gooooo0ooo
0003o`3o00?o003o4oooool3ool000?o0?l00ol00?l=ooooo`Coogl00_ooool4ool001_ooooo1?l0
o`0@ooooo`?oogl00_ooool4ool001Sooooo1?oo000/ooooo`Co003o1?ooool3ool000?o0?l01?l0
0?l=ooooo`?oogl00_ooool4ool001Sooooo1?oo000Cooooo`?oogl00_ooool4ool002oooooo0ooo
O`0;ooooo`?oogl0B?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000[ooooo0_l00002
ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`Co0?l05Oooool3ool000?o0?l00ol00?lC
ooooo`?oo`000ol0o`03o`00o`gooooo1?ooO`02ooooo`Coo`006oooool4o`3o013ooooo0oooO`02
ooooo`Coo`006?ooool4ool002cooooo1?l00?l4ooooo`?oo`000ol0o`04o`00o`gooooo0oooO`02
ooooo`Coo`006?ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo00_ooooo0oooO`18
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Eoooo
o`?oo`000ol0o`03o`00oa?ooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Koooo
o`Co0?l04?ooool3oomo00;ooooo1?oo000Hooooo`Coo`00;?ooool4o`00o`Cooooo0ooo0004o`3o
013ooooo0oooO`02ooooo`Coo`006?ooool4ool001?ooooo0oooO`02ooooo`Coo`00;oooool3oomo
05Kooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Go
oooo0ooo0004o`3o01Gooooo0ooo0003o`3o00?o003o3Oooool4oomo00;ooooo1?oo000Kooooo`Co
0?l05Oooool4ool001Sooooo1?oo000dooooo`?oo`001?l0o`0@ooooo`?oogl00_ooool4ool001So
oooo1?oo000Cooooo`?oogl00_ooool4ool002oooooo0oooO`1Fooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Eooooo`?oo`001?l0o`0Eooooo`?oo`00
1?l0o`0Eooooo`Coo`006oooool4o`3o01Gooooo1?oo000Hooooo`Coo`00=?ooool3ool000Co0?l0
4?ooool3oomo00;ooooo1?oo000Hooooo`Coo`004oooool3oomo00;ooooo1?oo0028ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o01Gooooo0ooo0004o`3o01Gooooo0ooo
0004o`3o01Gooooo1?oo000Kooooo`Co0?l05Oooool4ool001Sooooo1?oo000dooooo`?oo`001?l0
o`0@ooooo`?oogl00_ooool4ool001Sooooo1?oo000Cooooo`?oogl00_ooool4ool008Oooooo0_l0
000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l05Oooool3ool000Co0?l05Oooool3
ool000Co0?l05Oooool4ool001_ooooo1?l0o`0Eooooo`Coo`006?ooool4ool003Cooooo0ooo0004
o`3o013ooooo0oooO`02ooooo`Coo`006?ooool4ool001?ooooo0oooO`02ooooo`Coo`00R?ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l05Oooool3ool0
00Co0?l05Oooool3ool000Co0?l05Oooool4ool001_ooooo1?l0o`0Eooooo`Coo`006?ooool4ool0
03Cooooo0ooo0004o`3o013ooooo0oooO`02ooooo`Coo`006?ooool4ool001?ooooo0oooO`02oooo
o`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co
0?l05Oooool3ool000Co0?l05Oooool3ool000Co0?l05Oooool4ool001_ooooo1?l0o`0Eooooo`Co
o`006?ooool4ool003Cooooo0ooo0004o`3o013ooooo0oooO`02ooooo`Coo`006?ooool4ool001?o
oooo0oooO`02ooooo`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l05Oooool3ool000Co0?l05Oooool3ool000Co0?l05Oooool4ool001_ooooo
1?l0o`0Eooooo`Coo`006?ooool4ool003Cooooo0ooo0004o`3o013ooooo0oooO`02ooooo`Coo`00
6?ooool4ool001?ooooo0oooO`02ooooo`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l05Oooool3ool000Co0?l05Oooool3ool000Co0?l05Ooo
ool4ool001_ooooo1?l0o`0Eooooo`Coo`006?ooool4ool003Cooooo0ooo0004o`3o013ooooo0ooo
O`02ooooo`Coo`006?ooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`0Eooooo`?oo`001?l0o`0Eooooo`?oo`001?l0o`0E
ooooo`Coo`006oooool4o`3o037ooooo1?oo000dooooo`?oo`001?l0o`0@ooooo`?oogl00_ooool4
ool001Sooooo1?oo000Hooooo`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0
003oooooooooo`03ooooo`Co0?l05Oooool3ool000Co0?l05Oooool3ool000Co0?l05Oooool4ool0
01_ooooo1?l0o`0aooooo`Coo`00=?ooool3ool000Co0?l04?ooool3oomo00;ooooo1?oo000Hoooo
o`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`Co
0?l05Oooool3ool000Co0?l05Oooool3ool000Co0?l05Oooool4ool001_ooooo1?l0o`0aooooo`Co
o`00=?ooool3ool000Co0?l05Oooool4ool001Sooooo1?oo000Hooooo`Coo`00Qoooool2o`0000[o
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Eooooo`?oo`001?l0o`0Eooooo`?oo`00
1?l0o`0Eooooo`Coo`006oooool4o`3o037ooooo1?oo000dooooo`?oo`001?l0o`0Eooooo`Coo`00
6?ooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oo
oooooooo00?ooooo1?l0o`0Hooooo`Co0?l05Oooool3ool000Co0?l05Oooool4ool001_ooooo1?l0
o`0aooooo`Coo`00=?ooool3ool000Co0?l05Oooool4ool001Sooooo1?oo000Hooooo`Coo`00R?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4
o`3o01Gooooo0ooo0004o`3o01Gooooo1?oo000Kooooo`Co0?l0<Oooool4ool003Cooooo0ooo0004
o`3o01Gooooo1?oo000Hooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Eooooo`?oo`001?l0o`0Eoooo
o`Coo`006oooool4o`3o037ooooo1?oo000dooooo`?oo`001?l0o`0Eooooo`Coo`006?ooool4ool0
01Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`0Hooooo`Co0?l05Oooool3ool000Co0?l0=?ooool4o`3o037ooooo1?oo000dooooo`?o
o`001?l0o`0Eooooo`Coo`006?ooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l05Oooool3ool000Co0?l0
=?ooool4o`3o037ooooo1?oo000dooooo`?oo`001?l0o`0Eooooo`Coo`006?ooool4ool001Sooooo
1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o01Sooooo1?l0
o`0Eooooo`?oo`001?l0o`0dooooo`Co0?l0<Oooool4ool003Cooooo0ooo0004o`3o01Gooooo1?oo
000Hooooo`Coo`006?ooool4ool008Oooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03
ooooo`Co0?l06?ooool4o`3o01Gooooo1?oo000gooooo`Co0?l0<Oooool4ool003Cooooo0ooo0004
o`3o01Gooooo1?oo000Hooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Eooooo`Coo`00=oooool4o`3o
037ooooo1?oo000gooooo`Co0?l05Oooool4ool001Sooooo1?oo000Hooooo`Coo`00R?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o01Go
oooo1?oo000gooooo`Co0?l0<Oooool4ool003Oooooo1?l0o`0Eooooo`Coo`006?ooool4ool001So
oooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
1?l0o`0Hooooo`Co0?l05Oooool4ool003Oooooo1?l0o`0aooooo`Coo`00=oooool4o`3o01Gooooo
1?oo000Hooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Eooooo`Coo`00=oooool4o`3o037ooooo1?oo
000gooooo`Co0?l05Oooool4ool001Sooooo1?oo000Hooooo`Coo`00R?ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o01Gooooo1?oo000g
ooooo`Co0?l0<Oooool4ool003Oooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Eoooo
o`Coo`00=oooool4o`3o037ooooo1?oo000gooooo`Co0?l0<Oooool4ool001Sooooo1?oo0028oooo
o`03o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o01Sooooo1?l0o`0Eooooo`Co
o`00=oooool4o`3o037ooooo1?oo000gooooo`Co0?l0<Oooool4ool001Sooooo1?oo0027ooooo`;o
00002_ooool002Kooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`0Eooooo`Coo`00
=oooool4o`3o037ooooo1?oo000gooooo`Co0?l0<Oooool4ool001Sooooo1?oo0028ooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l05Ooo
ool4ool003Oooooo1?l0o`0aooooo`Coo`00=oooool4o`3o037ooooo1?oo000Hooooo`Coo`00R?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4
o`3o053ooooo1?l0o`0aooooo`Coo`00=oooool4o`3o037ooooo1?oo000Hooooo`Coo`00R?ooool0
0ol0003oooooooooo`08ooooo`004Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Oooooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`1@ooooo`Co0?l0<Oooool4ool0
03Oooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool0013o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`006?ooool4ool0
08Sooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o
06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool0013o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`Co00000_ooool4o`3o
01Sooooo1?l0o`1@ooooo`Co0?l0K?ooool4o`3o037ooooo1?oo000Hooooo`Coo`00QOooool4o`00
00[ooooo000@ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`Co0?l06?ooool4o`3o053ooooo1?l0o`1/ooooo`Co0?l0<Oooool4ool0
01Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o
06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool0017o
oooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool4o`3o01So
oooo1?l0o`1@ooooo`Co0?l0K?ooool4o`3o037ooooo1?oo000Hooooo`Coo`00R?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o053ooooo
1?l0o`1/ooooo`Co0?l0<Oooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o06cooooo1?l0
o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000
ooooooooool00oooool4o`3o01Sooooo1?l0o`1@ooooo`Co0?l0K?ooool4o`3o037ooooo1?oo000H
ooooo`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`0Hoooo
o`Co0?l0D?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Oooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4o`3o053ooooo1?l0o`1/ooooo`Co
0?l0<Oooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`00
6?ooool4ool008Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00ooo
ool4o`3o01Sooooo1?l0o`1@ooooo`Co0?l0K?ooool4o`3o037ooooo1?oo000Hooooo`Coo`00R?oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l06?ooool4
o`3o053ooooo1?l0o`1/ooooo`Co0?l0<Oooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`0Hooooo`Co0?l0D?ooool4o`3o
06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o01Sooooo1?l0o`1@ooooo`Co0?l0K?ooool4o`3o037o
oooo1?oo000Hooooo`Coo`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooo
ooooo`03ooooo`Co0?l0K?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo
00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`Co0?l0K?ooool4o`3o06cooooo1?l0
o`0aooooo`Coo`006?ooool4ool008Oooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03
ooooo`Co0?l0K?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o06cooooo1?l0o`1/oooo
o`Co0?l0<Oooool4ool001Sooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`1/ooooo`Co0?l0K?ooool4o`3o037ooooo1?oo000Hooooo`Co
o`00R?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0
K?ooool4o`3o06cooooo1?l0o`0aooooo`Coo`006?ooool4ool008Sooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o06cooooo1?l0o`1/ooooo`Co0?l0COoo
ool4ool008Sooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4
o`3o06cooooo1?l0o`1/ooooo`Co0?l0COooool4ool008Sooooo00?o0000ooooooooool02?ooool0
02Kooooo0ol00003ooooo`Co0?l0K?ooool4o`3o06cooooo1?l0o`1=ooooo`Coo`00Qoooool2o`00
00[ooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`1/ooooo`Co0?l0K?ooool4o`3o04go
oooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo
1?l0o`1/ooooo`Co0?l0K?ooool4o`3o04gooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`1/ooooo`Co0?l0K?ooool4o`3o04gooooo1?oo
0028ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`1/
ooooo`Co0?l0K?ooool4o`3o04gooooo1?oo0028ooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`1/ooooo`Co0?l0_Oooool4ool008Sooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o06cooooo1?l0o`3ooooood[o
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o06cooooo
1?l0o`3ooooood[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003ooooo`Co0?l0K?oo
ool4o`3o0?ooooooBOooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`1/
ooooo`Co0?l0oooooom:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
00?ooooo1?l0o`1/ooooo`Co0?l0oooooom:ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`1/ooooo`Co0?l0oooooom:ooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00001ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000:ooooo`002_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo
000:ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l00007ooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool000[ooooo
00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o0000
2_ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooo
okWooooo0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo
0_l0000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo
000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02?ooool0017ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01_ooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000:oooo
o`004?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02?ooool0017ooooo0_l00009ooooo`?o00001oooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo
000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Voooo
o`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`?o0000
0oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03oooo
o`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo0ol00003oooo
o`Co0?l0ooooooniooooo`;o00002_ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00002ooooo`?o00001oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000;ooooo
1?l0o`3ooooookOooooo1?l0000:ooooo`002_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Ko0000ooooooooooooooooo`000?ooool4o`0000Oooooo00?o0000ooooooooool00oooool4o`3o
0?oooooo^_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007oooo
o`07o`000?ooooooooooooooool0003oooooo`00000:ooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00009ooooo`?o00000_ooool5
o`0000Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08
ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08
ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Voooo
o`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo
000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool0
0ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Voooo
o`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03o`000?oooooooooo00?o
oooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooo
oooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0017ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00Cooooo1?l00002ooooo`Co0?l0oooooongooooo`Co00002_ooool0013ooooo00Co0000oooo
oooooooo00002Oooool2o`0000Oooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08
ooooo`004?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000A
ooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjoooo
o`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[o
oooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0
000:ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`08ooooo`009_ooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000:oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
02Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08oooo
o`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`08ooooo`009_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00Sooooo000Vooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000[ooooo000Vooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool002Kooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`009_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000V
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02?ooool0
00_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00001oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002Oooool2o`0000Kooooo00?o
0000ooooooooool01?ooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000:ooooo`002_ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o00001oooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo
0ol00002ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000oooo
ooooool02?ooool002Kooooo0ol0003ooooool3ooooo0_l0000:ooooo`009_ooool00ol0003ooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool002Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool002Ko
ooooool00035o`0000[ooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000]ooooo`?o00002_ooool5
o`0000[ooooo0ol0000<ooooo`?o00002_ooool3o`0000_ooooo0ol0000<ooooo`03o`000?oooooo
oooo00[ooooo0ol0000;ooooo`;o00002Oooool3o`0000Cooooo0_l00005ooooo`?o00000oooool3
o`0000Gooooo0ol00002ooooo`Go00001?ooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool3
o`0000Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool0
0ol0003oooooooooo`04ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`;o00001Oooool5
o`0000?ooooo0_l00004ooooo`Go00000_ooool3o`0000Cooooo1Ol000000ooooooo0000o`000003
o`0000?ooooo1Ol00002ooooo`?o00001?ooool5o`0000?ooooo0ol00003ooooo`Go00000_ooool3
o`0000Cooooo1Ol00002ooooo`?o00001?ooool5o`0000?ooooo00?o0000ooooooooool00oooool5
o`0000;ooooo0ol00004ooooo`Go00000_ooool2o`0000Kooooo0ol00004ooooo`;o00001Oooool3
o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000kooooo000^ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000cooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000kooooo000^
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`Go00003Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000003?oo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`05o`00
0?ooooooooooooooool000004?ooool002kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0:ooooo`;o00002_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo00Oo
oooo1?l0000=ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`Co00002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`Co00001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooooooool3o`0000Oooooo00Co0000oooooooooooooooo1?l00005
ooooo`;o00000oooool01?l0003oooooooooool00005ooooo`;o00001?ooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`00;_ooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000[ooooo1?l0000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000001_ooool01?l0003oooooooooooooool4o`0000Kooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo
00Ko0000oooooooooooo0000ooooool00004ooooo`06o`000?ooooooooooooooool0003ooooo1?l0
0004ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0<ooooo`00
;Oooool2o`0000_ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oooooooooooooo
ool000002oooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`;o
00001?ooool2o`0000Kooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001Oooool2o`0000Gooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000004ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00001Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooooooo0_l00004ooooo`07o`000?ooooooooooooooool0003o
ooooo`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000Gooooo00Oo
0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool002kooooo
00?o0000ooooooooool02_ooool3o`0000_ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo
1Ol0000;ooooo`;o00002_ooool5o`0000[ooooo0ol0000;ooooo`?o00002Oooool00ol0003ooooo
ooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`Go
00001Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool01?l0003oooooooooooooool5o`00
00Gooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`00
00?ooooo0ol00005ooooo`?o00000oooool3o`0000Gooooo0ol00005ooooo`03o`000?oooooooooo
00?ooooo0ol00002ooooo`Go00001?ooool3o`0000Cooooo0_l00005ooooo`?o00000_ooool5o`00
00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool2o`00
00Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`?o00003oooool00001
\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-2.06768, -0.0286661, 0.0713992, \
0.0013474}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0217391 0.0310559 0.0147151 0.924439 [
[.01863 -0.0125 -3 -9 ]
[.01863 -0.0125 3 0 ]
[.04969 -0.0125 -3 -9 ]
[.04969 -0.0125 3 0 ]
[.08075 -0.0125 -3 -9 ]
[.08075 -0.0125 3 0 ]
[.1118 -0.0125 -3 -9 ]
[.1118 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.17391 -0.0125 -3 -9 ]
[.17391 -0.0125 3 0 ]
[.20497 -0.0125 -3 -9 ]
[.20497 -0.0125 3 0 ]
[.23602 -0.0125 -3 -9 ]
[.23602 -0.0125 3 0 ]
[.26708 -0.0125 -3 -9 ]
[.26708 -0.0125 3 0 ]
[.29814 -0.0125 -6 -9 ]
[.29814 -0.0125 6 0 ]
[.32919 -0.0125 -6 -9 ]
[.32919 -0.0125 6 0 ]
[.36025 -0.0125 -6 -9 ]
[.36025 -0.0125 6 0 ]
[.3913 -0.0125 -6 -9 ]
[.3913 -0.0125 6 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.45342 -0.0125 -6 -9 ]
[.45342 -0.0125 6 0 ]
[.48447 -0.0125 -6 -9 ]
[.48447 -0.0125 6 0 ]
[.51553 -0.0125 -6 -9 ]
[.51553 -0.0125 6 0 ]
[.54658 -0.0125 -6 -9 ]
[.54658 -0.0125 6 0 ]
[.57764 -0.0125 -6 -9 ]
[.57764 -0.0125 6 0 ]
[.6087 -0.0125 -6 -9 ]
[.6087 -0.0125 6 0 ]
[.63975 -0.0125 -6 -9 ]
[.63975 -0.0125 6 0 ]
[.67081 -0.0125 -6 -9 ]
[.67081 -0.0125 6 0 ]
[.70186 -0.0125 -6 -9 ]
[.70186 -0.0125 6 0 ]
[.73292 -0.0125 -6 -9 ]
[.73292 -0.0125 6 0 ]
[.76398 -0.0125 -6 -9 ]
[.76398 -0.0125 6 0 ]
[.79503 -0.0125 -6 -9 ]
[.79503 -0.0125 6 0 ]
[.82609 -0.0125 -6 -9 ]
[.82609 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.8882 -0.0125 -6 -9 ]
[.8882 -0.0125 6 0 ]
[.91925 -0.0125 -6 -9 ]
[.91925 -0.0125 6 0 ]
[.95031 -0.0125 -6 -9 ]
[.95031 -0.0125 6 0 ]
[.98137 -0.0125 -6 -9 ]
[.98137 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10716 -18 -4.5 ]
[-0.0125 .10716 0 4.5 ]
[-0.0125 .1996 -18 -4.5 ]
[-0.0125 .1996 0 4.5 ]
[-0.0125 .29205 -18 -4.5 ]
[-0.0125 .29205 0 4.5 ]
[-0.0125 .38449 -18 -4.5 ]
[-0.0125 .38449 0 4.5 ]
[-0.0125 .47693 -18 -4.5 ]
[-0.0125 .47693 0 4.5 ]
[-0.0125 .56938 -18 -4.5 ]
[-0.0125 .56938 0 4.5 ]
[ 0 0 -0.125 0 ]
[.01863 .63053 -3 0 ]
[.01863 .63053 3 9 ]
[.04969 .63053 -3 0 ]
[.04969 .63053 3 9 ]
[.08075 .63053 -3 0 ]
[.08075 .63053 3 9 ]
[.1118 .63053 -3 0 ]
[.1118 .63053 3 9 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.17391 .63053 -3 0 ]
[.17391 .63053 3 9 ]
[.20497 .63053 -3 0 ]
[.20497 .63053 3 9 ]
[.23602 .63053 -3 0 ]
[.23602 .63053 3 9 ]
[.26708 .63053 -3 0 ]
[.26708 .63053 3 9 ]
[.29814 .63053 -6 0 ]
[.29814 .63053 6 9 ]
[.32919 .63053 -6 0 ]
[.32919 .63053 6 9 ]
[.36025 .63053 -6 0 ]
[.36025 .63053 6 9 ]
[.3913 .63053 -6 0 ]
[.3913 .63053 6 9 ]
[.42236 .63053 -6 0 ]
[.42236 .63053 6 9 ]
[.45342 .63053 -6 0 ]
[.45342 .63053 6 9 ]
[.48447 .63053 -6 0 ]
[.48447 .63053 6 9 ]
[.51553 .63053 -6 0 ]
[.51553 .63053 6 9 ]
[.54658 .63053 -6 0 ]
[.54658 .63053 6 9 ]
[.57764 .63053 -6 0 ]
[.57764 .63053 6 9 ]
[.6087 .63053 -6 0 ]
[.6087 .63053 6 9 ]
[.63975 .63053 -6 0 ]
[.63975 .63053 6 9 ]
[.67081 .63053 -6 0 ]
[.67081 .63053 6 9 ]
[.70186 .63053 -6 0 ]
[.70186 .63053 6 9 ]
[.73292 .63053 -6 0 ]
[.73292 .63053 6 9 ]
[.76398 .63053 -6 0 ]
[.76398 .63053 6 9 ]
[.79503 .63053 -6 0 ]
[.79503 .63053 6 9 ]
[.82609 .63053 -6 0 ]
[.82609 .63053 6 9 ]
[.85714 .63053 -6 0 ]
[.85714 .63053 6 9 ]
[.8882 .63053 -6 0 ]
[.8882 .63053 6 9 ]
[.91925 .63053 -6 0 ]
[.91925 .63053 6 9 ]
[.95031 .63053 -6 0 ]
[.95031 .63053 6 9 ]
[.98137 .63053 -6 0 ]
[.98137 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01863 0 m
.01863 .00625 L
s
[(1)] .01863 -0.0125 0 1 Mshowa
.04969 0 m
.04969 .00625 L
s
[(2)] .04969 -0.0125 0 1 Mshowa
.08075 0 m
.08075 .00625 L
s
[(3)] .08075 -0.0125 0 1 Mshowa
.1118 0 m
.1118 .00625 L
s
[(4)] .1118 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(5)] .14286 -0.0125 0 1 Mshowa
.17391 0 m
.17391 .00625 L
s
[(6)] .17391 -0.0125 0 1 Mshowa
.20497 0 m
.20497 .00625 L
s
[(7)] .20497 -0.0125 0 1 Mshowa
.23602 0 m
.23602 .00625 L
s
[(8)] .23602 -0.0125 0 1 Mshowa
.26708 0 m
.26708 .00625 L
s
[(9)] .26708 -0.0125 0 1 Mshowa
.29814 0 m
.29814 .00625 L
s
[(10)] .29814 -0.0125 0 1 Mshowa
.32919 0 m
.32919 .00625 L
s
[(11)] .32919 -0.0125 0 1 Mshowa
.36025 0 m
.36025 .00625 L
s
[(12)] .36025 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(13)] .3913 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(14)] .42236 -0.0125 0 1 Mshowa
.45342 0 m
.45342 .00625 L
s
[(15)] .45342 -0.0125 0 1 Mshowa
.48447 0 m
.48447 .00625 L
s
[(16)] .48447 -0.0125 0 1 Mshowa
.51553 0 m
.51553 .00625 L
s
[(17)] .51553 -0.0125 0 1 Mshowa
.54658 0 m
.54658 .00625 L
s
[(18)] .54658 -0.0125 0 1 Mshowa
.57764 0 m
.57764 .00625 L
s
[(19)] .57764 -0.0125 0 1 Mshowa
.6087 0 m
.6087 .00625 L
s
[(20)] .6087 -0.0125 0 1 Mshowa
.63975 0 m
.63975 .00625 L
s
[(21)] .63975 -0.0125 0 1 Mshowa
.67081 0 m
.67081 .00625 L
s
[(22)] .67081 -0.0125 0 1 Mshowa
.70186 0 m
.70186 .00625 L
s
[(23)] .70186 -0.0125 0 1 Mshowa
.73292 0 m
.73292 .00625 L
s
[(24)] .73292 -0.0125 0 1 Mshowa
.76398 0 m
.76398 .00625 L
s
[(25)] .76398 -0.0125 0 1 Mshowa
.79503 0 m
.79503 .00625 L
s
[(26)] .79503 -0.0125 0 1 Mshowa
.82609 0 m
.82609 .00625 L
s
[(27)] .82609 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(28)] .85714 -0.0125 0 1 Mshowa
.8882 0 m
.8882 .00625 L
s
[(29)] .8882 -0.0125 0 1 Mshowa
.91925 0 m
.91925 .00625 L
s
[(30)] .91925 -0.0125 0 1 Mshowa
.95031 0 m
.95031 .00625 L
s
[(31)] .95031 -0.0125 0 1 Mshowa
.98137 0 m
.98137 .00625 L
s
[(32)] .98137 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10716 m
.00625 .10716 L
s
[(0.1)] -0.0125 .10716 1 0 Mshowa
0 .1996 m
.00625 .1996 L
s
[(0.2)] -0.0125 .1996 1 0 Mshowa
0 .29205 m
.00625 .29205 L
s
[(0.3)] -0.0125 .29205 1 0 Mshowa
0 .38449 m
.00625 .38449 L
s
[(0.4)] -0.0125 .38449 1 0 Mshowa
0 .47693 m
.00625 .47693 L
s
[(0.5)] -0.0125 .47693 1 0 Mshowa
0 .56938 m
.00625 .56938 L
s
[(0.6)] -0.0125 .56938 1 0 Mshowa
.125 Mabswid
0 .0332 m
.00375 .0332 L
s
0 .05169 m
.00375 .05169 L
s
0 .07018 m
.00375 .07018 L
s
0 .08867 m
.00375 .08867 L
s
0 .12565 m
.00375 .12565 L
s
0 .14414 m
.00375 .14414 L
s
0 .16263 m
.00375 .16263 L
s
0 .18111 m
.00375 .18111 L
s
0 .21809 m
.00375 .21809 L
s
0 .23658 m
.00375 .23658 L
s
0 .25507 m
.00375 .25507 L
s
0 .27356 m
.00375 .27356 L
s
0 .31054 m
.00375 .31054 L
s
0 .32902 m
.00375 .32902 L
s
0 .34751 m
.00375 .34751 L
s
0 .366 m
.00375 .366 L
s
0 .40298 m
.00375 .40298 L
s
0 .42147 m
.00375 .42147 L
s
0 .43996 m
.00375 .43996 L
s
0 .45845 m
.00375 .45845 L
s
0 .49542 m
.00375 .49542 L
s
0 .51391 m
.00375 .51391 L
s
0 .5324 m
.00375 .5324 L
s
0 .55089 m
.00375 .55089 L
s
0 .58787 m
.00375 .58787 L
s
0 .60636 m
.00375 .60636 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01863 .61178 m
.01863 .61803 L
s
[(1)] .01863 .63053 0 -1 Mshowa
.04969 .61178 m
.04969 .61803 L
s
[(2)] .04969 .63053 0 -1 Mshowa
.08075 .61178 m
.08075 .61803 L
s
[(3)] .08075 .63053 0 -1 Mshowa
.1118 .61178 m
.1118 .61803 L
s
[(4)] .1118 .63053 0 -1 Mshowa
.14286 .61178 m
.14286 .61803 L
s
[(5)] .14286 .63053 0 -1 Mshowa
.17391 .61178 m
.17391 .61803 L
s
[(6)] .17391 .63053 0 -1 Mshowa
.20497 .61178 m
.20497 .61803 L
s
[(7)] .20497 .63053 0 -1 Mshowa
.23602 .61178 m
.23602 .61803 L
s
[(8)] .23602 .63053 0 -1 Mshowa
.26708 .61178 m
.26708 .61803 L
s
[(9)] .26708 .63053 0 -1 Mshowa
.29814 .61178 m
.29814 .61803 L
s
[(10)] .29814 .63053 0 -1 Mshowa
.32919 .61178 m
.32919 .61803 L
s
[(11)] .32919 .63053 0 -1 Mshowa
.36025 .61178 m
.36025 .61803 L
s
[(12)] .36025 .63053 0 -1 Mshowa
.3913 .61178 m
.3913 .61803 L
s
[(13)] .3913 .63053 0 -1 Mshowa
.42236 .61178 m
.42236 .61803 L
s
[(14)] .42236 .63053 0 -1 Mshowa
.45342 .61178 m
.45342 .61803 L
s
[(15)] .45342 .63053 0 -1 Mshowa
.48447 .61178 m
.48447 .61803 L
s
[(16)] .48447 .63053 0 -1 Mshowa
.51553 .61178 m
.51553 .61803 L
s
[(17)] .51553 .63053 0 -1 Mshowa
.54658 .61178 m
.54658 .61803 L
s
[(18)] .54658 .63053 0 -1 Mshowa
.57764 .61178 m
.57764 .61803 L
s
[(19)] .57764 .63053 0 -1 Mshowa
.6087 .61178 m
.6087 .61803 L
s
[(20)] .6087 .63053 0 -1 Mshowa
.63975 .61178 m
.63975 .61803 L
s
[(21)] .63975 .63053 0 -1 Mshowa
.67081 .61178 m
.67081 .61803 L
s
[(22)] .67081 .63053 0 -1 Mshowa
.70186 .61178 m
.70186 .61803 L
s
[(23)] .70186 .63053 0 -1 Mshowa
.73292 .61178 m
.73292 .61803 L
s
[(24)] .73292 .63053 0 -1 Mshowa
.76398 .61178 m
.76398 .61803 L
s
[(25)] .76398 .63053 0 -1 Mshowa
.79503 .61178 m
.79503 .61803 L
s
[(26)] .79503 .63053 0 -1 Mshowa
.82609 .61178 m
.82609 .61803 L
s
[(27)] .82609 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(28)] .85714 .63053 0 -1 Mshowa
.8882 .61178 m
.8882 .61803 L
s
[(29)] .8882 .63053 0 -1 Mshowa
.91925 .61178 m
.91925 .61803 L
s
[(30)] .91925 .63053 0 -1 Mshowa
.95031 .61178 m
.95031 .61803 L
s
[(31)] .95031 .63053 0 -1 Mshowa
.98137 .61178 m
.98137 .61803 L
s
[(32)] .98137 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10716 m
1 .10716 L
s
.99375 .1996 m
1 .1996 L
s
.99375 .29205 m
1 .29205 L
s
.99375 .38449 m
1 .38449 L
s
.99375 .47693 m
1 .47693 L
s
.99375 .56938 m
1 .56938 L
s
.125 Mabswid
.99625 .0332 m
1 .0332 L
s
.99625 .05169 m
1 .05169 L
s
.99625 .07018 m
1 .07018 L
s
.99625 .08867 m
1 .08867 L
s
.99625 .12565 m
1 .12565 L
s
.99625 .14414 m
1 .14414 L
s
.99625 .16263 m
1 .16263 L
s
.99625 .18111 m
1 .18111 L
s
.99625 .21809 m
1 .21809 L
s
.99625 .23658 m
1 .23658 L
s
.99625 .25507 m
1 .25507 L
s
.99625 .27356 m
1 .27356 L
s
.99625 .31054 m
1 .31054 L
s
.99625 .32902 m
1 .32902 L
s
.99625 .34751 m
1 .34751 L
s
.99625 .366 m
1 .366 L
s
.99625 .40298 m
1 .40298 L
s
.99625 .42147 m
1 .42147 L
s
.99625 .43996 m
1 .43996 L
s
.99625 .45845 m
1 .45845 L
s
.99625 .49542 m
1 .49542 L
s
.99625 .51391 m
1 .51391 L
s
.99625 .5324 m
1 .5324 L
s
.99625 .55089 m
1 .55089 L
s
.99625 .58787 m
1 .58787 L
s
.99625 .60636 m
1 .60636 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
F
.5 Mabswid
.00621 .01472 m
.00621 .01472 L
.01242 .01472 L
.01242 .01472 L
.00621 .01472 L
s
.03727 .01472 m
.03727 .05235 L
.04348 .05235 L
.04348 .01472 L
F
.03727 .01472 m
.03727 .05235 L
.04348 .05235 L
.04348 .01472 L
.03727 .01472 L
s
.06832 .01472 m
.06832 .02445 L
.07453 .02445 L
.07453 .01472 L
F
.06832 .01472 m
.06832 .02445 L
.07453 .02445 L
.07453 .01472 L
.06832 .01472 L
s
.09938 .01472 m
.09938 .0556 L
.10559 .0556 L
.10559 .01472 L
F
.09938 .01472 m
.09938 .0556 L
.10559 .0556 L
.10559 .01472 L
.09938 .01472 L
s
.13043 .01472 m
.13043 .01472 L
.13665 .01472 L
.13665 .01472 L
F
.13043 .01472 m
.13043 .01472 L
.13665 .01472 L
.13665 .01472 L
.13043 .01472 L
s
.16149 .01472 m
.16149 .01666 L
.1677 .01666 L
.1677 .01472 L
F
.16149 .01472 m
.16149 .01666 L
.1677 .01666 L
.1677 .01472 L
.16149 .01472 L
s
.19255 .01472 m
.19255 .05365 L
.19876 .05365 L
.19876 .01472 L
F
.19255 .01472 m
.19255 .05365 L
.19876 .05365 L
.19876 .01472 L
.19255 .01472 L
s
.2236 .01472 m
.2236 .05755 L
.22981 .05755 L
.22981 .01472 L
F
.2236 .01472 m
.2236 .05755 L
.22981 .05755 L
.22981 .01472 L
.2236 .01472 L
s
.25466 .01472 m
.25466 .01634 L
.26087 .01634 L
.26087 .01472 L
F
.25466 .01472 m
.25466 .01634 L
.26087 .01634 L
.26087 .01472 L
.25466 .01472 L
s
.28571 .01472 m
.28571 .0423 L
.29193 .0423 L
.29193 .01472 L
F
.28571 .01472 m
.28571 .0423 L
.29193 .0423 L
.29193 .01472 L
.28571 .01472 L
s
.31677 .01472 m
.31677 .03808 L
.32298 .03808 L
.32298 .01472 L
F
.31677 .01472 m
.31677 .03808 L
.32298 .03808 L
.32298 .01472 L
.31677 .01472 L
s
.34783 .01472 m
.34783 .02088 L
.35404 .02088 L
.35404 .01472 L
F
.34783 .01472 m
.34783 .02088 L
.35404 .02088 L
.35404 .01472 L
.34783 .01472 L
s
.37888 .01472 m
.37888 .02802 L
.38509 .02802 L
.38509 .01472 L
F
.37888 .01472 m
.37888 .02802 L
.38509 .02802 L
.38509 .01472 L
.37888 .01472 L
s
.40994 .01472 m
.40994 .01926 L
.41615 .01926 L
.41615 .01472 L
F
.40994 .01472 m
.40994 .01926 L
.41615 .01926 L
.41615 .01472 L
.40994 .01472 L
s
.44099 .01472 m
.44099 .08707 L
.4472 .08707 L
.4472 .01472 L
F
.44099 .01472 m
.44099 .08707 L
.4472 .08707 L
.4472 .01472 L
.44099 .01472 L
s
.47205 .01472 m
.47205 .06339 L
.47826 .06339 L
.47826 .01472 L
F
.47205 .01472 m
.47205 .06339 L
.47826 .06339 L
.47826 .01472 L
.47205 .01472 L
s
.50311 .01472 m
.50311 .01536 L
.50932 .01536 L
.50932 .01472 L
F
.50311 .01472 m
.50311 .01536 L
.50932 .01536 L
.50932 .01472 L
.50311 .01472 L
s
.53416 .01472 m
.53416 .0569 L
.54037 .0569 L
.54037 .01472 L
F
.53416 .01472 m
.53416 .0569 L
.54037 .0569 L
.54037 .01472 L
.53416 .01472 L
s
.56522 .01472 m
.56522 .04197 L
.57143 .04197 L
.57143 .01472 L
F
.56522 .01472 m
.56522 .04197 L
.57143 .04197 L
.57143 .01472 L
.56522 .01472 L
s
.59627 .01472 m
.59627 .08642 L
.60248 .08642 L
.60248 .01472 L
F
.59627 .01472 m
.59627 .08642 L
.60248 .08642 L
.60248 .01472 L
.59627 .01472 L
s
.62733 .01472 m
.62733 .03159 L
.63354 .03159 L
.63354 .01472 L
F
.62733 .01472 m
.62733 .03159 L
.63354 .03159 L
.63354 .01472 L
.62733 .01472 L
s
.65839 .01472 m
.65839 .06728 L
.6646 .06728 L
.6646 .01472 L
F
.65839 .01472 m
.65839 .06728 L
.6646 .06728 L
.6646 .01472 L
.65839 .01472 L
s
.68944 .01472 m
.68944 .02283 L
.69565 .02283 L
.69565 .01472 L
F
.68944 .01472 m
.68944 .02283 L
.69565 .02283 L
.69565 .01472 L
.68944 .01472 L
s
.7205 .01472 m
.7205 .02477 L
.72671 .02477 L
.72671 .01472 L
F
.7205 .01472 m
.7205 .02477 L
.72671 .02477 L
.72671 .01472 L
.7205 .01472 L
s
.75155 .01472 m
.75155 .01666 L
.75776 .01666 L
.75776 .01472 L
F
.75155 .01472 m
.75155 .01666 L
.75776 .01666 L
.75776 .01472 L
.75155 .01472 L
s
.78261 .01472 m
.78261 .10784 L
.78882 .10784 L
.78882 .01472 L
F
.78261 .01472 m
.78261 .10784 L
.78882 .10784 L
.78882 .01472 L
.78261 .01472 L
s
.81366 .01472 m
.81366 .06696 L
.81988 .06696 L
.81988 .01472 L
F
.81366 .01472 m
.81366 .06696 L
.81988 .06696 L
.81988 .01472 L
.81366 .01472 L
s
.84472 .01472 m
.84472 .10362 L
.85093 .10362 L
.85093 .01472 L
F
.84472 .01472 m
.84472 .10362 L
.85093 .10362 L
.85093 .01472 L
.84472 .01472 L
s
.87578 .01472 m
.87578 .01828 L
.88199 .01828 L
.88199 .01472 L
F
.87578 .01472 m
.87578 .01828 L
.88199 .01828 L
.88199 .01472 L
.87578 .01472 L
s
.90683 .01472 m
.90683 .01569 L
.91304 .01569 L
.91304 .01472 L
F
.90683 .01472 m
.90683 .01569 L
.91304 .01569 L
.91304 .01472 L
.90683 .01472 L
s
.93789 .01472 m
.93789 .02705 L
.9441 .02705 L
.9441 .01472 L
F
.93789 .01472 m
.93789 .02705 L
.9441 .02705 L
.9441 .01472 L
.93789 .01472 L
s
.96894 .01472 m
.96894 .08707 L
.97516 .08707 L
.97516 .01472 L
F
.96894 .01472 m
.96894 .08707 L
.97516 .08707 L
.97516 .01472 L
.96894 .01472 L
s
0 1 0 r
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
F
.01242 .01472 m
.01242 .60332 L
.01863 .60332 L
.01863 .01472 L
.01242 .01472 L
s
.04348 .01472 m
.04348 .01536 L
.04969 .01536 L
.04969 .01472 L
F
.04348 .01472 m
.04348 .01536 L
.04969 .01536 L
.04969 .01472 L
.04348 .01472 L
s
.07453 .01472 m
.07453 .01504 L
.08075 .01504 L
.08075 .01472 L
F
.07453 .01472 m
.07453 .01504 L
.08075 .01504 L
.08075 .01472 L
.07453 .01472 L
s
.10559 .01472 m
.10559 .01569 L
.1118 .01569 L
.1118 .01472 L
F
.10559 .01472 m
.10559 .01569 L
.1118 .01569 L
.1118 .01472 L
.10559 .01472 L
s
.13665 .01472 m
.13665 .10654 L
.14286 .10654 L
.14286 .01472 L
F
.13665 .01472 m
.13665 .10654 L
.14286 .10654 L
.14286 .01472 L
.13665 .01472 L
s
.1677 .01472 m
.1677 .06047 L
.17391 .06047 L
.17391 .01472 L
F
.1677 .01472 m
.1677 .06047 L
.17391 .06047 L
.17391 .01472 L
.1677 .01472 L
s
.19876 .01472 m
.19876 .01536 L
.20497 .01536 L
.20497 .01472 L
F
.19876 .01472 m
.19876 .01536 L
.20497 .01536 L
.20497 .01472 L
.19876 .01472 L
s
.22981 .01472 m
.22981 .01536 L
.23602 .01536 L
.23602 .01472 L
F
.22981 .01472 m
.22981 .01536 L
.23602 .01536 L
.23602 .01472 L
.22981 .01472 L
s
.26087 .01472 m
.26087 .0569 L
.26708 .0569 L
.26708 .01472 L
F
.26087 .01472 m
.26087 .0569 L
.26708 .0569 L
.26708 .01472 L
.26087 .01472 L
s
.29193 .01472 m
.29193 .01472 L
.29814 .01472 L
.29814 .01472 L
F
.29193 .01472 m
.29193 .01472 L
.29814 .01472 L
.29814 .01472 L
.29193 .01472 L
s
.32298 .01472 m
.32298 .01472 L
.32919 .01472 L
.32919 .01472 L
F
.32298 .01472 m
.32298 .01472 L
.32919 .01472 L
.32919 .01472 L
.32298 .01472 L
s
.35404 .01472 m
.35404 .01504 L
.36025 .01504 L
.36025 .01472 L
F
.35404 .01472 m
.35404 .01504 L
.36025 .01504 L
.36025 .01472 L
.35404 .01472 L
s
.38509 .01472 m
.38509 .01666 L
.3913 .01666 L
.3913 .01472 L
F
.38509 .01472 m
.38509 .01666 L
.3913 .01666 L
.3913 .01472 L
.38509 .01472 L
s
.41615 .01472 m
.41615 .01504 L
.42236 .01504 L
.42236 .01472 L
F
.41615 .01472 m
.41615 .01504 L
.42236 .01504 L
.42236 .01472 L
.41615 .01472 L
s
.4472 .01472 m
.4472 .01472 L
.45342 .01472 L
.45342 .01472 L
F
.4472 .01472 m
.4472 .01472 L
.45342 .01472 L
.45342 .01472 L
.4472 .01472 L
s
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
F
.47826 .01472 m
.47826 .01472 L
.48447 .01472 L
.48447 .01472 L
.47826 .01472 L
s
.50932 .01472 m
.50932 .11206 L
.51553 .11206 L
.51553 .01472 L
F
.50932 .01472 m
.50932 .11206 L
.51553 .11206 L
.51553 .01472 L
.50932 .01472 L
s
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
F
.54037 .01472 m
.54037 .01472 L
.54658 .01472 L
.54658 .01472 L
.54037 .01472 L
s
.57143 .01472 m
.57143 .01504 L
.57764 .01504 L
.57764 .01472 L
F
.57143 .01472 m
.57143 .01504 L
.57764 .01504 L
.57764 .01472 L
.57143 .01472 L
s
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
F
.60248 .01472 m
.60248 .01472 L
.6087 .01472 L
.6087 .01472 L
.60248 .01472 L
s
.63354 .01472 m
.63354 .01569 L
.63975 .01569 L
.63975 .01472 L
F
.63354 .01472 m
.63354 .01569 L
.63975 .01569 L
.63975 .01472 L
.63354 .01472 L
s
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
F
.6646 .01472 m
.6646 .01472 L
.67081 .01472 L
.67081 .01472 L
.6646 .01472 L
s
.69565 .01472 m
.69565 .01472 L
.70186 .01472 L
.70186 .01472 L
F
.69565 .01472 m
.69565 .01472 L
.70186 .01472 L
.70186 .01472 L
.69565 .01472 L
s
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
F
.72671 .01472 m
.72671 .01472 L
.73292 .01472 L
.73292 .01472 L
.72671 .01472 L
s
.75776 .01472 m
.75776 .06631 L
.76398 .06631 L
.76398 .01472 L
F
.75776 .01472 m
.75776 .06631 L
.76398 .06631 L
.76398 .01472 L
.75776 .01472 L
s
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
F
.78882 .01472 m
.78882 .01472 L
.79503 .01472 L
.79503 .01472 L
.78882 .01472 L
s
.81988 .01472 m
.81988 .01472 L
.82609 .01472 L
.82609 .01472 L
F
.81988 .01472 m
.81988 .01472 L
.82609 .01472 L
.82609 .01472 L
.81988 .01472 L
s
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
F
.85093 .01472 m
.85093 .01472 L
.85714 .01472 L
.85714 .01472 L
.85093 .01472 L
s
.88199 .01472 m
.88199 .01472 L
.8882 .01472 L
.8882 .01472 L
F
.88199 .01472 m
.88199 .01472 L
.8882 .01472 L
.8882 .01472 L
.88199 .01472 L
s
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
F
.91304 .01472 m
.91304 .01472 L
.91925 .01472 L
.91925 .01472 L
.91304 .01472 L
s
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
F
.9441 .01472 m
.9441 .01472 L
.95031 .01472 L
.95031 .01472 L
.9441 .01472 L
s
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
F
.97516 .01472 m
.97516 .01472 L
.98137 .01472 L
.98137 .01472 L
.97516 .01472 L
s
0 0 1 r
.01863 .01472 m
.01863 .12406 L
.02484 .12406 L
.02484 .01472 L
F
.01863 .01472 m
.01863 .12406 L
.02484 .12406 L
.02484 .01472 L
.01863 .01472 L
s
.04969 .01472 m
.04969 .01893 L
.0559 .01893 L
.0559 .01472 L
F
.04969 .01472 m
.04969 .01893 L
.0559 .01893 L
.0559 .01472 L
.04969 .01472 L
s
.08075 .01472 m
.08075 .01666 L
.08696 .01666 L
.08696 .01472 L
F
.08075 .01472 m
.08075 .01666 L
.08696 .01666 L
.08696 .01472 L
.08075 .01472 L
s
.1118 .01472 m
.1118 .01958 L
.11801 .01958 L
.11801 .01472 L
F
.1118 .01472 m
.1118 .01958 L
.11801 .01958 L
.11801 .01472 L
.1118 .01472 L
s
.14286 .01472 m
.14286 .16884 L
.14907 .16884 L
.14907 .01472 L
F
.14286 .01472 m
.14286 .16884 L
.14907 .16884 L
.14907 .01472 L
.14286 .01472 L
s
.17391 .01472 m
.17391 .1484 L
.18012 .1484 L
.18012 .01472 L
F
.17391 .01472 m
.17391 .1484 L
.18012 .1484 L
.18012 .01472 L
.17391 .01472 L
s
.20497 .01472 m
.20497 .03386 L
.21118 .03386 L
.21118 .01472 L
F
.20497 .01472 m
.20497 .03386 L
.21118 .03386 L
.21118 .01472 L
.20497 .01472 L
s
.23602 .01472 m
.23602 .02185 L
.24224 .02185 L
.24224 .01472 L
F
.23602 .01472 m
.23602 .02185 L
.24224 .02185 L
.24224 .01472 L
.23602 .01472 L
s
.26708 .01472 m
.26708 .15943 L
.27329 .15943 L
.27329 .01472 L
F
.26708 .01472 m
.26708 .15943 L
.27329 .15943 L
.27329 .01472 L
.26708 .01472 L
s
.29814 .01472 m
.29814 .01634 L
.30435 .01634 L
.30435 .01472 L
F
.29814 .01472 m
.29814 .01634 L
.30435 .01634 L
.30435 .01472 L
.29814 .01472 L
s
.32919 .01472 m
.32919 .01569 L
.3354 .01569 L
.3354 .01472 L
F
.32919 .01472 m
.32919 .01569 L
.3354 .01569 L
.3354 .01472 L
.32919 .01472 L
s
.36025 .01472 m
.36025 .01536 L
.36646 .01536 L
.36646 .01472 L
F
.36025 .01472 m
.36025 .01536 L
.36646 .01536 L
.36646 .01472 L
.36025 .01472 L
s
.3913 .01472 m
.3913 .03483 L
.39752 .03483 L
.39752 .01472 L
F
.3913 .01472 m
.3913 .03483 L
.39752 .03483 L
.39752 .01472 L
.3913 .01472 L
s
.42236 .01472 m
.42236 .01504 L
.42857 .01504 L
.42857 .01472 L
F
.42236 .01472 m
.42236 .01504 L
.42857 .01504 L
.42857 .01472 L
.42236 .01472 L
s
.45342 .01472 m
.45342 .01536 L
.45963 .01536 L
.45963 .01472 L
F
.45342 .01472 m
.45342 .01536 L
.45963 .01536 L
.45963 .01472 L
.45342 .01472 L
s
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
F
.48447 .01472 m
.48447 .01472 L
.49068 .01472 L
.49068 .01472 L
.48447 .01472 L
s
.51553 .01472 m
.51553 .16105 L
.52174 .16105 L
.52174 .01472 L
F
.51553 .01472 m
.51553 .16105 L
.52174 .16105 L
.52174 .01472 L
.51553 .01472 L
s
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
F
.54658 .01472 m
.54658 .01472 L
.5528 .01472 L
.5528 .01472 L
.54658 .01472 L
s
.57764 .01472 m
.57764 .01504 L
.58385 .01504 L
.58385 .01472 L
F
.57764 .01472 m
.57764 .01504 L
.58385 .01504 L
.58385 .01472 L
.57764 .01472 L
s
.6087 .01472 m
.6087 .01504 L
.61491 .01504 L
.61491 .01472 L
F
.6087 .01472 m
.6087 .01504 L
.61491 .01504 L
.61491 .01472 L
.6087 .01472 L
s
.63975 .01472 m
.63975 .04424 L
.64596 .04424 L
.64596 .01472 L
F
.63975 .01472 m
.63975 .04424 L
.64596 .04424 L
.64596 .01472 L
.63975 .01472 L
s
.67081 .01472 m
.67081 .01504 L
.67702 .01504 L
.67702 .01472 L
F
.67081 .01472 m
.67081 .01504 L
.67702 .01504 L
.67702 .01472 L
.67081 .01472 L
s
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
F
.70186 .01472 m
.70186 .01472 L
.70807 .01472 L
.70807 .01472 L
.70186 .01472 L
s
.73292 .01472 m
.73292 .01504 L
.73913 .01504 L
.73913 .01472 L
F
.73292 .01472 m
.73292 .01504 L
.73913 .01504 L
.73913 .01472 L
.73292 .01472 L
s
.76398 .01472 m
.76398 .15813 L
.77019 .15813 L
.77019 .01472 L
F
.76398 .01472 m
.76398 .15813 L
.77019 .15813 L
.77019 .01472 L
.76398 .01472 L
s
.79503 .01472 m
.79503 .01504 L
.80124 .01504 L
.80124 .01472 L
F
.79503 .01472 m
.79503 .01504 L
.80124 .01504 L
.80124 .01472 L
.79503 .01472 L
s
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
F
.82609 .01472 m
.82609 .01472 L
.8323 .01472 L
.8323 .01472 L
.82609 .01472 L
s
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
F
.85714 .01472 m
.85714 .01472 L
.86335 .01472 L
.86335 .01472 L
.85714 .01472 L
s
.8882 .01472 m
.8882 .01472 L
.89441 .01472 L
.89441 .01472 L
F
.8882 .01472 m
.8882 .01472 L
.89441 .01472 L
.89441 .01472 L
.8882 .01472 L
s
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
F
.91925 .01472 m
.91925 .01472 L
.92547 .01472 L
.92547 .01472 L
.91925 .01472 L
s
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
F
.95031 .01472 m
.95031 .01472 L
.95652 .01472 L
.95652 .01472 L
.95031 .01472 L
s
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
F
.98137 .01472 m
.98137 .01472 L
.98758 .01472 L
.98758 .01472 L
.98137 .01472 L
s
1 .5 0 r
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
F
.02484 .01472 m
.02484 .01472 L
.03106 .01472 L
.03106 .01472 L
.02484 .01472 L
s
.0559 .01472 m
.0559 .04716 L
.06211 .04716 L
.06211 .01472 L
F
.0559 .01472 m
.0559 .04716 L
.06211 .04716 L
.06211 .01472 L
.0559 .01472 L
s
.08696 .01472 m
.08696 .0702 L
.09317 .0702 L
.09317 .01472 L
F
.08696 .01472 m
.08696 .0702 L
.09317 .0702 L
.09317 .01472 L
.08696 .01472 L
s
.11801 .01472 m
.11801 .06079 L
.12422 .06079 L
.12422 .01472 L
F
.11801 .01472 m
.11801 .06079 L
.12422 .06079 L
.12422 .01472 L
.11801 .01472 L
s
.14907 .01472 m
.14907 .01504 L
.15528 .01504 L
.15528 .01472 L
F
.14907 .01472 m
.14907 .01504 L
.15528 .01504 L
.15528 .01472 L
.14907 .01472 L
s
.18012 .01472 m
.18012 .02672 L
.18634 .02672 L
.18634 .01472 L
F
.18012 .01472 m
.18012 .02672 L
.18634 .02672 L
.18634 .01472 L
.18012 .01472 L
s
.21118 .01472 m
.21118 .0556 L
.21739 .0556 L
.21739 .01472 L
F
.21118 .01472 m
.21118 .0556 L
.21739 .0556 L
.21739 .01472 L
.21118 .01472 L
s
.24224 .01472 m
.24224 .04976 L
.24845 .04976 L
.24845 .01472 L
F
.24224 .01472 m
.24224 .04976 L
.24845 .04976 L
.24845 .01472 L
.24224 .01472 L
s
.27329 .01472 m
.27329 .02348 L
.2795 .02348 L
.2795 .01472 L
F
.27329 .01472 m
.27329 .02348 L
.2795 .02348 L
.2795 .01472 L
.27329 .01472 L
s
.30435 .01472 m
.30435 .05073 L
.31056 .05073 L
.31056 .01472 L
F
.30435 .01472 m
.30435 .05073 L
.31056 .05073 L
.31056 .01472 L
.30435 .01472 L
s
.3354 .01472 m
.3354 .05333 L
.34161 .05333 L
.34161 .01472 L
F
.3354 .01472 m
.3354 .05333 L
.34161 .05333 L
.34161 .01472 L
.3354 .01472 L
s
.36646 .01472 m
.36646 .05008 L
.37267 .05008 L
.37267 .01472 L
F
.36646 .01472 m
.36646 .05008 L
.37267 .05008 L
.37267 .01472 L
.36646 .01472 L
s
.39752 .01472 m
.39752 .06079 L
.40373 .06079 L
.40373 .01472 L
F
.39752 .01472 m
.39752 .06079 L
.40373 .06079 L
.40373 .01472 L
.39752 .01472 L
s
.42857 .01472 m
.42857 .07442 L
.43478 .07442 L
.43478 .01472 L
F
.42857 .01472 m
.42857 .07442 L
.43478 .07442 L
.43478 .01472 L
.42857 .01472 L
s
.45963 .01472 m
.45963 .04165 L
.46584 .04165 L
.46584 .01472 L
F
.45963 .01472 m
.45963 .04165 L
.46584 .04165 L
.46584 .01472 L
.45963 .01472 L
s
.49068 .01472 m
.49068 .03289 L
.49689 .03289 L
.49689 .01472 L
F
.49068 .01472 m
.49068 .03289 L
.49689 .03289 L
.49689 .01472 L
.49068 .01472 L
s
.52174 .01472 m
.52174 .0212 L
.52795 .0212 L
.52795 .01472 L
F
.52174 .01472 m
.52174 .0212 L
.52795 .0212 L
.52795 .01472 L
.52174 .01472 L
s
.5528 .01472 m
.5528 .03873 L
.55901 .03873 L
.55901 .01472 L
F
.5528 .01472 m
.5528 .03873 L
.55901 .03873 L
.55901 .01472 L
.5528 .01472 L
s
.58385 .01472 m
.58385 .07117 L
.59006 .07117 L
.59006 .01472 L
F
.58385 .01472 m
.58385 .07117 L
.59006 .07117 L
.59006 .01472 L
.58385 .01472 L
s
.61491 .01472 m
.61491 .0371 L
.62112 .0371 L
.62112 .01472 L
F
.61491 .01472 m
.61491 .0371 L
.62112 .0371 L
.62112 .01472 L
.61491 .01472 L
s
.64596 .01472 m
.64596 .04911 L
.65217 .04911 L
.65217 .01472 L
F
.64596 .01472 m
.64596 .04911 L
.65217 .04911 L
.65217 .01472 L
.64596 .01472 L
s
.67702 .01472 m
.67702 .04197 L
.68323 .04197 L
.68323 .01472 L
F
.67702 .01472 m
.67702 .04197 L
.68323 .04197 L
.68323 .01472 L
.67702 .01472 L
s
.70807 .01472 m
.70807 .0543 L
.71429 .0543 L
.71429 .01472 L
F
.70807 .01472 m
.70807 .0543 L
.71429 .0543 L
.71429 .01472 L
.70807 .01472 L
s
.73913 .01472 m
.73913 .06176 L
.74534 .06176 L
.74534 .01472 L
F
.73913 .01472 m
.73913 .06176 L
.74534 .06176 L
.74534 .01472 L
.73913 .01472 L
s
.77019 .01472 m
.77019 .03418 L
.7764 .03418 L
.7764 .01472 L
F
.77019 .01472 m
.77019 .03418 L
.7764 .03418 L
.7764 .01472 L
.77019 .01472 L
s
.80124 .01472 m
.80124 .0238 L
.80745 .0238 L
.80745 .01472 L
F
.80124 .01472 m
.80124 .0238 L
.80745 .0238 L
.80745 .01472 L
.80124 .01472 L
s
.8323 .01472 m
.8323 .03159 L
.83851 .03159 L
.83851 .01472 L
F
.8323 .01472 m
.8323 .03159 L
.83851 .03159 L
.83851 .01472 L
.8323 .01472 L
s
.86335 .01472 m
.86335 .02672 L
.86957 .02672 L
.86957 .01472 L
F
.86335 .01472 m
.86335 .02672 L
.86957 .02672 L
.86957 .01472 L
.86335 .01472 L
s
.89441 .01472 m
.89441 .05495 L
.90062 .05495 L
.90062 .01472 L
F
.89441 .01472 m
.89441 .05495 L
.90062 .05495 L
.90062 .01472 L
.89441 .01472 L
s
.92547 .01472 m
.92547 .04619 L
.93168 .04619 L
.93168 .01472 L
F
.92547 .01472 m
.92547 .04619 L
.93168 .04619 L
.93168 .01472 L
.92547 .01472 L
s
.95652 .01472 m
.95652 .05203 L
.96273 .05203 L
.96273 .01472 L
F
.95652 .01472 m
.95652 .05203 L
.96273 .05203 L
.96273 .01472 L
.95652 .01472 L
s
.98758 .01472 m
.98758 .02315 L
.99379 .02315 L
.99379 .01472 L
F
.98758 .01472 m
.98758 .02315 L
.99379 .02315 L
.99379 .01472 L
.98758 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:_ooool3o`0000[ooooo1Ol0000:ooooo`?o00003?ooool3o`0000[ooooo0ol0000;oooo
o`?o00003?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`0000Wooooo0ol00004oooo
o`;o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00000_ooool5o`0000Cooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003oooo
o`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool5o`0000;ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`?o00000oooool5o`0000;ooooo0ol00004ooooo`Go00000_ooool3o`0000Cooooo1Ol00003oooo
o`03o`000?oooooooooo00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000;ooooo0_l00006oooo
o`?o00001?ooool2o`0000Gooooo0ol00003ooooo`?o00001Oooool3o`0000;ooooo1Ol0000Aoooo
o`00:oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Aooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooooooo`07ooooo`Co00003Oooool00ol0003oooooooooo`09ooooo`?o0000
2oooool4o`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol00007ooooo`04
o`000?ooooooooooooooo`Co00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool04?ooool0
02_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000:ooooo`Co00002_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00006ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool03oooool002[ooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0
003oooooooooo`05ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
1ol0003ooooooooooooooooo0000ooooool000001oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`Go00002oooool2o`0000[ooooo1Ol0000:ooooo`?o00002ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool5o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00Co0000oooooooooooooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0ol00004ooooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool5o`0000Cooooo0ol00004ooooo`;o
00001Oooool3o`0000;ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`?o
00001Oooool3o`0000Cooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`?o
00000oooool3o`0001;ooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Soooooooo0000aOl0000=
ooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Oooooo00?o0000ooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00_ooooo000I
ooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ool000?o0?l00_l00?l5oomo0004o`000?oo
003oo`00ool000?o0?l00_l00?l4oomo00;o00000ooo0003o`3o00;o003o1?ooO`02o`0000?oo`00
0ol0o`02o`00o`Coogl00_l00003ool000?o0?l00_l00?l4oomo00;o00000ooo0003o`3o00;o003o
1?ooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o0000
0ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl0
0_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`00
0ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o
0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o0000
0ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l0
0ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl0
0_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o0oooO`02o`0000?oo`00
0ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00;o00000ooo0003o`3o00?o003o
0oooO`02o`0000?oo`000ol0o`03o`00o`?oogl00_l00003ool000?o0?l00ol00?l3oomo00?o0000
3Oooool001Wooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?l5ooooo`Coo`000_ooool2o`00o`Coogl00_ooool4ool000;ooooo0_l00?l4oomo00;ooooo
1?oo0002ooooo`;o003o1?ooO`05ooooo`?o0?l00ol00?l5ooooo`?oo`000ol0o`02o`00o`Coogl0
0_ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`02ooooo`?oo`00
0ol0o`03o`00o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl0
0_ooool4ool000Gooooo0oooO`02ooooo`?oo`000ol0o`03o`00o`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool3ool000?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
1?oo0005ooooo`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool000;ooooo0_l00?l4oomo00;ooooo
1?oo0004ooooo`Coogl00_ooool4ool000;ooooo0_l00?l4oomo00Gooooo0ol0o`03o`00o`Sooooo
0ol0o`02o`00o`Coogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo0002ooooo`?o003o
0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`02ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l0
0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo
0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo
00?o0000ooooooooool02oooool001[ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo0ol0
o`03o`00o`Gooooo1?oo0004ooooo`Coogl00_ooool4ool000Cooooo1?ooO`02ooooo`Coo`001?oo
ool4oomo00Gooooo0ol0o`03o`00o`Sooooo0ol0o`02o`00o`Coogl00_ooool4ool000;ooooo0ol0
0?l3oomo00;ooooo1?oo0002ooooo`?o003o0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo
0002ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Ooo
ool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0
o`03o`00o`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo
0005ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00;ooooo1?oo0004ooooo`Coogl00_ooool4
ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l8ooooo`?o0?l00_l00?l4oomo00;ooooo1?oo0002
ooooo`?o003o0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4
ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Coo`000_ooool3
o`00o`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05
ooooo`?o0?l01?l00?l4ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4
ool000Gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool4ool000Gooooo0oooO`0;
ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo0005
ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;
ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool0
00Cooooo1?ooO`0:ooooo`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l8oooo
o`?o0?l00_l00?l4oomo00;ooooo1?oo0002ooooo`?o003o0oooO`02ooooo`Coo`001Oooool3oomo
00Gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;oooo
o`?oogl00_ooool4ool000;ooooo0ol00?l3oomo00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo
00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`02oooo
o`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000;ooooo0ol00?l3oomo
00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00_ooooo0oooO`05ooooo`?o0?l00ol00?l3oomo
00;ooooo1?oo000:ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo
00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000:ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo1?oo0004ooooo`Co
ogl02_ooool4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o00?o003o2?ooool3o`3o00?o
003o1Oooool4ool000;ooooo0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co
003o1?ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`02ooooo`Co
o`000_ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Go
oooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?o
ogl00_ooool4ool000Gooooo0oooO`02ooooo`Coo`000_ooool3o`00o`?oogl00_ooool4ool000Go
oooo0oooO`0;ooooo`?oogl02oooool3oomo00Gooooo0ol0o`03o`00o`?oogl00_ooool4ool000[o
oooo1?oo0005ooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;o
oooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
0ol0o`03o`00o`Gooooo1?oo0004ooooo`Coogl02_ooool4oomo00;ooooo1?oo0004ooooo`Coogl0
1Oooool3o`3o00?o003o2?ooool3o`3o00?o003o1Oooool4ool000;ooooo0ol00?l3oomo00;ooooo
1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`02ooooo`Coo`00
1Oooool3oomo00_ooooo0oooO`08ooooo`?o003o0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl0
0_ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo0002ooooo`?o003o
0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00?o003o
0oooO`02ooooo`Coo`002_ooool4ool000Gooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo
0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo00?o0000ooooooooool02oooool002?ooooo0ol0
0003ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00[ooooo1?ooO`02ooooo`Coo`001?oo
ool4oomo00Gooooo0ol0o`03o`00o`Sooooo0ol0o`03o`00o`Gooooo1?oo0002ooooo`?o003o0ooo
O`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl00_oo
ool4ool000Gooooo0oooO`0;ooooo`?oogl02?ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`001Ooo
ool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`08ooooo`?o003o0ooo
O`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00?o003o0ooo
O`02ooooo`Coo`002_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00_ooooo0ooo
O`02ooooo`Coo`002Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00o`Gooooo1?oo0004ooooo`Coogl02_ooool4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3
o`3o00?o003o2?ooool3o`3o00?o003o1Oooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3
oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;
ooooo`?oogl02?ooool3o`00o`?oogl02oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4
ool000gooooo0ol0o`04o`00o`Cooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`02
ooooo`Coo`001Oooool3oomo00Sooooo0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3
oomo00_ooooo0oooO`05ooooo`?o0?l00ol00?l3oomo00;ooooo1?oo000:ooooo`Coo`002_ooool4
ool001?ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00o`Gooooo1?oo0004oooo
o`Coogl02_ooool4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o00?o003o2?ooool3o`3o
00?o003o1Oooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00Gooooo0ol0o`04o`00
o`Cooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`0;ooooo`?oogl02oooool3oomo
00_ooooo0oooO`02ooooo`Coo`001Oooool3oomo00;ooooo1?oo000=ooooo`?o0?l01?l00?l4oooo
o`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`08oooo
o`?o003o0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl01Oooool3o`3o
00Co003o1?ooool4ool000[ooooo1?oo000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`0;oooo
o`?oogl00_ooool4ool000[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool3o`3o00?o003o1Oooool4ool000Cooooo1?ooO`0:ooooo`Coogl00_ooool4ool000Co
oooo1?ooO`05ooooo`?o0?l00ol00?l8ooooo`?o0?l00ol00?l5ooooo`Coo`001Oooool3oomo00;o
oooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`0;ooooo`?o
ogl02oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo0oooO`02ooooo`Co
o`003Oooool3o`3o00Co003o1?ooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo00;o
oooo1?oo000@ooooo`?o003o0oooO`02ooooo`Coo`001Oooool3oomo00_ooooo0oooO`0;ooooo`?o
ogl01Oooool3o`3o00Co003o1?ooool4ool000[ooooo1?oo000:ooooo`Coo`004oooool3oomo00_o
oooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4ool000Cooooo1?ooO`0:ooooo`Coogl0
0_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l8ooooo`?o0?l00ol00?l5ooooo`Coo`00
1Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000Gooooo
0oooO`0;ooooo`?oogl02oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool000Gooooo
0oooO`02ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool000[ooooo1?oo0005ooooo`?oogl0
0_ooool4ool0013ooooo0ol00?l3oomo00;ooooo1?oo0005ooooo`?oogl02oooool3oomo00_ooooo
0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`002_ooool4ool000[ooooo1?oo000Cooooo`?oogl0
2oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`Coo`001?ooool4oomo00[ooooo1?oo
O`02ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`03o`00o`Sooooo0ol0o`03o`00o`Gooooo1?oo
0005ooooo`?oogl00_ooool4ool000Gooooo0oooO`05ooooo`?o0?l01?l00?l=ooooo`?oogl02ooo
ool3oomo00_ooooo0oooO`0;ooooo`?oogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Ooo
ool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02ooooo`Coo`004?ooool3o`00o`?oogl00_oo
ool4ool001?ooooo0oooO`0;ooooo`?oogl01Oooool3o`3o00Co003o1?ooool4ool000[ooooo1?oo
000:ooooo`Coo`004oooool3oomo00_ooooo0oooO`0;ooooo`?oogl00_ooool4ool000[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o1Oooool4
ool000Cooooo1?ooO`0:ooooo`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l8
ooooo`?o0?l00ol00?l5ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3
o`3o00Co003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl02oooool3oomo00_ooooo0oooO`02
ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4
ool001?ooooo0oooO`02ooooo`Coo`004oooool3oomo00_ooooo0oooO`05ooooo`?o0?l01?l00?l4
ooooo`Coo`002_ooool4ool000[ooooo1?oo000Cooooo`?oogl02oooool3oomo00_ooooo0oooO`02
ooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03oooo
o`?o0?l00ol00?l5ooooo`Coo`004_ooool4oomo00;ooooo1?oo0004ooooo`Coogl01Oooool3o`3o
00?o003o2?ooool3o`3o00?o003o1Oooool4ool000Gooooo0oooO`02ooooo`Coo`001Oooool3oomo
00Gooooo0ol0o`04o`00o`gooooo0oooO`0;ooooo`?oogl02oooool3oomo00_ooooo0oooO`0;oooo
o`?oogl00_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo
00;ooooo1?oo000Cooooo`?oogl00_ooool4ool001?ooooo0oooO`0;ooooo`?oogl01Oooool3o`3o
00Co003o1?ooool4ool000[ooooo1?oo000:ooooo`Coo`004oooool3oomo01Wooooo0oooO`02oooo
o`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo0ol0o`03o`00o`Go
oooo1?oo000Booooo`Coogl00_ooool4ool000Cooooo1?ooO`05ooooo`?o0?l00ol00?l8ooooo`?o
0?l00ol00?l5ooooo`Coo`001Oooool3oomo00;ooooo1?oo0005ooooo`?oogl01Oooool3o`3o00Co
003o3Oooool3oomo00_ooooo0oooO`0;ooooo`?oogl02oooool3oomo00_ooooo0oooO`02ooooo`Co
o`002_ooool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001So
oooo1?oo000Cooooo`?oogl02oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000:ooooo`Co
o`002_ooool4ool001?ooooo0oooO`0Iooooo`?oogl00_ooool4ool000Wooooo0_l0000=ooooo`00
8oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?l5ooooo`Coo`004_ooool4oomo00;ooooo
1?oo0004ooooo`Coogl01Oooool3o`3o00?o003o2?ooool3o`3o00?o003o1Oooool4ool000Gooooo
0oooO`02ooooo`Coo`003Oooool3o`3o00Co003o6oooool3oomo01Wooooo0oooO`0;ooooo`?oogl0
0_ooool4ool000[ooooo1?oo000=ooooo`?o0?l01?l00?l4ooooo`Coo`004oooool3oomo00;ooooo
1?oo000Hooooo`Coo`004oooool3oomo00_ooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`00
2_ooool4ool000[ooooo1?oo000Cooooo`?oogl06Oooool3oomo00;ooooo1?oo000:ooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oa_ooooo1?oo
O`02ooooo`Coo`001?ooool4oomo00Gooooo0ol0o`03o`00o`Sooooo0ol0o`03o`00o`kooooo0ooo
O`02ooooo`Coo`003Oooool3o`3o00Co003o=oooool3oomo00_ooooo0oooO`02ooooo`Coo`002_oo
ool4ool000gooooo0ol0o`04o`00o`Cooooo1?oo000Cooooo`?oogl00_ooool4ool001Sooooo1?oo
000Cooooo`?oogl02oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000:ooooo`Coo`002_oo
ool4ool001?ooooo0oooO`0Nooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?lKooooo`Coogl02_ooool4oomo00Gooooo0ol0o`03
o`00o`Sooooo0ol0o`03o`00oa?ooooo1?oo000=ooooo`?o0?l01?l00?lgooooo`?oogl02oooool3
oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o1?ooool4ool001?ooooo0oooO`02
ooooo`Coo`006?ooool4ool0027ooooo0oooO`05ooooo`?o0?l01?l00?l4ooooo`Coo`002_ooool4
ool000[ooooo1?oo000dooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`?o0?l00ol00?lKooooo`Coogl02_ooool4oomo00Gooooo0ol0o`03o`00
o`Sooooo0ol0o`03o`00obOooooo1?l00?lgooooo`?oogl02oooool3oomo00;ooooo1?oo000:oooo
o`Coo`003Oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo000Hooooo`Coo`008Oooool3oomo
00Gooooo0ol0o`04o`00o`Cooooo1?oo000:ooooo`Coo`002_ooool4ool003Cooooo1?oo000:oooo
o`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oa_o
oooo1?ooO`0:ooooo`Coogl01Oooool3o`3o00?o003o2oooool3o`00obOooooo1?l00?lgooooo`?o
ogl02oooool3oomo00;ooooo1?oo000:ooooo`Coo`003Oooool3o`3o00Co003o6oooool3oomo00;o
oooo1?oo000Hooooo`Coo`008Oooool3oomo00Gooooo0ol0o`04o`00o`Cooooo1?oo000:ooooo`Co
o`002_ooool4ool003Cooooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`00
0?oooooooooo00?ooooo0ol0o`03o`00oa_ooooo1?ooO`0Cooooo`?o0?l00ol00?l;ooooo`?o003o
9oooool4o`00odGooooo0oooO`02ooooo`Coo`002_ooool4ool000gooooo0ol0o`04o`00oa_ooooo
0oooO`02ooooo`Coo`006?ooool4ool002Wooooo0ol0o`04o`00o`Cooooo1?oo000:ooooo`Coo`00
2_ooool4ool003Cooooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo0ol0o`03o`00oa_ooooo1?ooO`0Cooooo`?o0?l00ol00?l;ooooo`?o003o9ooo
ool4o`00odGooooo0oooO`02ooooo`Coo`006oooool3o`3o00Co003o6oooool3oomo00;ooooo1?oo
000Hooooo`Coo`00:Oooool3o`3o00Co003o1?ooool4ool000[ooooo1?oo000:ooooo`Coo`00=?oo
ool4ool000[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool3
o`3o00?o003o6oooool4oomo01?ooooo0ol0o`03o`00o`_ooooo0ol00?lWooooo`Co003oAOooool3
oomo00;ooooo1?oo000Kooooo`?o0?l01?l00?lKooooo`?oogl00_ooool4ool004Sooooo1?l00?l4
ooooo`Coo`006?ooool4ool003Cooooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo000Soooo
o`?o00000oooool3o`3o00?o003o6oooool4oomo01?ooooo0ol0o`03o`00o`_ooooo0ol00?lWoooo
o`Co003oAOooool3oomo00;ooooo1?oo000Kooooo`?o0?l01?l00?lKooooo`?oogl00_ooool4ool0
04Sooooo1?l00?l4ooooo`Coo`006?ooool4ool003Cooooo1?oo0009ooooo`;o00003Oooool002?o
oooo00?o0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o2oooool3o`00obOo
oooo1?l00?m5ooooo`?oogl00_ooool4ool001_ooooo0ol0o`04o`00ob3ooooo1?oo0018ooooo`Co
003o1?ooool4ool001Sooooo1?oo000dooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o
9oooool4o`00odGooooo0oooO`02ooooo`Coo`006oooool3o`3o00Co003o8?ooool4ool004Sooooo
1?l00?l4ooooo`Coo`006?ooool4ool003Cooooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00o`_ooooo0ol0
0?lWooooo`Co003oB_ooool4ool001_ooooo0ol0o`04o`00ob3ooooo1?oo0018ooooo`Co003o1?oo
ool4ool001Sooooo1?oo000dooooo`Coo`002_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4
o`00od[ooooo1?oo000Kooooo`?o0?l01?l00?lPooooo`Coo`00B?ooool4o`00o`Cooooo1?oo000H
ooooo`Coo`00=?ooool4ool000[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o2oooool3o`00obOooooo1?l00?m:oooo
o`Coo`006oooool3o`3o00Co003o8?ooool4ool004Sooooo1?l00?l4ooooo`Coo`006?ooool4ool0
03Cooooo1?oo000:ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?o
oooo0ol0o`03o`00oc;ooooo0ol0o`03o`00o`_ooooo0ol00?lWooooo`Co003oB_ooool4ool001_o
oooo0ol0o`04o`00ob3ooooo1?oo0018ooooo`Co003o1?ooool4ool001Sooooo1?oo000dooooo`Co
o`002_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4o`00od[ooooo1?oo000Kooooo`?o0?l0
1?l00?lPooooo`Coo`00B?ooool4o`00o`Cooooo1?oo000Hooooo`Coo`00=?ooool4ool000[ooooo
00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`?o0?l00ol00?lbooooo`?o0?l00ol0
0?l;ooooo`?o003o9oooool4o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?l4ooooo`Coo`006?oo
ool4ool0047ooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?lb
ooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?l4
ooooo`Coo`006?ooool4ool004;ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooo
ooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o2oooool3o`00obOooooo1?l00?mYoooo
o`?o0?l01?l00?m/ooooo`Co003o1?ooool4ool001Sooooo1?oo0012ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00o`_o
oooo0ol00?lWooooo`Co003oJOooool3o`3o00Co003oK?ooool4o`00o`Cooooo1?oo000Hooooo`Co
o`00@_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l0
0ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4o`00ofWooooo0ol0o`04o`00ofcooooo
1?l00?l4ooooo`Coo`006?ooool4ool004;ooooo00?o0000ooooooooool02oooool002?ooooo00?o
0000ooooooooool00oooool3o`3o00?o003o<_ooool3o`3o00?o003o2oooool3o`00obOooooo1?l0
0?mYooooo`?o0?l01?l00?m/ooooo`Co003o1?ooool4ool001Sooooo1?oo0012ooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4
o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?l4ooooo`Coo`006?ooool4ool004;ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00oc;ooooo0ol0o`03o`00o`_ooooo0ol00?lW
ooooo`Co003oJOooool3o`3o00Co003oK?ooool4o`00o`Cooooo1?oo000Hooooo`Coo`00@_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo1?l00002ooooo`?o0?l00ol00?lbooooo`?o0?l00ol00?l;ooooo`?o003o9oooool4
o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?l4ooooo`Coo`00Foooool4o`0000gooooo000=oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`?o0?l00ol00?leooooo`?o003o2oooool3o`00obOooooo1?l00?mYooooo`?o0?l01?l00?m/
ooooo`Co003o1?ooool4ool005kooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03
o`00ocGooooo0ol00?l;ooooo`?o003o9oooool4o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?mV
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo0_l00008
ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?l;ooooo`?o003o9oooool4
o`00ofWooooo0ol0o`04o`00ofcooooo1?l00?mVooooo`03o`000?oooooooooo00_ooooo000>oooo
o`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00
ocGooooo0ol00?l;ooooo`?o003o9oooool4o`00ofcooooo1?l00?m/ooooo`Co003oI_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o
003o2oooool3o`00obOooooo1?l00?m/ooooo`Co003oK?ooool4o`00ofKooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool3o`3o00?o003o=Oooool3o`00o`_ooooo
0ol00?lWooooo`Co003oK?ooool4o`00ofcooooo1?l00?mVooooo`03o`000?oooooooooo00_ooooo
000Sooooo`03o`000?oooooooooo00?ooooo0ol0o`03o`00ocGooooo0ol00?l;ooooo`?o003o9ooo
ool4o`00ofcooooo1?l00?m/ooooo`Co003oI_ooool00ol0003oooooooooo`0;ooooo`008oooool0
0ol0003oooooooooo`03ooooo`?o0?l00ol00?leooooo`?o003o2oooool3o`00obOooooo1?l00?m/
ooooo`Co003oK?ooool4o`00ofKooooo00?o0000ooooooooool02oooool002?ooooo0ol00003oooo
o`Co0?l0=oooool3o`00o`_ooooo0ol00?lWooooo`Co003oK?ooool4o`00ofcooooo1?l00?mUoooo
o`;o00003Oooool002?ooooo00?o0000ooooooooool00oooool4o`3o03Oooooo0ol00?l;ooooo`?o
003o9oooool4o`00ofcooooo1?l00?m/ooooo`Co003oI_ooool00ol0003oooooooooo`0;ooooo`00
8oooool00ol0003oooooooooo`03ooooo`Co0?l0=oooool3o`00o`_ooooo0ol00?lWooooo`Co003o
K?ooool4o`00ofcooooo1?l00?mVooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`0gooooo`?o003o2oooool3o`00obOooooo1?l00?m/ooooo`Co003oK?oo
ool4o`00ofKooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4
o`3o03Oooooo0ol00?l;ooooo`?o003o9oooool4o`00ofcooooo1?l00?m/ooooo`Co003oI_ooool0
0ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0=oooool3o`00
o`_ooooo0ol00?lWooooo`Co003oK?ooool4o`00ofcooooo1?l00?mVooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`0gooooo`?o003o2oooool3o`00obOo
oooo1?l00?m/ooooo`Co003oK?ooool4o`00ofKooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o03Oooooo0ol00?l;ooooo`?o003o9oooool4o`00ofcooooo
1?l00?m/ooooo`Co003oI_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0
o`0gooooo`?o003o2oooool3o`00obOooooo1?l00?m/ooooo`Co003oK?ooool4o`00ofGooooo0_l0
000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0=oooool3o`00o`_ooooo0ol00?lW
ooooo`Co003oK?ooool4o`00ofcooooo1?l00?mVooooo`03o`000?oooooooooo00_ooooo000Soooo
o`03o`000?oooooooooo00?ooooo1?l0o`0gooooo`?o003o2oooool3o`00obOooooo1?l00?m/oooo
o`Co003oK?ooool4o`00ofKooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o03Oooooo0ol00?leooooo`Co003oK?ooool4o`00ofcooooo1?l00?mVooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`0gooooo`?o003o
=Oooool4o`00ofcooooo1?l00?m/ooooo`Co003oI_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0=oooool3o`00ocGooooo1?l00?m/ooooo`Co003oK?oo
ool4o`00ofKooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4
o`3o03Oooooo0ol00?leooooo`Co003oK?ooool4o`00ofcooooo1?l00?mVooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`0gooooo`?o003o=Oooool4o`00
ofcooooo1?l00?oFooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o03Oo
oooo0ol00?nUooooo`Co003oeOooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo
1?l0o`0gooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`0gooooo`?o003ooooooon0ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`0gooooo`?o003ooooooon0ooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003o
ooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`00
0?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o
0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooo
oooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01_ooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000=
ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool000kooooo0_l00009ooooo`?o00001ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;oooo
o`008oooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Oooooo1?l00002ooooo`Co0?l0
oooooongooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooookWooooo
0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`Co0?l0ooooooniooooo`;o
00003Oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooookWooooo0_l0000=
ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo
000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02ooo
ool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o
0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`003Oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
1oooool4o`0000;ooooo1?l0o`3ooooookOooooo1?l0000=ooooo`003Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool4o`3o0?oooooo
^_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`;o0000
1oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo
000>ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03oooo
o`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?o
oooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool0
0oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0
o`3ooooookWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03oooo
o`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oo
oooo^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0
o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4
o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0000?ooooo1?l0o`3ooooo
okWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonj
ooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooo
ok[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oo
oooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0
oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o00000oooool4o`3o0?oooooo^Ooo
ool2o`0000gooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_oo
ool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Oooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool4o`0000;ooooo1?l0
o`3ooooookOooooo1?l0000=ooooo`003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol0003ooooooooo
o`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`Co0?l0oooo
oonjooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002?ooool5o`0000Kooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008ooo
ool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o00000oooool4o`3o0?oooooo^Oooool2o`0000gooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0
003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03
o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo
0ol00003ooooo`Co0?l0ooooooniooooo`;o00003Oooool002?ooooo00?o0000ooooooooool00ooo
ool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000
ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
00?ooooo1?l0o`3ooooookWooooo0_l0000=ooooo`008oooool00ol0003oooooooooo`03ooooo`Co
0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo
ool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03
ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo
00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000oooooooo
ool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003ooooo
ooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oo
oooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo0ol00003
ooooo`Co0?l0ooooooniooooo`;o00003Oooool002?ooooo00?o0000ooooooooool00oooool4o`3o
0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co
0?l0oooooonjooooo`03o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo
1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool00ooo
ool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool0
0ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Oooooo1?l00002ooooo`Co0?l0
oooooongooooo`Co00003Oooool000gooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool0
2oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000ooooooooool02oooool000kooooo0_l0
000:ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03
o`000?oooooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo
00?o0000ooooooooool02oooool002?ooooo0ol00003ooooo`Co0?l0ooooooniooooo`;o00003Ooo
ool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003oooooooooo`0;
ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oooooooooo
00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000oooooooo
ool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0003ooooo
ooooo`0;ooooo`008oooool00ol0003oooooooooo`03ooooo`Co0?l0oooooonjooooo`03o`000?oo
oooooooo00_ooooo000Sooooo`03o`000?oooooooooo00?ooooo1?l0o`3ooooook[ooooo00?o0000
ooooooooool02oooool002?ooooo00?o0000ooooooooool00oooool4o`3o0?oooooo^_ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0003ooooool3ooooo0_l0000=ooooo`008oooool00ol0003ooooooooo
o`3ooooool7ooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool002?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool002?ooooo
ool00035o`0000gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000Zooooo`?o00002_ooool5o`00
00[ooooo0ol0000<ooooo`?o00002_ooool3o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo
00[ooooo0ol0000;ooooo`;o00002Oooool3o`0000Cooooo0_l00005ooooo`?o00000oooool3o`00
00Gooooo0ol00002ooooo`Go00001?ooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool3o`00
00Cooooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool00ol0
003oooooooooo`04ooooo`?o00000oooool3o`0000Gooooo0ol00003ooooo`;o00001Oooool5o`00
00?ooooo0_l00004ooooo`Go00000_ooool3o`0000Cooooo1Ol000000ooooooo0000o`000003o`00
00?ooooo1Ol00002ooooo`?o00001?ooool5o`0000?ooooo0ol00003ooooo`Go00000_ooool3o`00
00Cooooo1Ol00002ooooo`?o00001?ooool5o`0000?ooooo00?o0000ooooooooool00oooool5o`00
00;ooooo0ol00004ooooo`Go00000_ooool2o`0000Kooooo0ol00004ooooo`;o00001Oooool3o`00
00?ooooo0ol00005ooooo`?o00000_ooool5o`00017ooooo000[ooooo`03o`000?oooooooooo00[o
oooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00017ooooo000[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`Go00003Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooooooool5o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go0000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000004oooool002_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0:ooooo`;o00002_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo00Oooooo
1?l0000=ooooo`03o`000?oooooooooo00Wooooo0ol0000;ooooo`Co00002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`Co00001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooooooool3o`0000Oooooo00Co0000oooooooooooooooo1?l00005oooo
o`;o00000oooool01?l0003oooooooooool00005ooooo`;o00001?ooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
000000[ooooo1?l0000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001_ooool01?l0003oooooooooooooool4o`0000Kooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko
0000oooooooooooo0000ooooool00004ooooo`06o`000?ooooooooooooooool0003ooooo1?l00004
ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0?ooooo`00:_oo
ool2o`0000_ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool0
00002oooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`;o0000
1?ooool2o`0000Kooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00001Oooool2o`0000Gooooo0_l00003oooo
o`03o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00001Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooooooo0_l00004ooooo`07o`000?ooooooooooooooool0003ooooo
o`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000Gooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool03oooool002_ooooo00?o
0000ooooooooool02_ooool3o`0000_ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo1Ol0
000;ooooo`;o00002_ooool5o`0000[ooooo0ol0000;ooooo`?o00002Oooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`Go0000
1Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool01?l0003oooooooooooooool5o`0000Go
oooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000?o
oooo0ol00005ooooo`?o00000oooool3o`0000Gooooo0ol00005ooooo`03o`000?oooooooooo00?o
oooo0ol00002ooooo`Go00001?ooool3o`0000Cooooo0_l00005ooooo`?o00000_ooool5o`0000Co
oooo0ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00005ooooo`?o00001?ooool2o`0000Go
oooo0ol00004ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`?o00004_ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-1.85349, -0.0510305, 0.0713992, \
0.00239861}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(289.246972`8.912813814704634\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .46702 L
.2381 .46702 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .46702 L
.2381 .46702 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01564 L
.71429 .01564 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01564 L
.71429 .01564 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .14726 L
.95238 .14726 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .14726 L
.95238 .14726 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF80000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF80000000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF80000000FF0000FFFF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF00000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF00000000FFFF8000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
0000FF0000FFFF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01272 L
.2381 .01272 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01272 L
.2381 .01272 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .34729 L
.47619 .34729 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .34729 L
.47619 .34729 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .26302 L
.71429 .26302 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .26302 L
.71429 .26302 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FFFF8000FF80000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FFFF8000FF0000FF80000000FF
FF80000000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF80000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF0000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FFFF8000FF80000000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00FF8000
FF80000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01606 L
.2381 .01606 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01606 L
.2381 .01606 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .07988 L
.47619 .07988 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .07988 L
.47619 .07988 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .47995 L
.71429 .47995 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .47995 L
.71429 .47995 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .06591 L
.95238 .06591 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .06591 L
.95238 .06591 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF00000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000
FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF8000
FF80000000FF0000FF0000FFFF8000
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF0000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF00000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FFFF8000
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF80000000FF0000FFFF8000
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FFFF80000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FFFF8000
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .17333 L
.2381 .17333 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .17333 L
.2381 .17333 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .04901 L
.71429 .04901 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .04901 L
.71429 .04901 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .40757 L
.95238 .40757 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .40757 L
.95238 .40757 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF00000000FF0000FF0000FFFF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF80000000FFFF0000FF8000FF00000000FFFF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000
FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF0000FF80000000FFFF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000
0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF0000FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF0000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF80000000FFFF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF80000000FF0000FFFF8000FF0000
FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF0000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
0000FF0000FFFF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF80000000FFFF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF0000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF80000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF0000
0000FF0000FFFF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FFFF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000
FF8000FF80000000FFFF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF80000000FF
FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF80000000FFFF00000000FFFF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF00000000FF
FF8000FF8000FF8000FF0000FF80000000FFFF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF0000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF0000FF8000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF80000000FFFF8000FF8000FF0000FF0000
FF0000FF8000FF80000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF00000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF00000000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .44429 L
.2381 .44429 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .44429 L
.2381 .44429 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .10867 L
.47619 .10867 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .10867 L
.47619 .10867 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .05047 L
.71429 .05047 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .05047 L
.71429 .05047 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03838 L
.95238 .03838 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03838 L
.95238 .03838 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF800000FF00
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF8000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF8000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF8000FF8000
FF0000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF8000FF0000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000
FF000000FF0000FF0000FF00FF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF000000FF000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF00FF00000000FFFF8000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF80000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF00000000FFFF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF00FF00000000FFFF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF8000FF00000000FFFF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF000000FF00
00FF00FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF8000
00FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF8000
00FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF000000FFFF0000FF0000FF0000FF00000000FF00FF0000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF00000000FFFF0000FF0000FF8000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF00FF0000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF00FF000000FF00FF0000FF0000
FF00000000FF00FF00FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF000000FF00
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF00FF00FF0000FF000000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FF
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF000000FF00
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
FF0000FF000000FF000000FFFF0000FF00000000FF00FF0000FF00FF000000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF000000FFFF0000FF00000000FF00FF0000FF00FF000000FF00FF0000
FF000000FF0000FF00FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF80000000FFFF0000FF0000
FF0000FF0000FF000000FF00FF8000FF000000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF00FF00FF000000FF00FF0000
FF0000FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF000000FF00
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF00000000FFFF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000
FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF800000FF000000FF0000FFFF00000000FFFF0000FF000000FF0000FF00
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF000000FFFF0000FF00000000FFFF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FF00FF00FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF000000FFFF0000FF00000000FFFF000000FF00FF800000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF8000FF0000FF0000
FF00000000FF00FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF000000FF00
00FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000
FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF00FF8000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF00FF0000FF0000FF00FF8000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000
00FF00FF0000FF0000FF00000000FF
00FF0000FF0000FF00FF0000FF00000000FFFF000000FF00FF8000FF000000FF000000FF
FF0000FF0000FF800000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF00
FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF8000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000
FF000000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF0000FF00
FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF00FF00FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF800000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00000000FFFF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000
0000FF00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF0000
FF0000FF0000FF000000FF00FF0000
00FF00FF0000FF000000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF000000FF00FF0000
00FF0000FF00FF000000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF00FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00
FF000000FF00FF8000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF8000FF800000FF00FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF000000FF00FF000000FF00FF0000FF000000FF000000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .14309 L
.2381 .14309 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .14309 L
.2381 .14309 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .41988 L
.47619 .41988 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .41988 L
.47619 .41988 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .05694 L
.71429 .05694 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .05694 L
.71429 .05694 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0219 L
.95238 .0219 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0219 L
.95238 .0219 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF00000000FF00FF0000FF0000FF00FF0000FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000
0000FFFF8000FF80000000FFFF0000
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FF00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF00000000FFFF0000
FF0000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF80000000FFFF0000
FF8000FF800000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
00FF000000FF00FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF00000000FFFF0000
FF0000FF8000FF8000FF8000FF0000
00FF00FF800000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00
FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000FF0000
0000FFFF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00
FF000000FF000000FF00FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FFFF0000
0000FF0000FFFF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF00FF800000FF000000FFFF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF00000000FFFF0000
0000FF0000FFFF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000
00FF0000FF0000FF000000FFFF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FFFF0000
FF00000000FFFF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF0000
FF0000FF8000FF8000FF8000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF000000FF0000FFFF00000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF80000000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF000000FFFF0000
00FF00FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF000000FFFF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FFFF80000000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF000000FFFF0000
FF0000FF00000000FFFF0000FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF000000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
0000FF00FF0000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF00FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF00FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000
FF000000FF000000FF00FF00FF000000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF00000000FFFF000000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FF00FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF00000000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FF00FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF000000FFFF00000000FF
FF0000FF00000000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF80000000FF00FF0000FF000000FFFF00000000FF
0000FFFF0000FF800000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF80000000FF00FF0000FF00FF8000FF0000FF8000
FF800000FF00FF800000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF00000000FF00FF0000FF00FF000000FF00FF0000
FF800000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF000000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF0000FF800000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF8000FF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF800000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF000000FF00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF000000FF00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00
0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00
0000FF00FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00000000FF00FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF000000FFFF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF000000FFFF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF00000000FF0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF000000FFFF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF000000FFFF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF0000FF80000000FF0000FFFF0000FF8000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF00000000FF0000FF0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF000000FFFF00000000FFFF0000FF0000FF0000FF800000FF0000FF0000FF0000FF00
FF000000FF000000FFFF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF00000000FF00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF00FF00FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .24571 L
.2381 .24571 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .24571 L
.2381 .24571 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .13036 L
.47619 .13036 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .13036 L
.47619 .13036 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .15998 L
.71429 .15998 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .15998 L
.71429 .15998 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .10575 L
.95238 .10575 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .10575 L
.95238 .10575 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF000000FF0000FF00FF0000
FF00000000FFFF000000FF00FF8000FF0000FF00000000FF0000FFFF8000FF8000FF0000
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000
FF80000000FFFF0000FF000000FF0000FF00FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF800000FF00FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF00000000FFFF80000000FFFF0000FF0000
FF0000FF00000000FFFF00000000FF
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF000000FF0000FF0000FF00
FF8000FF8000FF0000FF0000FF000000FF00FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF8000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00FF0000FF0000
FF00000000FFFF8000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF0000
0000FF0000FF0000FFFF80000000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF8000FF000000FF0000FF0000FF00
FF0000FF0000FF000000FF00FF000000FF0000FF000000FF0000FF0000FF0000FFFF0000
FF0000FF8000FF8000FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000
FF8000FF8000FF000000FF0000FF00FF00000000FF0000FFFF80000000FF0000FFFF8000
FF0000FF80000000FFFF80000000FFFF8000FF8000FF8000FF0000FF0000FF00000000FF
0000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
0000FF0000FF0000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF0000FF0000FF000000FF00
FF000000FF00FF000000FF000000FF00FF00FF0000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000
0000FFFF8000FF0000FF000000FF00FF00000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF80000000FF
0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF800000FF00FF0000FF8000FF0000FF8000FF00000000FF
0000FF0000FF0000FFFF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
FF8000FF00000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF00000000FFFF00000000FF
FF8000FF8000FF000000FF0000FF00FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF00000000FF00FF00FF8000FF0000
FF8000FF0000FF000000FF00FF0000FF8000FF0000FF8000FF8000FF8000FF00000000FF
0000FF0000FF0000FFFF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF00000000FFFF0000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF00000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FFFF0000FF0000FF800000FF00FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FFFF8000FF0000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FFFF000000FF00
FF80000000FF0000FFFF00000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF000000FF0000FF00
FF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000FF0000
FF00000000FFFF8000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF0000FF00000000FF0000FF0000FF0000FFFF8000FF000000FF00
00FF00FF00000000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
00FF00FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000
FF000000FF000000FFFF0000FF00000000FFFF8000FF8000FF0000FF80000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF00FF000000FFFF00000000FF0000FF0000FF0000FFFF000000FF0000FF00
00FF00FF0000FF0000FF8000FF800000FF00FF0000FF80000000FFFF8000FF00000000FF
00FF00FF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF00FF00000000FFFF0000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF8000
FF8000FF8000FF000000FF0000FF0000FF00FF0000FF000000FF00FF00000000FFFF0000
FF0000FF8000FF00000000FFFF000000FF00FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF800000FF000000FFFF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF00000000FF00FF0000FF0000FF00FF0000FF8000FF0000FF0000FF8000
00FF0000FF000000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF80000000FFFF8000FF0000
FF0000FF80000000FF00FF0000FF0000FF00FF0000FF0000FF000000FF000000FFFF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF0000
FF000000FF0000FF000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF800000FF0000FF00FF00000000FFFF8000FF0000FF0000FF8000
00FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF00000000FFFF0000FF0000FF0000FF000000FF00
FF0000FF0000FF8000FF000000FF0000FF00FF0000FF0000FF000000FF000000FFFF0000
FF0000FF8000FF0000FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF0000FF00000000FF00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00FF000000FF000000FFFF0000
FF0000FF8000FF0000FF000000FF00FF00000000FFFF0000FF8000FF8000FF0000FF0000
FF000000FF000000FFFF0000FF00000000FF0000FFFF8000FF0000FF00000000FFFF0000
FF80000000FF0000FFFF0000FF8000FF8000FF00000000FFFF8000FF80000000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000
FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF8000FF0000
FF0000FF0000FF8000FF0000FF000000FF0000FF0000FF00FF000000FF000000FF00FF00
FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF000000FF00FF8000FF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF0000
FF00000000FFFF0000FF0000FF0000
FF0000FF000000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FF0000FF0000FFFF0000
0000FF0000FFFF8000FF8000FF000000FF0000FF0000FF0000FF00FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
0000FF00FF00FF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
00FF000000FFFF0000FF0000FF8000
00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF800000FF000000FF
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
0000FF0000FF0000FF0000FFFF000000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF00000000FF00FF00FF0000FF0000FF00000000FF0000FFFF8000FF8000FF8000
0000FF00FF0000FF000000FF0000FFFF0000FF8000FF0000FF8000FF000000FF00FF0000
0000FFFF00000000FFFF8000FF0000FF80000000FFFF8000FF8000FF80000000FFFF0000
FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF0000FF00FF0000FF00000000FFFF0000FF8000FF800000FF000000FF
FF00000000FFFF8000FF0000FF0000FF0000FF8000FF0000FF8000FF00000000FFFF8000
0000FF0000FF0000FF0000FFFF000000FF0000FF00FF000000FF00FF000000FF00FF0000
FF0000FF8000FF80000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FFFF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
0000FF0000FFFF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF80000000FF
FF000000FF0000FF0000FF0000FF0000FF000000FFFF8000FF0000FF800000FF00FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF80000000FFFF80000000FF0000FFFF8000
0000FF0000FFFF80000000FFFF000000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF8000FF8000FF8000FF8000FF000000FF00FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FF0000FF00FF00FF8000FF000000FF00FF8000FF80000000FFFF8000
FF8000FF0000FF8000FF80000000FF
FF0000FF000000FF0000FF0000FF00FF0000FF8000FF0000FF0000FF8000FF00000000FF
FF0000FF0000FF8000FF8000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF
0000FF0000FFFF8000FF800000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
FF0000FF80000000FFFF8000FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF000000FF0000FF0000FF0000FF000000FFFF8000
FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FF
0000FF0000FFFF8000FF800000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF00000000FF0000FFFF00000000FFFF000000FF000000FF0000FF0000FF0000FF0000FF
FF00000000FFFF80000000FFFF8000FF0000FF00000000FFFF0000FF00000000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF00FF0000FF8000
FF80000000FF0000FF0000FF0000FF
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF8000FF0000FF0000FF00000000FF00FF000000FFFF00000000FF0000FF
0000FF0000FFFF8000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF000000FF
FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF8000FF8000FF0000FF00000000FFFF0000FF80000000FFFF8000
0000FFFF8000FF8000FF0000FF0000FF0000FF80000000FF00FF0000FF00FF0000FF0000
FF8000FF80000000FF0000FF0000FF
FF0000FF8000FF000000FF00FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000
0000FF00FF000000FFFF0000FF0000FF00000000FF00FF000000FFFF00000000FF0000FF
0000FF0000FFFF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF000000FF
0000FFFF80000000FFFF000000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF80000000FF0000FF0000FF
00FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF800000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FF0000FF
0000FFFF8000FF00000000FF00FF0000FF00FF0000FF000000FF0000FF0000FF000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF80000000FFFF8000FF8000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF80000000FFFF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF00000000FF
FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF000000FF
FF8000FF8000FF00000000FF00FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FFFF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF00000000FF00FF00FF0000FF00000000FFFF0000FF0000
FF0000FF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF8000FF00000000FF
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00000000FF0000FF
FF80000000FFFF00000000FF00FF0000FF0000FF0000FF0000FF00FF000000FF000000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF8000
FF80000000FFFF80000000FF0000FFFF80000000FFFF000000FF0000FF0000FF00FF0000
FF0000FF8000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF80000000FF0000FF
0000FF00FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF00
00FF00FF00000000FFFF000000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF
FF80000000FFFF00000000FF00FF0000FF0000FF00FF000000FF00FF000000FF000000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF0000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00000000FFFF0000FF8000FF8000
0000FF0000FFFF80000000FF0000FF
FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF80000000FF0000FF
0000FF0000FFFF00000000FF00FF0000FF0000FF00FF0000FF0000FF000000FF000000FF
0000FFFF00000000FFFF0000FF8000FF8000FF0000FF00000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF000000FF00FF800000FF00FF00000000FF0000FF0000FFFF8000
0000FF0000FFFF00000000FF0000FF
0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF000000FFFF00000000FFFF8000
0000FFFF80000000FF0000FF00FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000
FF0000FF00000000FFFF000000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF800000FF0000FF0000FF00FF00000000FF
FF00000000FFFF0000FF000000FF0000FF00FF0000FF0000FF80000000FF0000FFFF8000
0000FFFF8000FF8000FF80000000FF
FF000000FF0000FF0000FF00FF0000FF00000000FFFF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF000000FFFF0000FF00000000FFFF000000FF00FF0000FF0000FF8000
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
FF0000FF80000000FFFF0000FF00000000FFFF8000FF000000FF00FF0000FF00000000FF
FF80000000FFFF8000FF0000FF000000FF00FF0000FF00000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF
0000FFFF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF000000FF0000FFFF00000000FFFF000000FF000000FF00FF000000FF
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF8000FF00000000FF00FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF8000FF8000FF0000FF00000000FF00FF00FF000000FF00FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF8000FF0000FF00000000FF0000FF
0000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF000000FF0000FF0000FF0000FFFF000000FF000000FF00FF00FF0000
FF00000000FFFF80000000FF00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF00000000FF00FF00FF0000FF0000FF0000FF80000000FFFF80000000FFFF8000
00FF0000FF000000FFFF000000FF0000FF0000FF00FF0000FF00000000FFFF00000000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FFFF80000000FF
FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FFFF000000FF00FF0000FF00000000FF
FF8000FF80000000FF0000FF0000FF00FF00FF0000FF000000FF0000FF0000FF00FF0000
FF8000FF00000000FF00FF00FF0000FF0000FF80000000FFFF80000000FF0000FFFF0000
FF000000FF000000FFFF000000FF0000FF0000FF00FF0000FF00000000FFFF00000000FF
0000FF0000FF0000FFFF8000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
0000FFFF8000FF00000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000
0000FFFF80000000FF0000FFFF0000FF000000FF00FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF80000000FF
FF00000000FF00FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF00FF0000FF000000FF
0000FFFF8000FF80000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
0000FFFF0000FF00000000FFFF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF80000000FFFF80000000FF0000FF0000FF
FF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF000000FF00FF0000FF00000000FF00FF0000FF000000FF
0000FF0000FFFF80000000FF0000FF
0000FFFF0000FF000000FF00FF0000FF00000000FF00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF8000FF0000
FF8000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000
00FF000000FFFF0000FF0000FF8000FF0000FF80000000FFFF8000FF00000000FF0000FF
0000FFFF8000FF000000FF000000FF00FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FF0000FFFF8000FF8000FF000000FF00FF0000FF0000FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF00FF0000FF0000FF00000000FF00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF80000000FFFF8000FF0000
FF8000FF00000000FF00FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000
00FF0000FF00FF0000FF00000000FFFF0000FF80000000FFFF0000FF00000000FF0000FF
0000FFFF8000FF000000FF000000FF00FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FF0000FFFF8000FF8000FF000000FF00FF0000FF0000FF800000FF0000FF000000FF
FF00000000FFFF80000000FF0000FF
0000FF00FF0000FF00FF0000FF0000FF00000000FF00FF00FF0000FF0000FF000000FF00
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF80000000FFFF8000
FF8000FF80000000FF00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF00000000FFFF0000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF
0000FF0000FFFF8000FF8000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF80000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .13829 L
.2381 .13829 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .13829 L
.2381 .13829 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .05569 L
.47619 .05569 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .05569 L
.47619 .05569 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11722 L
.71429 .11722 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11722 L
.71429 .11722 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .33061 L
.95238 .33061 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .33061 L
.95238 .33061 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF000000FF00FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF80000000FFFF0000FF800000FF000000FF00FF0000FF00FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF00000000FFFF8000FF0000FF8000FF8000
FF800000FF000000FFFF8000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF0000FF80000000FFFF0000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF0000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF00000000FF0000FF00FF00FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF80000000FFFF0000FF0000FF8000FF0000FF000000FF0000FF00
FF8000FF0000FF0000FF8000FF0000FF80000000FFFF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF00000000FF
FF8000FF8000FF8000FF8000FF0000
FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF00000000FFFF8000FF0000
FF8000FF8000FF800000FF00FF0000FF80000000FF00FF000000FFFF0000FF8000FF8000
FF0000FF0000FF0000FF800000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF0000FF00000000FFFF00000000FFFF8000FF80000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF00000000FFFF0000FF0000FF00000000FF00FF000000FFFF0000FF8000FF0000
FF8000FF8000FF0000FF800000FF00FF000000FF00FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF0000FF8000FF8000FF8000
00FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF00000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF0000FF8000FF000000FF00FF00000000FF0000FF0000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF80000000FFFF8000FF80000000FFFF0000FF000000FF00FF0000FF0000
FF0000FF80000000FFFF0000FF000000FF00FF8000FF800000FF0000FF00FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF
00FF000000FFFF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF800000FF00FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF0000FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF80000000FFFF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00FF8000FF8000
00FF000000FFFF8000FF000000FF00
FF8000FF8000FF0000FF0000FF0000FF8000FF800000FF0000FF00FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF800000FF00FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF80000000FFFF8000FF8000FF0000
00FF0000FF000000FFFF000000FF00FF800000FF00FF800000FF00FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF000000FFFF8000
FF80000000FFFF8000FF8000FF8000
00FF00FF0000FF8000FF8000FF0000FF800000FF000000FF00FF00FF0000FF8000FF0000
FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF80000000FFFF8000FF8000
FF800000FF00FF8000FF8000FF0000FF0000FF80000000FFFF80000000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF0000FF8000FF8000
FF80000000FFFF80000000FFFF8000
00FF00FF0000FF0000FF0000FF0000FF80000000FFFF8000FF0000FF8000FF0000FF8000
0000FF0000FF00FF00FF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000
FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF0000FF0000FF800000FF00
FF8000FF800000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF80000000FFFF8000FF8000
FF00000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF0000FF800000FF00FF8000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF8000
00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF00000000FF00FF00FF0000
FF0000FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF80000000FFFF8000FF8000
FF00000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000
FF8000FF800000FF00FF0000FF0000FF8000FF8000FF8000FF0000FF00000000FF00FF00
FF80000000FFFF8000FF00000000FFFF8000FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF0000FF00000000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF0000
FF8000FF80000000FFFF80000000FF
FF0000FF8000FF8000FF0000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
FF800000FF00FF0000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF80000000FFFF80000000FFFF80000000FF
FF80000000FF0000FFFF80000000FF
FF0000FF80000000FFFF000000FF0000FF00FF8000FF0000FF8000FF8000FF8000FF8000
0000FFFF800000FF0000FF000000FFFF0000FF0000FF800000FF0000FF0000FF0000FF00
FF8000FF0000FF8000FF8000FF80000000FFFF80000000FFFF80000000FFFF80000000FF
FF8000FF0000FF0000FF80000000FFFF8000FF80000000FFFF0000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF0000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF80000000FFFF8000
FF0000FF8000FF80000000FF0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000
0000FFFF800000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00FF00000000FF
FF8000FF80000000FFFF8000FF00000000FFFF0000FF8000FF80000000FFFF8000FF8000
0000FF00FF000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF0000FF00000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
0000FFFF8000FF8000FF800000FF00
FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF0000FF8000
FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
0000FF00FF00FF80000000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000
FF8000FF00000000FF00FF00FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF00000000FF00FF00
FF0000FF0000FF0000FF800000FF00
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000
FF80000000FFFF800000FF000000FF0000FF0000FF0000FF00FF00FF0000FF0000FF0000
0000FFFF00000000FFFF80000000FFFF8000FF8000FF00000000FFFF8000FF80000000FF
FF800000FF0000FF000000FFFF80000000FFFF8000FF8000FF800000FF00FF00000000FF
0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF80000000FF0000FFFF8000FF000000FF000000FF00FF00
00FF00FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF80000000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000FF8000FF0000
FF8000FF00000000FFFF80000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FF0000FFFF8000FF80000000FFFF8000FF0000FF0000FF8000
FF0000FF00000000FFFF0000FF0000FF8000FF8000FF80000000FFFF8000FF00000000FF
FF0000FF0000FF8000FF8000FF80000000FFFF0000FF8000FF80000000FF0000FF00FF00
00FF00FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF0000
FF00000000FF0000FFFF00000000FFFF80000000FF0000FF00FF00FF00000000FFFF8000
FF8000FF0000FF80000000FFFF80000000FFFF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF80000000FFFF0000FF0000FF00000000FF00FF0000FF00FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF00FF00
00FF00FF0000FF8000FF8000FF8000
0000FF00FF0000FF00FF0000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF0000
FF8000FF00000000FFFF00000000FF0000FFFF8000FF8000FF80000000FFFF8000FF0000
FF8000FF0000FF8000FF8000FF80000000FFFF00000000FFFF80000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF00000000FF00FF0000FF000000FFFF8000FF8000
FF80000000FFFF800000FF00FF80000000FFFF8000FF80000000FF0000FF0000FF00FF00
00FF000000FFFF80000000FFFF8000
0000FFFF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000
FF8000FF80000000FF00FF00FF0000FF0000FF8000FF80000000FF0000FFFF8000FF0000
FF800000FF000000FF0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF80000000FFFF0000FF0000FF8000FF800000FF000000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FFFF800000FF00FF0000FF80000000FF0000FFFF0000
FF00000000FFFF8000FF8000FF8000
FF0000FF000000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF00000000FFFF80000000FF0000FFFF0000FF8000FF8000FF8000FF0000FF8000
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF
FF8000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF80000000FF00FF00FF8000FF800000FF0000FF00FF8000FF00000000FFFF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF000000FF00FF80000000FFFF8000FF8000FF80000000FFFF80000000FFFF8000
0000FFFF8000FF8000FF0000FF00000000FF0000FFFF00000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF80000000FF
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF8000FF000000FF00FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF000000FF0000FF0000FF00FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF000000FF00FF8000FF8000FF8000FF8000FF80000000FF00FF000000FFFF8000
0000FFFF8000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF80000000FF00FF00FF8000FF8000FF80000000FFFF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF80000000FFFF0000FF8000FF8000FF800000FF00FF000000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF0000FF00FF0000FF0000FF0000FF80000000FFFF00000000FFFF8000
FF8000FF8000FF800000FF00FF0000FF8000FF8000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF0000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF80000000FFFF0000FF8000FF8000FF00000000FF0000FF0000FFFF8000FF0000FF0000
FF8000FF00000000FFFF8000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF8000FF000000FF0000FF00FF000000FF000000FFFF00000000FFFF0000FF8000FF8000
0000FFFF80000000FF00FF00FF0000FF0000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF000000FFFF00000000FFFF80000000FF
FF8000FF8000FF80000000FF0000FF00FF000000FFFF8000FF80000000FFFF8000FF0000
FF8000FF0000FF0000FF80000000FF00FF00FF80000000FFFF80000000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF0000FF00000000FFFF8000FF80000000FF
00FF000000FF0000FF0000FF0000FF
FF8000FF800000FF00FF0000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF800000FF000000FF00FF00FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF00000000FFFF80000000FF
FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF00000000FFFF8000FF00000000FFFF0000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
FF0000FF00000000FF0000FF0000FF
00FF00FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF80000000FF0000FF0000FF
FF8000FF80000000FF00FF00FF8000FF00000000FF00FF00FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF00000000FF0000FFFF0000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF000000FFFF8000FF8000FF00000000FF0000FF
0000FFFF8000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF80000000FF0000FF0000FF
0000FFFF800000FF0000FF00FF0000FF00000000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF00000000FFFF0000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF0000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FFFF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF00FF00FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000
FF0000FF8000FF80000000FFFF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF00FF00FF8000FF00000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FFFF800000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000
0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF800000FF000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF
0000FF0000FF00FF00FF8000FF0000FF8000FF0000FF0000FF8000FF80000000FFFF8000
FF0000FF80000000FFFF8000FF8000
FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
0000FFFF800000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF80000000FF00FF00FF800000FF0000FF00FF0000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FF00FF00FF0000FF8000FF800000FF00FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF800000FF0000FF000000FFFF8000FF80000000FF0000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF800000FF0000FF000000FFFF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF800000FF0000FF00FF0000FF800000FF00FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF000000FF00FF00FF00000000FF0000FFFF80000000FF0000FF
FF8000FF8000FF8000FF80000000FFFF8000FF0000FF800000FF00FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00
00FF00FF0000FF0000FF000000FF0000FF00FF8000FF0000FF8000FF0000FF8000FF8000
FF800000FF0000FF00FF000000FF0000FF00FF0000FF0000FF80000000FFFF000000FF00
FF8000FF8000FF8000FF80000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .48016 L
.2381 .48016 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .48016 L
.2381 .48016 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01835 L
.47619 .01835 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01835 L
.47619 .01835 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .12118 L
.71429 .12118 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .12118 L
.71429 .12118 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02211 L
.95238 .02211 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02211 L
.95238 .02211 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000FF0000FF8000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF8000FF8000FF80000000FF
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF8000FF8000
FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF8000
0000FF0000FFFF0000FF8000FF80000000FFFF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF8000
FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FF
FF00000000FF0000FFFF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF00FF00FF0000FF00000000FFFF00000000FFFF0000FF00000000FFFF80000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FFFF000000FF00
FF0000FF0000FF0000FF80000000FF
00FF0000FF000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
00FF0000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF80000000FFFF0000
00FF00FF0000FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00
FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF
00FF000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000
FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF8000FF80000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF000000FF00
0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000
FF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FF0000FF0000FFFF00000000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FF0000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF0000FF0000FF00000000FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .11514 L
.2381 .11514 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .11514 L
.2381 .11514 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .29035 L
.47619 .29035 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .29035 L
.47619 .29035 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .22318 L
.71429 .22318 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .22318 L
.71429 .22318 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01314 L
.95238 .01314 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01314 L
.95238 .01314 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF00FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF
00FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FF0000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FFFF0000FF00000000FF00FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF000000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FFFF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF000000FF0000FF00FF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF000000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
FF00000000FFFF000000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF
0000FFFF00000000FF00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FFFF00000000FFFF0000
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF00FF00000000FF
FF0000FF0000FF00000000FF0000FF
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF00FF000000FF000000FF0000FFFF00000000FF0000FF0000FF
0000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FFFF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF00FF0000FF00
FF000000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF000000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF00FF0000FF0000FF000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF00000000FF00FF000000FFFF0000FF00000000FF
FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF00000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF00FF0000FF0000FF00FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FFFF000000FF000000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF00000000FF0000FF00FF00FF000000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF00FF000000FF000000FF0000FF0000FFFF0000FF0000FF00000000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FFFF000000FF00FF00000000FFFF00000000FF
0000FF0000FFFF000000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000FF00000000FF
FF0000FF000000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF00000000FF00FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FFFF00000000FFFF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF0000FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF00000000FF
FF0000FF000000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FF
00FF00FF0000FF00000000FFFF0000FF00000000FF0000FF00FF00FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FFFF00000000FF0000FF0000FF0000FF00FF000000FFFF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF00000000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF000000FF00FF00FF000000FF0000FF0000FF00FF00000000FFFF0000FF0000
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FFFF0000FF000000FF000000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
00FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF00FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF00FF00000000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FFFF000000FF0000FF00FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF
00FF00FF000000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FFFF00000000FF0000FF0000FF00FF0000FF0000FF00
00FF00FF000000FF000000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
FF0000FF0000FF000000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF00FF00000000FFFF0000FF00000000FFFF00000000FF00FF000000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF00000000FF
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
0000FF00FF00FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
0000FF0000FFFF00000000FF00FF000000FF00FF00FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF0000FF00FF00
00FF0000FF00FF00000000FFFF0000FF0000FF0000FF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF00FF00
00FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF8000FF80000000FF0000FF00FF000000FF00FF000000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF000000FF000000FF0000FF
FF00000000FFFF0000FF0000FF0000FF80000000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF80000000FF0000FF00FF0000FF0000FF0000FF00
00FF00FF00000000FF0000FF0000FF0000FF0000FFFF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF00000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF00000000FF00FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF
FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF000000FF0000FF00
0000FFFF0000FF000000FF000000FFFF0000FF0000FF0000FF0000FF000000FF000000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF0000
FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00FF0000FF00000000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FFFF00000000FFFF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .13725 L
.2381 .13725 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .13725 L
.2381 .13725 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .22193 L
.47619 .22193 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .22193 L
.47619 .22193 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .27053 L
.71429 .27053 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .27053 L
.71429 .27053 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01209 L
.95238 .01209 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF00FF000000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FFFF00000000FF
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF000000FF0000FF000000FF00FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FFFF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF000000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF00FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000
0000FF00FF0000FF0000FF000000FF
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF00
0000FF00FF000000FF00FF000000FFFF000000FF000000FFFF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF000000FFFF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF00000000FF0000FF00FF000000FF0000FF0000FF00FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FFFF00000000FF00FF000000FF0000FF0000FF0000FF0000FFFF0000FF000000FF00
00FF0000FF000000FFFF00000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FF0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF000000FF00
00FF0000FF00FF000000FF00FF0000FF000000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
00FF00FF000000FF0000FF0000FF00
FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF0000FF0000
0000FF0000FF00FF000000FFFF00000000FF00FF00FF000000FF0000FF00FF000000FF00
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FFFF0000FF0000FF00000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF00000000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF00FF00FF00000000FFFF0000FF000000FF00FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF0000FF0000FF00000000FF0000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF00FF00000000FF0000FF0000FFFF0000
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FFFF00000000FFFF00000000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF000000FF0000FF0000FF00FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF000000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF00000000FF0000FF0000FF00FF000000FFFF00000000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FF00FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF000000FF00FF0000FF0000FF00000000FF0000FFFF000000FF00
0000FF0000FF0000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF0000FF0000FF0000FF00000000FF00FF000000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FFFF0000
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00FF0000
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF00FF00
00FF000000FF0000FF00FF000000FF00FF00FF000000FF00FF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF00
00FF000000FF00FF000000FF0000FF00FF00FF00000000FF0000FFFF0000FF00000000FF
FF000000FF000000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF000000FFFF00000000FFFF0000FF0000FF0000
0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FF
0000FFFF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF0000FF000000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF000000FF00
0000FF0000FF00FF00FF000000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF00FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF00000000FF00FF0000FF0000FF00
0000FFFF0000FF00000000FFFF0000FF000000FF0000FF0000FF00FF0000FF00000000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF00FF00
0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF000000FF000000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FFFF000000FF00FF0000FF000000FF00FF00000000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF000000FF
FF000000FF0000FF0000FF000000FF0000FFFF00000000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF00000000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF00000000FF00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF
FF00000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF00FF00000000FFFF0000FF0000FF000000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
FF00000000FF0000FF0000FF0000FF00FF00FF00000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000
FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
FF0000FF0000FF0000FF000000FF0000FF00FF00000000FFFF0000FF00000000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF00000000FF
0000FF00FF000000FF0000FF0000FF
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF0000FF00FF00FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF0000FFFF000000FF00FF00000000FF0000FF0000FFFF0000FF000000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
0000FF00FF000000FF00FF000000FF
FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF00FF000000FF0000FFFF00000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
00FF000000FF00FF00FF00000000FF0000FFFF00000000FFFF0000FF00000000FF00FF00
00FF0000FF000000FF0000FFFF00000000FF0000FFFF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF
0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
FF00000000FF0000FF0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF00000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF00FF000000FF0000FF0000FFFF00000000FF0000FF
00FF0000FF0000FF0000FF00FF00000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF00FF00000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF000000FF00FF0000FF00000000FF00FF00
00FF000000FF0000FF0000FF0000FFFF000000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF00000000FF
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF00FF000000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF00FF0000
00FF0000FF000000FF00FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF00
0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF00FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FFFF00000000FF
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00FF000000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF000000FF000000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF00FF00000000FFFF0000
FF00000000FFFF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FFFF0000FF0000FF0000
FF000000FF00FF00000000FF00FF0000FF000000FF00FF00FF00000000FF00FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF000000FF0000FF000000FF00FF00FF0000FF0000
0000FFFF0000FF00000000FF00FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FFFF0000
0000FF0000FFFF000000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF000000FF000000FF0000FF0000FF0000FF0000FF0000FFFF0000
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FFFF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF00FF00FF00000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF00FF00000000FFFF0000FF00000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FFFF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF000000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
00FF0000FF000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FFFF00000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FFFF0000FF000000FF00FF0000FF00000000FFFF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF000000FF0000FF0000FF000000FF00FF00
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .06007 L
.2381 .06007 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .06007 L
.2381 .06007 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01877 L
.71429 .01877 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01877 L
.71429 .01877 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .55108 L
.95238 .55108 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .55108 L
.95238 .55108 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF
FF0000FF0000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .5636 L
.2381 .5636 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .5636 L
.2381 .5636 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01251 L
.71429 .01251 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05319 L
.95238 .05319 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05319 L
.95238 .05319 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF800000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000
0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02231 L
.2381 .02231 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02231 L
.2381 .02231 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .27199 L
.47619 .27199 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .27199 L
.47619 .27199 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .24947 L
.71429 .24947 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .24947 L
.71429 .24947 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09803 L
.95238 .09803 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09803 L
.95238 .09803 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF00000000FF0000FFFF8000FF8000
FF80000000FF00FF0000FF00FF8000FF0000FF0000FF0000FF000000FF0000FF0000FF00
0000FF00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
0000FFFF80000000FF0000FF00FF00FF800000FF00FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF80000000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF0000FF8000FF0000FF8000FF00000000FF0000FF00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF0000FF80000000FF00FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF80000000FF0000FFFF8000FF800000FF00
00FF000000FF00FF000000FF00FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF00000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF0000FF8000FF0000FF800000FF0000FF00
00FF0000FF00FF8000FF80000000FFFF800000FF0000FF000000FFFF80000000FFFF8000
FF800000FF00FF8000FF800000FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FFFF8000
FF0000FF8000FF00000000FFFF8000FF0000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF0000FF800000FF000000FF
00FF000000FF00FF00FF0000FF800000FF0000FF0000FF0000FF000000FF00FF0000FF00
FF8000FF0000FF800000FF00FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
FF8000FF800000FF000000FFFF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF80000000FF0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF00FF800000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FFFF800000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF00FF800000FF00
00FF000000FF0000FF0000FF00FF000000FFFF80000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF000000FF00FF00FF8000
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FFFF8000FF8000FF8000FF000000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FFFF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF80000000FFFF8000
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF80000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF00FF80000000FFFF8000FF800000FF00
FF80000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF0000FF80000000FFFF80000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FFFF800000FF0000FF0000FF00FF800000FF00FF800000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF00000000FF0000FF00FF00
00FF0000FF00FF8000FF80000000FF0000FF00FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF00FF00FF8000FF8000FF8000
FF000000FF0000FF00FF800000FF00
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF00000000FF00FF00FF8000
0000FF0000FFFF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
FF800000FF000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
FF8000FF800000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF000000FFFF80000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF800000FF000000FFFF8000
FF8000FF8000FF00000000FF0000FF0000FF0000FFFF800000FF0000FF0000FF000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FFFF8000
FF80000000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FFFF8000FF8000FF0000FF8000FF80000000FFFF8000FF80000000FFFF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00FF80000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF80000000FF0000FF
FF800000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
00FF0000FF0000FF000000FFFF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FFFF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF80000000FF0000FF00FF0000FF0000FF0000FF000000FFFF8000
FF800000FF00FF800000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF800000FF0000FF000000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000
0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00FF0000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF800000FF0000FF000000FF
FF8000FF8000FF8000FF0000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF000000FF00FF00
0000FFFF80000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00FF80000000FFFF8000FF8000
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF000000FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FFFF800000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF00FF8000
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF00FF00FF8000FF800000FF0000FF000000FF00FF000000FF
FF8000FF80000000FFFF800000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00FF800000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF000000FF0000FF
FF8000FF8000FF0000FF800000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF
FF800000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00FF80000000FFFF80000000FF
0000FF00FF0000FF0000FF000000FFFF8000FF80000000FFFF800000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF00FF80000000FF0000FF
0000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF800000FF00
FF8000FF800000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FFFF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF00FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00FF800000FF00
00FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF00FF800000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF000000FF00FF8000FF0000FF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF00FF00
FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF00FF8000FF8000FF8000FF800000FF000000FF00FF00
0000FF00FF00FF80000000FF0000FF0000FF0000FFFF80000000FFFF800000FF000000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00FF00FF80000000FF00FF00
00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF00FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
0000FF0000FFFF8000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF00FF00
0000FF00FF000000FFFF80000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF00FF8000FF800000FF00FF800000FF0000FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF00FF8000FF8000FF0000FF800000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF00FF8000FF80000000FF0000FFFF800000FF000000FF00FF0000FF000000FF0000FF
00FF000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00FF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF000000FF00
0000FF0000FFFF800000FF00FF8000FF800000FF00FF800000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00FF8000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF000000FFFF80000000FF0000FFFF800000FF00FF80000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF000000FF00FF0000FF00
00FF0000FF00FF800000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
00FF0000FF00FF80000000FF0000FFFF8000FF8000FF800000FF00FF80000000FF0000FF
00FF000000FF0000FF0000FF00FF00FF8000FF80000000FF0000FFFF800000FF0000FF00
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FF00FF0000FF00FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01251 L
.2381 .01251 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01251 L
.2381 .01251 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .13871 L
.47619 .13871 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .13871 L
.47619 .13871 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .46035 L
.71429 .46035 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .46035 L
.71429 .46035 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03024 L
.95238 .03024 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03024 L
.95238 .03024 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF800000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF800000FF00FF80000000FF0000FF0000FF
0000FFFF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF800000FF00FF80000000FF0000FF0000FF
FF8000FF00000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF00FF80000000FF0000FF00FF000000FF
00FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FF0000FFFF80000000FF0000FF
FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FFFF8000FF800000FF00FF800000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF000000FF00FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF00FF80000000FF00FF0000FF0000FF00FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF00FF80000000FF0000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF800000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
00FF00FF800000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FFFF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000
00FF00FF8000FF80000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FFFF8000FF8000
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00
00FF000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF00FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00FF80000000FFFF8000FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF80000000FF00FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00FF800000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF8000
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF00FF000000FF00FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FFFF800000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF00FF00FF800000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF00FF800000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FFFF800000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF00FF000000FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .1118 L
.2381 .1118 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .1118 L
.2381 .1118 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .13057 L
.47619 .13057 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .13057 L
.47619 .13057 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .10325 L
.71429 .10325 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .10325 L
.71429 .10325 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .29619 L
.95238 .29619 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .29619 L
.95238 .29619 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF00FF0000FF00FF8000FF8000
FF8000FF80000000FFFF0000FF800000FF0000FF00FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF800000FF0000FF00FF800000FF0000FF000000FF0000FF0000FF
FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF800000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF800000FF00FF0000FF8000FF800000FF000000FF00FF00FF8000FF8000FF0000FF8000
00FF00FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF000000FF
FF8000FF8000FF8000FF0000FF8000FF0000FF800000FF00FF80000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF000000FF00FF80000000FF0000FF00FF00FF8000FF80000000FF
FF8000FF800000FF00FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF80000000FF0000FF00FF000000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF80000000FF
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF0000FF800000FF00FF8000FF8000
FF0000FF0000FF8000FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF00FF00
FF8000FF8000FF8000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF800000FF000000FF00FF00FF800000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF80000000FF
FF800000FF0000FF000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF000000FF0000FF0000FF0000FF00FF0000FF800000FF0000FF00
FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000
00FF00FF80000000FF00FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
00FF00FF800000FF00FF800000FF00FF80000000FF0000FFFF8000FF8000FF80000000FF
0000FFFF800000FF00FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF000000FF00
FF8000FF0000FF800000FF0000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF8000
00FF00FF80000000FF0000FFFF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF800000FF00
FF8000FF0000FF8000FF0000FF8000FF8000FF00000000FFFF80000000FFFF8000FF8000
FF0000FF00000000FF00FF0000FF0000FF000000FF0000FF0000FFFF800000FF00FF8000
FF800000FF000000FF00FF00FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF80000000FF0000FFFF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
00FF000000FFFF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF800000FF00FF8000FF80000000FF0000FF00FF00FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF0000
00FF00FF80000000FFFF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF000000FF0000FF00FF000000FFFF8000
00FF000000FFFF800000FF00FF8000
00FF00FF8000FF0000FF8000FF00000000FF00FF000000FF0000FF0000FF0000FFFF0000
FF8000FF000000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF800000FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF0000FF8000FF0000FF0000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF0000FF80000000FF
FF0000FF8000FF8000FF80000000FF00FF0000FF0000FF000000FF0000FF00FF00FF8000
00FF00FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF000000FFFF8000FF8000
0000FFFF80000000FF00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000FF0000
FF8000FF0000FF0000FF800000FF0000FF000000FF0000FFFF8000FF8000FF0000FF8000
FF000000FF0000FF00FF800000FF00FF0000FF0000FF8000FF8000FF00000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00FF8000
FF80000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF0000FF0000FF000000FFFF8000FF8000
FF8000FF8000FF80000000FF00FF00FF80000000FFFF8000FF8000FF0000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF000000FF0000FF000000FF0000FFFF0000FF8000FF0000FF8000
0000FF00FF0000FF000000FF00FF0000FF000000FFFF80000000FFFF0000FF8000FF0000
FF800000FF000000FF00FF0000FF00FF8000FF80000000FF0000FF0000FF00FF0000FF00
00FF00FF800000FF00FF8000FF8000
0000FFFF80000000FFFF8000FF000000FF0000FF00FF800000FF0000FF00FF8000FF8000
0000FF0000FFFF8000FF800000FF00FF80000000FF0000FFFF8000FF8000FF80000000FF
FF8000FF800000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF000000FF00FF800000FF00FF8000FF8000FF8000
00FF00FF80000000FFFF800000FF0000FF0000FF0000FF000000FF0000FFFF8000FF0000
0000FFFF8000FF0000FF8000FF000000FF000000FF00FF0000FF00FF800000FF00FF8000
0000FFFF80000000FF0000FFFF8000
00FF00FF8000FF8000FF8000FF0000FF8000FF000000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF800000FF0000FF00FF8000FF8000FF80000000FF
FF8000FF0000FF0000FF8000FF000000FF00FF8000FF8000FF0000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF000000FF0000FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000FF0000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF000000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF0000FF800000FF00FF800000FF0000FF00FF800000FF0000FF000000FFFF80000000FF
FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF800000FF00FF8000
0000FF0000FFFF8000FF8000FF8000
00FF00FF8000FF8000FF0000FF0000FF0000FF80000000FF00FF00FF8000FF8000FF8000
FF0000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF000000FF00FF00
FF8000FF0000FF8000FF000000FF00FF8000FF8000FF000000FF00FF800000FF00FF8000
00FF00FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF00000000FFFF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000
FF8000FF8000FF0000FF8000FF0000FF00000000FF0000FFFF800000FF00FF0000FF0000
FF8000FF8000FF0000FF8000FF00000000FFFF800000FF0000FF00FF80000000FF0000FF
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF800000FF00FF0000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF0000
FF800000FF00FF80000000FFFF8000FF8000FF8000FF8000FF800000FF000000FF0000FF
FF800000FF000000FF0000FF0000FF0000FFFF8000FF8000FF800000FF000000FFFF8000
FF8000FF8000FF000000FF00FF8000
00FF00FF8000FF80000000FFFF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000
00FF0000FF000000FF0000FF00FF0000FF00FF8000FF00000000FF0000FF00FF0000FF00
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF00FF00
0000FF00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
00FF000000FF0000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF00000000FF
0000FF00FF000000FF00FF0000FF0000FF00FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF800000FF0000FF00FF000000FF00FF800000FF00FF80000000FF
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF000000FF000000FFFF80000000FF
00FF000000FFFF8000FF00000000FF0000FF0000FFFF8000FF8000FF800000FF00FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000FF800000FF00FF0000FF8000
FF0000FF80000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00FF8000
FF8000FF0000FF800000FF0000FF00
0000FFFF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF80000000FF
FF80000000FF00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF800000FF0000FF0000FF00
FF800000FF00FF8000FF800000FF00FF00000000FF0000FF0000FFFF8000FF80000000FF
00FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF800000FF0000FF0000FF00FF80000000FF0000FF0000FF00FF00FF8000
00FF0000FF0000FF00FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
00FF000000FF0000FF00FF000000FF00FF00FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF00FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF0000FF00FF00FF8000FF8000
FF8000FF0000FF800000FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
00FF000000FF00FF0000FF0000FF000000FFFF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF00000000FF0000FF00FF00FF800000FF000000FF
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF80000000FFFF8000FF0000
0000FFFF800000FF00FF800000FF0000FF000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000
00FF0000FF000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000FF8000FF0000
FF0000FF800000FF00FF800000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF0000FF000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF000000FFFF80000000FFFF800000FF0000FF00FF8000
0000FF0000FFFF8000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF8000FF8000FF0000
FF0000FF0000FF8000FF800000FF00FF800000FF000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF800000FF00FF0000FF8000FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000FF800000FF000000FF00FF0000FF0000FF00FF8000
FF8000FF8000FF0000FF000000FF00
FF8000FF800000FF00FF8000FF8000FF0000FF800000FF000000FFFF8000FF0000FF8000
FF00000000FFFF8000FF8000FF800000FF00FF8000FF8000FF8000FF000000FF000000FF
0000FF0000FF0000FFFF8000FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF800000FF00FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF0000FF0000FF800000FF00
FF0000FF0000FF8000FF8000FF0000FF80000000FF0000FF0000FFFF8000FF8000FF0000
FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF0000FF0000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF000000FF000000FFFF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF0000FF0000FF80000000FF
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF80000000FF00FF000000FF
0000FF0000FFFF8000FF800000FF00FF80000000FFFF8000FF8000FF8000FF8000FF8000
00FF00FF000000FF000000FFFF80000000FFFF80000000FF0000FFFF800000FF00FF8000
FF8000FF00000000FFFF8000FF80000000FF0000FFFF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF000000FF00FF80000000FFFF8000FF8000FF8000FF0000
FF8000FF8000FF80000000FF00FF00
FF8000FF00000000FF00FF00FF8000FF8000FF0000FF800000FF000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF0000FF800000FF00FF8000FF80000000FFFF8000FF8000
FF8000FF80000000FF00FF000000FF0000FF0000FFFF80000000FFFF8000FF0000FF8000
FF8000FF80000000FF00FF000000FF0000FFFF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF000000FF0000FF00FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF000000FF00FF8000FF0000FF8000FF0000
FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF800000FF000000FF
0000FF00FF00FF8000FF80000000FFFF800000FF000000FF00FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF000000FF00FF0000FF00FF80000000FF00FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000
0000FF0000FFFF8000FF0000FF8000FF800000FF00FF8000FF8000FF0000FF8000FF0000
FF0000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
0000FFFF800000FF000000FFFF8000
00FF00FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF00FF8000
00FF0000FF000000FFFF8000FF000000FF0000FF000000FF00FF000000FFFF8000FF8000
FF8000FF800000FF0000FF000000FF0000FF00FF00FF800000FF00FF8000FF0000FF8000
FF0000FF800000FF00FF0000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
FF800000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FFFF80000000FF
FF000000FF0000FF00FF0000FF8000FF0000FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
00FF00FF8000FF80000000FF0000FF
FF8000FF0000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF000000FF000000FF00FF000000FF00FF000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF800000FF00FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00
00FF0000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF800000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF0000
FF8000FF0000FF0000FF00000000FF00FF000000FFFF80000000FFFF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF00000000FF00FF0000FF00FF8000FF8000FF0000FF0000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF800000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF8000
FF0000FF0000FF8000FF00000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
0000FF00FF00FF80000000FFFF8000FF0000FF0000FF0000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF0000
FF8000FF800000FF000000FF0000FF00FF00FF8000FF800000FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF000000FFFF800000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF800000FF000000FF00FF0000FF00FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF80000000FF0000FF00FF00FF80000000FFFF8000FF8000FF0000FF800000FF00FF8000
00FF00FF8000FF0000FF0000FF0000
00FF00FF8000FF80000000FF00FF0000FF0000FF0000FF00FF800000FF0000FF000000FF
00FF0000FF0000FF0000FF00FF800000FF000000FF00FF00FF8000FF80000000FFFF8000
FF8000FF0000FF0000FF800000FF0000FF00FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF80000000FFFF0000FF8000FF0000FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF0000
00FF0000FF00FF8000FF800000FF000000FFFF8000FF8000FF0000FF0000FF8000FF0000
00FF00FF8000FF8000FF8000FF8000
0000FFFF80000000FF00FF000000FF0000FF0000FFFF8000FF8000FF800000FF00FF8000
FF8000FF8000FF000000FF00FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF8000FF000000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF000000FFFF800000FF00FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF800000FF00FF80000000FFFF80000000FF00FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .48204 L
.2381 .48204 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .48204 L
.2381 .48204 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0244 L
.47619 .0244 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0244 L
.47619 .0244 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .11826 L
.71429 .11826 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .11826 L
.71429 .11826 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0171 L
.95238 .0171 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0171 L
.95238 .0171 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FF0000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF0000FF0000FF8000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000
00FF000000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF00000000FF
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF000000FF00FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
00FF00FF8000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FFFF00000000FFFF00000000FF0000FFFF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
00FF00FF8000FF000000FF000000FF
0000FF00FF00FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF00000000FFFF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF000000FF0000FFFF00000000FF
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF
00FF000000FF0000FFFF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF00000000FFFF0000FF0000FF0000
0000FF00FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF000000FF00
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FFFF00000000FF0000FFFF00000000FFFF0000FF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF
0000FFFF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FFFF0000FF00000000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FFFF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF
0000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF
00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF8000FF8000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF000000FFFF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF00FF0000FF8000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF800000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF000000FF00FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0317 L
.2381 .0317 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0317 L
.2381 .0317 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .31642 L
.47619 .31642 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .31642 L
.47619 .31642 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .1508 L
.71429 .1508 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .1508 L
.71429 .1508 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .14288 L
.95238 .14288 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .14288 L
.95238 .14288 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF00FF80000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF
0000FFFF800000FF00FF800000FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FFFF800000FF00
00FF00FF800000FF000000FF00FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
0000FF0000FF0000FFFF800000FF00
FF0000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF00FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FFFF800000FF00FF800000FF0000FF00FF8000FF8000FF80000000FF0000FF0000FF
FF800000FF0000FF00FF800000FF0000FF0000FF00FF00000000FF0000FFFF800000FF00
00FF00FF80000000FF0000FFFF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF80000000FF00FF00FF800000FF00
0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF00FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF800000FF00FF0000FF8000FF8000FF80000000FF0000FF0000FF
FF800000FF0000FF00FF800000FF0000FF0000FF000000FFFF00000000FFFF800000FF00
00FF00FF80000000FFFF0000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF0000FF00FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FFFF80000000FF
FF00000000FFFF8000FF8000FF8000FF00000000FF0000FF0000FF00FF000000FF0000FF
FF800000FF0000FF000000FF0000FF0000FF00FF000000FFFF00000000FFFF800000FF00
00FF00FF80000000FF0000FFFF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
0000FF00FF0000FF00FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF800000FF00
00FF000000FF0000FF0000FFFF8000FF8000FF800000FF00FF80000000FF0000FF00FF00
0000FF0000FF00FF00FF800000FF00
0000FF00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF80000000FF00FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000
0000FF0000FFFF00000000FF0000FF00FF0000FF000000FF0000FF0000FFFF800000FF00
00FF000000FF0000FF0000FFFF8000FF800000FF0000FF00FF80000000FF0000FF00FF00
FF800000FF0000FF00FF800000FF00
0000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF80000000FF00FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF00000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF00000000FF00FF0000FF000000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FFFF800000FF0000FF00FF800000FF00FF8000FF8000
FF800000FF0000FF0000FF0000FF00
0000FF00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF0000FF800000FF00FF80000000FF00FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF00000000FFFF800000FF000000FFFF8000FF8000
FF80000000FF0000FF0000FFFF8000FF800000FF0000FF00FF800000FF00FF8000FF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF00FF80000000FF00FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF00000000FF0000FF00FF000000FFFF8000FF8000
FF8000FF80000000FF0000FFFF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000
0000FF0000FFFF000000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF00FF80000000FF00FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF800000FF00FF80000000FF00FF0000FF000000FF00FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FFFF00000000FF
0000FF0000FFFF0000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF00FF8000FF8000FF80000000FF00FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF
0000FF00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF00FF00000000FF
0000FF0000FFFF80000000FFFF800000FF000000FF00FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF00FF80000000FF0000FFFF0000FF0000
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF00000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
00FF000000FFFF80000000FFFF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF00FF000000FF0000FF0000FF0000FF00FF800000FF00FF00000000FF0000FF
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF00000000FF0000FF00FF00
FF00000000FF0000FF0000FFFF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF0000FF800000FF00FF800000FF00FF8000FF800000FF000000FF0000FF
0000FF0000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF00000000FFFF00000000FFFF800000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00FF800000FF000000FF0000FF
0000FF0000FFFF0000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF0000FF00FF80000000FF0000FF0000FF0000FFFF00000000FF0000FF00FF00
0000FF0000FFFF000000FF00FF800000FF00FF8000FF80000000FF0000FFFF800000FF00
FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF80000000FF0000FF0000FF
00FF0000FF0000FF00FF80000000FF0000FF0000FF0000FFFF00000000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FFFF0000FF000000FF00FF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FFFF80000000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF0000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF80000000FF00FF0000FF0000FF00FF8000FF80000000FF0000FF
00FF00FF8000FF80000000FF0000FF0000FF0000FFFF000000FF00FF80000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF000000FF00
0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF000000FFFF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
00FF00FF8000FF80000000FF0000FFFF00000000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00FF8000FF8000FF800000FF00
FF80000000FF00FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00FF8000
0000FF0000FFFF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF00FF80000000FFFF00000000FFFF00000000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF00FF000000FFFF800000FF0000FF00FF8000FF8000FF800000FF00
FF80000000FF0000FF00FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
0000FFFF0000FF8000FF800000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF0000FF800000FF00FF80000000FF0000FF0000FF
0000FF00FF00FF800000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00
FF80000000FF0000FF00FF0000FF00FF800000FF0000FF0000FF0000FF000000FF0000FF
0000FFFF0000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF80000000FF0000FFFF800000FF00FF800000FF0000FF00
00FF00FF800000FF00FF800000FF0000FF00FF800000FF00FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF8000
0000FF0000FF0000FF0000FFFF800000FF00FF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF000000FF00FF8000FF800000FF0000FF00FF800000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF000000FFFF800000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FFFF800000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF00000000FF
0000FF00FF00FF8000FF8000FF8000FF00000000FF0000FFFF00000000FF0000FF00FF00
0000FF0000FF0000FFFF80000000FF00FF00FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF000000FF00FF8000FF800000FF00FF8000FF80000000FF0000FF0000FF
00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF00FF800000FF00FF80000000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF00FF00000000FF00FF0000FF000000FF0000FF00FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF00FF800000FF00FF800000FF00FF00000000FF0000FF
00FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000
00FF000000FFFF8000FF8000FF8000FF800000FF0000FF000000FF0000FF0000FF0000FF
0000FFFF8000FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF80000000FF0000FF00FF0000FF000000FFFF0000FF8000FF800000FF00
FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF00FF000000FF00FF0000
00FF00FF000000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF00FF800000FF0000FF000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF80000000FF0000FF00FF0000FF000000FF0000FFFF8000FF800000FF00
FF800000FF00FF80000000FF00FF00FF800000FF00FF800000FF00FF000000FF00FF0000
FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF800000FF000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF00
00FF0000FF00FF8000FF8000FF0000FF00000000FF0000FF0000FFFF8000FF800000FF00
FF800000FF00FF80000000FF0000FFFF8000FF8000FF800000FF000000FF0000FFFF0000
0000FFFF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF80000000FF0000FFFF800000FF00FF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF8000
FF800000FF000000FF0000FFFF00000000FFFF80000000FF0000FFFF8000FF800000FF00
FF800000FF00FF80000000FF0000FFFF8000FF800000FF00FF8000FF80000000FFFF8000
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF000000FFFF800000FF00FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF800000FF00FF000000FF000000FFFF0000FF00000000FF00FF00
FF00000000FF0000FFFF800000FF000000FFFF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF80000000FF00FF00FF8000FF800000FF0000FF00FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF000000FFFF800000FF000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF800000FF00FF800000FF00FF8000FF0000FF00000000FF00FF00
00FF0000FF000000FFFF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF000000FFFF800000FF000000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF00FF0000FF0000FF00
FF800000FF000000FF00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF00FF80000000FF0000FFFF800000FF0000FF00
FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00FF0000
0000FF00FF00FF000000FF000000FF00FF000000FF0000FF0000FFFF8000FF800000FF00
FF80000000FF0000FF00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF00FF00
0000FF0000FFFF00000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
FF80000000FF0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .09449 L
.2381 .09449 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .09449 L
.2381 .09449 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .107 L
.47619 .107 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .107 L
.47619 .107 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .34333 L
.71429 .34333 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .34333 L
.71429 .34333 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .09699 L
.95238 .09699 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .09699 L
.95238 .09699 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF800000FF00FF800000FF00FF8000FF0000FF0000FF8000FF8000
00FF00FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF800000FF00FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF0000
FF0000FF80000000FF0000FFFF800000FF0000FF00FF8000FF8000FF0000FF00000000FF
FF00000000FFFF0000FF00000000FF
0000FF0000FFFF000000FF0000FF00FF800000FF00FF0000FF0000FF0000FF8000FF8000
00FF00FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000
0000FF0000FF00FF00FF8000FF800000FF00FF0000FF000000FF00FF00000000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF00000000FF0000FF
00FF00FF80000000FF0000FFFF800000FF00FF80000000FF0000FF0000FF0000FFFF0000
FF000000FF0000FF000000FF0000FF
0000FF0000FFFF0000FF800000FF00FF80000000FFFF0000FF0000FF000000FF00FF8000
00FF00FF00000000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF8000FF8000
0000FFFF000000FF0000FF00FF800000FF00FF0000FF800000FF000000FF0000FFFF0000
0000FF0000FFFF0000FF0000FF000000FF000000FF0000FFFF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000
00FF000000FF0000FF0000FFFF800000FF00FF80000000FF0000FF0000FF0000FFFF0000
0000FFFF000000FF00FF8000FF8000
0000FF0000FFFF0000FF800000FF00FF80000000FFFF0000FF0000FF000000FF00FF8000
00FF00FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
00FF00FF000000FF00FF8000FF800000FF0000FF00FF8000FF80000000FF0000FFFF0000
0000FF0000FFFF0000FF0000FF000000FF00FF8000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF0000
FF00000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF800000FF000000FF0000FFFF00000000FF0000FF
00FF00FF8000FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FFFF000000FF0000FF00FF800000FF0000FF000000FFFF80000000FF0000FF00FF00
0000FFFF0000FF0000FF0000FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF00000000FFFF0000FF0000FF8000FF8000FF80000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FFFF000000FF00
FF8000FF0000FF0000FF800000FF0000FF0000FF00FF80000000FFFF00000000FF0000FF
00FF00FF80000000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF00FF000000FF
0000FFFF000000FF00FF8000FF800000FF00FF0000FF0000FF80000000FF0000FF0000FF
0000FFFF00000000FFFF000000FF00FF80000000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF800000FF00FF800000FF00FF800000FF00FF80000000FF
0000FF0000FF0000FFFF000000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF00000000FF0000FF
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FFFF00000000FFFF8000FF800000FF0000FF0000FF000000FF0000FFFF00000000FF
0000FF0000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000
FF00000000FF0000FFFF0000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF80000000FF0000FFFF000000FF00
0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000
FF80000000FF0000FFFF8000FF800000FF0000FF00FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF00000000FFFF800000FF00FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FFFF00000000FF
0000FF00FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000
FF80000000FF0000FFFF8000FF800000FF0000FF00FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00FF8000FF80000000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF00000000FF00FF0000FF00FF8000FF80000000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
FF000000FF00FF800000FF0000FF00FF8000FF80000000FF00FF00FF800000FF00FF8000
00FF0000FF00FF80000000FF0000FF0000FFFF00000000FF0000FFFF000000FF00FF8000
0000FFFF0000FF8000FF8000FF8000FF80000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF00000000FF00FF0000FF00FF80000000FF0000FF
FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF00FF000000FF00FF0000FF00FF8000FF800000FF000000FF0000FF0000FFFF0000
0000FFFF00000000FF0000FF0000FF
00FF00FF0000FF80000000FF0000FFFF8000FF8000FF000000FF00FF800000FF00FF8000
00FF0000FF00FF80000000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FFFF000000FF00FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF00000000FF0000FFFF00000000FF00FF0000FF00FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
FF000000FF000000FF0000FF00FF00FF8000FF800000FF000000FF0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF
00FF00FF8000FF80000000FF0000FFFF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF00000000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
0000FFFF0000FF80000000FFFF80000000FFFF000000FF00FF0000FF8000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF0000
FF0000FF8000FF80000000FFFF0000FF8000FF800000FF00FF800000FF000000FF0000FF
0000FF0000FF0000FFFF80000000FF
00FF00FF8000FF80000000FF00FF00FF800000FF0000FF00FF800000FF0000FF00FF8000
FF800000FF00FF0000FF00000000FF0000FF0000FFFF00000000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF000000FF0000FF
FF00000000FF0000FF00FF000000FF0000FF0000FF0000FFFF000000FF00FF00000000FF
FF00000000FFFF80000000FFFF0000FF8000FF800000FF00FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF00000000FF
FF0000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
FF80000000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FFFF0000FF00000000FFFF00000000FF
FF000000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF80000000FF0000FF
0000FF0000FFFF00000000FF0000FF
FF0000FF8000FF8000FF0000FF800000FF00FF80000000FF0000FFFF8000FF800000FF00
FF80000000FF00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FFFF0000FF000000FF000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FFFF000000FF000000FF0000FF0000FFFF00000000FF0000FFFF00000000FF
FF000000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF80000000FF0000FF
0000FF00FF00FF00000000FFFF0000
0000FF00FF000000FFFF0000FF800000FF000000FF0000FF0000FFFF0000FF800000FF00
FF80000000FF00FF00FF0000FF8000FF00000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00FF80000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF80000000FF0000FFFF8000FF800000FF00FF80000000FF0000FF0000FF
FF000000FF000000FF0000FFFF0000
0000FF00FF00FF800000FF000000FF00FF000000FF0000FF0000FFFF000000FF0000FF00
FF80000000FFFF0000FF00000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FFFF000000FF00FF8000FF800000FF0000FF00FF8000FF80000000FFFF0000
FF00000000FF00FF000000FF0000FFFF00000000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF00FF80000000FF0000FFFF800000FF0000FF00FF80000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
FF000000FF000000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000FF800000FF00
0000FF0000FFFF0000FF00000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FFFF00000000FF00FF00FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF00000000FF00FF00FF0000FF0000FF0000FF8000FF80000000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF0000FF00000000FF
FF000000FF000000FF0000FF0000FF
0000FFFF8000FF800000FF00FF800000FF00FF80000000FF0000FF00FF00FF800000FF00
0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF800000FF00FF80000000FF0000FFFF00000000FF
0000FFFF00000000FF0000FF00FF000000FF0000FFFF00000000FF0000FF0000FF0000FF
FF800000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FFFF800000FF00FF800000FF0000FF000000FF0000FF0000FF00FF00FF800000FF00
FF80000000FFFF80000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF0000
00FF000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF00FF800000FF0000FF00FF80000000FF00FF0000FF00FF800000FF00
00FF0000FF00FF80000000FF0000FFFF00000000FFFF00000000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FFFF0000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000
00FF0000FF000000FF0000FF0000FF00FF0000FF00FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF000000FF000000FF
00FF0000FF0000FF00FF800000FF0000FF00FF80000000FF00FF0000FF00FF8000FF8000
FF800000FF00FF80000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF8000
FF8000FF80000000FF0000FFFF000000FF0000FF0000FF00FF0000FF8000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000
00FF0000FF0000FF000000FF0000FF00FF0000FF00FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF0000FF000000FF00
FF8000FF8000FF8000FF0000FF000000FF0000FF0000FF00FF80000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
00FF0000FF0000FF000000FF0000FFFF000000FF00FF800000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF00FF000000FF00FF800000FF0000FF00FF8000FF800000FF00FF0000FF80000000FF
0000FF00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF000000FFFF000000FF0000FF0000FF0000FF00FF80000000FF0000FF00FF00
00FF000000FF0000FFFF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
FF800000FF00FF00000000FF0000FFFF000000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FFFF000000FF00FF80000000FF0000FF0000FFFF8000FF0000FF000000FF00FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF8000FF00000000FF0000FF00FF00FF80000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
FF8000FF0000FF00000000FFFF0000FF0000FF0000FF800000FF00FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF000000FF00FF80000000FF0000FFFF8000FF800000FF00FF00000000FFFF8000
00FF00FF800000FF00FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FF00FF000000FFFF0000FF000000FF00
FF8000FF0000FF00000000FFFF00000000FF0000FFFF8000FF000000FF000000FF0000FF
0000FFFF00000000FF0000FF0000FF
0000FFFF000000FF00FF80000000FF0000FFFF8000FF800000FF0000FF0000FF0000FF00
00FF00FF800000FF00FF80000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF0000FF00000000FF0000FF0000FF0000FFFF800000FF0000FF000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF80000000FF0000FF0000FFFF000000FF00FF8000
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FFFF000000FF00FF0000FF0000
FF0000FF00000000FF0000FF0000FF
0000FF00FF0000FF00FF80000000FF0000FFFF8000FF800000FF0000FF0000FF0000FF00
FF0000FF800000FF00FF80000000FFFF000000FF000000FF0000FF0000FF0000FF0000FF
FF000000FF00FF0000FF00000000FF0000FF0000FF0000FFFF800000FF0000FF000000FF
0000FFFF00000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF80000000FF0000FF0000FF0000FF0000FFFF8000
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF0000FF00000000FF0000FF0000FF
0000FF00FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FFFF000000FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000
00FF0000FF00FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF
0000FFFF0000FF8000FF80000000FF00FF00FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF000000FF00FF000000FF00FF800000FF00FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF0000FF0000FF00000000FF0000FF0000FFFF8000
00FF0000FF00FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
FF8000FF0000FF8000FF000000FF0000FF0000FF00FF8000FF8000FF00000000FFFF8000
0000FFFF0000FF0000FF000000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FF0000FF0000FFFF8000
FF800000FF00FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
00FF000000FFFF8000FF800000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF00000000FF0000FF0000FF
0000FFFF0000FF80000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF8000
FF800000FF00FF80000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FFFF8000FF8000FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF
0000FFFF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF800000FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF00FF00FF800000FF000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF00000000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FFFF800000FF000000FF0000FF0000FF0000FF
00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FFFF8000
FF8000FF800000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
00FF00FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF000000FF00FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF800000FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
00FF00FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF800000FF0000FF00FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02649 L
.2381 .02649 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02649 L
.2381 .02649 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .23716 L
.47619 .23716 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .23716 L
.47619 .23716 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02774 L
.71429 .02774 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02774 L
.71429 .02774 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .35042 L
.95238 .35042 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .35042 L
.95238 .35042 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF8000FF8000FF0000FF0000FF800000FF00FF8000FF8000FF80000000FF0000FFFF8000
00FF00FF800000FF00FF800000FF00FF8000FF80000000FFFF0000FF0000FF8000FF8000
0000FF0000FFFF800000FF0000FF00
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF80000000FF0000FFFF0000
0000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF000000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF80000000FFFF0000
0000FFFF800000FF00FF800000FF00FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000
FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF0000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
00FF00FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00
FF800000FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000
FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF80000000FFFF00000000FFFF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000
FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00FF800000FF00FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000
00FF00FF800000FF0000FF000000FFFF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
0000FF0000FFFF800000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF00
FF8000FF8000FF000000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF800000FF00FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
0000FF0000FFFF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF800000FF00FF0000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF800000FF00FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
0000FF0000FFFF8000FF800000FF00FF80000000FF00FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF00
00FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF80000000FFFF0000FF8000FF8000FF8000FF8000
0000FFFF000000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
FF800000FF00FF8000FF8000FF0000FF8000FF800000FF00FF8000FF800000FF00FF8000
0000FF00FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000
00FF0000FF00FF8000FF8000FF8000
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF00FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF0000FF00
FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF80000000FF0000FF00FF00FF8000FF8000
FF800000FF00FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF0000FF00
FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF00FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000
00FF00FF8000FF800000FF0000FF00FF8000FF80000000FF0000FF0000FFFF800000FF00
FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00
00FF00FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF8000
00FF00FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF0000FF8000
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
0000FFFF000000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF80000000FFFF0000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF80000000FF0000FFFF800000FF00
FF8000FF800000FF00FF8000FF8000FF80000000FFFF8000FF8000FF8000FF00000000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF80000000FFFF0000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF80000000FF0000FF0000FF00FF00
FF0000FF800000FF0000FF00FF800000FF000000FFFF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF80000000FF0000FF0000FFFF000000FF00
FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF000000FF00FF800000FF00FF8000FF800000FF00
00FF00FF8000FF0000FF0000FF0000
FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF80000000FF00FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00
FF800000FF0000FF00FF000000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00
FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF80000000FF00FF00
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF00
FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF80000000FF00FF00FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00
00FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF8000
FF00000000FFFF8000FF8000FF8000FF800000FF00FF0000FF8000FF800000FF0000FF00
FF8000FF8000FF80000000FF00FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF80000000FF0000FFFF8000FF8000
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF80000000FF00FF00
FF8000FF80000000FF0000FF00FF00FF800000FF00FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF80000000FF0000FF0000FFFF8000FF8000
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF0000FF0000
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF8000FF800000FF0000FF00
FF8000FF80000000FF0000FFFF8000FF800000FF00FF800000FF00FF8000FF8000FF0000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF80000000FF0000FFFF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF8000FF00000000FF0000FFFF800000FF00FF8000FF8000FF800000FF000000FF
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00
00FF00FF800000FF00FF800000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF80000000FF00FF00FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF0000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000FF800000FF00
FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
00FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF800000FF00
FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00
00FF0000FF00FF80000000FF0000FFFF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59843 L
.2381 .59843 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59843 L
.2381 .59843 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01272 L
.47619 .01272 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01272 L
.47619 .01272 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02816 L
.2381 .02816 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02816 L
.2381 .02816 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .27846 L
.47619 .27846 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .27846 L
.47619 .27846 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .29765 L
.71429 .29765 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .29765 L
.71429 .29765 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03754 L
.95238 .03754 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03754 L
.95238 .03754 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF000000FF0000FF00
0000FF0000FF0000FF00FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF00
0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF0000FF000000FF00FF00
FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000FF0000FF000000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF0000FF00
FF0000FF0000FF000000FF0000FF000000FF00FF000000FF00FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00FF0000FF8000FF000000FF00
FF000000FF0000FF000000FF00FF00
FF000000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF00FF00FF8000FF8000FF8000FF800000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF00FF8000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
00FF0000FF0000FF000000FF00FF00FF8000FF8000FF8000FF8000FF000000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00
FF800000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF00FF0000FF0000FF0000FF00
FF0000FF0000FF800000FF0000FF0000FF000000FF00FF00FF000000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF0000FF000000FFFF0000FF000000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00FF000000FF00FF8000FF8000
FF8000FF800000FF000000FF00FF00
0000FFFF800000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF000000FF00
00FF00FF8000FF8000FF800000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00
00FF000000FF00FF0000FF000000FF00FF0000FF00FF000000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF800000FF00
00FF0000FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF000000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF00
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF00FF000000FF00FF00FF000000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF00FF0000
00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000FF800000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF000000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF000000FF0000FF000000FF00FF0000FF00FF8000FF000000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF000000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF000000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF0000FF00FF800000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF8000FF80000000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF00FF00FF80000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF0000FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF800000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FFFF000000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00FF8000
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF00FF000000FF0000FFFF800000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF80000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF00FF00FF800000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF00FF8000
0000FF00FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
00FF0000FF000000FF00FF00FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
FF800000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00
FF800000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF00FF8000
00FF0000FF0000FF000000FF00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF00FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF00FF8000
00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF00FF800000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF80000000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF00FF0000FF800000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF00
00FF000000FF0000FFFF80000000FF00FF00FF80000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF
00FF000000FF00FF000000FF00FF00
0000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF0000
00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF00FF80000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF00
00FF000000FF00FF000000FF00FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF00FF80000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF00000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
FF8000FF80000000FF00FF0000FF000000FFFF800000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF00FF80000000FF00FF00
0000FFFF00000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF00FF0000FF00FF0000FF0000FF000000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00FF8000FF8000
FF000000FF0000FF000000FF00FF00
0000FFFF8000FF800000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF000000FF00FF000000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00FF8000
FF800000FF0000FF000000FF00FF00
0000FF00FF00FF800000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF800000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF000000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF
00FF0000FF0000FF000000FF00FF00FF000000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF00FF800000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF00FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0146 L
.2381 .0146 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0146 L
.2381 .0146 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .20545 L
.47619 .20545 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .20545 L
.47619 .20545 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .39568 L
.71429 .39568 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .39568 L
.71429 .39568 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02607 L
.95238 .02607 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02607 L
.95238 .02607 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FFFF800000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF
00FF000000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FFFF8000FF800000FF0000FF0000FF00FF0000FF0000FF800000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF00FF800000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
0000FF0000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF00FF0000FF0000FF000000FFFF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF
0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF800000FF00FF8000
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF00FF00FF0000FF0000FF800000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF000000FF00FF000000FF00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF00FF80000000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00FF8000
0000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FFFF8000
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF
00FF0000FF000000FFFF80000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF800000FF00FF80000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FFFF80000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF00FF80000000FF00FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF800000FF00
FF80000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FFFF800000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF00FF000000FF00FF0000FF8000FF000000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF800000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF00FF8000
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00FF0000FF8000
FF000000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF0000
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF00FF800000FF0000FF00
0000FF00FF000000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00FF8000FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF00FF800000FF0000FF00
00FF000000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF00FF00FF8000
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF000000FF00FF000000FFFF0000FF800000FF00
00FF000000FF00FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF000000FFFF80000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00FF800000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF00FF800000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF800000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF800000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF000000FFFF800000FF000000FF00FF000000FF
00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF
00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .12369 L
.2381 .12369 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .12369 L
.2381 .12369 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .05527 L
.47619 .05527 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .05527 L
.47619 .05527 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01835 L
.71429 .01835 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01835 L
.71429 .01835 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .44449 L
.95238 .44449 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .44449 L
.95238 .44449 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
00FF00FF0000FF0000FF000000FF00FF8000FF800000FF00FF8000FF800000FF00FF0000
FF8000FF8000FF800000FF00FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF000000FF00FF8000FF8000FF800000FF00FF8000FF8000FF0000FF000000FF0000FF00
FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF800000FF00FF0000FF0000FF0000FF0000FF800000FF0000FF0000FF00
0000FF00FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF800000FF00
00FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF0000FF8000FF8000FF800000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF000000FF00FF0000FF8000FF0000
FF0000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
00FF00FF800000FF0000FF00FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF00FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF800000FF0000FF000000FF00FF00FF80000000FF00FF0000FF000000FF00FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF000000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF000000FF00FF00FF8000FF8000FF8000
FF8000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF000000FF00FF8000FF800000FF00FF0000FF8000
FF0000FF0000FF000000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF000000FF0000FF00FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF0000FF800000FF0000FF0000FF000000FF00FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
00FF00FF8000FF8000FF0000FF00000000FF00FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF800000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF0000FF0000
FF8000FF0000FF000000FF0000FF00FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF000000FF0000FF00FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF000000FF0000FF00
00FF00FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF800000FF00
FF0000FF000000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF000000FF0000FF00FF800000FF00FF0000FF0000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
00FF000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF00FF00FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF000000FF00FF0000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
00FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF000000FF00FF00FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF80000000FFFF800000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF800000FF00
00FF0000FF00FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF0000FF8000FF8000FF8000
FF800000FF00FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF000000FF00FF800000FF000000FFFF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF00FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF0000FF800000FF000000FFFF80000000FFFF8000
FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF800000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF80000000FFFF8000FF000000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF000000FF00FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF00FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF000000FF00FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF000000FF00
00FF000000FF00FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000
FF8000FF800000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5ooo
O`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
03[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o
001o5_oo000jo`00OaOoogl01?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go
001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool003[o
001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0M
o`00OaKo0?l01Ol007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0h
o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05
o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`00
0?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo000Fooooo`80oh00403o00050?n001@0o`00103oP0050?l0
00D0oh003`3o00030?n001T0o`000P3oP0090?l000@0oh001`3o00020?n000L0o`000P3oP0000`3o
0000oh000?n000020?n000kooooo5P00o`000`000?l00?l0003o0007003o00L0003o0P3oP00;003o
00T0003o0P00o`070000o`L00?l02@000?l4003o00h0003o1@00o`0F0000o`800?l01@000?l>oooo
o`80003o0P00o`000`000?l00?l0003o0002003o00L0003o0P3oP0040000o`030?n000000?l0003o
00T0003o0P00o`050000o`80oh0010000?l00`3oP000003o0000o`0X0000o`<0oh00;@000?l>oooo
o`D0o`000P3oP0040?l000<0oh001P3o000<0?n00080o`000P3oP0020?l000T0oh000`3o00020?n0
0080003o2@3oP0050?l00080oh000P3o00070?n000D0o`000P3oP0020?l00080oh0000<0o`000?n0
003oP000103oP0020?l000L0oh000P3o00000`3oP000o`000?l0000;0?n00080o`0000<0oh000?l0
003o00000P3oP0020?l00080oh001@3o000Hooooo`005_ooool20?n00100o`001@3oP00D0?l000@0
oh001@3o00050?n000l0o`000`3oP00I0?l00080oh002@3o00040?n000L0o`000P3oP0070?l00080
oh0000<0o`000?n0003oP0000P3oP00>oooooaH00?l000<0003o003o0000o`001`00o`070000o`80
oh002`00o`090000o`800?l01`000?l7003o00T0003o1000o`0>0000o`D00?l05P000?l2003o00D0
003o3_ooool20000o`800?l000<0003o003o0000o`000P00o`070000o`80oh0010000?l00`3oP000
003o0000o`090000o`800?l01@000?l20?n000@0003o00<0oh000000o`000?l0:0000?l30?n002d0
003o3_ooool50?l00080oh00103o00030?n000H0o`00303oP0020?l00080oh000P3o00090?n000<0
o`000P3oP0020000o`T0oh001@3o00020?n00080o`001`3oP0050?l00080oh000P3o00020?n00003
0?l0003oP000oh0000@0oh000P3o00070?n00080o`0000<0oh000?l0003o00002`3oP0020?l00003
0?n0003o0000o`000080oh000P3o00020?n000D0o`006?ooool001Kooooo7@3o00030?n000@0o`00
0P3oP0090?l000030?n0003o0000o`0000@0o`000P3oP0070?l00080oh00203o00020?n001P0o`00
00<0oh000?l0003o00003@3o00000`3oP000o`000?l000020?l00080oh000P3o00000`3oP000o`00
0?l0000;0?l000kooooo10000?l00`00o`00003o0000o`02003o0080003o0`00o`020000o`800?l0
1@000?l7003o00@0003o103oP0050000o`@00?l000<0003o003o0000o`001000o`070000o`800?l0
2@000?l5003o00L0003o0P00o`0B0000o`L00?l03@000?l30?n000/0003o3_ooool20000o`T00?l0
0`000?l20?n00080003o0P3oP00E0000o`80oh0010000?l00`3oP000003o0000o`0P0000o`800?l0
:@000?l80?n000D0003o3_ooool90?n000@0o`002@3oP0000`3o0000oh000?n0000;0?n000<0o`00
3`3oP0030?l000@0oh001@3o00070?n000H0o`000P3oP0000`3o0000oh000?n000060?n000030?l0
003oP000oh0000@0o`000P3oP0050?l000T0oh000`3o00090?n00080o`00103oP0020?l000D0oh00
6?ooool001Kooooo7@3o00030?n000@0o`000P3oP0090?l000030?n0003o0000o`0000@0o`000P3o
P0070?l00080oh00203o00020?n001P0o`0000<0oh000?l0003o00003@3o00000`3oP000o`000?l0
00020?l00080oh000P3o00000`3oP000o`000?l0000;0?l000kooooo10000?l00`00o`00003o0000
o`02003o0080003o0`00o`020000o`800?l01@000?l7003o00@0003o103oP0050000o`@00?l000<0
003o003o0000o`001000o`070000o`800?l02@000?l5003o00L0003o0P00o`0B0000o`L00?l03@00
0?l30?n000/0003o3_ooool20000o`T00?l00`000?l20?n00080003o0P3oP00E0000o`80oh001000
0?l00`3oP000003o0000o`0P0000o`800?l0:@000?l80?n000D0003o3_ooool90?n000@0o`002@3o
P0000`3o0000oh000?n0000;0?n000<0o`003`3oP0030?l000@0oh001@3o00070?n000H0o`000P3o
P0000`3o0000oh000?n000060?n000030?l0003oP000oh0000@0o`000P3oP0050?l000T0oh000`3o
00090?n00080o`00103oP0020?l000D0oh006?ooool001Kooooo0P3oP00R0?l00080oh0000<0o`00
0?n0003oP0001P3o00000`3oP000o`000?l000040?l000<0oh003`3o00000`3oP000o`000?l0000H
0?l000030?n0003o0000o`000080oh002@3o00030?n000H0o`000P3oP0070?l000L0oh003_ooool4
0000o`T00?l02P000?l9003o00T0003o0P00o`050000o`H00?l01`000?l4003o00X0003o0P00o`05
0000o`@00?l04P000?l5003o00d0003o0P3oP0000`000?l0oh000?n0000;0000o`kooooo0P000?l7
003o0180003o0`00o`0?0000o`T0oh0040000?l20?n000030000o`3oP000oh0000@0003o0P3oP000
0`3o0000003o0000o`070000o`800?l04P000?l20?n000L0003o1@3oP0040?l000T0003o3_ooool4
0?l000D0003o0P3oP0020?l000030?n0003o0000o`0000/0oh000P3o00000`3oP000o`000?l00004
0?n00080o`006@3oP0020?l000D0oh000P3o00030?n00080o`001`3oP0020?l00080oh000`3o0006
0?n00080o`001@3oP0070?l000L0oh000P3o00020?n00080o`000`3oP0060?l000D0oh006?ooool0
01Kooooo0P3o00020?n001h0o`000P3oP0070?l000T0oh000P3o00020?n000L0o`000P3oP0080?l0
0080oh001`3o00020?n001T0o`000P3oP0020?l000D0oh00403o00020000o`80o`003_ooool40000
o``00?l010000?l<003o00T0003o1000o`050000o`@00?l03P000?l2003o00<0003o1P00o`020000
o`D00?l04P000?l2003o00h0003o103oP0000`000?l0oh000?n000040000o`80oh001@000?l>oooo
o`@0003o00<00?l00000o`000?l02@000?l40?n00080o`0000<0oh000000o`000?l010000?l00`00
o`00003o0000o`0B0000o`80oh0010000?l5003o00T0003o0P3oP0070000o`D0oh001P000?l3003o
0100003o103oP0050000o`d0oh001`000?l>ooooo`@0oh001@000?lK0?n000L0o`000P3oP0020?l0
00<0oh000P3o00020?n00080o`0000<0oh000000o`000?l00P000?l<0?n000H0o`000P3oP0000`3o
0000oh000?n000090?n00080o`00103oP0000`3o0000oh000?n000020?l000T0oh000P000?lE0?n0
0080o`006?ooool001Kooooo0P3o00020?n001h0o`000P3oP0070?l000T0oh000P3o00020?n000L0
o`000P3oP0080?l00080oh001`3o00020?n001T0o`000P3oP0020?l000D0oh00403o00020000o`80
o`003_ooool40000o``00?l010000?l<003o00T0003o1000o`050000o`@00?l03P000?l2003o00<0
003o1P00o`020000o`D00?l04P000?l2003o00h0003o103oP0000`000?l0oh000?n000040000o`80
oh001@000?l>ooooo`@0003o00<00?l00000o`000?l02@000?l40?n00080o`0000<0oh000000o`00
0?l010000?l00`00o`00003o0000o`0B0000o`80oh0010000?l5003o00T0003o0P3oP0070000o`D0
oh001P000?l3003o0100003o103oP0050000o`d0oh001`000?l>ooooo`@0oh001@000?lK0?n000L0
o`000P3oP0020?l000<0oh000P3o00020?n00080o`0000<0oh000000o`000?l00P000?l<0?n000H0
o`000P3oP0000`3o0000oh000?n000090?n00080o`00103oP0000`3o0000oh000?n000020?l000T0
oh000P000?lE0?n00080o`006?ooool001Kooooo0P3o00020?n000030?l0003oP000oh000080oh00
1`3o00020?n000`0o`001P3oP0030?l000H0oh000P3o00000`3oP000o`000?l000020?l00080oh00
0P3o00050?n00080o`000P3oP0030?l000D0oh000P3o00020?n000L0o`000P3oP00I0?l000D0oh00
0P3o00040?n00080o`0000<0oh000?l0003o00001P3o00000`3oP000003o0000o`020?n000kooooo
10000?l:003o0080003o0P00o`040000oa000?l02@000?l9003o00D0003o1000o`000`000?l00?l0
003o0002003o00<0003o0P00o`020000o`800?l01`000?l2003o0080003o0`00o`020000o`@00?l0
00<0003o003o0000o`000P00o`0E0000o`80oh001`000?l4003o00kooooo10000?l00`00o`00003o
0000o`02003o00/0003o0`3oP0090000o`L0oh0020000?l30?n00180003o103oP0000`000?l0oh00
0?n000040000o`80oh0000<0003o0?n0003oP0006@000?l40?n000L0003o1@3oP0020?l000@0oh00
1@000?l20?n000kooooo103o00030?n00080o`000P3oP0020?l000030?n0003o0000o`0000H0o`00
00<0oh000000o`000?l0803oP0020?l00080oh000P3o00090?n000030?l0003oP000oh0000T0oh00
0P3o000P0?n000H0o`003P3oP00Hooooo`005_ooool20?l00080oh0000<0o`000?n0003oP0000P3o
P0070?l00080oh00303o00060?n000<0o`001P3oP0020?l000030?n0003o0000o`000080o`000P3o
P0020?l000D0oh000P3o00020?n000<0o`001@3oP0020?l00080oh001`3o00020?n001T0o`001@3o
P0020?l000@0oh000P3o00000`3oP000o`000?l000060?l000030?n000000?l0003o0080oh003_oo
ool40000o`X00?l00P000?l2003o00@0003o4000o`090000o`T00?l01@000?l4003o00030000o`00
o`000?l000800?l00`000?l2003o0080003o0P00o`070000o`800?l00P000?l3003o0080003o1000
o`000`000?l00?l0003o0002003o01D0003o0P3oP0070000o`@00?l03_ooool40000o`03003o0000
0?l0003o00800?l02`000?l30?n000T0003o1`3oP0080000o`<0oh004P000?l40?n000030000o`3o
P000oh0000@0003o0P3oP0000`000?l0oh000?n0000I0000o`@0oh001`000?l50?n00080o`00103o
P0050000o`80oh003_ooool40?l000<0oh000P3o00020?n00080o`0000<0oh000?l0003o00001P3o
00000`3oP000003o0000o`0P0?n00080o`000P3oP0020?l000T0oh0000<0o`000?n0003oP0002@3o
P0020?l00200oh001P3o000>0?n001Sooooo000Fooooo`T0o`000P3oP0070?l00080oh003P3o0002
0?n000L0o`00103oP0070?l00080oh0000<0o`000?n0003oP0002`3o00070?n000D0o`001P3oP00G
0?l000@0oh000`3o00070?n000H0o`000P3oP0000`3o0000oh000?n000020000o`kooooo4P00o`02
0000oaT00?l00P000?l7003o00D0003o2@00o`040000o`<00?l010000?l2003o00`0003o0P00o`02
0000o`800?l030000?l2003o0080003o00<00?l00000o`000?l010000?l20?n000030?l0003oP000
oh000080003o0P3oP0070000o`kooooo10000?l7003o00T0003o0P3o00000`3oP000003o0000o`09
0000o`@0oh005@000?l6003o00030?n000000?l0003o0080003o0P3oP0000`000?l0oh000?n00006
0?n000030?l0003oP000oh0000@0003o0P3oP0030000o`80oh003@000?l30?n000/0003o0`3oP002
0000o`80oh002@000?l>ooooo`80o`000`3oP0060?l00100oh000P3o00030?n00080o`001`3oP002
0?l00080oh000P3o00030?n000d0o`000`3oP0020?l00080oh000P3o00070?n00080o`0000<0oh00
0?l0003o00000P3o00070?n00080003o0P3o00020?n000030?l000000?l0003o0080o`000P3oP002
0?l000D0oh000P3o00000`3oP000o`000?l0000=0?n00080o`0000<0oh000?l0003o00000P3o000H
ooooo`005_ooool90?l00080oh001`3o00020?n000h0o`000P3oP0070?l000@0oh001`3o00020?n0
00030?l0003oP000oh0000/0o`001`3oP0050?l000H0oh005`3o00040?n000<0o`001`3oP0060?l0
0080oh0000<0o`000?n0003oP0000P000?l>oooooa800?l00P000?lI003o0080003o1`00o`050000
o`T00?l010000?l3003o00@0003o0P00o`0<0000o`800?l00P000?l2003o00`0003o0P00o`020000
o`03003o00000?l0003o00@0003o0P3oP0000`3o0000oh000?n000020000o`80oh001`000?l>oooo
o`@0003o1`00o`090000o`80o`0000<0oh000000o`000?l02@000?l40?n001D0003o1P00o`000`3o
P000003o0000o`020000o`80oh0000<0003o0?n0003oP0001P3oP0000`3o0000oh000?n000040000
o`80oh000`000?l20?n000d0003o0`3oP00;0000o`<0oh000P000?l20?n000T0003o3_ooool20?l0
00<0oh001P3o000@0?n00080o`000`3oP0020?l000L0oh000P3o00020?n00080o`000`3oP00=0?l0
00<0oh000P3o00020?n00080o`001`3oP0020?l000030?n0003o0000o`000080o`001`3oP0020000
o`80o`000P3oP0000`3o0000003o0000o`020?l00080oh000P3o00050?n00080o`0000<0oh000?l0
003o00003@3oP0020?l000030?n0003o0000o`000080o`006?ooool001Kooooo403o00040?n000D0
o`000P3oP0020?l000L0oh001@3o00040?n000T0o`000P3oP0090?l000030?n0003o0000o`000100
o`00103oP00E0?l00080oh002@3o00020?n00080o`0000<0oh000?l0003o00001P3oP0000`3o0000
oh000?n000020?l000kooooo1000o`000`000?l00?l0003o000O003o00030000o`00o`000?l001@0
0?l01`000?l2003o0080003o0`00o`040000o`D00?l00P000?l2003o0080003o1`00o`090000o`80
0?l00`000?l9003o00L0003o0P00o`090000o`kooooo0P000?l7003o00L0003o103oP00P0000o`80
oh000`000?l20?n00100003o103oP0020?l000<0oh001`000?l20?n000/0003o0P3oP0020000o`<0
oh001`000?l2003o0180003o3_ooool20?l00080oh0000<0o`000?n0003oP0000P3o00070?n00080
o`000P3oP0020?l000030?n0003o0000o`0000L0oh000P3o00020?n000D0o`003`3oP0050?l000T0
oh000P3o000G0?n00080o`00703oP0020000o`/0oh006?ooool001Kooooo0P3oP00<0?l000@0oh00
1`3o00040?n000<0o`001P3oP00@0?l00080oh001`3o00020?n00100o`0000<0oh000?l0003o0000
0P3oP0020?l00080oh00803o00020?n000L0o`000P3oP0000`000?l0oh000?n000020?l000kooooo
?@00o`070000o`T00?l01`000?l2003o00@0003o1`00o`020000o`03003o00000?l0003o00800?l0
1`000?l9003o00L0003o0P00o`090000o`kooooo0P000?l3003o00/0003o0P00o`0G0000o`@0oh00
70000?l;0?n000/0003o0P3oP00<0000o`80oh006`000?l>ooooo`D0oh00103o00020?n00080o`00
3P3oP0020000o`030?n0003o0000o`000080o`003@3oP0000`3o0000oh000?n000020000o`80oh00
1`3o00020?n000D0o`000P3oP0020?l000030?n0003o0000o`0000@0o`001@3oP0020?l000d0oh00
0`000?l20?n00080o`000`3oP0020?l00080oh001@3o00070?n00080003o0P3o00020?n000D0o`00
0P3oP00Hooooo`005_ooool20?n000`0o`00103oP0070?l000@0oh000`3o00060?n00100o`000P3o
P0070?l00080oh00403o00000`3oP000o`000?l000020?n00080o`000P3oP00P0?l00080oh001`3o
00020?n000030000o`3oP000oh000080o`003_oooolm003o00L0003o2@00o`070000o`800?l01000
0?l7003o0080003o00<00?l00000o`000?l00P00o`070000o`T00?l01`000?l2003o00T0003o3_oo
ool20000o`<00?l02`000?l2003o01L0003o103oP00L0000o`/0oh002`000?l20?n000`0003o0P3o
P00K0000o`kooooo1@3oP0040?l00080oh000P3o000>0?n00080003o00<0oh000?l0003o00000P3o
000=0?n000030?l0003oP000oh000080003o0P3oP0070?l00080oh001@3o00020?n00080o`0000<0
oh000?l0003o0000103o00050?n00080o`003@3oP0030000o`80oh000P3o00030?n00080o`000P3o
P0050?l000L0oh000P000?l20?l00080oh001@3o00020?n001Sooooo000Fooooob80o`000P3oP005
0?l000@0oh002@3o00030?n00100o`000P3oP00;0?l00080oh00303o00040?n00100o`000P3oP00;
0?l000<0oh000P3o000>oooooaH00?l000<0003o003o0000o`003@00o`000`000?l00?l0003o0004
003o0080003o00<00?l00000o`000?l01`00o`0;0000o`@00?l04`000?l6003o0080003o00<00?l0
0000o`000?l04000o`040000o`800?l030000?l2003o00kooooo3P000?l20?n001T0003o103oP009
0000o`<0oh000P3o00020?n00080003o0P3oP00:0000o`H0oh0000<0o`000?n0003oP0001`000?l2
0?n000/0003o0P3oP00P0000o`kooooo103oP0000`3o0000oh000?n000070?n00080003o103oP002
0?l000030?n0003o0000o`000080oh000P000?l00`3oP000o`000?l000020?l00080oh001@3o0006
0?n000030?l0003oP000oh000080003o0P3oP0070?l00080oh000`3o00040?n000<0o`004P3oP006
0?l00080oh0000<0003o0?l0003o00000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3o0009
0?n000D0003o2`3oP00Hooooo`005_oooolR0?l00080oh001@3o00040?n000T0o`000`3oP00@0?l0
0080oh002`3o00020?n000`0o`00103oP00@0?l00080oh002`3o00030?n00080o`003_oooolF003o
00030000o`00o`000?l000d00?l000<0003o003o0000o`001000o`020000o`03003o00000?l0003o
00L00?l02`000?l4003o01<0003o1P00o`020000o`03003o00000?l0003o01000?l010000?l2003o
00`0003o0P00o`0>ooooo`h0003o0P3oP00I0000o`@0oh002@000?l30?n00080o`000P3oP0020000
o`80oh002P000?l60?n000030?l0003oP000oh0000L0003o0P3oP00;0000o`80oh0080000?l>oooo
o`@0oh0000<0o`000?n0003oP0001`3oP0020000o`@0oh000P3o00000`3oP000o`000?l000020?n0
0080003o00<0oh000?l0003o00000P3o00020?n000D0o`001P3oP0000`3o0000oh000?n000020000
o`80oh001`3o00020?n000<0o`00103oP0030?l00180oh001P3o00020?n000030000o`3o0000o`00
0080oh000P3o00020?n000030?l0003oP000oh000080o`002@3oP0050000o`/0oh006?ooool001Ko
oooo2@3o00040?n000030?l0003oP000oh000280o`001P3oP0000`3o0000oh000?n000020?n001@0
o`001@3oP00B0?l00080oh002P3o00020?n000@0o`000P3oP0070?l000<0oh00103o000>ooooobH0
0?l000<0003o003o0000o`002@00o`020000o`800?l00P000?l00`00o`00003o0000o`0;0000o`D0
0?l010000?l20?n000`0003o1000o`020000o`X00?l010000?l7003o00T0003o0P3oP0050000o`80
0?l03_ooool>0000o`80oh006`000?l20?n000/0003o00<0oh000000o`000?l00P3oP0020?l000`0
003o2@3oP00?0000o`<0oh002@000?l20?n00100003o1000o`050000o`kooooo0P3oP0020?l000<0
oh000P3o00040?n000030000o`3oP000oh000280oh000P000?l20?l000L0oh001@3o00060?n000L0
o`000P3oP0000`3o0000oh000?n000020?n00080003o0`3o00090?n00080o`00503oP0020?l000D0
003o0P3oP0050000o`80oh006?ooool001Kooooo2@3o00040?n000030?l0003oP000oh000280o`00
1P3oP0000`3o0000oh000?n000020?n001@0o`001@3oP00B0?l00080oh002P3o00020?n000@0o`00
0P3oP0070?l000<0oh00103o000>ooooobH00?l000<0003o003o0000o`002@00o`020000o`800?l0
0P000?l00`00o`00003o0000o`0;0000o`D00?l010000?l20?n000`0003o1000o`020000o`X00?l0
10000?l7003o00T0003o0P3oP0050000o`800?l03_ooool>0000o`80oh006`000?l20?n000/0003o
00<0oh000000o`000?l00P3oP0020?l000`0003o2@3oP00?0000o`<0oh002@000?l20?n00100003o
1000o`050000o`kooooo0P3oP0020?l000<0oh000P3o00040?n000030000o`3oP000oh000280oh00
0P000?l20?l000L0oh001@3o00060?n000L0o`000P3oP0000`3o0000oh000?n000020?n00080003o
0`3o00090?n00080o`00503oP0020?l000D0003o0P3oP0050000o`80oh006?ooool001Kooooo2@3o
00020?n000<0o`000P3oP0020?l00080oh003P3o00020?n000L0o`000P3oP0070?l000@0oh00303o
00020?n000/0o`0000<0oh000?l0003o00007`3o00000`3oP000o`000?l000020?n00080o`001@3o
P0060?l000D0oh003_ooool2003o0080003o00<00?l00000o`000?l02`00o`070000o`T00?l01`00
0?l@003o00/0003o1@00o`0D0000o`800?l00P000?l2003o00030000o`00o`000?l000T00?l06`00
0?l>oooooa00003o1000o`0E0000o`80oh005P000?l30?n00200003o0P3oP00K0000o`@00?l01@00
0?l>ooooo`D0o`00203oP0030000o`@0oh000P3o00070?n000D0o`001@3oP0060?l00080oh0000<0
o`000?n0003oP0000P3oP0040?l000030?n0003o0000o`000080o`00103oP0000`000?l0o`000?l0
000D0?n00080o`001`3oP0030000o`80o`000P3oP0050?l000@0oh000P000?l70?n00080003o1`3o
P0050000o`80oh006?ooool001Kooooo2@3o00020?n000<0o`000P3oP0020?l00080oh003P3o0002
0?n000L0o`000P3oP0070?l000@0oh00303o00020?n000/0o`0000<0oh000?l0003o00007`3o0000
0`3oP000o`000?l000020?n00080o`001@3oP0060?l000D0oh003_ooool2003o0080003o00<00?l0
0000o`000?l02`00o`070000o`T00?l01`000?l@003o00/0003o1@00o`0D0000o`800?l00P000?l2
003o00030000o`00o`000?l000T00?l06`000?l>oooooa00003o1000o`0E0000o`80oh005P000?l3
0?n00200003o0P3oP00K0000o`@00?l01@000?l>ooooo`D0o`00203oP0030000o`@0oh000P3o0007
0?n000D0o`001@3oP0060?l00080oh0000<0o`000?n0003oP0000P3oP0040?l000030?n0003o0000
o`000080o`00103oP0000`000?l0o`000?l0000D0?n00080o`001`3oP0030000o`80o`000P3oP005
0?l000@0oh000P000?l70?n00080003o1`3oP0050000o`80oh006?ooool001Kooooo0P3oP0030?l0
0080oh002@3o00060?n000030?l0003oP000oh0001@0o`000P3oP0070?l000<0oh00103o00020?n0
00L0o`000P3oP0070?l000<0oh000P3o00040?n002@0o`0000<0oh000?l0003o00000P3o00020?n0
00<0003o103oP00>ooooo`800?l01@000?l4003o0080003o5@00o`070000o`l00?l030000?l4003o
01<0003o1000o`070000o`T00?l01@000?l4003o0180003o3_ooool>0000o`@00?l05@000?l40?n0
0100003o1P00o`030?n000T0003o103oP00:0000o`800?l050000?l3003o00d0003o1000o`050000
o`kooooo1`3oP0020?l000@0oh000`000?l40?n00080o`0000<0oh000000o`000?l00P000?l70?n0
00D0o`000P3oP0020?l00100oh000P3o00070?n00080003o0P3oP0000`3o0000oh000?n000020?l0
00@0oh0000<0o`000?n0003oP0000P3o00050?n00080o`003@3oP0050?l000@0oh0000<0003o0?n0
003oP0001P3oP0050000o`D0oh00103o000Hooooo`005_ooool90?l00080oh000`3o00020?n00180
o`000P000?l70?n002@0o`000P000?l70?l00080oh00803o00020?n000D0o`000P3oP0020000o`<0
oh000P3o000>ooooo`800?l00`000?l2003o00H0003o5`00o`050000o`/00?l00P000?l7003o0200
003o1000o`050000o`T00?l01@000?l6003o0080003o1@00o`090000o`kooooo50000?l30?n00280
003o0P00o`020000o`@00?l03P000?l20?n000D0003o0P00o`020000o`03003o00000?l0003o02T0
003o0P3oP0020?l000kooooo1@3oP0020?l00080oh000P3o00020?n000030000o`3oP000oh0000@0
oh000P3o00000`3oP000003o0000o`040?n000030?l0003oP000oh000080oh000P3o00020?n00003
0?l0003oP000oh000080oh001`3o00070?n00080o`00103oP0030?l00080oh000P3o00050?n00080
o`004P3oP0020?l000<0oh000P3o00020?n00080o`000P3oP0000`3o0000oh000?n000040?n00003
0?l0003oP000oh0000H0oh0000<0003o0?n0003oP0000P3o00020?n000<0o`000P3oP0020?l001So
oooo000Fooooo`T0o`000P3oP0030?l00080oh004P3o00020000o`L0oh00903o00020000o`L0o`00
0P3oP00P0?l00080oh001@3o00020?n00080003o0`3oP0020?l000kooooo0P00o`030000o`800?l0
1P000?lG003o00D0003o2`00o`020000o`L00?l080000?l4003o00D0003o2@00o`050000o`H00?l0
0P000?l5003o00T0003o3_oooolD0000o`<0oh008P000?l2003o0080003o1000o`0>0000o`80oh00
1@000?l2003o0080003o00<00?l00000o`000?l0:@000?l20?n00080o`003_ooool50?n00080o`00
0P3oP0020?l00080oh0000<0003o0?n0003oP000103oP0020?l000030?n000000?l0003o00@0oh00
00<0o`000?n0003oP0000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0070?l000L0oh00
0P3o00040?n000<0o`000P3oP0020?l000D0oh000P3o000B0?n00080o`000`3oP0020?l00080oh00
0P3o00020?n000030?l0003oP000oh0000@0oh0000<0o`000?n0003oP0001P3oP0000`000?l0oh00
0?n000020?l00080oh000`3o00020?n00080o`006?ooool001Kooooo0P3oP00<0?l00080oh000P3o
00020?n000<0o`00103oP0090?l000<0oh00103o00070?n000H0o`0000<0oh000?l0003o0000103o
00020?n001T0o`0000<0oh000?l0003o00004P3o00020?n000L0o`000P3oP0050?l000L0oh000P3o
00020?n000kooooo3@000?l9003o00030000o`00o`000?l000@0003o1`00o`070000oa000?l02@00
0?l9003o00D0003o1P00o`020000o`03003o00000?l0003o00T0003o2@00o`040000o`<00?l05000
0?l>oooooa@0003o0`3oP0040000o`D00?l02@000?l20?n00080003o0P3oP00:0000o`H00?l04000
0?l30?n000l0003o0P00o`0W0000o`kooooo103o00000`3oP000o`000?l000090?n00080o`000P3o
P0020?l000030?n0003o0000o`0000D0oh00203o000@0?n000<0o`001P3oP0020?l000L0oh001@3o
00040?n000030?l0003oP000oh000080o`001@3oP0040?l00080oh000P3o00000`3oP000o`000?l0
00020?l00080oh001@3o00040?n000030?l0003oP000oh000080o`000P3oP0030000o`80oh001P3o
00000`3oP000o`000?l000020?n001Sooooo000Fooooo`80oh00303o00020?n00080o`000P3oP003
0?l000@0oh002@3o00030?n000@0o`001`3oP0060?l000030?n0003o0000o`0000@0o`000P3oP00I
0?l000030?n0003o0000o`000180o`000P3oP0070?l00080oh001@3o00070?n00080o`000P3oP00>
ooooo`d0003o2@00o`000`000?l00?l0003o00040000o`L00?l01`000?l@003o00T0003o2@00o`05
0000o`H00?l00P000?l00`00o`00003o0000o`090000o`T00?l010000?l3003o01@0003o3_oooolD
0000o`<0oh0010000?l5003o00T0003o0P3oP0020000o`80oh002P000?l6003o0100003o0`3oP00?
0000o`800?l09`000?l>ooooo`@0o`0000<0oh000?l0003o00002@3oP0020?l00080oh000P3o0000
0`3oP000o`000?l000050?n000P0o`00403oP0030?l000H0oh000P3o00070?n000D0o`00103oP000
0`3o0000oh000?n000020?l000D0oh00103o00020?n00080o`0000<0oh000?l0003o00000P3o0002
0?n000D0o`00103oP0000`3o0000oh000?n000020?l00080oh000`000?l20?n000H0o`0000<0oh00
0?l0003o00000P3oP00Hooooo`005_ooool20?n000D0o`000P3oP00T0?l00080oh0000<0o`000?n0
003oP0000P3oP0020?l00080oh006@3o00000`3oP000o`000?l0000?0?l000030?n0003o0000o`00
0080oh000P3o00030?n000d0o`000P3oP0090?l000030?n0003o0000o`000080o`003_ooool7003o
00H0003o2@00o`0A0000o`800?l00P000?l=003o00X0003o1P00o`0:0000o`H00?l01@000?l2003o
00L0003o3P00o`080000o`03003o00000?l0003o00T0003o0P00o`0>oooooa00003o103oP00E0000
o`H0oh003P000?l2003o00X0003o0P3oP00M0000o`80oh0070000?l20?n00080003o3_ooool90?n0
0080003o1@3oP0020?l00080oh000`3o00060?n000030?l0003oP000oh0000H0o`001`3oP0020?l0
00<0oh000P3o000=0?n000<0o`005P3oP0000`3o0000oh000?n000060?n000D0o`004P3oP0020?l0
00030000o`3oP000oh0000/0oh006?ooool001Kooooo0P3oP0050?l00080oh00903o00020?n00003
0?l0003oP000oh000080oh000P3o00020?n001T0o`0000<0oh000?l0003o00003`3o00000`3oP000
o`000?l000020?n00080o`000`3oP00=0?l00080oh002@3o00000`3oP000o`000?l000020?l000ko
oooo1`00o`060000o`T00?l04@000?l2003o0080003o3@00o`0:0000o`H00?l02P000?l6003o00D0
003o0P00o`070000o`h00?l020000?l00`00o`00003o0000o`090000o`800?l03_ooool@0000o`@0
oh005@000?l60?n000h0003o0P00o`0:0000o`80oh007@000?l20?n001`0003o0P3oP0020000o`ko
oooo2@3oP0020000o`D0oh000P3o00020?n000<0o`001P3oP0000`3o0000oh000?n000060?l000L0
oh000P3o00030?n00080o`003@3oP0030?l001H0oh0000<0o`000?n0003oP0001P3oP0050?l00180
oh000P3o00000`000?l0oh000?n0000;0?n001Sooooo000Foooooa00o`001P3oP0000`3o0000oh00
0?n000050?n000@0o`000P3oP00G0?l000H0oh004@3o00040?n002/0o`000P3oP0070?l000kooooo
1`00o`070000o`T00?l03@000?lD003o01`0003o0P00o`070000o`800?l01`000?l;003o0080003o
00<00?l00000o`000?l03`000?l3003o0080003o3_oooolB0000o`80oh000`000?l4003o02H0003o
00<0oh000000o`000?l02`000?l30?n00080o`000P000?l20?n00200003o0P00o`020000o`03003o
00000?l0003o00@0003o0`3oP0040000o`kooooo0P000?l50?l000d0oh000P3o00030?n00080o`00
0P3oP0030?l000H0oh0000<0003o0?n0003oP000103oP0020?l000D0oh001@3o00060?n00080o`00
303oP0050000o`@0oh000P3o00030?n00080003o1P3o00030?n00080o`00103oP0030?l000D0oh00
103o00040?n000030?l0003oP000oh0000H0o`001@3oP00Hooooo`005_ooool@0?l000H0oh0000<0
o`000?n0003oP0001@3oP0040?l00080oh005`3o00060?n00140o`00103oP00[0?l00080oh001`3o
000>ooooo`L00?l01`000?l9003o00d0003o5000o`0L0000o`800?l01`000?l2003o00L0003o2`00
o`020000o`03003o00000?l0003o00l0003o0`00o`020000o`kooooo4P000?l20?n000<0003o1000
o`0V0000o`030?n000000?l0003o00/0003o0`3oP0020?l00080003o0P3oP00P0000o`800?l00P00
0?l00`00o`00003o0000o`040000o`<0oh0010000?l>ooooo`80003o1@3o000=0?n00080o`000`3o
P0020?l00080oh000`3o00060?n000030000o`3oP000oh0000@0oh000P3o00050?n000D0o`001P3o
P0020?l000`0oh001@000?l40?n00080o`000`3oP0020000o`H0o`000`3oP0020?l000@0oh000`3o
00050?n000@0o`00103oP0000`3o0000oh000?n000060?l000D0oh006?ooool001Kooooo0P3o0007
0?n000L0o`000P3oP0020?l00080oh00403o00000`3oP000o`000?l0000@0?l000H0oh002@3o0000
0`3oP000o`000?l000040?n000<0o`000P3oP00V0?l00080oh002@3o00030?n00080o`003_oooolG
003o00d0003o4P00o`0C0000o`800?l02@000?l2003o0180003o0P3oP0020?l000030?n000000?l0
003o00800?l00P000?l3003o00d0003o1`00o`0>ooooo`d0003o0`3oP0090000o`800?l00P000?l0
0`00o`00003o0000o`020000o`800?l0=`000?l4003o00@0003o00<0oh000000o`000?l01`000?l2
0?n00100003o0P3oP0090000o`kooooo0P000?l<0?n00080o`00103oP0030?l000H0oh0000<0o`00
0?n0003oP0001P3oP0000`000?l0oh000?n0000H0?n000D0003o0P3o00000`3oP000o`000?l00002
0?l00080oh000P3o00030?n00080o`003P3oP0020?l000d0oh0000<0o`000?n0003oP0000P3o000>
0?n00080o`000P3oP00Hooooo`005_ooool20?n000D0o`00103oP0070?l00080oh001@3o00020?n0
00D0o`000P3oP00W0?l00080oh00103o00020?n000<0o`00103oP00R0?l00080oh0000<0o`000?n0
003oP000103oP0070?l000kooooo7P00o`080000oa000?l0<0000?l40?n00080003o00<0oh00003o
0000o`002@00o`020000o`<00?l02`000?l2003o00kooooo1`000?l40?n00080o`002P000?l4003o
00/0003o2@3oP0000`000?l0oh000?n0000=0000o`80oh006@000?l3003o00@0003o0P3oP00<0000
o`80oh003P000?l40?n000L0003o3_ooool40000o`030?l0003oP000oh000080o`001@3oP0020?l0
00/0oh000`3o00040?n00080o`000P3oP0000`000?l0oh000?n000020?l000D0oh001P3o00090?n0
00<0003o0P3oP0020?l00080oh0000<0o`000?n0003oP0003@3oP0020000o`030?n000000?l0003o
0080oh000P3o00030?n00080o`001P3oP0000`3o0000oh000?n0000>0?n000H0003o0P3oP0000`3o
0000oh000?n000020?n001Sooooo000Fooooo`80oh001@3o00040?n000L0o`000P3oP0050?l00080
oh001@3o00020?n002L0o`000P3oP0040?l00080oh000`3o00040?n00280o`000P3oP0000`3o0000
oh000?n000040?n000L0o`003_oooolN003o00P0003o4000o`0`0000o`@0oh000P000?l00`3oP000
0?l0003o0009003o0080003o0`00o`0;0000o`800?l03_ooool70000o`@0oh000P3o000:0000o`@0
0?l02`000?l90?n000030000o`3oP000oh0000d0003o0P3oP00I0000o`<00?l010000?l20?n000`0
003o0P3oP00>0000o`@0oh001`000?l>ooooo`@0003o00<0o`000?n0003oP0000P3o00050?n00080
o`002`3oP0030?l000@0oh000P3o00020?n000030000o`3oP000oh000080o`001@3oP0060?l000T0
oh000`000?l20?n00080o`000P3oP0000`3o0000oh000?n0000=0?n00080003o00<0oh000000o`00
0?l00P3oP0020?l000<0oh000P3o00060?n000030?l0003oP000oh0000h0oh001P000?l20?n00003
0?l0003oP000oh000080oh006?ooool001Kooooo0P3o00090?n000D0o`000P3oP0050?l00080oh00
2`3o00020?n000030?l0003oP000oh0000@0oh003P3o00020?n001@0o`0000<0oh000?l0003o0000
903o00040?n000D0o`00103oP0050?l000kooooo1@00o`020000obd00?l04P000?l5003o00@0003o
2@00o`0>0000o`80o`000P3oP0020?l000030?n00000o`000?l001000?l00P000?l2003o0080003o
1@00o`0>oooooaL0003o0P00o`0>0000o`/0oh002`000?l40?n000X0003o0P3oP0040000o`03003o
00000?l0003o00L0003o0P00o`0T0000o`80oh001`000?l>ooooo`@0003o403oP0020?l000D0oh00
0`3o00040?n00080o`000P3oP0000`3o0000oh000?n000020?n000D0o`004P3oP0020?l000L0oh00
1`3o00020?n00080o`00103oP0030000o`T0o`000P3oP0020?l00080oh0000<0o`000?n0003oP000
0P3o00020?n000030000o`3oP000oh000080oh002`000?l50?n00080o`006?ooool001Kooooo0P3o
00090?n000D0o`000P3oP0050?l00080oh002`3o00020?n000030?l0003oP000oh0000@0oh003P3o
00020?n001@0o`0000<0oh000?l0003o0000903o00040?n000D0o`00103oP0050?l000kooooo1@00
o`020000obd00?l04P000?l5003o00@0003o2@00o`0>0000o`80o`000P3oP0020?l000030?n00000
o`000?l001000?l00P000?l2003o0080003o1@00o`0>oooooaL0003o0P00o`0>0000o`/0oh002`00
0?l40?n000X0003o0P3oP0040000o`03003o00000?l0003o00L0003o0P00o`0T0000o`80oh001`00
0?l>ooooo`@0003o403oP0020?l000D0oh000`3o00040?n00080o`000P3oP0000`3o0000oh000?n0
00020?n000D0o`004P3oP0020?l000L0oh001`3o00020?n00080o`00103oP0030000o`T0o`000P3o
P0020?l00080oh0000<0o`000?n0003oP0000P3o00020?n000030000o`3oP000oh000080oh002`00
0?l50?n00080o`006?ooool001Kooooo1@3o00040?n000@0o`0000<0oh000?l0003o00000P3o0002
0?n000`0o`00103oP00<0?l00080oh005`3o00020?n000H0o`0000<0oh000?l0003o00002`3o0004
0?n001L0o`000P3oP0090?l000030?n0003o0000o`000080oh003_oooolf003o00h0003o2@00o`02
0000o`T00?l02@000?l3003o0080003o103oP0030000o`@00?l00P000?l5003o0080003o0`00o`0;
0000o`800?l03_ooool50000o`@00?l02@000?l2003o00T0003o00<0oh000000o`000?l02@000?l6
0?n000030?l000000?l0003o00/0003o0P3oP0030000o`80oh005P000?l7003o00D0003o0P3oP004
0000o`D00?l00P000?l00`00o`00003o0000o`0;0000o`80o`001@000?l20?n000kooooo10000?l0
0`3o0000oh000?n000020?l00080oh002@3o00030?n00080o`000P3oP0030?l000T0oh000P3o0006
0?n000030?l0003oP000oh0000d0oh000P000?l30?n00080o`003P3oP0040?l00080oh000`000?l=
0?n00080o`00203oP0040000o`80o`002@000?l20?n000030?l0003oP000oh000080oh006?ooool0
01Kooooo1@3o00040?n000@0o`0000<0oh000?l0003o00000P3o00020?n000`0o`00103oP00<0?l0
0080oh005`3o00020?n000H0o`0000<0oh000?l0003o00002`3o00040?n001L0o`000P3oP0090?l0
00030?n0003o0000o`000080oh003_oooolf003o00h0003o2@00o`020000o`T00?l02@000?l3003o
0080003o103oP0030000o`@00?l00P000?l5003o0080003o0`00o`0;0000o`800?l03_ooool50000
o`@00?l02@000?l2003o00T0003o00<0oh000000o`000?l02@000?l60?n000030?l000000?l0003o
00/0003o0P3oP0030000o`80oh005P000?l7003o00D0003o0P3oP0040000o`D00?l00P000?l00`00
o`00003o0000o`0;0000o`80o`001@000?l20?n000kooooo10000?l00`3o0000oh000?n000020?l0
0080oh002@3o00030?n00080o`000P3oP0030?l000T0oh000P3o00060?n000030?l0003oP000oh00
00d0oh000P000?l30?n00080o`003P3oP0040?l00080oh000`000?l=0?n00080o`00203oP0040000
o`80o`002@000?l20?n000030?l0003oP000oh000080oh006?ooool001Kooooo0P3oP0020?l000<0
oh001`3o00020?n00080o`000P3oP0050?l00080oh007P3o00020?n001H0o`000`3oP00?0?l00003
0?n0003o0000o`0001d0o`000P3oP0050?l000kooooo=P00o`050000o`800?l02@000?l<003o0080
003o1000o`0@0000ob000?l00P000?l>ooooo`@0003o1@00o`020000o`D00?l01`000?l2003o00T0
003o0P3oP0020000o`030?n000000?l0003o00@0oh007P000?l40?n000<0003o103oP00;0000o`<0
oh000P000?l20?n001T0003o0P3o00020?n000<0003o0P3oP00>ooooo`80oh000P3o000@0?n00080
o`0000<0oh000?l0003o0000103oP0000`3o0000oh000?n000020?l00080oh000`3o00060?n00080
o`00403oP0020?l000`0oh000P3o00020?n000030000o`3oP000oh0000H0oh0000<0003o0?n0003o
P0001P3o00050?n00080o`000P3oP0050?l000D0oh000P3o00020?n000<0003o0P3oP0020000o`D0
oh000P3o00020?n001Sooooo000Fooooo`D0o`00103oP0040?l000030?n0003o0000o`000080oh00
1@3o00060?n000`0o`000P3oP00@0?l00080oh00303o00020?n000L0o`000P3oP0040?l00080oh00
2P3o00020?n000/0o`000P3oP00>0?l000D0oh00103o000>oooooaT00?l00P000?l3003o00P0003o
4`00o`0;0000o`h00?l00P000?l2003o00d0003o00<00?l00000o`000?l04000o`060000o`L00?l0
0P000?l5003o00kooooo1@000?l8003o00030000o`00o`000?l000T0003o0P00o`0;0000o`<0oh00
2`000?l2003o00T0003o0P00o`050000o`<0oh000P3o00020?n00080003o0P3oP0050000o`80oh00
4P000?l2003o00P0003o1000o`0;0000o`80oh001@000?l>ooooo`80oh000P3o000:0?n00080o`00
0P3oP0020?l000L0oh000P3o00030?n00080o`00103oP0000`3o0000oh000?n0000H0?n000D0o`00
303oP0040?l000T0oh000P3o00020?n000D0o`00303oP0020?l000@0oh000P000?l30?n00080003o
103oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`D0o`00103oP0040?l000030?n0003o
0000o`000080oh001@3o00060?n000`0o`000P3oP00@0?l00080oh00303o00020?n000L0o`000P3o
P0040?l00080oh002P3o00020?n000/0o`000P3oP00>0?l000D0oh00103o000>oooooaT00?l00P00
0?l3003o00P0003o4`00o`0;0000o`h00?l00P000?l2003o00d0003o00<00?l00000o`000?l04000
o`060000o`L00?l00P000?l5003o00kooooo1@000?l8003o00030000o`00o`000?l000T0003o0P00
o`0;0000o`<0oh002`000?l2003o00T0003o0P00o`050000o`<0oh000P3o00020?n00080003o0P3o
P0050000o`80oh004P000?l2003o00P0003o1000o`0;0000o`80oh001@000?l>ooooo`80oh000P3o
000:0?n00080o`000P3oP0020?l000L0oh000P3o00030?n00080o`00103oP0000`3o0000oh000?n0
000H0?n000D0o`00303oP0040?l000T0oh000P3o00020?n000D0o`00303oP0020?l000@0oh000P00
0?l30?n00080003o103oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`@0oh0000<0o`00
0?n0003oP0001`3o00040?n000D0o`00103oP0070?l00080oh003P3o00020?n000h0o`000P3oP007
0?l00080oh001@3o00020?n002H0o`001@3oP0040?l000<0oh00103o000>ooooo`800?l00P000?lJ
003o00P0003o4000o`030000o`800?l00P000?l2003o00<0oh0010000?l<003o00/0003o6@00o`0=
0000o`L00?l03_ooool50000o`/00?l09P000?l3003o00H0003o0P00o`0:0000o`L0oh000P3o0002
0?n001d0003o00<00?l00000o`000?l050000?l>ooooo`80o`000`3oP0020?l00080oh000P3o0002
0?n000030000o`3oP000oh0000@0oh000P3o00000`3oP000o`000?l0000;0?n00080o`001`3oP002
0000oaX0oh000P3o00020?n00080o`007@3oP0000`3o0000oh000?n000040?n000030?l0003oP000
oh0000@0oh000P000?l30?n000H0o`000`3oP0020?l001Sooooo000Fooooo`@0oh0000<0o`000?n0
003oP0001`3o00040?n000D0o`00103oP0070?l00080oh003P3o00020?n000h0o`000P3oP0070?l0
0080oh001@3o00020?n002H0o`001@3oP0040?l000<0oh00103o000>ooooo`800?l00P000?lJ003o
00P0003o4000o`030000o`800?l00P000?l2003o00<0oh0010000?l<003o00/0003o6@00o`0=0000
o`L00?l03_ooool50000o`/00?l09P000?l3003o00H0003o0P00o`0:0000o`L0oh000P3o00020?n0
01d0003o00<00?l00000o`000?l050000?l>ooooo`80o`000`3oP0020?l00080oh000P3o00020?n0
00030000o`3oP000oh0000@0oh000P3o00000`3oP000o`000?l0000;0?n00080o`001`3oP0020000
oaX0oh000P3o00020?n00080o`007@3oP0000`3o0000oh000?n000040?n000030?l0003oP000oh00
00@0oh000P000?l30?n000H0o`000`3oP0020?l001Sooooo000Fooooo`80oh000`3o00020000o`@0
oh000P3o00050?n000D0o`000P3oP00>0?l000@0oh001`3o00020?n000L0o`00103oP0050?l00080
oh00303o00060?n000/0o`0000<0oh000?l0003o00001P3o00000`3oP000o`000?l0000>0?l000@0
oh000P3o00030?n000@0o`003_oooolN003o00P0003o3P00o`090000o`800?l01@000?l9003o0180
003o5`00o`0=0000o`D00?l00P000?l>oooooaL0003o1000o`0D0000o`030?n000000?l0003o00T0
003o0P00o`020000o`800?l02P000?l20?n00080003o0`3oP0090000o`800?l03@000?l30?n00080
003o0P3oP00I0000o`kooooo103o00050?n000D0o`002@3oP0020?l00080oh000P3o00000`3oP000
o`000?l000020?l00080oh000P000?l00`3o0000003o0000o`020?l00080oh000P3o00050?n000@0
o`001`3oP0030000o`80oh000P3o000<0?n000@0003o103oP00:0?l00080003o0P3oP0020?l000L0
oh001@3o00040?n00080003o00<0oh000?l0003o00001`3oP0040?l001Sooooo000Fooooo`80oh00
0`3o00020000o`@0oh000P3o00050?n000D0o`000P3oP00>0?l000@0oh001`3o00020?n000L0o`00
103oP0050?l00080oh00303o00060?n000/0o`0000<0oh000?l0003o00001P3o00000`3oP000o`00
0?l0000>0?l000@0oh000P3o00030?n000@0o`003_oooolN003o00P0003o3P00o`090000o`800?l0
1@000?l9003o0180003o5`00o`0=0000o`D00?l00P000?l>oooooaL0003o1000o`0D0000o`030?n0
00000?l0003o00T0003o0P00o`020000o`800?l02P000?l20?n00080003o0`3oP0090000o`800?l0
3@000?l30?n00080003o0P3oP00I0000o`kooooo103o00050?n000D0o`002@3oP0020?l00080oh00
0P3o00000`3oP000o`000?l000020?l00080oh000P000?l00`3o0000003o0000o`020?l00080oh00
0P3o00050?n000@0o`001`3oP0030000o`80oh000P3o000<0?n000@0003o103oP00:0?l00080003o
0P3oP0020?l000L0oh001@3o00040?n00080003o00<0oh000?l0003o00001`3oP0040?l001Sooooo
000Fooooo`D0o`001P3oP0020?l000D0oh00303o00020?n000l0o`0000<0oh000?l0003o0000103o
00020?n000D0o`000P000?lI0?l00080oh0000<0o`000?n0003oP0007`3o00070?n00080003o00<0
oh000?l0003o00000P3o000>oooooc800?l01P000?l9003o00030000o`00o`000?l000D00?l02@00
0?l4003o00T0003o6@00o`070000o`/00?l03_ooool90000o`800?l03P000?l4003o00L0003o0P3o
P0050000o`800?l02`000?l7003o01L0003o4000o`040000o`80oh001`000?l5003o0080003o0P00
o`0:0000o`@0oh003_ooool40?l000030?n0003o0000o`0000H0o`000`3oP0020?l000T0oh000P3o
00000`3oP000o`000?l0000F0?n00080o`0000<0oh000?l0003o00002@3oP0020?l000<0oh00103o
00020?n00080o`000`3oP0020?l000D0oh00103o00070?n00080003o0P3o00020?n000030?l0003o
P000oh0000L0o`002`3oP0040?l000D0oh006?ooool001Kooooo1@3o00060?n00080o`001@3oP00<
0?l00080oh003`3o00000`3oP000o`000?l000040?l00080oh001@3o00020000oaT0o`000P3oP000
0`3o0000oh000?n0000O0?l000L0oh000P000?l00`3oP000o`000?l000020?l000kooooo<P00o`06
0000o`T00?l000<0003o003o0000o`001@00o`090000o`@00?l02@000?lI003o00L0003o2`00o`0>
ooooo`T0003o0P00o`0>0000o`@00?l01`000?l20?n000D0003o0P00o`0;0000o`L00?l05`000?l@
003o00@0003o0P3oP0070000o`D00?l00P000?l2003o00X0003o103oP00>ooooo`@0o`0000<0oh00
0?l0003o00001P3o00030?n00080o`002@3oP0020?l000030?n0003o0000o`0001H0oh000P3o0000
0`3oP000o`000?l000090?n00080o`000`3oP0040?l00080oh000P3o00030?n00080o`001@3oP004
0?l000L0oh000P000?l20?l00080oh0000<0o`000?n0003oP0001`3o000;0?n000@0o`001@3oP00H
ooooo`005_ooool20?n00080o`000`3oP0060?l000<0oh001P3o00050?n000`0o`000P3oP0070?l0
0080oh001`3o00090?n000@0o`000P3oP00B0?l000030?n0003o0000o`0000H0oh000`3o00060?n0
01<0o`002`3oP00>ooooo`h00?l00P000?l9003o00D0003o5000o`060000o`03003o00000?l0003o
00800?l00P000?l:003o00T0003o1000o`090000oaT00?l02@000?l7003o0080003o3_ooool70000
o`H00?l02@000?l8003o01X0003o1@00o`0P0000o`L00?l04P000?l2003o00D0003o1P00o`070000
o`kooooo103oP0000`3o0000oh000?n000020?n000@0o`002P3oP0020?l000@0oh000`3o00020?n0
0080003o1`3oP0020?l000D0oh00103o00090?n00080003o00<0oh000?l0003o0000103oP0030?l0
00T0oh000P3o00020?n000<0o`002`3oP0040?l000X0oh000P3o00020?n00080o`000`3oP0020?l0
00L0oh00103o000Hooooo`005_ooool50?l000@0oh00503o00000`3oP000o`000?l000040?n000D0
o`000P3oP00G0?l00080oh00103o00000`3oP000o`000?l0000T0?l00080oh000`3o00020?n00080
o`000P3oP0070?l000@0oh0000<0o`000?n0003oP0000P3o000>oooooad00?l00`000?lI003o0080
003o0P00o`050000o`800?l00P000?l5003o00L0003o1000o`090000oaT00?l00P000?l@003o00ko
oooo1`000?l7003o00T0003o1P00o`050000o`@00?l040000?l9003o0180003o00<0oh000000o`00
0?l06@000?l4003o00<0003o1P00o`0>0000o`800?l03_ooool40?n000T0o`000`3oP0040000o`80
oh000`3o00040?n000<0o`000P3oP0020000o`D0oh0010000?l<0?n00080o`001`3oP0020?l00080
oh000P3o00000`3oP000o`000?l000020?l000D0oh00103o00050?n000@0o`002@3oP0020?l00080
oh000`3o00040?n000<0o`003`3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`D0o`00
103oP00D0?l000030?n0003o0000o`0000@0oh001@3o00020?n001L0o`000P3oP0040?l000030?n0
003o0000o`0002@0o`000P3oP0030?l00080oh000P3o00020?n000L0o`00103oP0000`3o0000oh00
0?n000020?l000kooooo7@00o`030000oaT00?l00P000?l2003o00D0003o0P00o`020000o`D00?l0
1`000?l4003o00T0003o6@00o`020000oa000?l03_ooool70000o`L00?l02@000?l6003o00D0003o
1000o`0@0000o`T00?l04P000?l00`3oP000003o0000o`0I0000o`@00?l00`000?l6003o00h0003o
0P00o`0>ooooo`@0oh002@3o00030?n000@0003o0P3oP0030?l000@0oh000`3o00020?n00080003o
1@3oP0040000o``0oh000P3o00070?n00080o`000P3oP0020?l000030?n0003o0000o`000080o`00
1@3oP0040?l000D0oh00103o00090?n00080o`000P3oP0030?l000@0oh000`3o000?0?n000030?l0
003oP000oh000080oh006?ooool001Kooooo0P3oP00N0?l00080oh001@3o00040?n000d0o`000`3o
P00;0?l00080oh000`3o00020?n00080o`000`3oP00T0?l000@0oh001@3o00040?n00080003o1@3o
000>oooooad00?l01@000?lK003o00D0003o1000o`070000o`T00?l02@000?lG003o00d0003o0`00
o`020000o`800?l03_ooool90000o`@00?l05@000?l2003o0080003o00<00?l00000o`000?l02`00
0?l7003o01@0003o0`3oP0080000o`03003o00000?l0003o02d0003o3_ooool20?n000<0003o2`3o
P0020000o`80oh001@3o00050?n00080o`001`3oP0020?l00080oh000P3o00050?n00080o`00103o
P0050?l00080oh002@3o000@0?n00080o`002@3oP0000`3o0000oh000?n000060?n000030?l0003o
P000oh0000T0oh000P3o00020?n000D0o`000P3oP0020?l000<0oh000P3o000Hooooo`005_ooool2
0?n001h0o`000P3oP0050?l000@0oh003@3o00030?n000/0o`000P3oP0030?l00080oh000P3o0003
0?n002@0o`00103oP0050?l000@0oh000P000?l50?l000kooooo7@00o`050000oa/00?l01@000?l4
003o00L0003o2@00o`090000oaL00?l03@000?l3003o0080003o0P00o`0>ooooo`T0003o1000o`0E
0000o`800?l00P000?l00`00o`00003o0000o`0;0000o`L00?l050000?l30?n000P0003o00<00?l0
0000o`000?l0;@000?l>ooooo`80oh000`000?l;0?n00080003o0P3oP0050?l000D0oh000P3o0007
0?n00080o`000P3oP0020?l000D0oh000P3o00040?n000D0o`000P3oP0090?l00100oh000P3o0009
0?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0002@3oP0020?l00080oh001@3o0002
0?n00080o`000`3oP0020?l001Sooooo000Fooooo`80oh001`3o00040?n000030?l0003oP000oh00
00L0o`000P3oP00>0?l000@0oh00403o00020?n00100o`001@3oP00?0?l00080oh0000<0o`000?n0
003oP0003@3o00000`3oP000o`000?l000020000o`80oh001`3o00020?n00080003o1@3o000>oooo
o`800?l01@000?lI003o0080003o5000o`0C0000o`800?l00P000?l;003o0180003o4P00o`0<0000
o`800?l03_ooool40000o``00?l06@000?l20?n000T0003o1`00o`0O0000o`03003o00000?l0003o
02@0003o103oP0030000o`800?l03_ooool40?n000030?l0003oP000oh000080oh001@3o00090?n0
0080o`001@3oP0020?l000/0oh000P3o00050?n00080003o103oP0000`3o0000oh000?n000020?l0
00D0oh002@3o00060?n000030000o`3oP000oh0000@0oh000P3o000I0?n000T0o`0000<0oh000?l0
003o0000103oP0020?l000030?n0003o0000o`000080003o6?ooool001Kooooo0P3oP0070?l000@0
oh0000<0o`000?n0003oP0001`3o00020?n000h0o`00103oP00@0?l00080oh00403o00050?n000l0
o`000P3oP0000`3o0000oh000?n0000=0?l000030?n0003o0000o`000080003o0P3oP0070?l00080
oh000P000?l50?l000kooooo0P00o`050000oaT00?l00P000?lD003o01<0003o0P00o`020000o`/0
0?l04P000?lB003o00`0003o0P00o`0>ooooo`@0003o3000o`0I0000o`80oh002@000?l7003o01l0
003o00<00?l00000o`000?l090000?l40?n000<0003o0P00o`0>ooooo`@0oh0000<0o`000?n0003o
P0000P3oP0050?l000T0oh000P3o00050?n00080o`002`3oP0020?l000D0oh000P000?l40?n00003
0?l0003oP000oh000080o`001@3oP0090?l000H0oh0000<0003o0?n0003oP000103oP0020?l001T0
oh002@3o00000`3oP000o`000?l000040?n00080o`0000<0oh000?l0003o00000P000?lHooooo`00
5_ooool20?n000T0o`001@3oP0060?l000030?n0003o0000o`0000d0o`0000<0oh000?l0003o0000
1P3o00000`3oP000o`000?l0000M0?l000<0oh000P3o00020?n00080o`000P3oP00J0?l000H0oh00
0`3o00020?n00080o`0010000?l00`3oP000o`000?l000020?l000kooooo1@000?l8003o00030000
o`00o`000?l002800?l07@000?l9003o00L0003o1000o`000`000?l00?l0003o000B003o00/0003o
0P00o`050000o`kooooo1000o`000`000?l00?l0003o0002003o00D0003o0P00o`0>0000o`T00?l0
0P000?l20?n000D0003o0P00o`070000o`800?l01P000?l3003o00D0003o1000o`0>0000o`800?l0
40000?l4003o01D0003o1000o`0>ooooo`D0oh000P3o00020?n00080003o0P3oP0000`3o0000oh00
0?n000020?n000D0o`000P3oP0020000o`L0oh0010000?l50?n00080o`000P3oP0050000o`/0oh00
0P000?l00`3o0000oh000?n000040?l000h0oh001@3o00040?n000@0o`0000<0oh000?l0003o0000
103oP0020?l000P0oh00103o00040?n000030?l0003oP000oh0000H0o`0000<0oh000?l0003o0000
0P3oP00Hooooo`005_ooool20?n000T0o`001@3oP0060?l000030?n0003o0000o`0000d0o`0000<0
oh000?l0003o00001P3o00000`3oP000o`000?l0000M0?l000<0oh000P3o00020?n00080o`000P3o
P00J0?l000H0oh000`3o00020?n00080o`0010000?l00`3oP000o`000?l000020?l000kooooo1@00
0?l8003o00030000o`00o`000?l002800?l07@000?l9003o00L0003o1000o`000`000?l00?l0003o
000B003o00/0003o0P00o`050000o`kooooo1000o`000`000?l00?l0003o0002003o00D0003o0P00
o`0>0000o`T00?l00P000?l20?n000D0003o0P00o`070000o`800?l01P000?l3003o00D0003o1000
o`0>0000o`800?l040000?l4003o01D0003o1000o`0>ooooo`D0oh000P3o00020?n00080003o0P3o
P0000`3o0000oh000?n000020?n000D0o`000P3oP0020000o`L0oh0010000?l50?n00080o`000P3o
P0050000o`/0oh000P000?l00`3o0000oh000?n000040?l000h0oh001@3o00040?n000@0o`0000<0
oh000?l0003o0000103oP0020?l000P0oh00103o00040?n000030?l0003oP000oh0000H0o`0000<0
oh000?l0003o00000P3oP00Hooooo`005_ooool90?l00080oh002@3o00050?n00280o`00103oP007
0?l00080oh000`3o00060?n000L0o`000P3oP0070?l000L0oh002`3o00000`3oP000o`000?l00002
0?n000D0o`000P3oP0020?l000L0oh000P3o000>ooooo`L0003o1P00o`000`000?l00?l0003o000=
003o00030000o`00o`000?l001T00?l05P000?l9003o00/0003o5@00o`0B0000o`kooooo1`00o`06
0000o`T00?l020000?l6003o0080003o00<00?l00000o`000?l01`000?l4003o00h0003o0P00o`05
0000o`H00?l030000?l2003o00/0003o1@00o`0;0000o`800?l01@000?l2003o00T0003o3_ooool2
0?n00080o`001@3oP0020000o`80oh0000<0o`000?n0003oP0000P3o00020?n000<0o`000P3oP002
0000o`D0o`000P3oP0020000o`<0oh001P3o00030?n000@0003o1@3o00060?n00080o`001@3oP005
0?l000/0oh000P3o00020?n000030?l0003oP000oh000080o`002`3oP0030?l00080oh000P3o0005
0?n000@0o`000P3oP0050?l000D0oh000P3o00020?n001Sooooo000Fooooo`/0o`000`3oP0040?l0
0080oh000P3o00000`3oP000o`000?l000050?n000@0o`000P3oP0020?l000D0oh008P3o00040?n0
0180o`000`3oP00I0?l00080003o0P3o00020?n000030?l0003oP000oh000080oh003_ooool50000
obl00?l03@000?l00`00o`00003o0000o`090000o`80oh002@00o`090000oaL00?l02`000?l7003o
00kooooo3P000?l8003o00L0003o1@00o`020000o`D00?l01`000?l2003o0100003o0P00o`090000
o`800?l030000?l2003o0100003o0P00o`070000o`80oh000P000?l20?n000h0003o3_ooool90?n0
0080o`001`3oP0050?l000/0oh000P000?l20?n000030?l0003oP000oh0000T0oh000P3o00070?n0
0080o`000P3oP0020?l000h0oh000P3o00070?n00080o`000`3oP0020?l000D0oh000P3o000F0?n0
00030?l0003oP000oh0000L0oh000P3o00020?n001Sooooo000Fooooo`/0o`000`3oP0040?l00080
oh000P3o00000`3oP000o`000?l000050?n000@0o`000P3oP0020?l000D0oh008P3o00040?n00180
o`000`3oP00I0?l00080003o0P3o00020?n000030?l0003oP000oh000080oh003_ooool50000obl0
0?l03@000?l00`00o`00003o0000o`090000o`80oh002@00o`090000oaL00?l02`000?l7003o00ko
oooo3P000?l8003o00L0003o1@00o`020000o`D00?l01`000?l2003o0100003o0P00o`090000o`80
0?l030000?l2003o0100003o0P00o`070000o`80oh000P000?l20?n000h0003o3_ooool90?n00080
o`001`3oP0050?l000/0oh000P000?l20?n000030?l0003oP000oh0000T0oh000P3o00070?n00080
o`000P3oP0020?l000h0oh000P3o00070?n00080o`000`3oP0020?l000D0oh000P3o000F0?n00003
0?l0003oP000oh0000L0oh000P3o00020?n001Sooooo000Fooooo`80o`000P3oP00C0?l00080oh00
0P3o00030?n000T0o`000P3oP00@0?l00080oh000P3o00020?n00080o`00203oP0040?l000@0oh00
1@3o00040?n001<0o`000P3oP00=0?l000030?n0003o0000o`0000@0oh001`3o000>ooooo`L0003o
=000o`0D0000o`T00?l02@000?lE003o00L0003o0P3oP0060000o`03003o00000?l0003o00800?l0
3_ooool50000o`800?l01`000?l;003o00/0003o0`00o`0X0000o`<0oh00>0000?l>ooooo`@0o`00
2P3oP0040?l000@0oh0000<0o`000?n0003oP0000P3oP0020000o`030?l0003oP000oh000080oh00
0P000?l70?n000D0o`000P3oP0020?l00180oh001`3o000;0?n000<0o`001P3oP0020?l000030?n0
003o0000o`0000@0o`000P3oP0000`3o0000oh000?n000020?l000D0oh00103o00030?n000@0o`00
2@3oP00Hooooo`005_ooool20?l00080oh004`3o00020?n00080o`000`3oP0090?l00080oh00403o
00020?n00080o`000P3oP0020?l000P0oh00103o00040?n000D0o`00103oP00C0?l00080oh003@3o
00000`3oP000o`000?l000040?n000L0o`003_ooool70000oc@00?l050000?l9003o00T0003o5@00
o`070000o`80oh001P000?l00`00o`00003o0000o`02003o00kooooo1@000?l2003o00L0003o2`00
o`0;0000o`<00?l0:0000?l30?n003P0003o3_ooool40?l000X0oh00103o00040?n000030?l0003o
P000oh000080oh000P000?l00`3o0000oh000?n000020?n00080003o1`3oP0050?l00080oh000P3o
000B0?n000L0o`002`3oP0030?l000H0oh000P3o00000`3oP000o`000?l000040?l00080oh0000<0
o`000?n0003oP0000P3o00050?n000@0o`000`3oP0040?l000T0oh006?ooool001Kooooo0P3o0003
0?n000H0o`000`3oP00?0?l000<0oh000P3o00090?n000D0o`000P3oP0060?l000<0oh001P3o0005
0?n000<0o`000P3oP0020?l00080oh000P3o00000`3oP000o`000?l0000B0?l00080oh00303o0006
0?n000<0o`001P3oP0050?l00080oh003_ooool50000ocP00?l040000?l7003o00L0003o0P3oP007
0000oaH00?l02`000?l5003o00kooooo1@000?l2003o00L0003o1000o`020000o`800?l000<0003o
003o0000o`002@000?l7003o00/0003o103oP00d0000o`03003o00000?l0003o00/0003o0P3oP00>
0000o`kooooo2@3oP0020?l000L0oh001@3o00020?n00080003o1`3oP0020000o`L0oh000P3o000;
0?n000L0o`000`3oP0020000o`80oh000P3o00090?n000030?l0003oP000oh0000l0oh0000<0o`00
0?n0003oP0004P3oP0040?l000h0oh006?ooool001Kooooo0P3o00030?n000H0o`000`3oP00?0?l0
00<0oh000P3o00090?n000D0o`000P3oP0060?l000<0oh001P3o00050?n000<0o`000P3oP0020?l0
0080oh000P3o00000`3oP000o`000?l0000B0?l00080oh00303o00060?n000<0o`001P3oP0050?l0
0080oh003_ooool50000ocP00?l040000?l7003o00L0003o0P3oP0070000oaH00?l02`000?l5003o
00kooooo1@000?l2003o00L0003o1000o`020000o`800?l000<0003o003o0000o`002@000?l7003o
00/0003o103oP00d0000o`03003o00000?l0003o00/0003o0P3oP00>0000o`kooooo2@3oP0020?l0
00L0oh001@3o00020?n00080003o1`3oP0020000o`L0oh000P3o000;0?n000L0o`000`3oP0020000
o`80oh000P3o00090?n000030?l0003oP000oh0000l0oh0000<0o`000?n0003oP0004P3oP0040?l0
00h0oh006?ooool001Kooooo0P3oP0070?l00080oh000P3o00000`3oP000o`000?l0000O0?l00003
0?n0003o0000o`0000L0o`00103oP0050?l00080oh004P3o00040?n001D0o`001@3oP0020?l000H0
oh000`3o00060?n000<0o`000P3oP00>ooooo`L0003o=P00o`0;0000o`03003o00000?l0003o00@0
003o1@00o`0@0000oa@00?l010000?l00`00o`00003o0000o`040000o`L00?l03_ooool20?n000`0
003o0P00o`040000o`<00?l02`000?l2003o0180003o0`3oP00[0000o`@0oh0010000?l00`00o`00
003o0000o`0K0000o`kooooo103oP0030000o`80oh001@3o00020?n00080o`001@3oP0020?l000T0
003o103oP0000`3o0000oh000?n000020?n000L0o`00103oP0020?l001`0oh000P3o000;0?n00080
o`00303oP0020?l000<0oh000P000?l70?n000@0o`002@3oP00Hooooo`005_ooool40?l000030?n0
003o0000o`000080oh002`3o00020?n000P0o`000P3oP0040?l000<0oh00203o00000`3oP000o`00
0?l000020?l000@0oh000`3o00020?n000D0o`000P3oP00>0?l000T0oh00603o00050?n00080o`00
0`3oP0020?l000@0oh001@3o00020?n000kooooo0P00o`020000o`03003o00000?l0003o00H00?l0
00<0003o003o0000o`00:`00o`060000o`<0oh003@000?l00`00o`00003o0000o`0?0000o`03003o
00000?l0003o0080003o4000o`090000o`T00?l03_oooolT0000o`D00?l090000?l4003o00<0003o
2@00o`0?0000o`<00?l01@000?l2003o0080003o1`00o`0;0000o`kooooo1`000?l40?n00080o`00
2P3oP0020?l000@0003o0`3oP0020000oaH0oh0000<0o`000?n0003oP0000P3o00020?n00080o`00
00<0oh000?l0003o00000P3oP0020?l000L0oh000`3o00090?n00080o`00503oP0030000o`T0oh00
103o00090?n001Sooooo000Fooooo`@0o`0000<0oh000?l0003o00000P3oP00;0?l00080oh00203o
00020?n000@0o`000`3oP0080?l000030?n0003o0000o`000080o`00103oP0030?l00080oh001@3o
00020?n000h0o`002@3oP00H0?l000D0oh000P3o00030?n00080o`00103oP0050?l00080oh003_oo
ool2003o0080003o00<00?l00000o`000?l01P00o`000`000?l00?l0003o000[003o00H0003o0`3o
P00=0000o`03003o00000?l0003o00l0003o00<00?l00000o`000?l00P000?l@003o00T0003o2@00
o`0>ooooob@0003o1@00o`0T0000o`@00?l00`000?l9003o00l0003o0`00o`050000o`800?l00P00
0?l7003o00/0003o3_ooool70000o`@0oh000P3o000:0?n00080o`0010000?l30?n00080003o5P3o
P0000`3o0000oh000?n000020?l00080oh000P3o00000`3oP000o`000?l000020?n00080o`001`3o
P0030?l000T0oh000P3o000D0?n000<0003o2@3oP0040?l000T0oh006?ooool001Kooooo2@3o0004
0?n002<0o`000P3oP0040?l00080oh0000<0o`000?n0003oP0006@3o00020?n000D0o`000P3oP006
0?l000030?n0003o0000o`0000h0o`000P3oP0060?l000D0oh000P3o00030?n000@0o`003_ooool2
003o00D0003o:`00o`020000o`L00?l03@000?l00`00o`00003o0000o`060000o`<00?l02`000?lK
003o0080003o3P00o`0>ooooo`80003o0P3oP0000`3o0000003o0000o`0O0000o`<00?l00P000?l4
0?n001T0003o00<0oh000000o`000?l02@000?l7003o00@0003o0P00o`0E0000o`T00?l02`000?l>
ooooo`80003o0`3oP0020000o`@0oh001`3o00050?n00080o`000P3oP0020?l000030?n0003o0000
o`000080oh001`3o000R0?n000H0o`000`3oP0020?l000L0oh000P3o00070?n000@0003o2@3oP000
0`3o0000oh000?n000020?l000@0oh0000<0003o0?n0003oP0001P3oP0000`3o0000oh000?n00002
0?l001Sooooo000Fooooo`T0o`00103oP00S0?l00080oh00103o00020?n000030?l0003oP000oh00
01T0o`000P3oP0050?l00080oh001P3o00000`3oP000o`000?l0000>0?l00080oh001P3o00050?n0
0080o`000`3oP0040?l000kooooo0P00o`050000ob/00?l00P000?l7003o00d0003o00<00?l00000
o`000?l01P000?l3003o00/0003o6`00o`020000o`h00?l03_ooool20000o`80oh0000<0o`000000
o`000?l07`000?l3003o0080003o103oP00I0000o`030?n000000?l0003o00T0003o1`00o`040000
o`800?l05@000?l9003o00/0003o3_ooool20000o`<0oh000P000?l40?n000L0o`001@3oP0020?l0
0080oh000P3o00000`3oP000o`000?l000020?n000L0o`008P3oP0060?l000<0oh000P3o00070?n0
0080o`001`3oP0040000o`T0oh0000<0o`000?n0003oP0000P3o00040?n000030000o`3oP000oh00
00H0oh0000<0o`000?n0003oP0000P3o000Hooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000W
ooooog7o00009ooooomao`0002OoooooLOl0000Tooooo`008_ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo
0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo
0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o
1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
1?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oo
oolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolF
o`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00
o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Go
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Co
oooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo
0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5
oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000O
oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo
0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool001oooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?l007oo
001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lF
ool000Go001o5_l0o`0jo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lG
ool000Co001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo
001o00;o001o5ooo000jo`00OaKoogl01?l007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000OoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo
00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001o
o`00O`02o`00OaOoo`00E?l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o
5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool0
07l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo
0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l0K_l007l0
0ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08_ooool002;oooooL_l0000Wooooog7o00009ooooomao`0002OoooooLOl0000T
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool50?l000P00?l000<0o`00
003o0000o`001`3o00020?n00080o`000P3oP00:0?l000P00?l02P3o00060?n000800?l00`3o0002
003o00T0o`000`000?l20?l00080oh001@3o0002003o00L0o`000P000?l70?l00080oh002`3o0002
0000o`T0o`0000<0003o0?l0003o00000P3oP00>ooooo`80oh000P000?l<003o00L0o`000P000?l5
003o00@0o`000P00o`070000oa@00?l00P3o00000`00o`00003o0000o`09003o0080o`005@00o`02
0?l000T00?l00P3o0005003o0080o`000P00o`020?l000<00?l00P3o00020000o`<0oh000P000?l2
0?l000kooooo1@00o`080?l000030000o`3o0000o`0000@00?l00`3o00020000o`80o`000P00o`00
0`3oP000o`000?l000020?l000@0003o0`3oP0020?l000800?l00P3oP00<003o00@0o`000`3oP002
0000o`@0o`000`00o`040?l00080003o00<0o`000000o`000?l02@3o00090000o`80oh000P00o`03
0?l000T0003o0P3o00020000o`80oh0000<0003o0?l0003o00001P3o00000`000?l0o`000?l00002
0000o`kooooo0P3oP0020?l00003003o003o0000o`000080o`001@3oP002003o00L0oh000P000?l2
0?l00080oh0000<00?l00000o`000?l01000o`020?n000<0o`00103oP0030?l00080oh000P000?l2
0?l000T0oh000P3o00000`3oP000o`000?l000020?n00080o`000`3oP0020?l00080003o0P3oP000
0`3o0000oh000?n000040?n000800?l000<0003o0?n0003oP0000P3o00020?n000<0o`000P3oP002
0?l00080003o1`3o00020?n000030?l0003oP000oh000080003o0P3o00050?n00080003o2@3oP00H
ooooo`005_ooool50?l000P00?l000<0o`00003o0000o`001`3o00020?n00080o`000P3oP00:0?l0
00P00?l02P3o00060?n000800?l00`3o0002003o00T0o`000`000?l20?l00080oh001@3o0002003o
00L0o`000P000?l70?l00080oh002`3o00020000o`T0o`0000<0003o0?l0003o00000P3oP00>oooo
o`80oh000P000?l<003o00L0o`000P000?l5003o00@0o`000P00o`070000oa@00?l00P3o00000`00
o`00003o0000o`09003o0080o`005@00o`020?l000T00?l00P3o0005003o0080o`000P00o`020?l0
00<00?l00P3o00020000o`<0oh000P000?l20?l000kooooo1@00o`080?l000030000o`3o0000o`00
00@00?l00`3o00020000o`80o`000P00o`000`3oP000o`000?l000020?l000@0003o0`3oP0020?l0
00800?l00P3oP00<003o00@0o`000`3oP0020000o`@0o`000`00o`040?l00080003o00<0o`000000
o`000?l02@3o00090000o`80oh000P00o`030?l000T0003o0P3o00020000o`80oh0000<0003o0?l0
003o00001P3o00000`000?l0o`000?l000020000o`kooooo0P3oP0020?l00003003o003o0000o`00
0080o`001@3oP002003o00L0oh000P000?l20?l00080oh0000<00?l00000o`000?l01000o`020?n0
00<0o`00103oP0030?l00080oh000P000?l20?l000T0oh000P3o00000`3oP000o`000?l000020?n0
0080o`000`3oP0020?l00080003o0P3oP0000`3o0000oh000?n000040?n000800?l000<0003o0?n0
003oP0000P3o00020?n000<0o`000P3oP0020?l00080003o1`3o00020?n000030?l0003oP000oh00
0080003o0P3o00050?n00080003o2@3oP00Hooooo`005_ooool50?l000H00?l03P3o00020?n00080
003o303o0006003o00X0o`000P3oP0020000oa00o`000P3oP0030000o`80o`000P3oP00=0?l00003
003o003o0000o`000080o`002@00o`030?l00080003o103o00020000o`<0o`000P000?l40?l00003
0000o`3oP000oh000080oh003_ooool40000o`T00?l02@3o0008003o0080o`001000o`070000oa@0
0?l00`3o00020000o`800?l00P3o0007003o0080o`001@00o`020?l001h00?l01`3o00020000o`@0
o`000P3oP0000`3o0000003o0000o`020?l000kooooo1@00o`080?l000030000o`3o0000o`0000H0
0?l00`3oP0050?l000800?l00P3o00070000o`@0o`000P3oP0030?l000/00?l02`3o00000`00o`00
o`000?l000020?l000L0oh001P3o000:0000o`80o`000P00o`050?l00080003o0P3oP0020?l00003
0?n000000?l0003o0080o`001@3oP0040?l000D0003o0P3oP0020000o`kooooo0P3oP0020000o`<0
0?l0103o00070?n00080o`001`3oP0030?l000@0003o0P00o`030?l000@0oh000P3o00020?n00003
0?l0003oP000oh000080003o103o00000`3oP000o`000?l000020?l000@00?l000<0oh000?l0003o
00000P3o00020?n000030?l0003oP000oh000080003o0P3oP0020?l000D0oh000P00o`0<0?n00080
o`000P000?l20?n00080o`000`3oP0020?l000D0oh000P3o00050?n00080o`000P000?l70?n00080
o`006?ooool001Kooooo1@3o0006003o00h0o`000P3oP0020000o``0o`001P00o`0:0?l00080oh00
0P000?l@0?l00080oh000`000?l20?l00080oh003@3o00000`00o`00o`000?l000020?l000T00?l0
0`3o00020000o`@0o`000P000?l30?l00080003o103o00000`000?l0oh000?n000020?n000kooooo
10000?l9003o00T0o`002000o`020?l000@00?l01`000?lD003o00<0o`000P000?l2003o0080o`00
1`00o`020?l000D00?l00P3o000N003o00L0o`000P000?l40?l00080oh0000<0o`000000o`000?l0
0P3o000>ooooo`D00?l0203o00000`000?l0o`000?l00006003o00<0oh001@3o0002003o0080o`00
1`000?l40?l00080oh000`3o000;003o00/0o`0000<00?l00?l0003o00000P3o00070?n000H0o`00
2P000?l20?l000800?l01@3o00020000o`80oh000P3o00000`3oP000003o0000o`020?l000D0oh00
103o00050000o`80oh000P000?l>ooooo`80oh000P000?l3003o00@0o`001`3oP0020?l000L0oh00
0`3o00040000o`800?l00`3o00040?n00080o`000P3oP0000`3o0000oh000?n000020000o`@0o`00
00<0oh000?l0003o00000P3o0004003o00030?n0003o0000o`000080o`000P3oP0000`3o0000oh00
0?n000020000o`80oh000P3o00050?n000800?l0303oP0020?l00080003o0P3oP0020?l000<0oh00
0P3o00050?n00080o`001@3oP0020?l00080003o1`3oP0020?l001Sooooo000Fooooo`80o`000P3o
P005003o0100o`000P3oP0020000o`D0o`000P3oP0050?l000H00?l01`3o00030000oa@0o`000P3o
P0030000oaH0o`002@00o`030?l00080oh000P3o00020?n00080003o2@3o00000`3oP000o`000?l0
00020?n000kooooo0P3o00020?n000T00?l0303o000;003o00L0003o5000o`020?l00003003o0000
0?l0003o00/00?l00P3o000U003o00L0o`000P000?l40?l000<0oh000P000?l20?l000kooooo2`00
o`020?l000030?n0003o0000o`0000H00?l01@3o0002003o00030?l00000o`000?l000800?l01`00
0?l40?l000<0oh000P3o0002003o00@0o`0000<00?l00?l0003o00000P00o`040?l000<0oh000P3o
0003003o0080o`0010000?l20?n000<0003o0P3oP0020?l00080oh0000<0003o0?n0003oP0000P00
0?l50?n000H0o`000`000?l20?n00080o`000`3oP0020?l000T0oh000P3o00090000o`kooooo103o
P0000`000?l0o`000?l000020?l000D0oh000P3o00020000o`80oh000P3o00050?n000800?l000<0
o`000?n0003oP0000P000?l2003o0080003o00<0o`000?n0003oP0000P3oP0050?l00080oh000P00
o`020?l000<0oh000P3o00040?n000<0o`000P3oP0040?l000030000o`3o0000o`000080003o103o
P0000`000?l0o`000?l000060?l000030?n0003o0000o`000080o`001@3oP0020?l000@0oh000P3o
00030?n00080o`000P3oP0000`3o0000oh000?n000040?n00080003o00<0oh000000o`000?l02`3o
P00Hooooo`005_ooool20?l000D00?l0103o00020?n000030?l00000o`000?l000T0o`00103oP005
0?l00080003o0`3o00020?n000/0o`000P00o`020000oa00o`000`3oP0040?l000<0003o603o0002
0000o`D00?l00P3o00000`000?l0oh000?n000020?l000@0003o1`3o00020?n000<0003o0P3o000>
ooooo`@0oh001@00o`020?l000D00?l01P3o000:003o0080o`000P00o`070000o`/00?l00P3o0007
003o0080o`0000<00?l00000o`000?l01000o`000`3o00000?l0003o0004003o0080o`001@00o`02
0?l001h00?l00P3o00040000o`030?l000000?l0003o00@0o`001@3oP0020?l000kooooo103oP005
003o00@0o`0000<0oh000?l0003o0000103o0002003o00030?l00000o`000?l00080o`000P00o`00
0`000?l00?l0003o00020?l000L0oh0010000?l30?n00080o`000P00o`040?l000D00?l0103o0000
0`000?l0oh000?n000040?l00003003o003o0000o`0000L0003o1P3oP0020?l000T0oh0000<0003o
0?l0003o00000P3o00020?n000L0003o0`00o`040?l00080oh002@3o00070?n000kooooo103oP000
0`000?l0o`000?l000020?l000T0oh000P3o00030?n00080o`000P000?l50?l00080003o0P00o`02
0000o`030?l0003oP000oh000080o`00103oP0000`3o0000oh000?n00002003o0080o`000P00o`03
0?l000/0oh000P3o00030?n000@0003o0P3o00050?n000800?l00P3o000E0?n000@0o`0000<0003o
0?n0003oP0001P3oP0000`000?l0oh000?n0000;0?n001Sooooo000Fooooo`80o`001@00o`040?l0
0080oh0000<0o`00003o0000o`002@3o00040?n000D0o`000P000?l30?l00080oh002`3o0002003o
0080003o403o00030?n000@0o`000`000?lH0?l00080003o1@00o`020?l000030000o`3oP000oh00
0080o`0010000?l70?l00080oh000`000?l20?l000kooooo103oP005003o0080o`001@00o`060?l0
00X00?l00P3o0002003o00L0003o2`00o`020?l000L00?l00P3o00000`00o`00003o0000o`04003o
00030?l00000o`000?l000@00?l00P3o0005003o0080o`007P00o`020?l000@0003o00<0o`000000
o`000?l0103o00050?n00080o`003_ooool40?n000D00?l0103o00000`3oP000o`000?l000040?l0
00800?l000<0o`00003o0000o`000P3o0002003o00030000o`00o`000?l00080o`001`3oP0040000
o`<0oh000P3o0002003o00@0o`001@00o`040?l000030000o`3oP000oh0000@0o`0000<00?l00?l0
003o00001`000?l60?n00080o`002@3oP0000`000?l0o`000?l000020?l00080oh001`000?l3003o
00@0o`000P3oP0090?l000L0oh003_ooool40?n000030000o`3o0000o`000080o`002@3oP0020?l0
00<0oh000P3o00020000o`D0o`000P000?l2003o0080003o00<0o`000?n0003oP0000P3o00040?n0
00030?l0003oP000oh0000800?l00P3o0002003o00<0o`002`3oP0020?l000<0oh0010000?l20?l0
00D0oh000P00o`020?l001D0oh00103o00000`000?l0oh000?n000060?n000030000o`3oP000oh00
00/0oh006?ooool001Kooooo2@00o`070?l00080oh001`3o00020000o`80oh0000<00?l00?l0003o
0000503o0002003o00D0o`000P000?l;0?l000030?n000000?l0003o00@0o`000P000?l70?l00080
003o1@3o00020?n000<0o`000P000?l60?l000D00?l00P3o00000`000?l0oh000?n000020?l00080
oh002@3o00020?n000D0o`003_ooool2003o0080oh001@00o`020?l000T00?l00P3o000:003o0080
o`000P00o`070000o`/00?l00P3o0007003o0080o`001`00o`000`3o00000?l0003o0002003o00@0
o`001@00o`040?l000<00?l00P3o0005003o0080o`004P00o`050000o`@0o`000P000?l50?n00080
o`003_ooool40?n000D00?l0103o00000`3oP000o`000?l000020?l00080oh000P3o00000`3oP000
o`000?l000040?l000030?n00000o`000?l00080o`000P3oP0020?l000030?n0003o0000o`0000L0
003o0P3o0004003o0080o`000`00o`060?l000030?n0003o0000o`000080003o1@3oP0070000o`/0
oh000P3o00040?n000030000o`3o0000o`000080003o0P3o00020000o`<0oh000P3o0003003o00@0
o`000P3oP0030?l00080oh00103o00070?n000kooooo0P000?l20?l000D0003o2@3oP0050?l000@0
oh003P00o`020?n000D0o`000P3oP0020?l000D0oh001P000?l30?n00080o`000P3oP0020?l00003
003o003o0000o`0000L0003o103oP0040?l000X0oh000P3o00090?n00080o`000P3oP0000`000?l0
oh000?n0000D0?n001Sooooo000Fooooo`T00?l01`3o00020?n000L0o`000P000?l20?n00003003o
003o0000o`0001@0o`000P00o`050?l00080003o2`3o00000`3oP000003o0000o`040?l00080003o
1`3o00020000o`D0o`000P3oP0030?l00080003o1P3o0005003o0080o`0000<0003o0?n0003oP000
0P3o00020?n000T0o`000P3oP0050?l000kooooo0P00o`020?n000D00?l00P3o0009003o0080o`00
2P00o`020?l000800?l01`000?l;003o0080o`001`00o`020?l000L00?l000<0o`00003o0000o`00
0P00o`040?l000D00?l0103o0003003o0080o`001@00o`020?l001800?l01@000?l40?l00080003o
1@3oP0020?l000kooooo103oP005003o00@0o`0000<0oh000?l0003o00000P3o00020?n00080o`00
00<0oh000?l0003o0000103o00000`3oP0000?l0003o00020?l00080oh000P3o00000`3oP000o`00
0?l000070000o`80o`001000o`020?l000<00?l01P3o00000`3oP000o`000?l000020000o`D0oh00
1`000?l;0?n00080o`00103oP0000`000?l0o`000?l000020000o`80o`000P000?l30?n00080o`00
0`00o`040?l00080oh000`3o00020?n000@0o`001`3oP00>ooooo`80003o0P3o00050000o`T0oh00
1@3o00040?n000h00?l00P3oP0050?l00080oh000P3o00050?n000H0003o0`3oP0020?l00080oh00
0P3o00000`00o`00o`000?l000070000o`@0oh00103o000:0?n00080o`002@3oP0020?l00080oh00
00<0003o0?n0003oP000503oP00Hooooo`005_ooool9003o00@0o`001@00o`090?l000<00?l03@3o
00020000oa`0o`000P000?l40?l00080003o1`3o00020?n000030?l000000?l0003o0080o`000P3o
P0030?l00080003o3@3o00000`3oP000o`000?l000020?l00080oh002@3o00020000o`D0o`003_oo
ool9003o0080o`002@00o`050?l000D00?l00P3o0004003o00L0003o5000o`030?l000H00?l00`3o
0002003o00D0o`001000o`020?l000800?l000<0003o003o0000o`000P3o0005003o0080o`001P00
o`000`3o00000?l0003o0009003o00@0003o00<0o`000000o`000?l00P3o00040000o`030?l00000
0?l0003o0080o`003_ooool40000o`L00?l00`3o00020000o`800?l00P3oP0020?l000030?n0003o
0000o`000080o`000P00o`000`3o0000oh000?n000020?l000D0oh000P3o00070000o`80o`001000
o`020?l000D00?l0103o00050000o`D0oh000P000?l20?n000T0003o1@3oP0040?l000L0oh001@3o
00020000o`@0o`001@000?l70?n000H0o`001@000?l>ooooo`80oh000P3o00000`3oP000003o0000
o`040?n00080003o0`3o0002003o00D0o`000P3oP0020000o`<0o`000P00o`040?n000<00?l0103o
00020?n000<0o`000P3oP0020?l000D0oh001P000?l30?n00080o`001@3oP0020?l00080oh002@00
0?l2003o0080003o00<0oh000?l0003o00001`3oP0040000o`L0oh000P3o00090?n000D0o`000P3o
P0040?l000D0oh006?ooool001Kooooo2@00o`040?l000D00?l02@3o0003003o00d0o`000P000?lL
0?l00080003o103o00020000o`L0o`000P3oP0000`3o0000003o0000o`020?l00080oh000`3o0002
0000o`d0o`0000<0oh000?l0003o00000P3o00020?n000T0o`000P000?l50?l000kooooo2@00o`02
0?l000T00?l01@3o0005003o0080o`001000o`070000oa@00?l00`3o0006003o00<0o`000P00o`05
0?l000@00?l00P3o0002003o00030000o`00o`000?l00080o`001@00o`020?l000H00?l000<0o`00
003o0000o`002@00o`040000o`030?l000000?l0003o0080o`0010000?l00`3o0000003o0000o`02
0?l000kooooo10000?l7003o00<0o`000P000?l2003o0080oh000P3o00000`3oP000o`000?l00002
0?l000800?l000<0o`000?n0003oP0000P3o00050?n00080o`001`000?l20?l000@00?l00P3o0005
003o00@0o`001@000?l50?n00080003o0P3oP0090000o`D0oh00103o00070?n000D0o`000P000?l4
0?l000D0003o1`3oP0060?l000D0003o3_ooool20?n00080o`0000<0oh000000o`000?l0103oP002
0000o`<0o`000P00o`050?l00080oh000P000?l30?l000800?l0103oP003003o00@0o`000P3oP003
0?l00080oh000P3o00050?n000H0003o0`3oP0020?l000D0oh000P3o00020?n000T0003o0P00o`02
0000o`030?n0003o0000o`0000L0oh0010000?l70?n00080o`002@3oP0050?l00080oh00103o0005
0?n001Sooooo000Fooooo`T00?l0103o00000`00o`00o`000?l0000;0?l000800?l01@3o00020000
o`D0o`001000o`030?l00080oh001000o`0C0?l00080003o2`3o0002003o00`0o`000P000?l=0?l0
00030000o`3o0000o`0000d0o`000P000?l30?l00080oh003_ooool9003o0080o`001`00o`050?l0
00L00?l00P3o0004003o00L0003o5000o`020?l00003003o003oP000oh0000800?l00P000?l:0?l0
00800?l01P3o00000`000?l00?l0003o0007003o0080o`001P00o`000`3o00000?l0003o0009003o
0080003o0`3o00020000o`80o`0010000?l00`3o0000003o0000o`020?l000kooooo10000?l5003o
0080003o0`3o00020?n000800?l00P3o00030?n000T0o`000P000?l20?l000`0oh000P3o000=003o
0080o`001@000?l20?n000030?l0003oP000oh000080003o0P3oP00<0000o`@0o`002@000?l20?l0
00800?l000<0oh000000o`000?l00P000?l20?l000T0003o00<0oh000000o`000?l00P000?l40?l0
00D0003o3_ooool20?n00080o`000`3oP0020?l000@0oh0000<00?l00?l0003o00000P3o00020?n0
0080o`001@3oP00;0?l00003003o003o0000o`000080o`000P3oP0050?l00080003o3P3oP0020000
o`80oh001`3o00020?n000L0003o0P3oP0020000o`030?l0003oP000oh000080oh000P3o00030?n0
0080003o4P3oP0020?l00080oh0000<00?l00?n0003oP0000P3oP002003o0080003o00<0oh000?l0
003o00000P00o`0Hooooo`005_ooool4003o00030?l00000o`000?l000800?l00P3o0002003o00L0
o`000P000?lC0?l000@00?l01@3o0006003o0100o`0000<0oh000000o`000?l03`3o00000`3oP000
o`000?l000040?l00080oh0000<00?l00?l0003o00001P3o00000`00o`00003o0000o`0D0?l00080
003o0`3o00020?n000kooooo5000o`020?l000P00?l00P3o0004003o00L0003o3@00o`000`3o0000
0?l0003o0002003o00@0o`001@00o`020000o`T0o`000`00o`060?l000030?n00000o`000?l000l0
0?l000<0o`00003o0000o`002`00o`070?l000@0003o00<0o`000000o`000?l00P3o000>ooooo`@0
oh001`00o`030?l00080oh000P3o0004003o00030?l00000o`000?l000L0o`0010000?l50?n000@0
o`000P000?l00`3oP000o`000?l00002003o00@0o`001`00o`020?l000<0003o1`3oP00?0000o`03
0?n0003o0000o`000080o`001`000?l20?n00080o`000`00o`020?l00080003o0P3o00000`000?l0
o`000?l0000;0000o`800?l00P3o00050000o`kooooo103oP0050?l000@0oh000`00o`020?l000T0
oh001@3o00060?n000030000o`3oP000oh0000@0o`000P3oP0000`00o`00o`000?l000020?n00080
o`000`3oP0020?l000L0oh000P000?l50?n000@0o`000P3oP0050000obP0oh0000<00?l00?n0003o
P000103oP0020000o`<0oh000P3o000Hooooo`005_ooool4003o00030?l00000o`000?l000800?l0
0P3o0002003o00L0o`000P000?lC0?l000@00?l01@3o0006003o0100o`0000<0oh000000o`000?l0
3`3o00000`3oP000o`000?l000040?l00080oh0000<00?l00?l0003o00001P3o00000`00o`00003o
0000o`0D0?l00080003o0`3o00020?n000kooooo5000o`020?l000P00?l00P3o0004003o00L0003o
3@00o`000`3o00000?l0003o0002003o00@0o`001@00o`020000o`T0o`000`00o`060?l000030?n0
0000o`000?l000l00?l000<0o`00003o0000o`002`00o`070?l000@0003o00<0o`000000o`000?l0
0P3o000>ooooo`@0oh001`00o`030?l00080oh000P3o0004003o00030?l00000o`000?l000L0o`00
10000?l50?n000@0o`000P000?l00`3oP000o`000?l00002003o00@0o`001`00o`020?l000<0003o
1`3oP00?0000o`030?n0003o0000o`000080o`001`000?l20?n00080o`000`00o`020?l00080003o
0P3o00000`000?l0o`000?l0000;0000o`800?l00P3o00050000o`kooooo103oP0050?l000@0oh00
0`00o`020?l000T0oh001@3o00060?n000030000o`3oP000oh0000@0o`000P3oP0000`00o`00o`00
0?l000020?n00080o`000`3oP0020?l000L0oh000P000?l50?n000@0o`000P3oP0050000obP0oh00
00<00?l00?n0003oP000103oP0020000o`<0oh000P3o000Hooooo`005_ooool4003o00030?l00000
o`000?l001@0o`000P00o`000`000?l0o`000?l000060?l000030000o`00o`000?l000800?l01`3o
0002003o00L0o`000P000?l@0?l00080003o2`3o00000`3oP000o`000?l000040?l000L00?l01@3o
00020000o`h0o`000P3oP0040?l00080003o0`3o00020?n000kooooo7P00o`020?l000@00?l01`00
0?l=003o00030?l00000o`000?l000@00?l00P3o0007003o00T0o`001@00o`040?l002000?l00`3o
00020000o`@0o`000P000?l00`3o0000003o0000o`020?l000kooooo103oP007003o0080o`0000<0
0?l00?l0003o00001`3o0002003o0080003o0`3o00020000o`@0oh000P3o00000`3oP000003o0000
o`040?l00080003o0`3o0004003o0080o`001@00o`040?l000L0003o0`3o00070000o`H0oh000P00
0?l00`00o`00003o0000o`020?l000L0003o0P3o0005003o00@0o`000`3oP002003o0080o`000P3o
P0020000o`030?n0003o0000o`000080003o0P00o`020?l000D0003o3_ooool4003o00030000o`3o
0000o`0000800?l00P3oP002003o00030?n00000o`000?l00080o`00303oP0020000o`H0oh0000<0
o`000?n0003oP000103oP0020?l000030?n0003o0000o`000080o`001@3oP0040?l000D0oh000P00
0?l70?n00080003o0P3oP0020000o`L0oh000P000?lG0?n00080o`002@3oP0000`00o`00003o0000
o`040?n00080003o1@3oP00Hooooo`005_ooool4003o00030?l00000o`000?l001@0o`000P00o`00
0`000?l0o`000?l000060?l000030000o`00o`000?l000800?l01`3o0002003o00L0o`000P000?l@
0?l00080003o2`3o00000`3oP000o`000?l000040?l000L00?l01@3o00020000o`h0o`000P3oP004
0?l00080003o0`3o00020?n000kooooo7P00o`020?l000@00?l01`000?l=003o00030?l00000o`00
0?l000@00?l00P3o0007003o00T0o`001@00o`040?l002000?l00`3o00020000o`@0o`000P000?l0
0`3o0000003o0000o`020?l000kooooo103oP007003o0080o`0000<00?l00?l0003o00001`3o0002
003o0080003o0`3o00020000o`@0oh000P3o00000`3oP000003o0000o`040?l00080003o0`3o0004
003o0080o`001@00o`040?l000L0003o0`3o00070000o`H0oh000P000?l00`00o`00003o0000o`02
0?l000L0003o0P3o0005003o00@0o`000`3oP002003o0080o`000P3oP0020000o`030?n0003o0000
o`000080003o0P00o`020?l000D0003o3_ooool4003o00030000o`3o0000o`0000800?l00P3oP002
003o00030?n00000o`000?l00080o`00303oP0020000o`H0oh0000<0o`000?n0003oP000103oP002
0?l000030?n0003o0000o`000080o`001@3oP0040?l000D0oh000P000?l70?n00080003o0P3oP002
0000o`L0oh000P000?lG0?n00080o`002@3oP0000`00o`00003o0000o`040?n00080003o1@3oP00H
ooooo`005_ooool2003o00h0o`000P000?l;0?l000030000o`3o0000o`0000H0o`0000<0003o003o
0000o`000P00o`070?l000800?l01`3o00020?n00080o`000P3oP0080?l00080003o0P3o00020000
o`<0o`000P000?l=0?l00080003o00<00?l00?l0003o00000P00o`050?l00080003o0P00o`070?l0
0080003o0`3o00020000o`T0o`000P3oP00>ooooo`T00?l00P3o000I003o00L0003o3@00o`000`3o
00000?l0003o00020?l000800?l00P3o000:003o00H0o`001`00o`020?l001800?l000<0o`00003o
0000o`002`00o`020?l00003003o00000?l0003o00@0o`001@3oP0020?l000kooooo3@00o`070?l0
00<00?l00P3o00020000o`<0o`000P3oP0040?l00080oh0000<0o`000000o`000?l01P3oP0000`3o
00000?l0003o0004003o00<0o`000P00o`020?l00080003o0`3o00020?n00080o`000P000?l00`3o
00000?l0003o00020?l000D0003o203oP0000`00o`00003o0000o`020?l00080oh000`3o00020?n0
00H0o`0000<00?l00?l0003o00000P3o00020000o`D00?l00P3o00020?n000<0o`000P3oP004003o
00030000o`3o0000o`000080o`003_ooool2003o0080o`000`3oP0020?l00080oh000P00o`000`00
0?l00?l0003o00020?l00080oh000P3o00050?n00080o`0000<0oh000000o`000?l01P3oP0000`00
0?l0oh000?n000040?n000800?l00`3oP0040?l00080oh0000<0003o0?n0003oP00010000?l30?n0
0080003o1`3oP0020000o`@0oh0000<0o`000?n0003oP0007@3oP0020?l000<0oh0010000?l20?n0
00030?l0003oP000oh0000@0oh000P000?l00`3oP000003o0000o`020?n001Sooooo000Fooooo`80
0?l03P3o00020000o`/0o`0000<0003o0?l0003o00001P3o00000`000?l00?l0003o0002003o00L0
o`000P00o`070?l00080oh000P3o00020?n000P0o`000P000?l20?l00080003o0`3o00020000o`d0
o`000P000?l00`00o`00o`000?l00002003o00D0o`000P000?l2003o00L0o`000P000?l30?l00080
003o2@3o00020?n000kooooo2@00o`020?l001T00?l01`000?l=003o00030?l00000o`000?l00080
o`000P00o`020?l000X00?l01P3o0007003o0080o`004P00o`000`3o00000?l0003o000;003o0080
o`0000<00?l00000o`000?l0103o00050?n00080o`003_ooool=003o00L0o`000`00o`020?l00080
003o0`3o00020?n000@0o`000P3oP0000`3o0000003o0000o`060?n000030?l00000o`000?l000@0
0?l00`3o0002003o0080o`000P000?l30?l00080oh000P3o00020000o`030?l00000o`000?l00080
o`001@000?l80?n00003003o00000?l0003o0080o`000P3oP0030?l00080oh001P3o00000`00o`00
o`000?l000020?l00080003o1@00o`020?l00080oh000`3o00020?n000@00?l000<0003o0?l0003o
00000P3o000>ooooo`800?l00P3o00030?n00080o`000P3oP002003o00030000o`00o`000?l00080
o`000P3oP0020?l000D0oh000P3o00000`3oP000003o0000o`060?n000030000o`3oP000oh0000@0
oh000P00o`030?n000@0o`000P3oP0000`000?l0oh000?n000040000o`<0oh000P000?l70?n00080
003o103oP0000`3o0000oh000?n0000M0?n00080o`000`3oP0040000o`80oh0000<0o`000?n0003o
P000103oP0020000o`030?n000000?l0003o0080oh006?ooool001Kooooo1@3o00020?n000T0o`00
0P000?l;0?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00001000o`050?l000800?l0
1`3o00020?n000L0o`000P000?l70?l00080003o0`3o00020000o`L0o`000P000?l40?l00080003o
00<00?l00?l0003o00000P3o0002003o00<0o`001000o`070?l00080oh000`3o00040000o`@0o`00
00<0003o0?l0003o00000P3o000>ooooo`T00?l00P3o000I003o00L0003o4000o`020?l000800?l0
0P3o0003003o00d0o`0000<0003o003o0000o`001000o`020?l000`00?l00P3o0004003o00030?l0
0000o`000?l00080o`000P00o`000`3o00000?l0003o0007003o0080003o103o00020?n000D0o`00
3_ooool=003o00`0o`000P00o`020?l000<00?l0103o00020?n000030000o`3oP000oh0000@0o`00
0P3oP0000`000?l00?l0003o0004003o00D0o`000P00o`020000o`<0o`000P3oP0020?l000<0oh00
103o00050000o`80oh00103o0003003o0080003o2@3o00020?n000@0o`0000<0oh000?l0003o0000
0P3o00020?n000<00?l00P3o00020000o`80oh000`3o00020?n000@00?l01@3o000>ooooo`800?l0
1`3o00020?n00080003o00<0oh000?l0003o00000P3oP0020?l00080oh000`000?l2003o0080o`00
0`3oP0020?l000@0oh0000<0003o0?n0003oP000103oP0030?l00080oh000P3o00050?n00080o`00
0P000?l40?l000<0oh000P000?l20?n000030000o`3oP000oh0000@0oh000P3o00030?n000H0o`00
4P3oP0000`000?l0oh000?n000070?n000H0003o2@3oP0030000o`80oh006?ooool001Kooooo1@3o
00020?n000T0o`000P000?l;0?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00001000
o`050?l000800?l01`3o00020?n000L0o`000P000?l70?l00080003o0`3o00020000o`L0o`000P00
0?l40?l00080003o00<00?l00?l0003o00000P3o0002003o00<0o`001000o`070?l00080oh000`3o
00040000o`@0o`0000<0003o0?l0003o00000P3o000>ooooo`T00?l00P3o000I003o00L0003o4000
o`020?l000800?l00P3o0003003o00d0o`0000<0003o003o0000o`001000o`020?l000`00?l00P3o
0004003o00030?l00000o`000?l00080o`000P00o`000`3o00000?l0003o0007003o0080003o103o
00020?n000D0o`003_ooool=003o00`0o`000P00o`020?l000<00?l0103o00020?n000030000o`3o
P000oh0000@0o`000P3oP0000`000?l00?l0003o0004003o00D0o`000P00o`020000o`<0o`000P3o
P0020?l000<0oh00103o00050000o`80oh00103o0003003o0080003o2@3o00020?n000@0o`0000<0
oh000?l0003o00000P3o00020?n000<00?l00P3o00020000o`80oh000`3o00020?n000@00?l01@3o
000>ooooo`800?l01`3o00020?n00080003o00<0oh000?l0003o00000P3oP0020?l00080oh000`00
0?l2003o0080o`000`3oP0020?l000@0oh0000<0003o0?n0003oP000103oP0030?l00080oh000P3o
00050?n00080o`000P000?l40?l000<0oh000P000?l20?n000030000o`3oP000oh0000@0oh000P3o
00030?n000H0o`004P3oP0000`000?l0oh000?n000070?n000H0003o2@3oP0030000o`80oh006?oo
ool001Kooooo2@3o0004003o00<0o`000P000?l;0?l000030000o`3o0000o`0000H0o`0000<0oh00
0?l0003o00000P00o`020000o``0o`000P3oP0040?l00080003o0`3o00020000o`L0o`0010000?l0
0`3o0000003o0000o`060?l00003003o00000?l0003o00@0o`000P000?l3003o0080o`000P00o`03
0?l000@00?l01`3o00040?n000<0o`000P000?l40?l000030000o`3o0000o`000080o`003_ooool9
003o0080o`004P00o`000`3o00000?l0003o0004003o00<0003o0P3o00020000oa000?l0103o0002
0?n000D00?l02@3o00020?n000030000o`00o`000?l000@00?l00`3o000D003o00D0o`001P00o`02
0?l00003003o00000?l0003o0080o`000P00o`020?n000D0o`003_ooool20?l000/00?l000<0o`00
003o0000o`002@3o0005003o0080o`000P000?l70?l000800?l0103o00000`3oP000o`000?l00004
003o00D0o`000P00o`020000o`<0o`000P3oP0040?l00003003o003o0000o`000080o`000P000?l5
0?n000H0o`0000<0003o003o0000o`001000o`070?l00080003o0P3o00000`3oP000o`000?l00004
0?l000030?n0003o0000o`000080o`001@000?l=0?l000kooooo1@3o00060?n00080003o00<0oh00
0?l0003o00000P3o00020?n000800?l00`3oP002003o0080o`0000<0oh000?l0003o00002@3o0002
0000o`/0oh001@3o00070?n000@0003o2@3oP0020?l000<0oh00103o00020000o`X0oh000P3o0004
0?n00080o`00203oP0020?l000T0oh000P3o00040?n000030000o`3oP000oh000080oh006?ooool0
01Kooooo2@3o0004003o00<0o`000P000?lG0?l000800?l00P000?lB0?l00080oh000`3o00020000
oa@0o`0000<00?l00000o`000?l0103o00020000o`<00?l00P3o0002003o00<0o`001000o`030?l0
0080003o0P3o00020?n000L0o`000P000?l20?n000030000o`3o0000o`000080o`003_ooool9003o
0080o`001@00o`020?l000/00?l000<0o`00003o0000o`001000o`020000o`<0o`000P3oP00B003o
0080o`000P00o`000`3o00000?l0003o0004003o00<0o`0010000?l20?n000030000o`00o`000?l0
00@00?l00`3o000D003o00L0o`001000o`020?l00003003o00000?l0003o00H0o`0000<0003o0?l0
003o00000P3o000>ooooo`@0o`0000<00?l00?l0003o00000P3o0002003o0080o`001`00o`050?l0
00D00?l04@3o00000`3oP000o`000?l00007003o0080o`000P00o`020000o`<0o`000P3oP0040?l0
0003003o003o0000o`000080003o0P3o00030?n000H0o`000P00o`000`000?l0o`000?l000020?l0
00@0003o00<0oh000?l0003o00000P3o00020000o`80o`0000<0oh000000o`000?l00P000?l20?l0
00<0oh000P3o00020000o`<0oh000P000?l90?l00080oh003_ooool20?l00080003o00<0o`000?n0
003oP0001P3oP0050?l000@0oh0000<0o`000?n0003oP0000P00o`020?n000L0o`000`3oP0020000
o`80oh000P00o`030?l000P0oh0000<0o`000000o`000?l01P000?l80?n00080o`00103oP0020?l0
00030000o`00o`000?l000@0o`000P3oP0030000o`@0oh000P000?lA0?n00080o`001P3oP0000`00
0?l0o`000?l000060?n000030000o`3oP000oh000080oh006?ooool001Kooooo2@3o0004003o00<0
o`000P000?lG0?l000800?l00P000?lB0?l00080oh000`3o00020000oa@0o`0000<00?l00000o`00
0?l0103o00020000o`<00?l00P3o0002003o00<0o`001000o`030?l00080003o0P3o00020?n000L0
o`000P000?l20?n000030000o`3o0000o`000080o`003_ooool9003o0080o`001@00o`020?l000/0
0?l000<0o`00003o0000o`001000o`020000o`<0o`000P3oP00B003o0080o`000P00o`000`3o0000
0?l0003o0004003o00<0o`0010000?l20?n000030000o`00o`000?l000@00?l00`3o000D003o00L0
o`001000o`020?l00003003o00000?l0003o00H0o`0000<0003o0?l0003o00000P3o000>ooooo`@0
o`0000<00?l00?l0003o00000P3o0002003o0080o`001`00o`050?l000D00?l04@3o00000`3oP000
o`000?l00007003o0080o`000P00o`020000o`<0o`000P3oP0040?l00003003o003o0000o`000080
003o0P3o00030?n000H0o`000P00o`000`000?l0o`000?l000020?l000@0003o00<0oh000?l0003o
00000P3o00020000o`80o`0000<0oh000000o`000?l00P000?l20?l000<0oh000P3o00020000o`<0
oh000P000?l90?l00080oh003_ooool20?l00080003o00<0o`000?n0003oP0001P3oP0050?l000@0
oh0000<0o`000?n0003oP0000P00o`020?n000L0o`000`3oP0020000o`80oh000P00o`030?l000P0
oh0000<0o`000000o`000?l01P000?l80?n00080o`00103oP0020?l000030000o`00o`000?l000@0
o`000P3oP0030000o`@0oh000P000?lA0?n00080o`001P3oP0000`000?l0o`000?l000060?n00003
0000o`3oP000oh000080oh006?ooool001Kooooo1@3o0002003o0080oh000P3o0002003o00030?l0
0000o`000?l001T0o`001000o`0K0?l00003003o003o0000o`0001H0o`000P3oP0000`000?l00?l0
003o00020?l000800?l00`3o00020?n000D0o`0020000?l3003o0080o`001@3oP0040?l000kooooo
0P00o`020?l000`00?l00P3o0002003o0080o`001`00o`000`3o00000?l0003o0006003o00030?l0
0000o`000?l00080oh004P00o`020?l000800?l000<0o`00003o0000o`001000o`030?l000L0003o
1P00o`030?l001l00?l00P3o0009003o00030000o`3o0000o`0000800?l03_ooool20?n000/0o`00
00<00?l00?l0003o00000P3o0002003o00<0o`000P00o`020?l000<00?l0203o00000`000?l0oh00
0?n000060?l000030?n0003o0000o`000080o`001@00o`020?l000800?l00P000?l2003o00030?l0
003oP000oh0000@0o`0000<00?l00?l0003o0000103o00030?n000H0o`000P00o`000`3oP000o`00
0?l000020?l000L0003o0P3o00020000o`80o`000`3oP0040000o`030?n000000?l0003o00H0003o
00<0oh000000o`000?l0103o00020000o`D0o`003_ooool20?l00080003o1`3oP0050?l00080003o
1`3oP002003o00<0o`001P3oP0030?l00080003o0P00o`020?n00080003o00<0oh000?l0003o0000
0P000?l20?n00080o`001@000?l@0?n00080o`000P00o`030?l000@0003o0P3oP0000`000?l0oh00
0?n0000;0?n00080o`002P3oP0020?l000H0oh0000<0003o0?n0003oP0000P3o00040?n000030000
o`3oP000oh000080003o6?ooool001Kooooo1@3o0002003o0080oh000P3o0002003o00030?l00000
o`000?l001T0o`001000o`0K0?l00003003o003o0000o`0001H0o`000P3oP0000`000?l00?l0003o
00020?l000800?l00`3o00020?n000D0o`0020000?l3003o0080o`001@3oP0040?l000kooooo0P00
o`020?l000`00?l00P3o0002003o0080o`001`00o`000`3o00000?l0003o0006003o00030?l00000
o`000?l00080oh004P00o`020?l000800?l000<0o`00003o0000o`001000o`030?l000L0003o1P00
o`030?l001l00?l00P3o0009003o00030000o`3o0000o`0000800?l03_ooool20?n000/0o`0000<0
0?l00?l0003o00000P3o0002003o00<0o`000P00o`020?l000<00?l0203o00000`000?l0oh000?n0
00060?l000030?n0003o0000o`000080o`001@00o`020?l000800?l00P000?l2003o00030?l0003o
P000oh0000@0o`0000<00?l00?l0003o0000103o00030?n000H0o`000P00o`000`3oP000o`000?l0
00020?l000L0003o0P3o00020000o`80o`000`3oP0040000o`030?n000000?l0003o00H0003o00<0
oh000000o`000?l0103o00020000o`D0o`003_ooool20?l00080003o1`3oP0050?l00080003o1`3o
P002003o00<0o`001P3oP0030?l00080003o0P00o`020?n00080003o00<0oh000?l0003o00000P00
0?l20?n00080o`001@000?l@0?n00080o`000P00o`030?l000@0003o0P3oP0000`000?l0oh000?n0
000;0?n00080o`002P3oP0020?l000H0oh0000<0003o0?n0003oP0000P3o00040?n000030000o`3o
P000oh000080003o6?ooool001Kooooo403o0002003o0100o`000P000?l50?l000@00?l00P3o0000
0`00o`00o`000?l0000G0?l000@00?l05`3o0006003o00X0o`000P000?l20?l000@0oh001@3o0005
0000o`@0o`003_ooool@003o0080o`000P00o`020?l002000?l00P3o0005003o0080o`002@00o`03
0?l000L0003o6`00o`020?l000/00?l00P3o00000`00o`00o`000?l000020?l00080003o0`00o`02
0?l000800?l03_ooool40?l00003003o003oP000oh0000/0o`000P00o`020000o`P0o`00103oP002
0?l000D0003o0P3o00040000o`<0oh000P3o0007003o0080o`000P3oP0050?l000@0oh002@3o0005
0?n00080003o0P00o`000`3oP000003o0000o`090000o`T0o`0040000?l20?l000800?l00P000?l3
0?l00080oh003_ooool20?l000<0oh000P3o00040?n00080003o00<0o`000?n0003oP0001`3oP002
0000o`800?l00`3o00060?n00080o`000`3oP0020?l00080oh000P000?l30?n000@0003o0P3oP005
0000o`D0oh000P00o`020?l000L0oh000P00o`020?l000D0oh000P000?l20?n000030000o`3oP000
oh0000@0oh000`000?l40?n00080o`001`3oP0020?l000030?n000000?l0003o0080oh000P000?l2
0?n000030000o`3oP000oh000080003o0P3oP0030000o`80oh000P000?lHooooo`005_ooool@0?l0
00800?l0403o00020000o`D0o`001000o`020?l00003003o003o0000o`0001L0o`001000o`0G0?l0
00H00?l02P3o00020000o`80o`00103oP0050?l000D0003o103o000>oooooa000?l00P3o0002003o
0080o`008000o`020?l000D00?l00P3o0009003o00<0o`001`000?lK003o0080o`002`00o`020?l0
0003003o003o0000o`000080o`000P000?l3003o0080o`000P00o`0>ooooo`@0o`0000<00?l00?n0
003oP0002`3o0002003o0080003o203o00040?n00080o`001@000?l20?l000@0003o0`3oP0020?l0
00L00?l00P3o00020?n000D0o`00103oP0090?l000D0oh000P000?l2003o00030?n000000?l0003o
00T0003o2@3o000@0000o`80o`000P00o`020000o`<0o`000P3oP00>ooooo`80o`000`3oP0020?l0
00@0oh000P000?l00`3o0000oh000?n000070?n00080003o0P00o`030?l000H0oh000P3o00030?n0
0080o`000P3oP0020000o`<0oh0010000?l20?n000D0003o1@3oP002003o0080o`001`3oP002003o
0080o`001@3oP0020000o`80oh0000<0003o0?n0003oP000103oP0030000o`@0oh000P3o00070?n0
0080o`0000<0oh000000o`000?l00P3oP0020000o`80oh0000<0003o0?n0003oP0000P000?l20?n0
00<0003o0P3oP0020000oaSooooo000Fooooo`/0o`000P3oP00<0?l00080oh000P00o`050?l00080
003o1@3o0002003o00L0o`001000o`030?l00080003o7@3o0003003o00/0o`001P00o`0<0?l00080
003o0P3o00000`00o`00o`000?l000020?l00080oh000P3o00000`000?l0o`000?l000020?l000ko
oooo0P00o`020?l000`00?l01P3o0008003o0080o`00:000o`030?l000L0003o5000o`020?l000D0
0?l00P3o000;003o00L0o`000P000?l5003o0080o`003_ooool2003o0080o`000`00o`070?l000@0
oh000P00o`020000o`030?l0003oP000oh0000@0oh001`3o00020000o`030?l000000?l0003o0080
o`001`000?l20?l000@00?l000<0o`00003o0000o`002@3o00020000o`800?l01@3o00040000o`D0
oh000P000?l3003o00@0003o0P3o00020?n000030?l0003oP000oh000080o`000P00o`020?l00003
0000o`3o0000o`000080003o0P3oP0000`3o0000oh000?n000020000o`D0oh000P000?l90?l00080
003o3_ooool20?l00080oh0000<0003o0?l0003o00001000o`020?n000030?l0003oP000oh0000H0
oh0000<0003o0?n0003oP0001000o`000`000?l0o`000?l000020?l00080oh001`00o`020?n00080
o`001@3oP0020000o`80oh0000<0003o0?n0003oP0000P000?l20?n00080003o00<0oh000?l0003o
00000P3o00020?n000030000o`3oP000oh000080oh000P000?l20?l000D0oh0010000?l30?n000L0
003o3@3oP003003o0080o`001`3oP0080000o`030?n000000?l0003o0080oh006?ooool001Kooooo
2`3o00020?n000`0o`000P3oP002003o00D0o`000P000?l50?l000800?l01`3o0004003o00<0o`00
0P000?lM0?l000<00?l02`3o0006003o00`0o`000P000?l20?l00003003o003o0000o`000080o`00
0P3oP0020?l000030000o`3o0000o`000080o`003_ooool2003o0080o`003000o`060?l000P00?l0
0P3o000X003o00<0o`001`000?lD003o0080o`001@00o`020?l000/00?l01`3o00020000o`D00?l0
0P3o000>ooooo`800?l00P3o0003003o00L0o`00103oP002003o0080003o00<0o`000?n0003oP000
103oP0070?l00080003o00<0o`000000o`000?l00P3o00070000o`80o`001000o`000`3o00000?l0
003o00090?l00080003o0P00o`050?l000@0003o1@3oP0020000o`<00?l010000?l20?l00080oh00
00<0o`000?n0003oP0000P3o0002003o0080o`0000<0003o0?l0003o00000P000?l20?n000030?l0
003oP000oh000080003o1@3oP0020000o`T0o`000P000?l>ooooo`80o`000P3oP0000`000?l0o`00
0?l00004003o0080oh0000<0o`000?n0003oP0001P3oP0000`000?l0oh000?n00004003o00030000
o`3o0000o`000080o`000P3oP007003o0080oh000P3o00050?n00080003o0P3oP0000`000?l0oh00
0?n000020000o`80oh000P000?l00`3oP000o`000?l000020?l00080oh0000<0003o0?n0003oP000
0P3oP0020000o`80o`001@3oP0040000o`<0oh001`000?l=0?n000<00?l00P3o00070?n000P0003o
00<0oh000000o`000?l00P3oP00Hooooo`005_oooolG0?l000800?l00P3oP002003o00<0003o0P3o
00020000o`<0o`001P00o`050?l000800?l01@3o00020000o`@0o`000P000?l30?l00080003o1`3o
00020000o`L0o`000P3oP00>0?l000H00?l0303o00020000o`T0o`000P3oP0000`000?l0o`000?l0
00020?l000kooooo0P00o`020?l000`00?l01P3o0008003o0080o`007`00o`030?l000H00?l00`3o
00070000o`P00?l000<0o`00003o0000o`000P000?l9003o0080o`000`00o`040?l00080003o1`00
o`070?l00080003o1@00o`020?l000kooooo1`00o`040?l00080003o00<0o`000?n0003oP0000P3o
P002003o0080003o00<0o`000000o`000?l00P3oP0050?l00080oh000P3o00020?n000030?l00000
0?l0003o0080oh001`000?l20?l000@00?l000<0o`00003o0000o`000P3o0002003o00<0o`00103o
P0020000o`D0o`002`000?l30?l00080003o0P3oP0040?l000<0oh001P3o00030000o`80oh000P3o
00050?n00080o`000`3oP0090?l00080oh000P000?l>ooooo`80o`000`3oP0040000o`80oh000P3o
00090?n000030000o`3oP000oh0000@00?l01`000?l3003o0080o`000P000?l40?n000030000o`3o
P000oh000080o`000P000?l20?l000<0oh000P000?l40?n000030000o`00o`000?l000T0003o0P3o
P0020000o`030?n0003o0000o`0000T0oh001`000?l40?l00080003o2P3oP0020?l00080oh00103o
00030?n00080o`000P000?l50?n000800?l06?ooool001Kooooo0P00o`020000oaL0o`000P00o`00
0`000?l0o`000?l000020?l00080003o1@3o0004003o00`0o`000P000?l40?l00080003o0`3o0002
0000oaT0o`001000o`030?l00080003o0P00o`030?l00080003o2@3o00020000o`T0o`000P000?l5
0?l000kooooo0P00o`020?l000L00?l00P3o0003003o00@0o`002P00o`040?l00080003o4P00o`02
0?l000<00?l00P3o0002003o00<0o`000P00o`020000o`800?l000<0o`00003o0000o`001`000?l8
003o00030?l00000o`000?l00080003o2@00o`020?l000<00?l0103o00020000o`030?l00000o`00
0?l00080o`001@00o`040?l00080003o1@00o`020?l000kooooo0P3o0009003o0080003o00<0oh00
0?l0003o00000P3oP002003o0080o`001@000?l50?l00080oh000P000?l20?n000<0003o0P3oP004
0000o`030?n000000?l0003o0080o`001`00o`020?l000800?l00P3o00070?n000030?l00000o`00
0?l00080o`002`000?l30?l00080oh00103o00020?n000D0o`000P000?l20?l000L0003o00<00?l0
0?n0003oP0000P3o0002003o00<0oh000P000?l40?n00080o`000`3oP0020000o`kooooo1@3oP002
0000o`80oh000P3o000<0?n000H00?l01`000?l2003o00<0o`00103oP0020?l000030000o`3oP000
oh0000L0oh000P3o00070000o`800?l00P3oP0090000o`80oh0000<0o`000?n0003oP000103oP002
0?l000030000o`00o`000?l000L0oh00103o000>0?n000800?l01@3o00020000o`800?l01@3o0002
0?n000800?l06?ooool001Kooooo0P00o`020000oaL0o`000P00o`000`000?l0o`000?l000020?l0
0080003o1@3o0004003o00`0o`000P000?l40?l00080003o0`3o00020000oaT0o`001000o`030?l0
0080003o0P00o`030?l00080003o2@3o00020000o`T0o`000P000?l50?l000kooooo0P00o`020?l0
00L00?l00P3o0003003o00@0o`002P00o`040?l00080003o4P00o`020?l000<00?l00P3o0002003o
00<0o`000P00o`020000o`800?l000<0o`00003o0000o`001`000?l8003o00030?l00000o`000?l0
0080003o2@00o`020?l000<00?l0103o00020000o`030?l00000o`000?l00080o`001@00o`040?l0
0080003o1@00o`020?l000kooooo0P3o0009003o0080003o00<0oh000?l0003o00000P3oP002003o
0080o`001@000?l50?l00080oh000P000?l20?n000<0003o0P3oP0040000o`030?n000000?l0003o
0080o`001`00o`020?l000800?l00P3o00070?n000030?l00000o`000?l00080o`002`000?l30?l0
0080oh00103o00020?n000D0o`000P000?l20?l000L0003o00<00?l00?n0003oP0000P3o0002003o
00<0oh000P000?l40?n00080o`000`3oP0020000o`kooooo1@3oP0020000o`80oh000P3o000<0?n0
00H00?l01`000?l2003o00<0o`00103oP0020?l000030000o`3oP000oh0000L0oh000P3o00070000
o`800?l00P3oP0090000o`80oh0000<0o`000?n0003oP000103oP0020?l000030000o`00o`000?l0
00L0oh00103o000>0?n000800?l01@3o00020000o`800?l01@3o00020?n000800?l06?ooool001Ko
oooo1000o`0C0?l000800?l00P3o0002003o00030000o`3o0000o`000080o`000P000?l20?l00003
003o003oP000oh0000@00?l02@3o0002003o02L0o`000P3oP002003o00<0o`000P3oP0050?l00080
003o0P00o`070?l00080oh002@3o00020000o`<0o`000P00o`0>ooooo`800?l00P3o0007003o0080
o`0000<00?l00?l0003o00000P3o000<003o00@0o`000P000?lG003o00T0o`000P000?l3003o0080
o`001`000?l8003o00030?l00000o`000?l00080003o2@00o`020?l000<00?l00P3o0007003o0080
o`001@00o`040?l00080003o1`00o`0>ooooo`@0o`001@00o`020?l00080oh000`3o00020?n00080
o`000P000?l30?l000@0oh001@3o00020000o`<0o`0020000?l30?n000T00?l00P3o0004003o0003
0?l0003oP000oh000080003o0P3oP0000`3o00000?l0003o0002003o00T0003o1@3o00020?n000/0
o`002`000?l00`00o`00o`000?l00007003o0080003o0P3oP0020?l000L0003o3_ooool20000o``0
oh0010000?l40?l000030?n000000?l0003o0080oh000P00o`070000o`800?l01@3o00020000o`80
o`0000<0003o0?n0003oP0000P000?l40?n000030?l000000?l0003o00@0oh000P000?l00`3oP000
0?l0003o0002003o0080003o00<0oh000000o`000?l01P3oP0000`00o`00o`000?l000070000o`80
o`001`3oP0040?l000T0oh000P3o00000`3oP000003o0000o`020000o`80oh000P3o00000`00o`00
003o0000o`04003o0080oh0000<0o`000?n0003oP0000P3o000Hooooo`005_ooool4003o01<0o`00
0P00o`020?l000800?l000<0003o0?l0003o00000P3o00020000o`80o`0000<00?l00?n0003oP000
1000o`090?l000800?l09`3o00020?n000800?l00`3o00020?n000D0o`000P000?l2003o00L0o`00
0P3oP0090?l00080003o0`3o0002003o00kooooo0P00o`020?l000L00?l00P3o00000`00o`00o`00
0?l000020?l000`00?l0103o00020000oaL00?l02@3o00020000o`<00?l00P3o00070000o`P00?l0
00<0o`00003o0000o`000P000?l9003o0080o`000`00o`020?l000L00?l00P3o0005003o00@0o`00
0P000?l7003o00kooooo103o0005003o0080o`000P3oP0030?l00080oh000P3o00020000o`<0o`00
103oP0050?l00080003o0`3o00080000o`<0oh002@00o`020?l000@00?l000<0o`000?n0003oP000
0P000?l20?n000030?l00000o`000?l000800?l02@000?l50?l00080oh002`3o000;0000o`03003o
003o0000o`0000L00?l00P000?l20?n00080o`001`000?l>ooooo`80003o303oP0040000o`@0o`00
00<0oh000000o`000?l00P3oP002003o00L0003o0P00o`050?l00080003o0P3o00000`000?l0oh00
0?n000020000o`@0oh0000<0o`000000o`000?l0103oP0020000o`030?n00000o`000?l000800?l0
0P000?l00`3oP000003o0000o`060?n00003003o003o0000o`0000L0003o0P3o00070?n000@0o`00
2@3oP0020?l000030?n000000?l0003o0080003o0P3oP0020?l00003003o00000?l0003o00@00?l0
0P3oP0000`3o0000oh000?n000020?l001Sooooo000Fooooo`@00?l01@3o0004003o00<0o`000P00
0?l70?l000@00?l00`3o0004003o0080o`0000<00?l00?l0003o00001000o`090?l000800?l000<0
oh000?l0003o00001P3o00000`00o`00o`000?l000020?l000800?l05@3o0002003o00h0o`000P3o
P0090?l00080003o2@3o00020000o`<0o`000P00o`0>ooooo`800?l00P3o0007003o0080o`000`00
o`020?l000`00?l0103o00020000o`h00?l01P3o0003003o0080003o0P3o00020000o`<0o`000P00
0?l3003o0080o`001`000?l8003o00030?l00000o`000?l00080003o3P00o`020?l000L00?l00P3o
0005003o0080o`002`00o`0>ooooo`D0o`000P00o`070?l000800?l01P3o00000`3oP000o`000?l0
00020?l00080oh001@3o00020?n000<0o`0020000?l30?n000T00?l00P3o0002003o00<0o`001000
0?l20?l000030000o`3o0000o`0000800?l02@000?l20?l00080003o00<0oh000000o`000?l00P3o
P0040?l000030000o`3o0000o`000080o`001@000?l60?n000<0o`000P3oP005003o0080o`00103o
P0070000o`kooooo0P3oP0020?l000h0oh001@3o00020?n00080003o0P3o00070000o`<0o`000P3o
P0020?l00080oh000P3o00000`000?l0oh000?n000040000o`<0o`002`3oP0020?l000<0003o103o
P0020000o`80oh000`3o00020?n000@0o`0000<0003o0?l0003o00000P3o00050?n00080003o0P3o
P0020?l00080003o0`3o00050?n00080003o0P3o00040?n000<0003o1000o`020?l000D0oh006?oo
ool001Kooooo1000o`050?l000@00?l00`3o00020000o`L0o`001000o`030?l000@00?l00P3o0000
0`00o`00o`000?l00004003o00T0o`000P00o`000`3oP000o`000?l000060?l00003003o003o0000
o`000080o`000P00o`0E0?l000800?l03P3o00020?n000T0o`000P000?l90?l00080003o0`3o0002
003o00kooooo0P00o`020?l000L00?l00P3o0003003o0080o`003000o`040?l00080003o3P00o`06
0?l000<00?l00P000?l20?l00080003o0`3o00020000o`<00?l00P3o00070000o`P00?l000<0o`00
003o0000o`000P000?l>003o0080o`001`00o`020?l000D00?l00P3o000;003o00kooooo1@3o0002
003o00L0o`000P00o`060?l000030?n0003o0000o`000080o`000P3oP0050?l00080oh000`3o0008
0000o`<0oh002@00o`020?l000800?l00`3o00040000o`80o`0000<0003o0?l0003o00000P00o`09
0000o`80o`000P000?l00`3oP000003o0000o`020?n000@0o`0000<0003o0?l0003o00000P3o0005
0000o`H0oh000`3o00020?n000D00?l00P3o00040?n000L0003o3_ooool20?n00080o`003P3oP005
0?l00080oh000P000?l20?l000L0003o0`3o00020?n00080o`000P3oP0020?l000030000o`3oP000
oh0000@0003o0`3o000;0?n00080o`000`000?l40?n00080003o0P3oP0030?l00080oh00103o0000
0`000?l0o`000?l000020?l000D0oh000P000?l20?n00080o`000P000?l30?l000D0oh000P000?l2
0?l000@0oh000`000?l4003o0080o`001@3oP00Hooooo`005_ooool4003o00`0o`000P00o`070?l0
00@00?l00`3o0007003o0080o`001P00o`070?l000800?l03P3o0003003o00/0o`000P00o`0=0?l0
00030?n00000o`000?l000@0o`000P3oP0000`3o0000oh000?n000070?l000@0003o2`3o00000`3o
P000o`000?l000020?l000kooooo0P00o`020?l000L00?l00P3o0003003o0080o`003P00o`020?l0
00h00?l0103o00020?n00080003o0`00o`020000o`80o`000`000?l20?l00080oh000`00o`020?l0
00L0003o2000o`000`3o00000?l0003o00020000oaL00?l00P3o0005003o0080o`002`00o`0>oooo
o`D0o`000P00o`0@0?l000800?l00P3oP0050?l00080003o0P00o`020000o`030?l000000?l0003o
00H0003o00<0oh000?l0003o00000P3o0002003o00<0o`001P00o`020000o`030?l0003oP000oh00
00T0o`002@000?l20?l00080003o00<0o`000?n0003oP0000P3oP0040?l000030000o`3o0000o`00
0080oh000P000?l20?n000030000o`3oP000oh000080oh001@3o00020?n00080003o0`00o`040?l0
00@0oh001@000?l>ooooo`80oh000P000?l00`3oP000o`000?l000070?n00080o`000P3oP0020000
o`<0o`0010000?l20?l000030000o`3oP000oh0000@0003o0P00o`000`3o0000003o0000o`040?n0
0080o`0000<0oh000000o`000?l00P3oP0020000o`80o`001@3oP0020?l00080oh0000<0o`000?n0
003oP0001@3oP0020000o`H0oh000`3o00020?n00080o`000P3oP0000`000?l0o`000?l000040?l0
0080003o0`00o`040?l000<0oh000P3o00050?n000@0003o103oP0030000o`@00?l00P3o00050?n0
01Sooooo000Fooooo`D00?l00P3o0004003o00h0o`000P000?l5003o0080oh000P3o0003003o00l0
o`000P00o`0@0?l00003003o003o0000o`0001@0o`000P00o`030?l000@00?l00P3o0002003o00D0
o`000P3oP0050?l00080003o0P3o00000`00o`00o`000?l000020?l000800?l01@3o00020000o`ko
oooo0P00o`020?l000L00?l00P3o000C003o0080o`003P00o`040?l00080oh000P000?l3003o0080
oh000P3o00030?n000800?l00P3oP003003o0080o`001`000?l6003o00<0o`007@00o`020?l00080
0?l00`3o0009003o0080o`003_ooool20?l00080oh0000<0o`00003o0000o`000P3o0002003o00D0
o`000P000?l40?l000030000o`00o`000?l00080003o1@3o00020000o`800?l00P000?l00`3o0000
003o0000o`060000o`D0o`001000o`000`3o00000?l0003o0004003o00<0003o0P3oP0020000o`80
o`000`00o`020?l000T0003o0P3o00020000o`h0o`0010000?l00`3o0000oh000?n000090?l00080
oh002@3o00020?n000D0003o3_ooool20000o`<00?l00P3o00070?n000800?l00P3o00020?n00080
o`0000<0oh000?l0003o00000P000?l20?l000<0003o1P3oP0000`000?l0oh000?n000020?l00080
oh000P3o00050?n00080003o0P3o00000`000?l0oh000?n000020000o`@0o`00303oP0050000o`80
o`000P3oP0040?l000030?n0003o0000o`0000@0o`000P000?l3003o0080003o1@3oP0020000o`80
oh000P00o`000`3oP000003o0000o`040?n000D0003o1000o`020000o`030?n000000?l0003o0080
oh006?ooool001Kooooo1@00o`020?l000@00?l03P3o00020000o`D00?l00P3oP0020?l000<00?l0
3`3o0002003o0100o`0000<00?l00?l0003o0000503o0002003o00<0o`001000o`020?l000800?l0
1@3o00020?n000D0o`000P000?l20?l00003003o003o0000o`000080o`000P00o`050?l00080003o
3_ooool2003o0080o`001`00o`020?l001<00?l00P3o000>003o00@0o`000P3oP0020000o`<00?l0
0P3oP0020?l000<0oh000P00o`020?n000<00?l00P3o00070000o`H00?l00`3o000M003o0080o`00
0P00o`030?l000T00?l00P3o000>ooooo`80o`000P3oP0000`3o00000?l0003o00020?l000800?l0
1@3o00020000o`@0o`0000<0003o003o0000o`000P000?l50?l00080003o0P00o`020000o`030?l0
00000?l0003o00H0003o1@3o0004003o00030?l00000o`000?l000@00?l00`000?l20?n00080003o
0P3o0003003o0080o`002@000?l20?l00080003o3P3o00040000o`030?l0003oP000oh0000T0o`00
0P3oP0090?l00080oh001@000?l>ooooo`80003o0`00o`020?l000L0oh000P00o`020?l00080oh00
0P3o00000`3oP000o`000?l000020000o`80o`000`000?l60?n000030000o`3oP000oh000080o`00
0P3oP0020?l000D0oh000P000?l20?l000030000o`3oP000oh000080003o103o000<0?n000D0003o
0P3o00020?n000@0o`0000<0oh000?l0003o0000103o00020000o`<00?l00P000?l50?n00080003o
0P3oP002003o00030?n000000?l0003o00@0oh001@000?l4003o0080003o00<0oh000000o`000?l0
0P3oP00Hooooo`005_ooool5003o00@0o`000P000?l20?l00003003o003oP000oh000080o`000P00
o`020000o`<0o`000P3oP005003o0080o`001@00o`0?0?l000800?l04@3o0002003o00H0o`0000<0
003o0?l0003o00002@3o0004003o00<0o`001000o`0D0?l00003003o003o0000o`0000T0o`000P00
0?l>ooooo`800?l00P3o0007003o0080o`004`00o`020?l000800?l00P000?l:003o0080003o103o
00020000o`<00?l00P3o0002003o0080o`0000<0oh00003o0000o`001`00o`070000o`H00?l00P3o
0003003o0080oh006@00o`020?l000800?l000<0003o003o0000o`002@00o`020?l000kooooo1000
o`000`3o00000?l0003o0002003o00L0o`000P000?l40?l000030?n00000o`000?l000L0o`001000
o`030?l000H0003o0P3oP0000`3o0000003o0000o`04003o00<0o`001P00o`070000o`L0o`000P00
0?l20?n000030000o`3oP000oh000080oh000P3o00020000o`h0o`000P000?l30?l000@0oh000P3o
00000`3oP000o`000?l000040?n000T0o`000`3oP0020000o`80oh003_ooool20000o`80oh0000<0
0?l00?n0003oP0001`3oP002003o0080o`001`3oP0020000o`800?l00`3o00040?n000<0003o0P3o
P0020?l00080oh000P00o`070000o`80o`001`3oP0020000o`D0oh000P3o000:0?n00080o`00103o
P0020?l000030?n000000?l0003o00@0o`000`3oP002003o0080003o1@3oP0070000o`80oh000P00
o`020?l00080oh000`000?l40?l00080003o1@3oP00Hooooo`005_ooool5003o00@0o`000P000?l2
0?l00003003o003oP000oh000080o`000P00o`020000o`<0o`000P3oP005003o0080o`001@00o`0?
0?l000800?l04@3o0002003o00H0o`0000<0003o0?l0003o00002@3o0004003o00<0o`001000o`0D
0?l00003003o003o0000o`0000T0o`000P000?l>ooooo`800?l00P3o0007003o0080o`004`00o`02
0?l000800?l00P000?l:003o0080003o103o00020000o`<00?l00P3o0002003o0080o`0000<0oh00
003o0000o`001`00o`070000o`H00?l00P3o0003003o0080oh006@00o`020?l000800?l000<0003o
003o0000o`002@00o`020?l000kooooo1000o`000`3o00000?l0003o0002003o00L0o`000P000?l4
0?l000030?n00000o`000?l000L0o`001000o`030?l000H0003o0P3oP0000`3o0000003o0000o`04
003o00<0o`001P00o`070000o`L0o`000P000?l20?n000030000o`3oP000oh000080oh000P3o0002
0000o`h0o`000P000?l30?l000@0oh000P3o00000`3oP000o`000?l000040?n000T0o`000`3oP002
0000o`80oh003_ooool20000o`80oh0000<00?l00?n0003oP0001`3oP002003o0080o`001`3oP002
0000o`800?l00`3o00040?n000<0003o0P3oP0020?l00080oh000P00o`070000o`80o`001`3oP002
0000o`D0oh000P3o000:0?n00080o`00103oP0020?l000030?n000000?l0003o00@0o`000`3oP002
003o0080003o1@3oP0070000o`80oh000P00o`020?l00080oh000`000?l40?l00080003o1@3oP00H
ooooo`005_ooool40?l00003003o003o0000o`000080o`000P00o`020?l00003003o003o0000o`00
0080o`001000o`030?l00080oh001`3o0002003o0080o`000`00o`090?l000800?l00P3o0002003o
00<0o`001000o`0T0?l000D00?l02`3o00000`000?l0o`000?l000020?n000L0o`000P00o`070?l0
00800?l03_ooool2003o0080o`006P00o`060?l00080003o2P00o`020000o`@0o`000P3oP009003o
00030?l00000o`000?l000L00?l01`000?l6003o00<0o`007@00o`020?l000800?l000<0003o003o
0000o`002@00o`020?l000kooooo3@00o`030?l00080oh000P3o00020000o`030?n0003o0000o`00
00D0o`001P00o`030?l000800?l00P000?l40?n000030?l000000?l0003o00@00?l00P3o0007003o
00L0003o1`3o000=0?n000030?l000000?l0003o00@0o`000P3oP0000`3o00000?l0003o00070?l0
0080oh000P000?l30?l00080003o0P00o`040?l000030000o`3o0000o`0000@0o`000`3oP0040000
o`kooooo103o00000`00o`00oh000?n000070?n000800?l00P3oP0020?l000T0oh0000<0o`000?n0
003oP000103oP0020?l000L0oh000P3o00000`000?l0oh000?n000040000o`80o`001@3oP0020?l0
0080oh0000<0003o0?n0003oP0000P000?l<0?n00080o`000P000?l20?n00080o`0000<0oh000000
o`000?l02@3oP0020000o`80oh000P000?l30?n00080003o0P00o`030?n000@00?l00P3oP0000`3o
0000003o0000o`060?n000030?l0003oP000oh000080oh006?ooool001Kooooo103o00000`00o`00
o`000?l000020?l000800?l00P3o00000`00o`00o`000?l000020?l000@00?l00`3o00020?n000L0
o`000P00o`020?l000<00?l02@3o0002003o0080o`000P00o`030?l000@00?l0903o0005003o00/0
o`0000<0003o0?l0003o00000P3oP0070?l000800?l01`3o0002003o00kooooo0P00o`020?l001X0
0?l01P3o00020000o`X00?l00P000?l40?l00080oh002@00o`000`3o00000?l0003o0007003o00L0
003o1P00o`030?l001d00?l00P3o0002003o00030000o`00o`000?l000T00?l00P3o000>ooooo`d0
0?l00`3o00020?n00080o`000P000?l00`3oP000o`000?l000050?l000H00?l00`3o0002003o0080
003o103oP0000`3o0000003o0000o`04003o0080o`001`00o`070000o`L0o`003@3oP0000`3o0000
003o0000o`040?l00080oh0000<0o`00003o0000o`001`3o00020?n00080003o0`3o00020000o`80
0?l0103o00000`000?l0o`000?l000040?l000<0oh0010000?l>ooooo`@0o`0000<00?l00?n0003o
P0001`3oP002003o0080oh000P3o00090?n000030?l0003oP000oh0000@0oh000P3o00070?n00080
o`0000<0003o0?n0003oP00010000?l20?l000D0oh000P3o00020?n000030000o`3oP000oh000080
003o303oP0020?l00080003o0P3oP0020?l000030?n000000?l0003o00T0oh000P000?l20?n00080
003o0`3oP0020000o`800?l00`3oP004003o0080oh0000<0o`000000o`000?l01P3oP0000`3o0000
oh000?n000020?n001Sooooo000Fooooo`800?l02@3o0003003o00P0o`0000<00?l00?l0003o0000
3P3o0002003o00L0o`001000o`0K0?l00080oh0000<0o`00003o0000o`007`3o00000`000?l0o`00
0?l0000B0?l00080oh003_ooool2003o0080o`004000o`020?l000P00?l00P3o00020?n00080o`00
0P000?l:003o0080003o103o00020?n000L00?l00P3o000:003o00L0003o1P00o`030?l002400?l0
00<0003o003o0000o`002`00o`0>ooooo`d00?l000<0o`00003o0000o`000P3oP0020?l00080003o
1`3o00000`00o`00o`000?l00004003o00<0o`0010000?l20?n00080003o00<0o`000000o`000?l0
2@00o`020?l000800?l01`000?l50?l00080003o1@3o00020000o`@0oh000P000?l00`3oP000003o
0000o`020000o`80oh000P000?l00`3o00000?l0003o0004003o00<0o`00103oP0030?l000@00?l0
103o00030?n000@0o`000`3oP0040000o`kooooo103o00000`00o`00oh000?n000020000o`D0oh00
0P000?l20?n00080003o0P3oP0000`000?l0oh000?n000020?n000<0o`0010000?l20?l00080003o
3P3oP0020000o`80oh0000<0o`000?n0003oP000103oP0020000o`<0o`002`3oP0020?l000030?n0
003o0000o`000080o`000P3oP0020?l00003003o003o0000o`0000@0oh000P000?l:0?n000H0003o
00<0oh000?l0003o00001P00o`000`3o0000oh000?n000040?n00080o`001@3oP00Hooooo`005_oo
ool2003o00T0o`000`00o`080?l00003003o003o0000o`0000h0o`000P00o`070?l000@00?l06`3o
00020?n000030?l00000o`000?l001l0o`0000<0003o0?l0003o00004P3o00020?n000kooooo0P00
o`020?l001000?l00P3o0008003o0080o`000P3oP0020?l00080003o2P00o`020000o`@0o`000P3o
P007003o0080o`002P00o`070000o`H00?l00`3o000Q003o00030000o`00o`000?l000/00?l03_oo
ool=003o00030?l00000o`000?l00080oh000P3o00020000o`L0o`0000<00?l00?l0003o00001000
o`030?l000@0003o0P3oP0020000o`030?l000000?l0003o00T00?l00P3o0002003o00L0003o1@3o
00020000o`D0o`000P000?l40?n00080003o00<0oh000000o`000?l00P000?l20?n00080003o00<0
o`00003o0000o`001000o`030?l000@0oh000`3o0004003o00@0o`000`3oP0040?l000<0oh001000
0?l>ooooo`@0o`0000<00?l00?n0003oP0000P000?l50?n00080003o0P3oP0020000o`80oh0000<0
003o0?n0003oP0000P3oP0030?l000@0003o0P3o00020000o`h0oh000P000?l20?n000030?l0003o
P000oh0000@0oh000P000?l30?l000/0oh000P3o00000`3oP000o`000?l000020?l00080oh000P3o
00000`00o`00o`000?l000040?n00080003o2P3oP0060000o`030?n0003o0000o`0000H00?l000<0
o`000?n0003oP000103oP0020?l000D0oh006?ooool001Kooooo1000o`070?l000<00?l00P3o0004
003o00h0o`000P00o`020?n000D0o`000P00o`020?l000T00?l0803o00020?n002L0o`000P000?l3
0?l00080003o0P3o000>ooooo`/00?l00P3o000@003o00L0o`000P000?l<003o00@0o`002@00o`02
0?l000X00?l0103o00030?n000H00?l00P3o0009003o00030?l00000o`000?l000@00?l00P3o000:
003o0080o`000P00o`090?l000L00?l03_ooool20000o`L00?l00P3o0002003o00030?l00000o`00
0?l000@0o`000`00o`020?l00080003o0P3o0007003o00<0o`0010000?l20?n00080003o00<0o`00
0000o`000?l01P00o`000`3o00000?l0003o00020?l000800?l01`000?l30?l00080oh001P3o0000
0`3oP000003o0000o`0?0000o`D00?l02`3o0005003o0080o`000P000?l00`3o0000oh000?n00002
0?n000@0003o00<0oh000000o`000?l00P000?l>ooooo`@0o`0000<00?l00?n0003oP0001`3oP002
0000o`800?l00P000?l20?n000030000o`3oP000oh0000L0o`000P000?l20?l000L0003o1@3oP002
0?l00080oh000P000?l2003o00D0oh000P000?l20?l000030?n0003o0000o`0000/0oh000P3o0007
0?n000D0o`00103oP0020000o`030?n000000?l0003o00L0oh000P000?l20?l000D0oh000P00o`02
0?l000800?l03P3oP00Hooooo`005_ooool20?l000800?l000<0o`00003o0000o`000P00o`020?l0
00800?l00`3o0004003o00X0o`000P3oP0070?l000@00?l0103o00000`00o`00o`000?l00006003o
00X0o`000P00o`0>0?l00080oh001P3o00000`3oP000o`000?l000070?l00080oh005P3o00000`00
0?l0o`000?l000070?l000800?l00P3o000>oooooah00?l01P3o000>003o00@0o`005@00o`040?l0
00800?l000<0oh00003o0000o`003`00o`000`3o00000?l0003o0004003o0080o`002P00o`0=0?l0
00L00?l03_ooool20?l000D00?l01`3o0002003o0080o`001@00o`070?l000H00?l00P3o00000`3o
P000003o0000o`060000o`030?l000000?l0003o00H00?l01@3o0002003o00<0003o0P3o00020000
o`80o`000`3oP0040?l00080003o0`3oP0090000o`H0oh001@00o`050?l00080oh00103o00000`00
o`00oh000?n00002003o0080o`001@000?l20?n000@0003o00<0o`000000o`000?l00P000?l>oooo
o`80oh000P000?l3003o00H0o`0000<0oh000000o`000?l00P3o00020000o`L0oh000P00o`000`3o
0000oh000?n000020?n00080o`001`000?l50?n000@00?l00P3oP003003o0080o`000P3oP0020000
o`<0o`002@3oP0020?l00080oh000P3o00070?n00080003o00<0o`000?n0003oP0000P3oP0020?l0
00D0003o0P3oP0040?l000030?n0003o0000o`000080003o0`3oP0020000o`80oh00103o00090?n0
00030?l0003oP000oh000080oh006?ooool001Kooooo0P3o0002003o00030?l00000o`000?l00080
0?l00P3o0002003o00<0o`001000o`0:0?l00080oh001`3o0004003o00@0o`0000<00?l00?l0003o
00001P00o`0:0?l000800?l03P3o00020?n000H0o`0000<0oh000?l0003o00001`3o00020?n001H0
o`0000<0003o0?l0003o00001`3o0002003o0080o`003_oooolN003o00H0o`003P00o`040?l001D0
0?l0103o0002003o00030?n00000o`000?l000l00?l000<0o`00003o0000o`001000o`020?l000X0
0?l03@3o0007003o00kooooo0P3o0005003o00L0o`000P00o`020?l000D00?l01`3o0006003o0080
o`0000<0oh000000o`000?l01P000?l00`3o0000003o0000o`06003o00D0o`000P00o`030000o`80
o`000P000?l20?l000<0oh00103o00020000o`<0oh002@000?l60?n000D00?l01@3o00020?n000@0
o`0000<00?l00?n0003oP0000P00o`020?l000D0003o0P3oP0040000o`030?l000000?l0003o0080
003o3_ooool20?n00080003o0`00o`060?l000030?n000000?l0003o0080o`000P000?l70?n00080
0?l000<0o`000?n0003oP0000P3oP0020?l000L0003o1@3oP004003o0080oh000`00o`020?l00080
oh000P000?l30?l000T0oh000P3o00020?n00080o`001`3oP0020000o`030?l0003oP000oh000080
oh000P3o00050000o`80oh00103o00000`3oP000o`000?l000020000o`<0oh000P000?l20?n000@0
o`002@3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`T00?l00P3o0002003o00<0o`00
1000o`090?l00003003o003o0000o`0000T0o`001000o`050?l000800?l03@3o00000`3oP0000?l0
003o000;0?l00080003o803o00020?n000030?l000000?l0003o0080003o103o00000`000?l0o`00
0?l000060?l000030000o`00o`000?l00080o`003_oooolG003o0080o`000P00o`020000o`03003o
003o0000o`0000@0o`003P00o`040?l000T00?l00P3o000:003o00@0o`000P00o`030?l000800?l0
0P000?l;003o00030?l00000o`000?l000@00?l00P3o000:003o00d0o`001`00o`0>ooooo`80003o
1@00o`070?l000/00?l01`3o0004003o0080003o00<0o`000000o`000?l00P3oP0020000o`80oh00
0`000?l7003o00@0o`000P00o`050?l00080003o0P3o00000`00o`00o`000?l000040?l000`0003o
103o00040?n000D00?l00P3o00020000o`030?l000000?l0003o00@0o`000`00o`040?l00080oh00
0`000?l20?n00080003o1@3oP0020000o`kooooo0P3oP0020?l000<00?l00P3o0002003o0080003o
00<0o`000000o`000?l00P3o00040?n000030000o`3oP000oh000080003o0P00o`030?l00080oh00
1@000?l;0?n000H00?l000<0003o0?l0003o00000P000?l20?n00080003o1@3oP0030000o`800?l0
0P000?l40?n000030000o`3oP000oh000080o`000P3oP0030?l00080oh000P000?l2003o0080oh00
00<0003o0?n0003oP0000P000?l20?l000X0oh000P000?l40?l00080003o0`3oP0020000o`800?l0
1`000?lHooooo`005_ooool9003o0080o`000P00o`030?l000@00?l02@3o00000`00o`00o`000?l0
00090?l000@00?l01@3o0002003o00d0o`0000<0oh00003o0000o`002`3o00020000ob00o`000P3o
P0000`3o0000003o0000o`020000o`@0o`0000<0003o0?l0003o00001P3o00000`000?l00?l0003o
00020?l000kooooo5`00o`020?l000800?l00P000?l00`00o`00o`000?l000040?l000h00?l0103o
0009003o0080o`002P00o`040?l000800?l00`3o0002003o0080003o2`00o`000`3o00000?l0003o
0004003o0080o`002P00o`0=0?l000L00?l03_ooool20000o`D00?l01`3o000;003o00L0o`001000
o`020000o`030?l000000?l0003o0080oh000P000?l20?n000<0003o1`00o`040?l000800?l01@3o
00020000o`80o`0000<00?l00?l0003o0000103o000<0000o`@0o`00103oP005003o0080o`000P00
0?l00`3o0000003o0000o`040?l000<00?l0103o00020?n000<0003o0P3oP0020000o`D0oh000P00
0?l>ooooo`80oh000P3o0003003o0080o`000P00o`020000o`030?l000000?l0003o0080o`00103o
P0000`000?l0oh000?n000020000o`800?l00`3o00020?n000D0003o2`3oP006003o00030000o`3o
0000o`000080003o0P3oP0020000o`D0oh000`000?l2003o0080003o103oP0000`000?l0oh000?n0
00020?l00080oh000`3o00020?n00080003o0P00o`020?n000030000o`3oP000oh000080003o0P3o
000:0?n00080003o103o00020000o`<0oh000P000?l2003o00L0003o6?ooool001Kooooo0P3o0007
003o00D0o`000P00o`040?l000<00?l02`3o00020?n000h0o`000P00o`020?n000`0o`000P00o`04
0?l000030000o`3o0000o`0000@0o`000P000?l30?l00080oh001`3o0002003o00D0o`000P3oP006
0?l00003003o003o0000o`0000800?l02`3o00000`3oP000o`000?l000060?l000030?n00000o`00
0?l00080o`003_ooool4003o00030?l00000o`000?l001000?l00P3o0002003o0080003o00<00?l0
0?l0003o0000103o000>003o0080o`002@00o`040?l000D00?l02@3o0003003o0080o`000P00o`02
0000o`T00?l00`3o000F003o00/0o`0000<0oh000?l0003o00000P00o`0>ooooo`80o`001@00o`04
0?l00080003o00<0o`00003o0000o`001000o`020?l000D00?l00P000?l30?l00080003o0P3o0002
003o00<0o`00103oP0050000o`L00?l02`3o00020?n000D00?l00P3o0002003o00L0003o0P3o0002
0?n000030000o`3o0000o`000080o`000P000?l20?n000030?l00000o`000?l000@0o`000P000?l0
0`3oP000003o0000o`020?n000<0o`000P00o`040?l000T0003o0`3oP0040000o`kooooo103oP000
0`00o`00o`000?l000020?n00080o`000P000?l00`3o0000oh000?n000070?n000800?l00P000?l2
003o00<0o`000P3oP0020000o`L0oh00103o00000`3oP000o`000?l000020?l000800?l01@3o0002
0000o`80oh000P000?l70?n000030000o`3o0000o`0000H0oh0000<0o`000?n0003oP0002@3oP004
003o0080o`0000<0003o0?n0003oP0000P3o00020000o`80o`0000<0003o0?n0003oP0002`3oP002
0000o`030?n000000?l0003o0080003o103o00050000oaSooooo000Fooooo`80o`001`00o`050?l0
00800?l0103o0003003o00/0o`000P3oP00>0?l000800?l00P3oP00<0?l000800?l0103o00000`00
0?l0o`000?l000040?l00080003o0`3o00020?n000L0o`000P00o`050?l00080oh001P3o00000`00
o`00o`000?l00002003o00/0o`0000<0oh000?l0003o00001P3o00000`3oP0000?l0003o00020?l0
00kooooo1000o`000`3o00000?l0003o000@003o0080o`000P00o`020000o`03003o003o0000o`00
00@0o`003P00o`020?l000T00?l0103o0005003o00T0o`000`00o`020?l000800?l00P000?l9003o
00<0o`005P00o`0;0?l000030?n0003o0000o`0000800?l03_ooool20?l000D00?l0103o00020000
o`030?l00000o`000?l000@00?l00P3o0005003o0080003o0`3o00020000o`80o`000P00o`030?l0
00@0oh001@000?l7003o00/0o`000P3oP005003o0080o`000P00o`070000o`80o`000P3oP0000`00
0?l0o`000?l000020?l00080003o0P3oP0000`3o00000?l0003o00040?l00080003o00<0oh000000
o`000?l00P3oP0030?l000800?l0103o00090000o`<0oh0010000?l>ooooo`@0oh0000<00?l00?l0
003o00000P3oP0020?l00080003o00<0o`000?n0003oP0001`3oP002003o0080003o0P00o`030?l0
0080oh000P000?l70?n000@0o`0000<0oh000?l0003o00000P3o0002003o00D0o`000P000?l20?n0
0080003o1`3oP0000`000?l0o`000?l000060?n000030?l0003oP000oh0000T0oh001000o`020?l0
00030000o`3oP000oh000080o`000P000?l20?l000030000o`3oP000oh0000/0oh000P000?l00`3o
P000003o0000o`020000o`@0o`001@000?lHooooo`005_ooool50?l000H00?l02@3o0005003o0080
o`000P00o`050?l00080003o3P3o0002003o00T0o`000P00o`090?l000030000o`3o0000o`000180
o`001000o`0;0?l00003003o003o0000o`0000D0o`000P3oP00D0?l000kooooo1000o`000`3o0000
0?l0003o000D003o0080003o00<00?l00?l0003o0000103o000>003o0080o`002@00o`050?l000@0
0?l02@3o0003003o0080o`000P00o`020000o`D00?l00P3o0002003o0080o`005`00o`020?l000D0
0?l02@3o000>ooooo`80003o0P3o0003003o00T0o`001000o`020?l000D00?l00`000?l20?l00080
003o0P3o0002003o00030000o`00o`000?l00080003o0P3o00050000o`L00?l0203o00000`3oP000
o`000?l000020000o`800?l01`3o00070000o`80o`000`3oP0040?l00080003o0P00o`000`3o0000
0?l0003o00040?l000T0003o1`3o00070000o`80oh000`3o00040000o`kooooo0P00o`020?l000<0
oh00103o00020?n000030?l0003oP000oh0000H0003o0`3oP0020000o`800?l000<0oh000?l0003o
00000P000?l2003o00<0oh000P3o00060?n000D0o`0010000?l00`3o0000oh000?n000060?n00003
0000o`3oP000oh0000d0oh0000<0003o0?n0003oP000103oP0020?l000D0oh000P00o`020000o`<0
oh000P3o00050000o`80oh000P3o00020?n000030?l0003oP000oh0000H0oh001@000?l20?n000<0
o`00103oP00Hooooo`005_ooool50?l000H00?l02@3o0005003o0080o`000P00o`050?l00080003o
3P3o0002003o00T0o`000P00o`090?l000030000o`3o0000o`000180o`001000o`0;0?l00003003o
003o0000o`0000D0o`000P3oP00D0?l000kooooo1000o`000`3o00000?l0003o000D003o0080003o
00<00?l00?l0003o0000103o000>003o0080o`002@00o`050?l000@00?l02@3o0003003o0080o`00
0P00o`020000o`D00?l00P3o0002003o0080o`005`00o`020?l000D00?l02@3o000>ooooo`80003o
0P3o0003003o00T0o`001000o`020?l000D00?l00`000?l20?l00080003o0P3o0002003o00030000
o`00o`000?l00080003o0P3o00050000o`L00?l0203o00000`3oP000o`000?l000020000o`800?l0
1`3o00070000o`80o`000`3oP0040?l00080003o0P00o`000`3o00000?l0003o00040?l000T0003o
1`3o00070000o`80oh000`3o00040000o`kooooo0P00o`020?l000<0oh00103o00020?n000030?l0
003oP000oh0000H0003o0`3oP0020000o`800?l000<0oh000?l0003o00000P000?l2003o00<0oh00
0P3o00060?n000D0o`0010000?l00`3o0000oh000?n000060?n000030000o`3oP000oh0000d0oh00
00<0003o0?n0003oP000103oP0020?l000D0oh000P00o`020000o`<0oh000P3o00050000o`80oh00
0P3o00020?n000030?l0003oP000oh0000H0oh001@000?l20?n000<0o`00103oP00Hooooo`005_oo
ool2003o00<0o`001P00o`050?l00080003o103o00000`000?l00?l0003o00090?l00080003o0`3o
00020?n001@0o`000P00o`020000o`L0o`0000<0003o0?l0003o00002`3o0005003o0080o`001P00
o`0:0?l000@00?l01`3o0002003o00D0o`000P3oP0050?l00080oh000P3o000>ooooo`80o`000P00
o`000`3o00000?l0003o000G003o00H0o`006@00o`0<0?l00080003o103o0003003o0080o`002@00
o`020?l000800?l01@3o00020000o`@00?l000<0o`00003o0000o`002`00o`020?l000D00?l00P3o
0002003o00D0o`003_ooool20000o`<0o`000P00o`090?l000@00?l00P3o0005003o00L0003o0P3o
0002003o00030000o`00o`000?l000@0o`000P000?l00`3oP000003o0000o`04003o00L0o`000P00
o`050?l00080003o0P00o`050?l00080oh000P000?l00`3oP000003o0000o`020?n000@00?l000<0
003o0?l0003o00001P00o`030?l00080003o0P3o00090000o`<0o`000P000?l20?l000<0003o0P3o
P0020000o`D0o`0010000?l>ooooo`80o`001`3oP0020?l00080oh0000<0o`000?n0003oP0001`00
0?l20?n000@00?l00`3o00020000o`D0o`00203oP0030?l000L0oh000P3o00060?n000D0o`000P00
0?l00`3o0000oh000?n000060?n000030000o`3oP000oh000080003o103oP0000`3o0000oh000?n0
00020?n000@00?l00`3oP0020?l000D0oh000P000?l40?n000030?l0003oP000oh0000/0oh000P3o
00020000o`<0o`000P3oP00Hooooo`005_ooool50?l000H00?l01@3o00020000o`@0o`0000<0oh00
003o0000o`002@3o00020000oa/0o`000P00o`0G0?l000<00?l00P3o0006003o00030?l00000o`00
0?l000800?l0103o00000`000?l00?l0003o0002003o00L0o`000P00o`030?l00080oh001`3o0002
003o0080o`003_ooool50?l001T00?l01P3o000I003o0080003o1@3o00020000o`<0o`000P000?l4
0?l000h00?l00P3o0002003o0080003o0`3o00020000oa000?l00P3o0007003o0080o`000P00o`00
0`000?l0o`000?l000020?l000kooooo0P000?l90?l00080003o0`3o000;003o00L0003o0P3o0002
003o00<0o`000P000?l40?n000D0003o0P00o`030?l000H00?l00P3o00000`3oP000o`000?l00002
0000o`800?l00`3o00020?n00080003o0P3oP0030000o`@0o`000P00o`000`000?l0o`000?l00006
003o00<0o`000P000?l20?l000L0003o0P3oP0070?l000<0003o0P3o00040000o`80oh0000<0o`00
0000o`000?l00P000?l>ooooo`80o`001@3oP0020?l000L0oh000P000?l20?n000D0003o0P00o`02
0?l000L0oh000P000?l00`3o0000oh000?n000020?n00080o`000`3oP0020000o`80oh000P000?l3
0?n00080o`001P3oP0050?l00080003o4P3oP0030?l00080oh001000o`0<0?n00080003o2`3oP000
0`3o0000003o0000o`020?n00080003o1`3oP00Hooooo`005_ooool50?l000H00?l01@3o00020000
o`@0o`0000<0oh00003o0000o`002@3o00020000oa/0o`000P00o`0G0?l000<00?l00P3o0006003o
00030?l00000o`000?l000800?l0103o00000`000?l00?l0003o0002003o00L0o`000P00o`030?l0
0080oh001`3o0002003o0080o`003_ooool50?l001T00?l01P3o000I003o0080003o1@3o00020000
o`<0o`000P000?l40?l000h00?l00P3o0002003o0080003o0`3o00020000oa000?l00P3o0007003o
0080o`000P00o`000`000?l0o`000?l000020?l000kooooo0P000?l90?l00080003o0`3o000;003o
00L0003o0P3o0002003o00<0o`000P000?l40?n000D0003o0P00o`030?l000H00?l00P3o00000`3o
P000o`000?l000020000o`800?l00`3o00020?n00080003o0P3oP0030000o`@0o`000P00o`000`00
0?l0o`000?l00006003o00<0o`000P000?l20?l000L0003o0P3oP0070?l000<0003o0P3o00040000
o`80oh0000<0o`000000o`000?l00P000?l>ooooo`80o`001@3oP0020?l000L0oh000P000?l20?n0
00D0003o0P00o`020?l000L0oh000P000?l00`3o0000oh000?n000020?n00080o`000`3oP0020000
o`80oh000P000?l30?n00080o`001P3oP0050?l00080003o4P3oP0030?l00080oh001000o`0<0?n0
0080003o2`3oP0000`3o0000003o0000o`020?n00080003o1`3oP00Hooooo`005_ooool2003o00<0
o`001P00o`030?l00080003o1P3o00000`00o`00o`000?l000090?l00080003o2`3o00030?n001T0
o`000P3oP0050?l00080003o103o0003003o00T0o`000P00o`070?l000800?l0503o00020000o`03
0?l00000o`000?l00080o`003_ooool50?l001T00?l00P3o000@003o0080o`002`00o`020000o`D0
o`0010000?l50?l001000?l00P3o0002003o0080003o1@3o000@003o0080o`001`00o`020?l00080
0?l000<0003o0?l0003o00000P3o000>ooooo`80oh002@3o00020000o`T0o`0000<00?l00?l0003o
00000P3o00020000o`<0o`000P000?l40?l000030?n0003o0000o`000080o`000P000?l20?n000<0
003o103o0002003o00030?l00000o`000?l000@00?l01`3o00020?n000<0o`000P3oP0040000o`<0
oh000P000?l20?l00080003o00<00?l00?l0003o00001P00o`070?l000T0003o1`3o00020000o`<0
0?l010000?l30?n000@0003o3_ooool@0?n000L0003o0P00o`020?n00080o`0000<0003o0?n0003o
P000103oP0030000o`P0oh0000<0o`000000o`000?l0403oP0020000o`@0o`001@3oP0050000o`80
oh00103o00020?n000030?l0003oP000oh000080oh00103o00070?n000<0003o0P3oP002003o00L0
oh000P3o00030?n00080003o0P3oP0020000o`80oh0000<0003o0?n0003oP0000P3oP00Hooooo`00
5_ooool2003o00<0o`001P00o`030?l00080003o1P3o00000`00o`00o`000?l000090?l00080003o
2`3o00030?n001T0o`000P3oP0050?l00080003o103o0003003o00T0o`000P00o`070?l000800?l0
503o00020000o`030?l00000o`000?l00080o`003_ooool50?l001T00?l00P3o000@003o0080o`00
2`00o`020000o`D0o`0010000?l50?l001000?l00P3o0002003o0080003o1@3o000@003o0080o`00
1`00o`020?l000800?l000<0003o0?l0003o00000P3o000>ooooo`80oh002@3o00020000o`T0o`00
00<00?l00?l0003o00000P3o00020000o`<0o`000P000?l40?l000030?n0003o0000o`000080o`00
0P000?l20?n000<0003o103o0002003o00030?l00000o`000?l000@00?l01`3o00020?n000<0o`00
0P3oP0040000o`<0oh000P000?l20?l00080003o00<00?l00?l0003o00001P00o`070?l000T0003o
1`3o00020000o`<00?l010000?l30?n000@0003o3_ooool@0?n000L0003o0P00o`020?n00080o`00
00<0003o0?n0003oP000103oP0030000o`P0oh0000<0o`000000o`000?l0403oP0020000o`@0o`00
1@3oP0050000o`80oh00103o00020?n000030?l0003oP000oh000080oh00103o00070?n000<0003o
0P3oP002003o00L0oh000P3o00030?n00080003o0P3oP0020000o`80oh0000<0003o0?n0003oP000
0P3oP00Hooooo`005_ooool4003o00030?l00000o`000?l000@00?l00`3o00020000oad0o`000P00
o`0G0?l00080003o1@3o00020?n000D0o`000P00o`020?l000<00?l0103o0005003o00P0o`001@00
o`0B0?l00080003o1@3o000>ooooo`D0o`00:`00o`020?l000/00?l00P000?l30?l00080oh001000
0?l00`3o0000oh000?n000020?l00080003o3P00o`020?l000D00?l00P3o000B003o0080o`003000
o`040?l000kooooo803o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000o`<0o`000P00
0?l40?l000D00?l02`3o00020?n000<0o`000P3oP0020000o`80oh001@000?l20?l00080003o00<0
o`00003o0000o`002@00o`040?l000D0003o103oP0000`3o00000?l0003o00040?l00080003o0`00
o`060000o`030?n000000?l0003o0080003o3_ooool50?n000800?l00P000?l50?n000T0003o1P00
o`0:0000oad0oh0010000?l<0?n000800?l00P3o000<0?n00080o`00103oP0050000o`800?l00P3o
P0000`3o0000oh000?n000040?l000<0oh000P000?l20?n00080o`000P3oP0000`000?l0oh000?n0
00020?n001Sooooo000Fooooo`@00?l000<0o`00003o0000o`001000o`030?l00080003o7@3o0002
003o01L0o`000P000?l50?l00080oh001@3o0002003o0080o`000`00o`040?l000D00?l0203o0005
003o0180o`000P000?l50?l000kooooo1@3o000[003o0080o`002`00o`020000o`<0o`000P3oP004
0000o`030?l0003oP000oh000080o`000P000?l>003o0080o`001@00o`020?l001800?l00P3o000<
003o00@0o`003_oooolP0?l00080003o103o00000`000?l0o`000?l000020?l00080003o0`3o0002
0000o`@0o`001@00o`0;0?l00080oh000`3o00020?n00080003o0P3oP0050000o`80o`000P000?l0
0`3o00000?l0003o0009003o00@0o`001@000?l40?n000030?l00000o`000?l000@0o`000P000?l3
003o00H0003o00<0oh000000o`000?l00P000?l>ooooo`D0oh000P00o`020000o`D0oh002@000?l6
003o00X0003o7@3oP0040000o``0oh000P00o`020?l000`0oh000P3o00040?n000D0003o0P00o`02
0?n000030?l0003oP000oh0000@0o`000`3oP0020000o`80oh000P3o00020?n000030000o`3oP000
oh000080oh006?ooool001Kooooo0P00o`020?l000L00?l00`3o00020000o`@00?l00P3o00000`3o
P000o`000?l0000D0?l000<00?l03@3o00020000o`L0o`000P000?l50?l00080003o0P3o0005003o
00T0o`001000o`0J0?l00080003o103o00020?n000030?l00000o`000?l000800?l03_ooool50?l0
00T00?l00P3o000P003o0080o`002`00o`050?l000H0003o1@3o0009003o0080o`000`00o`040?l0
00D00?l00P3o000B003o0080o`003000o`040?l000kooooo0P000?l30?l000800?l0103o00020000
o`03003o003o0000o`000100o`0010000?l20?l000030000o`3oP000oh000080o`000P3oP0030?l0
00@00?l0103o0003003o0080o`000P00o`020?l00003003o00000?l0003o00@0o`0000<0oh000?l0
003o00000P3oP0020000o`80oh0000<0o`000000o`000?l010000?l20?n000030?l00000o`000?l0
0080003o2@00o`020?l000D0003o103oP0000`3o00000?l0003o00040?l00080oh000`00o`0;0000
o`kooooo0P3o00030?n000800?l01`3oP0020?l000L0003o0P3oP004003o00T0003o0`3o00090?n0
0080003o0P00o`020?n000<00?l0103o00050?n00080003o2`3oP0000`3o0000oh000?n00002003o
0080o`00303oP0040000o`@0oh000`000?l2003o0080o`000`3oP002003o00D0o`003@3oP00Hoooo
o`005_ooool;003o00D0o`001000o`020?l000<00?l01`3o0006003o00X0o`000P00o`040?l000<0
0?l03@3o00020000o`T0o`0000<0oh00003o0000o`000P00o`020?l000800?l000<0oh000?l0003o
0000103o0002003o00L0o`000P00o`080?l00080oh001000o`090?l000<00?l00P3o0002003o00ko
oooo1@3o0009003o0080o`002@00o`020?l000L00?l00P3o000I003o00@0o`0000<00?l00000o`00
0?l00P3o00020000o`D0o`000P3oP007003o0080o`000P00o`000`000?l0o`000?l00007003o0080
o`008000o`040?l000kooooo0P000?l3003o00H0o`000P000?l00`00o`00o`000?l0000;0?l00080
oh000`3o00040000o`80oh0000<0003o0?n0003oP0000P3o00020?n00080o`0000<0003o003o0000
o`000P00o`040?l000<00?l01P3o0003003o00@0o`0000<0003o0?l0003o00000P3oP0020000o`<0
o`001P000?l20?n000030?l00000o`000?l00080003o2@00o`020?l000D0003o103oP0000`3o0000
0?l0003o00040?l00080oh000`00o`020000o`80o`000P000?l00`3oP000003o0000o`020000o`ko
oooo103oP003003o0080003o0P3o00090?n00080o`000`3oP004003o00030000o`3oP000oh000080
oh0010000?l00`3o0000oh000?n000060?n000<0o`000P3oP004003o00030000o`3o0000o`0000H0
o`001@3oP0020?l000T0oh0000<0o`000?n0003oP0000P00o`020000o``0oh000P000?l90?n000@0
0?l000<0o`000?n0003oP0000P00o`070?l000/0oh006?ooool001Kooooo2`00o`050?l000@00?l0
0P3o0003003o00L0o`001P00o`0:0?l000800?l0103o0003003o00d0o`000P000?l90?l000030?n0
0000o`000?l000800?l00P3o0002003o00030?n0003o0000o`0000@0o`000P00o`070?l000800?l0
203o00020?n000@00?l02@3o0003003o0080o`000P00o`0>ooooo`D0o`002@00o`020?l000T00?l0
0P3o0007003o0080o`006@00o`040?l00003003o00000?l0003o0080o`000P000?l50?l00080oh00
1`00o`020?l000800?l000<0003o0?l0003o00001`00o`020?l002000?l0103o000>ooooo`80003o
0`00o`060?l00080003o00<00?l00?l0003o00002`3o00020?n000<0o`0010000?l20?n000030000
o`3oP000oh000080o`000P3oP0020?l000030000o`00o`000?l000800?l0103o0003003o00H0o`00
0`00o`040?l000030000o`3o0000o`000080oh000P000?l30?l000H0003o0P3oP0000`3o00000?l0
003o00020000o`T00?l00P3o00050000o`@0oh0000<0o`00003o0000o`00103o00020?n000<00?l0
0P000?l20?l00080003o00<0oh000000o`000?l00P000?l>ooooo`@0oh000`00o`020000o`80o`00
2@3oP0020?l000<0oh001000o`000`000?l0oh000?n000020?n000@0003o00<0o`000?n0003oP000
1P3oP0030?l00080oh001000o`000`000?l0o`000?l000060?l000D0oh000P3o00090?n000030?l0
003oP000oh0000800?l00P000?l<0?n00080003o2@3oP004003o00030?l0003oP000oh0000800?l0
1`3o000;0?n001Sooooo000Fooooo`/00?l02@3o0005003o00D0o`00103oP002003o00T0o`000P00
0?l>0?l00080003o4`3o0004003o0080o`000P00o`000`3o00000?l0003o00040?l000800?l000<0
003o0?l0003o00001P3o00000`3oP000o`000?l000050?l000800?l02`3o0005003o0080o`000P00
o`0>ooooo`80o`003000o`020?l000T00?l00P3o00020000o`D00?l00P3o000<003o0080o`002`00
o`020?l000<00?l01P3o00000`3oP000o`000?l000040?l00080003o00<00?l00?l0003o00000P00
o`070?l000L00?l00P3o000P003o00@0o`003_ooool20000o`<00?l01P3o00020000o`03003o003o
0000o`0000@0o`000P00o`050?l00080003o0`3o00060000o`030?n000000?l0003o00H0oh0000<0
003o003o0000o`000P00o`0;0?l000D00?l0103o00000`000?l0o`000?l000070?n000P0003o2@00
o`000`3o0000003o0000o`040?l000D0003o103oP0000`3o00000?l0003o00060?l000D00?l0103o
00000`3oP000003o0000o`020000o`kooooo1`00o`020000o`800?l00P3o00030000o`80oh001000
0?l70?n000030000o`3oP000oh000080o`000P3oP002003o00D0o`002@3oP0040?l000030?n0003o
0000o`000080oh00103o00050?n00080o`002@3oP0030?l000@00?l01@3o0004003o0080oh0000<0
o`000?n0003oP0000P3o00050?n000@00?l00P3o0003003o00@0o`000P3oP0000`000?l0o`000?l0
0002003o00L0oh000P000?lHooooo`005_ooool;003o00T0o`001@00o`050?l000@0oh000P00o`09
0?l00080003o3P3o00020000oa<0o`001000o`020?l000800?l000<0o`00003o0000o`00103o0002
003o00030000o`3o0000o`0000H0o`0000<0oh000?l0003o00001@3o0002003o00/0o`001@00o`02
0?l000800?l03_ooool20?l000`00?l00P3o0009003o0080o`000P000?l5003o0080o`003000o`02
0?l000/00?l00P3o0003003o00H0o`0000<0oh000?l0003o0000103o00020000o`03003o003o0000
o`0000800?l01`3o0007003o0080o`008000o`040?l000kooooo0P000?l3003o00H0o`000P000?l0
0`00o`00o`000?l000040?l000800?l01@3o00020000o`<0o`001P000?l00`3oP000003o0000o`06
0?n000030000o`00o`000?l000800?l02`3o0005003o00@0o`0000<0003o0?l0003o00001`3oP008
0000o`T00?l000<0o`000000o`000?l0103o00050000o`@0oh0000<0o`00003o0000o`001P3o0005
003o00@0o`0000<0oh000000o`000?l00P000?l>ooooo`L00?l00P000?l2003o0080o`000`000?l2
0?n000@0003o1`3oP0000`000?l0oh000?n000020?l00080oh000P00o`050?l000T0oh00103o0000
0`3oP000o`000?l000020?n000@0o`001@3oP0020?l000T0oh000`3o0004003o00D0o`001000o`02
0?n000030?l0003oP000oh000080o`001@3oP004003o0080o`000`00o`040?l00080oh0000<0003o
0?l0003o00000P00o`070?n00080003o6?ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Rooooog;o00009ooo
oomao`0002OoooooLOl0000Wooooog;o00008oooool002;ooooo00?o0000ooooooooool00ooooolF
ool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolF
o`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo
5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
7ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`00
1OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5_oo0005oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l00_l007lGool000Co001o5_l0o`05o`00OaKo003o7ol007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool0
07l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo
0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03
o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo
001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l0
0ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool0
0ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l0K_l007l00ol0003ooooooooo
o`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;oooooL_l0000Wooooog7o0000
9ooooomao`0002OoooooL_l0000Sooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
5_ooool40?l000030000o`3o0000o`000080003o2`3o00020000o`030?l000000?l0003o00d0o`00
00<0oh000?l0003o00001`3o00020000oaT0o`000P000?l20?l00080003o0`3o00040?n00080003o
1`3o00020?n000030?l000000?l0003o00/0o`000P000?l70?l000D0oh002`3o000>ooooo`@0003o
1`3o00050000oa000?l01`3o000=003o0080003o0`3o00020000o`/0o`003P000?l7003o00@0o`00
0P000?l20?l000T0003o00<00?l00?l0003o00003@000?l30?l000H0003o0`3o00020000o`kooooo
1@000?l2003o0080003o2@00o`020000o`<00?l00P3o0007003o0080003o1`00o`020000oa800?l0
2`000?l00`3o0000003o0000o`040?l000<0003o0P3o00020000o`L00?l03`3o00000`00o`00o`00
0?l00004003o00030000o`00o`000?l000800?l03P3o00040000o`kooooo3P3oP0020?l000L0oh00
0P3o000=0?n000<0o`002@3oP0020?l000@0oh001@3o00090?n00080o`00803oP0020?l00080oh00
00<0o`000?n0003oP0000P3oP0020000o`<0o`001P3oP0000`3o0000oh000?n0000;0?n001Sooooo
000Fooooo`@0o`0000<0003o0?l0003o00000P000?l;0?l00080003o00<0o`000000o`000?l03@3o
00000`3oP000o`000?l000070?l00080003o6@3o00020000o`80o`000P000?l30?l000@0oh000P00
0?l70?l00080oh0000<0o`000000o`000?l02`3o00020000o`L0o`001@3oP00;0?l000kooooo1000
0?l70?l000D0003o4000o`070?l000d00?l00P000?l30?l00080003o2`3o000>0000o`L00?l0103o
00020000o`80o`002@000?l00`00o`00o`000?l0000=0000o`<0o`001P000?l30?l00080003o3_oo
ool50000o`800?l00P000?l9003o0080003o0`00o`020?l000L00?l00P000?l7003o0080003o4P00
o`0;0000o`030?l000000?l0003o00@0o`000`000?l20?l00080003o1`00o`0?0?l00003003o003o
0000o`0000@00?l000<0003o003o0000o`000P00o`0>0?l000@0003o3_ooool>0?n00080o`001`3o
P0020?l000d0oh000`3o00090?n00080o`00103oP0050?l000T0oh000P3o000P0?n00080o`000P3o
P0000`3o0000oh000?n000020?n00080003o0`3o00060?n000030?l0003oP000oh0000/0oh006?oo
ool001Kooooo2@3o00020000o`D0o`000P000?l20?l00080003o2P3o00020000o`D0o`0010000?l;
0?l000<0oh00:`3o00020000o`/0o`000`000?l60?l000D0oh002`3o000>ooooo`@0003o1@3o0005
0000o`P00?l02P000?l40?l000L0003o1`3o000B0000o`D0o`002`000?l2003o00@0003o00<00?l0
0?l0003o00007`000?l00`3o0000003o0000o`020000o`80o`001`000?l>ooooo`@0003o0`3o000=
003o00L0003o2`00o`000`3o00000?l0003o00020000o`@00?l01`000?l2003o00030000o`3o0000
o`000080003o1`3o00040000o`L0o`001@00o`040000o`800?l000<0003o003o0000o`001P3o0000
0`000?l0o`000?l000060000o`03003o00000?l0003o00/0003o0P3o00030000o`80o`000P000?l5
003o0080003o3_oooolR0?n00080o`000P3oP0030?l001/0oh000P000?l30?l000/0oh000P3o000D
0?n00080o`007P3oP00Hooooo`005_ooool90?l00080003o1@3o00020000o`80o`000P000?l:0?l0
0080003o1@3o00040000o`/0o`000`3oP00[0?l00080003o2`3o00030000o`H0o`001@3oP00;0?l0
00kooooo10000?l50?l000D0003o2000o`0:0000o`@0o`001`000?l70?l00180003o1@3o000;0000
o`800?l010000?l00`00o`00o`000?l0000O0000o`030?l000000?l0003o0080003o0P3o00070000
o`kooooo10000?l30?l000d00?l01`000?l;003o00030?l00000o`000?l00080003o1000o`070000
o`800?l000<0003o0?l0003o00000P000?l70?l000@0003o1`3o0005003o00@0003o0P00o`000`00
0?l00?l0003o00060?l000030000o`3o0000o`0000H0003o00<00?l00000o`000?l02`000?l20?l0
00<0003o0P3o00020000o`D00?l00P000?l>ooooob80oh000P3o00020?n000<0o`006`3oP0020000
o`<0o`002`3oP0020?l001@0oh000P3o000N0?n001Sooooo000Foooooad0o`0000<0003o0?l0003o
00001P3o00050000o`/0o`000`3oP00;0?l00080003o303o00060?n001@0o`0000<0003o0?l0003o
0000103o00030000o`@0o`001@3oP0020000o`D0o`00103oP00>ooooo`@0003o00<0o`000000o`00
0?l0103o00020000o`L00?l01`3o0002003o00`0003o1`3o0002003o00d0003o0P00o`080?l00080
0?l00P3o0009003o0080o`005@00o`020000o`800?l00`000?l40?l00080003o1@3o00020000o`@0
o`000`00o`020?l000kooooo2`3o0009003o00T0003o00<00?l00000o`000?l010000?l3003o0080
003o0P00o`020000o`800?l000<0003o003o0000o`000P000?l20?l000800?l000<0003o0?l0003o
00002@3o0004003o00030000o`3o0000o`0000@0003o0P3o000:003o00/0003o0P3o000;003o0003
0000o`00o`000?l000800?l04P000?l>ooooo`T0oh000P3o00090?n00080o`001@3oP0020?l001/0
oh0000<0o`000?n0003oP0001P3oP0000`000?l0o`000?l0000@0?l001T0oh000P3o00020?n000<0
o`005P3oP00Hooooo`005_oooolk0?l000@0003o4`3o00020?n000@0003o2`3o00030000o`80o`00
0P000?l20?l000030000o`3o0000o`0000D0o`0010000?l50?l000@0003o1@3o00040?n000kooooo
2`000?l2003o00030000o`00o`000?l00080003o0P00o`070?l000D00?l01`000?l;003o00d0003o
0P00o`0<0?l000D0003o2`00o`070000o`@00?l02@000?l3003o0080003o0P3o000@0000o`80o`00
3_ooool90?l000T00?l01`3o00040000o`03003o00000?l0003o00@0003o0P00o`090?l000D00?l0
1`3o00070000o`80o`000P000?l2003o00T0003o0`3o0006003o00030000o`3o0000o`000080003o
0P00o`090000o`800?l00`000?l4003o00030000o`00o`000?l000T00?l02`000?l>ooooo`h0oh00
0P000?l40?l002@0oh0000<0003o0?n0003oP000403oP0020?l002@0oh000`3o00090?n000@0o`00
2@3oP00Hooooo`005_oooolk0?l000@0003o4`3o00020?n000@0003o2`3o00030000o`80o`000P00
0?l20?l000030000o`3o0000o`0000D0o`0010000?l50?l000@0003o1@3o00040?n000kooooo2`00
0?l2003o00030000o`00o`000?l00080003o0P00o`070?l000D00?l01`000?l;003o00d0003o0P00
o`0<0?l000D0003o2`00o`070000o`@00?l02@000?l3003o0080003o0P3o000@0000o`80o`003_oo
ool90?l000T00?l01`3o00040000o`03003o00000?l0003o00@0003o0P00o`090?l000D00?l01`3o
00070000o`80o`000P000?l2003o00T0003o0`3o0006003o00030000o`3o0000o`000080003o0P00
o`090000o`800?l00`000?l4003o00030000o`00o`000?l000T00?l02`000?l>ooooo`h0oh000P00
0?l40?l002@0oh0000<0003o0?n0003oP000403oP0020?l002@0oh000`3o00090?n000@0o`002@3o
P00Hooooo`005_ooool20?l00080003o1`3o00030000o`l0o`0000<0003o0?l0003o0000403o0002
0000oa/0o`000P000?l30?l000@0oh0010000?l00`3o0000oh000?n000020?n00080003o1`3o0005
0000o`/0o`000P000?l30?l000H0003o1@3o00020?n000kooooo2`000?l9003o00L0003o1`00o`0;
0000oa@00?l00`3o00050000o`@0o`0010000?l30?l000800?l01@000?l6003o00L0003o0P3o0002
0000o`<0o`005`000?l4003o00kooooo1@3o00040000o`L00?l02@3o0004003o00L0003o0P00o`0C
0?l00080003o0P3o000>0000o`T0o`001P00o`000`3o00000?l0003o00040?l000800?l030000?l7
003o0080003o1`00o`020000o`800?l00P3o0005003o00kooooo4P3oP0020?l00080oh0000<0o`00
0?n0003oP000103oP0000`3o0000oh000?n0000D0?n00080003o403oP0050?l003X0oh0000<0o`00
0?n0003oP0000P3o000Hooooo`005_ooool20?l00080003o1`3o00030000o`l0o`0000<0003o0?l0
003o0000403o00020000oa/0o`000P000?l30?l000@0oh0010000?l00`3o0000oh000?n000020?n0
0080003o1`3o00050000o`/0o`000P000?l30?l000H0003o1@3o00020?n000kooooo2`000?l9003o
00L0003o1`00o`0;0000oa@00?l00`3o00050000o`@0o`0010000?l30?l000800?l01@000?l6003o
00L0003o0P3o00020000o`<0o`005`000?l4003o00kooooo1@3o00040000o`L00?l02@3o0004003o
00L0003o0P00o`0C0?l00080003o0P3o000>0000o`T0o`001P00o`000`3o00000?l0003o00040?l0
00800?l030000?l7003o0080003o1`00o`020000o`800?l00P3o0005003o00kooooo4P3oP0020?l0
0080oh0000<0o`000?n0003oP000103oP0000`3o0000oh000?n0000D0?n00080003o403oP0050?l0
03X0oh0000<0o`000?n0003oP0000P3o000Hooooo`005_ooool20?l00080003o1`3o00020000oa00
o`0000<0003o0?l0003o00007`3o00030000o`/0o`000P000?l20?l000030000o`3o0000o`0000T0
o`0010000?l90?l00080003o0`3o00020000o`80o`0000<0oh000?l0003o00002@3o00020000o`@0
o`0000<0003o0?l0003o00000P000?l>ooooo`80o`000P000?l00`3o00000?l0003o0006003o0003
0000o`00o`000?l00080003o0P00o`030000o`80o`000P000?l7003o00D0o`004@00o`090000o`03
0?l000000?l0003o00h0003o0P3o0007003o0080003o1`00o`040000o`80o`002@000?l3003o0080
003o2`00o`020000o`030?l000000?l0003o0080o`003_ooool40?l000L0003o0`00o`080?l000<0
003o0P00o`020000o`030?l000000?l0003o00800?l00P3o0003003o0080o`000P00o`090?l00080
003o0`3o00090000o`L00?l00P000?l60?l000<0003o1000o`070000o`L00?l02`000?l9003o0080
003o0`00o`0;0000o`kooooo4P3oP0020?l00200oh000P3o000B0?n000<0o`002`3oP0050?l000H0
oh000P000?lS0?n00080o`000P3oP00Hooooo`005_ooool20?l00080003o1`3o00020000oa00o`00
00<0003o0?l0003o00007`3o00030000o`/0o`000P000?l20?l000030000o`3o0000o`0000T0o`00
10000?l90?l00080003o0`3o00020000o`80o`0000<0oh000?l0003o00002@3o00020000o`@0o`00
00<0003o0?l0003o00000P000?l>ooooo`80o`000P000?l00`3o00000?l0003o0006003o00030000
o`00o`000?l00080003o0P00o`030000o`80o`000P000?l7003o00D0o`004@00o`090000o`030?l0
00000?l0003o00h0003o0P3o0007003o0080003o1`00o`040000o`80o`002@000?l3003o0080003o
2`00o`020000o`030?l000000?l0003o0080o`003_ooool40?l000L0003o0`00o`080?l000<0003o
0P00o`020000o`030?l000000?l0003o00800?l00P3o0003003o0080o`000P00o`090?l00080003o
0`3o00090000o`L00?l00P000?l60?l000<0003o1000o`070000o`L00?l02`000?l9003o0080003o
0`00o`0;0000o`kooooo4P3oP0020?l00200oh000P3o000B0?n000<0o`002`3oP0050?l000H0oh00
0P000?lS0?n00080o`000P3oP00Hooooo`005_ooool20?l000<0003o1P3o0002003o00L0o`000P00
0?l30?l00080003o2@3o00020000ocT0o`000P000?lY0?l000kooooo1000o`030000o`d00?l00P3o
000:003o00L0o`005000o`020?l000800?l030000?l90?l001000?l03`000?l5003o00@0003o00<0
0?l00?l0003o00000P000?l50?l000@0003o3_ooool70000o`800?l00P3o00020000o`<0o`002`00
0?l2003o00030?l000000?l0003o00@0o`000P00o`000`3o0000003o0000o`070000o`P0o`004000
0?l00`00o`00o`000?l000040?l000<0003o103o00020000o`80o`002@000?l50?l00080003o2@3o
00000`00o`00o`000?l000060?l000<0003o1000o`070000o`kooooo6@3oP0020?l002d0oh000`3o
000F0?n00080o`00803oP0020?l000D0oh006?ooool001Kooooo0P000?l20?l000030000o`3o0000
o`0000@0o`000P000?lE0?l000@0003o2@3o00000`000?l0o`000?l000020?l00080003o9@3o0002
0000o`d0o`000P000?l70?l000030000o`3o0000o`000180o`000P000?l>ooooo`800?l00P3o000J
003o0080o`000P000?l40?l000<0003o3@00o`0>0000o`800?l01@000?l90?l000l00?l01@3o0007
0000o`80o`000P000?l30?l000L0003o2@3o00040000o`kooooo3@000?l00`00o`00003o0000o`06
0000o`L00?l000<0003o003o0000o`000P00o`020?l000D0003o0P3o00020000o`<0o`003`000?l3
0?l00080003o0P3o00020000o`030?l000000?l0003o0080o`001`000?l20?l000L0003o0P3o0005
003o0080o`002`000?l20?l00003003o003o0000o`0000T0o`000P000?l20?l000L0003o3_oooom8
0?n000030?l0003oP000oh0002P0oh0000<0o`000?n0003oP000503oP00Hooooo`005_ooool20000
o`80o`0000<0003o0?l0003o0000103o00020000oaD0o`0010000?l90?l000030000o`3o0000o`00
0080o`000P000?lU0?l00080003o3@3o00020000o`L0o`0000<0003o0?l0003o00004P3o00020000
o`kooooo0P00o`020?l001X00?l00P3o00020000o`@0o`000`000?l=003o00h0003o0P00o`050000
o`T0o`003`00o`050?l000L0003o0P3o00020000o`<0o`001`000?l90?l000@0003o3_ooool=0000
o`03003o00000?l0003o00H0003o1`00o`000`000?l00?l0003o0002003o0080o`001@000?l20?l0
0080003o0`3o000?0000o`<0o`000P000?l20?l00080003o00<0o`000000o`000?l00P3o00070000
o`80o`001`000?l20?l000D00?l00P3o000;0000o`80o`0000<00?l00?l0003o00002@3o00020000
o`80o`001`000?l>ooooodP0oh0000<0o`000?n0003oP000:03oP0000`3o0000oh000?n0000D0?n0
01Sooooo000Fooooo`80003o0P3o00000`000?l0o`000?l000020?l000@0003o403o00000`000?l0
o`000?l000060?l00003003o003o0000o`0000H0o`0000<0003o0?l0003o00003`3o00050000o`D0
o`000P000?lB0?l00080003o2@3o00070000oaL0o`000P000?l>oooooa@00?l01`000?l3003o00l0
003o1@00o`020?l000800?l00`000?l20?l000L0003o0P3o0002003o0100o`003@00o`070?l000L0
0?l030000?l20?l000@0003o0P3o00000`000?l00?l0003o0002003o00kooooo2@00o`0=0000o`03
0?l00000o`000?l000@0o`002P000?l2003o00L0o`003`00o`030?l000H0003o00<00?l00000o`00
0?l00P3o00020000o`<0o`002@000?l2003o00L0o`003@000?l20?l00003003o003o0000o`0000@0
o`000`000?l20?l000800?l01@000?l40?l000kooooo403oP0020?l000L0oh000P3o000i0?n00080
o`006@3oP0020?l001T0oh006?ooool001Kooooo0P000?l20?l000030000o`3o0000o`000080o`00
10000?l@0?l000030000o`3o0000o`0000H0o`0000<00?l00?l0003o00001P3o00000`000?l0o`00
0?l0000?0?l000D0003o1@3o00020000oa80o`000P000?l90?l000L0003o5`3o00020000o`kooooo
5000o`070000o`<00?l03`000?l5003o0080o`000P00o`030000o`80o`001`000?l20?l000800?l0
403o000=003o00L0o`001`00o`0<0000o`80o`0010000?l20?l000030000o`00o`000?l000800?l0
3_ooool9003o00d0003o00<0o`00003o0000o`00103o000:0000o`800?l01`3o000?003o00<0o`00
1P000?l00`00o`00003o0000o`020?l00080003o0`3o00090000o`800?l01`3o000=0000o`80o`00
00<00?l00?l0003o0000103o00030000o`80o`000P00o`050000o`@0o`003_ooool@0?n00080o`00
1`3oP0020?l003T0oh000P3o000I0?n00080o`006@3oP00Hooooo`005_ooool40?l000030000o`3o
0000o`000080o`000P000?l20?l000030000o`3o0000o`0000d0o`0000<0003o0?l0003o00008P3o
00020000o`80o`000P000?l30?l000@0003o5@3o00020000o`80o`001@000?l20?l00080003o1@3o
00020000oa80o`003_oooolM003o00D0003o103o00000`000?l0o`000?l000020?l00080003o3P00
o`020000o`800?l01@3o00020000o`L0o`00103oP0030000o`80o`002`00o`070000o`800?l00P00
0?l3003o00h0003o0P3o00070000o`@00?l03_ooool9003o00L0003o1P00o`070?l000030000o`00
o`000?l000T0003o103o00030000o`l00?l01`000?l2003o00D0003o0P3o00070000o`D00?l01P00
0?l20?l000L0003o0P3o000<0000o`80o`001@000?l4003o00L0003o3_oooolF0?n000D0003o0P3o
000W0?n00080o`00303oP0020000o`@0o`006@3oP0030?l00080oh000P3o00090?n00080o`001`3o
P00Hooooo`005_ooool40?l000030000o`3o0000o`000080o`000P000?l20?l000030000o`3o0000
o`0000d0o`0000<0003o0?l0003o00008P3o00020000o`80o`000P000?l30?l000@0003o5@3o0002
0000o`80o`001@000?l20?l00080003o1@3o00020000oa80o`003_oooolM003o00D0003o103o0000
0`000?l0o`000?l000020?l00080003o3P00o`020000o`800?l01@3o00020000o`L0o`00103oP003
0000o`80o`002`00o`070000o`800?l00P000?l3003o00h0003o0P3o00070000o`@00?l03_ooool9
003o00L0003o1P00o`070?l000030000o`00o`000?l000T0003o103o00030000o`l00?l01`000?l2
003o00D0003o0P3o00070000o`D00?l01P000?l20?l000L0003o0P3o000<0000o`80o`001@000?l4
003o00L0003o3_oooolF0?n000D0003o0P3o000W0?n00080o`00303oP0020000o`@0o`006@3oP003
0?l00080oh000P3o00090?n00080o`001`3oP00Hooooo`005_ooool20000o`80o`0000<0003o0?l0
003o00005P3o00030000ob/0o`000P000?l@0?l00080003o3@3o00000`000?l0o`000?l000020?l0
0080003o1@3o00020000o`<0o`000P000?l70?l00080003o0P3o000>ooooo`80o`000P00o`000`00
0?l00?l0003o0006003o00D0003o3000o`020?l000@0003o1`3o0009003o01D0003o3@3o000;003o
0080o`001`000?l5003o00T0003o0P00o`020000o`<0o`000P000?l70?l000800?l03_ooool40000
o`X00?l00P3o00040000o`<00?l00P000?l2003o00h0003o0P3o00050000o`T00?l03@000?l2003o
00030000o`00o`000?l000H00?l00`000?l;003o00@0o`001`000?l20?l001h0003o3_oooolB0?n0
00`0o`009P3oP0020?l000h0oh000P3o000d0?n001Sooooo000Fooooo`80003o0P3o00000`000?l0
o`000?l0000F0?l000<0003o:`3o00020000oa00o`000P000?l=0?l000030000o`3o0000o`000080
o`000P000?l50?l00080003o0`3o00020000o`L0o`000P000?l20?l000kooooo0P3o0002003o0003
0000o`00o`000?l000H00?l01@000?l<003o0080o`0010000?l70?l000T00?l05@000?l=0?l000/0
0?l00P3o00070000o`D00?l02@000?l2003o0080003o0`3o00020000o`L0o`000P00o`0>ooooo`@0
003o2P00o`020?l000@0003o0`00o`020000o`800?l03P000?l20?l000D0003o2@00o`0=0000o`80
0?l000<0003o003o0000o`001P00o`030000o`/00?l0103o00070000o`80o`007P000?l>oooooa80
oh00303o000V0?n00080o`003P3oP0020?l003@0oh006?ooool001Kooooo103o00000`000?l0o`00
0?l0000@0?l000@0003o0P3o00000`000?l0o`000?l000070?l00080003o=P3o00020000oa/0o`00
1@000?l50?l000@0003o3_ooool@0000o`h00?l00P3o0002003o00L0o`002@000?l2003o00T0003o
0P3o00030000o`H00?l000<0003o0?l0003o00000P3o00020000o`<0o`000P000?l20?l000/00?l0
0P3o00000`00o`00o`000?l0000=003o00<0o`000P000?l2003o0080003o0`3o00020000o`@0o`00
00<0003o003o0000o`000P00o`0>ooooo`800?l01`000?l5003o0080003o0P00o`020000o`800?l0
1`000?l5003o00h0003o2@00o`0;0000o`L00?l00P000?l4003o00<0o`002@00o`020000o`800?l0
2`000?lC003o00T0003o0P3o000>ooooo`@0o`005@3oP0020?l004T0oh000P3o000T0?n001Sooooo
000Fooooo`D0003o1P3o00020000oa00o`0000<0003o0?l0003o00002@3o00020000o`@0o`000`00
0?lb0?l00080003o803o00020000o`80o`003_oooolD003o00D0o`000P000?l3003o00T0003o0P3o
000;003o00d0003o00<0o`000000o`000?l01@00o`060?l000<0003o203o0005003o00L0003o2@00
o`070000o`80o`000P00o`020000o`D0o`000P000?l30?l00080003o0P3o000>ooooo`80003o1`00
o`040000o`03003o00000?l0003o00@00?l00P3o00000`000?l00?l0003o0007003o00/0003o8000
o`020?l00080003o0`3o00020000o`@00?l00`000?l2003o0080003o0P00o`020?l00003003o003o
0000o`000080o`0010000?l<003o0080003o0P3o00000`000?l00?l0003o0006003o00D0003o3_oo
ool20?l000T0oh000P3o000>0?n000L0o`00403oP0020000o`@0o`000`3oP0020?l004d0oh006?oo
ool001Kooooo1@000?l60?l00080003o403o00000`000?l0o`000?l000090?l00080003o103o0003
0000oc80o`000P000?lP0?l00080003o0P3o000>oooooa@00?l01@3o00020000o`<00?l02@000?l2
0?l000/00?l03@000?l00`3o0000003o0000o`05003o00H0o`000`000?l80?l000D00?l01`000?l9
003o00L0003o0P3o0002003o0080003o1@3o00020000o`<0o`000P000?l20?l000kooooo0P000?l7
003o00@0003o00<00?l00000o`000?l01000o`020?l000030000o`00o`000?l000L00?l02`000?lP
003o0080o`000P000?l30?l00080003o1000o`030000o`800?l00P000?l2003o0080o`0000<00?l0
0?l0003o00000P3o00040000o``00?l00P000?l20?l000030000o`00o`000?l000H00?l01@000?l>
ooooo`80o`002@3oP0020?l000h0oh001`3o000@0?n00080003o103o00030?n00080o`00C@3oP00H
ooooo`005_ooool50000o`/0o`00103oP0020000o`D0o`000P000?l90?l000030000o`3o0000o`00
0080o`002@000?l50?l00080003o1`3o00020000o`/0o`000P3oP0000`000?l0o`000?l000060?l0
00030000o`3o0000o`0000L0o`0010000?l20?l000<0003o3@3o00020?n000h0o`003_oooolD003o
00D0o`0010000?l00`00o`00o`000?l00002003o00T0003o2@00o`0@0000o`800?l00P3o00000`00
o`00003o0000o`040000o`D0o`001P000?l7003o0080o`003000o`070000o`80o`000P00o`020?l0
00030000o`3o0000o`0000H0003o00<0o`00003o0000o`000P3o000>ooooo`@0003o3000o`020000
oa@00?l000<0003o0?l0003o00001`000?lH003o00X0o`000P000?l4003o0080003o00<00?l00000
o`000?l00P000?l2003o0080o`000`000?l40?l00080003o00<0o`00003o0000o`000P000?l3003o
0080o`001`000?l4003o00T0003o3_oooolN0?n00080o`004P3oP0020?l00480oh000P3o000B0?n0
01Sooooo000Fooooo`D0003o2`3o00040?n00080003o1@3o00020000o`T0o`0000<0003o0?l0003o
00000P3o00090000o`D0o`000P000?l70?l00080003o2`3o00020?n000030000o`3o0000o`0000H0
o`0000<0003o0?l0003o00001`3o00040000o`80o`000`000?l=0?l00080oh003P3o000>oooooa@0
0?l01@3o00040000o`03003o003o0000o`0000800?l02@000?l9003o0100003o0P00o`020?l00003
003o00000?l0003o00@0003o1@3o00060000o`L00?l00P3o000<003o00L0003o0P3o0002003o0080
o`0000<0003o0?l0003o00001P000?l00`3o00000?l0003o00020?l000kooooo10000?l<003o0080
003o5000o`000`000?l0o`000?l000070000oaP00?l02P3o00020000o`@00?l00P000?l00`00o`00
003o0000o`020000o`800?l00P3o00030000o`@0o`000P000?l00`3o00000?l0003o00020000o`<0
0?l00P3o00070000o`@00?l02@000?l>oooooah0oh000P3o000B0?n00080o`00@P3oP0020?l00180
oh006?ooool001Kooooo0P000?l2003o00<0o`000P000?l20?l00080003o0`3o00020000o`80oh00
0P000?l30?l00080003o7P3o00020000o`80o`000P000?l20?l000030000o`3o0000o`000080003o
1`3o00020000oaD0o`000P000?l=0?l000030000o`3o0000o`0000L0o`000P000?l;0?l000kooooo
5000o`070000o`<00?l0203o000>003o00L0003o103o00020000o`<0o`001@00o`040?l00080003o
1@3o000;0000o`800?l00`3o00020000o`T00?l00P3o00070000o`800?l01@000?l20?l000T0003o
3_ooool90?l000d00?l00`3o0007003o0100003o3@00o`020000o`D00?l01`000?l40?l00080003o
00<0o`000000o`000?l01000o`070000o`800?l00P000?l00`3o0000003o0000o`060?l000<0003o
1`00o`0;0?l00080003o0`3o00040000o`kooooo5`3oP0020?l001L0oh000P3o00090?n00080003o
0P3o00050?n000D0o`00;@3oP0040?l00100oh006?ooool001Kooooo0P000?l2003o00<0o`000P00
0?l20?l00080003o0`3o00020000o`80oh000P000?l30?l00080003o7P3o00020000o`80o`000P00
0?l20?l000030000o`3o0000o`000080003o1`3o00020000oaD0o`000P000?l=0?l000030000o`3o
0000o`0000L0o`000P000?l;0?l000kooooo5000o`070000o`<00?l0203o000>003o00L0003o103o
00020000o`<0o`001@00o`040?l00080003o1@3o000;0000o`800?l00`3o00020000o`T00?l00P3o
00070000o`800?l01@000?l20?l000T0003o3_ooool90?l000d00?l00`3o0007003o0100003o3@00
o`020000o`D00?l01`000?l40?l00080003o00<0o`000000o`000?l01000o`070000o`800?l00P00
0?l00`3o0000003o0000o`060?l000<0003o1`00o`0;0?l00080003o0`3o00040000o`kooooo5`3o
P0020?l001L0oh000P3o00090?n00080003o0P3o00050?n000D0o`00;@3oP0040?l00100oh006?oo
ool001Kooooo1000o`070?l00080003o00<0o`000000o`000?l00P000?l20?l00080003o00<0o`00
0000o`000?l00P000?l30?l00080003o1P3o00000`000?l0o`000?l0000=0?l00080003o;03o0002
0000o`T0o`000P3oP0020?l000<0003o1P3o00050000o`@0o`0000<0oh000?l0003o00000P3o000>
oooooa800?l01`000?l4003o00030000o`3o0000o`000080003o103o000E003o0080o`001`000?l2
003o00D0003o0P3o00070000o`800?l01@000?l60?l00080003o3P00o`0>0000o`80o`002@000?l>
ooooo`80003o0P3o00000`00o`00o`000?l0000=003o00L0o`001@00o`070000o`80o`001P000?lE
003o00L0003o0P3o00040000o`<0o`000P00o`040000o`03003o003o0000o`0000H00?l000<0o`00
0000o`000?l0103o00030000o`H00?l00`000?l2003o0080o`000P000?l:0?l000@00?l03_oooolk
0?n00080003o0P3o00050?n00080o`002@3oP0020?l002<0oh0010000?l40?l000h0oh006?ooool0
01Kooooo1000o`070?l00080003o00<0o`000000o`000?l00P000?l20?l00080003o00<0o`000000
o`000?l00P000?l30?l00080003o1P3o00000`000?l0o`000?l0000=0?l00080003o;03o00020000
o`T0o`000P3oP0020?l000<0003o1P3o00050000o`@0o`0000<0oh000?l0003o00000P3o000>oooo
oa800?l01`000?l4003o00030000o`3o0000o`000080003o103o000E003o0080o`001`000?l2003o
00D0003o0P3o00070000o`800?l01@000?l60?l00080003o3P00o`0>0000o`80o`002@000?l>oooo
o`80003o0P3o00000`00o`00o`000?l0000=003o00L0o`001@00o`070000o`80o`001P000?lE003o
00L0003o0P3o00040000o`<0o`000P00o`040000o`03003o003o0000o`0000H00?l000<0o`000000
o`000?l0103o00030000o`H00?l00`000?l2003o0080o`000P000?l:0?l000@00?l03_oooolk0?n0
0080003o0P3o00050?n00080o`002@3oP0020?l002<0oh0010000?l40?l000h0oh006?ooool001Ko
oooo1000o`0E0?l00080003o2`3o00000`000?l0o`000?l0000O0?l000030000o`3o0000o`000080
003o0P3o00020000o`D0o`0010000?lI0?l000D0003o103o00000`000?l0o`000?l00002003o00D0
o`000P3oP0020000o`kooooo7P00o`040000o`80o`004P00o`020000o`030?l000000?l0003o0080
003o0P3o00020000o`<0o`001`00o`020?l000T0003o0P00o`030?l00080003o103o00030000o`80
0?l00P3o0002003o00<0o`003`00o`030000o`/0o`003_ooool90000o`800?l00`3o00020000o`H0
0?l000<0003o0?l0003o00000P3o00020000o`<0o`001P00o`030?l000L0003o1000o`020000o`/0
0?l00`3o00070000o`80o`0010000?l00`3o0000003o0000o`02003o00@0003o00<00?l00000o`00
0?l00P000?l4003o0100003o00<00?l00?l0003o00000P00o`090000o`@0o`001@000?l>ooooo`/0
oh000P3o000I0?n000030?l0003oP000oh0001/0oh00103o000`0?n000@0o`003P3oP00Hooooo`00
5_ooool4003o00030000o`3o0000o`000080o`000P000?lK0?l000<0003o1P3o00030000o`@0o`00
0`000?lM0?l000@0003o0`3o00040000o`h0o`000P000?l90?l00080003o303o00020000o`kooooo
7@00o`090000oa800?l030000?l7003o00L0003o1P00o`020000o`030?l000000?l0003o00H0003o
00<00?l00000o`000?l00P3o0002003o00<0o`002@00o`020000o`@00?l000<0003o003o0000o`00
2`3o000>ooooo`d0003o1`00o`050000o`80o`000P00o`030?l000800?l00P3o00050000o`/0o`00
0P000?l9003o0080003o00<0o`00003o0000o`001000o`030000o`80o`001@000?l40?l00080003o
0`3o00020000o`T00?l01P3o00000`00o`00o`000?l0000;0?l00100003o3_ooool=0?n000030?l0
003oP000oh000080o`006`3oP0020?l000X0oh000P3o000Y0?n00080003o103o000>0?n00080003o
0P3o000>0?n001Sooooo000Fooooo`@00?l000<0003o0?l0003o00000P3o00020000oa/0o`000`00
0?l60?l000<0003o103o00030000oad0o`0010000?l30?l000@0003o3P3o00020000o`T0o`000P00
0?l<0?l00080003o3_oooolM003o00T0003o4P00o`0<0000o`L00?l01`000?l6003o0080003o00<0
o`000000o`000?l01P000?l00`00o`00003o0000o`020?l000800?l00`3o0009003o0080003o1000
o`000`000?l00?l0003o000;0?l000kooooo3@000?l7003o00D0003o0P3o0002003o00<0o`000P00
o`020?l000D0003o2`3o00020000o`T00?l00P000?l00`3o00000?l0003o0004003o00<0003o0P3o
00050000o`@0o`000P000?l30?l00080003o2@00o`060?l00003003o003o0000o`0000/0o`004000
0?l>ooooo`d0oh0000<0o`000?n0003oP0000P3o000K0?n00080o`002P3oP0020?l002T0oh000P00
0?l40?l000h0oh000P000?l20?l000h0oh006?ooool001Kooooo0P00o`020000ob/0o`000`000?l@
0?l00080003o6@3o00020000o`@0o`0000<0003o0?l0003o00000P3o00020000oah0o`000P000?l>
ooooo`@0o`004000o`020000o`P00?l020000?lC003o00P0003o1@00o`030000o`800?l010000?l7
003o0080o`002@000?l7003o00D0003o0P00o`050000o`P00?l03P000?l>ooooo`L0003o1000o`07
0000o`@0o`0000<0003o0?l0003o00000P3o00020000o`03003o003o0000o`0000800?l0403o0002
003o00@0003o1`00o`020000o`030?l000000?l0003o00@0003o0`00o`0=0000o`800?l000<0003o
003o0000o`000P000?l7003o0080o`001`00o`020?l00080003o1@3o0002003o0100003o3_ooool=
0?n000<0o`004P3oP0020000o`80o`00703oP0060?l000L0oh000P3o000W0?n00080o`000P3oP007
0?l000L0oh006?ooool001Kooooo0P00o`020000ob/0o`000`000?l@0?l00080003o6@3o00020000
o`@0o`0000<0003o0?l0003o00000P3o00020000oah0o`000P000?l>ooooo`@0o`004000o`020000
o`P00?l020000?lC003o00P0003o1@00o`030000o`800?l010000?l7003o0080o`002@000?l7003o
00D0003o0P00o`050000o`P00?l03P000?l>ooooo`L0003o1000o`070000o`@0o`0000<0003o0?l0
003o00000P3o00020000o`03003o003o0000o`0000800?l0403o0002003o00@0003o1`00o`020000
o`030?l000000?l0003o00@0003o0`00o`0=0000o`800?l000<0003o003o0000o`000P000?l7003o
0080o`001`00o`020?l00080003o1@3o0002003o0100003o3_ooool=0?n000<0o`004P3oP0020000
o`80o`00703oP0060?l000L0oh000P3o000W0?n00080o`000P3oP0070?l000L0oh006?ooool001Ko
oooo1000o`070?l000<0003o1P3o00030000o`l0o`0000<0003o0?l0003o0000103o00020000o`<0
o`000P000?l50?l00080003o1P3o00030000oaH0o`000`000?l60?l000<0003o3@3o00000`00o`00
o`000?l0000?0?l000<0003o0P3o000>ooooo`80003o0P3o000J003o0080o`000P00o`020?l000h0
0?l02@000?l60?l000X0003o3`00o`070000o`D00?l02@000?l=003o00D0003o0P3o00070000o`ko
oooo1`000?l2003o00/0003o1`3o000;0000o`030?l000000?l0003o00L0o`002@000?l4003o00@0
003o00<0o`000000o`000?l01@000?l2003o0080o`001@000?l2003o01@0003o0P3o0002003o00P0
003o0P3o00020000o`L0o`002`000?l>ooooo`T0oh000P000?l20?n000<0o`00K@3oP0040?l000L0
oh000P3o000Hooooo`005_ooool4003o00L0o`000`000?l60?l000<0003o3`3o00000`000?l0o`00
0?l000040?l00080003o0`3o00020000o`D0o`000P000?l60?l000<0003o5P3o00030000o`H0o`00
0`000?l=0?l00003003o003o0000o`0000l0o`000`000?l20?l000kooooo0P000?l20?l001X00?l0
0P3o0002003o0080o`003P00o`090000o`H0o`002P000?l?003o00L0003o1@00o`090000o`d00?l0
1@000?l20?l000L0003o3_ooool70000o`800?l02`000?l70?l000/0003o00<0o`000000o`000?l0
1`3o00090000o`@00?l010000?l00`3o0000003o0000o`050000o`800?l00P3o00050000o`800?l0
50000?l20?l000800?l020000?l20?l00080003o1`3o000;0000o`kooooo2@3oP0020000o`80oh00
0`3o001]0?n000@0o`001`3oP0020?l001Sooooo000Fooooo`800?l00P000?l@0?l000<0003o0P3o
00050000o`P0o`0000<0003o0?l0003o0000603o00000`000?l0o`000?l000050?l00080oh002`3o
00020000o`L0o`000P000?l30?l000@0003o2`3o00030000oa@0o`003_ooool40000oaT00?l000<0
003o0?l0003o000010000?l20?l001800?l02@3o00000`000?l00?l0003o00020000o`<00?l02`00
0?l2003o00L0003o1000o`020000o`03003o00000?l0003o01H00?l02@000?l00`3o0000003o0000
o`02003o00kooooo0P000?l30?l000T00?l00P000?l90?l000d0003o00<0o`000000o`000?l00P3o
00020?n000T0003o0`00o`020000o`H00?l01`3o0003003o0080o`000P000?l30?l000T0003o0P3o
00040000o`80o`005@000?l70?l000@0003o0P00o`050000o`kooooo2@3o00020?n00080003o00<0
o`000?n0003oP0004P3oP0020000o`80oh0000<0o`000?n0003oP000E03oP0020?l00080003o103o
00000`3oP000003o0000o`020000oaSooooo000Fooooo`@00?l00`3o00020?n00100o`0010000?l5
0?l00080003o803o00020000o`h0o`0010000?l90?l00080003o1`3o00020000o`030?l000000?l0
003o0080003o6@3o000>ooooo`D0003o5P00o`090000o`80o`002@00o`000`000?l00?l0003o0002
0?l000D00?l00P3o00020000o`@0o`001@000?l2003o00030000o`00o`000?l000L00?l020000?l<
003o0080o`005000o`070000o`<0o`000P00o`020000o`kooooo1@3o000;003o00@0o`000P000?l0
0`3o0000003o0000o`070000o`800?l01@3o00040000o`80o`000P000?l30?l000d00?l00P000?l0
0`3o0000003o0000o`020000o`80o`0000<00?l00?l0003o00001P000?l30?l000@00?l00P000?l0
0`00o`00003o0000o`090000o`80o`002@000?l;0?l000030000o`3o0000o`0000@0003o0P00o`00
0`000?l00?l0003o00020000o`koooooL`3oP0000`3o0000oh000?n000090?n000@0o`001`3oP00H
ooooo`005_ooool4003o00<0o`000P3oP00@0?l000@0003o1@3o00020000ob00o`000P000?l>0?l0
00@0003o2@3o00020000o`L0o`000P000?l00`3o0000003o0000o`020000oaT0o`003_ooool50000
oaH00?l02@000?l20?l000T00?l000<0003o003o0000o`000P3o0005003o0080o`000P000?l40?l0
00D0003o0P00o`000`000?l00?l0003o0007003o00P0003o3000o`020?l001@00?l01`000?l30?l0
00800?l00P000?l>ooooo`D0o`002`00o`040?l00080003o00<0o`000000o`000?l01`000?l2003o
00D0o`0010000?l20?l00080003o0`3o000=003o0080003o00<0o`000000o`000?l00P000?l20?l0
0003003o003o0000o`0000H0003o0`3o0004003o0080003o00<00?l00000o`000?l02@000?l20?l0
00T0003o2`3o00000`000?l0o`000?l000040000o`800?l000<0003o003o0000o`000P000?l>oooo
og<0oh0000<0o`000?n0003oP0002@3oP0040?l000L0oh006?ooool001Kooooo0P00o`070?l00080
003o0`3o00020?n000/0o`000P000?l30?l00080003o3@3o00000`000?l0o`000?l000060?l00003
0000o`3o0000o`000100o`000P000?l70?l000@0003o0`3o00020?n002P0o`0000<0oh000000o`00
0?l00P3o000>ooooo`80003o1@00o`070000oa000?l020000?l:003o0080003o0P3o000>0000o`T0
0?l0103o00050000o`H00?l030000?l20?l000h00?l02@000?l20?l000T0003o3_ooool20?l000<0
003o2`00o`0;0000o`80o`000`000?l2003o00@0003o00<0o`000000o`000?l0103o00020000o`<0
o`003`00o`030000o`L0o`0010000?l70?l000800?l00P000?l00`00o`00o`000?l000040000o`80
o`0000<0003o0?l0003o00000P3o00020000o`D00?l010000?l00`3o0000003o0000o`020000o`80
o`0030000?l2003o0080003o3_oooom80?n000<0o`00403oP0020?l002d0oh006?ooool001Kooooo
0P00o`070?l00080003o0`3o00020?n000/0o`000P000?l30?l00080003o3@3o00000`000?l0o`00
0?l000060?l000030000o`3o0000o`000100o`000P000?l70?l000@0003o0`3o00020?n002P0o`00
00<0oh000000o`000?l00P3o000>ooooo`80003o1@00o`070000oa000?l020000?l:003o0080003o
0P3o000>0000o`T00?l0103o00050000o`H00?l030000?l20?l000h00?l02@000?l20?l000T0003o
3_ooool20?l000<0003o2`00o`0;0000o`80o`000`000?l2003o00@0003o00<0o`000000o`000?l0
103o00020000o`<0o`003`00o`030000o`L0o`0010000?l70?l000800?l00P000?l00`00o`00o`00
0?l000040000o`80o`0000<0003o0?l0003o00000P3o00020000o`D00?l010000?l00`3o0000003o
0000o`020000o`80o`0030000?l2003o0080003o3_oooom80?n000<0o`00403oP0020?l002d0oh00
6?ooool001Kooooo0P00o`050?l000H0003o0`3o00040000ob80o`000P000?l50?l00080oh00303o
00020000o`L0o`000P00o`050?l000@0003o0P3o00030000o`/0o`000P000?l70?l00080003o303o
00040000o`kooooo0P00o`020?l00003003o003o0000o`000080o`003P00o`040000o`800?l01@00
0?l@003o00l0003o0`3o00020000o`800?l02@3o0007003o0080003o00<00?l00000o`000?l01`00
o`020?l00080003o0P3o000@003o00T0003o1@00o`020000o`kooooo0P000?l2003o00030000o`00
o`000?l000L00?l040000?l4003o00T0003o0P3o00090000o``00?l02@000?l20?l00080003o0`3o
00060000o`<0o`004P000?l2003o00T0003o0P3o00030000o`80o`001P000?l5003o00koooooB`3o
P0020?l000/0oh000P3o00000`3oP000o`000?l0000]0?n001Sooooo000Fooooo`800?l01@3o0006
0000o`<0o`0010000?lR0?l00080003o1@3o00020?n000`0o`000P000?l70?l000800?l01@3o0004
0000o`80o`000`000?l;0?l00080003o1`3o00020000o``0o`0010000?l>ooooo`800?l00P3o0000
0`00o`00o`000?l000020?l000h00?l010000?l2003o00D0003o4000o`0?0000o`<0o`000P000?l2
003o00T0o`001`00o`020000o`03003o00000?l0003o00L00?l00P3o00020000o`80o`004000o`09
0000o`D00?l00P000?l>ooooo`80003o0P00o`000`000?l00?l0003o0007003o0100003o1000o`09
0000o`80o`002@000?l<003o00T0003o0P3o00020000o`<0o`001P000?l30?l00180003o0P00o`09
0000o`80o`000`000?l20?l000H0003o1@00o`0>oooood/0oh000P3o000;0?n00080o`0000<0oh00
0?l0003o0000;@3oP00Hooooo`005_ooool2003o00h0o`0010000?l50?l00080003o1`3o00040000
oaL0o`000P3oP0030000oa80o`0010000?l30?l00080003o503o00020000o`h0o`000P000?l30?l0
00@0003o3_ooool7003o0080003o5`00o`020000oa000?l02@000?l6003o00030000o`3o0000o`00
00@00?l000<0o`000000o`000?l01P3o00050000o`800?l00P3o00000`00o`00o`000?l00004003o
00T0003o3P00o`090000o`80o`001@000?l2003o00kooooo0P000?lD003o00030000o`00o`000?l0
00@00?l000<0003o003o0000o`001`00o`040000o`80o`001@000?l60?l001400?l02@000?l20?l0
0080003o1000o`090000o`03003o00000?l0003o0080003o2@00o`0@0000o`@00?l000<0003o003o
0000o`000P000?l>ooooocP0oh000`000?l20?l000L0oh000P3o000`0?n00080o`004P3oP00Hoooo
o`005_ooool2003o00h0o`0010000?l50?l00080003o1`3o00040000oaL0o`000P3oP0030000oa80
o`0010000?l30?l00080003o503o00020000o`h0o`000P000?l30?l000@0003o3_ooool7003o0080
003o5`00o`020000oa000?l02@000?l6003o00030000o`3o0000o`0000@00?l000<0o`000000o`00
0?l01P3o00050000o`800?l00P3o00000`00o`00o`000?l00004003o00T0003o3P00o`090000o`80
o`001@000?l2003o00kooooo0P000?lD003o00030000o`00o`000?l000@00?l000<0003o003o0000
o`001`00o`040000o`80o`001@000?l60?l001400?l02@000?l20?l00080003o1000o`090000o`03
003o00000?l0003o0080003o2@00o`0@0000o`@00?l000<0003o003o0000o`000P000?l>ooooocP0
oh000`000?l20?l000L0oh000P3o000`0?n00080o`004P3oP00Hooooo`005_ooool2003o0080003o
0`3o00020000oa00o`000P000?l70?l000@0003o00<0o`000000o`000?l00P3o00020000oa80o`00
0P000?l50?l000L0003o4P3o00040000o`030?l000000?l0003o00T0o`0010000?lE0?l00080003o
3_ooool40000oa800?l00`000?lT003o00L0003o1000o`000`000?l0o`000?l000060000o`L00?l0
0P3o00000`00o`00003o0000o`020000o`@00?l000<0o`000000o`000?l01P000?l00`00o`00003o
0000o`0;003o0080003o00<00?l00000o`000?l00P000?l50?l000@00?l03_ooool20?l002L00?l0
2`000?l@003o0180003o103o00050000o`800?l01@000?l20?l000@0003o1`00o`000`3o0000003o
0000o`02003o00L0003o2`00o`0>ooooo`T0oh000P3o000;0?n000030?l0003oP000oh0000L0o`00
6@3oP0020?l000/0oh000`3o00110?n001Sooooo000Fooooo`L0o`000P00o`0E0?l00080003o1`3o
00020000o`80o`000P000?lD0?l000030000o`3o0000o`000080o`001`000?lh0?l000030000o`3o
0000o`000080003o3_ooool2003o00<0003o0P00o`020000o`h00?l00P000?lM003o00h0003o0P3o
00020000o`<0o`002`00o`0D0000o`D00?l00P000?l;003o00030?l00000o`000?l000T0o`000P00
o`0>ooooo`@0o`000`00o`020?l001800?l00P000?l>003o0080003o0P00o`000`3o0000003o0000
o`060000o``00?l010000?l00`00o`00003o0000o`060000o`03003o00000?l0003o00L0003o1P00
o`020?l00003003o003o0000o`000080o`000P000?l3003o00L0003o0P3o0002003o00d0003o0`3o
00020000o`kooooo0P3oP0020?l000`0oh000P000?l20?l000D0oh001@3o000H0?n000/0o`00>`3o
P0000`000?l0oh000?n0000;0?n001Sooooo000Fooooo`L0o`000P00o`0E0?l00080003o1`3o0002
0000o`80o`000P000?lD0?l000030000o`3o0000o`000080o`001`000?lh0?l000030000o`3o0000
o`000080003o3_ooool2003o00<0003o0P00o`020000o`h00?l00P000?lM003o00h0003o0P3o0002
0000o`<0o`002`00o`0D0000o`D00?l00P000?l;003o00030?l00000o`000?l000T0o`000P00o`0>
ooooo`@0o`000`00o`020?l001800?l00P000?l>003o0080003o0P00o`000`3o0000003o0000o`06
0000o``00?l010000?l00`00o`00003o0000o`060000o`03003o00000?l0003o00L0003o1P00o`02
0?l00003003o003o0000o`000080o`000P000?l3003o00L0003o0P3o0002003o00d0003o0`3o0002
0000o`kooooo0P3oP0020?l000`0oh000P000?l20?l000D0oh001@3o000H0?n000/0o`00>`3oP000
0`000?l0oh000?n0000;0?n001Sooooo000Fooooo`80003o0`3o00020000oaL0o`000P000?l60?l0
00<0003o103o00020000o`D0o`000P000?l@0?l00080003o2P3o00040000o`d0o`0000<0003o0?l0
003o000010000?l30?l000@0003o0P3o00000`000?l0o`000?l0000@0?l000@0003o3_oooolk003o
0080003o1`00o`020?l00080003o0`3o00020000o`80o`000P000?l00`00o`00003o0000o`04003o
00<0003o2000o`030000o`800?l00P000?l2003o00L0003o0`00o`070000o`80o`000P000?l20?l0
00D0003o0P00o`0>ooooo`@0o`006@00o`070000o``00?l020000?l<003o0080003o1@00o`020?l0
00D00?l02@000?l2003o0080003o0P00o`070000o`800?l00P3o0003003o0080003o0`00o`020?l0
00800?l00P3o0002003o00<0o`000P00o`090000o`kooooo0P3oP0020?l001`0oh000P3o000I0?n0
00@0o`00B`3oP00Hooooo`005_ooool20000o`<0o`000P000?lG0?l00080003o1P3o00030000o`@0
o`000P000?l50?l00080003o403o00020000o`X0o`0010000?l=0?l000030000o`3o0000o`0000@0
003o0`3o00040000o`80o`0000<0003o0?l0003o0000403o00040000o`kooooo>`00o`020000o`L0
0?l00P3o00020000o`<0o`000P000?l20?l00080003o00<00?l00000o`000?l01000o`030000o`P0
0?l00`000?l2003o0080003o0P00o`070000o`<00?l01`000?l20?l00080003o0P3o00050000o`80
0?l03_ooool40?l001T00?l01`000?l<003o00P0003o3000o`020000o`D00?l00P3o0005003o00T0
003o0P00o`020000o`800?l01`000?l2003o0080o`000`00o`020000o`<00?l00P3o0002003o0080
o`000P00o`030?l000800?l02@000?l>ooooo`80oh000P3o000L0?n00080o`006@3oP0040?l004/0
oh006?ooool001Kooooo0P000?l30?l00080003o6`3o00020000oa00o`0010000?l70?l00080003o
1`3o00000`000?l0o`000?l000090?l00080003o103o00000`000?l0o`000?l000090?l000@0003o
0`3o0004003o01L0o`000P000?l>oooooc@00?l00P3o0005003o0080003o103o00000`000?l0o`00
0?l0000;0?l000L00?l010000?l00`00o`00003o0000o`060000o`D00?l00P000?lB003o00<0o`00
0P00o`070000o`800?l03_ooool20000o`<0o`001P000?lB003o00L0003o0`00o`040000o`80o`00
2@000?l<003o0080o`000P00o`070?l000h0003o0P00o`020000o`800?l01`000?l<003o00l0003o
0`00o`040000o`kooooo6@3oP0020?l002d0oh0000<0o`000?n0003oP000:@3oP0020?l001@0oh00
6?ooool001Kooooo0P000?l30?l00080003o6`3o00020000oa00o`0010000?l70?l00080003o1`3o
00000`000?l0o`000?l000090?l00080003o103o00000`000?l0o`000?l000090?l000@0003o0`3o
0004003o01L0o`000P000?l>oooooc@00?l00P3o0005003o0080003o103o00000`000?l0o`000?l0
000;0?l000L00?l010000?l00`00o`00003o0000o`060000o`D00?l00P000?lB003o00<0o`000P00
o`070000o`800?l03_ooool20000o`<0o`001P000?lB003o00L0003o0`00o`040000o`80o`002@00
0?l<003o0080o`000P00o`070?l000h0003o0P00o`020000o`800?l01`000?l<003o00l0003o0`00
o`040000o`kooooo6@3oP0020?l002d0oh0000<0o`000?n0003oP000:@3oP0020?l001@0oh006?oo
ool001Kooooo0P000?l<0?l00080003o1`3o00040000o`L0o`000P000?l<0?l00080003o0P3o0004
0000o`<0o`000P000?lE0?l00080003o0P3o00050000o`@0o`0010000?l30?l000@0003o1@3o0002
0000o`T0o`000`000?l80?l000030000o`3o0000o`000080o`003_oooolb003o00L0003o0P3o0002
0000o`80o`000P000?l>0?l000L00?l00P000?l2003o00030?l000000?l0003o00d0o`000P00o`03
0000o`80o`000P000?l00`00o`00003o0000o`02003o0080o`003P000?l2003o00kooooo10000?l0
0`3o0000003o0000o`070000o`H00?l00P3o0007003o00L0003o0`00o`0=0000o`h00?l02`000?l2
003o00<0003o0P3o00020000o`@0o`002P00o`020000o`@00?l01`000?l2003o00L0003o0P00o`0>
0000o`kooooo803oP0020?l00080oh000P3o000S0?n00080003o0P3o00050?n00080o`007`3oP000
0`3o0000oh000?n000070?n00080o`002`3oP00Hooooo`005_ooool20000o``0o`000P000?l70?l0
00@0003o1`3o00020000o``0o`000P000?l20?l000@0003o0`3o00020000oaD0o`000P000?l20?l0
00D0003o103o00040000o`<0o`0010000?l50?l00080003o2@3o00030000o`P0o`0000<0003o0?l0
003o00000P3o000>oooooc800?l01`000?l20?l00080003o0P3o00020000o`h0o`001`00o`020000
o`800?l000<0o`000000o`000?l03@3o0002003o00<0003o0P3o00020000o`03003o00000?l0003o
00800?l00P3o000>0000o`800?l03_ooool40000o`030?l000000?l0003o00L0003o1P00o`020?l0
00L00?l01`000?l3003o00d0003o3P00o`0;0000o`800?l00`000?l20?l00080003o103o000:003o
0080003o1000o`070000o`800?l01`000?l2003o00h0003o3_oooolP0?n00080o`000P3oP0020?l0
02<0oh000P000?l20?l000D0oh000P3o000O0?n000030?l0003oP000oh0000L0oh000P3o000;0?n0
01Sooooo000Fooooo`80003o5`3o00020000o`D0o`0010000?lD0?l000<0003o2`3o00030000oad0
o`0010000?l50?l00080003o1`3o00020000o`80o`0000<0003o0?l0003o00001P3o00000`000?l0
o`000?l000020?l000kooooo8P00o`040000o`03003o00000?l0003o0080003o403o0002003o00@0
003o3P3o0002003o00<0003o1P00o`000`3o0000003o0000o`070?l00080003o3P00o`0=0000o`80
o`001@000?l2003o00kooooo1@3o000;003o00L0003o1000o`090000o`800?l000<0o`00003o0000
o`000P00o`070000oa@00?l00P000?l00`3o00000?l0003o00070000o`80o`002`000?l2003o0080
o`0000<00?l00?l0003o00003P00o`020000o`800?l010000?l00`00o`00003o0000o`07003o0080
003o0P00o`0>ooooo`h0oh000P3o000X0?n000030?l0003oP000oh0003P0oh0000<0o`000?n0003o
P000403oP0020?l00080oh006?ooool001Kooooo0P000?l>0?l00080003o0P3o00020000o`<0o`00
0P000?l50?l000@0003o1`3o00020000o`80o`0000<0oh000?l0003o00001`3o0002003o00/0o`00
1@000?l20?l000@0oh000`000?l;0?l000D0003o2`3o00020000oa@0o`0000<0003o0?l0003o0000
0P3o000>ooooo`800?l00P3o00000`00o`00o`000?l000020?l001@00?l000<0o`00003o0000o`00
3`00o`000`3o00000?l0003o0002003o0100003o103o00030?n000@0003o0P00o`000`000?l00?l0
003o00060000o`030?l000000?l0003o00d0003o2P00o`060000o`800?l000<0003o003o0000o`00
0P00o`070000o`800?l03_ooool50000o`P00?l000<0003o003o0000o`001`000?l6003o00030000
o`00o`000?l000800?l00P000?l2003o00030?l000000?l0003o00@0o`000P000?l30?l000800?l0
0P3o0003003o0080o`002`00o`020000o`<00?l01P000?l70?l000800?l000<0o`000000o`000?l0
1000o`020000o`03003o003o0000o`000080003o1@00o`060?l000T00?l000<0003o0?l0003o0000
0P3o00020000o`L0o`003_ooool>0?n00080o`005P3oP0000`3o0000oh000?n0000;0?n00080o`00
7P3oP0020?l002L0oh000P3o000;0?n001Sooooo000Fooooo`80003o3P3o00020000o`80o`000P00
0?l30?l00080003o1@3o00040000o`L0o`000P000?l20?l000030?n0003o0000o`0000L0o`000P00
o`0;0?l000D0003o0P3o00040?n000<0003o2`3o00050000o`/0o`000P000?lD0?l000030000o`3o
0000o`000080o`003_ooool2003o0080o`0000<00?l00?l0003o00000P3o000D003o00030?l00000
o`000?l000l00?l000<0o`00003o0000o`000P00o`0@0000o`@0o`000`3oP0040000o`800?l000<0
003o003o0000o`001P000?l00`3o0000003o0000o`0=0000o`X00?l01P000?l2003o00030000o`00
o`000?l000800?l01`000?l2003o00kooooo1@000?l8003o00030000o`00o`000?l000L0003o1P00
o`000`000?l00?l0003o0002003o0080003o0P00o`000`3o0000003o0000o`040?l00080003o0`3o
0002003o0080o`000`00o`020?l000/00?l00P000?l3003o00H0003o1`3o0002003o00030?l00000
0?l0003o00@00?l00P000?l00`00o`00o`000?l000020000o`D00?l01P3o0009003o00030000o`3o
0000o`000080o`000P000?l70?l000kooooo3P3oP0020?l001H0oh0000<0o`000?n0003oP0002`3o
P0020?l001h0oh000P3o000W0?n00080o`002`3oP00Hooooo`005_ooool40000oa`0o`0010000?l5
0?l000@0003o1`3o00020000oa00o`000`000?l80?l000<0003o3@3o00050000o`@0o`000P00o`00
0`000?l0o`000?l000040000o`T0o`0000<0003o0?l0003o00001P3o00030000o`80o`003_ooool2
003o00<0o`000P00o`020?l000d00?l03P000?l3003o0180003o0P3o0002003o00@0003o00<0o`00
0000o`000?l01@3o00020?n00080003o0P3o000;003o0100003o3000o`020000o`L00?l02@000?l2
003o00kooooo1@000?l8003o00030?l00000o`000?l000800?l010000?l00`00o`00003o0000o`04
003o00L0003o0P00o`050000o`80o`000P00o`030?l000800?l00P3o0002003o00<0o`001000o`02
0?l00003003o00000?l0003o00/00?l03P000?l40?l000<00?l00P000?l2003o00@0o`0000<0003o
0?l0003o00000P3o00020000o`03003o003o0000o`0000@00?l02@3o00050000o`80o`003_oooomj
0?n00080003o0`3o000;0?n001Sooooo000Fooooo`@0003o703o00040000o`D0o`0010000?l70?l0
0080003o403o00030000o`P0o`000`000?l=0?l000D0003o103o0002003o00030000o`3o0000o`00
00@0003o2@3o00000`000?l0o`000?l000060?l000<0003o0P3o000>ooooo`800?l00`3o0002003o
0080o`003@00o`0>0000o`<00?l04P000?l20?l000800?l010000?l00`3o0000003o0000o`050?l0
0080oh000P000?l20?l000/00?l040000?l<003o0080003o1`00o`090000o`800?l03_ooool50000
o`P00?l000<0o`00003o0000o`000P00o`040000o`03003o00000?l0003o00@00?l01`000?l2003o
00D0003o0P3o0002003o00<0o`000P00o`020?l000800?l00`3o0004003o0080o`0000<00?l00000
o`000?l02`00o`0>0000o`@0o`000`00o`020000o`800?l0103o00000`000?l0o`000?l000020?l0
0080003o00<00?l00?l0003o00001000o`090?l000D0003o0P3o000>ooooogX0oh000P000?l30?l0
00/0oh006?ooool001Kooooo0P3o00050000o`80o`000P000?l;0?l000030000o`3o0000o`000080
003o2`3o00000`000?l0o`000?l000020?l00080003o0P3o00070000oa`0o`000P000?l40?l000<0
003o103o00040000o`T0o`001`000?l70?l000<0003o203o00030000o`80o`003_ooool2003o00<0
o`006000o`050000oaL00?l00P3o00020000o`D0o`000P000?l50?l00080oh0010000?l9003o0080
o`002@000?l30?l001800?l00P000?l5003o0080003o1000o`050000o`kooooo10000?l00`3o0000
0?l0003o0002003o0080003o0P00o`070000o`T00?l01@3o0009003o00D0003o0P3o0002003o00/0
003o0P3o00000`00o`00003o0000o`09003o0100003o0P00o`020000o`800?l01`000?l20?l000<0
0?l0403o00040000o`800?l000<0o`000000o`000?l00P000?l>ooooocl0oh000P3o000Y0?n00080
o`001@3oP0020000oaL0oh006?ooool001Kooooo0P3o00050000o`80o`000P000?l;0?l000030000
o`3o0000o`000080003o2`3o00000`000?l0o`000?l000020?l00080003o0P3o00070000oa`0o`00
0P000?l40?l000<0003o103o00040000o`T0o`001`000?l70?l000<0003o203o00030000o`80o`00
3_ooool2003o00<0o`006000o`050000oaL00?l00P3o00020000o`D0o`000P000?l50?l00080oh00
10000?l9003o0080o`002@000?l30?l001800?l00P000?l5003o0080003o1000o`050000o`kooooo
10000?l00`3o00000?l0003o0002003o0080003o0P00o`070000o`T00?l01@3o0009003o00D0003o
0P3o0002003o00/0003o0P3o00000`00o`00003o0000o`09003o0100003o0P00o`020000o`800?l0
1`000?l20?l000<00?l0403o00040000o`800?l000<0o`000000o`000?l00P000?l>ooooocl0oh00
0P3o000Y0?n00080o`001@3oP0020000oaL0oh006?ooool001Kooooo103o00030000o`l0o`001@00
0?lD0?l000030000o`3o0000o`000080003o1@3o00020000o`80o`0010000?lA0?l000@0003o0P3o
00050000o`80o`0010000?l30?l000T0003o2@3o00020000o`T0o`000P000?l50?l000kooooo2@00
0?l7003o0080003o2@00o`070000oa000?l00P000?l5003o0080o`0010000?l30?l00080003o3P3o
0002003o0080003o0P3o00020000o`<00?l02@3o0004003o0080o`001@00o`020000o`03003o0000
0?l0003o00800?l010000?l>003o00kooooo1@000?l=003o0080003o1`00o`020?l000030000o`3o
0000o`000080o`000P000?l2003o0100003o0`00o`020000o`800?l00P000?l20?l000030000o`00
o`000?l000L00?l00P3o00020000o`80o`0000<0003o0?l0003o00000P3o00020000o`800?l01`3o
0003003o0100003o2@3o00060000o`<00?l010000?l>ooooo`D0oh000P3o000B0?n00080o`008P3o
P0040?l001<0oh000P000?l20?l00380oh006?ooool001Kooooo10000?lB0?l000030000o`3o0000
o`000080003o0`3o00020000oa00o`0010000?l50?l00080003o103o00020000oaL0o`000`000?l4
0?l000@0003o0`3o0002003o01D0o`000P000?l40?l000D0003o0P3o000>ooooo`L0003o5000o`05
0000oaT00?l00P3o00060000o`030?l000000?l0003o00D0o`000P000?l40?l00080003o00<0o`00
003o0000o`000P00o`020000o`<0o`000P00o`020000o`T0o`000P00o`030000o`800?l01@000?l2
003o00@0003o2`00o`050000o`kooooo1`00o`070000oa@00?l00P000?l7003o00L0003o1000o`0@
0000o`D00?l03@3o0003003o00P0o`001@00o`040?l000<00?l01@000?l?0?l000800?l01@000?l>
oooooaH0oh000`3o00070?n000H0o`0000<0oh000?l0003o00006@3oP0020?l00100oh000P3o000d
0?n001Sooooo000Fooooo`@0003o4P3o00000`000?l0o`000?l000020000o`<0o`000P000?l@0?l0
00@0003o1@3o00020000o`@0o`000P000?lG0?l000<0003o103o00040000o`<0o`000P00o`0E0?l0
0080003o103o00050000o`80o`003_ooool70000oa@00?l01@000?lI003o0080o`001P000?l00`3o
0000003o0000o`050?l00080003o103o00020000o`030?l00000o`000?l000800?l00P000?l30?l0
00800?l00P000?l90?l000800?l00`000?l2003o00D0003o0P00o`040000o`/00?l01@000?l>oooo
o`L00?l01`000?lD003o0080003o1`00o`070000o`@00?l040000?l5003o00d0o`000`00o`080?l0
00D00?l0103o0003003o00D0003o3`3o0002003o00D0003o3_oooolF0?n000<0o`001`3oP0060?l0
00030?n0003o0000o`0001T0oh000P3o000@0?n00080o`00=03oP00Hooooo`005_ooool40000o`L0
o`000`000?l80?l00003003o003o0000o`000100o`000P000?l=0?l000T0003o0`3o00050000oa@0
o`001P000?l:0?l000800?l03P3o0002003o0080003o1@3o00020000o`80o`003_ooool40000o`D0
0?l01@000?lZ003o00030000o`3o0000o`0000@0003o0`3o00060000o`030?l000000?l0003o00@0
003o0P00o`030?l000H0003o1@3o00070000o`@0o`000`000?l20?l00080003o0`3o0002003o0080
o`004P00o`0>ooooo`L00?l00P3o000=003o00030?l000000?l0003o0080o`001`000?l2003o0080
003o00<00?l00000o`000?l02@000?l;003o00T0003o0`3o0002003o00@0o`000P000?l00`3o0000
003o0000o`040?l000<0003o203o0005003o0080003o0P00o`050?l00080003o1`3o00050000o`H0
0?l01@000?l>ooooo`D0oh00103o00210?n001Sooooo000Fooooo`@0003o1`3o00030000o`P0o`00
00<00?l00?l0003o0000403o00020000o`d0o`002@000?l30?l000D0003o503o00060000o`X0o`00
0P00o`0>0?l000800?l00P000?l50?l00080003o0P3o000>ooooo`@0003o1@00o`050000obX00?l0
00<0003o0?l0003o000010000?l30?l000H0003o00<0o`000000o`000?l010000?l2003o00<0o`00
1P000?l50?l000L0003o103o00030000o`80o`000P000?l30?l000800?l00P3o000B003o00kooooo
1`00o`020?l000d00?l000<0o`000000o`000?l00P3o00070000o`800?l00P000?l00`00o`00003o
0000o`090000o`/00?l02@000?l30?l000800?l0103o00020000o`030?l000000?l0003o00@0o`00
0`000?l80?l000D00?l00P000?l2003o00D0o`000P000?l70?l000D0003o1P00o`050000o`kooooo
1@3oP0040?l00840oh006?ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Rooooog;o00009ooooomao`0002Oo
ooooLOl0000Wooooog;o00008oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol0
0?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo
0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l0
0?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00o`Gooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o
1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo
5ol0o`04oooooaKo003o1OoooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaOo0?l07ooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`0Mo`00OaOo0?l07ol007lFoomo00Go001o00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo
001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lF
o`3o00Go001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0>?l007lF
o`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o
0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o
0000o`00Ool007l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00
O`1^o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKo
o`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000oooooooo
ool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l0K_l007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
ooooL_l0000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`005_ooool[0?l00080oh000P3o00000`3oP000o`000?l000020?l00080
oh00=P3o00000`3oP000o`000?l000020000o`<0o`000P3oP00D0?l000kooooo4P00o`020000o`80
0?l000<0003o003o0000o`001@00o`080?n000D00?l01@000?l6003o0080oh0000<0o`000000o`00
0?l00P000?l50?n00080003o1000o`000`3oP000o`000?l000060?l000D00?l00P000?l3003o0080
oh001000o`070?n000@00?l000<0003o0?n0003oP00010000?l00`00o`00oh000?n00002003o00L0
oh000P000?l20?n000D0003o0P00o`0>oooooe80003o0P00o`020?n00100003o0P00o`0P0000o`80
0?l03_ooool2003o0080oh000`00o`070?n000@0003o103oP007003o00<0oh0010000?l3003o00P0
oh0000<0003o0?l0003o00000P3oP004003o00030?l0003oP000oh000080o`001@3oP0020?l000@0
oh000`00o`020?n000@00?l01@000?l20?n000<0o`00203oP0050000o`L00?l00P3o00070?n00080
o`000P3oP0030?l00080oh000P3o00050?n000800?l06?ooool001Kooooo:`3o00020?n00080o`00
00<0oh000?l0003o00000P3o00020?n003H0o`0000<0oh000?l0003o00000P000?l30?l00080oh00
503o000>oooooa800?l00P000?l2003o00030000o`00o`000?l000D00?l0203oP005003o00D0003o
1P00o`020?n000030?l000000?l0003o0080003o1@3oP0020000o`@00?l000<0oh000?l0003o0000
1P3o0005003o0080003o0`00o`020?n000@00?l01`3oP004003o00030000o`3oP000oh0000@0003o
00<00?l00?n0003oP0000P00o`070?n00080003o0P3oP0050000o`800?l03_oooomB0000o`800?l0
0P3oP00@0000o`800?l080000?l2003o00kooooo0P00o`020?n000<00?l01`3oP0040000o`@0oh00
1`00o`030?n000@0003o0`00o`080?n000030000o`3o0000o`000080oh001000o`000`3o0000oh00
0?n000020?l000D0oh000P3o00040?n000<00?l00P3oP004003o00D0003o0P3oP0030?l000P0oh00
1@000?l7003o0080o`001`3oP0020?l00080oh000`3o00020?n00080o`001@3oP002003o01Sooooo
000Fooooobd0o`000`3oP0040?l00080003o0`3o00020?n00380o`000P3oP00K0?l000kooooo0P00
o`020000o``00?l010000?l9003o00030?n00000o`000?l000800?l01@3oP0060000o`800?l000<0
003o003o0000o`002`00o`050?n000800?l00P3oP0020?l000030?n0003o0000o`000080oh000P3o
00030000o`T00?l01P3oP0020?l000030?n0003o0000o`000080oh000P000?l7003o00L0oh001000
0?l30?n000@00?l00P000?l00`00o`00003o0000o`02003o00kooooo3P000?l6003o01T0003o0P00
o`000`000?l00?l0003o00090000o`800?l010000?l00`00o`00003o0000o`090000o`800?l05`00
0?l4003o0080003o00<00?l00000o`000?l05`000?l4003o00kooooo0P3oP003003o00/0oh001P00
o`000`3oP0000?l0003o00020?l000<0oh000P00o`020000o`800?l00`3oP0020?l00080oh000P00
o`070?n000@0003o2P3oP0020?l00080oh001@00o`020?n000L00?l00P000?l50?n00080o`000P3o
P0020?l00080oh0000<00?l00?n0003oP00010000?l@0?l00080oh001`3o00020?n000030?l0003o
P000oh000080oh006?ooool001Kooooo;@3o00030?n000@0o`000P000?l30?l00080oh00<P3o0002
0?n001/0o`003_ooool2003o0080003o3000o`040000o`T00?l000<0oh00003o0000o`000P00o`05
0?n000H0003o0P00o`000`000?l00?l0003o000;003o00D0oh000P00o`020?n00080o`0000<0oh00
0?l0003o00000P3oP0020?l000<0003o2@00o`060?n00080o`0000<0oh000?l0003o00000P3oP002
0000o`L00?l01`3oP0040000o`<0oh001000o`020000o`03003o00000?l0003o00800?l03_ooool>
0000o`H00?l06@000?l2003o00030000o`00o`000?l000T0003o0P00o`040000o`03003o00000?l0
003o00T0003o0P00o`0G0000o`@00?l00P000?l00`00o`00003o0000o`0G0000o`@00?l03_ooool2
0?n000<00?l02`3oP006003o00030?n00000o`000?l00080o`000`3oP002003o0080003o0P00o`03
0?n00080o`000P3oP002003o00L0oh0010000?l:0?n00080o`000P3oP005003o0080oh001`00o`02
0000o`D0oh000P3o00020?n00080o`000P3oP0000`00o`00oh000?n000040000oa00o`000P3oP007
0?l00080oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool[0?l00080oh001`3o00020?n0
03L0o`000P3oP00>0?l00080oh001`3o00020?n00080o`003_ooool20?n000`00?l01P000?l<003o
00L0003o0P00o`090000o`/00?l01@3oP0020?l000D0oh000P3o00040000o``00?l0103oP002003o
0080o`0000<0oh000?l0003o00000P3oP007003o00@0oh0000<0003o0?n0003oP0001000o`020000
o`030?n000000?l0003o00@0oh000P00o`030?n000800?l03_oooold0000o`800?l00P000?l00`00
o`00003o0000o`0=0000o`<00?l010000?l20?n000L0003o0P00o`0B0000o`030?n00000o`000?l0
0080003o0`00o`0;0000o`800?l02@000?l>ooooo`80oh001@00o`070?n000@0o`000P3oP0020?l0
00<0oh00103o00000`00o`00oh000?n000040000o`800?l00`3oP0020000o`@0oh0000<00?l00?n0
003oP000103oP002003o00<0o`001P3oP0000`3o0000oh000?n000020?n000<0003o0P00o`040000
o`80oh001@000?l50?n00080o`003@3oP00<0?l000H0oh0000<0o`000?n0003oP0001`3o00020?n0
0080003o6?ooool001Kooooo:`3o00020?n005H0o`000P3oP0030?l00080oh003_ooool20000o`D0
0?l01P000?l00`00o`00003o0000o`040000o`T00?l000<0oh00003o0000o`002@00o`0;0000o`L0
0?l010000?l20?n000030?l0003oP000oh000080o`000P000?l00`3oP000o`000?l000020?n000h0
0?l0103oP0040?l000030?n0003o0000o`000080oh000P00o`020000o`03003o00000?l0003o0080
0?l00P3o00000`3oP0000?l0003o0006003o00030000o`00o`000?l000800?l00P3oP0020?l00003
0?n00000o`000?l00080oh003_ooool2003o0080003o00<00?l00000o`000?l03`000?l00`00o`00
003o0000o`0K0000o`@00?l000<0003o003o0000o`003P000?l40?n000800?l00P3oP0070000o`80
oh000`00o`0;0000o`80oh000`000?l20?n000T0003o1@00o`0;0000o`800?l03_ooool2003o0080
oh000`00o`060?n000030?l0003oP000oh0000800?l0103oP0030?l000@0oh001`00o`030?n00080
003o0P00o`050?n000@0o`000P3oP0020000o`X0oh000P000?l20?n000800?l000<0003o003o0000
o`000P3oP002003o00<0oh000P00o`060?n000<0o`001P3oP0000`3o0000oh000?n000020?n000D0
o`00103oP0050?l00080oh000P3o00030?n00080o`000P3oP0050?l00080oh000P000?lHooooo`00
5_ooool[0?l00080oh00EP3o00020?n000<0o`000P3oP00>ooooo`80003o1@00o`060000o`03003o
00000?l0003o00@0003o2@00o`000`3oP0000?l0003o0009003o00/0003o1`00o`040000o`80oh00
00<0o`000?n0003oP0000P3o00020000o`030?n0003o0000o`000080oh003P00o`040?n000@0o`00
00<0oh000?l0003o00000P3oP002003o0080003o00<00?l00000o`000?l00P00o`020?l000030?n0
0000o`000?l000H00?l000<0003o003o0000o`000P00o`020?n00080o`0000<0oh00003o0000o`00
0P3oP00>ooooo`800?l00P000?l00`00o`00003o0000o`0?0000o`03003o00000?l0003o01/0003o
1000o`000`000?l00?l0003o000>0000o`@0oh000P00o`020?n000L0003o0P3oP003003o00/0003o
0P3oP0030000o`80oh002@000?l5003o00/0003o0P00o`0>ooooo`800?l00P3oP003003o00H0oh00
00<0o`000?n0003oP0000P00o`040?n000<0o`00103oP007003o00<0oh000P000?l2003o00D0oh00
103o00020?n00080003o2P3oP0020000o`80oh000P00o`000`000?l00?l0003o00020?n000800?l0
0`3oP002003o00H0oh000`3o00060?n000030?l0003oP000oh000080oh001@3o00040?n000D0o`00
0P3oP0020?l000<0oh000P3o00020?n000D0o`000P3oP0020000oaSooooo000Fooooo`80o`000P3o
P01V0?l00080oh007P3o000>oooooa@0003o2@00o`000`3oP0000?l0003o0004003o0080oh000`00
o`0@0000o`800?l010000?l2003o00<0oh000P00o`020000o`030?n00000o`000?l00080oh002`00
o`030?n000H0003o0`3oP0020?l00080oh0010000?l00`00o`00003o0000o`02003o00D0003o1P00
o`070000o`<00?l00P3oP002003o00kooooo0P00o`0D0000o`03003o00000?l0003o00h0003o1000
o`050000o`800?l05`000?l40?n000800?l00P3oP0050000o`80oh000P3o00000`000?l0oh000?n0
00060000o`030?n000000?l0003o00d0003o00<00?l00000o`000?l00P00o`020?n000<0003o0P00
o`020000o`D00?l00P3oP0020000o`kooooo0P3oP003003o0080003o103oP0020?l000D0oh000P3o
00030?n00080o`000P3oP0020?l000L00?l00P3o00000`3oP0000?l0003o0002003o00D0oh000P00
o`020?n000800?l01@3oP0020?l000@0oh0000<00?l00?n0003oP0000P000?l7003o00@0003o2@3o
P0000`3o0000oh000?n000020000o`@0oh0000<0o`000?n0003oP000103oP0020?l000030?n0003o
0000o`0000L0oh000P3o00040?n000<0o`002@3oP002003o01Sooooo000Fooooo`80o`000P3oP01V
0?l00080oh007P3o000>oooooa@0003o2@00o`000`3oP0000?l0003o0004003o0080oh000`00o`0@
0000o`800?l010000?l2003o00<0oh000P00o`020000o`030?n00000o`000?l00080oh002`00o`03
0?n000H0003o0`3oP0020?l00080oh0010000?l00`00o`00003o0000o`02003o00D0003o1P00o`07
0000o`<00?l00P3oP002003o00kooooo0P00o`0D0000o`03003o00000?l0003o00h0003o1000o`05
0000o`800?l05`000?l40?n000800?l00P3oP0050000o`80oh000P3o00000`000?l0oh000?n00006
0000o`030?n000000?l0003o00d0003o00<00?l00000o`000?l00P00o`020?n000<0003o0P00o`02
0000o`D00?l00P3oP0020000o`kooooo0P3oP003003o0080003o103oP0020?l000D0oh000P3o0003
0?n00080o`000P3oP0020?l000L00?l00P3o00000`3oP0000?l0003o0002003o00D0oh000P00o`02
0?n000800?l01@3oP0020?l000@0oh0000<00?l00?n0003oP0000P000?l7003o00@0003o2@3oP000
0`3o0000oh000?n000020000o`@0oh0000<0o`000?n0003oP000103oP0020?l000030?n0003o0000
o`0000L0oh000P3o00040?n000<0o`002@3oP002003o01Sooooo000FooooofH0o`000P3oP00<0?l0
0080oh00503o000>oooooa@0003o1`00o`020000o`030?n00000o`000?l000T00?l00P000?l2003o
00T0003o1`00o`020?n000T0003o00<00?l00000o`000?l00P00o`020000o`<00?l00P3oP004003o
00D0003o0P00o`020000o`80oh001`000?lG003o0080oh000P00o`000`000?l00?l0003o00020?n0
00kooooo=P000?l2003o00`0003o1`00o`020?n000@0003o00<0oh000000o`000?l00P000?l20?n0
0080003o00<0o`000000o`000?l050000?l2003o00<0003o0P00o`020?n000D00?l02`000?l>oooo
o`800?l00`3oP002003o00T0o`001P3oP0000`00o`00oh000?n00002003o0080oh0000<00?l00?n0
003oP00010000?l50?n000@0003o0P3oP0000`00o`00oh000?n000020?l00080oh000`3o00040?n0
0080o`000P00o`000`3oP000o`000?l000020?n000D00?l0103oP0030?l000@0oh000P00o`020?n0
00<0003o0P3oP009003o00@0o`0000<0oh000?l0003o00000P000?l90?n000<0o`000P3oP0020?l0
0080oh000`3o00020?n000800?l06?ooool001KoooooIP3o00020?n000`0o`000P3oP00D0?l000ko
oooo50000?l7003o0080003o00<0oh00003o0000o`002@00o`020000o`800?l02@000?l7003o0080
oh002@000?l00`00o`00003o0000o`02003o0080003o0`00o`020?n000@00?l01@000?l2003o0080
003o0P3oP0070000oaL00?l00P3oP002003o00030000o`00o`000?l00080oh003_oooolf0000o`80
0?l030000?l7003o0080oh0010000?l00`3oP000003o0000o`020000o`80oh000P000?l00`3o0000
003o0000o`0D0000o`800?l00`000?l2003o0080oh001@00o`0;0000o`kooooo0P00o`030?n00080
0?l02@3o00060?n00003003o003oP000oh0000800?l00P3oP0000`00o`00oh000?n000040000o`D0
oh0010000?l20?n00003003o003oP000oh000080o`000P3oP0030?l000@0oh000P3o0002003o0003
0?n0003o0000o`000080oh001@00o`040?n000<0o`00103oP002003o0080oh000`000?l20?n000T0
0?l0103o00000`3oP000o`000?l000020000o`T0oh000`3o00020?n00080o`000P3oP0030?l00080
oh000P00o`0Hooooo`005_oooolf0?l00080oh00>@3o00020?n00180o`0000<0oh000?l0003o0000
0P3o000>ooooo`@0003o00<00?l00000o`000?l01P00o`070000o`800?l000<0003o003o0000o`00
0P00o`020000o`D0oh000P3o0007003o00/0003o1@00o`0F0000o`03003o00000?l0003o0080003o
1000o`000`000?l00?l0003o00070000o`800?l00P000?l7003o0080003o0P00o`050000o`@00?l0
00<0003o003o0000o`001P00o`000`000?l00?l0003o00020000o`kooooo40000?l2003o0200003o
0P3oP00>0000o`@00?l01@000?l40?n000800?l000<0oh00003o0000o`004P000?l2003o00T0003o
0P00o`0<0000o`800?l010000?l00`00o`00oh000?n000020000o`kooooo0P3oP0020?l000030?n0
003o0000o`0000@0oh000P3o00000`000?l0oh000?n000020000o`@0oh000`3o00020000o`D00?l0
1P000?l00`3oP0000?l0003o00040?n000800?l000<0003o003o0000o`00103oP0020000o`L0oh00
1@3o00050?n000800?l0103oP0030?l00080oh000P3o00040?n000<0003o0P3oP004003o00D0oh00
0P3o00020?n000030?l0003oP000oh000080oh000P3o00050?n00080o`000P3oP0000`3o0000oh00
0?n000020?l000800?l00P000?l50?n001Sooooo000Foooooc@0o`000P3oP01?0?l000030?n0003o
0000o`000080o`003_ooool20000o`h00?l00P000?l9003o0080003o0`3oP002003o00@0oh001@00
o`090000o`L00?l00P000?l7003o00h0003o0P00o`0?0000oaX00?l00P3oP002003o0080oh001`00
o`0>oooooa00003o1P00o`0E0000o`T00?l010000?l3003o0080003o1000o`0:0000o`80oh000P3o
0002003o00030?n000000?l0003o0180003o0P00o`0;0000o`03003o00000?l0003o00T0003o0P00
o`070000o`800?l03_ooool40?n000030?l0003oP000oh000080oh000P00o`0;0000o`<0oh000P00
o`030?n000@0003o0P00o`070?n00080o`001@00o`090?n000@0o`000`3oP0020?l000T0oh000P00
0?l70?l000800?l00P3oP0000`000?l0oh000?n000020?n000800?l01@3oP0020?l000D0oh000P3o
00050?n000@00?l010000?l00`00o`00003o0000o`020?n000800?l00P000?l00`3oP0000?l0003o
00020?n001Sooooo000Foooooc@0o`000P3oP01?0?l000030?n0003o0000o`000080o`003_ooool2
0000o`h00?l00P000?l9003o0080003o0`3oP002003o00@0oh001@00o`090000o`L00?l00P000?l7
003o00h0003o0P00o`0?0000oaX00?l00P3oP002003o0080oh001`00o`0>oooooa00003o1P00o`0E
0000o`T00?l010000?l3003o0080003o1000o`0:0000o`80oh000P3o0002003o00030?n000000?l0
003o0180003o0P00o`0;0000o`03003o00000?l0003o00T0003o0P00o`070000o`800?l03_ooool4
0?n000030?l0003oP000oh000080oh000P00o`0;0000o`<0oh000P00o`030?n000@0003o0P00o`07
0?n00080o`001@00o`090?n000@0o`000`3oP0020?l000T0oh000P000?l70?l000800?l00P3oP000
0`000?l0oh000?n000020?n000800?l01@3oP0020?l000D0oh000P3o00050?n000@00?l010000?l0
0`00o`00003o0000o`020?n000800?l00P000?l00`3oP0000?l0003o00020?n001Sooooo000Foooo
ob/0o`000P3oP0070?l00080oh003P3o00040?n000T0o`0000<0oh000?l0003o00006@3o00020?n0
0180o`000P3oP0070?l000kooooo4P00o`0;0000o`<0oh000P00o`020?n000L00?l01@000?l9003o
00@0003o0P00o`020?n000`00?l00P3oP003003o00P0003o1@00o`040000o`T00?l000<0003o003o
0000o`000P000?l;003o00030?n000000?l0003o0080oh001000o`000`3oP0000?l0003o0002003o
00kooooo:`000?l20?n000D00?l03@000?l3003o0080oh000P000?l5003o00@0oh005`000?l4003o
01D0003o0P00o`040000o`03003o00000?l0003o0080003o3_ooool2003o0080oh0000<0o`000?n0
003oP0000P3o00020000o`800?l01`000?l20?l000030?n0003o0000o`0000@00?l01`3oP002003o
00<0oh000P3o00020?n000L00?l010000?l50?n000@0o`0000<0oh000?l0003o0000103o00030?n0
00@0003o0P3o00000`3oP000o`000?l000020?l00080oh000`00o`040?n000800?l01@3oP0020?l0
0080oh000P000?l00`3o0000oh000?n000040?n000030000o`00o`000?l000@00?l00`000?l2003o
0080oh000P00o`030?n000800?l00P3oP00Hooooo`005_ooool[0?l00080oh001`3o00020?n000h0
o`00103oP0090?l000030?n0003o0000o`0001T0o`000P3oP00B0?l00080oh001`3o000>oooooa80
0?l02`000?l30?n000800?l00P3oP007003o00D0003o2@00o`040000o`800?l00P3oP00<003o0080
oh000`00o`080000o`D00?l010000?l9003o00030000o`00o`000?l00080003o2`00o`000`3oP000
003o0000o`020?n000@00?l000<0oh00003o0000o`000P00o`0>ooooob/0003o0P3oP005003o00d0
003o0`00o`020?n00080003o1@00o`040?n001L0003o1000o`0E0000o`800?l010000?l00`00o`00
003o0000o`020000o`kooooo0P00o`020?n000030?l0003oP000oh000080o`000P000?l2003o00L0
003o0P3o00000`3oP000o`000?l00004003o00L0oh000P00o`030?n00080o`000P3oP007003o00@0
003o1@3oP0040?l000030?n0003o0000o`0000@0o`000`3oP0040000o`80o`0000<0oh000?l0003o
00000P3o00020?n000<00?l0103oP002003o00D0oh000P3o00020?n00080003o00<0o`000?n0003o
P000103oP0000`000?l00?l0003o0004003o00<0003o0P00o`020?n000800?l00`3oP002003o0080
oh006?ooool001Kooooo3P3o00020?n000L0o`000P3oP00]0?l00080oh008P3o00020?n001D0o`00
0P3oP0030?l00080oh000P3o000>ooooo`T00?l00P000?l20?n000030000o`00o`000?l000H00?l0
1`000?l50?n000D0003o0P00o`020000o`800?l00`000?lK003o0080oh000P00o`020?n00003003o
00000?l0003o00@00?l00P000?l:003o00H0003o2@00o`030?n000800?l00P3oP0020000o`<0oh00
0P00o`020?n000D0003o0P00o`0>ooooob@0003o0P00o`050000o`80oh0030000?l2003o01T0003o
0P00o`040000o`03003o00000?l0003o00/0003o0P00o`0K0000o`03003o00000?l0003o0080003o
3_ooool50?n000@0o`000P3oP005003o0080003o103oP0000`000?l0oh000?n000020000o`<00?l0
2@3oP0020?l00080oh000P3o00030?n000T00?l00P3oP002003o0080oh000P3o00000`3oP000o`00
0?l000020?l00080oh000`00o`040000o`<0oh000P3o00020?n00080o`000`00o`020?n000800?l0
103o00030?n00080o`000P000?l2003o00`0003o1000o`000`000?l00?l0003o00040?n000<0003o
103oP00Hooooo`005_ooool>0?l00080oh001`3o00020?n002d0o`000P3oP00R0?l00080oh005@3o
00020?n000<0o`000P3oP0020?l000kooooo2@00o`020000o`80oh0000<0003o003o0000o`001P00
o`070000o`D0oh001@000?l2003o0080003o0P00o`030000oa/00?l00P3oP002003o0080oh0000<0
0?l00000o`000?l01000o`020000o`X00?l01P000?l9003o00<0oh000P00o`020?n00080003o0`3o
P002003o0080oh001@000?l2003o00kooooo90000?l2003o00D0003o0P3oP00<0000o`800?l06@00
0?l2003o00@0003o00<00?l00000o`000?l02`000?l2003o01/0003o00<00?l00000o`000?l00P00
0?l>ooooo`D0oh00103o00020?n000D00?l00P000?l40?n000030000o`3oP000oh000080003o0`00
o`090?n00080o`000P3oP0020?l000<0oh002@00o`020?n000800?l00P3oP0020?l000030?n0003o
0000o`000080o`000P3oP003003o00@0003o0`3oP0020?l00080oh000P3o0003003o0080oh000P00
o`040?l000<0oh000P3o00020000o`800?l030000?l4003o00030000o`00o`000?l000@0oh000`00
0?l40?n001Sooooo000Foooood40o`0000<0oh000?l0003o00000P3o00020?n002L0o`000P3oP00@
0?l00080oh001`3o000>ooooo`800?l02@000?l9003o00<0003o1P00o`030?n000800?l00P3oP009
003o00<0003o3@00o`020000o`D00?l01@3oP002003o00L0oh004P00o`060000o`T00?l00`3oP006
003o00D0oh000P3o00020?n000030000o`3oP000oh000080003o3_oooolD0000o`800?l08`000?l9
003o04P0003o3_ooool20?n00080o`001@3oP007003o0080003o2@3oP0020000o`03003o003oP000
oh000080003o103oP0000`3o0000oh000?n000020000o`/0oh000P3o00090?n000030?l0003oP000
oh0000@0o`000`00o`040000o`80o`0000<0oh000?l0003o00000P3oP0020000o`<00?l00P000?l4
003o0080003o00<0oh000000o`000?l00P3o00020?n00080o`0000<0oh00003o0000o`000P000?l3
003o00@0oh001@000?l6003o0080oh0000<00?l00?n0003oP0000P3oP00Hooooo`005_oooom10?l0
00030?n0003o0000o`000080o`000P3oP00W0?l00080oh00403o00020?n000L0o`003_ooool2003o
00T0003o2@00o`030000o`H00?l00`3oP002003o0080oh002@00o`030000o`d00?l00P000?l5003o
00D0oh000P00o`070?n001800?l01P000?l9003o00<0oh001P00o`050?n00080o`000P3oP0000`00
0?l0oh000?n000020000o`kooooo50000?l2003o02<0003o2@00o`180000o`kooooo0P3oP0020?l0
00D0oh001`00o`020000o`T0oh000P000?l00`00o`00oh000?n000020000o`@0oh0000<0o`000?n0
003oP0000P000?l;0?n00080o`002@3oP0000`3o0000oh000?n000040?l000<00?l010000?l20?l0
00030?n0003o0000o`000080oh000P000?l3003o0080003o1000o`020000o`030?n000000?l0003o
0080o`000P3oP0020?l000030?n00000o`000?l00080003o0`00o`040?n000D0003o1P00o`020?n0
0003003o003oP000oh000080oh006?ooool001Kooooo103o00000`3oP000o`000?l0000j0?l00003
0?n0003o0000o`0004H0o`003_ooool50000o`800?l010000?l2003o00030000o`00o`000?l000H0
0?l000<0003o003o0000o`000P00o`020000o`030?n00000o`000?l000@00?l00P3oP0000`00o`00
oh000?n00002003o00T0003o1`00o`020?n000D00?l0103oP0020?l000030?n0003o0000o`000080
o`000P3oP0020?l000<0003o1P00o`030?n000@0003o0`00o`020?n000h00?l00P3oP0040000o`80
0?l01@3oP0020?l000<00?l00P3oP002003o00kooooo>@000?l8003o04T0003o3_ooool20000o`80
oh0000<0003o0?n0003oP0000P3o0004003o00030?n00000o`000?l000800?l0103oP0030000o`@0
oh0000<00?l00?n0003oP00010000?l50?n00080003o103oP0000`00o`00o`000?l000040?n00080
o`003P3oP0020?l000030?n0003o0000o`0000800?l00P3oP002003o00D0oh000P00o`020?n00003
0000o`3oP000oh0000L00?l010000?l20?n00080o`0000<0003o0?n0003oP0000P3o00020?n00003
0?l00000o`000?l00080003o1000o`000`3oP0000?l0003o00020?n00080003o0P3oP0030000o`80
oh006?ooool001Kooooo?@3o00020?n00080o`0000<0oh000?l0003o00005P3o00000`3oP000o`00
0?l000090?l00080oh00103o00000`3oP000o`000?l0000K0?l000kooooo1@000?l2003o0080003o
0P00o`030000o`800?l00P000?l2003o00<0003o0P00o`0>0000o`@00?l02@000?l2003o00D0003o
1P00o`050?n000<0o`00103oP0020000o`80o`0000<0003o003o0000o`000P3oP0040000o`030?n0
0000o`000?l000H00?l000<0oh00003o0000o`001P00o`000`3oP0000?l0003o00050000o`80oh00
1P000?l30?n00080003o103oP005003o00kooooo1000o`0^0000o`800?l01`000?l6003o00X0003o
1000o`0I0000o`800?l01`000?l9003o0100003o3_ooool2003o00D0oh000P3o00020?n00080o`00
1@00o`0;0?n000030000o`3oP000oh0000@00?l01@3oP0020000o`80oh000`3o00020?n00080o`00
0P00o`030?n00080o`00103oP0020000o`<0oh000P3o00070?n000@00?l00`3oP002003o0080o`00
1`00o`040000o`D0oh000P3o00030?n000800?l02@3oP002003o0080o`000`00o`020?n000D00?l0
0P3oP002003o01Sooooo000Fooooocd0o`000P3oP0020?l000030?n0003o0000o`0001H0o`0000<0
oh000?l0003o00002@3o00020?n000@0o`0000<0oh000?l0003o00006`3o000>ooooo`D0003o0P00
o`020000o`800?l00`000?l2003o0080003o0P00o`030000o`800?l03P000?l4003o00T0003o0P00
o`050000o`H00?l01@3oP0030?l000@0oh000P000?l20?l000030000o`00o`000?l00080oh001000
0?l00`3oP0000?l0003o0006003o00030?n00000o`000?l000H00?l000<0oh00003o0000o`001@00
0?l20?n000H0003o0`3oP0020000o`@0oh001@00o`0>ooooo`@00?l0;P000?l2003o00L0003o1P00
o`0:0000o`@00?l06@000?l2003o00L0003o2@00o`0@0000o`kooooo0P00o`050?n00080o`000P3o
P0020?l000D00?l02`3oP0000`000?l0oh000?n00004003o00D0oh000P000?l20?n000<0o`000P3o
P0020?l000800?l00`3oP0020?l000@0oh000P000?l30?n00080o`001`3oP004003o00<0oh000P00
o`020?l000L00?l010000?l50?n00080o`000`3oP002003o00T0oh000P00o`020?l000<00?l00P3o
P005003o0080oh000P00o`0Hooooo`005_ooool50?l00080oh00?`3o00020?n000<0o`000P3oP00I
0?l00080oh003P3o00020?n000d0o`0000<0oh000?l0003o00000P3o000>ooooo`80003o0P00o`00
0`000?l00?l0003o0002003o00D0003o0P00o`070000o`@00?l01@000?l2003o0080003o0P3oP003
0000o`800?l02`000?l9003o00T0oh0000<0o`000000o`000?l01P3oP0000`00o`00003o0000o`06
0?n000030?l000000?l0003o00H0003o00<0oh00003o0000o`001000o`020000o`030?n00000o`00
0?l000d00?l000<0oh000000o`000?l0103oP0050000o`800?l03_ooool20000o`800?l070000?l4
003o00<0003o0P00o`0@0000o`80oh0050000?l2003o00L0003o0P00o`0E0000o`800?l01@000?l4
003o00L0003o1000o`030000o`800?l03_ooool2003o00<0oh00103o00050?n00080003o1`3oP002
0?l000D0oh000P00o`040?n000L00?l0103o00030?n00080003o1@3oP0020?l000@0oh000`000?l2
0?n00080o`002@3oP002003o00D0oh000P3o00020?n00003003o003oP000oh0000@00?l00P3oP003
003o0080003o0P3oP0020000o`<0o`000P3oP0020?l000D0oh000P000?l30?n000800?l00P3oP004
0000o`D0oh006?ooool001Kooooo1@3o00020?n003l0o`000P3oP0030?l00080oh006@3o00020?n0
00h0o`000P3oP00=0?l000030?n0003o0000o`000080o`003_ooool20000o`800?l000<0003o003o
0000o`000P00o`050000o`800?l01`000?l4003o00D0003o0P00o`020000o`80oh000`000?l2003o
00/0003o2@00o`090?n000030?l000000?l0003o00H0oh0000<00?l00000o`000?l01P3oP0000`3o
0000003o0000o`060000o`030?n00000o`000?l000@00?l00P000?l00`3oP0000?l0003o000=003o
00030?n000000?l0003o00@0oh001@000?l2003o00kooooo0P000?l2003o01`0003o1000o`030000
o`800?l040000?l20?n001@0003o0P00o`070000o`800?l05@000?l2003o00D0003o1000o`070000
o`@00?l00`000?l2003o00kooooo0P00o`030?n000@0o`001@3oP0020000o`L0oh000P3o00050?n0
00800?l0103oP007003o00@0o`000`3oP0020000o`D0oh000P3o00040?n000<0003o0P3oP0020?l0
00T0oh000P00o`050?n00080o`000P3oP0000`00o`00oh000?n00004003o0080oh000`00o`020000
o`80oh000P000?l30?l00080oh000P3o00050?n00080003o0`3oP002003o0080oh0010000?l50?n0
01Sooooo000Fooooo`D0o`000P3oP00@0?l00080oh00BP3o00000`3oP000o`000?l0000K0?l00080
oh001`3o000>ooooo`D0003o1000o`020000o`D00?l01`000?l=003o00L0003o1000o`050000o`T0
0?l01`000?l40?n000030?l0003oP000oh000080oh000P000?l30?n00080003o1`3oP008003o0003
0?n000000?l0003o0080003o0P00o`020000o`h00?l00P000?l00`3oP000003o0000o`020000o`80
oh000P00o`000`000?l00?l0003o0002003o00kooooo1000o`070000o`800?l06P000?l2003o00L0
003o0P00o`0@0000o`800?l02@000?l4003o00030000o`00o`000?l002T0003o3@00o`0>ooooo`80
0?l00`3oP0060?l00080oh0000<0003o003o0000o`001P3oP0000`3o0000oh000?n00002003o00L0
oh001@00o`020000o`800?l00P3oP0020?l000030?n0003o0000o`0000800?l0103oP0000`3o0000
0?l0003o00020?n000800?l00P3oP0000`00o`00oh000?n000020?l00080oh0000<0o`000?n0003o
P000103oP002003o00<0oh000P3o000B0?n00080o`000P3oP00:0000o`80oh000P3o00020000o`03
0?n00000o`000?l00080oh001000o`000`3oP0000?l0003o00020?n001Sooooo000Fooooo`D0o`00
0P3oP00@0?l00080oh00BP3o00000`3oP000o`000?l0000K0?l00080oh001`3o000>ooooo`D0003o
1000o`020000o`D00?l01`000?l=003o00L0003o1000o`050000o`T00?l01`000?l40?n000030?l0
003oP000oh000080oh000P000?l30?n00080003o1`3oP008003o00030?n000000?l0003o0080003o
0P00o`020000o`h00?l00P000?l00`3oP000003o0000o`020000o`80oh000P00o`000`000?l00?l0
003o0002003o00kooooo1000o`070000o`800?l06P000?l2003o00L0003o0P00o`0@0000o`800?l0
2@000?l4003o00030000o`00o`000?l002T0003o3@00o`0>ooooo`800?l00`3oP0060?l00080oh00
00<0003o003o0000o`001P3oP0000`3o0000oh000?n00002003o00L0oh001@00o`020000o`800?l0
0P3oP0020?l000030?n0003o0000o`0000800?l0103oP0000`3o00000?l0003o00020?n000800?l0
0P3oP0000`00o`00oh000?n000020?l00080oh0000<0o`000?n0003oP000103oP002003o00<0oh00
0P3o000B0?n00080o`000P3oP00:0000o`80oh000P3o00020000o`030?n00000o`000?l00080oh00
1000o`000`3oP0000?l0003o00020?n001Sooooo000Fooooob00o`000P3oP00]0?l00080oh004P3o
00000`3oP000o`000?l0000K0?l00080oh001`3o000>ooooo`/0003o1@00o`090000o`@00?l000<0
oh00003o0000o`001000o`020000o`03003o00000?l0003o0080003o3P00o`020?n000H0003o1@00
o`020000o`D0oh000P3o00030?n000800?l0103oP002003o00030?n00000o`000?l000T00?l02`00
0?l;003o00<0oh000P00o`020?n000L00?l03_ooool2003o01@0003o00<00?l00000o`000?l08P00
0?l2003o00`0003o0P00o`0M0000o`800?l04P000?l7003o0080oh000`000?l2003o00kooooo103o
P0000`3o0000oh000?n000040?l000<0003o0P3oP002003o00@0o`000`3oP0020?l00080oh0000<0
o`000000o`000?l00P3oP004003o00030?n000000?l0003o0080003o0P3oP0020?l000030?n0003o
0000o`0000L0oh000P3o00070?n000800?l00P3o00050?n00080003o0P3oP0020?l000<0oh000P3o
00020?n000800?l000<0oh000000o`000?l02@3oP002003o00@0003o00<0oh00003o0000o`001`00
0?l60?n00003003o00000?l0003o00H0oh0000<0o`00003o0000o`000P3oP00Hooooo`005_oooolP
0?l00080oh00;@3o00020?n00180o`0000<0oh000?l0003o00006`3o00020?n000L0o`003_ooool;
0000o`D00?l02@000?l4003o00030?n00000o`000?l000@00?l00P000?l00`00o`00003o0000o`02
0000o`h00?l00P3oP0060000o`D00?l00P000?l50?n00080o`000`3oP002003o00@0oh000P00o`00
0`3oP0000?l0003o0009003o00/0003o2`00o`030?n000800?l00P3oP007003o00kooooo0P00o`0D
0000o`03003o00000?l0003o0280003o0P00o`0<0000o`800?l07@000?l2003o0180003o1`00o`02
0?n000<0003o0P00o`0>ooooo`@0oh0000<0o`000?n0003oP000103o00030000o`80oh000P00o`04
0?l000<0oh000P3o00020?n000030?l000000?l0003o0080oh001000o`000`3oP000003o0000o`02
0000o`80oh000P3o00000`3oP000o`000?l000070?n00080o`001`3oP002003o0080o`001@3oP002
0000o`80oh000P3o00030?n00080o`000P3oP002003o00030?n000000?l0003o00T0oh000P00o`04
0000o`030?n00000o`000?l000L0003o1P3oP0000`00o`00003o0000o`060?n000030?l00000o`00
0?l00080oh006?ooool001Kooooo403o00020?n000h0o`000P3oP0050?l00080oh00H@3o000>oooo
o`/0003o1@00o`0;0000o`800?l000<0003o003o0000o`000P000?l5003o00@0003o3P00o`090000
o`80oh001000o`070?n00080o`0000<0oh000000o`000?l00P000?l20?n000L0003o4P00o`020?n0
00<0003o1`00o`020000o`@0oh000P00o`000`3oP0000?l0003o0002003o00kooooo0P00o`020000
o`03003o00000?l0003o00H0003o00<0oh000000o`000?l010000?l3003o0080003o0P00o`0[0000
o`D00?l00P000?l4003o00T0003o00<00?l00000o`000?l02@000?l2003o01D0003o0P3oP0020000
o`@0oh000`000?l20?n000kooooo0P00o`030?n00080003o0P3oP0020000o`<0oh000P3o00060?n0
00<00?l010000?l3003o0080oh000P3o00030000o`@00?l0103oP0000`3o0000oh000?n000040?n0
0080o`001@3oP0020000o`800?l000<0003o003o0000o`001@3oP0020?l000H0oh0000<0o`000?n0
003oP0000P3oP002003o00L0003o103oP0000`3o0000oh000?n000020?n00080o`000`000?l2003o
0080003o1@00o`040?n000D0003o1`3oP0040000oaSooooo000FooooobL0o`00103oP00I0?l00080
oh007P3o00020?n00080o`000P3oP00>0?l00080oh00403o000>ooooo`d0003o0`00o`0=0000o`03
003o00000?l0003o00L00?l010000?l4003o00030000o`00o`000?l000800?l01`000?l6003o00<0
oh000P000?l50?n000@0003o0P3oP003003o00H0003o0`00o`020000o`@00?l000<0003o003o0000
o`001P00o`000`3oP0000?l0003o000=003o00030000o`3oP000oh000080oh001@000?l4003o00ko
oooo3@000?l00`00o`00003o0000o`040000o`800?l05`000?l2003o01T0003o0`00o`0D0000o`@0
0?l000<0003o0?n0003oP0001`000?l20?n000h0003o1P3oP002003o00030000o`00o`000?l00080
0?l03_ooool70?n000@00?l00P3o00000`00o`00oh000?n00002003o0080oh000P000?l00`3oP000
0?l0003o0004003o00X0oh000P3o00060?n000030?l0003oP000oh0000@0o`000P3oP0000`3o0000
0?l0003o00020000o`80oh000P000?l00`00o`00003o0000o`020?n00080o`001@000?l50?n00080
0?l00P3oP0070000o`@0oh000`3o00020?n000800?l00P3o00020?n000030?l0003oP000oh0000@0
003o00<00?l00000o`000?l010000?l2003o00030000o`00o`000?l000@0oh000P3o00000`3oP000
0?l0003o0002003o01Sooooo000FooooobL0o`00103oP00I0?l00080oh007P3o00020?n00080o`00
0P3oP00>0?l00080oh00403o000>ooooo`d0003o0`00o`0=0000o`03003o00000?l0003o00L00?l0
10000?l4003o00030000o`00o`000?l000800?l01`000?l6003o00<0oh000P000?l50?n000@0003o
0P3oP003003o00H0003o0`00o`020000o`@00?l000<0003o003o0000o`001P00o`000`3oP0000?l0
003o000=003o00030000o`3oP000oh000080oh001@000?l4003o00kooooo3@000?l00`00o`00003o
0000o`040000o`800?l05`000?l2003o01T0003o0`00o`0D0000o`@00?l000<0003o0?n0003oP000
1`000?l20?n000h0003o1P3oP002003o00030000o`00o`000?l000800?l03_ooool70?n000@00?l0
0P3o00000`00o`00oh000?n00002003o0080oh000P000?l00`3oP0000?l0003o0004003o00X0oh00
0P3o00060?n000030?l0003oP000oh0000@0o`000P3oP0000`3o00000?l0003o00020000o`80oh00
0P000?l00`00o`00003o0000o`020?n00080o`001@000?l50?n000800?l00P3oP0070000o`@0oh00
0`3o00020?n000800?l00P3o00020?n000030?l0003oP000oh0000@0003o00<00?l00000o`000?l0
10000?l2003o00030000o`00o`000?l000@0oh000P3o00000`3oP0000?l0003o0002003o01Sooooo
000Fooooob80o`000P3oP00G0?l00080oh000P3o00030?n002X0o`0000<0oh000?l0003o00001`3o
00020?n00180o`003_ooool4003o01T0003o2@00o`0<0000o`800?l01`000?l4003o0080o`0000<0
003o0?n0003oP0001`3oP0040000o`80oh000`00o`020000o`D0oh000P3o00020?n000@00?l00`3o
P006003o00030000o`00o`000?l000D00?l00P3oP007003o0080003o0P00o`020000o`80oh001@00
0?l>oooooaL0003o1000o`0;0000o`03003o00000?l0003o00L0003o0P00o`090000o`800?l03P00
0?l20?n000T0003o0P00o`020?n00003003o00000?l0003o0080003o1000o`090000o`P00?l01000
0?l2003o00D0003o0P3oP0020000o`80oh000`00o`020000o`kooooo0P000?l30?n00080o`00103o
P0070?l00080oh000P000?l00`3oP000003o0000o`07003o00H0oh0000<0o`000?n0003oP0000P3o
P0020?l00080oh0000<0o`000?n0003oP0000P3oP0050?l00080oh001P00o`000`3oP0000?l0003o
00040?n00003003o003o0000o`0000H0003o0`3oP0020000o`800?l00`3oP002003o00@0oh000P00
o`000`3oP000o`000?l000060?n000030?l0003oP000oh000080oh001@00o`020?n000D0003o0P00
o`020?n000D00?l0103oP00Hooooo`005_oooolR0?l00080oh005`3o00020?n00080o`000`3oP00Z
0?l000030?n0003o0000o`0000L0o`000P3oP00B0?l000kooooo1000o`0I0000o`T00?l030000?l2
003o00L0003o1000o`020?l000030000o`3oP000oh0000L0oh0010000?l20?n000<00?l00P000?l5
0?n00080o`000P3oP004003o00<0oh001P00o`000`000?l00?l0003o0005003o0080oh001`00o`02
0000o`800?l00P000?l20?n000D0003o3_oooolG0000o`@00?l02`000?l00`00o`00003o0000o`07
0000o`800?l02@000?l2003o00h0003o0P3oP0090000o`800?l00P3oP0000`00o`00003o0000o`02
0000o`@00?l02@000?l8003o00@0003o0P00o`050000o`80oh000P000?l20?n000<00?l00P000?l>
ooooo`80003o0`3oP0020?l000@0oh001`3o00020?n00080003o00<0oh000000o`000?l01`00o`06
0?n000030?l0003oP000oh000080oh000P3o00020?n000030?l0003oP000oh000080oh001@3o0002
0?n000H00?l000<0oh00003o0000o`00103oP0000`00o`00o`000?l000060000o`<0oh000P000?l2
003o00<0oh000P00o`040?n000800?l000<0oh000?l0003o00001P3oP0000`3o0000oh000?n00002
0?n000D00?l00P3oP0050000o`800?l00P3oP005003o00@0oh006?ooool001Kooooo0P3oP00R0?l0
0080oh00803o00020?n002`0o`000P3oP0020?l00080oh001@3o00020?n000T0o`003_ooool2003o
00/0003o0`00o`0D0000o`<00?l02@000?l2003o00H0003o00<00?l00?n0003oP0000P000?l40?n0
00030000o`3oP000oh000080003o2@3oP0070000o`D0oh000P3o0004003o0080oh002P000?l2003o
0080003o0P00o`000`000?l0oh000?n00002003o00h0003o0P00o`020?n000kooooo6@000?l7003o
02H0003o0P3oP0050000o`D00?l0103oP002003o00<0oh0010000?l2003o00T0003o1`00o`050000
o`H00?l000<0003o0?n0003oP0000P3oP002003o00L0003o3_ooool50000o`80oh000P000?l90?n0
0080003o0P3oP0000`00o`00003o0000o`020000o`800?l000<0003o003o0000o`00103oP0030?l0
0080oh000P00o`0;0?n000<0o`000P3oP002003o00D0oh00103o00020?n000030?l0003oP000oh00
00@0oh001@000?l9003o00@0oh001@000?l2003o00D0oh000P3o00020?n000D00?l010000?l70?n0
00D0003o0P3oP002003o01Sooooo000Fooooo`80oh008P3o00020?n00200o`000P3oP00/0?l00080
oh000P3o00020?n000D0o`000P3oP0090?l000kooooo0P00o`0;0000o`<00?l050000?l3003o00T0
003o0P00o`060000o`03003o003oP000oh000080003o103oP0000`000?l0oh000?n000020000o`T0
oh001`000?l50?n00080o`001000o`020?n000X0003o0P00o`020000o`800?l000<0003o0?n0003o
P0000P00o`0>0000o`800?l00P3oP00>oooooaT0003o1`00o`0V0000o`80oh001@000?l5003o00@0
oh000P00o`030?n000@0003o0P00o`090000o`L00?l01@000?l6003o00030000o`3oP000oh000080
oh000P00o`070000o`kooooo1@000?l20?n00080003o2@3oP0020000o`80oh0000<00?l00000o`00
0?l00P000?l2003o00030000o`00o`000?l000@0oh000`3o00020?n000800?l02`3oP0030?l00080
oh000P00o`050?n000@0o`000P3oP0000`3o0000oh000?n000040?n000D0003o2@00o`040?n000D0
003o0P00o`050?n00080o`000P3oP005003o00@0003o1`3oP0050000o`80oh000P00o`0Hooooo`00
5_ooool20?l00080oh00L03o00020?n000/0o`000P3oP0070?l000kooooo1000o`090000o`03003o
00000?l0003o00h0003o1000o`020000o`800?l02P000?l9003o00H0oh002@000?l00`00o`00oh00
0?n000020?n000@00?l000<0003o003o0000o`000P000?l40?n000030000o`3oP000oh0000L00?l0
3@000?l2003o00030000o`00o`000?l000H00?l000<0003o003o0000o`000P00o`040000o`D00?l0
3_ooool20000o`<00?l050000?l2003o0080003o00<00?l00000o`000?l01`000?l6003o00D0003o
0P00o`0B0000o`L00?l0103oP0000`00o`00oh000?n00004003o00D0003o0P3oP00B0000o`80oh00
00<0003o003o0000o`0040000?l2003o0080003o3_ooool2003o00/0003o2@3oP0000`00o`00003o
0000o`05003o0080003o0P3oP004003o00030?n00000o`000?l000L0oh000P3o00020?n00080o`00
0P3oP0000`3o0000oh000?n000090?n00080o`000`3oP0020?l000@0003o0P00o`000`3oP0000?l0
003o00020000o`80oh000P00o`000`3oP0000?l0003o00040?n000800?l00`3oP0020000o`80oh00
0P3o00000`000?l0oh000?n00002003o0080oh000`00o`020000o`@0oh002@000?l50?n001Sooooo
000FooooobL0o`000P3oP0070?l00080oh002@3o00020?n004H0o`000`3oP0040?l000kooooo0P00
o`0;0000o`03003o00000?l0003o00h0003o2000o`0:0000o`@00?l00P3oP003003o01@0003o0P3o
P003003o00@0003o103oP0000`3o0000oh000?n00009003o00T0003o0P00o`030000o`@00?l01000
0?l00`3oP000003o0000o`020000o`80oh000`00o`040000o`kooooo1@00o`0;0000o`800?l04000
0?l2003o00D0003o1000o`020?n000D0003o0P00o`070000o`800?l02@000?l00`00o`00oh000?n0
00020000o`@0oh000`00o`0M0000o`800?l000<0003o0?n0003oP0002`000?l4003o00D0003o3_oo
ool4003o00030000o`3oP000oh0000@0003o2@3oP0020?l000030?n00000o`000?l000@00?l02@3o
P0000`3o0000oh000?n0000;0?n000@0003o00<0oh00003o0000o`001000o`030?n000H0o`001`3o
P003003o0080oh001000o`0;0000o`<00?l0103oP0030?l00080oh000P00o`020?n00003003o0000
0?l0003o00@0003o0`00o`040000o`@00?l01@3oP00Hooooo`005_oooolW0?l00080oh001`3o0002
0?n000T0o`000P3oP0160?l000<0oh00103o000>ooooo`800?l02`000?l00`00o`00003o0000o`0>
0000o`P00?l02P000?l4003o0080oh000`00o`0D0000o`80oh000`00o`040000o`@0oh0000<0o`00
0?n0003oP0002@00o`090000o`800?l00`000?l4003o00@0003o00<0oh000000o`000?l00P000?l2
0?n000<00?l010000?l>ooooo`D00?l02`000?l2003o0100003o0P00o`050000o`@00?l00P3oP005
0000o`800?l01`000?l2003o00T0003o00<00?l00?n0003oP0000P000?l40?n000<00?l07@000?l2
003o00030000o`3oP000oh0000/0003o1000o`050000o`kooooo1000o`000`000?l0oh000?n00004
0000o`T0oh000P3o00000`3oP0000?l0003o0004003o00T0oh0000<0o`000?n0003oP0002`3oP004
0000o`030?n00000o`000?l000@00?l00`3oP0060?l000L0oh000`00o`020?n000@00?l02`000?l3
003o00@0oh000`3o00020?n000800?l00P3oP0000`00o`00003o0000o`040000o`<00?l010000?l4
003o00D0oh006?ooool001Kooooo503o00020?n001X0o`000P3oP0070?l00080oh007@3o00020?n0
00T0o`0000<0oh000?l0003o0000903o000>ooooo`D00?l010000?l2003o0080003o1`00o`0:0000
o`800?l010000?l2003o00X0003o0P00o`020000o`D00?l00P3oP0020000o`80oh000`000?l6003o
00030000o`3oP000oh000080oh000P000?l20?n000<00?l00P000?l2003o0080003o4P00o`000`00
0?l00?l0003o00050000o`800?l010000?l2003o00030?n000000?l0003o00H0003o00<00?l00000
o`000?l00P000?l>ooooo`800?l04P000?l7003o00<0003o0P00o`0;0000o`@00?l000<0003o003o
0000o`000P000?l4003o00030000o`00o`000?l000d0003o00<00?l00?n0003oP0000P000?l2003o
0080003o1@00o`040000o`<00?l04P000?l5003o0080003o1000o`020?n000L00?l00P000?l00`00
o`00003o0000o`020000o`kooooo0P3oP003003o00H0oh000`00o`020000o`T0oh000P000?l30?n0
00800?l04P3oP002003o0080003o0P3oP0000`000?l0oh000?n00004003o0080oh000`000?l20?n0
00<0o`001P3oP002003o00D0oh003@00o`000`000?l00?l0003o00040?n000D0o`00103oP0000`00
o`00oh000?n00002003o00L0003o1P3oP0000`3o0000oh000?n00002003o01Sooooo000Foooooa@0
o`000P3oP00J0?l00080oh001`3o00020?n001d0o`000P3oP0090?l000030?n0003o0000o`0002@0
o`003_ooool5003o00@0003o0P00o`020000o`L00?l02P000?l2003o00@0003o0P00o`0:0000o`80
0?l00P000?l5003o0080oh000P000?l20?n000<0003o1P00o`000`000?l0oh000?n000020?n00080
003o0P3oP003003o0080003o0P00o`020000oa800?l000<0003o003o0000o`001@000?l2003o00@0
003o0P00o`000`3oP000003o0000o`060000o`03003o00000?l0003o0080003o3_ooool2003o0180
003o1`00o`030000o`800?l02`000?l4003o00030000o`00o`000?l00080003o1000o`000`000?l0
0?l0003o000=0000o`03003o003oP000oh000080003o0P00o`020000o`D00?l010000?l3003o0180
003o1@00o`020000o`@00?l00P3oP007003o0080003o00<00?l00000o`000?l00P000?l>ooooo`80
oh000`00o`060?n000<00?l00P000?l90?n00080003o0`3oP002003o0180oh000P00o`020000o`80
oh0000<0003o0?n0003oP0001000o`020?n000<0003o0P3oP0030?l000H0oh000P00o`050?n000d0
0?l000<0003o003o0000o`00103oP0050?l000@0oh0000<00?l00?n0003oP0000P00o`070000o`H0
oh0000<0o`000?n0003oP0000P00o`0Hooooo`005_ooool20?n00200o`000P3oP00<0?l00080oh00
4P3o00020?n00280o`000P3oP00P0?l000kooooo1@00o`040000o`T00?l030000?l4003o0180003o
0P00o`020000o`L0oh002@000?l50?n00080003o1@3oP002003o00@0oh000`00o`040000o`L00?l0
0P000?l2003o00030000o`00o`000?l000800?l01`000?l7003o0080oh002@000?l>ooooo`80003o
1`00o`040000o`03003o00000?l0003o00@0003o3000o`0?0000o`L00?l04P000?l00`3oP000003o
0000o`060000o`03003o00000?l0003o01d0003o0`00o`020000o`/00?l02@000?l>ooooo`d0oh00
0`000?l40?n00080o`0000<0oh00003o0000o`000P00o`0E0?n00080003o0P3oP0020000o`<0oh00
0P3o00060?n000P0003o0P3o00040?n000800?l000<0o`000?n0003oP0000P3oP005003o0080oh00
1`00o`060?n000L0o`001@3oP002003o0080003o1@00o`060?n000<0o`000P00o`0Hooooo`005_oo
ool20?n00200o`000P3oP00<0?l00080oh004P3o00020?n00280o`000P3oP00P0?l000kooooo1@00
o`040000o`T00?l030000?l4003o0180003o0P00o`020000o`L0oh002@000?l50?n00080003o1@3o
P002003o00@0oh000`00o`040000o`L00?l00P000?l2003o00030000o`00o`000?l000800?l01`00
0?l7003o0080oh002@000?l>ooooo`80003o1`00o`040000o`03003o00000?l0003o00@0003o3000
o`0?0000o`L00?l04P000?l00`3oP000003o0000o`060000o`03003o00000?l0003o01d0003o0`00
o`020000o`/00?l02@000?l>ooooo`d0oh000`000?l40?n00080o`0000<0oh00003o0000o`000P00
o`0E0?n00080003o0P3oP0020000o`<0oh000P3o00060?n000P0003o0P3o00040?n000800?l000<0
o`000?n0003oP0000P3oP005003o0080oh001`00o`060?n000L0o`001@3oP002003o0080003o1@00
o`060?n000<0o`000P00o`0Hooooo`005_ooool20?n006@0o`000P3oP00;0?l000030?n0003o0000
o`0001@0o`003_ooool20000o`800?l000<0003o003o0000o`000P000?l5003o00T0003o1P00o`00
0`3oP000003o0000o`040000o`800?l03P000?l4003o00T0oh0000<0o`00003o0000o`001@00o`09
0?n000@0003o0P3oP0020?l000030?n000000?l0003o0100003o0P00o`0=0000o`T00?l000<0003o
003o0000o`000P00o`0>ooooo`80003o0P00o`0B0000o`X00?l03@000?l2003o00L0003o0P00o`07
0000o`80oh0000<0003o003o0000o`0040000?l2003o0200003o1000o`0;0000o`03003o00000?l0
003o0080003o3_ooool40?n00003003o003oP000oh000080oh000P3o00020?n00003003o00000?l0
003o0080oh000P3o00020?n000030?l000000?l0003o00D0oh000P00o`060?n000030?l00000o`00
0?l000L0003o103oP002003o00<0oh000P3o00090?n00080o`000`3oP0020?l000T0oh0010000?l2
0?n00003003o003oP000oh0000800?l00P3oP003003o00H0oh000P3o000:0?n000H0003o1@3oP005
0?l00080oh000P00o`0Hooooo`005_ooool20?n006@0o`000P3oP00;0?l000030?n0003o0000o`00
01@0o`003_ooool20000o`800?l000<0003o003o0000o`000P000?l5003o00T0003o1P00o`000`3o
P000003o0000o`040000o`800?l03P000?l4003o00T0oh0000<0o`00003o0000o`001@00o`090?n0
00@0003o0P3oP0020?l000030?n000000?l0003o0100003o0P00o`0=0000o`T00?l000<0003o003o
0000o`000P00o`0>ooooo`80003o0P00o`0B0000o`X00?l03@000?l2003o00L0003o0P00o`070000
o`80oh0000<0003o003o0000o`0040000?l2003o0200003o1000o`0;0000o`03003o00000?l0003o
0080003o3_ooool40?n00003003o003oP000oh000080oh000P3o00020?n00003003o00000?l0003o
0080oh000P3o00020?n000030?l000000?l0003o00D0oh000P00o`060?n000030?l00000o`000?l0
00L0003o103oP002003o00<0oh000P3o00090?n00080o`000`3oP0020?l000T0oh0010000?l20?n0
0003003o003oP000oh0000800?l00P3oP003003o00H0oh000P3o000:0?n000H0003o1@3oP0050?l0
0080oh000P00o`0Hooooo`005_oooolM0?l000030?n0003o0000o`0004@0o`000P3oP00D0?l00080
oh001@3o00020?n000<0o`000P3oP0020?l000kooooo10000?l:003o00T0003o3@00o`050000o`80
0?l02@000?l2003o00<0003o103oP0020000o`80oh000`000?l20?l000L0oh001`000?l6003o0003
0?n00000o`000?l000/00?l01@000?l2003o00@0003o00<00?l00000o`000?l01`00o`020?n000@0
0?l00P000?l5003o00kooooo0P00o`0G0000o`L00?l03@000?l2003o00030000o`00o`000?l000L0
003o0P00o`070000o`800?l03P000?l2003o02@0003o0P00o`050000o`800?l01@000?l2003o0080
003o3_ooool40?l000<0oh000P3o00020?n000D0003o103oP0020?l000030?n00000o`000?l000@0
oh001@00o`090?n000@00?l01@3oP002003o0080oh0000<00?l00?n0003oP0001P3o00030?n00080
0?l02`3oP0030?l000@0oh000`3o00020?n000@0o`000P00o`000`000?l0oh000?n000020?n00080
o`000P3oP0070?l000<0oh001P00o`070?n000<0o`000P3oP0020000oaSooooo000Fooooo`/0o`00
0P3oP01i0?l00080oh000P3o000>ooooo`@00?l000<0003o003o0000o`000P000?l4003o00X0003o
1P00o`000`3oP0000?l0003o0002003o0080003o0P00o`030000o`800?l02`000?l3003o00@0oh00
1@000?l60?n000030?l00000o`000?l00080oh000P3o00020?n00003003o00000?l0003o00T0003o
3@00o`050000o`/00?l00P000?l9003o00<0003o0P00o`0>oooooaT0003o0P00o`0B0000o`800?l0
30000?l4003o00L0003o0P00o`030000o`800?l00P000?l2003o00<0003o0P00o`0`0000o`@00?l0
3_ooool20?n00080o`001@3oP0050?l00080oh000P000?l2003o00D0003o103oP0000`00o`00oh00
0?n000020000o`T0oh000P00o`020?l00003003o00000?l0003o0080oh000P000?l20?n000<0003o
0P3oP002003o00<0oh000P3o00020000o`<0oh0010000?l20?n000800?l0403oP002003o00D0oh00
0P3o00070?n000<0o`000P00o`020?n00080003o1@3oP0020?l000D0oh000P000?l2003o01Sooooo
000Fooooo`/0o`000P3oP01i0?l00080oh000P3o000>ooooo`@00?l000<0003o003o0000o`000P00
0?l4003o00X0003o1P00o`000`3oP0000?l0003o0002003o0080003o0P00o`030000o`800?l02`00
0?l3003o00@0oh001@000?l60?n000030?l00000o`000?l00080oh000P3o00020?n00003003o0000
0?l0003o00T0003o3@00o`050000o`/00?l00P000?l9003o00<0003o0P00o`0>oooooaT0003o0P00
o`0B0000o`800?l030000?l4003o00L0003o0P00o`030000o`800?l00P000?l2003o00<0003o0P00
o`0`0000o`@00?l03_ooool20?n00080o`001@3oP0050?l00080oh000P000?l2003o00D0003o103o
P0000`00o`00oh000?n000020000o`T0oh000P00o`020?l00003003o00000?l0003o0080oh000P00
0?l20?n000<0003o0P3oP002003o00<0oh000P3o00020000o`<0oh0010000?l20?n000800?l0403o
P002003o00D0oh000P3o00070?n000<0o`000P00o`020?n00080003o1@3oP0020?l000D0oh000P00
0?l2003o01Sooooo000Foooooa@0o`000P3oP0000`3o0000oh000?n0000=0?l000030?n0003o0000
o`0000H0o`0000<0oh000?l0003o00001P3o00030?n00200o`000P3oP0070?l000@0oh00503o0000
0`3oP000o`000?l000020?l00080oh001`3o000>ooooo`@0003o1`00o`0C0000o`800?l050000?l5
003o0080oh002@000?l40?n000030000o`3oP000oh0000@0oh001@000?l2003o0080oh000P00o`00
0`3oP0000?l0003o0009003o0080oh000P00o`070000o`L00?l010000?l00`00o`00003o0000o`0;
0000o`kooooo?@000?l2003o01`0003o0P00o`0F0000o`03003o00000?l0003o00d0003o0P00o`00
0`000?l00?l0003o0002003o00kooooo0P3oP0020?l000030000o`00o`000?l000@0oh000P3o0000
0`3oP0000?l0003o00040000o`80oh000`000?l40?n000030?l0003oP000oh0000800?l0103oP000
0`000?l0oh000?n000060?n000030000o`00o`000?l000H0003o00<0oh000000o`000?l00P3oP002
0?l000D0oh000P000?l2003o00<0003o0P3oP0050?l000P0oh0000<0o`000?n0003oP0000P3oP002
0?l000<00?l0103oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o0002
003o0080oh0000<0o`000?n0003oP0000P3o00020?n000800?l00`3oP002003o01Sooooo000Foooo
oa@0o`000P3oP0000`3o0000oh000?n0000=0?l000030?n0003o0000o`0000H0o`0000<0oh000?l0
003o00001P3o00030?n00200o`000P3oP0070?l000@0oh00503o00000`3oP000o`000?l000020?l0
0080oh001`3o000>ooooo`@0003o1`00o`0C0000o`800?l050000?l5003o0080oh002@000?l40?n0
00030000o`3oP000oh0000@0oh001@000?l2003o0080oh000P00o`000`3oP0000?l0003o0009003o
0080oh000P00o`070000o`L00?l010000?l00`00o`00003o0000o`0;0000o`kooooo?@000?l2003o
01`0003o0P00o`0F0000o`03003o00000?l0003o00d0003o0P00o`000`000?l00?l0003o0002003o
00kooooo0P3oP0020?l000030000o`00o`000?l000@0oh000P3o00000`3oP0000?l0003o00040000
o`80oh000`000?l40?n000030?l0003oP000oh0000800?l0103oP0000`000?l0oh000?n000060?n0
00030000o`00o`000?l000H0003o00<0oh000000o`000?l00P3oP0020?l000D0oh000P000?l2003o
00<0003o0P3oP0050?l000P0oh0000<0o`000?n0003oP0000P3oP0020?l000<00?l0103oP0020?l0
0080oh0000<0o`000?n0003oP0000P3oP0020?l000<0oh000P3o0002003o0080oh0000<0o`000?n0
003oP0000P3o00020?n000800?l00`3oP002003o01Sooooo000Foooooa@0o`000P3oP00R0?l00003
0?n0003o0000o`0000@0o`000P3oP0030?l00080oh008P3o00020?n000T0o`0000<0oh000?l0003o
00002`3o00040?n000<0o`000P3oP00>ooooo`/00?l040000?l20?n000D00?l050000?l2003o00`0
003o0P3oP003003o00P0oh0000<00?l00000o`000?l00P00o`020000o`800?l000<0oh000000o`00
0?l01P000?l00`3oP000003o0000o`020?n000800?l01@000?l2003o0080003o1@00o`020000o`80
0?l000<0oh000000o`000?l01000o`050000o`800?l03_oooolk0000o`800?l050000?l3003o00@0
003o0P00o`000`000?l00?l0003o00020?n000h0003o0P00o`0@0000o`H00?l01@000?l>ooooo`D0
oh00203o00050?n000800?l00`000?l2003o00@0oh0000<0003o0?n0003oP0000P00o`020000o`<0
0?l0203oP003003o0080003o1000o`000`3oP000003o0000o`02003o00L0oh001000o`000`3oP000
0?l0003o00020?n000D00?l0103oP0040000o`030?n0003o0000o`0000@0oh000P00o`030?n00080
o`000P3oP0030?l00080oh000P00o`020?l000`0oh000P3o00020000o`80oh0000<00?l00000o`00
0?l00P3oP00Hooooo`005_oooolD0?l00080oh008P3o00000`3oP000o`000?l000040?l00080oh00
0`3o00020?n00280o`000P3oP0090?l000030?n0003o0000o`0000/0o`00103oP0030?l00080oh00
3_ooool;003o0100003o0P3oP005003o01@0003o0P00o`0<0000o`80oh000`00o`080?n00003003o
00000?l0003o00800?l00P000?l2003o00030?n000000?l0003o00H0003o00<0oh000000o`000?l0
0P3oP002003o00D0003o0P00o`020000o`D00?l00P000?l2003o00030?n000000?l0003o00@00?l0
1@000?l2003o00kooooo>`000?l2003o01@0003o0`00o`040000o`800?l000<0003o003o0000o`00
0P3oP00>0000o`800?l040000?l6003o00D0003o3_ooool50?n000P0o`001@3oP002003o00<0003o
0P00o`040?n000030000o`3oP000oh0000800?l00P000?l3003o00P0oh000`00o`020000o`@00?l0
00<0oh000000o`000?l00P00o`070?n000@00?l000<0oh00003o0000o`000P3oP005003o00@0oh00
10000?l00`3oP000o`000?l000040?n000800?l00`3oP0020?l00080oh000`3o00020?n000800?l0
0P3o000<0?n00080o`000P000?l20?n00003003o00000?l0003o0080oh006?ooool001Kooooo0P3o
P0100?l00080oh001`3o00020?n000/0o`000P3oP00C0?l00080oh003P3o00040?n00080o`000P3o
P0050?l000kooooo3@00o`0>0000o`80oh0000<0003o003o0000o`000P00o`020000o`800?l00`00
0?l2003o00D0003o1P00o`020?n00003003o003oP000oh0000H00?l00`000?l40?n000030000o`3o
P000oh000080003o0P3oP0050000o`800?l00P000?l2003o00030000o`3oP000oh0000@0003o0`00
o`0;0000o`800?l00`000?l4003o0080003o2`00o`000`3oP0000?l0003o00020000o`kooooo1000
0?l00`00o`00003o0000o`0X0000o`<00?l02@000?l2003o0100003o0P00o`0K0000o`800?l000<0
003o003o0000o`000P00o`0G0000o`80oh003_ooool2003o0080oh0000<0o`000?n0003oP0000P3o
00020?n00080o`001@3oP002003o0080oh000`00o`020000o`80oh0000<0o`00003o0000o`000P00
o`020000o`800?l000<0003o0?n0003oP0001P3oP003003o00@0003o0P00o`000`3oP0000?l0003o
00020?n00080o`000P3oP0000`3o0000oh000?n00002003o0080o`001`3oP003003o0080oh001000
o`090?n000800?l01@3oP0020?l00080oh000`3o00050?n00080o`001`3oP0020?l000L0oh001000
o`0Hooooo`005_ooool20?n00400o`000P3oP0070?l00080oh002`3o00020?n001<0o`000P3oP00>
0?l000@0oh000P3o00020?n000D0o`003_ooool=003o00h0003o0P3oP0000`000?l00?l0003o0002
003o0080003o0P00o`030000o`800?l01@000?l6003o0080oh0000<00?l00?n0003oP0001P00o`03
0000o`@0oh0000<0003o0?n0003oP0000P000?l20?n000D0003o0P00o`020000o`800?l000<0003o
0?n0003oP00010000?l3003o00/0003o0P00o`030000o`@00?l00P000?l;003o00030?n00000o`00
0?l00080003o3_ooool40000o`03003o00000?l0003o02P0003o0`00o`090000o`800?l040000?l2
003o01/0003o0P00o`000`000?l00?l0003o0002003o01L0003o0P3oP00>ooooo`800?l00P3oP000
0`3o0000oh000?n000020?l00080oh000P3o00050?n000800?l00P3oP003003o0080003o0P3oP000
0`3o00000?l0003o0002003o0080003o0P00o`000`000?l0oh000?n000060?n000<00?l010000?l2
003o00030?n00000o`000?l00080oh000P3o00020?n000030?l0003oP000oh0000800?l00P3o0007
0?n000<00?l00P3oP004003o00T0oh000P00o`050?n00080o`000P3oP0030?l000D0oh000P3o0007
0?n00080o`001`3oP004003o01Sooooo000Foooooa/0o`000P3oP00^0?l00080oh00103o00000`3o
P000o`000?l0000K0?l00080oh002@3o00030?n000800?l01P3oP0050?l000kooooo4000o`090000
o`800?l00`3oP002003o0080oh001000o`030000o`@00?l01@000?l7003o00@0oh001@00o`040?n0
00<00?l02`000?l?003o00030000o`00o`000?l000T0003o0P00o`050000oa@00?l03_ooool5003o
00P0003o0`00o`0K0000o`@00?l02P000?l2003o01l0003o2@00o`000`000?l00?l0003o00070000
o`H00?l05@000?l20?n000kooooo103oP0000`3o0000oh000?n000020?n000L00?l00P3oP002003o
0080oh0000<00?l00000o`000?l01`000?l20?n000D0003o1P3oP005003o00@0003o0`00o`040000
o`80oh000P000?l00`3o00000?l0003o0002003o0080o`0000<0oh000?l0003o00000P3oP005003o
00H0oh000P3o00000`3oP000o`000?l000040?l000<0oh000P3o00020?n00080o`000P3oP0050?l0
00T0oh000P3o00000`3oP000o`000?l000020?n000800?l00`3oP0040000oaSooooo000Fooooo`T0
o`000P3oP00;0?l000030?n0003o0000o`0000h0o`000P3oP00@0?l00080oh003P3o00020?n000l0
o`0000<0oh000?l0003o00000P3o00020?n001/0o`0000<00?l00?n0003oP0000P00o`090?l000ko
oooo4000o`070000o`@00?l00`3oP0020?l00080oh001@00o`040000o`@00?l000<0003o003o0000
o`001`00o`040?n000800?l00P3oP0000`00o`00oh000?n000020?n000<0003o0P3oP002003o0080
003o0`00o`040000o`800?l00P000?l00`3oP000003o0000o`0F0000o`03003o00000?l0003o0080
003o1000o`000`3oP000003o0000o`0;003o00kooooo0P000?l5003o00L0003o1000o`0E0000o`H0
0?l01`000?l4003o00D0003o0P00o`0:0000o`@00?l00P000?l5003o00/0003o5`00o`0B0000o`80
0?l03_ooool20?n00080o`0000<0oh000000o`000?l00P3oP0020000o`80oh001`000?l3003o00@0
003o0P00o`000`000?l00?l0003o00070000o`P0oh0000<0o`00003o0000o`000P000?l2003o0080
003o00<00?l00000o`000?l02`3oP0070?l00080003o0P3oP0000`00o`00oh000?n000040?n000D0
o`000P3oP0020?l000<0oh001P3o00030?n00080003o1`3oP0040?l000<0oh002@00o`040?n001So
oooo000Fooooo`T0o`000P3oP00;0?l000030?n0003o0000o`0000h0o`000P3oP00@0?l00080oh00
3P3o00020?n000l0o`0000<0oh000?l0003o00000P3o00020?n001/0o`0000<00?l00?n0003oP000
0P00o`090?l000kooooo4000o`070000o`@00?l00`3oP0020?l00080oh001@00o`040000o`@00?l0
00<0003o003o0000o`001`00o`040?n000800?l00P3oP0000`00o`00oh000?n000020?n000<0003o
0P3oP002003o0080003o0`00o`040000o`800?l00P000?l00`3oP000003o0000o`0F0000o`03003o
00000?l0003o0080003o1000o`000`3oP000003o0000o`0;003o00kooooo0P000?l5003o00L0003o
1000o`0E0000o`H00?l01`000?l4003o00D0003o0P00o`0:0000o`@00?l00P000?l5003o00/0003o
5`00o`0B0000o`800?l03_ooool20?n00080o`0000<0oh000000o`000?l00P3oP0020000o`80oh00
1`000?l3003o00@0003o0P00o`000`000?l00?l0003o00070000o`P0oh0000<0o`00003o0000o`00
0P000?l2003o0080003o00<00?l00000o`000?l02`3oP0070?l00080003o0P3oP0000`00o`00oh00
0?n000040?n000D0o`000P3oP0020?l000<0oh001P3o00030?n00080003o1`3oP0040?l000<0oh00
2@00o`040?n001Sooooo000Fooooo`@0o`0000<0oh000?l0003o00002`3o00020?n000<0o`000P3o
P00D0?l00080oh002P3o00020?n000h0o`00103oP0070?l00080oh00403o00020?n001@0o`0000<0
oh000?l0003o00000P3oP0070?l00080oh003_ooool@003o00/0003o0P3oP007003o00/0003o2@00
o`000`000?l0oh000?n000020?n00080o`000P00o`030000o`80oh000P00o`030?n000800?l00P3o
P003003o0080003o3`00o`000`000?l00?l0003o00040000o`<00?l00P000?l2003o0080003o0`00
o`070000o`800?l00P3oP009003o00kooooo0P00o`020000o`<00?l06@000?l4003o00<0003o5000
o`040000o`D00?l00P000?l7003o00L0003o0P00o`020000o`D00?l00P000?l5003o00P0oh0000<0
0?l00000o`000?l01@000?l2003o00@0003o0P00o`0>0000o`kooooo0P3oP002003o00<0oh001`00
0?l60?n000800?l01@000?l7003o0080003o0`00o`020?n00080o`000P3oP0050?l00080003o0P00
o`020000o`030?n000000?l0003o00@0oh000`3o00020?n000@0o`0000<0oh000?l0003o00001P3o
00030?n00080o`000P3oP0070?l000@0oh001@3o00040?n000030?l000000?l0003o00@00?l00`3o
P0040?l000<0oh001P00o`070?n001Sooooo000Fooooo`@0o`0000<0oh000?l0003o00002`3o0002
0?n000<0o`000P3oP00D0?l00080oh002P3o00020?n000h0o`00103oP0070?l00080oh00403o0002
0?n001@0o`0000<0oh000?l0003o00000P3oP0070?l00080oh003_ooool@003o00/0003o0P3oP007
003o00/0003o2@00o`000`000?l0oh000?n000020?n00080o`000P00o`030000o`80oh000P00o`03
0?n000800?l00P3oP003003o0080003o3`00o`000`000?l00?l0003o00040000o`<00?l00P000?l2
003o0080003o0`00o`070000o`800?l00P3oP009003o00kooooo0P00o`020000o`<00?l06@000?l4
003o00<0003o5000o`040000o`D00?l00P000?l7003o00L0003o0P00o`020000o`D00?l00P000?l5
003o00P0oh0000<00?l00000o`000?l01@000?l2003o00@0003o0P00o`0>0000o`kooooo0P3oP002
003o00<0oh001`000?l60?n000800?l01@000?l7003o0080003o0`00o`020?n00080o`000P3oP005
0?l00080003o0P00o`020000o`030?n000000?l0003o00@0oh000`3o00020?n000@0o`0000<0oh00
0?l0003o00001P3o00030?n00080o`000P3oP0070?l000@0oh001@3o00040?n000030?l000000?l0
003o00@00?l00`3oP0040?l000<0oh001P00o`070?n001Sooooo000Fooooo`80003o0`3oP00B0?l0
0080oh007@3o00020?n00280o`0000<0oh000?l0003o00001`3o00020?n00280o`000P3oP00>oooo
o`L00?l00P000?l2003o0080003o00<00?l00000o`000?l02@000?l2003o0080003o00<00?l00000
o`000?l04P000?l;003o00@0oh0000<00?l00000o`000?l00P3oP0030000o`80oh000P00o`020?n0
0080003o4000o`020000o`<00?l00P3oP00B003o00D0003o2`00o`0>ooooo`L00?l03`000?l3003o
01L0003o1000o`090000o`@00?l01@000?l7003o0080oh004000o`050000o`80oh000P000?l20?n0
00D00?l00P3oP007003o0080003o0P00o`050000o`800?l00P000?l00`00o`00003o0000o`020000
o`kooooo103oP00:0000o`80oh000P000?l20?n000<00?l010000?l7003o0080003o0`00o`040?n0
00@0o`0000<0oh000?l0003o00000P000?l5003o00H0oh000`3o00020?n000@0o`000`3oP0020?l0
0080oh000P3o00050?n000L0o`001P3oP0070?l00080oh0000<0003o003o0000o`000P3oP0020000
o`030?n0003o0000o`0000@0o`001@3oP0020000o`L0oh000P3o000Hooooo`005_ooool20000o`<0
oh004P3o00020?n001d0o`000P3oP00R0?l000030?n0003o0000o`0000L0o`000P3oP00R0?l00080
oh003_ooool7003o0080003o0P00o`020000o`03003o00000?l0003o00T0003o0P00o`020000o`03
003o00000?l0003o0180003o2`00o`040?n00003003o00000?l0003o0080oh000`000?l20?n00080
0?l00P3oP0020000oa000?l00P000?l3003o0080oh004P00o`050000o`/00?l03_ooool7003o00l0
003o0`00o`0G0000o`@00?l02@000?l4003o00D0003o1`00o`020?n001000?l01@000?l20?n00080
003o0P3oP005003o0080oh001`00o`020000o`800?l01@000?l2003o0080003o00<00?l00000o`00
0?l00P000?l>ooooo`@0oh002P000?l20?n00080003o0P3oP003003o00@0003o1`00o`020000o`<0
0?l0103oP0040?l000030?n0003o0000o`000080003o1@00o`060?n000<0o`000P3oP0040?l000<0
oh000P3o00020?n00080o`001@3oP0070?l000H0oh001`3o00020?n000030000o`00o`000?l00080
oh000P000?l00`3oP000o`000?l000040?l000D0oh000P000?l70?n00080o`006?ooool001Kooooo
1@3oP00l0?l000<0oh008P3o00020?n001D0o`000P3oP00;0?l000kooooo1`00o`040000o`D00?l0
0P000?l2003o00D0003o1`00o`0@0000o`800?l00P000?l9003o00@0oh001`00o`070?n000800?l0
00<0003o003o0000o`001P00o`000`3oP0000?l0003o0002003o00L0003o1`00o`060000oa<00?l0
10000?l>ooooo`L00?l02@000?l9003o00h0003o0P3oP0020000oaT00?l00P000?l>003o00H0003o
00<00?l00000o`000?l00P00o`020?n000<00?l00P3oP0070000o`800?l00P3oP003003o00@0003o
1@00o`060000o`D00?l00P000?l>ooooo`@0oh0000<00?l00000o`000?l00P000?l2003o00<0oh00
1000o`020000o`800?l000<0003o003o0000o`0010000?l3003o0080003o0P3oP002003o00L0oh00
0P3o00030?n000800?l00P000?l3003o00@0oh000P3o000:0?n00080o`000P3oP0020?l000<0oh00
0P00o`070?n000@0003o1@3oP0040?l00080oh000P3o00000`3oP000003o0000o`020000o`800?l0
00<0oh000000o`000?l0103oP0020?l000030?n00000o`000?l00080oh000P00o`020?n000D0o`00
6?ooool001Kooooo0P3oP0170?l00080oh00:03o00000`3oP000o`000?l000070?l00080oh000P3o
00020?n000<0o`000P3oP0020?l000kooooo4000o`020000o`800?l02@000?l3003o01l0003o0P3o
P003003o0080oh000`000?l60?n000800?l000<0oh000000o`000?l00P000?l2003o00D0003o0P00
o`040?n000<0003o0P3oP004003o00030?n000000?l0003o00@0003o3000o`020?n000D00?l01000
0?l>ooooo`L00?l00P000?l2003o00D0003o1P00o`0<0000o`800?l00`000?l6003o00`0003o2@00
o`040000o`800?l000<0003o003o0000o`002@00o`060000o`03003o00000?l0003o00@0003o0P00
o`050000o`@00?l01@000?l<003o00P0003o1@00o`0>ooooo`800?l00`3oP0020000o`L00?l00P3o
P004003o0080003o1`00o`000`3oP0000?l0003o00020000o`800?l00`3oP0020000o`@0oh000`3o
00020?n000@00?l00`3oP0020000o`L0oh000P3o00040?n000030000o`3o0000o`000080oh000P3o
00050?n000800?l01@3oP004003o00@0oh001@3o00020?n00080o`000`00o`040?n00003003o0000
0?l0003o00@0oh000`3o00020?n00080o`000P00o`070?n001Sooooo000Fooooo`80oh00A`3o0002
0?n002P0o`0000<0oh000?l0003o00001`3o00020?n00080o`000P3oP0030?l00080oh000P3o000>
oooooa000?l00P000?l2003o00T0003o0`00o`0O0000o`80oh000`00o`020?n000<0003o1P3oP002
003o00030?n000000?l0003o0080003o0P00o`050000o`800?l0103oP0030000o`80oh001000o`00
0`3oP000003o0000o`040000o``00?l00P3oP005003o00@0003o3_ooool7003o0080003o0P00o`05
0000o`H00?l030000?l2003o00<0003o1P00o`0<0000o`T00?l010000?l2003o00030000o`00o`00
0?l000T00?l01P000?l00`00o`00003o0000o`040000o`800?l01@000?l4003o00D0003o3000o`08
0000o`D00?l03_ooool2003o00<0oh000P000?l7003o0080oh001000o`020000o`L00?l000<0oh00
003o0000o`000P000?l2003o00<0oh000P000?l40?n000<0o`000P3oP004003o00<0oh000P000?l7
0?n00080o`00103oP0000`000?l0o`000?l000020?n00080o`001@3oP002003o00D0oh001000o`04
0?n000D0o`000P3oP0020?l000<00?l0103oP0000`00o`00003o0000o`040?n000<0o`000P3oP002
0?l000800?l01`3oP00Hooooo`005_ooool70?l00080oh00103o00000`3oP000o`000?l0000K0?l0
0080oh00703o00020?n00080o`000P3oP00N0?l00080oh00103o00000`3oP000o`000?l000070?l0
0080oh002`3o000>ooooo`@0oh003000o`020000o`800?l09@000?l20?n00080003o103oP0030000
o`@00?l00`3oP0020?l000@0oh002P00o`080000o`T00?l020000?l9003o00@0oh002@00o`0>oooo
o`800?l01@000?l2003o00d0003o0`00o`020000o`800?l01@000?lB003o00D0003o2`00o`050000
o`80oh001P00o`090000o`X00?l00P3oP009003o0080oh003000o`040000o`800?l00P000?l00`00
o`00003o0000o`02003o00kooooo0P000?l20?n000030000o`00o`000?l000H0003o1@3oP002003o
00D0oh000P3o0002003o00<0oh000P00o`050?n00080o`00103oP0020?l000030?n0003o0000o`00
0080oh000P3o0002003o00<0oh001000o`070?n000D00?l00P000?l20?n000800?l01@3oP0090000
o`D0oh00203o00000`3oP000o`000?l000020?n000800?l000<0oh000000o`000?l00P3oP0020000
o`800?l03P3oP00Hooooo`005_ooool70?l00080oh00103o00000`3oP000o`000?l0000K0?l00080
oh00703o00020?n00080o`000P3oP00N0?l00080oh00103o00000`3oP000o`000?l000070?l00080
oh002`3o000>ooooo`@0oh003000o`020000o`800?l09@000?l20?n00080003o103oP0030000o`@0
0?l00`3oP0020?l000@0oh002P00o`080000o`T00?l020000?l9003o00@0oh002@00o`0>ooooo`80
0?l01@000?l2003o00d0003o0`00o`020000o`800?l01@000?lB003o00D0003o2`00o`050000o`80
oh001P00o`090000o`X00?l00P3oP009003o0080oh003000o`040000o`800?l00P000?l00`00o`00
003o0000o`02003o00kooooo0P000?l20?n000030000o`00o`000?l000H0003o1@3oP002003o00D0
oh000P3o0002003o00<0oh000P00o`050?n00080o`00103oP0020?l000030?n0003o0000o`000080
oh000P3o0002003o00<0oh001000o`070?n000D00?l00P000?l20?n000800?l01@3oP0090000o`D0
oh00203o00000`3oP000o`000?l000020?n000800?l000<0oh000000o`000?l00P3oP0020000o`80
0?l03P3oP00Hooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0000Wooooog7o00009ooooomao`00
02OoooooLOl0000Tooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o00Co
oooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Go
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo
5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0
o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000O
oooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooo
oaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00
1?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool001oooooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o
00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo
5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00
Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00
OaKo0?l01Ol007lFo`00o`Co001o5oooO`04o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00
Ool007l0>?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00
OaKo0?l08?l007lFoomo00Co001o00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
8?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol0
07lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go
001o00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00
Ool007l0K_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000oooo
ooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00
Ool007l0KOl007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooog;o00009oooooma
o`0002OoooooLOl0000Wooooog7o00009?ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool001Kooooo0P3o00020000o`030?l000000?l0003o01l0o`0000<0003o0?l0003o00000P3o0002
0000o`L0o`000P000?lB0?l000030000o`3o0000o`000180o`004P000?lB0?l000@0003o00<0o`00
0000o`000?l00P000?l>ooooo`80o`000P3oP00E003o0080oh000P00o`000`3oP000003o0000o`04
003o0080003o4`00o`020?n000800?l01@000?l20?n000800?l00P3oP005003o0080oh001`000?l2
0?n000D00?l00P000?l5003o00@0003o0P3oP003003o0080oh000P00o`020000o`03003o003oP000
oh0000@0oh000P00o`030?n000800?l01@000?l20?n000800?l03_ooool50?l00080oh000P00o`02
0?n000800?l000<0oh000?l0003o00000P3o00040?n00003003o003o0000o`0000L0003o1P3o0005
0?n000L0003o0P3oP002003o00D0o`002`000?l30?l000d0003o0P00o`0;0000o`<00?l01`3o0002
0?n000@0003o00<0oh00003o0000o`000P00o`040?n000<0o`000P000?l20?l00080003o0`3o0002
0000o`kooooo0P3oP002003o00<0oh001000o`030?n000H00?l01`3oP002003o00D0oh001000o`03
0?n000800?l00P3oP002003o00030?n00000o`000?l000800?l00P3oP003003o00@0oh001000o`0<
0?n000800?l01@3oP002003o00@0oh000`3o00020?n000800?l01@3oP0040000o`80oh0000<00?l0
0?n0003oP0000P00o`020?n00003003o003oP000oh000080oh000P000?l30?l000@0oh0010000?l0
0`3oP0000?l0003o0002003o01Sooooo000Fooooo`80o`000P000?l00`3o0000003o0000o`0O0?l0
00030000o`3o0000o`000080o`000P000?l70?l00080003o4P3o00000`000?l0o`000?l0000B0?l0
0180003o4P3o00040000o`030?l000000?l0003o0080003o3_ooool20?l00080oh005@00o`020?n0
00800?l000<0oh000000o`000?l01000o`020000oa<00?l00P3oP002003o00D0003o0P3oP002003o
0080oh001@00o`020?n000L0003o0P3oP005003o0080003o1@00o`040000o`80oh000`00o`020?n0
00800?l00P000?l00`00o`00oh000?n000040?n000800?l00`3oP002003o00D0003o0P3oP002003o
00kooooo1@3o00020?n000800?l00P3oP002003o00030?n0003o0000o`000080o`00103oP0000`00
o`00o`000?l000070000o`H0o`001@3oP0070000o`80oh000P00o`050?l000/0003o0`3o000=0000
o`800?l02`000?l3003o00L0o`000P3oP0040000o`030?n00000o`000?l000800?l0103oP0030?l0
0080003o0P3o00020000o`<0o`000P000?l>ooooo`80oh000P00o`030?n000@00?l00`3oP006003o
00L0oh000P00o`050?n000@00?l00`3oP002003o0080oh000P00o`000`3oP0000?l0003o0002003o
0080oh000`00o`040?n000@00?l0303oP002003o00D0oh000P00o`040?n000<0o`000P3oP002003o
00D0oh0010000?l20?n00003003o003oP000oh0000800?l00P3oP0000`00o`00oh000?n000020?n0
0080003o0`3o00040?n000@0003o00<0oh00003o0000o`000P00o`0Hooooo`005_ooool20?l00080
003o2P3o00020000o`L0o`000P00o`0=0?l000030000o`3o0000o`000080o`000P000?lN0?l00080
003o0P3o00030000o`H0o`000P000?l30?l00180003o503o00020000o`030?l000000?l0003o0080
o`003_ooool20?l00080oh001`00o`020?n001000?l000<0oh000000o`000?l01000o`020?n001<0
0?l0103oP0050000o`80oh000P00o`020?n000<00?l01P3oP0050000o`80oh000`00o`020?n000H0
0?l000<0o`000000o`000?l00P000?l20?n000<00?l00P3oP0040000o`L0oh000P00o`000`3oP000
0?l0003o0002003o0080oh000P000?l00`00o`00oh000?n00002003o00kooooo10000?l00`3o0000
0?l0003o0002003o0080oh000P00o`050?l000@0oh0000<00?l00?l0003o00001`000?l60?l000D0
oh0010000?l00`00o`00oh000?n000020?n000800?l00`3o0002003o0080o`000P000?l20?l000<0
003o3@3o000B0000o`<00?l00P3o00040000o`03003o003oP000oh0000@0003o00<0oh00003o0000
o`000P3oP0070000o`@0o`000`00o`040000o`kooooo0P3oP002003o00<0oh001000o`030?n00080
0?l02`3oP003003o00@0oh001000o`000`3oP0000?l0003o0002003o0080oh000P00o`030?n000L0
0?l0103oP004003o00`0oh001000o`030?n000800?l01@3oP002003o0080oh000P00o`020?n00003
003o003oP000oh0000@0003o0P3o00000`000?l0oh000?n00002003o00T0oh000P3o00000`000?l0
oh000?n000070?n00080o`000P00o`0Hooooo`005_ooool20?l00080003o2P3o00020000o`L0o`00
0P00o`0=0?l000030000o`3o0000o`000080o`000P000?lN0?l00080003o0P3o00030000o`H0o`00
0P000?l30?l00180003o503o00020000o`030?l000000?l0003o0080o`003_ooool20?l00080oh00
1`00o`020?n001000?l000<0oh000000o`000?l01000o`020?n001<00?l0103oP0050000o`80oh00
0P00o`020?n000<00?l01P3oP0050000o`80oh000`00o`020?n000H00?l000<0o`000000o`000?l0
0P000?l20?n000<00?l00P3oP0040000o`L0oh000P00o`000`3oP0000?l0003o0002003o0080oh00
0P000?l00`00o`00oh000?n00002003o00kooooo10000?l00`3o00000?l0003o0002003o0080oh00
0P00o`050?l000@0oh0000<00?l00?l0003o00001`000?l60?l000D0oh0010000?l00`00o`00oh00
0?n000020?n000800?l00`3o0002003o0080o`000P000?l20?l000<0003o3@3o000B0000o`<00?l0
0P3o00040000o`03003o003oP000oh0000@0003o00<0oh00003o0000o`000P3oP0070000o`@0o`00
0`00o`040000o`kooooo0P3oP002003o00<0oh001000o`030?n000800?l02`3oP003003o00@0oh00
1000o`000`3oP0000?l0003o0002003o0080oh000P00o`030?n000L00?l0103oP004003o00`0oh00
1000o`030?n000800?l01@3oP002003o0080oh000P00o`020?n00003003o003oP000oh0000@0003o
0P3o00000`000?l0oh000?n00002003o00T0oh000P3o00000`000?l0oh000?n000070?n00080o`00
0P00o`0Hooooo`005_ooool20000o``0o`0010000?l50?l000800?l01`3o00020000o`d0o`0000<0
003o0?l0003o00007@3o00020000o`030?l000000?l0003o00@0o`000P000?l30?l00180003o1`3o
00040000oa00o`003_ooool20000o`80oh006@00o`000`3oP000003o0000o`04003o0080oh0000<0
0?l00?n0003oP0004000o`040?n000D0003o1P3oP0000`00o`00o`000?l000060?n000D0003o0P3o
P003003o0080oh001P00o`000`000?l0o`000?l000020000o`80oh000`00o`020?n00080003o0P3o
00050?n000@00?l000<0oh00003o0000o`000P00o`020?n000<00?l00P3oP002003o00kooooo1000
0?l00`3o0000oh000?n00002003o0080oh000P000?l50?l000800?l00P3oP0000`00o`00o`000?l0
00090000o`800?l00P000?l50?n00080003o0P3o0003003o0080oh000P00o`020?l000030?n00000
o`000?l000@0003o0P3o00030000o`D0o`000P00o`040000o`80o`004`000?l40?n000@0o`0000<0
0?l00000o`000?l010000?l00`3oP0000?l0003o00020?n000L0003o0P3o00020000o`80o`0000<0
0?l00?n0003oP0000P3oP00>ooooo`80oh000P00o`000`3oP0000?l0003o0004003o0080oh000`00
o`020?n000800?l00`3oP002003o0080oh001@00o`020?n000@00?l02@3oP0000`00o`00oh000?n0
0004003o0080oh000`00o`020?n000@00?l000<0oh00003o0000o`000P3oP003003o00H0oh000P00
o`030?n000800?l00P3oP002003o00D0oh000P00o`070?n00080003o0P3o00000`000?l0oh000?n0
0002003o0080oh0000<00?l00?n0003oP000103oP0020?l000030000o`3oP000oh0000T0oh000P00
o`0Hooooo`005_ooool40000o`030?l000000?l0003o00L0o`000P000?l70?l000800?l01`3o0004
0000oah0o`000P000?l>0?l00080003o103o00020000o`<0o`000P000?l20?l000/0003o00<0o`00
0000o`000?l0103o00000`3oP000o`000?l000040000o`T0o`000`000?l40?l000kooooo0P00o`03
0?n001P00?l000<0oh00003o0000o`001000o`020?n00003003o003oP000oh0000d00?l00P3oP003
003o0080003o0P3oP0020000o`030?l000000?l0003o00D0oh000P3o00060000o`03003o00000?l0
003o0080003o0P3oP003003o00H0003o0P00o`000`000?l0o`000?l000020000o`80oh000`00o`02
0?n000@0003o1@3oP002003o00<0oh001000o`020000o`<00?l00P3oP002003o00kooooo10000?l0
0`3o0000oh000?n00002003o0080oh000P000?l50?l000800?l00P3oP0000`00o`00o`000?l00002
0?n000`0003o103oP002003o0080o`0000<00?l00?n0003oP0000P3oP004003o00<0oh0010000?l2
0?l000<0003o1@3o0002003o0080oh000P3o000G0000o`80oh000P000?l30?l000H0003o1@3oP00>
0000o`@0o`003_ooool4003o00030?n00000o`000?l000@00?l00P3oP007003o0080oh000`00o`05
0?n000800?l00P3oP004003o00030?n00000o`000?l000@0oh000`00o`060?n000800?l000<0oh00
003o0000o`000P3oP002003o00<0oh002@00o`040?n000800?l00`3oP002003o00T0oh000P00o`07
0?n000@0o`000`3oP002003o00L0oh000P000?l50?l000T0oh000P00o`0Hooooo`005_ooool40000
o`030?l000000?l0003o00L0o`000P000?l70?l000800?l01`3o00040000oah0o`000P000?l>0?l0
0080003o103o00020000o`<0o`000P000?l20?l000/0003o00<0o`000000o`000?l0103o00000`3o
P000o`000?l000040000o`T0o`000`000?l40?l000kooooo0P00o`030?n001P00?l000<0oh00003o
0000o`001000o`020?n00003003o003oP000oh0000d00?l00P3oP003003o0080003o0P3oP0020000
o`030?l000000?l0003o00D0oh000P3o00060000o`03003o00000?l0003o0080003o0P3oP003003o
00H0003o0P00o`000`000?l0o`000?l000020000o`80oh000`00o`020?n000@0003o1@3oP002003o
00<0oh001000o`020000o`<00?l00P3oP002003o00kooooo10000?l00`3o0000oh000?n00002003o
0080oh000P000?l50?l000800?l00P3oP0000`00o`00o`000?l000020?n000`0003o103oP002003o
0080o`0000<00?l00?n0003oP0000P3oP004003o00<0oh0010000?l20?l000<0003o1@3o0002003o
0080oh000P3o000G0000o`80oh000P000?l30?l000H0003o1@3oP00>0000o`@0o`003_ooool4003o
00030?n00000o`000?l000@00?l00P3oP007003o0080oh000`00o`050?n000800?l00P3oP004003o
00030?n00000o`000?l000@0oh000`00o`060?n000800?l000<0oh00003o0000o`000P3oP002003o
00<0oh002@00o`040?n000800?l00`3oP002003o00T0oh000P00o`070?n000@0o`000`3oP002003o
00L0oh000P000?l50?l000T0oh000P00o`0Hooooo`005_ooool40000o`X0o`0010000?l50?l00080
0?l01`3o00040000obL0o`000P000?l50?l00080003o2@3o00020000o`80o`002`000?l00`3o0000
003o0000o`020000o`L0o`000P000?l30?l00080003o103o00020000o`D0o`003_ooool4003o0003
0?n00000o`000?l000@00?l00P3oP005003o0080oh001@00o`020?n000800?l000<0oh00003o0000
o`001000o`020?n00003003o003oP000oh0000d00?l00P3oP0000`00o`00003o0000o`0;0000o`80
oh001`000?l3003o0080003o0P00o`020000o`800?l01`000?l2003o00D0003o0P3oP003003o00H0
003o1@3oP002003o0080oh000`000?l2003o00@0003o00<00?l00?n0003oP0000P00o`0>ooooo`@0
oh0000<0o`000?n0003oP000103oP002003o00<0003o0P3o00040000o`03003o003oP000oh000080
oh000P000?l00`3o0000003o0000o`070000o`800?l010000?l20?l000<00?l00P3oP004003o0003
0000o`3oP000oh0000@0003o0P00o`000`000?l0o`000?l000050?l000H00?l06`000?l2003o0003
0?l000000?l0003o00@0o`001@3oP0040000o`03003o00000?l0003o00L0003o0P3o0002003o00ko
oooo1000o`000`3oP0000?l0003o0004003o0080oh000`00o`020?n000L00?l01@3oP004003o0080
oh001@00o`060?n00003003o003oP000oh0000800?l01@3oP002003o0080oh000P00o`030?n000H0
0?l000<0oh00003o0000o`000P00o`020?n000800?l00`3oP002003o00T0oh000P00o`030?n00080
0?l0103oP0020?l000D0oh000P00o`050?n000D0o`00103oP002003o0080oh0000<00?l00?n0003o
P0000P3oP00Hooooo`005_ooool40000o`X0o`0010000?l50?l000800?l01`3o00040000obL0o`00
0P000?l50?l00080003o2@3o00020000o`80o`002`000?l00`3o0000003o0000o`020000o`L0o`00
0P000?l30?l00080003o103o00020000o`D0o`003_ooool4003o00030?n00000o`000?l000@00?l0
0P3oP005003o0080oh001@00o`020?n000800?l000<0oh00003o0000o`001000o`020?n00003003o
003oP000oh0000d00?l00P3oP0000`00o`00003o0000o`0;0000o`80oh001`000?l3003o0080003o
0P00o`020000o`800?l01`000?l2003o00D0003o0P3oP003003o00H0003o1@3oP002003o0080oh00
0`000?l2003o00@0003o00<00?l00?n0003oP0000P00o`0>ooooo`@0oh0000<0o`000?n0003oP000
103oP002003o00<0003o0P3o00040000o`03003o003oP000oh000080oh000P000?l00`3o0000003o
0000o`070000o`800?l010000?l20?l000<00?l00P3oP004003o00030000o`3oP000oh0000@0003o
0P00o`000`000?l0o`000?l000050?l000H00?l06`000?l2003o00030?l000000?l0003o00@0o`00
1@3oP0040000o`03003o00000?l0003o00L0003o0P3o0002003o00kooooo1000o`000`3oP0000?l0
003o0004003o0080oh000`00o`020?n000L00?l01@3oP004003o0080oh001@00o`060?n00003003o
003oP000oh0000800?l01@3oP002003o0080oh000P00o`030?n000H00?l000<0oh00003o0000o`00
0P00o`020?n000800?l00`3oP002003o00T0oh000P00o`030?n000800?l0103oP0020?l000D0oh00
0P00o`050?n000D0o`00103oP002003o0080oh0000<00?l00?n0003oP0000P3oP00Hooooo`005_oo
ool20?l00080003o2P3o00020000oa00o`0010000?l50?l000800?l0<P3o00020000o`80o`002`00
0?l00`3o0000003o0000o`020000o`D0o`002@000?l20?l000800?l00P000?l50?l000kooooo0P00
0?l2003o00030?n00000o`000?l000@00?l00`3oP004003o00D0oh000P3o00050?n00080003o1000
o`020?n00003003o003oP000oh0000d00?l00P3oP003003o00/0003o0P3oP0070000o`800?l00`00
0?l20?n000@0003o00<0o`000000o`000?l00P000?l4003o00D0003o0P3oP003003o00H0003o0`3o
P004003o0080oh000`000?l2003o0080oh000`00o`020?n000800?l03_ooool20?n000<0o`000P3o
P006003o00030?n000000?l0003o0080o`0010000?l00`00o`00oh000?n000040000o`<0o`001`00
0?l2003o00@0003o0P3o00000`00o`00oh000?n000020?n000800?l00`3o00020?n000L0003o0P3o
00020000o`80o`0000<00?l00?n0003oP0002@000?l40?l000`0003o0P3oP0020?l00080003o0`3o
00040000o`80o`0000<0oh00003o0000o`000P3oP002003o0080oh0000<00?l00?n0003oP0001`00
0?l20?l000800?l03_ooool2003o00<0oh001P00o`020?n000<00?l00P3oP007003o00D0oh001000
o`020?n000<00?l02@3oP004003o00D0oh000P00o`020?n000@00?l000<0oh00003o0000o`000P3o
P002003o00030?n00000o`000?l000800?l00P3oP003003o00H0oh000P00o`000`3oP0000?l0003o
00020?n000800?l0403oP002003o00<0oh000P000?l20?l00080003o1@3oP002003o00L0oh006?oo
ool001Kooooo0P3o00020000o`X0o`000P000?l@0?l000@0003o1@3o0002003o0380o`000P000?l2
0?l000/0003o00<0o`000000o`000?l00P000?l50?l000T0003o0P3o0002003o0080003o1@3o000>
ooooo`80003o0P00o`000`3oP0000?l0003o0004003o00<0oh001000o`050?n00080o`001@3oP002
0000o`@00?l00P3oP0000`00o`00oh000?n0000=003o0080oh000`00o`0;0000o`80oh001`000?l2
003o00<0003o0P3oP0040000o`030?l000000?l0003o0080003o1000o`050000o`80oh000`00o`06
0000o`<0oh001000o`020?n000<0003o0P00o`020?n000<00?l00P3oP002003o00kooooo0P3oP003
0?l00080oh001P00o`000`3oP000003o0000o`020?l000@0003o00<00?l00?n0003oP00010000?l3
0?l000L0003o0P00o`040000o`80o`0000<00?l00?n0003oP0000P3oP002003o00<0o`000P3oP007
0000o`80o`000P000?l20?l00003003o003oP000oh0000T0003o103o000<0000o`80oh000P3o0002
0000o`<0o`0010000?l20?l000030?n00000o`000?l00080oh000P00o`020?n00003003o003oP000
oh0000L0003o0P3o0002003o00kooooo0P00o`030?n000H00?l00P3oP003003o0080oh001`00o`05
0?n000@00?l00P3oP003003o00T0oh001000o`050?n000800?l00P3oP004003o00030?n00000o`00
0?l00080oh000P00o`000`3oP0000?l0003o0002003o0080oh000`00o`060?n000800?l000<0oh00
003o0000o`000P3oP002003o0100oh000P00o`030?n00080003o0P3o00020000o`D0oh000P00o`07
0?n001Sooooo000Fooooo`@0003o2P3o00020000oa00o`0010000?l30?l000@0003o7@3o00000`00
0?l0o`000?l000060?l000030000o`3o0000o`0000T0o`000P000?l40?l000D0003o0P3o00020000
o`030?l000000?l0003o0080003o303o00020000o`@0o`000P000?l00`3o00000?l0003o00020?l0
00kooooo10000?l00`3oP0000?l0003o0004003o00<0oh001000o`050?n00080o`001@3oP0020000
o`@00?l00P3oP003003o0080oh001@00o`020?n000@00?l00P3oP003003o00/0003o0P3oP0000`00
0?l0o`000?l000090000o`80oh0010000?l00`3o0000003o0000o`04003o00L0003o1@3oP0070000
o`80oh001000o`020?n00003003o003oP000oh0000@0oh001`00o`0>ooooo`80003o2`00o`000`3o
P0000?l0003o00020?l000@0003o0`00o`020?n000/0003o0`00o`040000o`80o`0000<0003o0?n0
003oP0000P3oP005003o00@0003o0P3o00050000o`D00?l00P3oP0090000o`@0o`0030000?l20?l0
00@0003o0`3o00040000o`80o`001`3oP005003o00@0oh000`000?l20?l000800?l03_ooool2003o
00<0oh001000o`040?n000<00?l0103oP003003o00@0oh001`00o`020?n000D00?l0103oP002003o
00030?n00000o`000?l000H0oh000`00o`020?n000L00?l00P3oP002003o00030?n00000o`000?l0
00@0oh000P00o`070?n000<00?l0103oP002003o00`0oh000P00o`090?n000800?l01`3oP002003o
00<0oh000P00o`020?n001Sooooo000Fooooo`@0003o2P3o00020000o`80o`000P000?lC0?l000@0
003o7@3o00000`000?l0o`000?l000060?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o
00001`3o00020000o`@0o`001`000?lB0?l00080oh0000<0o`000?n0003oP0000P3oP00>ooooo`80
003o0P00o`000`3oP0000?l0003o0004003o00<0oh001000o`050?n00080o`000P3oP002003o0003
0?n000000?l0003o00@00?l00P3oP003003o0080oh001@00o`020?n000L00?l00P3oP00;0000o`80
oh0000<0003o0?l0003o00004P000?l2003o0080o`000P000?l00`3oP0000?l0003o00020000o`D0
oh001P000?l30?n000@00?l00P3oP0000`00o`00oh000?n000040?n000L00?l03_ooool20000o`L0
0?l00P3oP005003o00H0003o0`00o`020?n000/0003o0`00o`040?n000<0003o103oP004003o0003
0?l000000?l0003o00/0003o0`3o00020000o`80oh000P00o`020?n001L0003o0P3o00020000o`<0
o`0010000?l90?n000<0003o0P3oP0050000o`80o`000P000?l>ooooo`800?l00`3oP0020?l000@0
oh001@00o`040?n000D00?l0103oP003003o00L0oh000P00o`060?n00003003o003oP000oh000080
oh001`00o`020?n000L00?l01@3oP002003o0080oh001000o`070?n000<00?l0103oP002003o00D0
oh000P00o`040?n000<00?l02@3oP002003o0080oh0000<00?l00?n0003oP0002`3oP00Hooooo`00
5_ooool40000o`X0o`000P000?l20?l00080003o4`3o00040000oad0o`0000<0003o0?l0003o0000
1P3o00000`000?l0o`000?l000060?l000030000o`3o0000o`0000L0o`000P000?l40?l000L0003o
4P3o00020?n000030?l0003oP000oh000080oh003_ooool20000o`800?l000<0oh00003o0000o`00
1000o`030?n000@00?l01@3oP0020?l00080oh000P00o`000`3oP000003o0000o`04003o0080oh00
0`00o`020?n000D00?l00P3oP007003o0080oh002`000?l20?n000030000o`3o0000o`000180003o
0P00o`020?l00080003o00<0oh00003o0000o`000P000?l50?n000H0003o0`3oP004003o0080oh00
00<00?l00?n0003oP000103oP007003o00kooooo0P000?l7003o0080oh001@00o`060000o`<00?l0
0P3oP00;0000o`<00?l0103oP0030000o`@0oh001000o`000`3o0000003o0000o`0;0000o`<0o`00
0P000?l20?n000800?l00P3oP00G0000o`80o`000P000?l30?l000@0003o2@3oP0030000o`80oh00
1@000?l20?l00080003o3_ooool2003o00<0oh000P3o00040?n000D00?l0103oP005003o00@0oh00
0`00o`070?n000800?l01P3oP0000`00o`00oh000?n000020?n000L00?l00P3oP007003o00D0oh00
0P00o`020?n000@00?l01`3oP003003o00@0oh000P00o`050?n000800?l0103oP003003o00T0oh00
0P00o`020?n00003003o003oP000oh0000/0oh006?ooool001Kooooo10000?l:0?l00080003o5P3o
00050000ob@0o`000P000?l90?l000030000o`3o0000o`0000@0003o0`3o00020000o`@0o`001`00
0?l@0?l000800?l01`3o000>ooooo`@00?l000<0oh00003o0000o`001000o`030?n000H00?l00P3o
P003003o0080oh000P00o`000`3oP000003o0000o`04003o0080oh000`00o`020?n000@00?l00`3o
P002003o0080oh001@00o`020?n000T0003o0P3oP00E0000o`800?l00P3o00030000o`800?l00P00
0?l70?n000@0003o0`3oP002003o00@0oh000`3o00020?n000@0003o00<0o`00003o0000o`000P00
o`0>ooooo`80003o0P00o`000`3oP0000?l0003o0002003o00@0oh000`00o`020?n000800?l00P3o
P003003o0080oh0030000?l2003o00@0oh000`000?l40?n000@00?l000<0o`000000o`000?l03P00
0?l2003o0080003o0P00o`030?n00080003o0P3o000F0000o`<0o`000P000?l3003o00@0oh001`00
0?l20?l000T0003o3_ooool2003o0080oh000`00o`040?n000D00?l0103oP003003o00H0oh000`00
o`040?n000800?l000<0oh00003o0000o`00103oP002003o00030?n00000o`000?l00080oh001@00
o`040?n000800?l00P3oP003003o00T0oh001000o`030?n000H00?l01@3oP002003o00D0oh000P00
o`040?n000<00?l0103oP0000`00o`00oh000?n000020?n000800?l00P3oP0000`00o`00oh000?n0
000;0?n001Sooooo000Fooooo`@0003o2P3o00020000oaH0o`001@000?lT0?l00080003o2@3o0000
0`000?l0o`000?l000040000o`<0o`000P000?l40?l000L0003o403o0002003o00L0o`003_ooool4
003o00030?n00000o`000?l000@00?l00`3oP006003o0080oh000`00o`020?n000800?l000<0oh00
0000o`000?l01000o`020?n000<00?l00P3oP004003o00<0oh000P00o`020?n000D00?l00P3oP009
0000o`80oh005@000?l2003o0080o`000`000?l2003o0080003o1`3oP0040000o`<0oh000P00o`04
0?n000<0o`000P3oP0040000o`030?l00000o`000?l000800?l03_ooool20000o`800?l000<0oh00
003o0000o`000P00o`040?n000<00?l00P3oP002003o0080oh000`00o`020?n000`0003o0P00o`04
0?n000<0003o103oP004003o00030?l000000?l0003o00h0003o0P00o`020000o`800?l00`3oP002
0000o`80o`005P000?l30?l00080003o0`00o`040?n000L0003o0P3o00090000o`kooooo0P00o`02
0?n000<00?l0103oP005003o00@0oh000`00o`060?n000<00?l0103oP002003o00030?n00000o`00
0?l000@0oh000P00o`000`3oP0000?l0003o00020?n000D00?l0103oP002003o0080oh000`00o`09
0?n000@00?l00`3oP006003o00D0oh000P00o`050?n000800?l0103oP003003o00@0oh0000<00?l0
0?n0003oP0000P3oP002003o0080oh0000<00?l00?n0003oP0002`3oP00Hooooo`005_ooool70000
o`@0o`000P000?l00`3o0000003o0000o`020000ocH0o`0000<0003o0?l0003o00001P3o00000`00
0?l0o`000?l000060?l000<0003o0P3o00020000o`T0o`000`000?l20?l00080003o403o0002003o
0080oh001@3o000>ooooo`@00?l000<0oh00003o0000o`001000o`030?n000H00?l00P3oP003003o
0080oh000P00o`000`3oP000003o0000o`04003o0080oh000`00o`020?n000D00?l00P3oP002003o
0080oh001@00o`040?n00080o`0000<0003o0?n0003oP000103oP00B0000o`030?l0003oP000oh00
00800?l00P3oP0020000o`<00?l00P000?l2003o00<0oh002`00o`020?n000<0003o0P3o00060000
o`030?l0003oP000oh0000800?l03_ooool20?l000800?l000<0oh00003o0000o`000P00o`040?n0
00030000o`00o`000?l00080oh000P00o`020?n000<00?l00P3oP0050000o`80o`0010000?l00`3o
00000?l0003o00020?n00080003o0P3o00070?n00080003o00<00?l00000o`000?l02@000?l70?l0
0080003o1000o`000`3oP000003o0000o`020000o`80o`000P000?l00`3o0000003o0000o`090000
o`80o`001@000?l2003o0080003o0`00o`040?n000800?l01@000?l20?l00080003o0P3o00050000
o`kooooo0P00o`020?n000<00?l0103oP007003o0080oh000`00o`060?n000<00?l03`3oP0000`00
o`00oh000?n000020?n000D00?l0103oP002003o0080oh002000o`040?n000@00?l00`3oP006003o
00<0oh000P3o00040?n00003003o003oP000oh0000800?l0103oP003003o00D0oh000P00o`020?n0
00800?l02`3oP003003o0080oh006?ooool001Kooooo1`000?l40?l00080003o00<0o`000000o`00
0?l00P000?lf0?l000030000o`3o0000o`0000H0o`0000<0003o0?l0003o00001P3o00030000o`80
o`000P000?l90?l000<0003o0P3o00020000oa00o`000P00o`020?n000D0o`003_ooool4003o0003
0?n00000o`000?l000@00?l00`3oP006003o0080oh000`00o`020?n000800?l000<0oh000000o`00
0?l01000o`020?n000<00?l00P3oP005003o0080oh000P00o`020?n000D00?l0103oP0020?l00003
0000o`3oP000oh0000@0oh004P000?l00`3o0000oh000?n00002003o0080oh000P000?l3003o0080
003o0P00o`030?n000/00?l00P3oP0030000o`80o`001P000?l00`3o0000oh000?n00002003o00ko
oooo0P3o0002003o00030?n00000o`000?l000800?l0103oP0000`000?l00?l0003o00020?n00080
0?l00P3oP003003o0080oh001@000?l20?l000@0003o00<0o`00003o0000o`000P3oP0020000o`80
o`001`3oP0020000o`03003o00000?l0003o00T0003o1`3o00020000o`@00?l000<0oh000000o`00
0?l00P000?l20?l00080003o00<0o`000000o`000?l02@000?l20?l000D0003o0P00o`020000o`<0
0?l0103oP002003o00D0003o0P3o00020000o`80o`001@000?l>ooooo`800?l00P3oP003003o00@0
oh001`00o`020?n000<00?l01P3oP003003o00l0oh0000<00?l00?n0003oP0000P3oP005003o00@0
oh000P00o`020?n000P00?l0103oP004003o00<0oh001P00o`030?n00080o`00103oP0000`00o`00
oh000?n00002003o00@0oh000`00o`050?n000800?l00P3oP002003o00/0oh000`00o`020?n001So
oooo000Fooooo`@0003o00<0o`000000o`000?l0103o00020000o`030?l000000?l0003o0080003o
0P3o00020000o`D0o`000P000?lL0?l00080003o3@3o00000`000?l0o`000?l000020000o`80o`00
1@000?l40?l000D0003o0P3o00020000o`80o`000`000?l60?l000030000o`3o0000o`000180o`00
0P00o`020?n000D0o`003_ooool20?n000800?l000<0oh00003o0000o`001000o`030?n000H00?l0
0P3oP003003o0080oh000P00o`000`3oP0000?l0003o0004003o0080oh000`00o`020?n000T00?l0
0P3oP005003o00@0oh000P3o00000`000?l0oh000?n000040?n000T0003o00<00?l00000o`000?l0
10000?l3003o00H0oh000P000?l7003o00<0oh002`00o`020?n000h0003o0P00o`0>ooooo`800?l0
0P3o00000`3oP000003o0000o`020000o`@0oh0000<0o`00003o0000o`000P3oP002003o0080oh00
0`00o`020?n000D0003o103o00090000o`80o`0000<00?l00?n0003oP000103oP00<0000o`@0o`00
0`000?l20?l00080003o1000o`000`3oP000003o0000o`0B0000o`800?l010000?l00`3o00000?l0
003o00040000o`03003o003oP000oh000080oh000P00o`030000o`@0o`002@000?l>ooooo`800?l0
0P3oP003003o0080003o1@3oP004003o0080oh000`00o`020?n000800?l00P3oP003003o0080oh00
1@00o`080?n000<00?l0103oP003003o00@0oh000P00o`030?n000800?l00P3oP003003o0080oh00
1P00o`030?n000@00?l02`3oP0000`00o`00oh000?n000060?n000<0003o0P3oP002003o00030?n0
0000o`000?l000@0oh000P00o`000`3oP0000?l0003o0002003o00@0oh0000<0o`00003o0000o`00
0P00o`0Hooooo`005_ooool40000o`030?l000000?l0003o00@0o`000P000?l00`3o0000003o0000
o`020000o`80o`000P000?l50?l00080003o703o00020000o`d0o`0000<0003o0?l0003o00000P00
0?l20?l000D0003o103o00050000o`80o`000P000?l20?l000<0003o1P3o00000`000?l0o`000?l0
000B0?l000800?l00P3oP0050?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l00`3o
P006003o0080oh000`00o`020?n000800?l000<0oh00003o0000o`001000o`020?n000<00?l00P3o
P009003o0080oh001@00o`040?n00080o`0000<0003o0?n0003oP000103oP0090000o`03003o0000
0?l0003o00@0003o0`00o`060?n00080003o1`00o`030?n000/00?l00P3oP00>0000o`800?l03_oo
ool2003o0080o`0000<0oh000000o`000?l00P000?l40?n000030?l00000o`000?l00080oh000P00
o`020?n000<00?l00P3oP0050000o`@0o`002@000?l20?l00003003o003oP000oh0000@0oh003000
0?l40?l000<0003o0P3o00020000o`@00?l000<0oh000000o`000?l04P000?l2003o00@0003o00<0
o`00003o0000o`0010000?l00`00o`00oh000?n000020?n000800?l00`000?l40?l000T0003o3_oo
ool2003o0080oh000`00o`020000o`D0oh001000o`020?n000<00?l00P3oP002003o0080oh000`00
o`020?n000D00?l0203oP003003o00@0oh000`00o`040?n000800?l00`3oP002003o0080oh000`00
o`020?n000H00?l00`3oP004003o00/0oh0000<00?l00?n0003oP0001P3oP0030000o`80oh000P00
o`000`3oP0000?l0003o00040?n000800?l000<0oh00003o0000o`000P00o`040?n000030?l00000
o`000?l000800?l06?ooool001Kooooo10000?l00`3o0000003o0000o`040?l00080003o00<0o`00
0000o`000?l00P000?l>0?l000@0003o8P3o000<0000o`H0o`001`000?l40?l000<0003o5P3o0000
0`000?l0o`000?l000020000o`800?l00P3oP0030?l00080003o3_ooool20?n000800?l000<0oh00
003o0000o`001000o`020?n000`00?l00P3oP003003o0080oh002@00o`020?n001000?l0103oP003
0000o`800?l0103oP0090000o`03003o003o0000o`0000H0003o00<0oh000000o`000?l00P3oP002
003o0080003o1`00o`030?n000H00?l000<0oh00003o0000o`000P00o`020?n000<0003o1P3o0005
0000o`800?l03_ooool2003o00<0oh0010000?l20?n000T00?l00P3oP003003o0080o`001@000?l4
0?l000T0003o0P3o00000`3oP000003o0000o`020?n00080003o0P3o00000`00o`00o`000?l00002
0?n00080o`0040000?l2003o01D0003o0P00o`050?l000@0oh000P000?l00`3o0000oh000?n00002
0?n000800?l00P3oP0000`00o`00003o0000o`070000o`80oh000P000?l>ooooo`800?l00`3oP002
003o00L0oh001000o`020?n000<00?l00P3oP002003o0080oh0000<00?l00?n0003oP0001`00o`08
0?n000<00?l0103oP003003o00@0oh001000o`000`3oP0000?l0003o00020?n000800?l00`3oP002
003o00D0oh000P00o`020?n000800?l02`3oP0000`00o`00oh000?n000060?n000<0003o0P3oP005
003o00@0oh000P00o`000`3oP0000?l0003o00090?n000800?l06?ooool001Kooooo10000?l00`3o
0000003o0000o`020000o`80o`000P000?l00`3o0000003o0000o`020000o`@0o`0000<0003o003o
0000o`001`3o00040000ob80o`000`000?l40?l00080003o0P3o00000`000?l0o`000?l000060?l0
00<0003o1P3o00030000o`80o`000P000?lC0?l000@0003o0P00o`020?n000030?l00000o`000?l0
0080003o3_ooool;003o0080oh007000o`020?n001000?l00P3oP0020?l000D0003o103oP0090000
o`<0o`000P000?l2003o0080003o00<0oh000000o`000?l00P3oP002003o00<0oh002000o`000`3o
P0000?l0003o00020?l000L00?l00P3oP002003o00030?l000000?l0003o0080003o0P3o00050000
o`800?l03_ooool2003o00<0oh000P000?l2003o0080oh000`00o`020?n000@00?l00`3oP002003o
00@0o`001@000?l20?l00080003o00<0o`000000o`000?l00P000?l20?l000T0003o1@3o00020000
o`80o`002P000?l20?l000H0003o00<00?l00000o`000?l00P000?l20?l000<0003o0P00o`070000
o`80o`000P00o`020?l00080003o00<0o`000000o`000?l00P3oP0020000o`030?l0003oP000oh00
0080oh000P00o`030?n000T0003o0P3o00020000o`kooooo0P00o`030?n000800?l00P3o00050?n0
00800?l0103oP003003o0080oh000P00o`020?n00003003o003oP000oh000080oh001@00o`040?n0
00800?l00P3oP003003o00H0oh0000<00?l00?n0003oP0000P3oP004003o00030?n00000o`000?l0
0080oh000P00o`030?n000800?l01@3oP002003o0080oh0010000?l30?n000800?l00P3oP0020000
o`03003o003oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP002003o00030?n00000o`000?l0
00/0oh001000o`000`3oP0000?l0003o0002003o01Sooooo000Fooooo`@0003o00<0o`000000o`00
0?l00P000?l20?l00080003o00<0o`000000o`000?l00P000?l40?l000030000o`00o`000?l000L0
o`0010000?lR0?l000<0003o103o00020000o`80o`0000<0003o0?l0003o00001P3o00030000o`H0
o`000`000?l20?l00080003o4`3o00040000o`800?l00P3oP0000`3o00000?l0003o00020000o`ko
oooo2`00o`020?n001`00?l00P3oP00@003o0080oh000P3o00050000o`@0oh002@000?l30?l00080
003o0P00o`020000o`030?n000000?l0003o0080oh000P00o`030?n000P00?l000<0oh00003o0000
o`000P3o0007003o0080oh000P00o`000`3o0000003o0000o`020000o`80o`001@000?l2003o00ko
oooo0P00o`030?n00080003o0P00o`020?n000<00?l00P3oP004003o00<0oh000P00o`040?l000D0
003o0P3o00020000o`030?l000000?l0003o0080003o0P3o00090000o`D0o`000P000?l20?l000X0
003o0P3o00060000o`03003o00000?l0003o0080003o0P3o00030000o`800?l01`000?l20?l00080
0?l00P3o00020000o`030?l000000?l0003o0080oh000P000?l00`3o0000oh000?n000020?n00080
0?l00`3oP0090000o`80o`000P000?l>ooooo`800?l00`3oP002003o0080o`001@3oP002003o00@0
oh000`00o`020?n000800?l00P3oP0000`00o`00oh000?n000020?n000D00?l0103oP002003o0080
oh000`00o`060?n00003003o003oP000oh000080oh001000o`000`3oP0000?l0003o00020?n00080
0?l00`3oP002003o00D0oh000P00o`020?n000@0003o0`3oP002003o0080oh000P000?l00`00o`00
oh000?n000060?n000030?l0003oP000oh000080oh000P00o`000`3oP0000?l0003o000;0?n000@0
0?l000<0oh00003o0000o`000P00o`0Hooooo`005_ooool20000o`800?l000<0o`000000o`000?l0
0P000?l70?l00080003o3P3o00040000oaT0o`000P000?lG0?l00080003o0P3o00000`000?l0o`00
0?l000020000o`@0o`001`000?lG0?l000800?l00`000?l20?l00080003o3_ooool;003o0080oh00
;000o`020?n000T0003o1@3oP0060000o`80o`000`000?l2003o0080o`001@000?l20?n000800?l0
0`3oP008003o00<0oh000P3o00020?n00003003o003oP000oh0000800?l0103oP0000`00o`00003o
0000o`070000o`@0oh003_ooool20?l000<0oh001000o`020?n000D00?l00P3oP004003o00030?n0
00000?l0003o0080o`000`000?l60?l000L0003o103o00000`000?l0oh000?n0000;0000o`80o`00
2P000?l20?l00100003o0P00o`060000o`<0o`000P000?l20?l00080003o00<0o`00003o0000o`00
0P3oP003003o0080oh001000o`030?n000P0003o00<0o`000000o`000?l00P000?l>ooooo`800?l0
0`3oP002003o00L0oh001000o`040?n00003003o003oP000oh0000D00?l00P3oP007003o0080oh00
1000o`020?n000<00?l01P3oP0000`00o`00oh000?n000020?n000@00?l000<0oh00003o0000o`00
1`3oP002003o00D0oh000P00o`090?n000800?l00P3oP0020000o`030?l0003oP000oh0000H0oh00
00<0003o0?l0003o00001000o`000`3oP0000?l0003o0002003o00T0oh001000o`050?n001Sooooo
000Fooooo`80003o0P00o`000`3o0000003o0000o`020000o`L0o`000P000?l>0?l000@0003o6@3o
00020000oaL0o`000P000?l20?l000030000o`3o0000o`000080003o103o00070000oaL0o`000P00
o`030000o`80o`000P000?l>ooooo`/00?l00P3oP00/003o0080oh002@000?l50?n000H0003o0P3o
00030000o`800?l00P3o00050000o`80oh000P00o`030?n000P00?l00`3oP0020?l00080oh0000<0
0?l00?n0003oP0000P00o`040?n00003003o00000?l0003o00L0003o103oP00>ooooo`80o`000`3o
P004003o0080oh001@00o`020?n000@00?l000<0oh000000o`000?l00P3o00030000o`H0o`001`00
0?l40?l000030000o`3oP000oh0000/0003o0P3o000:0000o`80o`0040000?l2003o00H0003o0`3o
00020000o`80o`000P000?l00`3o00000?l0003o00020?n000<00?l00P3oP004003o00<0oh002000
0?l00`3o0000003o0000o`020000o`kooooo0P00o`030?n000800?l01`3oP004003o00@0oh0000<0
0?l00?n0003oP0001@00o`020?n000L00?l00P3oP004003o0080oh000`00o`060?n00003003o003o
P000oh000080oh001000o`000`3oP0000?l0003o00070?n000800?l01@3oP002003o00T0oh000P00
o`020?n00080003o00<0o`000?n0003oP0001P3oP0000`000?l0o`000?l00004003o00030?n00000
o`000?l000800?l02@3oP004003o00D0oh006?ooool001Kooooo10000?l00`3o0000003o0000o`07
0?l000@0003o3P3o00040000o`D0o`000P000?lB0?l00080003o6`3o000@0000o`X0o`002@000?l2
0?l00080003o0P00o`030000o`@0o`003_ooool;003o0080oh004`00o`020?n001800?l00P3oP003
003o0080oh002@000?l50?n000/0003o0P00o`020?l00080003o00<0o`000000o`000?l00P3oP002
003o00<0oh002000o`030?n000@0003o00<0oh00003o0000o`001000o`020?n00003003o00000?l0
003o00H0003o00<0o`000?n0003oP0000P3oP00>ooooo`80o`000`3oP0020?l00080oh000P00o`02
0?n000<0003o103oP002003o00030?n000000?l0003o00800?l00`3oP00A0000o`<00?l00P3o0009
0000o`80o`001`000?l30?l000800?l02`000?l20?l00080003o00<0o`00003o0000o`001P000?l0
0`3o0000003o0000o`020000o`80o`000P000?l00`3o00000?l0003o00020?n000<00?l00P3oP004
003o00<0oh001P000?l2003o00030?l000000?l0003o0080o`003_ooool2003o00<0oh000P00o`07
0?n000@00?l0103oP0000`00o`00oh000?n00007003o0080oh001@00o`020?n000800?l0103oP003
003o00H0oh0000<00?l00?n0003oP0000P3oP002003o00<0oh000P00o`070?n000800?l0103oP003
003o00@0oh000P00o`030?n00080o`00103oP0000`00o`00oh000?n000020?n000800?l00P3oP000
0`000?l00?l0003o0004003o00030?n00000o`000?l000@00?l00P3oP0000`00o`00oh000?n00002
0?n000@00?l01@3oP00Hooooo`005_ooool40000o`030?l000000?l0003o00L0o`0010000?l>0?l0
00@0003o1@3o00020000oa80o`000P000?lK0?l00100003o2P3o00090000o`80o`000P000?l2003o
00<0003o103o000>ooooo`/00?l00P3oP00C003o0080oh004P00o`020?n000<00?l00P3oP0090000
o`D0oh002`000?l2003o0080o`000P000?l00`3o0000003o0000o`020?n000800?l00`3oP008003o
00<0oh0010000?l00`3oP0000?l0003o0004003o0080oh0000<00?l00000o`000?l01P000?l00`3o
0000oh000?n000020?n000kooooo0P3o00030?n00080o`000P3oP002003o0080oh000`000?l40?n0
00800?l000<0oh000000o`000?l00P00o`030?n00140003o0`00o`020?l000T0003o0P3o00070000
o`<0o`000P00o`0;0000o`80o`000P000?l00`3o00000?l0003o00060000o`030?l000000?l0003o
0080003o0P3o00020000o`030?l00000o`000?l00080oh000`00o`020?n000@00?l00`3oP0060000
o`800?l000<0o`000000o`000?l00P3o000>ooooo`800?l00`3oP002003o00L0oh001000o`040?n0
0003003o003oP000oh0000L00?l00P3oP005003o0080oh000P00o`040?n000<00?l01P3oP0000`00
o`00oh000?n000020?n000800?l00`3oP002003o00L0oh000P00o`040?n000<00?l0103oP002003o
00<0oh000P3o00040?n00003003o003oP000oh000080oh000P00o`020?n000030000o`00o`000?l0
00@00?l000<0oh00003o0000o`001000o`020?n00003003o003oP000oh000080oh001000o`050?n0
01Sooooo000Fooooo`80003o0P00o`070?l00080oh000`000?l90?l00080003o1@3o00040000o`D0
o`000P000?l70?l00080003o2@3o00020000oa/0o`003P000?l20?l000D0003o103o000:0000o`80
o`000P000?l20?l00080003o1@3o000>ooooo`/00?l00P3oP00C003o0080oh004000o`040?n000<0
0?l00P3oP0070000o`@00?l00P3oP0070000o`80o`000`000?l2003o00@0003o00<0o`00003o0000
o`000P3oP002003o00<0oh0010000?l20?n000800?l00`3oP0040000o`030?n00000o`000?l000@0
0?l00`3oP0080000o`D00?l03_ooool20000o`800?l000<0003o0?l0003o00000P3oP002003o00D0
003o0P3o00020?n000800?l000<0oh000000o`000?l00P00o`020?l000030?n0003o0000o`000080
003o0P3oP00;0000o`D00?l00P3oP0020000o`03003o00000?l0003o00h0003o0P00o`0;0000o`80
o`005@000?l2003o0080oh000`000?l40?n000800?l00P3oP0050000o`80o`000P00o`030000o`80
o`003_ooool2003o0080oh000`00o`070?n000@00?l0103oP0000`00o`00oh000?n000020?n00080
0?l000<0oh00003o0000o`001P3oP003003o00L0oh000P00o`060?n000<00?l0103oP002003o0003
0?n00000o`000?l000800?l02`3oP003003o00@0oh000P00o`000`3oP0000?l0003o0002003o00@0
oh000`00o`020?n000800?l00P3oP007003o00L0oh000P00o`050?n000@00?l000<0oh00003o0000
o`000P3oP00Hooooo`005_ooool20000o`800?l01`3o00020?n000<0003o2@3o00020000o`D0o`00
10000?l50?l00080003o1`3o00020000o`T0o`000P000?lK0?l000h0003o0P3o00050000o`@0o`00
2P000?l20?l00080003o0P3o00020000o`D0o`003_ooool;003o0080oh004`00o`020?n001000?l0
103oP003003o0080oh001`000?l4003o0080oh001`000?l20?l000<0003o0P00o`040000o`030?l0
0000o`000?l00080oh000P00o`030?n000@0003o0P3oP002003o00<0oh0010000?l00`3oP0000?l0
003o0004003o00<0oh0020000?l5003o00kooooo0P000?l2003o00030000o`3o0000o`000080oh00
0P00o`050000o`80o`000P3oP002003o00030?n000000?l0003o00800?l00P3o00000`3oP000o`00
0?l000020000o`80oh002`000?l5003o0080oh000P000?l00`00o`00003o0000o`0>0000o`800?l0
2`000?l20?l001D0003o0P00o`020?n000<0003o103oP002003o0080oh001@000?l20?l000800?l0
0`000?l20?l000kooooo0P00o`020?n000<00?l01`3oP004003o00@0oh0000<00?l00?n0003oP000
0P3oP002003o00030?n00000o`000?l000H0oh000`00o`070?n000800?l01P3oP003003o00@0oh00
0P00o`000`3oP0000?l0003o0002003o00/0oh000`00o`040?n000800?l000<0oh00003o0000o`00
0P00o`040?n000<00?l00P3oP002003o0080oh001`00o`070?n000800?l01@3oP004003o00030?n0
0000o`000?l00080oh006?ooool001Kooooo0P000?l2003o00L0o`000P00o`0:0?l000800?l01`3o
00040000o`D0o`000P00o`070?l00080003o9P3o00050000o`80o`001`000?l20?l000D0003o103o
00090000o`h0o`003_oooolM003o00030?n00000o`000?l00080oh004000o`020?n000D00?l00P3o
P0060000o`D00?l00P3oP0070000o`80o`000`000?l2003o00D0003o2000o`050000o`@00?l00`3o
P0040000o`030?n00000o`000?l000@00?l00`3oP002003o00H0oh001@00o`0>ooooo`80003o0P00
o`000`3oP0000?l0003o00020000o`800?l01@000?l20?l000@00?l000<0oh000000o`000?l0103o
00050000o`800?l02`000?l00`3o00000?l0003o00040?n000<00?l0103oP0020000o`<0o`000P00
0?l2003o00<0003o0P3o00020000o`D0o`0060000?l2003o00030000o`00o`000?l00080oh000`00
0?l20?n000@00?l00P3oP0050000o`@00?l01@000?l>ooooo`800?l00P3oP0000`00o`00oh000?n0
00060?n000<00?l01P3oP0000`00o`00oh000?n000020?n000800?l00`3oP002003o00D0oh000P00
o`060?n00003003o003oP000oh0000@0oh000P00o`000`3oP0000?l0003o00020?n000@00?l000<0
oh00003o0000o`000P00o`020?n00003003o003oP000oh0000H0oh000`00o`020?n000@00?l000<0
oh00003o0000o`00103oP003003o00@0oh000P00o`020?n000<00?l00P3oP003003o00@0oh001000
0?l00`00o`00oh000?n000040?n000800?l01@3oP00Hooooo`005_ooool40000oa<0o`000P00o`07
0?l000@0003o1@3o0002003o02d0o`000P000?l00`3o0000003o0000o`020000o`80o`000`000?l2
0?l00080003o1@3o00020000o`@0o`0000<0003o0?l0003o00001P000?l:0?l00080oh000P3o000>
oooooad00?l000<0oh00003o0000o`004000o`020?n000L00?l0103oP0040000o`03003o003oP000
oh000080oh002@000?l30?l000800?l00P3o00050000o`P00?l01@000?l4003o00030000o`3oP000
oh0000@0003o00<0oh00003o0000o`001000o`030?n000800?l01`3oP004003o00kooooo0P3o0002
003o00D0003o0P00o`050000o`@0oh000P00o`030000o`@0o`0000<0003o003o0000o`001000o`09
0000o`80o`0000<0003o003o0000o`00103oP002003o00D0oh002@3o00020000o`03003o003o0000
o`0000@0o`000`3oP0080000o`030?l000000?l0003o00d0003o0P3o00080000o`80oh001P000?l3
0?l00080003o0P3o0002003o00D0003o3_ooool2003o0080oh0000<00?l00?n0003oP0001P3oP003
003o00H0oh0000<00?l00?n0003oP0000P3oP005003o00L0oh000P00o`040?n000<00?l01P3oP002
003o00030?n00000o`000?l00080oh001000o`030?n000800?l00P3oP0000`00o`00oh000?n00002
0?n000800?l00P3oP003003o0080oh001000o`000`3oP0000?l0003o0002003o00L0oh001000o`02
0?n000<00?l0103oP0000`00o`00oh000?n000020?n000D0003o1P3oP003003o00@0oh006?ooool0
01Kooooo10000?lC0?l000800?l01`3o00040000o`D0o`000P00o`0]0?l00080003o00<0o`000000
o`000?l00P000?l20?l000<0003o0P3o00020000o`D0o`000P000?l40?l000030000o`3o0000o`00
00H0003o2P3o00020?n00080o`003_oooolM003o00030?n00000o`000?l001000?l00P3oP007003o
00@0oh0010000?l00`00o`00oh000?n000020?n000T0003o0`3o0002003o0080o`001@000?l8003o
00D0003o1000o`000`000?l0oh000?n000040000o`030?n00000o`000?l000@00?l00`3oP002003o
00L0oh001000o`0>ooooo`80o`000P00o`050000o`800?l01@000?l40?n000800?l00`000?l40?l0
00030000o`00o`000?l000@00?l02@000?l20?l000030000o`00o`000?l000@0oh000P00o`050?n0
00T0o`000P000?l00`00o`00o`000?l000040?l000<0oh0020000?l00`3o0000003o0000o`0=0000
o`80o`0020000?l20?n000H0003o0`3o00020000o`80o`000P00o`050000o`kooooo0P00o`020?n0
0003003o003oP000oh0000H0oh000`00o`060?n00003003o003oP000oh000080oh001@00o`070?n0
00800?l0103oP003003o00H0oh000P00o`000`3oP0000?l0003o00020?n000@00?l00`3oP002003o
0080oh0000<00?l00?n0003oP0000P3oP002003o0080oh000`00o`020?n000@00?l000<0oh00003o
0000o`000P00o`070?n000@00?l00P3oP003003o00@0oh0000<00?l00?n0003oP0000P3oP0050000
o`H0oh000`00o`040?n001Sooooo000Fooooo`80003o1`3o00020000oah0o`000P00o`020000obh0
o`001P000?l50?l00080003o1@3o00040000oaD0o`000P3oP0020?l000kooooo7@00o`000`3oP000
0?l0003o00020?l00080oh003000o`020?n00080003o1@00o`040?n000@0003o00<00?l00?n0003o
P0000P3oP0070000o`80o`000P00o`000`3oP000003o0000o`070000o`/00?l00P3oP0020?l00080
0?l01`000?l00`3oP0000?l0003o0004003o00<0oh000P00o`020?n000800?l00P000?l30?n00080
0?l03_ooool20000o`<0oh000P00o`020?n000800?l00P3oP0030000o`800?l00P3oP002003o00<0
003o0P3o000I0000o`80oh000P00o`000`3oP000003o0000o`020000o`80o`000`000?l20?l000@0
003o00<00?l00000o`000?l00P000?l20?l000L0003o0P3oP002003o00030?l000000?l0003o00d0
003o0P3o00070000o`030?l000000?l0003o00H0003o00<0o`000000o`000?l00P000?l20?l000L0
003o3_ooool4003o00<0oh000P00o`040?n00003003o003oP000oh000080oh000P00o`020?n000<0
0?l00P3oP003003o0080oh000P00o`050?n000800?l0103oP003003o00T0oh000P00o`020?n00080
0?l01@3oP002003o0080oh000`00o`060?n00003003o003oP000oh000080oh001000o`000`3oP000
0?l0003o00020?n000@00?l00`3oP004003o0080oh0000<00?l00?n0003oP0000P3oP003003o00@0
oh001@000?l20?n000800?l00P3oP003003o00@0oh006?ooool001Kooooo0P000?l70?l00080003o
7P3o0002003o0080003o;P3o00060000o`D0o`000P000?l50?l000@0003o5@3o00020?n00080o`00
3_oooolM003o00030?n00000o`000?l00080o`000P3oP00<003o0080oh000P000?l5003o00@0oh00
10000?l00`00o`00oh000?n000020?n000L0003o0P3o0002003o00030?n000000?l0003o00L0003o
2`00o`020?n00080o`000P00o`070000o`030?n00000o`000?l000@00?l00`3oP002003o0080oh00
0P00o`020000o`<0oh000P00o`0>ooooo`80003o0`3oP002003o0080oh000P00o`020?n000<0003o
0P00o`020?n000800?l00`000?l20?l001T0003o0P3oP002003o00030?n000000?l0003o0080003o
0P3o00030000o`80o`0010000?l00`00o`00003o0000o`020000o`80o`001`000?l20?n000800?l0
00<0o`000000o`000?l03@000?l20?l000L0003o00<0o`000000o`000?l01P000?l00`3o0000003o
0000o`020000o`80o`001`000?l>ooooo`@00?l00`3oP002003o00@0oh0000<00?l00?n0003oP000
0P3oP002003o0080oh000`00o`020?n000<00?l00P3oP002003o00D0oh000P00o`040?n000<00?l0
2@3oP002003o0080oh000P00o`050?n000800?l00P3oP003003o00H0oh0000<00?l00?n0003oP000
0P3oP004003o00030?n00000o`000?l00080oh001000o`030?n000@00?l00P3oP0000`00o`00oh00
0?n000020?n000<00?l0103oP0050000o`80oh000P00o`020?n000<00?l0103oP00Hooooo`005_oo
oolf0?l00080oh007P3o00020000o`D0o`000P000?l50?l000P0003o00<0o`000000o`000?l06`3o
000>oooooad00?l000<0oh000000o`000?l010000?l<003o0080oh001`00o`040?n000@0003o00<0
0?l00?n0003oP0000P3oP0030000o`80o`0010000?l20?l000X0003o0P00o`020000o`D00?l01P3o
P002003o00030?n000000?l0003o00@00?l000<0oh00003o0000o`000P00o`020?n000800?l000<0
oh00003o0000o`000P3oP0040000o`<0oh000P00o`0>ooooo`80003o0P3oP0000`00o`00oh000?n0
0004003o00D0003o0P00o`020?n000800?l000<0oh000000o`000?l00P3oP0070000o`80o`001@00
0?l2003o00d0003o00<0oh000000o`000?l040000?l40?l000L0003o103oP0000`3o0000003o0000
o`090000o`80oh000P00o`020?l00003003o00000?l0003o00L0003o0P3o00040000o`030?l00000
0?l0003o00L0003o0P00o`020000o`kooooo1000o`030?n000@00?l00`3oP002003o00H0oh000`00
o`020?n000L00?l0103oP003003o00@0oh000`00o`090?n000800?l00P3oP002003o00X0oh000P00
o`040?n000<00?l0103oP004003o00030?n00000o`000?l000@0oh000P00o`050?n000D00?l0103o
P002003o00<0oh000P00o`020?n000<00?l00P3oP002003o00T0oh006?ooool001Kooooo=P3o0002
0?n001h0o`000P000?l50?l00080003o1@3o00080000o`030?l000000?l0003o01/0o`003_oooolM
003o00030?n000000?l0003o00@0003o3000o`020?n000L00?l0103oP0040000o`03003o003oP000
oh000080oh000`000?l20?l000@0003o0P3o000:0000o`800?l00P000?l5003o00H0oh000P00o`00
0`3oP000003o0000o`04003o00030?n00000o`000?l000800?l00P3oP002003o00030?n00000o`00
0?l00080oh0010000?l30?n000800?l03_ooool20000o`80oh0000<00?l00?n0003oP0001000o`05
0000o`800?l00P3oP002003o00030?n000000?l0003o0080oh001`000?l20?l000D0003o0P00o`0=
0000o`030?n000000?l0003o0100003o103o00070000o`@0oh0000<0o`000000o`000?l02@000?l2
0?n000800?l00P3o00000`00o`00003o0000o`070000o`80o`0010000?l00`3o0000003o0000o`07
0000o`800?l00P000?l>ooooo`@00?l00`3oP004003o00<0oh000P00o`060?n000<00?l00P3oP007
003o00@0oh000`00o`040?n000<00?l02@3oP002003o0080oh000P00o`0:0?n000800?l0103oP003
003o00@0oh001000o`000`3oP0000?l0003o00040?n000800?l01@3oP005003o00@0oh000P00o`03
0?n000800?l00P3oP003003o0080oh000P00o`090?n001Sooooo000Foooooc00o`000P000?l20?l0
0080003o:@3o00020000o`<0o`0020000?l<0?l00080003o1`3o0002003o00L0o`003_oooolM003o
00030?n000000?l0003o00@0003o3000o`020?n000L00?l00P3oP0070000o`800?l00P3oP0020000
o`030?l000000?l0003o0080o`001@000?l20?l000L0003o0P00o`020000o`80oh000`00o`060?n0
00800?l000<0oh000000o`000?l00P000?l2003o00<0oh001P00o`050?n00080003o0P3o00030?n0
00800?l03_ooool5003o0080oh001000o`020?n000030000o`00o`000?l000800?l00P3oP005003o
0080oh000`000?l20?l00080003o0P3o00030000o`80o`002`000?l5003o0100003o1P3o00050000
o`80o`00103oP00<0000o`@00?l00P3oP003003o00D0003o1000o`020?n000/0003o00<0o`00003o
0000o`000P000?l>ooooo`@00?l00`3oP004003o00/0oh0000<00?l00?n0003oP0000P3oP009003o
00<0oh000P00o`040?n000D00?l0103oP002003o00030?n00000o`000?l000H0oh0000<00?l00?n0
003oP0003@3oP0000`00o`00oh000?n00004003o00<0oh000P00o`020?n000@00?l000<0oh00003o
0000o`000P3oP004003o01<0oh000P00o`050?n00080o`000P3oP00Hooooo`005_oooolN0?l00080
003o1`3o00040000o`D0o`000P000?lT0?l00080003o1`3o00020000o`80o`001@000?l40?l00003
0000o`3o0000o`0001H0o`0000<0003o0?l0003o00000P000?l>ooooo`800?l00P3oP00I003o0003
0?n000000?l0003o00@0003o3000o`020?n000800?l00P3o00020?n00003003o003oP000oh0000L0
003o0P00o`020?n000800?l000<0o`000000o`000?l050000?l20?n000D00?l0103oP002003o0003
0?n000000?l0003o0080003o0`00o`020?n000L00?l01P000?l20?l000<0oh000P00o`0>ooooo`D0
0?l00P3oP004003o0080oh0000<0003o003o0000o`000P00o`050?n000800?l00P3oP0050000o`80
o`000P000?l50?l000H0oh000`000?l20?l000D00?l00P3o00020?n000@0o`0000<0003o0?l0003o
0000103o00000`000?l0o`000?l0000;0000o`800?l040000?l2003o0080o`001@00o`030000o`@0
0?l0103oP00>0000o`kooooo0P00o`020?n000<00?l00P3oP002003o00<0oh000P00o`060?n00003
003o003oP000oh000080oh000`00o`020?n000800?l01@3oP002003o00L0oh000P00o`070?n00080
0?l01P3oP003003o00D0oh001000o`020?n000800?l00`3oP006003o00D0oh001000o`000`3oP000
0?l0003o000>0?n000800?l01P3oP0000`00o`00oh000?n00002003o00D0oh000P3o00020?n001So
oooo000Foooooah0o`000P000?l70?l000@0003o1@3o00020000ob@0o`000P000?l70?l00080003o
0P3o00050000o`@0o`0000<0003o0?l0003o00005P3o00000`000?l0o`000?l000020000o`kooooo
0P00o`020?n001T00?l000<0oh000000o`000?l010000?l<003o0080oh000P00o`020?l00080oh00
00<00?l00?n0003oP0001`000?l2003o0080oh000P00o`000`3o0000003o0000o`0D0000o`80oh00
1@00o`040?n000800?l000<0oh000000o`000?l00P000?l3003o0080oh001`00o`060000o`80o`00
0`3oP002003o00kooooo1@00o`020?n000@00?l00P3oP0000`000?l00?l0003o0002003o00D0oh00
0P00o`020?n000D0003o0P3o00020000o`D0o`001P3oP0030000o`80o`001@00o`020?l00080oh00
103o00000`000?l0o`000?l000040?l000030000o`3o0000o`0000/0003o0P00o`0@0000o`800?l0
0P3o0005003o00<0003o1000o`040?n000h0003o3_ooool2003o0080oh000`00o`020?n000800?l0
0`3oP002003o00H0oh0000<00?l00?n0003oP0000P3oP003003o0080oh000P00o`050?n000800?l0
1`3oP002003o00L0oh000P00o`060?n000<00?l01@3oP004003o0080oh000P00o`030?n000H00?l0
1@3oP004003o00030?n00000o`000?l000h0oh000P00o`060?n00003003o003oP000oh0000800?l0
1@3oP0020?l00080oh006?ooool001Kooooo0P000?l20?l000<00?l0803o00040000o`D0o`000P00
0?lK0?l00080003o403o00020000o`<0o`0010000?l40?l000030000o`3o0000o`000080o`000P00
0?l00`3o00000?l0003o000?0?l000D0003o3_oooolF003o00030?n00000o`000?l000@00?l000<0
oh000000o`000?l00P000?l20?n000800?l000<0oh00003o0000o`001000o`020?n00003003o003o
P000oh0000@00?l00P3oP0000`00o`00oh000?n0000F0000o`<0o`000P3oP0070000o`80oh000P00
o`020?n000<00?l00P3oP004003o00030?n00000o`000?l00080o`000P00o`030?n000@00?l00P3o
P0000`00o`00003o0000o`060000o`D00?l03_ooool5003o0080oh001000o`030?n000@00?l0103o
P0030000o`@0oh002@000?l30?l000800?l01@3oP0040?l000D00?l00P3oP0040000o``0o`001P00
0?l00`3o0000003o0000o`020000o`800?l04P000?l20?l000D00?l00`000?l20?l000800?l00P3o
P002003o00h0003o3_ooool5003o00@0oh000P00o`030?n000800?l0103oP003003o00@0oh000`00
o`020?n000H00?l00`3oP002003o00@0oh000`00o`070?n000800?l01P3oP003003o00D0oh001000
o`020?n000<00?l00P3oP002003o0080oh000`00o`040?n000@00?l000<0oh00003o0000o`001P3o
P0000`000?l0o`000?l00002003o0080oh000`3o00090?n000800?l0103oP0000`000?l0o`000?l0
00020?n001Sooooo000Fooooo`80003o0P3o0003003o0200o`0010000?l50?l00080003o6`3o0002
0000oa00o`000P000?l30?l000@0003o103o00000`000?l0o`000?l000020?l00080003o00<0o`00
003o0000o`003`3o00050000o`kooooo5P00o`000`3oP0000?l0003o0004003o00030?n000000?l0
003o0080003o0P3oP002003o00030?n00000o`000?l000@00?l00P3oP0000`00o`00oh000?n00004
003o0080oh0000<00?l00?n0003oP0005P000?l30?l00080oh001`000?l20?n000800?l00P3oP003
003o0080oh001000o`000`3oP0000?l0003o00020?l000800?l00`3oP004003o0080oh0000<00?l0
0000o`000?l01P000?l5003o00kooooo1@00o`020?n000@00?l00`3oP004003o00@0oh000`000?l4
0?n000T0003o0`3o0002003o00D0oh00103o0005003o0080oh0010000?l<0?l000H0003o00<0o`00
0000o`000?l00P000?l2003o0180003o0P3o0005003o00<0003o0P3o0002003o0080oh000P00o`0>
0000o`kooooo1@00o`040?n000800?l00`3oP002003o00@0oh000`00o`040?n000<00?l00P3oP006
003o00<0oh000P00o`040?n000<00?l01`3oP002003o00H0oh000`00o`050?n000@00?l00P3oP003
003o0080oh000P00o`020?n000<00?l0103oP004003o00030?n00000o`000?l000H0oh0000<0003o
0?l0003o00000P00o`020?n000<0o`002@3oP002003o00@0oh0000<0003o0?l0003o00000P3oP00H
ooooo`005_ooool20000o`80o`000`00o`160?l00080003o403o00020000o`<0o`0010000?l40?l0
00030000o`3o0000o`0001@0o`001`000?l>oooooad00?l000<0oh00003o0000o`000P000?l20?n0
00800?l000<0oh00003o0000o`000P3oP004003o00<0oh001000o`020?n00003003o003oP000oh00
00T0003o0P3oP002003o00`0003o0P00o`070000o`80oh000P00o`020?n000T00?l00`3oP0020?l0
00800?l02@3oP0030?l000H0003o1@00o`0>ooooo`800?l00P3o00000`00o`00oh000?n00004003o
00<0oh000P00o`020?l00080oh000`000?l2003o00@0oh002P000?l20?l000H00?l000<0003o0?l0
003o00001`00o`020?n000@0003o0`00o`040000o`<0o`0020000?l00`3o0000003o0000o`040000
o`80o`002@000?l00`00o`00003o0000o`060000o`030?n00000o`000?l00080o`000`000?l20?l0
00H00?l03P000?l>ooooo`80oh000`00o`040?n000800?l00`3oP002003o00@0oh000`00o`060?n0
0003003o003oP000oh000080oh002`00o`030?n000800?l01`3oP002003o0080oh000P00o`020?n0
00<00?l01@3oP004003o0080oh000`000?l20?n000800?l0103oP0000`00o`00oh000?n000040?n0
0080003o1@3oP0020?l000<0003o1P3oP0030?l000@0oh000P00o`030?n000800?l0103oP0000`00
0?l0o`000?l000020?n001Sooooo000Fooooo`80003o0P3o0003003o04H0o`000P000?l@0?l00080
003o0`3o00040000o`@0o`0000<0003o0?l0003o0000503o00070000o`kooooo7@00o`000`3oP000
0?l0003o00020000o`80oh000P00o`000`3oP0000?l0003o00020?n000@00?l00`3oP004003o0080
oh0000<00?l00?n0003oP0002@000?l20?n000800?l030000?l2003o00L0003o0P3oP002003o0080
oh002@00o`030?n00080o`000P00o`090?n000<0o`001P000?l5003o00kooooo0P00o`020?l00003
003o003oP000oh0000@00?l00`3oP002003o0080o`000P3oP0030000o`800?l0103oP00:0000o`80
o`001P00o`000`000?l0o`000?l00007003o0080oh0010000?l3003o00@0003o0`3o00080000o`03
0?l000000?l0003o00@0003o0P3o00090000o`03003o00000?l0003o00H0003o00<0oh00003o0000
o`000P3o00030000o`80o`001P00o`0>0000o`kooooo0P3oP003003o00@0oh000P00o`030?n00080
0?l0103oP003003o00H0oh0000<00?l00?n0003oP0000P3oP00;003o00<0oh000P00o`070?n00080
0?l00P3oP002003o0080oh000`00o`050?n000@00?l00P3oP0030000o`80oh000P00o`040?n00003
003o003oP000oh0000@0oh000P000?l50?n00080o`000`000?l60?n000<0o`00103oP002003o00<0
oh000P00o`040?n000030000o`3o0000o`000080oh006?ooool001Kooooo0P000?l20?l00003003o
003o0000o`000100o`000P000?lG0?l000H0oh00:@3o00020000o`<0o`0010000?l20?l00080003o
5`3o00070000o`kooooo8P00o`020?n000800?l000<0oh00003o0000o`000P3oP004003o00L0oh00
0`00o`040?n00080o`000`000?l2003o00D0oh000P3o00040000o`80o`000`000?l2003o00D0003o
0P3oP0020000o`800?l00P3oP009003o00<0oh000P3o0002003o00<0oh000P00o`040?n000D0003o
1`00o`020?n000kooooo0P000?l20?l00003003o003oP000oh0000H0003o00<0oh000?l0003o0000
0P3o0002003o0080oh0000<0003o0?n0003oP000103oP00>0000o`D00?l00P3oP0020?l000@0003o
00<00?l00?n0003oP00010000?l2003o0100003o00<0o`000000o`000?l010000?l20?l000T0003o
00<00?l00000o`000?l010000?l2003o00030?n0003o0000o`000080o`000P000?l50?l00080oh00
0P00o`000`3o0000003o0000o`0;0000o`kooooo0P3oP003003o00T0oh001000o`020?n000<00?l0
1P3oP0000`00o`00oh000?n000040?n000<00?l00P3oP004003o00D0oh000P00o`040?n000<00?l0
0P3oP007003o00@0oh0000<00?l00?n0003oP000103oP0050000o`800?l00P3o00020?n000<00?l0
0P3oP002003o0080003o1@3oP0040?l000P0oh000P3o00040?n000800?l00`3oP002003o00@0oh00
00<00?l00?l0003o00000P3oP00Hooooo`005_ooool20000o`80o`0000<00?l00?l0003o0000403o
00020000oaL0o`001P3oP00Y0?l00080003o0`3o00040000o`80o`000P000?lG0?l000L0003o3_oo
oolR003o0080oh000P00o`000`3oP0000?l0003o00020?n000@00?l01`3oP003003o00@0oh000P3o
00030000o`800?l01@3oP0020?l000@0003o0P3o00030000o`800?l01@000?l20?n00080003o0P00
o`020?n000T00?l00`3oP0020?l000800?l00`3oP002003o00@0oh001@000?l7003o0080oh003_oo
ool20000o`80o`0000<00?l00?n0003oP0001P000?l00`3oP000o`000?l000020?l000800?l00P3o
P0000`000?l0oh000?n000040?n000h0003o1@00o`020?n00080o`0010000?l00`00o`00oh000?n0
00040000o`800?l040000?l00`3o0000003o0000o`040000o`80o`002@000?l00`00o`00003o0000
o`040000o`800?l000<0oh000?l0003o00000P3o00020000o`D0o`000P3oP002003o00030?l00000
0?l0003o00/0003o3_ooool20?n000<00?l02@3oP004003o0080oh000`00o`060?n00003003o003o
P000oh0000@0oh000`00o`020?n000@00?l01@3oP002003o00@0oh000`00o`020?n000L00?l0103o
P0000`00o`00oh000?n000040?n000D0003o0P00o`020?l00080oh000`00o`020?n000800?l00P00
0?l50?n000@0o`00203oP0020?l000@0oh000P00o`030?n000800?l0103oP0000`00o`00o`000?l0
00020?n001Sooooo000Fooooo`800?l00P3o00000`00o`00o`000?l0000@0?l000@0003o0P3o0000
0`00o`00o`000?l0000?0?l00003003o003o0000o`000080oh002`3o00020000oa`0o`000P000?l5
0?l00080003o0P3o00040000oa<0o`000P000?l20?l000L0003o3_oooolM003o00030?n00000o`00
0?l000H00?l000<0oh00003o0000o`000P3oP004003o00030?n00000o`000?l000@0oh001@00o`06
0000o`<00?l00P3oP002003o00030?n000000?l0003o00L0003o0P3o0006003o00030?l000000?l0
003o00@00?l00`000?l4003o0080oh000P00o`030?n000D00?l00P3oP002003o0080oh000P00o`00
0`3o0000003o0000o`020000o`800?l00P3oP003003o0080oh003_ooool40?l00003003o003oP000
oh0000@0003o0`3oP002003o0080o`000P000?l20?n00003003o003oP000oh0000800?l00P3oP000
0`00o`00003o0000o`0;0000o`D00?l00P3oP0070000o`80oh003@000?l00`3oP000003o0000o`0=
0000o`80o`002@000?l00`00o`00003o0000o`040?l000800?l000<0oh000?l0003o00000P3o0002
0000o`030?l000000?l0003o0080003o0P3oP0020?l00003003o00000?l0003o00@0003o0P3o0005
0000o`kooooo0P3oP003003o00H0oh000P00o`030?n000800?l0103oP0000`00o`00oh000?n00004
0?n000<00?l00P3oP005003o00@0oh000P00o`020?n00003003o003oP000oh0000800?l01@3oP002
003o00H0oh000`00o`040?n00003003o003oP000oh000080oh001@000?l20?l000800?l0103oP003
003o0080oh000P00o`050?n000H0o`00203oP0020?l000800?l00P3oP002003o00<0oh001000o`02
0?n000D0o`006?ooool001Kooooo0P00o`0E0?l00080003o103o00000`00o`00o`000?l000060?l0
0003003o003o0000o`0000H0o`0000<0oh00003o0000o`00403o0002003o00@0o`0000<0003o0?l0
003o0000503o00020000o`80o`001@000?lN0?l000@0003o3_oooolM003o00030?n00000o`000?l0
00H00?l000<0oh00003o0000o`000P3oP002003o0080003o1`3oP003003o00T0003o103oP002003o
00X0003o2000o`000`3oP000003o0000o`020000o`@00?l000<0003o0?l0003o0000103oP002003o
00030?n00000o`000?l00080oh000`00o`020?n000800?l00P3oP002003o00030?l00000o`000?l0
0080o`000P00o`020?l00003003o003oP000oh0000800?l03_ooool20000o`80o`0000<00?l00?n0
003oP00010000?l30?n000T00?l00P3oP002003o0080oh0000<0003o003o0000o`000P00o`0;0000
o`800?l00`3o00070000o`80oh001000o`090000o`030?n000000?l0003o0180003o0P00o`020?n0
00D0003o0P3o0002003o0080oh000`00o`020?n000T0003o0P3o00000`00o`00o`000?l000060?l0
00D0003o3_ooool20?n000D00?l0103oP003003o0080oh002@00o`040?n000<00?l0103oP003003o
00@0oh000P00o`020?n00003003o003oP000oh0000800?l01@3oP002003o00H0oh000`00o`0;0?n0
00800?l000<0oh000000o`000?l00P00o`040?n00003003o003oP000oh0000H0oh0000<0o`00003o
0000o`002@3oP0020?l000D0oh000P00o`020?n000800?l00`3oP002003o0080oh000`00o`020?l0
00800?l06?ooool001Kooooo0P00o`0E0?l00080003o103o00000`00o`00o`000?l000060?l00003
003o003o0000o`0000H0o`0000<0oh00003o0000o`00403o0002003o00@0o`0000<0003o0?l0003o
0000503o00020000o`80o`001@000?lN0?l000@0003o3_oooolM003o00030?n00000o`000?l000H0
0?l000<0oh00003o0000o`000P3oP002003o0080003o1`3oP003003o00T0003o103oP002003o00X0
003o2000o`000`3oP000003o0000o`020000o`@00?l000<0003o0?l0003o0000103oP002003o0003
0?n00000o`000?l00080oh000`00o`020?n000800?l00P3oP002003o00030?l00000o`000?l00080
o`000P00o`020?l00003003o003oP000oh0000800?l03_ooool20000o`80o`0000<00?l00?n0003o
P00010000?l30?n000T00?l00P3oP002003o0080oh0000<0003o003o0000o`000P00o`0;0000o`80
0?l00`3o00070000o`80oh001000o`090000o`030?n000000?l0003o0180003o0P00o`020?n000D0
003o0P3o0002003o0080oh000`00o`020?n000T0003o0P3o00000`00o`00o`000?l000060?l000D0
003o3_ooool20?n000D00?l0103oP003003o0080oh002@00o`040?n000<00?l0103oP003003o00@0
oh000P00o`020?n00003003o003oP000oh0000800?l01@3oP002003o00H0oh000`00o`0;0?n00080
0?l000<0oh000000o`000?l00P00o`040?n00003003o003oP000oh0000H0oh0000<0o`00003o0000
o`002@3oP0020?l000D0oh000P00o`020?n000800?l00`3oP002003o0080oh000`00o`020?l00080
0?l06?ooool001Kooooo0P000?m00?l000800?l0103o00000`000?l0o`000?l000020000oa80o`00
0P000?l20?l000D0003o8P3o000>oooooa800?l00P3oP003003o0080oh000P00o`030?n000/00?l0
0P3oP004003o00<0oh000P00o`020?n000<00?l02@000?l20?n000h0003o2000o`000`3oP000003o
0000o`020000o`@00?l00`000?l40?n000800?l000<0oh00003o0000o`000P3oP0020000o`03003o
003oP000oh0000800?l00P3oP002003o00030?l00000o`000?l000@0o`000P3oP0000`00o`00oh00
0?n00002003o00kooooo0P000?l3003o0080oh0010000?l30?n000P00?l000<0o`000?n0003oP000
0P00o`020?n000030000o`3o0000o`0000800?l02@000?l20?l000800?l00`3o00070000o`80oh00
1000o`030000o`80o`0010000?l00`3oP000003o0000o`0B0000o`800?l00P3oP0090000o`80oh00
0`00o`020?n000`0003o0P3o00020000o`@0o`001@000?l>ooooo`80oh001@00o`060?n00003003o
003oP000oh0000H00?l000<0oh00003o0000o`00103oP003003o0080oh001000o`050?n000800?l0
0P3oP0000`00o`00oh000?n00002003o00D0oh000P00o`060?n000<0003o2@3oP002003o00<0oh00
0P000?l2003o00@0oh000`00o`070?n000@00?l01`3oP002003o00D0oh001P00o`070?n000L00?l0
6?ooool001Kooooo0P000?m00?l000800?l0103o00000`000?l0o`000?l000020000oa80o`000P00
0?l20?l000D0003o8P3o000>oooooa800?l00P3oP003003o0080oh000P00o`030?n000/00?l00P3o
P004003o00<0oh000P00o`020?n000<00?l02@000?l20?n000h0003o2000o`000`3oP000003o0000
o`020000o`@00?l00`000?l40?n000800?l000<0oh00003o0000o`000P3oP0020000o`03003o003o
P000oh0000800?l00P3oP002003o00030?l00000o`000?l000@0o`000P3oP0000`00o`00oh000?n0
0002003o00kooooo0P000?l3003o0080oh0010000?l30?n000P00?l000<0o`000?n0003oP0000P00
o`020?n000030000o`3o0000o`0000800?l02@000?l20?l000800?l00`3o00070000o`80oh001000
o`030000o`80o`0010000?l00`3oP000003o0000o`0B0000o`800?l00P3oP0090000o`80oh000`00
o`020?n000`0003o0P3o00020000o`@0o`001@000?l>ooooo`80oh001@00o`060?n00003003o003o
P000oh0000H00?l000<0oh00003o0000o`00103oP003003o0080oh001000o`050?n000800?l00P3o
P0000`00o`00oh000?n00002003o00D0oh000P00o`060?n000<0003o2@3oP002003o00<0oh000P00
0?l2003o00@0oh000`00o`070?n000@00?l01`3oP002003o00D0oh001P00o`070?n000L00?l06?oo
ool001Kooooo10000?l^0?l00080003o103o00000`000?l0o`000?l0000O0?l000030000o`3o0000
o`000080o`000P000?l30?l00080003o103o00020000o`L0o`0000<0003o0?l0003o0000503o000>
oooooa/00?l00P3oP00<003o0080oh001000o`030?n000@00?l00P3oP0000`00o`00003o0000o`09
0000o`80oh002`000?l00`3oP0000?l0003o0006003o00<0oh00103o00050000o`@0oh000P00o`00
0`3oP0000?l0003o00020?n000<0003o1P3oP002003o00<0003o0P3o00020000o`80oh0000<00?l0
0?n0003oP0000P00o`0>ooooo`80003o0P00o`030?n000@00?l00`3oP002003o0080oh001000o`00
0`3o00000?l0003o0009003o0080o`000P000?l00`3o0000003o0000o`020000o`@0o`001`000?l2
0?l000D00?l00P3oP0090000o`03003o00000?l0003o0180003o0P00o`0;0000o`80oh000`00o`02
0?n00080003o00<0o`000000o`000?l02@000?l60?l000D0003o3_ooool5003o00@0oh000P00o`02
0?n00003003o003oP000oh0000@0oh000P00o`000`3oP0000?l0003o00040?n000<00?l00P3oP004
003o00<0oh001000o`050?n000800?l00P3oP002003o00030?n00000o`000?l000H0oh000`000?l9
0?n000800?l00`3oP004003o00L0oh000P00o`050?n00080003o0P00o`050?n000@00?l01@3oP002
003o0080oh000P00o`070?n000800?l000<0oh00003o0000o`000P00o`0Hooooo`005_ooool40000
obh0o`000P000?l40?l000030000o`3o0000o`0001l0o`0000<0003o0?l0003o00000P3o00020000
o`<0o`000P000?l40?l00080003o1`3o00000`000?l0o`000?l0000D0?l000kooooo6`00o`020?n0
00`00?l00P3oP004003o00<0oh001000o`020?n00003003o00000?l0003o00T0003o0P3oP00;0000
o`030?n00000o`000?l000H00?l00`3oP0040?l000D0003o103oP002003o00030?n00000o`000?l0
0080oh000`000?l60?n000800?l00`000?l20?l00080003o0P3oP0000`00o`00oh000?n00002003o
00kooooo0P000?l2003o00<0oh001000o`030?n000800?l00P3oP004003o00030?l00000o`000?l0
00T00?l00P3o00020000o`030?l000000?l0003o0080003o103o00070000o`80o`001@00o`020?n0
00T0003o00<00?l00000o`000?l04P000?l2003o00/0003o0P3oP003003o0080oh000P000?l00`3o
0000003o0000o`090000o`H0o`001@000?l>ooooo`D00?l0103oP002003o0080oh0000<00?l00?n0
003oP000103oP002003o00030?n00000o`000?l000@0oh000`00o`020?n000@00?l00`3oP004003o
00D0oh000P00o`020?n000800?l000<0oh00003o0000o`001P3oP0030000o`T0oh000P00o`030?n0
00@00?l01`3oP002003o00D0oh000P000?l2003o00D0oh001000o`050?n000800?l00P3oP002003o
00L0oh000P00o`000`3oP0000?l0003o0002003o01Sooooo000Fooooo`@0003o=03o00000`000?l0
o`000?l0000Y0?l000@0003o6@3o00020000o`<0oh00103o000>oooooa/00?l00P3oP007003o0080
oh000`00o`020?n000D00?l00P3oP0040000o`80oh0000<00?l00?n0003oP0000P3oP0070000o`80
oh002`000?l00`3oP0000?l0003o00040?n000800?l00`000?l20?l00080003o0P3oP0030000o`@0
oh000P00o`000`3oP0000?l0003o00020?n000<0003o103oP002003o00<0oh000P000?l20?n00080
003o1`00o`0>ooooo`80003o0P3o00030?n00080003o0P00o`070?n00080003o0P3oP0000`000?l0
o`000?l00002003o0080o`0000<00?l00?n0003oP0000P00o`020?l001D0003o1000o`020?n001h0
003o0P00o`050?l000H0003o0P3oP003003o0080oh000P000?l00`3o0000003o0000o`0=0000o`80
o`001@000?l>ooooo`800?l00P3oP0000`00o`00oh000?n000020?n000800?l00`3oP002003o00L0
oh000P00o`040?n000<00?l00P3oP004003o00<0oh001000o`020?n00003003o003oP000oh0000H0
0?l000<0oh00003o0000o`000P00o`040?n000030?l000000?l0003o00L0oh000P00o`020?l000<0
oh001000o`050?n00080003o0P00o`050?n000@00?l01@3oP004003o00<0oh001000o`090?n000@0
0?l000<0oh00003o0000o`000P00o`0Hooooo`005_ooool40000oc@0o`0000<0003o0?l0003o0000
:@3o00040000oaT0o`000P000?l30?n000@0o`003_oooolK003o0080oh001`00o`020?n000<00?l0
0P3oP005003o0080oh0010000?l20?n00003003o003oP000oh000080oh001`000?l20?n000/0003o
00<0oh00003o0000o`00103oP002003o00<0003o0P3o00020000o`80oh000`000?l40?n000800?l0
00<0oh00003o0000o`000P3oP0030000o`@0oh000P00o`030?n00080003o0P3oP0020000o`L00?l0
3_ooool20000o`80o`000`3oP0020000o`800?l01`3oP0020000o`80oh0000<0003o0?l0003o0000
0P00o`020?l00003003o003oP000oh0000800?l00P3o000E0000o`@00?l00P3oP00N0000o`800?l0
1@3o00060000o`80oh000`00o`020?n00080003o00<0o`000000o`000?l03@000?l20?l000D0003o
3_ooool2003o0080oh0000<00?l00?n0003oP0000P3oP002003o00<0oh000P00o`070?n000800?l0
103oP003003o0080oh001000o`030?n000@00?l00P3oP0000`00o`00oh000?n00006003o00030?n0
0000o`000?l000800?l0103oP0000`3o0000003o0000o`070?n000800?l00P3o00030?n000@00?l0
1@3oP0020000o`800?l01@3oP004003o00D0oh001000o`030?n000@00?l02@3oP004003o00030?n0
0000o`000?l000800?l06?ooool001Kooooo10000?lG0?l00080003o?P3o00040000o`D0o`001000
0?lI0?l000800?l01`3o000>oooooa/00?l00P3oP007003o0080oh002P00o`020?n000800?l00P00
0?l20?n00003003o003oP000oh000080oh001`000?l40?n00003003o003o0000o`0000800?l00P00
0?l30?l00080003o0P00o`020?l000<0003o0P3oP002003o0080003o0P3oP003003o0080oh001000
o`000`3oP0000?l0003o00020?n00080003o00<00?l00?n0003oP0000P3oP004003o00030?n00000
0?l0003o0080003o2@00o`0>ooooo`80oh000P3o00000`3oP000o`000?l00006003o00<0oh000P3o
00020000o`80oh0000<0003o0?l0003o0000103o00000`00o`00o`000?l000040?l001@0003o1@00
o`020?n00100003o0`00o`0;0000o`@0o`000P000?l00`3o0000003o0000o`040000o`<0oh000P00
o`020?n00080003o00<0o`000000o`000?l03@000?l20?l000D0003o3_ooool2003o00L0oh000P00
o`030?n000@0003o1@3oP002003o00@0oh000`00o`040?n000800?l00`3oP004003o00<0oh001P00
o`030?n000800?l00P3oP0040?l000X0oh001000o`030?n00080003o0P00o`040?n000<0003o0P00
o`020?n000800?l000<0oh00003o0000o`000P00o`070?n000800?l01@3oP002003o00T0oh000P00
o`030?n000@00?l06?ooool001Kooooo0P3oP002003o0200o`000P00o`000`000?l0o`000?l00004
0?l00080003o;03o00040000o`@0o`001@000?lI0?l000@00?l000<0003o0?l0003o00000P3o000>
oooooaL00?l00P3oP002003o0080oh001`00o`020?n000X00?l00P3oP002003o0080003o0P3oP000
0`00o`00003o0000o`020?n000L0003o103oP0000`00o`00oh000?n00002003o0080oh000`3o0002
0000o`H00?l000<0003o0?n0003oP0000P00o`040?n000T00?l01@3oP003003o0080oh001P00o`03
0?n000H00?l000<0oh00003o0000o`000P00o`0>ooooo`800?l00P000?l30?n000L00?l00P3oP007
0000o`d0o`0050000?l5003o0080oh003P000?l2003o0080o`001`000?l20?l000030?n000000?l0
003o00L0003o0P3o00040000o`<0oh000P00o`020?n00080003o00<0o`000000o`000?l050000?l>
ooooo`800?l01`3oP002003o0080oh001@000?l50?n000800?l0103oP003003o00@0oh000P00o`03
0?n000@00?l00`3oP002003o0080oh000P00o`030?n000800?l00P3oP0040?l000L0oh000`00o`04
0?l000<0oh001000o`040?n000<0003o103oP002003o00030?n00000o`000?l000@0oh000P3o0003
0?n000800?l01@3oP002003o00@0oh0000<00?l00?n0003oP0001000o`020?n00003003o003oP000
oh0000800?l06?ooool001Kooooo0P3oP002003o0200o`000P00o`000`000?l0o`000?l000040?l0
0080003o;03o00040000o`@0o`001@000?lI0?l000@00?l000<0003o0?l0003o00000P3o000>oooo
oaL00?l00P3oP002003o0080oh001`00o`020?n000X00?l00P3oP002003o0080003o0P3oP0000`00
o`00003o0000o`020?n000L0003o103oP0000`00o`00oh000?n00002003o0080oh000`3o00020000
o`H00?l000<0003o0?n0003oP0000P00o`040?n000T00?l01@3oP003003o0080oh001P00o`030?n0
00H00?l000<0oh00003o0000o`000P00o`0>ooooo`800?l00P000?l30?n000L00?l00P3oP0070000
o`d0o`0050000?l5003o0080oh003P000?l2003o0080o`001`000?l20?l000030?n000000?l0003o
00L0003o0P3o00040000o`<0oh000P00o`020?n00080003o00<0o`000000o`000?l050000?l>oooo
o`800?l01`3oP002003o0080oh001@000?l50?n000800?l0103oP003003o00@0oh000P00o`030?n0
00@00?l00`3oP002003o0080oh000P00o`030?n000800?l00P3oP0040?l000L0oh000`00o`040?l0
00<0oh001000o`040?n000<0003o103oP002003o00030?n00000o`000?l000@0oh000P3o00030?n0
00800?l01@3oP002003o00@0oh0000<00?l00?n0003oP0001000o`020?n00003003o003oP000oh00
00800?l06?ooool001Kooooo0P3oP002003o0280o`0000<0003o0?l0003o00003@3o00020000o`T0
o`0000<0003o0?l0003o00007`3o00050000oaL0o`000P000?l2003o0080o`0000<0oh000?l0003o
00000P3o000>oooooaL00?l00P3oP00;003o0080oh002P00o`020?n000800?l00P000?l20?n00003
003o00000?l0003o0080oh001`000?l20?n000<0003o103oP0070000o`L00?l00P3oP002003o00@0
oh002P00o`040?n000<00?l00P3oP006003o00<0oh001P00o`000`3oP0000?l0003o0002003o00ko
oooo0P00o`020000o`D0oh001@00o`0;0000o`80o`001@000?l2003o01@0003o1`00o`020?n000`0
003o1000o`020?l000L0003o0P3o00000`3oP000003o0000o`0=0000o`<0oh000P00o`040?n001L0
003o3_ooool2003o00L0oh000P00o`030?n000@0003o1@3oP004003o00<0oh000P00o`040?n000<0
0?l0203oP003003o0080oh001000o`050?n00080o`001@3oP0020?l00080oh000`00o`040?n000<0
o`000P3oP002003o00@0oh0000<0o`000000o`000?l00P000?l20?n000800?l01@3oP002003o0080
003o00<0oh00003o0000o`000P00o`050?n000800?l0103oP0000`00o`00oh000?n00004003o0080
oh0000<00?l00?n0003oP0000P00o`0Hooooo`005_ooool20?n000800?l08P3o00000`000?l0o`00
0?l0000=0?l00080003o2@3o00000`000?l0o`000?l0000O0?l000D0003o5`3o00020000o`800?l0
0P3o00000`3oP000o`000?l000020?l000kooooo5`00o`020?n000/00?l00P3oP00:003o0080oh00
0P00o`020000o`80oh0000<00?l00000o`000?l00P3oP0070000o`80oh000`000?l40?n000L0003o
1`00o`020?n000800?l0103oP00:003o00@0oh000`00o`020?n000H00?l00`3oP006003o00030?n0
0000o`000?l000800?l03_ooool2003o0080003o1@3oP005003o00/0003o0P3o00050000o`800?l0
50000?l7003o0080oh0030000?l4003o0080o`001`000?l20?l000030?n000000?l0003o00d0003o
0`3oP002003o00@0oh005`000?l>ooooo`800?l01`3oP002003o00<0oh0010000?l50?n000@00?l0
0`3oP002003o00@0oh000`00o`080?n000<00?l00P3oP004003o00D0oh000P3o00050?n00080o`00
0P3oP003003o00@0oh000`3o00020?n000800?l0103oP0000`3o0000003o0000o`020000o`80oh00
0P00o`050?n000800?l00P000?l00`3oP0000?l0003o0002003o00D0oh000P00o`040?n00003003o
003oP000oh0000@00?l00P3oP0000`00o`00oh000?n00002003o01Sooooo000Fooooo`80oh000P00
o`0E0?l00080003o503o00000`000?l0o`000?l000040?l00080003o:`3o00070000oaL0o`000P3o
P0070?l000kooooo5`00o`020?n000@00?l000<0oh00003o0000o`004000o`020?n000@00?l00P3o
P0000`00o`00003o0000o`070000o`80oh001@000?l60?n00080003o1@00o`020?n000800?l000<0
003o003o0000o`001000o`020?n000<00?l00P3oP005003o00@0oh000`00o`020?n000L00?l00P3o
P00;003o00kooooo10000?l30?n00080003o0P00o`020?n00003003o00000?l0003o00T0003o0P3o
P00K0000o`L00?l00P3oP00<0000o`80oh002`000?l20?l000030000o`3o0000o`0000T0003o0P3o
00020000o`T0oh005`000?l>ooooo`800?l00`3oP002003o0080oh000P00o`050?n00080003o0P00
o`030?n000H00?l000<0oh00003o0000o`001P3oP0000`00o`00oh000?n000060?n000<00?l02`3o
P0020?l000D0oh000P00o`020?n000<00?l0103oP0020?l000<0oh000P00o`040?n00003003o003o
P000oh0000@0oh000P00o`050?n00080o`000`3oP004003o00D0oh000P00o`040?n00003003o003o
P000oh000080oh000P00o`020?n000D00?l06?ooool001Kooooo0P3oP002003o01D0o`000P000?lD
0?l000030000o`3o0000o`0000@0o`000P000?l[0?l000L0003o5`3o00020?n000L0o`003_oooolG
003o0080oh001000o`000`3oP0000?l0003o000@003o0080oh001000o`020?n00003003o00000?l0
003o00L0003o0P3oP0050000o`H0oh000P000?l5003o0080oh000P00o`000`000?l00?l0003o0004
003o0080oh000`00o`020?n000D00?l0103oP003003o0080oh001`00o`020?n000/00?l03_ooool4
0000o`<0oh000P000?l2003o0080oh0000<00?l00000o`000?l02@000?l20?n001/0003o1`00o`02
0?n000`0003o0P3oP00;0000o`80o`0000<0003o0?l0003o00002@000?l20?l00080003o2@3oP00G
0000o`kooooo0P00o`030?n000800?l00P3oP002003o00D0oh000P000?l2003o00<0oh001P00o`00
0`3oP0000?l0003o00060?n00003003o003oP000oh0000H0oh000`00o`0;0?n00080o`001@3oP002
003o0080oh000`00o`040?n00080o`000`3oP002003o00@0oh0000<00?l00?n0003oP000103oP002
003o00D0oh000P3o00030?n000@00?l01@3oP002003o00@0oh0000<00?l00?n0003oP0000P3oP002
003o0080oh001@00o`0Hooooo`005_ooool20?n000800?l05@3o00020000oa/0o`000P000?l[0?l0
00L0003o0P00o`0C0?l00080003o1@3o0002003o0080o`003_oooolG003o0080oh001000o`000`3o
P0000?l0003o000F003o0080oh0000<00?l00000o`000?l01`000?l20?n000L0003o0P3oP0050000
o`@00?l00P000?l2003o00030000o`00o`000?l000@00?l00P3oP0030000o`80oh001000o`030?n0
00@00?l00`3oP00;003o0080oh001`00o`0>ooooo`@0003o0`3oP0040000o`80oh0000<00?l00000
o`000?l01P000?l3003o0080oh006`000?l3003o0080oh000P00o`020?n001T0003o0P3oP00:0000
o`@0o`000P000?l50?n000800?l00P3oP00G0000o`kooooo0P00o`030?n000800?l00P3oP002003o
00D0oh001000o`030?n000H00?l000<0oh00003o0000o`001P3oP0000`00o`00oh000?n000060?n0
0003003o003oP000oh000080oh000P00o`020?n000<00?l0103oP002003o00<0oh001000o`000`3o
P0000?l0003o0002003o00L0oh000P00o`040?n00003003o003oP000oh000100oh001`00o`020?n0
00800?l01@3oP002003o0080oh000P00o`020?n00003003o003oP000oh0000800?l06?ooool001Ko
oooo0P00o`1Q0?l000L0003o0P00o`0J0?l000800?l00P3o000>ooooo`@00?l000<0oh00003o0000
o`004000o`020?n000800?l00P3oP00I003o0080oh0000<00?l00000o`000?l00P3oP00>0000o`80
o`001@000?l2003o0080o`000P000?l2003o00030?l00000o`000?l00080003o0P00o`050000o`@0
oh000P00o`000`3oP000003o0000o`020000o`<00?l00P3oP002003o0080oh002@00o`020?n000D0
0?l03_ooool40000o`030?n000000?l0003o00@0003o0`3oP0080000o`03003o003oP000oh0000@0
oh006`000?l30?l000800?l00P3oP00I0000o`80oh0040000?l50?n000800?l00`3oP00F0000o`ko
oooo1`00o`020?n000800?l01@3oP002003o0080oh000P00o`000`3oP0000?l0003o0004003o0003
0?n00000o`000?l000800?l0103oP0000`00o`00oh000?n000040?n000<00?l0103oP004003o0003
0?n00000o`000?l000@0oh000P00o`030?n000800?l00`3oP004003o00L0oh000P00o`050?n00080
0?l00P3oP002003o0100oh000`00o`020?n000@00?l00`3oP002003o00H0oh0000<00?l00?n0003o
P0000P00o`0Hooooo`005_ooool2003o0640o`001`000?l2003o01X0o`000P00o`020?l000kooooo
1000o`000`3oP0000?l0003o000@003o0080oh000P00o`020?n001T00?l00P3oP0000`00o`00003o
0000o`020?n000h0003o0P3o00050000o`800?l00P3o00020000o`800?l000<0o`00003o0000o`00
0P000?l2003o00D0003o103oP002003o00030?n000000?l0003o0080003o0`00o`020?n000800?l0
0P3oP009003o0080oh001@00o`0>ooooo`@0003o00<0oh000000o`000?l010000?l30?n000P0003o
00<00?l00?n0003oP000103oP00K0000o`<0o`000P00o`020?n001T0003o0P3oP00@0000o`D0oh00
0P00o`030?n001H0003o3_ooool7003o0080oh000P00o`050?n000800?l00P3oP002003o00030?n0
0000o`000?l000@00?l000<0oh00003o0000o`000P00o`040?n00003003o003oP000oh0000@0oh00
0`00o`040?n000@00?l000<0oh00003o0000o`00103oP002003o00<0oh000P00o`030?n000@00?l0
1`3oP002003o00D0oh000P00o`020?n000800?l0403oP003003o0080oh001000o`030?n000800?l0
1P3oP0000`00o`00oh000?n00002003o01Sooooo000Fooooo`800?l0703o00020000oc/0o`000P00
0?l60?l000030000o`3o0000o`0000@0003o0P00o`0C0?l000800?l0103o00000`00o`00o`000?l0
00020?l000kooooo1000o`000`3oP0000?l0003o000D003o0080oh005`00o`020?n000<00?l00P00
0?l20?n000h0003o0P3o00070000o`800?l010000?l00`3o0000003o0000o`020000o`800?l01`00
0?l4003o00030?n000000?l0003o0080003o1`00o`020?n000D00?l00P3oP002003o0080oh001@00
o`0>ooooo`@0003o00<0oh000000o`000?l010000?l30?n000P0003o00<00?l00?n0003oP000103o
P00L0000o`80oh000P00o`0K0000o`80oh0040000?l30?n000@00?l00P3oP0000`3o0000003o0000
o`0D0000o`kooooo2`00o`020?n000<00?l0103oP002003o00030?n00000o`000?l00080oh000P00
o`090?n000<00?l0103oP003003o00@0oh001000o`000`3oP0000?l0003o00090?n000800?l00`3o
P006003o00D0oh001P00o`000`3oP000003o0000o`020000o`L0oh000P00o`090?n000<00?l00P3o
P002003o00D0oh000P00o`060?n000D00?l06?ooool001Kooooo0P00o`0L0?l00080003o>`3o0002
0000o`H0o`0000<0003o0?l0003o000010000?l2003o01<0o`000P00o`040?l00003003o003o0000
o`000080o`003_ooool4003o00030?n00000o`000?l001@00?l00P3oP00G003o0080oh000`00o`02
0000o`80oh003P000?l20?l000L0003o0P00o`040000o`030?l000000?l0003o0080003o0P00o`07
0000o`@00?l000<0oh000000o`000?l00P000?l7003o0080oh001@00o`020?n000800?l00P3oP005
003o00kooooo10000?l00`3oP000003o0000o`040000o`<0oh0020000?l00`00o`00oh000?n00004
0?n001`0003o0P3oP002003o01/0003o0P3oP00@0000o`<0oh001000o`020?n000030?l000000?l0
003o01@0003o3_ooool;003o0080oh000`00o`040?n000800?l000<0oh00003o0000o`000P3oP002
003o00T0oh000`00o`040?n000<00?l0103oP004003o00030?n00000o`000?l000T0oh000P00o`03
0?n000H00?l01@3oP006003o00030?n000000?l0003o0080003o1`3oP002003o00T0oh000`00o`02
0?n000800?l01@3oP002003o00H0oh001@00o`0Hooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooo
oaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaOo0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo
0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolG
o`3o01oooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool0
00Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000j
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000joooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00O`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001o
o`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go001o
5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o
5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0ho`00
OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`05o`00
O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l0
07oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`1^o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`005_ooool20?n006l0o`000`3oP00F0?l000kooooo0P3o0007003o00@0003o00<0
0?l00000o`000?l01000o`050000o`T00?l0103oP0000`3o00000?l0003o0002003o00D0003o0P00
o`060?n000T00?l00`3o0005003o0080003o0P00o`020000o`<00?l00P000?l2003o00@0003o0`00
o`020?n000d00?l000<0003o003o0000o`003P00o`060?n000<00?l00P000?l2003o00kooooo3@00
0?l00`00o`00003o0000o`020000o`800?l04P000?l00`00o`00003o0000o`0P0000o`800?l00P00
0?l20?n000D00?l04P000?l2003o00@0003o0`00o`0G0000o`800?l00P000?l>ooooo`80o`001@3o
P0020?l000d0oh0000<00?l00?n0003oP000103oP0000`00o`00oh000?n00004003o00L0oh000P00
o`050?l000800?l0103oP0000`00o`00oh000?n000020?n000800?l00P3o00050?n000800?l000<0
oh000?l0003o00000P3o00020?n00080o`002P3oP0040?l000D0oh000P3o00020?n000D0o`000P00
o`050?n000800?l0103oP0030?l000@00?l0103oP0000`00o`00oh000?n000020?n001Sooooo000F
ooooo`80oh00K`3o00030?n001H0o`003_ooool20?l000L00?l010000?l00`00o`00003o0000o`04
003o00D0003o2@00o`040?n000030?l00000o`000?l000800?l01@000?l2003o00H0oh002@00o`03
0?l000D00?l00P000?l2003o0080003o0`00o`020000o`800?l010000?l3003o0080oh003@00o`00
0`000?l00?l0003o000>003o00H0oh000`00o`020000o`800?l03_ooool=0000o`03003o00000?l0
003o0080003o0P00o`0B0000o`03003o00000?l0003o0200003o0P00o`020000o`80oh001@00o`0B
0000o`800?l010000?l3003o01L0003o0P00o`020000o`kooooo0P3o00050?n00080o`003@3oP000
0`00o`00oh000?n000040?n00003003o003oP000oh0000@00?l01`3oP002003o00D0o`000P00o`04
0?n00003003o003oP000oh000080oh000P00o`020?l000D0oh000P00o`000`3oP000o`000?l00002
0?l00080oh000P3o000:0?n000@0o`001@3oP0020?l00080oh001@3o0002003o00D0oh000P00o`04
0?n000<0o`001000o`040?n00003003o003oP000oh000080oh006?ooool001KoooooRP3o000>oooo
o`80o`001`00o`070000o`/00?l01`000?l50?l000@00?l02`000?l5003o0080oh001000o`050?l0
00<00?l00P000?l2003o0080003o0P00o`000`000?l00?l0003o0002003o00@0003o00<00?l00000
o`000?l03`00o`000`000?l00?l0003o00020000o`T00?l00P3o00000`3oP000o`000?l00002003o
0080o`000`00o`020000o`800?l03_ooool4003o0280003o00<00?l00000o`000?l080000?l2003o
01H0003o0P00o`000`000?l00?l0003o0009003o00L0003o0P00o`040000o`<00?l00P000?l2003o
0080003o00<00?l00000o`000?l00P00o`0>oooooaL0oh000P00o`090?n000@0o`000`3oP0020?l0
00D0oh001000o`020?n000800?l02@3oP0000`3o0000oh000?n000020?n000800?l01`3o00020?n0
00D00?l00P000?l2003o00030?n0003o0000o`000080o`001`3oP0020?l00080oh000`00o`040?n0
0080o`004P3oP0050?l001Sooooo000FooooohX0o`003_ooool20?l000L00?l01`000?l;003o00L0
003o1@3o0004003o00/0003o1@00o`020?n000@00?l01@3o0003003o0080003o0P00o`020000o`80
0?l000<0003o003o0000o`000P00o`040000o`03003o00000?l0003o00l00?l000<0003o003o0000
o`000P000?l9003o0080o`0000<0oh000?l0003o00000P00o`020?l000<00?l00P000?l2003o00ko
oooo1000o`0R0000o`03003o00000?l0003o0200003o0P00o`0F0000o`800?l000<0003o003o0000
o`002@00o`070000o`800?l010000?l3003o0080003o0P00o`020000o`03003o00000?l0003o0080
0?l03_oooolG0?n000800?l02@3oP0040?l000<0oh000P3o00050?n000@00?l00P3oP002003o00T0
oh0000<0o`000?n0003oP0000P3oP002003o00L0o`000P3oP005003o0080003o0P00o`000`3oP000
o`000?l000020?l000L0oh000P3o00020?n000<00?l0103oP0020?l00180oh001@3o000Hooooo`00
5_oooom?0?l00080oh00>@3o000>ooooo`80o`001`00o`040000o`03003o00000?l0003o0080003o
0P00o`030000o`800?l01@000?l2003o00L0oh001000o`0;0000o`D00?l00P3oP002003o0080oh00
1@3o000<003o0080o`000P000?l5003o0080003o0P00o`070?n00080o`001000o`000`000?l00?l0
003o0009003o00@0o`0000<00?l00?l0003o00000P00o`020?n000<00?l00P000?l2003o00kooooo
1000o`0B0000o`03003o00000?l0003o01d0003o1@00o`040000o`800?l000<0003o003o0000o`00
0P000?l3003o00@0003o1000o`030000o`L00?l01P000?l2003o00030000o`00o`000?l00080003o
0P00o`020000o`<00?l00P000?l2003o00030000o`00o`000?l000L00?l010000?l5003o0080003o
0P00o`0>ooooo`80o`001@3oP0060?l000<0oh000P3o000B0?n00080o`00303oP006003o00030?n0
003o0000o`000080o`000P3oP0020?l000X0oh000P3o0002003o00D0oh002@00o`020?n000L0o`00
1`3oP0020000o`D0o`001P3oP002003o00X0o`000P3oP0020?l001Sooooo000Foooood/0o`000P3o
P00h0?l000030?n0003o0000o`000080oh003_ooool20000o`L00?l02`000?l2003o00030000o`00
o`000?l000T0003o1000o`000`000?l00?l0003o0002003o00@0003o00<00?l00000o`000?l01000
0?l20?n000030000o`00o`000?l000H00?l00`3o00020?n000D00?l00P000?l2003o0080o`002@00
o`030?n000H00?l000<0003o0?l0003o00000P3o0004003o00L0003o0`00o`020000o`800?l00P3o
00000`00o`00oh000?n000060?n00003003o00000?l0003o00800?l03_ooool2003o01@0003o0`00
o`040000o`03003o00000?l0003o00H0003o0`00o`020000o`800?l02@000?l3003o0080003o1000
o`020000o`L00?l000<0003o003o0000o`001P00o`000`000?l00?l0003o0007003o0080003o1P00
o`000`000?l00?l0003o0004003o0080003o0`00o`020000o`L00?l00P000?l3003o00@0003o1@00
o`020000o`800?l03_ooool=0?n000030?l0003oP000oh0000h0oh000P3o00020?n000@0o`00303o
P004003o00<0oh000P3o000=0?n000030?l0003oP000oh0000/0oh001000o`030?n00080o`00103o
P0000`3o0000oh000?n000020?n000800?l02P3oP0060?l000800?l000<0o`000?n0003oP000103o
00050?n000800?l06?ooool001KoooooB`3o00020?n003P0o`0000<0oh000?l0003o00000P3oP00>
ooooo`80003o1`00o`0;0000o`800?l000<0003o003o0000o`002@000?l4003o00030000o`00o`00
0?l000800?l010000?l00`00o`00003o0000o`040000o`80oh0000<0003o003o0000o`001P00o`03
0?l00080oh001@00o`020000o`800?l00P3o0009003o00<0oh001P00o`000`000?l0o`000?l00002
0?l000@00?l01`000?l3003o0080003o0P00o`020?l00003003o003oP000oh0000H0oh0000<00?l0
0000o`000?l00P00o`0>ooooo`800?l050000?l3003o00@0003o00<00?l00000o`000?l01P000?l3
003o0080003o0P00o`090000o`<00?l00P000?l4003o0080003o1`00o`000`000?l00?l0003o0006
003o00030000o`00o`000?l000L00?l00P000?l6003o00030000o`00o`000?l000@00?l00P000?l3
003o0080003o1`00o`020000o`<00?l010000?l5003o0080003o0P00o`0>ooooo`d0oh0000<0o`00
0?n0003oP0003P3oP0020?l00080oh00103o000<0?n000@00?l00`3oP0020?l000d0oh0000<0o`00
0?n0003oP0002`3oP004003o00<0oh000P3o00040?n000030?l0003oP000oh000080oh000P00o`0:
0?n000H0o`000P00o`000`3o0000oh000?n000040?l000D0oh000P00o`0Hooooo`005_oooon:0?l0
00kooooo0P000?l20?n000D00?l03P000?l4003o00<0003o0P00o`020000o`@00?l000<0003o003o
0000o`000P00o`040000o`03003o00000?l0003o00L0003o1000o`040000o`<00?l00P000?l5003o
0080003o1@00o`020?l000@00?l01@3oP006003o00030?n00000o`000?l00080oh001@00o`020000
o`@00?l000<0003o003o0000o`000P00o`020?l000<00?l00P3o000;003o00kooooo0P00o`0E0000
o`800?l00P000?l3003o00@0003o2`00o`0@0000o`D00?l00P000?l40?n000D00?l0103o00000`3o
P0000?l0003o0006003o00D0003o0P00o`020?n000L00?l00P000?l5003o0080003o1@00o`020000
o`<00?l00P000?l2003o00@0003o00<00?l00000o`000?l00P00o`0>oooooa80oh0010000?l00`00
o`00oh000?n00004003o00D0oh001@3o000A0?n000030?l0003oP000oh0001/0oh000P3o00020?n0
00030?l0003oP000oh0000T0oh001000o`0:0?n00080o`001`3oP0020?l00080oh000P3o00070?n0
01Sooooo000FooooohX0o`003_ooool20000o`80oh001@00o`0>0000o`@00?l00`000?l2003o0080
003o1000o`000`000?l00?l0003o0002003o00@0003o00<00?l00000o`000?l01`000?l4003o00@0
003o0`00o`020000o`D00?l00P000?l5003o0080o`001000o`050?n000H00?l000<0oh00003o0000
o`000P3oP005003o0080003o1000o`000`000?l00?l0003o0002003o0080o`000`00o`020?l000/0
0?l03_ooool2003o01D0003o0P00o`020000o`<00?l010000?l;003o0100003o1@00o`020000o`@0
oh001@00o`040?l000030?n00000o`000?l000H00?l01@000?l2003o0080oh001`00o`020000o`D0
0?l00P000?l5003o0080003o0`00o`020000o`800?l010000?l00`00o`00003o0000o`02003o00ko
oooo4P3oP0040000o`03003o003oP000oh0000@00?l01@3oP0050?l00140oh0000<0o`000?n0003o
P0006`3oP0020?l00080oh0000<0o`000?n0003oP0002@3oP004003o00X0oh000P3o00070?n00080
o`000P3oP0020?l000L0oh006?ooool001Kooooo9`3o00020?n004X0o`0000<0oh000?l0003o0000
503o000>ooooo`80003o0P00o`000`000?l00?l0003o0002003o01/0003o0P00o`000`000?l00?l0
003o0002003o00@0003o00<00?l00000o`000?l040000?l2003o0080003o1@00o`020000o`D00?l0
0P3oP006003o00030?n00000o`000?l00080oh001000o`000`3oP0000?l0003o0002003o00@0003o
00<00?l00000o`000?l01@00o`020000o`800?l00P000?l<003o00@0003o3_ooool4003o01<0003o
0P00o`020000o`<00?l020000?l3003o0080003o0P00o`0>0000o`800?l010000?l00`00o`00003o
0000o`05003o0080003o2`3oP004003o00D0003o1000o`050000o`800?l00P000?l<003o00@0003o
0`00o`040000o`<00?l00P000?l2003o00kooooo503oP0020000o`P0oh001000o`050?l00180oh00
0P3o00040?n00080003o1`3oP0000`000?l00?l0003o0006003o00L0oh000`00o`020000o`800?l0
0P3oP0020000o`<00?l00P000?l2003o0200oh006?ooool001Kooooo9`3o00020?n004X0o`0000<0
oh000?l0003o0000503o000>ooooo`80003o0P00o`000`000?l00?l0003o0002003o01/0003o0P00
o`000`000?l00?l0003o0002003o00@0003o00<00?l00000o`000?l040000?l2003o0080003o1@00
o`020000o`D00?l00P3oP006003o00030?n00000o`000?l00080oh001000o`000`3oP0000?l0003o
0002003o00@0003o00<00?l00000o`000?l01@00o`020000o`800?l00P000?l<003o00@0003o3_oo
ool4003o01<0003o0P00o`020000o`<00?l020000?l3003o0080003o0P00o`0>0000o`800?l01000
0?l00`00o`00003o0000o`05003o0080003o2`3oP004003o00D0003o1000o`050000o`800?l00P00
0?l<003o00@0003o0`00o`040000o`<00?l00P000?l2003o00kooooo503oP0020000o`P0oh001000
o`050?l00180oh000P3o00040?n00080003o1`3oP0000`000?l00?l0003o0006003o00L0oh000`00
o`020000o`800?l00P3oP0020000o`<00?l00P000?l2003o0200oh006?ooool001Kooooo0P3oP01_
0?l000L0oh004P3o000>ooooo`80003o0P00o`000`000?l00?l0003o0002003o01D0003o0P00o`02
0000o`80oh000P3o0005003o01L0003o0P00o`020000oa800?l00P000?l5003o00d0003o00<00?l0
0000o`000?l01000o`050000o`L00?l00P3o0005003o00@0003o3_oooolK0000o`<00?l020000?l0
0`3oP0000?l0003o00020?n000800?l00P000?l00`00o`00003o0000o`0;0000o`D00?l010000?l2
003o00<0003o0P00o`040?l000030?n00000o`000?l000800?l00P000?l2003o00T0003o00<00?l0
0000o`000?l01000o`020000o`P00?l00P000?l;003o0080003o0`00o`020000o`800?l03_ooool9
0?n00080o`001`3oP0020?l000T0oh0000<0o`00003o0000o`000P00o`090?n000@0o`002P3oP002
003o00h0oh000P00o`0F0?n000800?l000<0003o003o0000o`002@3oP002003o0080o`005`3oP00H
ooooo`005_oooon:0?l000kooooo0P000?l2003o00030000o`00o`000?l000800?l01`000?l2003o
00`0003o0P00o`020000o`800?l00P3oP003003o01@0003o1`00o`040000o`03003o00000?l0003o
0080003o1@00o`020000o`@00?l00P000?l3003o00L0003o0P00o`0;0000o`800?l01@000?l5003o
00@0oh001`00o`020000o`kooooo40000?l2003o0080003o0`00o`0=0000o`D00?l00P3oP005003o
00/0003o0P00o`020000o`<00?l00P000?l2003o0080003o0`00o`090?n000800?l00P000?l2003o
00L0003o0`00o`020000o`@00?l00P000?l5003o0080003o1@00o`020?n00080003o1@00o`020000
o`L00?l03_ooool20?n000`0o`000P3oP0020?l000D0oh00103o00050?n000800?l05P3oP0000`3o
00000?l0003o00040?n00080o`00203oP004003o00D0oh000P3o000R0?n000@0o`002`3oP0000`3o
0000oh000?n000020?n001Sooooo000FooooohX0o`003_ooool20000o`800?l000<0003o003o0000
o`000P00o`070000o`800?l030000?l2003o0080003o0P00o`020?n000<00?l050000?l7003o00@0
003o00<00?l00000o`000?l00P000?l5003o0080003o1000o`020000o`<00?l01`000?l2003o00/0
003o0P00o`050000o`D00?l0103oP007003o0080003o3_ooool@0000o`800?l00P000?l3003o00d0
003o1@00o`020?n000D00?l02`000?l2003o0080003o0`00o`020000o`800?l00P000?l3003o00T0
oh000P00o`020000o`800?l01`000?l3003o0080003o1000o`020000o`D00?l00P000?l5003o0080
oh000P000?l5003o0080003o1`00o`0>ooooo`80oh00303o00020?n00080o`001@3oP0040?l000D0
oh000P00o`0F0?n000030?l00000o`000?l000@0oh000P3o00080?n000@00?l01@3oP0020?l00280
oh00103o000;0?n000030?l0003oP000oh000080oh006?ooool001KoooooB03o00000`3oP000o`00
0?l0000o0?l000kooooo1@000?l4003o00d0003o00<00?l00000o`000?l01@000?l2003o0080003o
0P00o`020?l000<00?l03`000?l3003o0080003o2@00o`020000o`03003o00000?l0003o00H0003o
0`00o`020000o`800?l00P000?l3003o00d0003o0P00o`050000o`800?l01@000?l4003o00030000
o`00o`000?l00080o`001`00o`020000o`kooooo1000o`0:0000o`@00?l00P000?l7003o00T0003o
0P00o`000`000?l00?l0003o00020?n00080003o0`00o`020000o`800?l010000?l00`00o`00003o
0000o`040000o`80oh0000<00?l00000o`000?l04P00o`0;0000o`800?l00`000?l2003o0080003o
0P00o`000`000?l00?l0003o0005003o0080003o0P00o`020000o`D00?l00P000?l7003o0080003o
3_ooool90?l000/0oh000P3o00000`3oP000o`000?l000070?l000800?l0103oP0000`00o`00o`00
0?l000020?n000D0o`001000o`090?n00080o`008P3oP0050?l000d0oh0000<0o`00003o0000o`00
0P00o`020?l000T0oh000`3o00040?n001Sooooo000FooooodP0o`0000<0oh000?l0003o0000?`3o
000>ooooo`D0003o1000o`0=0000o`03003o00000?l0003o00D0003o0P00o`020000o`800?l00P3o
0003003o00l0003o0`00o`020000o`T00?l00P000?l00`00o`00003o0000o`060000o`<00?l00P00
0?l2003o0080003o0`00o`0=0000o`800?l01@000?l2003o00D0003o1000o`000`000?l00?l0003o
00020?l000L00?l00P000?l>ooooo`@00?l02P000?l4003o0080003o1`00o`090000o`800?l000<0
003o003o0000o`000P3oP0020000o`<00?l00P000?l2003o00@0003o00<00?l00000o`000?l01000
0?l20?n00003003o00000?l0003o01800?l02`000?l2003o00<0003o0P00o`020000o`800?l000<0
003o003o0000o`001@00o`020000o`800?l00P000?l5003o0080003o1`00o`020000o`kooooo2@3o
000;0?n00080o`0000<0oh000?l0003o00001`3o0002003o00@0oh0000<00?l00?l0003o00000P3o
P0050?l000@00?l02@3oP0020?l00280oh001@3o000=0?n000030?l00000o`000?l000800?l00P3o
00090?n000<0o`00103oP00Hooooo`005_oooon:0?l000kooooo1`000?l2003o00T0003o0P00o`09
0000o`03003o00000?l0003o0080003o1000o`000`000?l00?l0003o0002003o00/0003o0`00o`02
0?n000H00?l000<0oh00003o0000o`001@00o`020000o`L0oh001P00o`020000o`T00?l00`000?l2
003o00@0003o00<00?l00000o`000?l01000o`000`000?l00?l0003o0004003o00T0oh000P3o0005
003o00kooooo1000o`0@0000o`D00?l02`000?l2003o00030000o`00o`000?l000H00?l000<0003o
003o0000o`001000o`020000o`03003o00000?l0003o00T0003o0P00o`020000o`<00?l00P000?l2
003o0080oh000`00o`0=0000o`800?l000<0003o003o0000o`000P00o`0<0000o`@00?l00P000?l5
003o0080003o1000o`000`000?l0oh000?n000020000o`kooooo0P3oP0020?l000030?n0003o0000
o`000080oh001@00o`020000o`800?l0803oP0040?l000L0oh000P3o00020?n00003003o003oP000
oh000080oh000`3o00020000o`H00?l08P3oP0000`00o`00003o0000o`0D0?n001Sooooo000Foooo
ohX0o`003_ooool70000o`800?l02@000?l2003o00T0003o00<00?l00000o`000?l00P000?l4003o
00030000o`00o`000?l000800?l02`000?l3003o0080oh001P00o`000`3oP0000?l0003o0005003o
0080003o1`3oP006003o0080003o2@00o`030000o`800?l010000?l00`00o`00003o0000o`04003o
00030000o`00o`000?l000@00?l02@3oP0020?l000D00?l03_ooool4003o0100003o1@00o`0;0000
o`800?l000<0003o003o0000o`001P00o`000`000?l00?l0003o0004003o0080003o00<00?l00000
o`000?l02@000?l2003o0080003o0`00o`020000o`800?l00P3oP003003o00d0003o0P00o`000`00
0?l00?l0003o0002003o00`0003o1000o`020000o`D00?l00P000?l4003o00030000o`3oP000oh00
0080003o3_ooool20?n00080o`0000<0oh000?l0003o00000P3oP005003o0080003o0P00o`0P0?n0
00@0o`001`3oP0020?l00080oh0000<00?l00?n0003oP0000P3oP0030?l00080003o1P00o`0R0?n0
0003003o00000?l0003o01@0oh006?ooool001KoooooRP3o000>ooooo`800?l01@000?l2003o00h0
003o1000o`070000o`@00?l04P000?l:0?n00080o`001000o`000`000?l00?l0003o0002003o0080
oh000P3o00000`00o`00o`000?l0000?003o00030000o`00o`000?l000800?l010000?l00`00o`00
003o0000o`04003o00<0003o2`00o`050?l000@00?l03_ooool20000o`800?l040000?l2003o01<0
003o0P00o`020000o`<00?l00P000?l2003o00d0003o00<0oh00003o0000o`000P3oP0020000o`D0
0?l00P000?l3003o00H0003o0P00o`050000o`@00?l000<0003o003o0000o`000P00o`090000o`80
0?l00`000?l2003o00/0003o0P00o`000`000?l00?l0003o00020000o`kooooo3P3oP004003o00h0
oh00103o00090?n000<0o`000P00o`0G0?n00080o`006@3oP0020?l00080oh002@3o00070?n000L0
o`002`3oP00Hooooo`005_oooon:0?l000kooooo0P00o`050000o`800?l03P000?l4003o00L0003o
1000o`0B0000o`X0oh000P3o0004003o00030000o`00o`000?l000800?l00P3oP0020?l00003003o
003o0000o`0000l00?l000<0003o003o0000o`000P00o`040000o`03003o00000?l0003o00@00?l0
0`000?l;003o00D0o`001000o`0>ooooo`80003o0P00o`0@0000o`800?l04`000?l2003o0080003o
0`00o`020000o`800?l03@000?l00`3oP0000?l0003o00020?n00080003o1@00o`020000o`<00?l0
1P000?l2003o00D0003o1000o`000`000?l00?l0003o0002003o00T0003o0P00o`030000o`800?l0
2`000?l2003o00030000o`00o`000?l00080003o3_ooool>0?n000@00?l03P3oP0040?l000T0oh00
0`3o0002003o01L0oh000P3o000I0?n00080o`000P3oP0090?l000L0oh001`3o000;0?n001Sooooo
000FooooohX0o`003_ooool4003o00030000o`00o`000?l000800?l03P000?l2003o00T0003o1000
o`0>0000o`T0oh000P00o`030?n00080o`002@00o`090?n00080o`002`00o`000`000?l00?l0003o
0002003o00@0003o00<00?l00000o`000?l01000o`000`000?l00?l0003o0004003o0080oh001@00
o`020?n000L00?l03_ooool20000o`800?l09@000?l4003o0080003o00<0oh000000o`000?l00P00
o`040000o`03003o00000?l0003o00L0003o1000o`020000o`X00?l01P000?l2003o00L0003o0P00
o`0>0000o`800?l00`000?l2003o00L0003o0P00o`050000o`800?l00P000?l>ooooo`T0oh000P3o
00020?n000030?l0003oP000oh0000H0oh001`00o`000`3o0000oh000?n0000D0?n00080o`000`3o
P00=0?l00080oh0000<0o`000?n0003oP0000P00o`090?n00080o`001@3oP002003o0080oh000`3o
00080?n000D0o`006@3oP00Hooooo`005_oooon:0?l000kooooo0P000?l7003o00h0003o1`00o`02
0000o`@00?l00`3oP0020000o`800?l01@000?l4003o00@0003o0`00o`020?l000h00?l01`3o0002
0?n000H0o`0000<0oh00003o0000o`000P00o`020?n000L00?l010000?l00`00o`00003o0000o`02
003o0080oh001@000?l2003o0080003o3P00o`0>ooooo`@00?l0:`000?l00`00o`00003o0000o`0;
0000o`800?l00`000?l2003o00@0003o1@00o`020000o`D00?l010000?l2003o00L0003o0P00o`03
0000o`H00?l04@000?l4003o00D0003o1000o`0>ooooo`D0o`001P3oP0020?l000030?n0003o0000
o`0000/0oh000P3o00030?n000H00?l0303oP0020?l00080oh000P00o`000`3oP000o`000?l0000D
0?n000800?l000<0oh000?l0003o0000103o000L0?n000T0o`002`3oP0020?l001Sooooo000Foooo
ohX0o`003_ooool20000o`L00?l03P000?l7003o0080003o1000o`030?n00080003o0P00o`050000
o`@00?l010000?l3003o0080o`003P00o`070?l00080oh001P3o00000`3oP0000?l0003o0002003o
0080oh001`00o`040000o`03003o00000?l0003o00800?l00P3oP0050000o`800?l00P000?l>003o
00kooooo1000o`0[0000o`03003o00000?l0003o00/0003o0P00o`030000o`800?l010000?l5003o
0080003o1@00o`040000o`800?l01`000?l2003o00<0003o1P00o`0A0000o`@00?l01@000?l4003o
00kooooo1@3o00060?n00080o`0000<0oh000?l0003o00002`3oP0020?l000<0oh001P00o`0<0?n0
0080o`000P3oP002003o00030?n0003o0000o`0001@0oh000P00o`000`3oP000o`000?l000040?l0
01`0oh002@3o000;0?n00080o`006?ooool001KoooooRP3o000>ooooo`80003o0P00o`000`000?l0
0?l0003o0002003o01D0003o1000o`020?n000D00?l040000?l4003o0080o`003000o`020?n000@0
o`0000<0oh00003o0000o`003`00o`000`000?l00?l0003o0004003o0080003o00<00?l00000o`00
0?l01000o`000`000?l00?l0003o0002003o00@0003o1@00o`020000o`L00?l03_ooool4003o02/0
003o00<00?l00000o`000?l040000?l2003o00@0003o00<00?l00000o`000?l010000?l2003o0003
0?n000000?l0003o00H00?l00`000?l2003o00L0003o0P00o`090000o`800?l02P000?l2003o00H0
003o00<00?l00000o`000?l00P00o`0>ooooo`80oh000P3o00000`3oP000o`000?l0000B0?n00080
o`001`3oP002003o0080o`0000<0oh000?l0003o00000P3o00020?n000<0o`001000o`020?n00080
0?l000<0oh000?l0003o00002`3oP003003o0080o`001000o`020?l000030?n0003o0000o`0000L0
oh000P3o000=0?n000<0o`00103oP0020?l000D0oh000P3o00020?n000030?l0003oP000oh0000H0
oh0000<00?l00?n0003oP0000P3oP00Hooooo`005_oooon:0?l000kooooo0P000?l2003o00030000
o`00o`000?l000800?l05@000?l4003o0080oh001@00o`0@0000o`@00?l00P3o000<003o0080oh00
103o00000`3oP0000?l0003o000?003o00030000o`00o`000?l000@00?l00P000?l00`00o`00003o
0000o`04003o00030000o`00o`000?l000800?l010000?l5003o0080003o1`00o`0>ooooo`@00?l0
:`000?l00`00o`00003o0000o`0@0000o`800?l010000?l00`00o`00003o0000o`040000o`800?l0
00<0oh000000o`000?l01P00o`030000o`800?l01`000?l2003o00T0003o0P00o`0:0000o`800?l0
1P000?l00`00o`00003o0000o`02003o00kooooo0P3oP0020?l000030?n0003o0000o`000180oh00
0P3o00070?n000800?l00P3o00000`3oP000o`000?l000020?l00080oh000`3o0004003o0080oh00
0P00o`000`3oP000o`000?l0000;0?n000<00?l00P3o0004003o0080o`0000<0oh000?l0003o0000
1`3oP0020?l000d0oh000`3o00040?n00080o`001@3oP0020?l00080oh0000<0o`000?n0003oP000
1P3oP0000`00o`00oh000?n000020?n001Sooooo000FooooohX0o`003_ooool40000o`03003o0000
0?l0003o00@00?l030000?l2003o0080003o0P00o`000`000?l00?l0003o00020000o`D00?l03`00
0?l5003o0080oh000P3o00030?n000T00?l0103o0009003o00<0003o0P00o`020000o`T00?l01`00
0?l4003o00<0003o0P00o`040000o`D00?l00P000?l7003o00kooooo0P000?l2003o01T0003o00<0
0?l00000o`000?l010000?l9003o01D0003o0P00o`040000o`03003o00000?l0003o00@0003o0`00
o`020000o`@00?l03P000?l2003o00T0003o0P00o`0:0000o`800?l02@000?l2003o00kooooo0P3o
P0030?l00080oh001P3o00090?n000L0o`002@3oP0000`3o0000oh000?n000060?n000D0o`000P3o
P0070?l000D00?l00P3o00050?n00080o`002@3oP0040?l000T0oh000`3o000V0?n001Sooooo000F
ooooohX0o`003_ooool40000o`03003o00000?l0003o00@00?l030000?l2003o0080003o0P00o`00
0`000?l00?l0003o00020000o`D00?l03`000?l5003o0080oh000P3o00030?n000T00?l0103o0009
003o00<0003o0P00o`020000o`T00?l01`000?l4003o00<0003o0P00o`040000o`D00?l00P000?l7
003o00kooooo0P000?l2003o01T0003o00<00?l00000o`000?l010000?l9003o01D0003o0P00o`04
0000o`03003o00000?l0003o00@0003o0`00o`020000o`@00?l03P000?l2003o00T0003o0P00o`0:
0000o`800?l02@000?l2003o00kooooo0P3oP0030?l00080oh001P3o00090?n000L0o`002@3oP000
0`3o0000oh000?n000060?n000D0o`000P3oP0070?l000D00?l00P3o00050?n00080o`002@3oP004
0?l000T0oh000`3o000V0?n001Sooooo000Foooooad0o`0000<0oh000?l0003o0000>03o00020?n0
0300o`003_ooool40000o`03003o00000?l0003o0080003o0P00o`0B0000o`<00?l00P000?l5003o
0180003o0P00o`020?n000L00?l00P000?l3003o0080003o0P3o0007003o0080003o1000o`000`00
0?l00?l0003o00020000o`/00?l00`000?l2003o0080003o0`00o`0;0000o`800?l00P000?l7003o
00kooooo0P000?l2003o0200003o3P00o`040000o`800?l00`000?l2003o00L0003o0P00o`020000
o`<00?l010000?l3003o0080003o0P00o`050000o`@00?l01`000?l4003o00L0003o0P00o`090000
o`03003o00000?l0003o00@00?l01`000?l>ooooo`L0oh000P3o00070?n00080o`002@3oP0020?l0
00030?n0003o0000o`0000d0oh001@3o00040?n00080o`000`3oP002003o0080oh000P00o`0S0?n0
00800?l04P3oP0050?l000H0oh000`00o`040?n001Sooooo000Foooooad0o`0000<0oh000?l0003o
0000>03o00020?n00300o`003_ooool40000o`03003o00000?l0003o0080003o0P00o`0B0000o`<0
0?l00P000?l5003o0180003o0P00o`020?n000L00?l00P000?l3003o0080003o0P3o0007003o0080
003o1000o`000`000?l00?l0003o00020000o`/00?l00`000?l2003o0080003o0`00o`0;0000o`80
0?l00P000?l7003o00kooooo0P000?l2003o0200003o3P00o`040000o`800?l00`000?l2003o00L0
003o0P00o`020000o`<00?l010000?l3003o0080003o0P00o`050000o`@00?l01`000?l4003o00L0
003o0P00o`090000o`03003o00000?l0003o00@00?l01`000?l>ooooo`L0oh000P3o00070?n00080
o`002@3oP0020?l000030?n0003o0000o`0000d0oh001@3o00040?n00080o`000`3oP002003o0080
oh000P00o`0S0?n000800?l04P3oP0050?l000H0oh000`00o`040?n001Sooooo000FooooohX0o`00
3_oooolN0000o`800?l00P000?l5003o0180003o0P00o`020000o`800?l00P3oP007003o00030000
o`00o`000?l000800?l00P000?l5003o0080003o1000o`000`000?l00?l0003o00040000o`80oh00
1`00o`030000o`800?l00P000?l5003o0080003o0P00o`020000o`D00?l00P000?l5003o0080003o
3_ooool20000o`<00?l07`000?l3003o0080oh000P00o`020?n00080003o0`00o`020000o`@00?l0
30000?l=003o00030?n000000?l0003o00T0003o0P00o`070000o`800?l01@000?l2003o00@0003o
00<00?l00000o`000?l00P000?l9003o00L0003o0P00o`0>ooooo`T0oh001@3o000@0?n00080o`00
103oP007003o0080o`002@3oP0050?l000@0oh000P00o`030?l000800?l00P3o000>0?n00080o`00
303oP0020?l000T0oh000P3o000I0?n001Sooooo000FooooohX0o`003_ooool>0000o`800?l03P00
0?l2003o00@0003o0P00o`0@0000o`<00?l00P3oP0020000o`T00?l00`000?l4003o0080003o1@00
o`020000o`@00?l000<0003o003o0000o`000P000?l7003o00T0003o2@00o`040000o`D00?l00P00
0?l5003o0080003o3_oooolT0000o`T00?l00P000?l3003o0080003o0P00o`030000o`800?l02@00
0?l2003o0080003o00<0oh00003o0000o`002@00o`020000o`800?l00P000?l3003o00L0003o1P00
o`070000o`800?l00`000?lD003o00kooooo4P3oP0040?l000L0oh000`3o00060?n00003003o003o
P000oh0000800?l0403oP0020?l00100oh000P00o`030?n00080o`000P3oP002003o00T0oh000P3o
00030?n00080o`000P3oP0030?l001d0oh006?ooool001KoooooRP3o000>ooooo`h0003o0P00o`0>
0000o`800?l010000?l2003o0100003o0`00o`020?n00080003o2@00o`030000o`@00?l00P000?l5
003o0080003o1000o`000`000?l00?l0003o00020000o`L00?l02@000?l9003o00@0003o1@00o`02
0000o`D00?l00P000?l>ooooob@0003o2@00o`020000o`<00?l00P000?l2003o00<0003o0P00o`09
0000o`800?l00P000?l00`3oP0000?l0003o0009003o0080003o0P00o`020000o`<00?l01`000?l6
003o00L0003o0P00o`030000oa@00?l03_oooolB0?n000@0o`001`3oP0030?l000H0oh0000<00?l0
0?n0003oP0000P00o`0@0?n00080o`00403oP002003o00<0oh000P3o00020?n000800?l02@3oP002
0?l000<0oh000P3o00020?n000<0o`007@3oP00Hooooo`005_oooon:0?l000kooooo1@000?l2003o
01/0003o1000o`0B0000o`03003o00000?l0003o0080003o1000o`000`000?l00?l0003o0002003o
00<0003o0P00o`040000o`D00?l00P000?l4003o00030000o`00o`000?l00080oh001@00o`040000
o`800?l01@000?l4003o00<0003o0P00o`020000o`D00?l00P3oP0020000o`D00?l00P000?l>oooo
o`80003o0`00o`0O0000o`800?l00`3oP009003o00H0003o00<00?l00000o`000?l02@000?l4003o
00030000o`00o`000?l00080o`000P00o`020?l000030?n0003o0000o`0000T00?l00P000?l9003o
0080oh000P00o`030?n001000?l00P3oP005003o0080003o0P00o`0>ooooo`80o`002@3oP0030?l0
00T0oh000P00o`050?n00080o`00103oP003003o00l0oh000P3o00050?n00080o`00303oP004003o
00`0oh000P3o00020?n000@0o`00803oP0020?l000030?n0003o0000o`000080oh006?ooool001Ko
ooooRP3o000>ooooo`D0003o0P00o`0K0000o`@00?l04P000?l00`00o`00003o0000o`020000o`@0
0?l000<0003o003o0000o`000P00o`030000o`800?l010000?l5003o0080003o1000o`000`000?l0
0?l0003o00020?n000D00?l010000?l2003o00D0003o1000o`030000o`800?l00P000?l5003o0080
oh000P000?l5003o0080003o3_ooool20000o`<00?l07`000?l2003o00<0oh002@00o`060000o`03
003o00000?l0003o00T0003o1000o`000`000?l00?l0003o00020?l000800?l00P3o00000`3oP000
o`000?l00009003o0080003o2@00o`020?n000800?l00`3oP00@003o0080oh001@00o`020000o`80
0?l03_ooool20?l000T0oh000`3o00090?n000800?l01@3oP0020?l000@0oh000`00o`0?0?n00080
o`001@3oP0020?l000`0oh001000o`0<0?n00080o`000P3oP0040?l00200oh000P3o00000`3oP000
o`000?l000020?n001Sooooo000FooooohX0o`003_ooool20000o`800?l000<0003o003o0000o`00
0P00o`050000o`800?l050000?l2003o01<0003o0P00o`020000o`@00?l000<0003o003o0000o`00
0P00o`020000o`D00?l00P000?l3003o00@0003o1000o`000`000?l00?l0003o00020?l000@00?l0
3P000?l3003o00H0003o1`00o`020?n000<00?l010000?l>ooooo`80003o1@00o`090000o`800?l0
10000?l00`00o`00003o0000o`040000o`03003o00000?l0003o00@0003o3000o`0D0000o`L00?l0
0P3oP002003o00D0oh001000o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`00
1P00o`050000o`800?l000<0003o003o0000o`001P00o`000`000?l00?l0003o00020?n000T00?l0
3_ooool70?n000L0o`007`3oP0020?l000<00?l00P3oP002003o00D0o`00103oP002003o00D0oh00
0P3o00030?n00080003o2@3oP002003o0080003o1`3oP0030?l00080oh000P3o000R0?n001Sooooo
000FooooohX0o`003_ooool20000o`800?l000<0003o003o0000o`000P00o`050000o`800?l05000
0?l2003o01<0003o0P00o`020000o`@00?l000<0003o003o0000o`000P00o`020000o`D00?l00P00
0?l3003o00@0003o1000o`000`000?l00?l0003o00020?l000@00?l03P000?l3003o00H0003o1`00
o`020?n000<00?l010000?l>ooooo`80003o1@00o`090000o`800?l010000?l00`00o`00003o0000
o`040000o`03003o00000?l0003o00@0003o3000o`0D0000o`L00?l00P3oP002003o00D0oh001000
o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`001P00o`050000o`800?l000<0
003o003o0000o`001P00o`000`000?l00?l0003o00020?n000T00?l03_ooool70?n000L0o`007`3o
P0020?l000<00?l00P3oP002003o00D0o`00103oP002003o00D0oh000P3o00030?n00080003o2@3o
P002003o0080003o1`3oP0030?l00080oh000P3o000R0?n001Sooooo000FoooooeH0o`00103oP00`
0?l000kooooo0P00o`020000o`D00?l01@000?l2003o01@0003o0P00o`0C0000o`P00?l000<0003o
003o0000o`001@00o`020000o`800?l00P000?l3003o00P0003o2@00o`0G0000o`L00?l00P000?l3
003o00@0003o3_ooool20000o`<00?l06@000?l2003o00@0003o0`00o`020?l00080oh000P3o0005
003o00l0003o00<00?l00000o`000?l02`00o`020?n000D0o`001000o`050000o`@00?l000<0003o
003o0000o`000P3oP004003o00030000o`00o`000?l00080003o0P00o`030000o`@00?l00P000?l3
003o0080oh002@00o`0>ooooo`80003o0P00o`000`3oP000o`000?l000040?n000<0o`000P3oP004
0?l000`0oh000P00o`090?n000@0o`008P3oP005003o00D0oh000P3o000I0?n000800?l00P3oP002
0?l00003003o003o0000o`0000@0oh000P3o00050?n001Sooooo000Fooooo`@0oh00QP3o000>oooo
o`@00?l000<0003o003o0000o`000P00o`0E0000o`800?l010000?l2003o01<0003o2@00o`070000
o`@00?l00P3oP005003o00T0003o1P00o`0C0000o`800?l00P000?l7003o0080003o0`00o`040000
o`kooooo0P000?l3003o00@0003o0P00o`020000o`<00?l01P000?l00`00o`00003o0000o`040000
o`<00?l01P000?l00`00o`00oh000?n000020?n000D00?l020000?l00`00o`00003o0000o`090000
o`800?l00P000?l3003o0080003o1000o`000`3oP0000?l0003o0004003o00<0003o1000o`020000
o`800?l000<0003o003o0000o`000P00o`050000o`T00?l00P000?l90?n000D0003o0P00o`020?n0
00kooooo3@3oP0090?l000<00?l03P3oP0080?l000h0oh000P00o`0C0?n000800?l0=P3oP00Hoooo
o`005_ooool40?n008H0o`003_ooool4003o00030000o`00o`000?l000800?l05@000?l2003o00@0
003o0P00o`0C0000o`T00?l01`000?l4003o0080oh001@00o`090000o`H00?l04`000?l2003o0080
003o1`00o`020000o`<00?l010000?l>ooooo`80003o0`00o`040000o`800?l00P000?l3003o00H0
003o00<00?l00000o`000?l010000?l3003o00H0003o00<00?l00?n0003oP0000P3oP005003o00P0
003o00<00?l00000o`000?l02@000?l2003o0080003o0`00o`020000o`@00?l000<0oh00003o0000
o`001000o`030000o`@00?l00P000?l2003o00030000o`00o`000?l000800?l01@000?l9003o0080
003o2@3oP0050000o`800?l00P3oP00>ooooo`d0oh002@3o0003003o00h0oh00203o000>0?n00080
0?l04`3oP002003o03H0oh006?ooool001Kooooo;@3o00020?n005/0o`003_ooool20000o`800?l0
00<0003o003o0000o`000P00o`0E0000o`800?l00P000?l4003o00`0003o0P00o`040000o`h00?l0
0`000?l9003o00@0003o0P00o`050000o`800?l00P000?l2003o01L0003o1@00o`020000o`D00?l0
10000?l>ooooo`80003o0`00o`040000o`800?l00P000?l00`00o`00003o0000o`0G0000o`800?l0
0P000?l7003o0100003o1P00o`000`000?l00?l0003o000;003o00/0003o0P00o`000`000?l00?l0
003o0002003o00D0003o0P00o`040000o`<00?l00P000?l2003o0080003o00<0o`000?n0003oP000
1000o`020000o`D00?l03_oooolB0?n000@0o`000`3oP0020?l002@0oh000P3o000<0?n000L0o`00
0P3oP002003o00<0oh000P3o00070?n000@0o`004P3oP002003o00030000o`00o`000?l000/0oh00
6?ooool001Kooooo;@3o00020?n005/0o`003_ooool20000o`800?l000<0003o003o0000o`000P00
o`0E0000o`800?l00P000?l4003o00`0003o0P00o`040000o`h00?l00`000?l9003o00@0003o0P00
o`050000o`800?l00P000?l2003o01L0003o1@00o`020000o`D00?l010000?l>ooooo`80003o0`00
o`040000o`800?l00P000?l00`00o`00003o0000o`0G0000o`800?l00P000?l7003o0100003o1P00
o`000`000?l00?l0003o000;003o00/0003o0P00o`000`000?l00?l0003o0002003o00D0003o0P00
o`040000o`<00?l00P000?l2003o0080003o00<0o`000?n0003oP0001000o`020000o`D00?l03_oo
oolB0?n000@0o`000`3oP0020?l002@0oh000P3o000<0?n000L0o`000P3oP002003o00<0oh000P3o
00070?n000@0o`004P3oP002003o00030000o`00o`000?l000/0oh006?ooool001KoooooJP3o0002
0?n001h0o`003_ooool20000o`800?l000<0003o003o0000o`000P00o`0E0000o`800?l010000?l2
003o0100003o1@00o`020000o`@00?l000<0oh00003o0000o`000P00o`020000o`<00?l00P000?l5
003o0080003o0P00o`0T0000o`800?l000<0003o003o0000o`000P000?l4003o00D0003o3_ooool2
0000o`<00?l08P000?l2003o0080003o1`00o`040000o`800?l02P000?l2003o0080003o0P00o`00
0`000?l00?l0003o0002003o0080003o0P3oP0000`000?l00?l0003o0002003o00h0003o1000o`04
0000o`D00?l00P000?l5003o00@0003o1@00o`040000o`03003o00000?l0003o00800?l03_ooool2
0?n000<0o`00103oP0040?l000X0oh000P00o`020?n000800?l0803oP0020?l000<0oh000P000?l2
0?n000800?l00`3oP0060?l000<0oh001P00o`030?l000H0oh001`3o000<0?n00080o`000P3oP005
003o00/0oh006?ooool001KoooooJP3o00020?n001h0o`003_ooool20000o`800?l000<0003o003o
0000o`000P00o`0E0000o`800?l010000?l2003o0100003o1@00o`020000o`@00?l000<0oh00003o
0000o`000P00o`020000o`<00?l00P000?l5003o0080003o0P00o`0T0000o`800?l000<0003o003o
0000o`000P000?l4003o00D0003o3_ooool20000o`<00?l08P000?l2003o0080003o1`00o`040000
o`800?l02P000?l2003o0080003o0P00o`000`000?l00?l0003o0002003o0080003o0P3oP0000`00
0?l00?l0003o0002003o00h0003o1000o`040000o`D00?l00P000?l5003o00@0003o1@00o`040000
o`03003o00000?l0003o00800?l03_ooool20?n000<0o`00103oP0040?l000X0oh000P00o`020?n0
00800?l0803oP0020?l000<0oh000P000?l20?n000800?l00`3oP0060?l000<0oh001P00o`030?l0
00H0oh001`3o000<0?n00080o`000P3oP005003o00/0oh006?ooool001KoooooRP3o000>ooooo`80
003o0P00o`000`000?l00?l0003o0002003o00@0003o00<00?l00000o`000?l02`000?l2003o0003
0000o`00o`000?l00080003o1000o`0:0000o`800?l00P000?l4003o00D0003o0P00o`020?n000D0
0?l00P000?l5003o0080oh002`00o`000`000?l00?l0003o0002003o00L0003o0P00o`0B0000o`D0
0?l00P000?l4003o00030000o`00o`000?l00080003o3_ooool5003o00l0003o0`00o`020000o`80
0?l030000?l2003o0080003o1@00o`060000o`800?l05`000?l20?n000<0003o0P00o`0>0000o`@0
0?l010000?l00`00o`00003o0000o`02003o0080003o1@00o`020000o`D00?l01P000?l00`00o`00
003o0000o`02003o00kooooo2`3oP0020?l00003003o003o0000o`0000L0oh000P00o`020?n000D0
o`00403oP0080?l000D0oh000P3o00020?n000030?l0003oP000oh000080oh000P3o000<0?n00080
o`001`3oP0040?l000L0oh00103o00000`3oP000o`000?l0000;0?n000800?l01`3oP0020?l000<0
oh000P3o000Hooooo`005_oooon:0?l000kooooo0P000?l2003o00030000o`00o`000?l000800?l0
10000?l00`00o`00003o0000o`0;0000o`800?l000<0003o003o0000o`000P000?l4003o00X0003o
0P00o`020000o`@00?l01@000?l2003o0080oh001@00o`020000o`D00?l00P3oP00;003o00030000
o`00o`000?l000800?l01`000?l2003o0180003o1@00o`020000o`@00?l000<0003o003o0000o`00
0P000?l>ooooo`D00?l03`000?l3003o0080003o0P00o`0<0000o`800?l00P000?l5003o00H0003o
0P00o`0G0000o`80oh000`000?l2003o00h0003o1000o`040000o`03003o00000?l0003o00800?l0
0P000?l5003o0080003o1@00o`060000o`03003o00000?l0003o00800?l03_ooool;0?n00080o`00
00<00?l00?l0003o00001`3oP002003o0080oh001@3o000@0?n000P0o`001@3oP0020?l00080oh00
00<0o`000?n0003oP0000P3oP0020?l000`0oh000P3o00070?n000@0o`001`3oP0040?l000030?n0
003o0000o`0000/0oh000P00o`070?n00080o`000`3oP0020?l001Sooooo000Fooooob80o`000P3o
P01V0?l000kooooo0P000?l2003o00030000o`00o`000?l000800?l010000?l00`00o`00003o0000
o`0;0000o`D00?l00P000?l4003o00X0003o0P00o`020000o`L00?l00P000?l2003o0080oh001@00
o`020000o`03003o00000?l0003o00l00?l000<0003o003o0000o`001P00o`000`000?l00?l0003o
0002003o00`0003o0P00o`040000o`h00?l00P000?l>ooooo`80003o0`00o`0A0000o`03003o0000
0?l0003o0180003o0P3oP005003o01T0003o0P00o`050000o`800?l08P000?l2003o00@0003o00<0
0?l00000o`000?l02@000?l2003o00kooooo0P3oP005003o00@0oh000P3o00000`00o`00oh000?n0
0002003o0080003o2@3oP005003o00T0oh000P3o000b0?n000@0o`001`3oP0030?l000L0oh00103o
00020?n000D00?l0103o00070?n001Sooooo000FooooohX0o`003_ooool9003o00@0003o0`00o`0@
0000o`H00?l02P000?l2003o00@0003o0P00o`000`000?l00?l0003o0009003o0080oh000`00o`02
0000oal00?l01`000?l2003o00030000o`00o`000?l00080003o1`00o`070000o`@00?l03_ooool4
0000o`03003o00000?l0003o00l0003o00<00?l00000o`000?l05P000?l3003o0200003o0P00o`0?
0000o`<00?l00P000?l4003o00D0003o0P00o`0G0000o`kooooo103oP0000`00o`00oh000?n00002
0?n00080o`000P3oP0000`00o`00003o0000o`020?n00080003o0P3oP0000`3o0000003o0000o`04
0?l000T0oh0000<0o`000?n0003oP000103oP0020?l000<0oh000P3o00040?n000030000o`3oP000
oh0001d0oh000P00o`000`3o0000oh000?n000020?l00080oh000`3o000;0?n00080o`002`3oP005
003o0080o`001@3oP0020?l001Sooooo000FooooohX0o`003_ooool9003o00@0003o0`00o`0@0000
o`H00?l02P000?l2003o00@0003o0P00o`000`000?l00?l0003o0009003o0080oh000`00o`020000
oal00?l01`000?l2003o00030000o`00o`000?l00080003o1`00o`070000o`@00?l03_ooool40000
o`03003o00000?l0003o00l0003o00<00?l00000o`000?l05P000?l3003o0200003o0P00o`0?0000
o`<00?l00P000?l4003o00D0003o0P00o`0G0000o`kooooo103oP0000`00o`00oh000?n000020?n0
0080o`000P3oP0000`00o`00003o0000o`020?n00080003o0P3oP0000`3o0000003o0000o`040?l0
00T0oh0000<0o`000?n0003oP000103oP0020?l000<0oh000P3o00040?n000030000o`3oP000oh00
01d0oh000P00o`000`3o0000oh000?n000020?l00080oh000`3o000;0?n00080o`002`3oP005003o
0080o`001@3oP0020?l001Sooooo000FooooohX0o`003_ooool20000o`800?l000<0003o003o0000
o`000P00o`040000o`<00?l03@000?l00`00o`00003o0000o`04003o0180003o0P00o`000`000?l0
0?l0003o000>003o0080003o1P00o`000`3oP000003o0000o`06003o00030000o`00o`000?l000@0
0?l00P3o00000`3oP0000?l0003o0002003o00`0003o0P00o`020000o`T00?l010000?l00`00o`00
003o0000o`02003o00kooooo;`000?l00`00o`00003o0000o`0P0000o`800?l010000?l2003o00T0
003o00<00?l00000o`000?l01`00o`040000o`800?l04P000?l3003o0080003o3_oooolh0?n000<0
0?l0103oP0030?l00180oh000P3o00020?n000`0o`00103oP0070?l001H0oh001@3o000Hooooo`00
5_oooon:0?l000kooooo0P000?l2003o00030000o`00o`000?l000800?l010000?l3003o00d0003o
00<00?l00000o`000?l01000o`0B0000o`800?l000<0003o003o0000o`003P00o`020000o`H00?l0
00<0oh000000o`000?l01P00o`000`000?l00?l0003o0004003o0080o`0000<0oh00003o0000o`00
0P00o`0<0000o`800?l00P000?l9003o00@0003o00<00?l00000o`000?l00P00o`0>ooooobl0003o
00<00?l00000o`000?l080000?l2003o00@0003o0P00o`090000o`03003o00000?l0003o00L00?l0
10000?l2003o0180003o0`00o`020000o`kooooo>03oP003003o00@0oh000`3o000B0?n00080o`00
0P3oP00<0?l000@0oh001`3o000F0?n000D0o`006?ooool001KoooooQ@3o00000`00o`00o`000?l0
00020?l000kooooo1`000?l2003o00@0003o0`00o`0;0000o`<00?l00P000?l4003o01D0003o2`00
o`040000o`03003o00000?l0003o00H00?l00`000?l4003o00<0003o0P3oP0020000o`800?l00P3o
P0030000o`800?l02@000?l2003o00030000o`00o`000?l000@0003o1@00o`020000o`800?l00P00
0?l00`00o`00003o0000o`02003o00kooooo7@000?l00`00o`00003o0000o`090000o`800?l00P00
0?l2003o02<0003o0P00o`040000o`800?l02@000?l3003o0080003o1000o`0E0000o`800?l00`00
0?l2003o0080003o3_ooool40?n000D0o`002`3oP0020?l000L0oh0000<0o`000?n0003oP0002`3o
P0040?l000<0oh001000o`020000o`D00?l02@3oP002003o00`0oh002@3o00060?n000030?l0003o
P000oh0001H0oh0000<0o`000?n0003oP0001`3oP0020?l00080oh006?ooool001KoooooQ@3o0000
0`00o`00o`000?l000020?l000kooooo1`000?l2003o00@0003o0`00o`0;0000o`<00?l00P000?l4
003o01D0003o2`00o`040000o`03003o00000?l0003o00H00?l00`000?l4003o00<0003o0P3oP002
0000o`800?l00P3oP0030000o`800?l02@000?l2003o00030000o`00o`000?l000@0003o1@00o`02
0000o`800?l00P000?l00`00o`00003o0000o`02003o00kooooo7@000?l00`00o`00003o0000o`09
0000o`800?l00P000?l2003o02<0003o0P00o`040000o`800?l02@000?l3003o0080003o1000o`0E
0000o`800?l00`000?l2003o0080003o3_ooool40?n000D0o`002`3oP0020?l000L0oh0000<0o`00
0?n0003oP0002`3oP0040?l000<0oh001000o`020000o`D00?l02@3oP002003o00`0oh002@3o0006
0?n000030?l0003oP000oh0001H0oh0000<0o`000?n0003oP0001`3oP0020?l00080oh006?ooool0
01KoooooRP3o000>ooooo`80003o0P00o`000`000?l00?l0003o0004003o0080003o1@00o`040000
o`03003o00000?l0003o0080003o0`00o`020000o`@00?l05@000?l6003o0080o`000`00o`020000
o`<00?l00P000?l4003o00L0003o1000o`000`000?l00?l0003o0006003o00030?n000000?l0003o
00@00?l030000?l2003o00@0003o00<00?l00000o`000?l01000o`020000o`03003o00000?l0003o
00800?l03_ooool]0000o`D00?l09P000?l2003o00030000o`00o`000?l000@0003o0P00o`000`00
0?l00?l0003o00020000o`D00?l01`000?l2003o00@0003o0P00o`070000o`800?l00`000?l2003o
00kooooo2`3oP0050?l000@0oh000P3o000:0?n00080o`000P3oP0030?l000@0oh001@3o00020?n0
0080003o0P3oP0020?l00003003o003oP000oh0001L0oh000P3o00020?n00080o`000P3oP0000`3o
0000oh000?n000070?n00080o`002@3oP0020?l000<0oh001P3o000;0?n000030?l0003oP000oh00
0080oh006?ooool001KoooooRP3o000>ooooo`80003o0P00o`000`000?l00?l0003o0004003o0080
003o1@00o`040000o`03003o00000?l0003o0080003o0`00o`020000o`@00?l05@000?l6003o0080
o`000`00o`020000o`<00?l00P000?l4003o00L0003o1000o`000`000?l00?l0003o0006003o0003
0?n000000?l0003o00@00?l030000?l2003o00@0003o00<00?l00000o`000?l01000o`020000o`03
003o00000?l0003o00800?l03_ooool]0000o`D00?l09P000?l2003o00030000o`00o`000?l000@0
003o0P00o`000`000?l00?l0003o00020000o`D00?l01`000?l2003o00@0003o0P00o`070000o`80
0?l00`000?l2003o00kooooo2`3oP0050?l000@0oh000P3o000:0?n00080o`000P3oP0030?l000@0
oh001@3o00020?n00080003o0P3oP0020?l00003003o003oP000oh0001L0oh000P3o00020?n00080
o`000P3oP0000`3o0000oh000?n000070?n00080o`002@3oP0020?l000<0oh001P3o000;0?n00003
0?l0003oP000oh000080oh006?ooool001KoooooMP3o00020?n00180o`003_ooool20000o`800?l0
00<0003o003o0000o`003@00o`020000o`<00?l00P000?l3003o0080003o1P00o`0C0000o`800?l0
0P000?l7003o0080003o0`00o`040000o`D00?l010000?l2003o0080003o00<00?l00000o`000?l0
1P00o`030000o`800?l02@000?l2003o00<0003o0P00o`020000o`<00?l010000?l5003o00@0003o
3_ooool50000o`800?l09P000?l3003o02X0003o00<00?l00000o`000?l010000?l2003o00T0003o
00<00?l00000o`000?l01@000?l2003o00@0003o0`00o`060000o`<00?l010000?l>ooooo`800?l0
1@3o000G0?n00080o`00503oP002003o00/0oh000`00o`040?n000D0o`000P3oP0050?l001P0oh00
1@3o00030?n000H0o`00403oP00Hooooo`005_oooon:0?l000kooooo0P000?l2003o00030000o`00
o`000?l000@00?l00P000?l5003o00@0003o00<00?l00000o`000?l01@00o`020000o`L00?l04@00
0?l3003o0080003o1@00o`020?n00080003o0`00o`020000o`L00?l00P000?l9003o0080003o1000
o`030000o`800?l02@000?l2003o00<0003o5000o`0>ooooo`@0003o0`00o`0?0000o`03003o0000
0?l0003o00h0003o0P00o`020000o`D00?l060000?l00`00o`00003o0000o`0?0000o`<00?l01000
0?l5003o0080oh001@00o`060000o`<00?l010000?l;003o00030000o`00o`000?l000800?l03_oo
ool90?n00080o`00?P3oP0020?l00080oh000P3o0002003o00T0oh0000<0o`000?n0003oP000103o
P0020?l000030?n0003o0000o`0000@0o`001@3oP0020?l000L0oh000P3o000>0?n000800?l06?oo
ool001KoooooRP3o000>ooooo`80003o0P00o`000`000?l00?l0003o0004003o0080003o1@00o`04
0000o`03003o00000?l0003o00D00?l00P000?l7003o0140003o0`00o`020000o`D00?l00P3oP002
0000o`<00?l00P000?l7003o0080003o2@00o`020000o`@00?l00`000?l2003o00T0003o0P00o`03
0000oa@00?l03_ooool40000o`<00?l03`000?l00`00o`00003o0000o`0>0000o`800?l00P000?l5
003o01P0003o00<00?l00000o`000?l03`000?l3003o00@0003o1@00o`020?n000D00?l01P000?l3
003o00@0003o2`00o`000`000?l00?l0003o0002003o00kooooo2@3oP0020?l003h0oh000P3o0002
0?n00080o`000P00o`090?n000030?l0003oP000oh0000@0oh000P3o00000`3oP000o`000?l00004
0?l000D0oh000P3o00070?n00080o`003P3oP002003o01Sooooo000FooooohX0o`003_ooool2003o
0080o`0000<0003o003o0000o`001000o`020000o`<00?l01P000?l30?n00080003o0`00o`020000
o`80oh001@00o`0B0000o`@00?l00P000?l:003o0080o`000P00o`020?l000<00?l00P000?l?003o
00<0003o0P00o`0>0000o`800?l00P000?l;003o00030?n000000?l0003o00800?l03_ooool40000
o`<00?l03`000?l3003o0080003o0P00o`050000o`800?l00`000?l9003o00P0003o00<00?l00000
o`000?l00P000?l4003o00X0003o0P00o`020000o`<00?l020000?l00`00o`00003o0000o`020000
o`@00?l000<0003o003o0000o`000P3oP005003o00H0003o1`00o`030000o`800?l010000?l3003o
00@0003o3_ooool20000o`/0o`0000<0oh000?l0003o0000103oP00:0?l000@0oh0010000?l00`00
o`00oh000?n000060?n000030?l0003oP000oh000080o`001@3oP0060?l000D0oh000P3o00020?n0
00030?l0003oP000oh0000T0oh000P3o00020?n000D0o`000P3oP0020?l00080oh004`3o000D0?n0
01Sooooo000FooooohX0o`003_ooool2003o0080o`0000<0003o003o0000o`001000o`020000o`<0
0?l01P000?l30?n00080003o0`00o`020000o`80oh001@00o`0B0000o`@00?l00P000?l:003o0080
o`000P00o`020?l000<00?l00P000?l?003o00<0003o0P00o`0>0000o`800?l00P000?l;003o0003
0?n000000?l0003o00800?l03_ooool40000o`<00?l03`000?l3003o0080003o0P00o`050000o`80
0?l00`000?l9003o00P0003o00<00?l00000o`000?l00P000?l4003o00X0003o0P00o`020000o`<0
0?l020000?l00`00o`00003o0000o`020000o`@00?l000<0003o003o0000o`000P3oP005003o00H0
003o1`00o`030000o`800?l010000?l3003o00@0003o3_ooool20000o`/0o`0000<0oh000?l0003o
0000103oP00:0?l000@0oh0010000?l00`00o`00oh000?n000060?n000030?l0003oP000oh000080
o`001@3oP0060?l000D0oh000P3o00020?n000030?l0003oP000oh0000T0oh000P3o00020?n000D0
o`000P3oP0020?l00080oh004`3o000D0?n001Sooooo000FoooooeP0o`000P00o`0U0?l000800?l0
2@3o000>ooooo`80003o0P3o00000`000?l00?l0003o0004003o0080003o0`00o`0=0000o`03003o
00000?l0003o0080003o0P00o`0E0000o`800?l010000?l3003o00@0003o0`00o`060?l000<00?l0
0P000?l7003o0080003o1P00o`030000o`800?l03P000?l2003o00@0003o00<00?l00?n0003oP000
0P3oP0020?l000<00?l00P000?l2003o00kooooo0P00o`020000o`<00?l03`000?l00`00o`00003o
0000o`0@0000o`800?l00P3oP003003o00@0003o0P00o`030000o`800?l01P000?l00`00o`00003o
0000o`070000o`800?l010000?l00`00o`00003o0000o`060000o`03003o00000?l0003o00@0003o
0P00o`050000o`@00?l020000?l2003o0080003o1000o`0:0000o`@00?l03_ooool=0?n000<0o`00
403oP0040?l000800?l000<0003o003o0000o`00:03oP0000`3o0000oh000?n000040?n000D0o`00
103oP0030?l000@0oh00103o00000`00o`00oh000?n000040?n000030?l0003oP000oh0000L0oh00
0P3o0004003o0080003o00<00?l00?n0003oP0000P3oP00Hooooo`005_oooomH0?l000800?l09@3o
0002003o00T0o`003_ooool20000o`80o`0000<0003o003o0000o`001000o`020000o`<00?l03@00
0?l00`00o`00003o0000o`020000o`800?l05@000?l2003o00@0003o0`00o`040000o`<00?l01P3o
0003003o0080003o1`00o`020000o`H00?l00`000?l2003o00h0003o0P00o`040000o`03003o003o
P000oh000080oh000P3o0003003o0080003o0P00o`0>ooooo`800?l00P000?l3003o00l0003o00<0
0?l00000o`000?l040000?l2003o0080oh000`00o`040000o`800?l00`000?l2003o00H0003o00<0
0?l00000o`000?l01`000?l2003o00@0003o00<00?l00000o`000?l01P000?l00`00o`00003o0000
o`040000o`800?l01@000?l4003o00P0003o0P00o`020000o`@00?l02P000?l4003o00kooooo3@3o
P0030?l00100oh00103o0002003o00030000o`00o`000?l002P0oh0000<0o`000?n0003oP000103o
P0050?l000@0oh000`3o00040?n000@0o`0000<00?l00?n0003oP000103oP0000`3o0000oh000?n0
00070?n00080o`001000o`020000o`03003o003oP000oh000080oh006?ooool001KoooooFP3o0000
0`3oP000o`000?l000070?l00080oh006@3o0002003o00T0o`003_ooool20000o`<0oh001000o`04
0000o`D00?l040000?l2003o01D0003o0P00o`020000o`D00?l00P000?l2003o0080003o1@3o000F
003o00<0003o0P00o`0>0000o`800?l00P000?l5003o00@0oh000`00o`020000o`800?l03_ooool4
0000o`<00?l06@000?l2003o0080003o0`00o`020000o`800?l00P000?l3003o00@0003o0P00o`09
0000o`800?l020000?l2003o00@0003o0`00o`0?0000o`800?l000<0003o0?n0003oP0000P3oP004
003o00030000o`00o`000?l000800?l00P000?l3003o0080003o0P3oP002003o00030000o`00o`00
0?l00080003o1000o`000`000?l00?l0003o0002003o00kooooo;`3oP0000`3o0000oh000?n00006
0?n00003003o003o0000o`000080o`00403oP0040?l001<0oh000P3o000T0?n001Sooooo000Foooo
odP0o`0000<0oh000?l0003o00006@3o00020?n002@0o`003_ooool20000o`800?l000<0oh00003o
0000o`000P00o`040000o`03003o00000?l0003o02d0003o2`00o`000`3o0000oh000?n00007003o
0080003o3`00o`030000o`800?l00P000?l2003o00<0003o0P00o`050000o`800?l00P000?l5003o
00@0o`001@00o`020000o`kooooo1`00o`0?0000o`03003o00000?l0003o00/0003o0`00o`080000
o`03003o00000?l0003o00@00?l00P000?l3003o0080003o0P00o`0B0000o`03003o00000?l0003o
00@00?l00P000?l00`00o`00003o0000o`040000o`800?l000<0003o003o0000o`000P000?l2003o
0080003o1@00o`020000o`03003o00000?l0003o00l00?l000<0003o003o0000o`000P000?l>oooo
o`@0oh000`00o`0b0?n00080o`002`3oP0020?l000L0oh000P3o00030?n000800?l09P3oP0030?l0
00H0oh001@3o000Hooooo`005_oooom80?l000030?n0003o0000o`0001T0o`000P3oP00T0?l000ko
oooo0P000?l2003o00030?n00000o`000?l000800?l010000?l00`00o`00003o0000o`0]0000o`/0
0?l000<0o`000?n0003oP0001`00o`020000o`l00?l00`000?l2003o0080003o0P00o`030000o`80
0?l01@000?l2003o0080003o1@00o`040?l000D00?l00P000?l>ooooo`L00?l03`000?l00`00o`00
003o0000o`0;0000o`<00?l020000?l00`00o`00003o0000o`04003o0080003o0`00o`020000o`80
0?l04P000?l00`00o`00003o0000o`04003o0080003o00<00?l00000o`000?l010000?l2003o0003
0000o`00o`000?l00080003o0P00o`020000o`D00?l00P000?l00`00o`00003o0000o`0?003o0003
0000o`00o`000?l00080003o3_ooool40?n000<00?l0<P3oP0020?l000/0oh000P3o00070?n00080
o`000`3oP002003o02H0oh000`3o00060?n000D0o`006?ooool001Kooooo0P3oP0100?l000@0oh00
9`3o00020?n001/0o`003_ooool4003o00030000o`00o`000?l000800?l010000?l00`00o`00003o
0000o`0Y0000o`800?l00P000?l2003o0080003o1@00o`020000o`03003o003o0000o`0000L00?l0
0P000?l6003o00030?n00000o`000?l000@00?l00P000?l5003o0080003o0P00o`000`000?l00?l0
003o0002003o00D0003o0P00o`020000o`800?l000<0oh00003o0000o`00103oP007003o00kooooo
0P000?l3003o00@0003o0P00o`0^0000o`800?l06`000?l2003o00T0003o0`00o`020000o`H00?l0
1@000?l3003o0080003o1P00o`000`000?l00?l0003o000;003o00kooooo103oP003003o00@0oh00
0`3o00020?n000@0o`001`3oP0020?l000`0oh000P3o000;0?n000<0o`000P00o`040?l000X0oh00
1P3o000D0?n000X0o`001P3oP0000`3o0000oh000?n0000D0?n001Sooooo000Fooooo`80oh00@03o
00040?n002L0o`000P3oP00K0?l000kooooo1000o`000`000?l00?l0003o0002003o00@0003o00<0
0?l00000o`000?l0:@000?l2003o0080003o0P00o`020000o`D00?l00P000?l00`00o`00o`000?l0
0007003o0080003o1P00o`000`3oP0000?l0003o0004003o0080003o1@00o`020000o`800?l000<0
003o003o0000o`000P00o`050000o`800?l00P000?l2003o00030?n00000o`000?l000@0oh001`00
o`0>ooooo`80003o0`00o`040000o`800?l0;P000?l2003o01/0003o0P00o`090000o`<00?l00P00
0?l6003o00D0003o0`00o`020000o`H00?l000<0003o003o0000o`002`00o`0>ooooo`@0oh000`00
o`040?n000<0o`000P3oP0040?l000L0oh000P3o000<0?n00080o`002`3oP0030?l000800?l0103o
000:0?n000H0o`00503oP00:0?l000H0oh0000<0o`000?n0003oP000503oP00Hooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59885 L
.2381 .59885 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59885 L
.2381 .59885 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0123 L
.47619 .0123 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01877 L
.95238 .01877 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01647 L
.2381 .01647 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01647 L
.2381 .01647 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .47557 L
.47619 .47557 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .47557 L
.47619 .47557 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .13391 L
.71429 .13391 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .13391 L
.71429 .13391 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF800000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF00FF8000FF000000FF00
FF80000000FF00FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF000000FF00
00FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF0000FF800000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF800000FF000000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FFFF8000FF0000FF00000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF800000FF00
FF8000FF80000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FFFF800000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF00FF00000000FF00FF00FF800000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF00FF0000FF000000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00FF00000000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FFFF000000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FFFF8000FF800000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF00FF000000FF0000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01439 L
.2381 .01439 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01439 L
.2381 .01439 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .10033 L
.47619 .10033 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .10033 L
.47619 .10033 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .51124 L
.71429 .51124 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .51124 L
.71429 .51124 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF00000000FF0000FF
FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF000000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF8000FF0000FF80000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01314 L
.2381 .01314 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01314 L
.2381 .01314 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01564 L
.47619 .01564 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01564 L
.47619 .01564 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0123 L
.71429 .0123 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .60073 L
.95238 .60073 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .60073 L
.95238 .60073 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo
02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0
o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5ooo
O`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001E
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Soooo
o`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`00
0?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oo
oolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0goooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?l007oo001o00;o
001o5_oo001Eo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l07Ol007lGo`3o00Co
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0=ol007lGo`00oaoo
001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`1Bo`00OaOoogl01?l007l00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000oooo
ooooool09?ooool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00
Ool007l0D_l007lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Co
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol0
0?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
oaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0
>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool0
8oooool002Cooooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?oo
ool00ol0003o001oo`00O`0Mo`00OaOo0?l0>Ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o03Oo001o5ol00?lOo`00O`03o`000?oooooooooo02Cooooo00?o0000o`00Ool007l0D_l0
07lGoomo00Co001o00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo
5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooooooo
ool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo
0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oo
oolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08ooo
ool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
05Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l0>Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0=ol007lGo`00oaoo
001o00?o0000ooooooooool09?ooool00ol0003o001oo`00O`1Bo`00OaOoogl01?l007l00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0goooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo
5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo
001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooo
ooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03
o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
oolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolF
ool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo
00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
ooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo
00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo
000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooooooo
o`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000
ooooooooool08oooool002Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Soooo
o`009?oooomao`0002KoooooLOl0000Wooooog7o00009_oooomao`0002Gooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`005ooooomD0?l000@0oh008P3o00020?n000030?l0003oP000oh0000/0o`003_oooolT003o
00030?n00000o`000?l000@0003o4@00o`020000o`800?l00P3o000>003o0080003o7P00o`020000
o`<00?l00P000?l6003o00030?n000000?l0003o00L0003o0P00o`0>ooooo`D0003o1000o`020000
o`03003o00000?l0003o00@0003o0P00o`0N0000o`<00?l0E0000?l>ooooofP0oh000P3o000B0?n0
00030?l0003oP000oh0000/0oh006Oooool001OoooooE03o00040?n00280o`000P3oP0000`3o0000
oh000?n0000;0?l000kooooo9000o`000`3oP0000?l0003o00040000oa400?l00P000?l2003o0080
o`003P00o`020000oah00?l00P000?l3003o0080003o1P00o`000`3oP000003o0000o`070000o`80
0?l03_ooool50000o`@00?l00P000?l00`00o`00003o0000o`040000o`800?l07P000?l3003o05@0
003o3_oooomX0?n00080o`004P3oP0000`3o0000oh000?n0000;0?n001Wooooo000GooooocH0o`00
0`3oP0110?l00080oh003P3o000>ooooo`800?l00P000?lJ003o0080003o0P00o`020?l000030?n0
0000o`000?l000@0003o5@00o`020?l000`00?l010000?l3003o0080003o5`00o`020000o`L00?l0
0P000?l2003o0080oh0000<0o`00003o0000o`000P3oP0020000o`03003o00000?l0003o00800?l0
3_ooool40000o`P00?l010000?l2003o01h0003o0P00o`020000o`03003o00000?l0003o0580003o
3_oooon:0?n001Wooooo000GooooocH0o`000`3oP0110?l00080oh003P3o000>ooooo`800?l00P00
0?lJ003o0080003o0P00o`020?l000030?n00000o`000?l000@0003o5@00o`020?l000`00?l01000
0?l3003o0080003o5`00o`020000o`L00?l00P000?l2003o0080oh0000<0o`00003o0000o`000P3o
P0020000o`03003o00000?l0003o00800?l03_ooool40000o`P00?l010000?l2003o01h0003o0P00
o`020000o`03003o00000?l0003o0580003o3_oooon:0?n001Wooooo000GooooocH0o`000`3oP00K
0?l00080oh00903o00050?n000L0o`00103oP00>ooooo`800?l00P000?lA003o0080003o3@00o`00
0`000?l00?l0003o00020000oaL00?l00P3o000N003o0080o`005`00o`020?l00080003o00<0o`00
003o0000o`000P00o`020000o`D00?l03_ooool40000o`L00?l02P000?l2003o0200003o0P00o`1@
0000o`koooooL`3oP0000`3o0000oh000?n0000D0?n001Wooooo000GooooohD0o`001@3oP00>oooo
o`@0003o8000o`050000oa800?l01@000?l20?l00080oh0000<00?l00000o`000?l00P000?lG003o
0080o`002`00o`030000o`D00?l020000?l5003o0080oh0000<00?l00000o`000?l00P00o`0>oooo
o`@0003o00<00?l00000o`000?l01000o`0A0000o`800?l04P000?l2003o00<0003o1P00o`0g0000
o`<00?l050000?l>ooooohX0oh006Oooool001OoooooQ@3o00050?n000kooooo10000?lP003o00D0
003o4P00o`050000o`80o`000P3oP0000`00o`00003o0000o`020000oaL00?l00P3o000;003o00<0
003o1@00o`080000o`D00?l00P3oP0000`00o`00003o0000o`02003o00kooooo10000?l00`00o`00
003o0000o`04003o0140003o0P00o`0B0000o`800?l00`000?l6003o03L0003o0`00o`0D0000o`ko
ooooRP3oP00Iooooo`005ooooom90?l00080oh001`3o00020?n003H0o`003_ooool40000ob400?l0
10000?lB003o00030000o`00o`000?l000H0003o00<00?l00000o`000?l00P000?l2003o0080003o
4000o`000`000?l00?l0003o0007003o0080003o1000o`000`000?l00?l0003o00040000o`D00?l0
3P000?l2003o00kooooo10000?l5003o0080003o00<00?l00000o`000?l0?@000?l50?n00080o`00
0`000?l40?l00080003o0P3o000E0000o`D00?l04P000?l>ooooohX0oh006Oooool001OoooooB@3o
00020?n000L0o`000P3oP00f0?l000kooooo10000?lQ003o00@0003o4P00o`000`000?l00?l0003o
00060000o`03003o00000?l0003o0080003o0P00o`020000oa000?l000<0003o003o0000o`001`00
o`020000o`@00?l000<0003o003o0000o`0010000?l5003o00h0003o0P00o`0>ooooo`@0003o1@00
o`020000o`03003o00000?l0003o03d0003o1@3oP0020?l000<0003o103o00020000o`80o`005@00
0?l5003o0180003o3_oooon:0?n001Wooooo000Gooooog<0o`0000<0oh000?l0003o0000503o000>
oooooaL00?l00P000?lS003o00/0003o0P00o`050000o`800?l010000?l00`00o`00003o0000o`06
0000o`D00?l01@000?l6003o00030000o`00o`000?l000L00?l01`000?l2003o00L0003o0P00o`0>
ooooo`@0003o2P00o`0T0000o`<00?l01P000?l00`00o`00003o0000o`0=0000o`80o`000`3oP002
0?l000800?l000<0003o003o0000o`0080000?l2003o0100003o3_oooomQ0?n00080003o9`3oP00I
ooooo`005ooooomc0?l000030?n0003o0000o`0001@0o`003_oooolG003o0080003o8`00o`0;0000
o`800?l01@000?l2003o00@0003o00<00?l00000o`000?l01P000?l5003o00D0003o1P00o`000`00
0?l00?l0003o0007003o00L0003o0P00o`070000o`800?l03_ooool40000o`X00?l090000?l3003o
00H0003o00<00?l00000o`000?l03@000?l20?l000<0oh000P3o0002003o00030000o`00o`000?l0
0200003o0P00o`0@0000o`koooooH@3oP0020000obL0oh006Oooool001OoooooM03o00020?n001@0
o`003_oooolE003o0080003o3P00o`020000o`800?l00P000?lA003o00P0003o00<00?l00000o`00
0?l02`000?l2003o00030000o`00o`000?l000@0003o1`00o`050000o`H00?l000<0003o003o0000
o`000P00o`020000o`T00?l000<0003o003o0000o`002@000?l>ooooo`@0003o1@00o`020000o`03
003o00000?l0003o02@0003o0P00o`0G0000o`<0oh000P3o00020?n002`0003o0P00o`090000o`ko
ooooRP3oP00Iooooo`005ooooon:0?l000kooooo9`00o`040000oa400?l020000?l3003o01@0003o
4000o`030000o`d00?l00P000?l3003o00@0003o00<00?l00000o`000?l00P00o`0>ooooo`@0003o
00<00?l00000o`000?l01`00o`020000o`800?l00`000?l4003o01T0003o0P00o`000`000?l00?l0
003o000D0000o`80oh0000<0o`000?n0003oP000103oP00N0000o`800?l02P000?l2003o00T0003o
3_oooon:0?n001Wooooo000GooooohX0o`003_oooolW003o00@0003o4@00o`080000o`<00?l05000
0?l@003o00<0003o3@00o`020000o`<00?l010000?l00`00o`00003o0000o`02003o00kooooo1000
0?l00`00o`00003o0000o`07003o0080003o0P00o`030000o`@00?l06@000?l2003o00030000o`00
o`000?l001@0003o0P3oP0000`3o0000oh000?n000040?n001h0003o0P00o`0:0000o`800?l02@00
0?l>ooooohX0oh006Oooool001OoooooRP3o000>ooooobD00?l00P000?l2003o0080003o4@00o`08
0000o`<00?l050000?lP003o00<0003o0P3oP0070000o`800?l03_ooool40000o`L00?l000<0003o
003o0000o`001`000?l4003o01L0003o1@00o`1D0000o`koooooRP3oP00Iooooo`005ooooon:0?l0
00kooooo9@00o`020000o`800?l00P000?lA003o00P0003o0`00o`0D0000ob000?l00`000?l20?n0
00L0003o0P00o`0>ooooo`@0003o1`00o`000`000?l00?l0003o00070000o`@00?l05`000?l5003o
05@0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolT003o00<0003o0P00o`020000oa00
0?l000<0003o003o0000o`0010000?l9003o0080003o00<0oh000?l0003o00000P3o00070000o`/0
0?l000<0003o003o0000o`005000o`020000o`030?n00000o`000?l000@0oh000`000?l2003o00ko
oooo0P000?l9003o00D0003o1`00o`0I0000o`@00?l06@000?l00`3oP000o`000?l0000T0000o`<0
0?l02@000?l4003o00D0003o3_ooool=0?n00003003o003oP000oh0000L0oh000P000?ma0?n001Wo
oooo000GooooohX0o`003_oooolT003o00<0003o0P00o`020000oa000?l000<0003o003o0000o`00
10000?l9003o0080003o00<0oh000?l0003o00000P3o00070000o`/00?l000<0003o003o0000o`00
5000o`020000o`030?n00000o`000?l000@0oh000`000?l2003o00kooooo0P000?l9003o00D0003o
1`00o`0I0000o`@00?l06@000?l00`3oP000o`000?l0000T0000o`<00?l02@000?l4003o00D0003o
3_ooool=0?n00003003o003oP000oh0000L0oh000P000?ma0?n001Wooooo000Goooooe40o`0000<0
0?l00?l0003o0000=P3o000>ooooob@00?l000<0003o003o0000o`000P00o`020000oa<00?l01000
0?l7003o00@0003o00<0oh00003o0000o`001000o`000`000?l00?l0003o000V003o00<0003o1000
o`050000o`kooooo1@000?l7003o00@0003o2`00o`0E0000o`D00?l0?@000?l2003o01D0003o3_oo
oon:0?n001Wooooo000Goooooe40o`0000<00?l00?l0003o0000=P3o000>ooooob@00?l000<0003o
003o0000o`000P00o`020000oa<00?l010000?l7003o00@0003o00<0oh00003o0000o`001000o`00
0`000?l00?l0003o000V003o00<0003o1000o`050000o`kooooo1@000?l7003o00@0003o2`00o`0E
0000o`D00?l0?@000?l2003o01D0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolU003o
0080003o0P00o`020000oa400?l01P000?l3003o0080o`000P000?l2003o0080oh0000<00?l00000
o`000?l00P000?lN003o0080003o2@00o`050000o`80o`001@000?l2003o00kooooo1`000?l;003o
0200003o0P00o`070000o`03003o00000?l0003o03L0003o0P00o`040000o`800?l030000?l>oooo
oaT0oh000P00o`1_0?n001Wooooo000GooooohX0o`003_oooolU003o0080003o5@00o`080000o`03
003o003o0000o`000080o`000P00o`070000o`D00?l010000?lC003o00@0003o3000o`020000o`80
0?l01@000?l2003o00kooooo0P000?l2003o00<0003o1000o`000`000?l00?l0003o0006003o00<0
003o0P00o`020000o`03003o00000?l0003o01L0003o0P00o`020000o`L00?l0=@000?l2003o0180
003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolU003o0080003o5@00o`080000o`03003o
003o0000o`000080o`000P00o`070000o`D00?l010000?lC003o00@0003o3000o`020000o`800?l0
1@000?l2003o00kooooo0P000?l2003o00<0003o1000o`000`000?l00?l0003o0006003o00<0003o
0P00o`020000o`03003o00000?l0003o01L0003o0P00o`020000o`L00?l0=@000?l2003o0180003o
3_oooon:0?n001Wooooo000GooooogP0o`000P3oP00;0?l000030?n0003o0000o`000080o`003_oo
oolU003o0080003o5000o`070000o`L00?l00P000?l5003o0080003o:`00o`000`000?l00?l0003o
0002003o00D0003o0P00o`0>ooooo`80003o0P00o`000`000?l00?l0003o0002003o0080003o0`00
o`040000o`800?l01`000?l3003o01/0003o0`00o`1=0000o`koooooRP3oP00Iooooo`005ooooomh
0?l00080oh002`3o00000`3oP000o`000?l000020?l000kooooo9@00o`020000oa@00?l01`000?l7
003o0080003o1@00o`020000ob/00?l000<0003o003o0000o`000P00o`050000o`800?l03_ooool2
0000o`800?l000<0003o003o0000o`000P00o`020000o`<00?l010000?l2003o00L0003o0`00o`0K
0000o`<00?l0C@000?l>ooooohX0oh006Oooool001OoooooP`3o00020?n000D0o`003_oooolT003o
00030000o`00o`000?l001L00?l010000?l7003o0080003o0`00o`020?l00080003o1@00o`060000
oa`00?l00P000?l2003o00P0003o1000o`0>ooooo`80003o0`00o`020000o`800?l040000?l2003o
01`0003o0P00o`1@0000o`koooooRP3oP00Iooooo`005ooooon30?l00080oh001@3o000>ooooob@0
0?l000<0003o003o0000o`005`00o`040000o`L00?l00P000?l3003o0080o`000P000?l5003o00H0
003o7000o`020000o`800?l020000?l4003o00kooooo0P000?l3003o0080003o0P00o`0@0000o`80
0?l070000?l2003o0500003o3_oooon:0?n001Wooooo000GooooohD0o`0000<0oh000?l0003o0000
0P3o000>oooooc/00?l01`000?l3003o00P0003o00<0o`00003o0000o`000P000?l3003o0080003o
9000o`090000o`D00?l03_ooool70000o`800?l040000?l2003o01T0003o00<00?l00000o`000?l0
0P00o`0d0000o`03003o00000?l0003o01T0003o3_oooomf0?n00080o`004P3oP00Iooooo`005ooo
oon50?l000030?n0003o0000o`000080o`003_oooolk003o00L0003o0`00o`080000o`030?l00000
o`000?l00080003o0`00o`020000ob@00?l02@000?l5003o00kooooo1`000?l2003o0100003o0P00
o`0I0000o`03003o00000?l0003o00800?l0=0000?l00`00o`00003o0000o`0I0000o`koooooMP3o
P0020?l00180oh006Oooool001OoooooRP3o000>ooooob000?l00P000?lI003o00L0003o1@00o`02
0000o`800?l00`000?l2003o00@0003o0`00o`070000o`L00?l00P000?l9003o0080003o2@00o`03
0000o`/00?l03_ooool40000o`<00?l02`000?l3003o01l0003o1`00o`150000o`800?l01`000?l>
ooooobH0oh0000<00?l00?n0003oP0006@3oP002003o04H0oh006Oooool001OoooooRP3o000>oooo
oah00?l00P000?l2003o0080003o4@00o`020000o`800?l02@000?l2003o00030000o`00o`000?l0
00@00?l00`000?l2003o0080003o0P00o`070000o`800?l000<0003o003o0000o`000P00o`020000
o`03003o00000?l0003o00@00?l00P000?lC003o00@0003o1@00o`0>oooooa80003o0`00o`0P0000
o`@00?l040000?l2003o03h0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolN003o0080
003o0P00o`020000oa400?l00P000?l2003o00T0003o0P00o`000`000?l00?l0003o0004003o00<0
003o0P00o`020000o`800?l01`000?l2003o00030000o`00o`000?l000800?l00P000?l00`00o`00
003o0000o`04003o0080003o4`00o`040000o`D00?l03_oooolB0000o`<00?l080000?l4003o0100
003o0P00o`0n0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo>@00o`050000o`80o`00
0P000?l9003o00<0003o0P00o`020000oa<00?l010000?l2003o0080003o4@00o`040000o`L00?l0
3_ooool40000o`L00?l030000?l2003o01/0003o00<00?l00000o`000?l00P00o`0B0000o`80o`00
00<0003o0?n0003oP0000P3o00020?n000030000o`00o`000?l000800?l09@000?l20?n000T0003o
3_ooool2003o07X0oh0000<00?l00?n0003oP0000P3oP002003o00L0oh006Oooool001OoooooRP3o
000>ooooocT00?l01@000?l20?l00080003o2@00o`030000o`800?l00P000?lC003o00@0003o0P00
o`020000oa400?l010000?l7003o00kooooo10000?l7003o00`0003o0P00o`0K0000o`03003o0000
0?l0003o00800?l04P000?l20?l000030000o`3oP000oh000080o`000P3oP0000`000?l00?l0003o
0002003o02D0003o0P3oP0090000o`kooooo0P00o`1j0?n00003003o003oP000oh000080oh000P00
o`070?n001Wooooo000GooooohX0o`003_oooolN003o00H0003o4@00o`020000o`@00?l01`000?l9
003o00L0003o2`00o`000`000?l00?l0003o0005003o00P0003o4@00o`060000o`D00?l03_ooool5
0000o`@00?l02@000?l2003o02<0003o0P00o`0B0000o`800?l020000?l2003o0380003o3_oooomo
0?n000800?l02@3oP00Iooooo`005ooooon:0?l000kooooo7P00o`060000oa400?l00P000?l4003o
00L0003o2@00o`070000o`/00?l000<0003o003o0000o`001@00o`080000oa400?l01P000?l5003o
00kooooo1@000?l4003o00T0003o0P00o`0S0000o`800?l04P000?l2003o00P0003o0P00o`0b0000
o`koooooO`3oP002003o00T0oh006Oooool001OoooooB@3o00020?n003l0o`003_oooolR003o0080
003o5`00o`070000o`800?l000<0003o003o0000o`000P00o`090000o`L00?l00P000?l2003o0003
0000o`00o`000?l002000?l00P000?l7003o00kooooo10000?l<003o0080003o0P00o`030000o`80
0?l03P000?l2003o0080003o00<0oh000000o`000?l01`000?l4003o01T0003o0P3o00000`00o`00
003o0000o`0>0000o`80oh008P000?l>ooooo`80oh000P00o`1k0?n000800?l02@3oP00Iooooo`00
5ooooon:0?l000kooooo7P00o`060000oa000?l000<0003o003o0000o`000P00o`090000o`L00?l0
10000?l00`00o`00003o0000o`020000o`<00?l020000?lP003o00030000o`00o`000?l000T00?l0
3_ooool50000o`L00?l00P000?l2003o00D0003o1000o`0K0000o`D00?l00P000?l00`00o`00003o
0000o`0f0000o`03003o00000?l0003o0180003o3_oooomo0?n000800?l02@3oP00Iooooo`005ooo
oon:0?l000kooooo7P00o`060000oa000?l000<0003o003o0000o`000P00o`090000o`L00?l01000
0?l00`00o`00003o0000o`020000o`<00?l020000?lP003o00030000o`00o`000?l000T00?l03_oo
ool50000o`L00?l00P000?l2003o00D0003o1000o`0K0000o`D00?l00P000?l00`00o`00003o0000
o`0f0000o`03003o00000?l0003o0180003o3_oooomo0?n000800?l02@3oP00Iooooo`005oooool>
0?l00080oh00M@3o00000`3oP000o`000?l000020?l000kooooo7P00o`060000oa400?l00P000?l4
003o00L0003o0P00o`000`000?l00?l0003o00020000o`@00?l01@000?l3003o00P0003o8000o`05
0000o`L00?l03_ooool2003o00<0003o1P00o`000`000?l00?l0003o0002003o0100003o0P00o`0B
0000o`L00?l04`000?l20?n001/0003o0P00o`0L0000o`koooooRP3oP00Iooooo`005oooool>0?l0
0080oh00M@3o00000`3oP000o`000?l000020?l000kooooo7P00o`060000oa400?l00P000?l4003o
00L0003o0P00o`000`000?l00?l0003o00020000o`@00?l01@000?l3003o00P0003o8000o`050000
o`L00?l03_ooool2003o00<0003o1P00o`000`000?l00?l0003o0002003o0100003o0P00o`0B0000
o`L00?l04`000?l20?n001/0003o0P00o`0L0000o`koooooRP3oP00Iooooo`005ooooon:0?l000ko
oooo8000o`040000oa400?l00P000?l7003o00H0003o1`00o`030000o`800?l00P000?l3003o0080
003o0P00o`050000oad00?l00P000?l00`00o`00003o0000o`020000o`L00?l03_ooool40000o`X0
0?l02@000?l4003o00<0003o1000o`0@0000o`800?l000<0003o003o0000o`001@00o`0a0000o`03
003o00000?l0003o00L0003o0P00o`0@0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo
8000o`040000oa400?l00P000?l7003o00H0003o1`00o`030000o`800?l00P000?l3003o0080003o
0P00o`050000oad00?l00P000?l00`00o`00003o0000o`020000o`L00?l03_ooool40000o`X00?l0
2@000?l4003o00<0003o1000o`0@0000o`800?l000<0003o003o0000o`001@00o`0a0000o`03003o
00000?l0003o00L0003o0P00o`0@0000o`koooooRP3oP00Iooooo`005ooooolm0?l00080oh00B`3o
000>ooooodT00?l02`000?l5003o00D0003o6@00o`060000o``00?l03_ooool50000o`H00?l01`00
0?l2003o00<0003o1@00o`020000o`800?l02`000?l00`00o`00003o0000o`070000o`T00?l09000
0?l3003o0080003o0P00o`0<0000o`H00?l03P000?l>ooooocT0oh000P3o001?0?n001Wooooo000G
ooooocd0o`000P3oP01;0?l000koooooB@00o`0;0000o`D00?l01@000?lI003o00H0003o3000o`0>
ooooo`D0003o1P00o`070000o`800?l00`000?l5003o0080003o0P00o`0;0000o`03003o00000?l0
003o00L0003o2@00o`0T0000o`<00?l00P000?l2003o00`0003o1P00o`0>0000o`kooooo>@3oP002
0?l004l0oh006Oooool001OoooooRP3o000>oooooc`00?l00P000?l;003o00T0003o:@00o`050000
o`T00?l03_ooool40000o`P00?l00P000?l2003o00@0003o3P00o`0<0000o`@00?l00`000?l2003o
0080003o0`00o`0V0000o`800?l04@000?l4003o0100003o3_oooon:0?n001Wooooo000GooooohX0
o`003_ooooli003o0080003o00<00?l00000o`000?l010000?l9003o0080003o00<00?l00000o`00
0?l00P000?l7003o00@0003o7P00o`020000o`03003o00000?l0003o0080003o1`00o`0>ooooo`@0
003o0`00o`020000o`L00?l00P000?l:003o0080003o0P00o`040000o`03003o00000?l0003o00h0
003o2@00o`0T0000o`800?l00`000?l2003o0080003o1@00o`0I0000o`kooooo403oP004003o07H0
oh006Oooool001OoooooRP3o000>ooooocT00?l00P000?l00`00o`00003o0000o`040000o`T00?l0
0P000?l00`00o`00003o0000o`020000o`L00?l010000?lN003o0080003o00<00?l00000o`000?l0
0P000?l7003o00kooooo10000?l3003o0080003o1`00o`020000o`X00?l00P000?l2003o00@0003o
00<00?l00000o`000?l03P000?l9003o02@0003o0P00o`030000o`800?l00P000?l5003o01T0003o
3_ooool@0?n000@00?l0MP3oP00Iooooo`005ooooon:0?l000kooooo8000o`020000oaX00?l01000
0?l7003o00/0003o9@00o`0;0000o`L00?l03_ooool40000o`<00?l00P000?l<003o0080003o0P00
o`070000o`@00?l040000?l:003o00T0003o0P00o`0R0000o`800?l070000?l>ooooo`@0oh0000<0
0?l00?n0003oP000P`3oP00Iooooo`005ooooon:0?l000kooooo8000o`020000oaX00?l010000?l7
003o00/0003o9@00o`0;0000o`L00?l03_ooool40000o`<00?l00P000?l<003o0080003o0P00o`07
0000o`@00?l040000?l:003o00T0003o0P00o`0R0000o`800?l070000?l>ooooo`@0oh0000<00?l0
0?n0003oP000P`3oP00Iooooo`005ooooon:0?l000kooooo>@00o`0;0000o`03003o00000?l0003o
00L0003o3`00o`050000o`800?l000<0003o003o0000o`005000o`0<0000o`800?l03_ooool40000
oa400?l00P000?l4003o00<0003o0P00o`0D0000o`P00?l02`000?l2003o0400003o3_oooon:0?n0
01Wooooo000GooooohX0o`003_ooooli003o00/0003o00<00?l00000o`000?l01`000?l?003o00D0
003o0P00o`000`000?l00?l0003o000D003o00`0003o0P00o`0>ooooo`@0003o4@00o`020000o`@0
0?l00`000?l2003o01@0003o2000o`0;0000o`800?l0@0000?l>ooooohX0oh006Oooool001Oooooo
P`3o00020?n000D0o`003_oooolb003o00<0003o1`00o`020000o`800?l010000?l00`00o`00003o
0000o`090000o`T00?l01@000?l4003o0080003o5@00o`020000o`D00?l00P000?l2003o00030000
o`00o`000?l000800?l03_ooool40000o`L00?l00`000?l6003o00D0003o0P00o`030000o`T00?l0
2@000?l2003o00L0003o1@00o`0M0000o`800?l04@000?l2003o01T0003o3_oooolR0?n000800?l0
IP3oP00Iooooo`005ooooon30?l00080oh001@3o000>oooooc800?l00`000?l7003o0080003o0P00
o`040000o`03003o00000?l0003o00T0003o2@00o`050000o`@00?l00P000?lE003o0080003o1@00
o`020000o`800?l000<0003o003o0000o`000P00o`0>ooooo`@0003o1`00o`030000o`H00?l01@00
0?l2003o00<0003o2@00o`090000o`800?l01`000?l5003o01d0003o0P00o`0A0000o`800?l06@00
0?l>ooooob80oh000P00o`1V0?n001Wooooo000Gooooogd0o`000P00o`0;0?l000kooooo?000o`09
0000o`800?l01`000?l2003o00@0003o1@00o`020000o`<00?l00P000?lM003o00<0003o1000o`00
0`000?l00?l0003o0002003o00kooooo1000o`000`000?l00?l0003o0004003o00030000o`00o`00
0?l000L00?l02`000?l2003o0100003o0P00o`080000o`800?l07@000?l2003o00030000o`00o`00
0?l002T0003o3_oooon:0?n001Wooooo000Gooooobl0o`0000<0oh000?l0003o00006`3o00020?n0
03/0o`003_ooool2003o0080003o=@00o`020000o`03003o00000?l0003o00800?l01`000?l40?n0
00<0003o2`00o`040000o`<00?l00P000?lW003o00kooooo1@000?l2003o0080003o0P00o`030000
o`L00?l02`000?l2003o0080003o00<00?l00000o`000?l00P00o`0B0000o`<00?l07@000?l2003o
00P0003o1000o`0P0000o`koooooRP3oP00Iooooo`005oooool_0?l000030?n0003o0000o`0001/0
o`000P3oP00k0?l000kooooo0P00o`020000ocD00?l00P000?l00`00o`00003o0000o`02003o00L0
003o103oP0030000o`/00?l010000?l3003o0080003o9`00o`0>ooooo`D0003o0P00o`020000o`80
0?l00`000?l7003o00/0003o0P00o`020000o`03003o00000?l0003o00800?l04P000?l3003o01d0
003o0P00o`080000o`@00?l080000?l>ooooohX0oh006Oooool001OoooooRP3o000>oooooch00?l0
2@000?l40?n000800?l000<0o`00003o0000o`00>@00o`0>ooooo`800?l00P000?l3003o00h0003o
0P00o`0N0000o`T00?l06`000?l2003o00D0003o0P00o`030000o`800?l08P000?l>oooood@0oh00
0P3o00140?n001Wooooo000GooooohX0o`003_ooooln003o00T0003o103oP002003o00030?l00000
o`000?l003T00?l03_ooool2003o0080003o0`00o`0>0000o`800?l07P000?l9003o01/0003o0P00
o`050000o`800?l00`000?l2003o0280003o3_oooom40?n00080o`00A03oP00Iooooo`005ooooon:
0?l000kooooo?000o`020000o`800?l02@000?l20?n000h00?l010000?l3003o0080003o9`00o`0>
ooooo`@0003o0`00o`050000o`800?l02@000?l2003o0200003o0`00o`1=0000o`koooooRP3oP00I
ooooo`005ooooon:0?l000kooooo?000o`020000o`800?l02@000?l20?n000h00?l010000?l3003o
0080003o9`00o`0>ooooo`@0003o0`00o`050000o`800?l02@000?l2003o0200003o0`00o`1=0000
o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo?000o`0;0000o`@00?l00P3o0003003o0080
003o0`00o`020000o`L00?l01`000?lT003o00kooooo1@000?l2003o00D0003o1000o`040000o`L0
0?l07P000?l5003o0300003o0P00o`0I0000o`kooooo1@3oP002003o0180oh000P00o`1_0?n001Wo
oooo000GooooohX0o`003_ooooli003o00D0003o0P3o00070000o`800?l00P000?l2003o00030000
o`00o`000?l000@00?l00`000?l2003o00L0003o0P00o`030000ob@00?l03_ooool20000o`<00?l0
E0000?l2003o0200003o0P00o`0<0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo>@00
o`050000o`80o`001`000?l2003o0080003o0P00o`000`000?l00?l0003o0004003o00<0003o0P00
o`070000o`800?l00`000?lT003o00kooooo0P000?l3003o05@0003o0P00o`0P0000o`800?l03000
0?l>ooooohX0oh006Oooool001OoooooRP3o000>oooooc/00?l040000?l3003o0080003o1@00o`09
0000o`800?l00P000?lW003o00kooooo30000?l2003o00T0003o0P00o`0R0000o`03003o00000?l0
003o01/0003o0P00o`0^0000o`kooooo1@3oP002003o08<0oh006Oooool001OoooooRP3o000>oooo
oc/00?l040000?l3003o0080003o1@00o`090000o`800?l00P000?lW003o00kooooo30000?l2003o
00T0003o0P00o`0R0000o`03003o00000?l0003o01/0003o0P00o`0^0000o`kooooo1@3oP002003o
08<0oh006Oooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.00596349 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13398 -12 -4.5 ]
[-0.0125 .13398 0 4.5 ]
[-0.0125 .25325 -12 -4.5 ]
[-0.0125 .25325 0 4.5 ]
[-0.0125 .37252 -12 -4.5 ]
[-0.0125 .37252 0 4.5 ]
[-0.0125 .49179 -12 -4.5 ]
[-0.0125 .49179 0 4.5 ]
[-0.0125 .61106 -18 -4.5 ]
[-0.0125 .61106 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13398 m
1 .13398 L
s
0 .25325 m
1 .25325 L
s
0 .37252 m
1 .37252 L
s
0 .49179 m
1 .49179 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13398 m
.00625 .13398 L
s
[(20)] -0.0125 .13398 1 0 Mshowa
0 .25325 m
.00625 .25325 L
s
[(40)] -0.0125 .25325 1 0 Mshowa
0 .37252 m
.00625 .37252 L
s
[(60)] -0.0125 .37252 1 0 Mshowa
0 .49179 m
.00625 .49179 L
s
[(80)] -0.0125 .49179 1 0 Mshowa
0 .61106 m
.00625 .61106 L
s
[(100)] -0.0125 .61106 1 0 Mshowa
.125 Mabswid
0 .04453 m
.00375 .04453 L
s
0 .07435 m
.00375 .07435 L
s
0 .10417 m
.00375 .10417 L
s
0 .1638 m
.00375 .1638 L
s
0 .19362 m
.00375 .19362 L
s
0 .22344 m
.00375 .22344 L
s
0 .28307 m
.00375 .28307 L
s
0 .31289 m
.00375 .31289 L
s
0 .34271 m
.00375 .34271 L
s
0 .40234 m
.00375 .40234 L
s
0 .43216 m
.00375 .43216 L
s
0 .46198 m
.00375 .46198 L
s
0 .52161 m
.00375 .52161 L
s
0 .55143 m
.00375 .55143 L
s
0 .58125 m
.00375 .58125 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13398 m
1 .13398 L
s
.99375 .25325 m
1 .25325 L
s
.99375 .37252 m
1 .37252 L
s
.99375 .49179 m
1 .49179 L
s
.99375 .61106 m
1 .61106 L
s
.125 Mabswid
.99625 .04453 m
1 .04453 L
s
.99625 .07435 m
1 .07435 L
s
.99625 .10417 m
1 .10417 L
s
.99625 .1638 m
1 .1638 L
s
.99625 .19362 m
1 .19362 L
s
.99625 .22344 m
1 .22344 L
s
.99625 .28307 m
1 .28307 L
s
.99625 .31289 m
1 .31289 L
s
.99625 .34271 m
1 .34271 L
s
.99625 .40234 m
1 .40234 L
s
.99625 .43216 m
1 .43216 L
s
.99625 .46198 m
1 .46198 L
s
.99625 .52161 m
1 .52161 L
s
.99625 .55143 m
1 .55143 L
s
.99625 .58125 m
1 .58125 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .60332 L
.06452 .60332 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .60332 L
.06452 .60332 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .48652 L
.22581 .48652 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .48652 L
.22581 .48652 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .56836 L
.3871 .56836 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .56836 L
.3871 .56836 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .48464 L
.54839 .48464 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .48464 L
.54839 .48464 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .44863 L
.70968 .44863 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .44863 L
.70968 .44863 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .47145 L
.87097 .47145 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .47145 L
.87097 .47145 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .28222 L
.09677 .28222 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .28222 L
.09677 .28222 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .32032 L
.25806 .32032 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .32032 L
.25806 .32032 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .27574 L
.41935 .27574 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .27574 L
.41935 .27574 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .29416 L
.58065 .29416 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .29416 L
.58065 .29416 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .42414 L
.74194 .42414 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .42414 L
.74194 .42414 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .3513 L
.90323 .3513 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .3513 L
.90323 .3513 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .39986 L
.12903 .39986 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .39986 L
.12903 .39986 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .34732 L
.29032 .34732 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .34732 L
.29032 .34732 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .46475 L
.45161 .46475 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .46475 L
.45161 .46475 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .27427 L
.6129 .27427 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .27427 L
.6129 .27427 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .16333 L
.77419 .16333 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .16333 L
.77419 .16333 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .48443 L
.93548 .48443 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .48443 L
.93548 .48443 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .44884 L
.16129 .44884 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .44884 L
.16129 .44884 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .35444 L
.32258 .35444 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .35444 L
.32258 .35444 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .30002 L
.48387 .30002 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .30002 L
.48387 .30002 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .5558 L
.64516 .5558 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .5558 L
.64516 .5558 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .33455 L
.80645 .33455 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .33455 L
.80645 .33455 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .41179 L
.96774 .41179 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .41179 L
.96774 .41179 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`0002kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Qoooooooo0000IOl0000;ooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`coogl02ol0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000;ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool001Oooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_o
o`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool0
00_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;oooo
o`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o
003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00Wo
oooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000@ooooo`Go00000oooool2o`0000Oooooo00?o0000ooooooooool02?ooool<
ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;
o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004Oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?oo
ool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0
o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`coo`002ol0
o`0<o`00o`coogl02_l007l<ool000_o0?l03?l00?l<oomo00_o001o2ooo000<o`3o00_o003o3?oo
O`0;o`00O`_oo`003?l0o`0;o`00o`googl02_l007l<ool000_o0?l02ol00?l=oomo00[o001o3?oo
000;o`3o00co003o3?ooO`08o`00O`Co00002oooool001?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l0
0?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02ooo
ool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`00
2ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o
3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0017ooooo
0ol00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00002Oooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;
o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=
oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool<
ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;
o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool0
00co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;oooo
o`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`004_ooool3o`0000?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02ooo
ool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Ooo
ool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003ooooooooo
o`09ooooo`004?ooool5o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo
000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_oo
ool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000@
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001_ooool3o`0000So001o
3?oo000;o`3o00co003o3?ooO`0:o`00O`coo`002ol0o`0<o`00o`coogl02ol007l;ool000co0?l0
2ol00?l<oomo00_o001o2ooo000<o`3o00_o003o3OooO`0:o`00O`coo`003?l0o`0:o`00O`googl0
2_l007l<ool000_o0?l03?l00?l<oomo00So001o1?l0000;ooooo`004Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool<ool000_o0?l0
3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl0
2oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`00
2ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l0
0007ooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<
ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000:ooooo`co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<ool000_ooooo2ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`coo`005_ooool=oomo
00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`co
o`005_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
2_ooool<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo3?oo000;ooooo`co003o
5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l0
3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool000[ooooo3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`coo`002ooo
ool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool<
ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:oooo
o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027o
oooo0_l00009ooooo`goo`002_ooool<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_o
oooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00Wooooo0ol0000;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?oo
O`0;ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l02_oo
ool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_ooool<
o`00o`coogl02oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool0
00[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:oooo
o`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[o
oooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`go
ogl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o
3?ooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool<ool000_ooooo3?l00?lFooooo`coo`00
5_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_oo
ool<o`00o`coogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`co003o5_oo
ool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=
ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool<
o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
00[ooooo3?l00?l<oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`coo`002oooool<o`00
oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool<ool000_o0?l03?l00?l<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`002_ooool<o`00o`co
ogl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Ko
oooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`coo`002ol0o`0<o`00o`coogl02Oooool3o`0000_o
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00
2_ooool<o`00o`coogl02oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo
3?oo000<o`3o027ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`005_ooool<
oomo00_ooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Q
ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool0
00[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_o
oooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3Ooo000:ooooo`co
003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo000:ooooo`co003o3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`00
5_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000:ooooo`co003o3?oo
O`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000A
ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<
oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<
ool000co0?l08Oooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo3Ooo000]ooooo`coo`002ooo
ool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo3?l0
0?l<oomo00_ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool000[ooooo
3?l00?l<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl0
2_ooool<ool000co0?l08Oooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool0
2Oooool0013ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`goo`00
2_l007l<o`00o`coogl02_l007l=ool002go001o3?oo000;o`00O`co003o5_l007l<ool001Ko001o
3OooO`0:o`00O`coo`003?l0o`0Qo`00O`goo`002_l007l<o`00o`coogl02?l007l4o`0000_ooooo
000@ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o
5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool000[ooooo3?l00?l<oomo00[ooooo
3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l0
8Oooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool001;ooooo0_l0
0004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_oo
ool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0
o`0Qooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;
ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool0
01Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`co
ogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`co
o`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo
3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`00
2_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_oo
ool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02ooo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<
o`00o`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:
ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`002_ooool<o`00o`coogl02_ooool=ool0
02gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qoooo
o`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wo
oooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Ko
oooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02Oooool3o`0000_o
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo
3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`00
2_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKooooo3?oo
000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:
ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo000<
o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;oooo
o`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool=o`00
oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Ko
oooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[o
oooo3?oo000<o`3o027ooooo3Ooo000:ooooo`go003o5_ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00
2oooool<o`00oaKooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo
3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3Ooo
O`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<
ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`goo`002_ooool=
o`00oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
01Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo
00[ooooo3Ooo000/ooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0027o
oooo0_l00009ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`002oooool<o`00oaKo
oooo3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo000:ooooo`go003o5?ooool3o`0000_o
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo
3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo
3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3Ooo
O`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;
ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lF
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Foooo
o`coogl02_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:oooo
o`goo`00;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000;ooooo`co
003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lFooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl0
2_ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`goo`00
;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l00?lFooooo`coo`005_oo
ool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000;ooooo`co003o5_ooool<
ool001Kooooo3OooO`13ooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool=ool002cooooo3Ooo000]ooooo`coo`002oooool<o`00
oaKooooo3?oo000Fooooo`googl0@oooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_o
oooo3?l00?lFooooo`coo`005_ooool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003o
ooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo
3?l00?lFooooo`coo`005_ooool=oomo04?ooooo3Ooo000:ooooo`go003o5?ooool3o`0000_ooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool000_ooooo3?l0
0?lFooooo`coo`005_ooool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000]
ooooo`coo`005_ooool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000]oooo
o`coo`005_ooool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=ool002gooooo3?oo000]ooooo`co
o`005_ooool=oomo05[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool002gooooo3?oo000Fooooo`googl0
F_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool002cooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`1Jooooo`go003o5_oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00;?ooool=
ool002gooooo3?oo000]ooooo`coo`005_ooool=oomo05[ooooo3Ol00?lFooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool02?ooool=ool0
02cooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`1Jooooo`go003o5_ooool00ol0
003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1m
ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`?o00002?l007l=ool006Ko001o3?oo001?o`00O`googl0N_l0
07l4o`0000_ooooo000Aooooo`?o00000oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Ooo
ool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003ooooo
ooooo`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03
o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool0
2?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=
oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
06Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo
001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3Ooo001V
ooooo`coo`00Coooool=oomo07_ooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0
OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_oo
ool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oo
oooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003ooooooooo
o`09ooooo`008Oooool2o`0000Wooooo3Ooo001Vooooo`coo`00Coooool=oomo07_ooooo0ol0000;
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1moooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`co
o`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool006Kooooo3?oo003Iooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo001Vooooo`coo`00fOooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`00I_ooool<ool00=Wooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo003Iooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00oooooom<ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000
ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`00oooooom:ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`00oooooom<ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00oooooom<ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003ooooo
ooooo`09ooooo`002oooool3o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooooooo
o`08ooooo`goo`00oooooom<ooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo0?ooooooHOooool00ol0003oooooooooo`09ooooo`003?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`3oooooof7ooooo00?o0000ooooooooool02Oooool000cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000Ooooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Moooo
o`Co00002oooool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`002oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0006oooooooo0000IOl0000;ooooo`003?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`000?ooooooMoooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool0047ooooo0ol0000eooooo`Go0000=_ooool3o`0003Oooooo0ol0000eoooo
o`?o0000=_ooool3o`0002kooooo0012ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooo
oooo0000=Oooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0<oooool0
1Ol0003ooooooooooooooooo000003Cooooo00Go0000ooooooooooooooooo`00000]ooooo`00@_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_oo
ool5o`0003Sooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002gooooo
0012ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool2o`0003Gooooo00Co
0000oooooooooooo0000>Oooool00ol0003oooooooooo`0booooo`Co0000;_ooool004;ooooo00?o
0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0
<oooool00ol0003oooooo`00000eooooo`Co0000=Oooool00ol0003oooooooooo`0_ooooo`00@Ooo
ool2o`0003Kooooo00Go0000ooooooooooooooooo`00000eooooo`05o`000?ooooooooooooooool0
0000=_ooool2o`0003Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`00
@_ooool00ol0003oooooooooo`0eooooo`?o0000=oooool3o`0003Sooooo00?o0000ooooooooool0
<oooool5o`0003Kooooo0_l0000^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.119489, -8.81706, \
0.0174717, 0.472545}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.00594025 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13352 -12 -4.5 ]
[-0.0125 .13352 0 4.5 ]
[-0.0125 .25233 -12 -4.5 ]
[-0.0125 .25233 0 4.5 ]
[-0.0125 .37113 -12 -4.5 ]
[-0.0125 .37113 0 4.5 ]
[-0.0125 .48993 -12 -4.5 ]
[-0.0125 .48993 0 4.5 ]
[-0.0125 .60874 -18 -4.5 ]
[-0.0125 .60874 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13352 m
.00625 .13352 L
s
[(20)] -0.0125 .13352 1 0 Mshowa
0 .25233 m
.00625 .25233 L
s
[(40)] -0.0125 .25233 1 0 Mshowa
0 .37113 m
.00625 .37113 L
s
[(60)] -0.0125 .37113 1 0 Mshowa
0 .48993 m
.00625 .48993 L
s
[(80)] -0.0125 .48993 1 0 Mshowa
0 .60874 m
.00625 .60874 L
s
[(100)] -0.0125 .60874 1 0 Mshowa
.125 Mabswid
0 .04442 m
.00375 .04442 L
s
0 .07412 m
.00375 .07412 L
s
0 .10382 m
.00375 .10382 L
s
0 .16322 m
.00375 .16322 L
s
0 .19292 m
.00375 .19292 L
s
0 .22262 m
.00375 .22262 L
s
0 .28203 m
.00375 .28203 L
s
0 .31173 m
.00375 .31173 L
s
0 .34143 m
.00375 .34143 L
s
0 .40083 m
.00375 .40083 L
s
0 .43053 m
.00375 .43053 L
s
0 .46023 m
.00375 .46023 L
s
0 .51964 m
.00375 .51964 L
s
0 .54934 m
.00375 .54934 L
s
0 .57904 m
.00375 .57904 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13352 m
1 .13352 L
s
.99375 .25233 m
1 .25233 L
s
.99375 .37113 m
1 .37113 L
s
.99375 .48993 m
1 .48993 L
s
.99375 .60874 m
1 .60874 L
s
.125 Mabswid
.99625 .04442 m
1 .04442 L
s
.99625 .07412 m
1 .07412 L
s
.99625 .10382 m
1 .10382 L
s
.99625 .16322 m
1 .16322 L
s
.99625 .19292 m
1 .19292 L
s
.99625 .22262 m
1 .22262 L
s
.99625 .28203 m
1 .28203 L
s
.99625 .31173 m
1 .31173 L
s
.99625 .34143 m
1 .34143 L
s
.99625 .40083 m
1 .40083 L
s
.99625 .43053 m
1 .43053 L
s
.99625 .46023 m
1 .46023 L
s
.99625 .51964 m
1 .51964 L
s
.99625 .54934 m
1 .54934 L
s
.99625 .57904 m
1 .57904 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .60144 L
.2381 .60144 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .60144 L
.2381 .60144 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .47822 L
.47619 .47822 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .47822 L
.47619 .47822 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .51387 L
.71429 .51387 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .51387 L
.71429 .51387 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00DOooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`0003gooooo001Booooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0??ooool005;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol0000mooooo`00D_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
03kooooo001Booooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000?_ooool0057ooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l0000n
ooooo`00D_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0??ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool0027oooooool0001Uo`0000_ooooo000Qooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`006?ooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00002oooool0
01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`005oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000?ooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl03Oooool4o`0000_ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
3ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool001;ooooo0ol00003ooooo`;o
00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000;ooooo
00Co0000oooooooooooo00001_ooool3o`0000koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0=ooooo`Co00002oooool0013ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`?o00003_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo00gooooo1?l0000;ooooo`004?ooool4o`0000?ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0>
ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00kooooo
A?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0013ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
4?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Aooooo`?o00000oooool01?l0003oooooooooool00006ooooo`?o00003_oooom4ool0
06GoooooA?l00?l@ooooodGoogl03Oooool4o`0000_ooooo000@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo001U
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oo
oom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3
o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
06GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool2o`0000ooooooA?oo002iooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool2o`0000ooooooA?oo002iooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002i
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
3ooooom4ool00;WoooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000;ooooo`?o00001?ooool2o`0000Cooooo0_l00007oooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`3oooooo`coooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?ooooooHOooool00ol0003ooooooooo
o`09ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001_ooool3o`000?ooooooG_ooool4o`0000_ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`00
2oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09oooo
o`003?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Ooooooool0001Uo`0000_o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo001Aooooo`?o0000DOooool5o`00053ooooo0ol0001Cooooo`?o0000?Ooo
ool005;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0001?ooooo`05o`000?oo
ooooooooooooool00000Doooool00ol0003oooooooooo`0looooo`00D_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0C_ooool5o`0003gooooo001B
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0D?ooool2o`00057ooooo00Co0000
oooooooooooo0000?_ooool005;ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooo
oooo000005?ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00000nooooo`00DOooool2
o`0005;ooooo00Go0000ooooooooooooooooo`00001?ooooo`05o`000?ooooooooooooooool00000
D_ooool2o`0003kooooo001Booooo`03o`000?oooooooooo057ooooo0ol0001Aooooo`?o0000E?oo
ool00ol0003oooooooooo`0looooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.00675159, -8.85156, \
0.0118357, 0.474394}}],

Cell[BoxData[
    \(89.97893997893998`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis and testing #6 (64 clusters per band)", "Section"],

Cell[CellGroupData[{

Cell["Level of quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Select level of quantization (1, 2, 3, 4, 5, 6)", "Subsubsection"],

Cell[BoxData[
    \(\(vqlevel = 6;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick corresponding VQ codebook and histograms", "Subsubsection"],

Cell[BoxData[{
    \(\(centroids = centroidsAll[\([vqlevel]\)];\)\), "\[IndentingNewLine]", 
    \(\(hist = histAll[\([vqlevel]\)];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize centroids by band", "Subsection"],

Cell["\<\
The graphics below illustrate the centroids by band (HL1, LH1, HH1, \
HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(VisualizeCentroids[#, ImageSize \[Rule] 500] &\)\  /@ \ 
        centroids;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A858735F46151B0F
C940FFB3682A0D31
E76A8D6E793E2017
9D3B897F4F4B1B06
6E6B5D6A7429082F
B7556E7B3B240612
775E61533C220002
764E5A19211C0B1B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
305D59775A794E4D
81B1EDFFD595844A
331D482D5821512C
271817001E1F352B
543255335B3B4C26
315880A6BEC3996C
1D403D4A63305931
65547E6366517454
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2428394927318B27
4B3A0036400D3E43
375416311F1B5B04
E00E109E111D3115
812BC64B0CC91926
D1195FA555526A9C
B61AB55633FF2E31
373C1B159103306F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26DA163269494A2B
B27A07FF191BC818
AA941F9043BF7504
598B36C3307DD413
AE1516C70598AC25
4C31702915C53C1B
5E052772214E6C50
331636220014141A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6E3D4328363B4129
3E28524A61426440
2D3F376B729E9456
5D628EA2FFE9B54E
321F3F464E455C43
3315100900012129
3C37200A1E130F0D
C48CAE89824A885A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
143C2F3E34141917
110412170802090C
1F0F261E1015040E
1418393C4E363329
1A2734375D24461F
2D462D34382B3323
160013171C1D0915
5482B3FFFF915444
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0BBA0013581B2A24
505438AA250B5816
1AD90C36822A4A24
8F8809FF310CE311
867B11A46D736503
208C1A9B4D58C114
870707BB044EAE0A
1F00423503092535
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B36411FF1932A635
AD89559637EC470F
7E6A59CE1796AE75
C22C34CF16CA7849
3145913F08CF4551
5712307A284F517A
1A295405128D1620
195E311771610025
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C2D34494E34504A
078E470E6D942C2C
576D257848003A9C
117345135DA91826
5BFB42FAC63C5DB8
12331C1B34591928
273B0C6843020355
61908090FF9B99A3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0319171D36403A0A
18150E09140F0A04
211B120F090D0700
221C15040A0A3012
2527223822464A2E
352D382D24482E1B
290D1F101A100E14
384A2A336ECAFF5E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BF6166476D430F5A
5A30FF0F379D2B33
4A62B31AE34B15AD
528EA516A86D7551
073FBD16A7635A6E
1C961808D7214D87
3B37524A3F3F8B0B
1C242E0B1A442F00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
15250E1A31323B2D
252E344E88DFFF95
3F3639313E525E2A
3224260E0A071105
1421060F1217191E
160C050A0519191F
0F1100160B2A0E21
5B49493E5044433D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1929182A4D2F323C
251B23331F30FF55
1223171236335D34
00090908182C241D
290C0F154B364E29
141515232F2AD331
332B1F1726546533
21192013373D423E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3D38410F1B1C2019
1B1415001C212C25
1C0E0C041F262D3E
1C1B3D2B2A4D5643
587699514D392930
505359314A44351D
26281C30132A2020
CCFFCB4C6D37454B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
30AD7712FF253062
217DA7438D45B825
1EB89035FC246D5B
16D53143C214D72B
435167836412C92B
1F980E389926912A
512A1C8E140AC510
12187A3112663500
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7718FF2112D0051B
BC2A9759AC692BAF
B929DA2C5CD0314A
2B25E90DA39A1ABE
616F4F1DC36F1A8A
0F158B0D57805747
1A4C080796091580
720E006626083F1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
65F7422A112B0502
4F9F2B08000F0404
41CC5C2C15260F0A
A5FF371904150C0D
49844E270D200C1C
92E12F230929130F
4ECC4F3314270E13
61C2263F12201623
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D825DB5E78FA3C6F
381CFF2090DD1AE1
5F76403CC56C0EAB
0C1B8C114E954A56
16551A0380001182
29931A36270E5C03
AF371CA92E1D5317
A62E7669724D4B79
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3427150C03001C27
462B151B0B150F25
5240213E3B523757
888E8090A595756E
72897BB18CBCB1A7
97BBD6FFEAF8F9D0
70B0BEC5B8C3D2A2
B3B5617986AF87D4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
34330F245B042D63
3982283842124A19
E32A14D60A195B1D
7E6F6C6934C0160F
CF3F3AF32C527F6B
D229809D13FF3524
522F967A0AB45091
03295B0039800F16
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C151C1E13140031
4C5E734949473F3E
69FFE7CA8E5E2F3F
4E765D7B3B626874
37393540366D5485
3A3C393944504758
284A232E24333B3E
6B4D51445A6B5E5D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B221F2831452E1C
2B372D2127242015
2326293926200F2C
20211B181E181520
1B0E081414120E15
0F00000910162517
0E140E090F161A1A
763A4C5EE8FF4D4F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B6F4FAC581C7F29
2FE4104ABE385155
44B208DD7E29FF15
96890DD36C5DAB21
3CA521BA7862C21F
A81A11EA1563DA18
53475A2A32B03E17
20460B0D383D0032
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
49493D371C3A3E03
FF1F21A71A255A35
9B2FC85F08EE192F
C40F7DA1467A59D2
C2139B8033F4355D
3905C53A33C215D8
712D5066756717A4
1F0E0D2F30003C59
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E4B601D4E160F16
481555560C2D230A
17716F073D55020D
3E228D6025412C0C
1C587C0C36360D00
3618223200041601
1A20660E02491903
393CFF5A1F77420D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
72885064395C4C37
FFA9615432313526
75582C2C0C1D050C
1622111B10030808
202E112112000221
09292D2E1F01141D
121A121A253A3A39
5446694B646593B4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
200E640D195F1E00
1E1A342E2A383223
165E311029651A18
19456E1533491B09
28FF2B1A9A1D173D
24A7376C2E346925
269B1D318C26493D
3C08277803247C2C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26DE359CB312FF0F
696139CE8C15D212
2AAA165CB63B9528
530805B11C18D910
3C2B292A2E711914
3611433900255B0E
834E47531F4C1F19
188D3517991C242F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D2A452E49953B1D
21213D4599761036
1F0E4A1F555B271F
2A0F3D364B551A24
04075B263E7B3019
2A38302FFFA53238
200048524243371D
241B44365B6C2A28
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
34383746372F232A
2C28333331211729
18372D4D47553C28
0E140A240E1E2422
070203090003050C
160B0E070D01020A
1E14101B142A2420
5DFFB89360583938
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1426661F3A431D1E
30D92B0A88271129
2C5D82615F366604
15FF4632FB172C54
20C2479D9718DC0E
49833083A0149B25
1FAE006AB81FA72A
4A251218203F121B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C71B90C94B8070D7
E80FA6A022FF3171
3428DC5915CE13B4
781D535A755E2DBB
0E128C0026AE2D6E
10291B00780C0791
12951E2A59303917
843C94493172000D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
300F43833E172027
163A4D52142C1909
27003E522F10142B
211E435B18100E1E
2E172F502B182810
482CFF9B2B3B2A32
1F2C503E2D171C2E
242139712D241F2C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3B5E584D72485261
5F65747299514842
4F5B4F6D624B3C4B
373538201820221C
301F29000E030B11
302C4E3657603E49
87D2E8FFEDD3AB85
A6AAA09BA594B38B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1657AD2E8C6B596A
18871D04C5193784
2A20264423368523
48230027490B4340
5C54332A1D134A00
FF2920A21824380E
8E37E8491DE5191F
6237452873474737
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
58D03F9FDB3D672C
3ED41DFB9A37FF21
884025EF503BCA1C
2E892B59577D761B
60141ABE092ABF25
411C48391160200E
2428752A163C4215
505F3CAE3F304A00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B1E212C2010221B
130F05191B0D1917
262A292D191C1F1B
A3DBFF9648222715
3C3D44291E2B0F11
09001B050D061616
26141C1B10170E1C
6F555649583A3A5B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
261E283E38352C2D
0C2215151C172F19
0B1B0F0500021119
211C111A291D1721
254239635E563931
1C2431383F203325
24251C1E172F2226
5439AFFF8C657150
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C195C002489142B
172A4F0C42160542
1FC2141F661D202D
585843C832106921
2ADD223E84494C2C
96A01CFF4220E314
887F19B1536D7A11
51023B840F225C48
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE171FB611345626
8045AB5F1EAE2212
F51763B1455D498B
D210E2631EFF1242
6510D26543A51DCA
902877556DA31B8E
090EB60E35B318A3
0F69270931172A00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
321F31461F5B5744
1927002E211C2443
4E505EEA4AE8FF4D
09470D2742273D32
2B22376E22696439
104416322B502430
1524264E2467922F
223A16443D5B454C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A1E2020241C2926
0F142224261C1D23
060B172223372C22
160D0E171B271824
1625140A0B0D080C
22250F0008010611
1419100905030B1A
494066494664FFB8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
692B3F4B225C321B
2518BF1D21891517
849A6D40AE3C1463
455BFF1A4CA9572F
3E8BBA0BF4531EA7
3AB0A311E7609F51
0C5BB939B453857D
041B1246051A8200
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BC3120FF3154F523
4A5D46473EA47318
5C0634990C4BBA2D
390F452B0D731C02
1F1E6A1D1C442F18
4EC84515733A1212
2E5BB550646B4B06
53B600A481168E1E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
212029232F279A54
230F030F10172725
290C0C0A310D3032
480D28464439FF62
3020310A37308144
1E14001B201A4A34
27131512272A5142
302A26262D13A427
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2027152413160D0E
0E14150B09040710
1A10110D04010807
240C070702000700
170B0110040A1B14
0F0E15111F1F2816
041D1F2723101E1A
FFAC41371F282931
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3889F306D4931AD2
4ACB800FCC8F5D99
1F51CA2694776E88
008E3103FF2B1BBD
2E492B4846338814
6C3E0926570E1946
41571B3629224A09
5427960A246F3D0F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C85671970EFF5424
7F3089AC14A8778A
BC065D991AC44D56
380BB02310E6147E
4823455E5645258F
0B11580210820831
1938342249050055
72240C70081A6A45
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DA2E39472729202B
9E2D233C1E261E2F
C01B3735132A2320
822016292519002E
EE2335481B362523
8C3118302B25121E
FF424C5B1D352B18
CD543059341E2140
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7552355588911894
0F007D1028AB3364
143F15067519138B
18521C1C332E3E13
77291B682D242D29
3F983D406449392A
F15729FF142B6F2D
2C20A3234D9C2197
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19170B0E16232B36
140400000A071C21
24212727191C313F
4C363B3E2C314B65
86867483725B625E
B0A19CB082694560
92837AA0958F678A
7EB1B7AD90FFD984
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
196E19079A181477
127017183E2E3C15
43421A3E5A082A41
3B9C1F3961104A2E
DC4B08FF0E1C9A1B
9654648D33A1211E
B84236D829489F62
032373003A900024
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C0B0207142A3A39
23221932316B364C
85737C9FA198956A
7F857198FFC2DA97
81687383828F9560
372A2A2D44324238
211D000700080617
6F50416443816972
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
272031353938251B
1E17111820241D1C
1513000F0C12191A
0B150E08170C1F20
131B12181B1E2222
241E2B1C21292D16
282734341D39291C
4252307AFF6D453F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B6DC32F5B41780F
1AE67C23FF0B3865
1CC0534CAD15C025
2C5C536A8D03A922
179C0124B80A8A32
2C191B731900B000
403D2536493C4017
3B89292032040D21
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3813173E00216E03
9E18246116370000
500EC70800892202
A539634A76572147
9133FF0B43F32716
3E44D40DC87B149D
717180029B7F3351
034507226F052D25
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2E6B1B3235517A58
729B9B78749BC47C
19352F2C591C4D9C
7FB580797A80A27F
125C3E30486D8481
A0BFC97DBD87DFA7
175E314300516075
88EF38D491B3B3FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B24262919264140
2233253319202B33
1023050C030E0C0A
1306000C0C0D171A
0809050A02201D1C
21171B1D11222252
1A20281C3F3C3B5B
7B53384B3B7BDCFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E68463B536E2A2A
411F3552162F6D1E
833747521A482717
2916C22D2F8A2414
8B8E8048BB3F166A
5858DF2860916E33
3584C12AFF4A398B
270F49602025AC00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28B30956C5379E37
48120E91151DD401
2B37272C444F2424
3116393B00245A08
8F2F504B253B1E12
3925FF1218A91103
808F8D25D94C2189
1C3E5E365F296F1F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E173931504A3521
091D261172140E18
1919160E520F2B06
190C17174710051A
080D0F0D2F111F16
00011913150C1818
34664F50FF4B5340
19380E1E4E34142B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2E3E332F0D110D0F
16191F18170C1A14
0616120D0C212A24
040013080D160F19
0104060B0415020F
100503130F0E312B
281F1A29271A2612
3257FF9F302D0F32
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F042E83113B842E
34154F090A6D0D00
122E5F1421311D1E
30CF230479220724
27598A505D3A6100
16FF4629F2141E55
1EBD477F7F0EE10D
3D74151445402914
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
243DB06807BD4676
59022F84316C5484
0400770812A51B38
0F182E1D3A131970
09861E072D361519
583A516C2B072C1A
35FF132A712A3039
B70F48AD0C93381D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool7ojRXZ0OoF5QH1omcLg<7oemOG`OoATI6
1olE5AD7oa/K6`Ko3`l?1Oooool7oc0`<0OoGEeM1omIFET7ogMgM`OoFUYJ1omiNGT7odi>CPKoCDe=
1_ooool6ob@T90Oo:2PX1oli>CT7odU9B@Oo9bLW1ola<C47oh^;R`Ko9bLW1_ooool7obHV9POof][J
1_lF5QH7oc8b<POoJFUY1om9BDT7odY:BPKo:b/[1_ooool7ofi^KPOo?Cdm1om3@d<7obPX:0Ko=SHf
1olk>c/7od51@@Ko:BTY1_ooool7oa@D50Oo?3`l1ol_;bl7ochn?POo=3@d1olD51@6oaTI6@Ko5aLG
1_ooool7o`/;2`Oo^[Zj1ol00007oa<C4`OoF5QH1olK6a/7obXZ:PKo92@T1Oooool7ok>c/`OoI6AT
1olA4A47ooooo`Oo6ATI1olb<S87ojJVYPKo=CDe3Oooool000_ooooo1onXZ:P7oeQHF0OoLg=c1omO
Gel7odI6APOo5ADE1olK6a/6o`l?3`Gooooo1ol`<307oeeMG@OoFEUI1omgMgL7oeYJFPOoNGUi1om>
CTh6ode=C@Kooooo1_lT92@7obPX:0Oo>CTi1om9BDT7obLW9`Oo<C4a1on;Rh/6obLW9`Kooooo1olV
9RH7om[JfPKo5QHF1olb<S87ofUYJ@OoBDU91om:BTX6ob/[:`Kooooo1om^KVh7ocdm?@Oo@d=31olX
:2P6ocHf=POo>c/k1om1@D46obTY:@Kooooo1olD51@7oc`l?0Oo;bl_1oln?Sh7oc@d=0Oo51@D1_lI
6AT6oaLG5`Kooooo1ol;2`/7okZj^POo00001olC4a<7oeQHF0Oo6a/K1olZ:RX6ob@T90Gooooo1onc
/k<7ofATI0Oo4A4A1oooool7oaTI6@Oo<S8b1onVYZH6ocDe=@gooooo000;ooooo`OoZ:RX1omHF5P7
og=cL`OoGemO1om6ATH7oaDE5@Oo6a/K1_l?3`l5ooooo`Oo<30`1omMGEd7oeUIF@OoMgMg1omJFUX7
ogUiN@OoCTi>1_m=CDd6ooooo`Ko92@T1olX:2P7ocTi>@OoBDU91olW9bL7oc4a<@OoRh^;1_lW9bL6
ooooo`Oo9RHV1ooJf]X6oaHF5POo<S8b1omYJFT7odU9B@OoBTY:1_l[:b/6ooooo`OoKVi^1olm?Cd7
od=3@`Oo:2PX1_lf=SH7oc/k>`Oo@D511_lY:BT6ooooo`Oo51@D1oll?3`7obl_;`Oo?Shn1old=3@7
oa@D50Ko6ATI1_lG5aL6ooooo`Oo2`/;1onj^[X7o`0000Oo4a<C1omHF5P7oa/K6`Oo:RXZ1_lT92@5
ooooo`Oo/k>c1omTI6@7oa4A4@Oooooo1olI6AT7oc8b<POoYZJV1_le=CD=ooooo`002oooool7ojRX
Z0OoF5QH1omcLg<7oemOG`OoATI61olE5AD7oa/K6`Ko3`l?1Oooool7oc0`<0OoGEeM1omIFET7ogMg
M`OoFUYJ1omiNGT7odi>CPKoCDe=1_ooool6ob@T90Oo:2PX1oli>CT7odU9B@Oo9bLW1ola<C47oh^;
R`Ko9bLW1_ooool7obHV9POof][J1_lF5QH7oc8b<POoJFUY1om9BDT7odY:BPKo:b/[1_ooool7ofi^
KPOo?Cdm1om3@d<7obPX:0Ko=SHf1olk>c/7od51@@Ko:BTY1_ooool7oa@D50Oo?3`l1ol_;bl7ochn
?POo=3@d1olD51@6oaTI6@Ko5aLG1_ooool7o`/;2`Oo^[Zj1ol00007oa<C4`OoF5QH1olK6a/7obXZ
:PKo92@T1Oooool7ok>c/`OoI6AT1olA4A47ooooo`Oo6ATI1olb<S87ojJVYPKo=CDe3Oooool000_o
oooo1onXZ:P7oeQHF0OoLg=c1omOGel7odI6APOo5ADE1olK6a/6o`l?3`Gooooo1ol`<307oeeMG@Oo
FEUI1omgMgL7oeYJFPOoNGUi1om>CTh6ode=C@Kooooo1_lT92@7obPX:0Oo>CTi1om9BDT7obLW9`Oo
<C4a1on;Rh/6obLW9`Kooooo1olV9RH7om[JfPKo5QHF1olb<S87ofUYJ@OoBDU91om:BTX6ob/[:`Ko
oooo1om^KVh7ocdm?@Oo@d=31olX:2P6ocHf=POo>c/k1om1@D46obTY:@Kooooo1olD51@7oc`l?0Oo
;bl_1oln?Sh7oc@d=0Oo51@D1_lI6AT6oaLG5`Kooooo1ol;2`/7okZj^POo00001olC4a<7oeQHF0Oo
6a/K1olZ:RX6ob@T90Gooooo1onc/k<7ofATI0Oo4A4A1oooool7oaTI6@Oo<S8b1onVYZH6ocDe=@go
oooo000;ooooo`OoZ:RX1omHF5P7og=cL`OoGemO1om6ATH7oaDE5@Oo6a/K1_l?3`l5ooooo`Oo<30`
1omMGEd7oeUIF@OoMgMg1omJFUX7ogUiN@OoCTi>1_m=CDd6ooooo`Ko92@T1olX:2P7ocTi>@OoBDU9
1olW9bL7oc4a<@OoRh^;1_lW9bL6ooooo`Oo9RHV1ooJf]X6oaHF5POo<S8b1omYJFT7odU9B@OoBTY:
1_l[:b/6ooooo`OoKVi^1olm?Cd7od=3@`Oo:2PX1_lf=SH7oc/k>`Oo@D511_lY:BT6ooooo`Oo51@D
1oll?3`7obl_;`Oo?Shn1old=3@7oa@D50Ko6ATI1_lG5aL6ooooo`Oo2`/;1onj^[X7o`0000Oo4a<C
1omHF5P7oa/K6`Oo:RXZ1_lT92@5ooooo`Oo/k>c1omTI6@7oa4A4@Oooooo1olI6AT7oc8b<POoYZJV
1_le=CD=ooooo`002oooool7ojRXZ0OoF5QH1omcLg<7oemOG`OoATI61olE5AD7oa/K6`Ko3`l?1Ooo
ool7oc0`<0OoGEeM1omIFET7ogMgM`OoFUYJ1omiNGT7odi>CPKoCDe=1_ooool6ob@T90Oo:2PX1oli
>CT7odU9B@Oo9bLW1ola<C47oh^;R`Ko9bLW1_ooool7obHV9POof][J1_lF5QH7oc8b<POoJFUY1om9
BDT7odY:BPKo:b/[1_ooool7ofi^KPOo?Cdm1om3@d<7obPX:0Ko=SHf1olk>c/7od51@@Ko:BTY1_oo
ool7oa@D50Oo?3`l1ol_;bl7ochn?POo=3@d1olD51@6oaTI6@Ko5aLG1_ooool7o`/;2`Oo^[Zj1ol0
0007oa<C4`OoF5QH1olK6a/7obXZ:PKo92@T1Oooool7ok>c/`OoI6AT1olA4A47ooooo`Oo6ATI1olb
<S87ojJVYPKo=CDe3Oooool000_ooooo1oo9bLT7od10@0Oooooo1onc/k<7ofQXJ0Oo:RXZ1ol=3@d6
oc4a<@Gooooo1on1PH47ok6a/@OokNg]1oooool7omGEe@OoUIFE1on4Q8@6odY:BPKooooo1_m;Bd/7
ocXj>POo00001olf=SH7od10@0Oo3@d=1oln?Sh6od=3@`Kooooo1onb/[87ogYjNPKo1`L71oooool7
oaTI6@Oo6a/K1oo8b<P6oaPH60Kooooo1oln?Sh7obPX:0OoDU9B1om:BTX6of5QH@Oo@T921omTI6@6
od10@0Kooooo1olA4A47o`@410Oo4Q8B1olG5aL7o`P820Oo0P821_l92@T6o``<30Kooooo1om@D507
oeADE0Oo>3Ph1onZZZX7obDU9@Oo2`/;1omHF5P6oaHF5PGooooo1on][Jd7ohV9R@OoEEEE1onFUYH7
ocLg=`Ook>c/1om7AdL6o`l?3`gooooo000;ooooo`OobLW91om0@407ooooo`Oo/k>c1omXJ6P7obXZ
:POo3@d=1_la<C45ooooo`OoPH611ona/K47ong]k@Oooooo1ooEeMD7oiFEU@OoQ8B41_m:BTX6oooo
o`KoBd];1olj>SX7o`0000Oo=SHf1om0@407o`d=3@Oo?Shn1_m3@d<6ooooo`Oo/[:b1omjNWX6o`L7
1`Oooooo1olI6AT7oa/K6`Oob<S81_lH61P6ooooo`Oo?Shn1olX:2P7oe9BDPOoBTY:1_mQHF47od92
@POoI6AT1_m0@406ooooo`Oo4A4A1ol410@7oa8B4POo5aLG1ol820P7o`820PKo2@T91_l<30`6oooo
o`OoD51@1omDE5@7ocPh>0OoZZZZ1olU9BD7o`/;2`OoF5QH1_lF5QH5ooooo`Oo[Jf]1on9RHT7oeEE
E@OoUYJF1olg=cL7onc/k0OoAdM71_l?3`l=ooooo`002oooool7olW9b@Oo@4101oooool7ok>c/`Oo
J6QX1olZ:RX7o`d=3@Ko<C4a1Oooool7oh61P@Oo/K6a1oo]kNd7ooooo`OoeMGE1onEUID7ohB4Q0Ko
BTY:1_ooool6od];B`Oo>SXj1ol00007ocHf=POo@4101ol=3@d7ochn?PKo@d=31_ooool7ok:b/POo
NWYj1_l71`L7ooooo`Oo6ATI1olK6a/7olS8b0Ko61PH1_ooool7ochn?POo:2PX1omBDU87odY:BPKo
HF5Q1om2@T87ofATI0Ko@4101_ooool7oa4A4@Oo10@41olB4Q87oaLG5`Oo20P81ol20P86o`T92@Ko
30`<1_ooool7oe1@D0OoE5AD1olh>3P7ojZZZPOo9BDU1ol;2`/7oeQHF0Ko5QHF1Oooool7ojf][@Oo
RHV91omEEED7oiJFUPOo=cLg1oo/k>`7odM7A`Ko3`l?3Oooool000_ooooo1oo9bLT7od10@0Oooooo
1onc/k<7ofQXJ0Oo:RXZ1ol=3@d6oc4a<@Gooooo1on1PH47ok6a/@OokNg]1oooool7omGEe@OoUIFE
1on4Q8@6odY:BPKooooo1_m;Bd/7ocXj>POo00001olf=SH7od10@0Oo3@d=1oln?Sh6od=3@`Kooooo
1onb/[87ogYjNPKo1`L71oooool7oaTI6@Oo6a/K1oo8b<P6oaPH60Kooooo1oln?Sh7obPX:0OoDU9B
1om:BTX6of5QH@Oo@T921omTI6@6od10@0Kooooo1olA4A47o`@410Oo4Q8B1olG5aL7o`P820Oo0P82
1_l92@T6o``<30Kooooo1om@D507oeADE0Oo>3Ph1onZZZX7obDU9@Oo2`/;1omHF5P6oaHF5PGooooo
1on][Jd7ohV9R@OoEEEE1onFUYH7ocLg=`Ook>c/1om7AdL6o`l?3`gooooo000;ooooo`OobLW91om0
@407ooooo`Oo/k>c1omXJ6P7obXZ:POo3@d=1_la<C45ooooo`OoPH611ona/K47ong]k@Oooooo1ooE
eMD7oiFEU@OoQ8B41_m:BTX6ooooo`KoBd];1olj>SX7o`0000Oo=SHf1om0@407o`d=3@Oo?Shn1_m3
@d<6ooooo`Oo/[:b1omjNWX6o`L71`Oooooo1olI6AT7oa/K6`Oob<S81_lH61P6ooooo`Oo?Shn1olX
:2P7oe9BDPOoBTY:1_mQHF47od92@POoI6AT1_m0@406ooooo`Oo4A4A1ol410@7oa8B4POo5aLG1ol8
20P7o`820PKo2@T91_l<30`6ooooo`OoD51@1omDE5@7ocPh>0OoZZZZ1olU9BD7o`/;2`OoF5QH1_lF
5QH5ooooo`Oo[Jf]1on9RHT7oeEEE@OoUYJF1olg=cL7onc/k0OoAdM71_l?3`l=ooooo`002oooool7
olW9b@Oo@4101oooool7ok>c/`OoJ6QX1olZ:RX7o`d=3@Ko<C4a1Oooool7oh61P@Oo/K6a1oo]kNd7
ooooo`OoeMGE1onEUID7ohB4Q0KoBTY:1_ooool6od];B`Oo>SXj1ol00007ocHf=POo@4101ol=3@d7
ochn?PKo@d=31_ooool7ok:b/POoNWYj1_l71`L7ooooo`Oo6ATI1olK6a/7olS8b0Ko61PH1_ooool7
ochn?POo:2PX1omBDU87odY:BPKoHF5Q1om2@T87ofATI0Ko@4101_ooool7oa4A4@Oo10@41olB4Q87
oaLG5`Oo20P81ol20P86o`T92@Ko30`<1_ooool7oe1@D0OoE5AD1olh>3P7ojZZZPOo9BDU1ol;2`/7
oeQHF0Ko5QHF1Oooool7ojf][@OoRHV91omEEED7oiJFUPOo=cLg1oo/k>`7odM7A`Ko3`l?3Oooool0
00_ooooo1oo9bLT7od10@0Oooooo1onc/k<7ofQXJ0Oo:RXZ1ol=3@d6oc4a<@Gooooo1on1PH47ok6a
/@OokNg]1oooool7omGEe@OoUIFE1on4Q8@6odY:BPKooooo1_m;Bd/7ocXj>POo00001olf=SH7od10
@0Oo3@d=1oln?Sh6od=3@`Kooooo1onb/[87ogYjNPKo1`L71oooool7oaTI6@Oo6a/K1oo8b<P6oaPH
60Kooooo1oln?Sh7obPX:0OoDU9B1om:BTX6of5QH@Oo@T921omTI6@6od10@0Kooooo1olA4A47o`@4
10Oo4Q8B1olG5aL7o`P820Oo0P821_l92@T6o``<30Kooooo1om@D507oeADE0Oo>3Ph1onZZZX7obDU
9@Oo2`/;1omHF5P6oaHF5PGooooo1on][Jd7ohV9R@OoEEEE1onFUYH7ocLg=`Ook>c/1om7AdL6o`l?
3`gooooo000;ooooo`OoinOW1omZJVX7ohf=S@OoKVi^1omiNGT7ochn?POo820P1_lG5aL5ooooo`Oo
<c<c1olM7Ad7odQ8B0Oo;Bd]1omHF5P7ob4Q8@OoDE5A1_l/;2`6ooooo`Ko=cLg1omDE5@7oaHF5POo
<C4a1olO7al7oa/K6`OoFe]K1_l410@6ooooo`OoZZZZ1onDU9@6oalO7`OoT92@1om3@d<7okno_`Oo
MGEe1_l410@6ooooo`Oo;Bd]1olo?cl7ocLg=`OoJf][1_mbLW87oijNWPOoU9BD1_mFEUH6ooooo`Oo
7alO1ol?3`l7obHV9POo7QhN1ol@4107oaDE5@Ko10@41_l>3Ph6ooooo`Oo6QXJ1ooIfMT7o``<30Oo
=SHf1on2PX87obXZ:POoBTY:1_lT92@5ooooo`OoOWin1omZJVX7oeUIF@Ooc/k>1olG5aL7oiJFUPOo
[Zj^1_meMGD=ooooo`002oooool7onOWi`OoJVYZ1on=SHd7ofi^KPOoNGUi1oln?Sh7ob0P80Ko5aLG
1Oooool7oc<c<`Oo7AdM1om8B4P7obd];@OoF5QH1olQ8B47oe5AD@Ko;2`/1_ooool6ocLg=`OoE5AD
1olF5QH7oc4a<@Oo7alO1olK6a/7oe]KF`Ko10@41_ooool7ojZZZPOoU9BD1_lO7al7oi2@T0Oo@d=3
1ono_kl7ogEeM@Ko10@41_ooool7obd];@Oo?clo1olg=cL7of][J`KoLW9b1onNWYh7oiBDU0KoEUIF
1_ooool7oalO7`Oo3`l?1olV9RH7oahN7POo410@1olE5AD6o`@410Ko3Ph>1_ooool7oaXJ6POofMWI
1ol<30`7ocHf=POoPX:21olZ:RX7odY:BPKo92@T1Oooool7oginOPOoJVYZ1omIFET7olk>cPOo5aLG
1onFUYH7ojj^[PKoMGEe3Oooool000_ooooo1ooWinL7ofYZJPOoSHf=1om^KVh7ogUiN@Oo?Shn1olP
8206oaLG5`Gooooo1olc<c<7oadM7@OoB4Q81ol];Bd7oeQHF0Oo8B4Q1omADE46ob`/;0Kooooo1_lg
=cL7oeADE0Oo5QHF1ola<C47oalO7`Oo6a/K1omKFe/6o`@410Kooooo1onZZZX7oiBDU0Ko7alO1on@
T907od=3@`Oo_kno1omeMGD6o`@410Kooooo1ol];Bd7oclo?`Oo=cLg1om[Jf/6og9bLPOoWYjN1onD
U9@6oeIFEPKooooo1olO7al7o`l?3`Oo9RHV1olN7Qh7oa0@40Oo5ADE1_l410@6o`h>3PKooooo1olJ
6QX7omWIf@Oo30`<1olf=SH7oh:2PPOo:RXZ1om:BTX6ob@T90Gooooo1omnOWh7ofYZJPOoFEUI1oo>
c/h7oaLG5`OoUYJF1on^[Zh6ogEeM@gooooo000;ooooo`OoinOW1omZJVX7ohf=S@OoKVi^1omiNGT7
ochn?POo820P1_lG5aL5ooooo`Oo<c<c1olM7Ad7odQ8B0Oo;Bd]1omHF5P7ob4Q8@OoDE5A1_l/;2`6
ooooo`Ko=cLg1omDE5@7oaHF5POo<C4a1olO7al7oa/K6`OoFe]K1_l410@6ooooo`OoZZZZ1onDU9@6
oalO7`OoT92@1om3@d<7okno_`OoMGEe1_l410@6ooooo`Oo;Bd]1olo?cl7ocLg=`OoJf][1_mbLW87
oijNWPOoU9BD1_mFEUH6ooooo`Oo7alO1ol?3`l7obHV9POo7QhN1ol@4107oaDE5@Ko10@41_l>3Ph6
ooooo`Oo6QXJ1ooIfMT7o``<30Oo=SHf1on2PX87obXZ:POoBTY:1_lT92@5ooooo`OoOWin1omZJVX7
oeUIF@Ooc/k>1olG5aL7oiJFUPOo[Zj^1_meMGD=ooooo`002oooool7onOWi`OoJVYZ1on=SHd7ofi^
KPOoNGUi1oln?Sh7ob0P80Ko5aLG1Oooool7oc<c<`Oo7AdM1om8B4P7obd];@OoF5QH1olQ8B47oe5A
D@Ko;2`/1_ooool6ocLg=`OoE5AD1olF5QH7oc4a<@Oo7alO1olK6a/7oe]KF`Ko10@41_ooool7ojZZ
ZPOoU9BD1_lO7al7oi2@T0Oo@d=31ono_kl7ogEeM@Ko10@41_ooool7obd];@Oo?clo1olg=cL7of][
J`KoLW9b1onNWYh7oiBDU0KoEUIF1_ooool7oalO7`Oo3`l?1olV9RH7oahN7POo410@1olE5AD6o`@4
10Ko3Ph>1_ooool7oaXJ6POofMWI1ol<30`7ocHf=POoPX:21olZ:RX7odY:BPKo92@T1Oooool7ogin
OPOoJVYZ1omIFET7olk>cPOo5aLG1onFUYH7ojj^[PKoMGEe3Oooool000_ooooo1ooWinL7ofYZJPOo
SHf=1om^KVh7ogUiN@Oo?Shn1olP8206oaLG5`Gooooo1olc<c<7oadM7@OoB4Q81ol];Bd7oeQHF0Oo
8B4Q1omADE46ob`/;0Kooooo1_lg=cL7oeADE0Oo5QHF1ola<C47oalO7`Oo6a/K1omKFe/6o`@410Ko
oooo1onZZZX7oiBDU0Ko7alO1on@T907od=3@`Oo_kno1omeMGD6o`@410Kooooo1ol];Bd7oclo?`Oo
=cLg1om[Jf/6og9bLPOoWYjN1onDU9@6oeIFEPKooooo1olO7al7o`l?3`Oo9RHV1olN7Qh7oa0@40Oo
5ADE1_l410@6o`h>3PKooooo1olJ6QX7omWIf@Oo30`<1olf=SH7oh:2PPOo:RXZ1om:BTX6ob@T90Go
oooo1omnOWh7ofYZJPOoFEUI1oo>c/h7oaLG5`OoUYJF1on^[Zh6ogEeM@gooooo000;ooooo`OoinOW
1omZJVX7ohf=S@OoKVi^1omiNGT7ochn?POo820P1_lG5aL5ooooo`Oo<c<c1olM7Ad7odQ8B0Oo;Bd]
1omHF5P7ob4Q8@OoDE5A1_l/;2`6ooooo`Ko=cLg1omDE5@7oaHF5POo<C4a1olO7al7oa/K6`OoFe]K
1_l410@6ooooo`OoZZZZ1onDU9@6oalO7`OoT92@1om3@d<7okno_`OoMGEe1_l410@6ooooo`Oo;Bd]
1olo?cl7ocLg=`OoJf][1_mbLW87oijNWPOoU9BD1_mFEUH6ooooo`Oo7alO1ol?3`l7obHV9POo7QhN
1ol@4107oaDE5@Ko10@41_l>3Ph6ooooo`Oo6QXJ1ooIfMT7o``<30Oo=SHf1on2PX87obXZ:POoBTY:
1_lT92@5ooooo`OoOWin1omZJVX7oeUIF@Ooc/k>1olG5aL7oiJFUPOo[Zj^1_meMGD=ooooo`002ooo
ool7oifMW@Oo>c/k1on9RHT7ogmoO`OoCdm?1om;Bd/7oa/K6`Ko1PH61Oooool7obLW9`Oo61PH1olG
5aL7o`0000Oo7QhN1olO7al7ocDe=@Ko:b/[1_ooool6on3Ph0Oo3Ph>1ol@4107oijNWPOo4A4A1olM
7Ad7oc4a<@Ko5ADE1_ooool7oeUIF@OoRh^;1_lf=SH7ol?3``Oo<30`1ommOGd7omCDe0Ko4a<C1_oo
ool7oeeMG@OoHV9R1on>SXh7oj:RXPKooooo1ooYjNT7okFe]@KoCTi>1_ooool7oa@D50Oo61PH1oli
>CT7oc`l?0OoCTi>1olf=SH6oc<c<`Ko:BTY1_ooool7ohn?S`OoR8R81ol92@T7ooooo`Oo<C4a1ol<
30`7on?Sh`Ko4A4A1Oooool7ol;2`POo;2`/1old=3@7olo?c`Oo5QHF1oo:b/X7ogQhN0KoBDU93Ooo
ool000_ooooo1onMWId7oc/k>`OoRHV91omoOgl7odm?C`OoBd];1olK6a/6o`H61PGooooo1olW9bL7
oaPH60Oo5aLG1ol00007oahN7POo7alO1ole=CD6ob/[:`Kooooo1_oPh>07o`h>3POo410@1onNWYh7
oa4A4@Oo7AdM1ola<C46oaDE5@Kooooo1omIFET7oh^;R`Ko=SHf1oo3`l<7oc0`<0OoOGem1ooDe=@6
oa<C4`Kooooo1omMGEd7of9RHPOoSXj>1onRXZ86ooooo`OojNWY1one]KD6odi>CPKooooo1olD51@7
oaPH60Oo>CTi1oll?3`7odi>CPOo=SHf1_lc<c<6obTY:@Kooooo1on?Shl7ohR8R0Oo2@T91oooool7
oc4a<@Oo30`<1ooShn<6oa4A4@Gooooo1oo2`/87ob`/;0Oo=3@d1oo?cll7oaHF5POob/[:1omhN7P6
odU9B@gooooo000;ooooo`OoWIfM1olk>c/7ohV9R@OoOgmo1om?Cdl7od];B`Oo6a/K1_l61PH5oooo
o`Oo9bLW1olH61P7oaLG5`Oo00001olN7Qh7oalO7`Oo=CDe1_l[:b/6ooooo`Koh>3P1ol>3Ph7oa0@
40OoWYjN1olA4A47oadM7@Oo<C4a1_lE5AD6ooooo`OoFEUI1on;Rh/6ocHf=POo`l?31ol`<307ogem
O@Ooe=CD1_lC4a<6ooooo`OoGEeM1omRHV87ohj>SPOoXZ:R1_ooool7onWYj@Oo]KFe1_m>CTh6oooo
o`Oo51@D1olH61P7ocTi>@Oo?3`l1om>CTh7ocHf=PKo<c<c1_lY:BT6ooooo`OoShn?1on8R8P7o`T9
2@Oooooo1ola<C47o``<30Oohn?S1_lA4A45ooooo`Oo`/;21ol/;2`7oc@d=0Ooclo?1olF5QH7ol[:
bPOoN7Qh1_m9BDT=ooooo`002oooool7oifMW@Oo>c/k1on9RHT7ogmoO`OoCdm?1om;Bd/7oa/K6`Ko
1PH61Oooool7obLW9`Oo61PH1olG5aL7o`0000Oo7QhN1olO7al7ocDe=@Ko:b/[1_ooool6on3Ph0Oo
3Ph>1ol@4107oijNWPOo4A4A1olM7Ad7oc4a<@Ko5ADE1_ooool7oeUIF@OoRh^;1_lf=SH7ol?3``Oo
<30`1ommOGd7omCDe0Ko4a<C1_ooool7oeeMG@OoHV9R1on>SXh7oj:RXPKooooo1ooYjNT7okFe]@Ko
CTi>1_ooool7oa@D50Oo61PH1oli>CT7oc`l?0OoCTi>1olf=SH6oc<c<`Ko:BTY1_ooool7ohn?S`Oo
R8R81ol92@T7ooooo`Oo<C4a1ol<30`7on?Sh`Ko4A4A1Oooool7ol;2`POo;2`/1old=3@7olo?c`Oo
5QHF1oo:b/X7ogQhN0KoBDU93Oooool000_ooooo1onMWId7oc/k>`OoRHV91omoOgl7odm?C`OoBd];
1olK6a/6o`H61PGooooo1olW9bL7oaPH60Oo5aLG1ol00007oahN7POo7alO1ole=CD6ob/[:`Kooooo
1_oPh>07o`h>3POo410@1onNWYh7oa4A4@Oo7AdM1ola<C46oaDE5@Kooooo1omIFET7oh^;R`Ko=SHf
1oo3`l<7oc0`<0OoOGem1ooDe=@6oa<C4`Kooooo1omMGEd7of9RHPOoSXj>1onRXZ86ooooo`OojNWY
1one]KD6odi>CPKooooo1olD51@7oaPH60Oo>CTi1oll?3`7odi>CPOo=SHf1_lc<c<6obTY:@Kooooo
1on?Shl7ohR8R0Oo2@T91oooool7oc4a<@Oo30`<1ooShn<6oa4A4@Gooooo1oo2`/87ob`/;0Oo=3@d
1oo?cll7oaHF5POob/[:1omhN7P6odU9B@gooooo000;ooooo`OoWIfM1olk>c/7ohV9R@OoOgmo1om?
Cdl7od];B`Oo6a/K1_l61PH5ooooo`Oo9bLW1olH61P7oaLG5`Oo00001olN7Qh7oalO7`Oo=CDe1_l[
:b/6ooooo`Koh>3P1ol>3Ph7oa0@40OoWYjN1olA4A47oadM7@Oo<C4a1_lE5AD6ooooo`OoFEUI1on;
Rh/6ocHf=POo`l?31ol`<307ogemO@Ooe=CD1_lC4a<6ooooo`OoGEeM1omRHV87ohj>SPOoXZ:R1_oo
ool7onWYj@Oo]KFe1_m>CTh6ooooo`Oo51@D1olH61P7ocTi>@Oo?3`l1om>CTh7ocHf=PKo<c<c1_lY
:BT6ooooo`OoShn?1on8R8P7o`T92@Oooooo1ola<C47o``<30Oohn?S1_lA4A45ooooo`Oo`/;21ol/
;2`7oc@d=0Ooclo?1olF5QH7ol[:bPOoN7Qh1_m9BDT=ooooo`002oooool7ofi^KPOoJf][1omMGEd7
ofYZJPOoM7Ad1olY:BT7o`P820Ko;bl_1Oooool7oeADE0Oo<S8b1omEEED7oc<c<`OoFe]K1olk>c/7
oda<C0Ko9RHV1_ooool6oh61P@Oo:b/[1oo6a/H7od];B`Oo30`<1oo9bLT7oaTI6@Ko9RHV1_ooool7
ojj^[POo5ADE1_lF5QH7olO7a`Oo1@D51onHV9P7ojb/[0Ko9BDU1_ooool7oc8b<POo7alO1olo?cl7
odI6APKoCTi>1om5ADD7oeaLG0Ko@d=31_ooool7oaXJ6POo9bLW1old=3@7ocLg=`OoGEeM1olT92@6
odI6APKo7alO1_ooool7ohJ6QPOoNg]k1olA4A47ojBTY0OoKFe]1omcLg<7ofEUI@Ko0`<31Oooool7
oc4a<@OoADE51onATI47oclo?`Oo20P81oo?cll7odE5A@KoDE5A3Oooool000_ooooo1om^KVh7of][
J`OoGEeM1omZJVX7ogAdM0Oo:BTY1ol820P6obl_;`Gooooo1omDE5@7oc8b<POoEEEE1olc<c<7oe]K
F`Oo>c/k1om<C4`6obHV9PKooooo1_n1PH47ob/[:`Ooa/K61om;Bd/7o``<30OobLW91olI6AT6obHV
9PKooooo1on^[Zh7oaDE5@Ko5QHF1oo7alL7o`D51@OoV9RH1on/[:`6obDU9@Kooooo1olb<S87oalO
7`Oo?clo1om6ATH6odi>CPOoADE51omLG5`6od=3@`Kooooo1olJ6QX7obLW9`Oo=3@d1olg=cL7oeeM
G@Oo92@T1_m6ATH6oalO7`Kooooo1on6QXH7og]kN`Oo4A4A1onTY:@7ofe]K@OoLg=c1omUIFD6o`<3
0`Gooooo1ola<C47odE5A@OoTI6A1olo?cl7o`P820Ooclo?1om5ADD6oe5AD@gooooo000;ooooo`Oo
KVi^1om[Jf/7oeeMG@OoJVYZ1omdM7@7obTY:@Oo20P81_l_;bl5ooooo`OoE5AD1olb<S87oeEEE@Oo
<c<c1omKFe/7oc/k>`OoC4a<1_lV9RH6ooooo`KoPH611ol[:b/7olK6aPOoBd];1ol<30`7olW9b@Oo
6ATI1_lV9RH6ooooo`Oo[Zj^1olE5AD6oaHF5POoalO71ol51@D7oiRHV0Oo[:b/1_lU9BD6ooooo`Oo
<S8b1olO7al7oclo?`OoATI61_m>CTh7odE5A@OoG5aL1_m3@d<6ooooo`Oo6QXJ1olW9bL7oc@d=0Oo
=cLg1omMGEd7ob@T90KoATI61_lO7al6ooooo`OoQXJ61omkNg/7oa4A4@OoY:BT1om]KFd7og=cL`Oo
IFEU1_l30`<5ooooo`Oo<C4a1om5ADD7oi6AT@Oo?clo1ol820P7olo?c`OoADE51_mADE4=ooooo`00
2oooool7ofi^KPOoJf][1omMGEd7ofYZJPOoM7Ad1olY:BT7o`P820Ko;bl_1Oooool7oeADE0Oo<S8b
1omEEED7oc<c<`OoFe]K1olk>c/7oda<C0Ko9RHV1_ooool6oh61P@Oo:b/[1oo6a/H7od];B`Oo30`<
1oo9bLT7oaTI6@Ko9RHV1_ooool7ojj^[POo5ADE1_lF5QH7olO7a`Oo1@D51onHV9P7ojb/[0Ko9BDU
1_ooool7oc8b<POo7alO1olo?cl7odI6APKoCTi>1om5ADD7oeaLG0Ko@d=31_ooool7oaXJ6POo9bLW
1old=3@7ocLg=`OoGEeM1olT92@6odI6APKo7alO1_ooool7ohJ6QPOoNg]k1olA4A47ojBTY0OoKFe]
1omcLg<7ofEUI@Ko0`<31Oooool7oc4a<@OoADE51onATI47oclo?`Oo20P81oo?cll7odE5A@KoDE5A
3Oooool000_ooooo1om^KVh7of][J`OoGEeM1omZJVX7ogAdM0Oo:BTY1ol820P6obl_;`Gooooo1omD
E5@7oc8b<POoEEEE1olc<c<7oe]KF`Oo>c/k1om<C4`6obHV9PKooooo1_n1PH47ob/[:`Ooa/K61om;
Bd/7o``<30OobLW91olI6AT6obHV9PKooooo1on^[Zh7oaDE5@Ko5QHF1oo7alL7o`D51@OoV9RH1on/
[:`6obDU9@Kooooo1olb<S87oalO7`Oo?clo1om6ATH6odi>CPOoADE51omLG5`6od=3@`Kooooo1olJ
6QX7obLW9`Oo=3@d1olg=cL7oeeMG@Oo92@T1_m6ATH6oalO7`Kooooo1on6QXH7og]kN`Oo4A4A1onT
Y:@7ofe]K@OoLg=c1omUIFD6o`<30`Gooooo1ola<C47odE5A@OoTI6A1olo?cl7o`P820Ooclo?1om5
ADD6oe5AD@gooooo000;ooooo`OoKVi^1om[Jf/7oeeMG@OoJVYZ1omdM7@7obTY:@Oo20P81_l_;bl5
ooooo`OoE5AD1olb<S87oeEEE@Oo<c<c1omKFe/7oc/k>`OoC4a<1_lV9RH6ooooo`KoPH611ol[:b/7
olK6aPOoBd];1ol<30`7olW9b@Oo6ATI1_lV9RH6ooooo`Oo[Zj^1olE5AD6oaHF5POoalO71ol51@D7
oiRHV0Oo[:b/1_lU9BD6ooooo`Oo<S8b1olO7al7oclo?`OoATI61_m>CTh7odE5A@OoG5aL1_m3@d<6
ooooo`Oo6QXJ1olW9bL7oc@d=0Oo=cLg1omMGEd7ob@T90KoATI61_lO7al6ooooo`OoQXJ61omkNg/7
oa4A4@OoY:BT1om]KFd7og=cL`OoIFEU1_l30`<5ooooo`Oo<C4a1om5ADD7oi6AT@Oo?clo1ol820P7
olo?c`OoADE51_mADE4=ooooo`002oooool7ofi^KPOoJf][1omMGEd7ofYZJPOoM7Ad1olY:BT7o`P8
20Ko;bl_1Oooool7oeADE0Oo<S8b1omEEED7oc<c<`OoFe]K1olk>c/7oda<C0Ko9RHV1_ooool6oh61
P@Oo:b/[1oo6a/H7od];B`Oo30`<1oo9bLT7oaTI6@Ko9RHV1_ooool7ojj^[POo5ADE1_lF5QH7olO7
a`Oo1@D51onHV9P7ojb/[0Ko9BDU1_ooool7oc8b<POo7alO1olo?cl7odI6APKoCTi>1om5ADD7oeaL
G0Ko@d=31_ooool7oaXJ6POo9bLW1old=3@7ocLg=`OoGEeM1olT92@6odI6APKo7alO1_ooool7ohJ6
QPOoNg]k1olA4A47ojBTY0OoKFe]1omcLg<7ofEUI@Ko0`<31Oooool7oc4a<@OoADE51onATI47oclo
?`Oo20P81oo?cll7odE5A@KoDE5A3Oooool000_ooooo1ong]kL7oeEEE@OoKVi^1omkNg/7oc/k>`Oo
92@T1ol61PH6oa8B4PGooooo1ola<C47oeQHF0OoP8201onVYZH7okjn_POo`l?31onIVIT6ofa/K0Ko
oooo1_oAdM47oaTI6@OoGemO1onUYJD7oeEEE@OoDU9B1omZJVX6oibLW0Kooooo1om<C4`7oc4a<@Ko
L71`1olY:BT7oaDE5@OoaLG51oll?3`6oa/K6`Kooooo1olc<c<7oaDE5@Oo410@1ol92@T6o`0000Oo
0@411olQ8B46obTY:@Kooooo1ol];Bd7odI6APOo;Bd]1old=3@7ocPh>0Oo:b/[1_lc<c<6ob<S8`Ko
oooo1olP8207ohb<S0Oo6QXJ1onKVi/7ode=C@OoF5QH1oo1`L46oa@D50Gooooo1omGEeL7oa8B4POo
<30`1omjNWX7obPX:0OoCdm?1omADE46ogYjNPgooooo000;ooooo`Oo]kNg1omEEED7ofi^KPOoNg]k
1olk>c/7ob@T90Oo1PH61_lB4Q85ooooo`Oo<C4a1omHF5P7oh20P0OoYZJV1onn_[h7ol?3``OoVIVI
1_m/K6`6ooooo`KodM7A1olI6AT7oemOG`OoYJFU1omEEED7oe9BDPOoJVYZ1_nLW9`6ooooo`OoC4a<
1ola<C46og1`L0Oo:BTY1olE5AD7olG5a@Oo?3`l1_lK6a/6ooooo`Oo<c<c1olE5AD7oa0@40Oo2@T9
1_l00007o`410@Oo8B4Q1_lY:BT6ooooo`Oo;Bd]1om6ATH7obd];@Oo=3@d1olh>3P7ob/[:`Ko<c<c
1_lS8b<6ooooo`Oo820P1on<S8`7oaXJ6POoVi^K1om=CDd7oeQHF0Oo`L711_lD51@5ooooo`OoEeMG
1olB4Q87oc0`<0OoNWYj1olX:2P7odm?C`OoDE5A1_mjNWX=ooooo`002oooool7okNg]`OoEEEE1om^
KVh7og]kN`Oo>c/k1olT92@7o`H61PKo4Q8B1Oooool7oc4a<@OoF5QH1on0P807ojJVYPOo_[jn1oo3
`l<7oiVIV@KoK6a/1_ooool6om7Ad@Oo6ATI1omOGel7ojFUY@OoEEEE1omBDU87ofYZJPKoW9bL1_oo
ool7oda<C0Oo<C4a1_m`L707obTY:@Oo5ADE1oo5aLD7oc`l?0Ko6a/K1_ooool7oc<c<`Oo5ADE1ol@
4107o`T92@Ko00001ol10@47ob4Q8@Ko:BTY1_ooool7obd];@OoATI61ol];Bd7oc@d=0Oo>3Ph1ol[
:b/6oc<c<`Ko8b<S1_ooool7ob0P80OoS8b<1olJ6QX7oi^KV`OoCDe=1omHF5P7ol71`@Ko51@D1Ooo
ool7oeMGE`Oo4Q8B1ol`<307ogYjNPOo:2PX1om?Cdl7oe5AD@KoNWYj3Oooool000_ooooo1ong]kL7
oeEEE@OoKVi^1omkNg/7oc/k>`Oo92@T1ol61PH6oa8B4PGooooo1ola<C47oeQHF0OoP8201onVYZH7
okjn_POo`l?31onIVIT6ofa/K0Kooooo1_oAdM47oaTI6@OoGemO1onUYJD7oeEEE@OoDU9B1omZJVX6
oibLW0Kooooo1om<C4`7oc4a<@KoL71`1olY:BT7oaDE5@OoaLG51oll?3`6oa/K6`Kooooo1olc<c<7
oaDE5@Oo410@1ol92@T6o`0000Oo0@411olQ8B46obTY:@Kooooo1ol];Bd7odI6APOo;Bd]1old=3@7
ocPh>0Oo:b/[1_lc<c<6ob<S8`Kooooo1olP8207ohb<S0Oo6QXJ1onKVi/7ode=C@OoF5QH1oo1`L46
oa@D50Gooooo1omGEeL7oa8B4POo<30`1omjNWX7obPX:0OoCdm?1omADE46ogYjNPgooooo000;oooo
o`Oo]kNg1omEEED7ofi^KPOoNg]k1olk>c/7ob@T90Oo1PH61_lB4Q85ooooo`Oo<C4a1omHF5P7oh20
P0OoYZJV1onn_[h7ol?3``OoVIVI1_m/K6`6ooooo`KodM7A1olI6AT7oemOG`OoYJFU1omEEED7oe9B
DPOoJVYZ1_nLW9`6ooooo`OoC4a<1ola<C46og1`L0Oo:BTY1olE5AD7olG5a@Oo?3`l1_lK6a/6oooo
o`Oo<c<c1olE5AD7oa0@40Oo2@T91_l00007o`410@Oo8B4Q1_lY:BT6ooooo`Oo;Bd]1om6ATH7obd]
;@Oo=3@d1olh>3P7ob/[:`Ko<c<c1_lS8b<6ooooo`Oo820P1on<S8`7oaXJ6POoVi^K1om=CDd7oeQH
F0Oo`L711_lD51@5ooooo`OoEeMG1olB4Q87oc0`<0OoNWYj1olX:2P7odm?C`OoDE5A1_mjNWX=oooo
o`002oooool7okNg]`OoEEEE1om^KVh7og]kN`Oo>c/k1olT92@7o`H61PKo4Q8B1Oooool7oc4a<@Oo
F5QH1on0P807ojJVYPOo_[jn1oo3`l<7oiVIV@KoK6a/1_ooool6om7Ad@Oo6ATI1omOGel7ojFUY@Oo
EEEE1omBDU87ofYZJPKoW9bL1_ooool7oda<C0Oo<C4a1_m`L707obTY:@Oo5ADE1oo5aLD7oc`l?0Ko
6a/K1_ooool7oc<c<`Oo5ADE1ol@4107o`T92@Ko00001ol10@47ob4Q8@Ko:BTY1_ooool7obd];@Oo
ATI61ol];Bd7oc@d=0Oo>3Ph1ol[:b/6oc<c<`Ko8b<S1_ooool7ob0P80OoS8b<1olJ6QX7oi^KV`Oo
CDe=1omHF5P7ol71`@Ko51@D1Oooool7oeMGE`Oo4Q8B1ol`<307ogYjNPOo:2PX1om?Cdl7oe5AD@Ko
NWYj3Oooool000_ooooo1ong]kL7oeEEE@OoKVi^1omkNg/7oc/k>`Oo92@T1ol61PH6oa8B4PGooooo
1ola<C47oeQHF0OoP8201onVYZH7okjn_POo`l?31onIVIT6ofa/K0Kooooo1_oAdM47oaTI6@OoGemO
1onUYJD7oeEEE@OoDU9B1omZJVX6oibLW0Kooooo1om<C4`7oc4a<@KoL71`1olY:BT7oaDE5@OoaLG5
1oll?3`6oa/K6`Kooooo1olc<c<7oaDE5@Oo410@1ol92@T6o`0000Oo0@411olQ8B46obTY:@Kooooo
1ol];Bd7odI6APOo;Bd]1old=3@7ocPh>0Oo:b/[1_lc<c<6ob<S8`Kooooo1olP8207ohb<S0Oo6QXJ
1onKVi/7ode=C@OoF5QH1oo1`L46oa@D50Gooooo1omGEeL7oa8B4POo<30`1omjNWX7obPX:0OoCdm?
1omADE46ogYjNPgooooo000;ooooo`OoMgMg1omNGUh7of5QH@OoDe=C1oll?3`7ob8R8POo00001_l2
0P85ooooo`Oo7AdM1om0@407ocdm?@OoBTY:1omSHf<7oc0`<0OoFEUI1_la<C46ooooo`Ko][Jf1olJ
6QX7okFe]@OoEUIF1olc<c<7ooooo`Oo;Rh^1_la<C46ooooo`OoGUiN1ol51@D6obLW9`OoLW9b1olQ
8B47odi>CPOoK6a/1_m@D506ooooo`Oo?3`l1olg=cL7ob0P80Oo2PX:1_lN7Qh7oa<C4`Oo3`l?1_l=
3@d6ooooo`Oo5QHF1ol00007oa<C4`Oo5aLG1olL71`7oadM7@Ko2@T91_lE5AD6ooooo`OoQhN73_l7
1`L7ok^k^`Oo10@41om>CTh7ojj^[PKo2PX:1Oooool7oaXJ6POo:BTY1omDE5@7o`D51@Oo4Q8B1on=
SHd7oaHF5PKo820P3Oooool000_ooooo1omgMgL7oeiNGPOoHF5Q1omCDe<7oc`l?0Oo8R8R1ol00006
o`820PGooooo1olM7Ad7od10@0Oo?Cdm1om:BTX7of=SH`Oo<30`1omIFET6oc4a<@Kooooo1_nf][H7
oaXJ6POo]KFe1omFEUH7oc<c<`Oooooo1ol^;Rh6oc4a<@Kooooo1omNGUh7o`D51@Ko9bLW1ombLW87
ob4Q8@OoCTi>1om/K6`6oe1@D0Kooooo1oll?3`7ocLg=`Oo820P1ol:2PX6oahN7POo4a<C1ol?3`l6
o`d=3@Kooooo1olF5QH7o`0000Oo4a<C1olG5aL7oa`L70Oo7AdM1_l92@T6oaDE5@Kooooo1on7QhL>
o`L71`Oo^k^k1ol410@7odi>CPOo[Zj^1_l:2PX5ooooo`Oo6QXJ1olY:BT7oeADE0Oo1@D51olB4Q87
ohf=S@Oo5QHF1_lP820=ooooo`002oooool7ogMgM`OoGUiN1omQHF47oe=CD`Oo?3`l1olR8R87o`00
00Ko0P821Oooool7oadM7@Oo@4101olm?Cd7odY:BPOoHf=S1ol`<307oeUIF@Ko<C4a1_ooool6okJf
]POo6QXJ1one]KD7oeIFEPOo<c<c1oooool7obh^;PKo<C4a1_ooool7oeiNGPOo1@D51_lW9bL7og9b
LPOo8B4Q1om>CTh7ofa/K0KoD51@1_ooool7oc`l?0Oo=cLg1olP8207o`X:2PKo7QhN1olC4a<7o`l?
3`Ko3@d=1_ooool7oaHF5POo00001olC4a<7oaLG5`Oo71`L1olM7Ad6o`T92@Ko5ADE1_ooool7ohN7
Q`ko1`L71onk^k/7o`@410OoCTi>1on^[Zh6o`X:2PGooooo1olJ6QX7obTY:@OoE5AD1ol51@D7oa8B
4POoSHf=1olF5QH6ob0P80gooooo000;ooooo`OoMgMg1omNGUh7of5QH@OoDe=C1oll?3`7ob8R8POo
00001_l20P85ooooo`Oo7AdM1om0@407ocdm?@OoBTY:1omSHf<7oc0`<0OoFEUI1_la<C46ooooo`Ko
][Jf1olJ6QX7okFe]@OoEUIF1olc<c<7ooooo`Oo;Rh^1_la<C46ooooo`OoGUiN1ol51@D6obLW9`Oo
LW9b1olQ8B47odi>CPOoK6a/1_m@D506ooooo`Oo?3`l1olg=cL7ob0P80Oo2PX:1_lN7Qh7oa<C4`Oo
3`l?1_l=3@d6ooooo`Oo5QHF1ol00007oa<C4`Oo5aLG1olL71`7oadM7@Ko2@T91_lE5AD6ooooo`Oo
QhN73_l71`L7ok^k^`Oo10@41om>CTh7ojj^[PKo2PX:1Oooool7oaXJ6POo:BTY1omDE5@7o`D51@Oo
4Q8B1on=SHd7oaHF5PKo820P3Oooool000_ooooo1omgMgL7oeiNGPOoHF5Q1omCDe<7oc`l?0Oo8R8R
1ol00006o`820PGooooo1olM7Ad7od10@0Oo?Cdm1om:BTX7of=SH`Oo<30`1omIFET6oc4a<@Kooooo
1_nf][H7oaXJ6POo]KFe1omFEUH7oc<c<`Oooooo1ol^;Rh6oc4a<@Kooooo1omNGUh7o`D51@Ko9bLW
1ombLW87ob4Q8@OoCTi>1om/K6`6oe1@D0Kooooo1oll?3`7ocLg=`Oo820P1ol:2PX6oahN7POo4a<C
1ol?3`l6o`d=3@Kooooo1olF5QH7o`0000Oo4a<C1olG5aL7oa`L70Oo7AdM1_l92@T6oaDE5@Kooooo
1on7QhL>o`L71`Oo^k^k1ol410@7odi>CPOo[Zj^1_l:2PX5ooooo`Oo6QXJ1olY:BT7oeADE0Oo1@D5
1olB4Q87ohf=S@Oo5QHF1_lP820=ooooo`002oooool7ogMgM`OoGUiN1omQHF47oe=CD`Oo?3`l1olR
8R87o`0000Ko0P821Oooool7oadM7@Oo@4101olm?Cd7odY:BPOoHf=S1ol`<307oeUIF@Ko<C4a1_oo
ool6okJf]POo6QXJ1one]KD7oeIFEPOo<c<c1oooool7obh^;PKo<C4a1_ooool7oeiNGPOo1@D51_lW
9bL7og9bLPOo8B4Q1om>CTh7ofa/K0KoD51@1_ooool7oc`l?0Oo=cLg1olP8207o`X:2PKo7QhN1olC
4a<7o`l?3`Ko3@d=1_ooool7oaHF5POo00001olC4a<7oaLG5`Oo71`L1olM7Ad6o`T92@Ko5ADE1_oo
ool7ohN7Q`ko1`L71onk^k/7o`@410OoCTi>1on^[Zh6o`X:2PGooooo1olJ6QX7obTY:@OoE5AD1ol5
1@D7oa8B4POoSHf=1olF5QH6ob0P80gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47
oa`L70Oo2`/;1_lK6a/5ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6
ooooo`Ko=cLg1oll?3`7oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6
ocHf=POo8R8R1ol0000>oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7
ohR8R0KoFUYJ1_ooool7oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7
o`0000Oo@T921ole=CD7o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7
og5aL@OoHF5Q1ol00006obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L
70Oo2`/;1_lK6a/5ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6oooo
o`Ko=cLg1oll?3`7oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf
=POo8R8R1ol0000>oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8
R0KoFUYJ1_ooool7oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`00
00Oo@T921ole=CD7o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5a
L@OoHF5Q1ol00006obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L70Oo
2`/;1_lK6a/5ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6ooooo`Ko
=cLg1oll?3`7oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf=POo
8R8R1ol0000>oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8R0Ko
FUYJ1_ooool7oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`0000Oo
@T921ole=CD7o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5aL@Oo
HF5Q1ol00006obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L70Oo2`/;
1_lK6a/5ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6ooooo`Ko=cLg
1oll?3`7oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf=POo8R8R
1ol0000>oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8R0KoFUYJ
1_ooool7oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`0000Oo@T92
1ole=CD7o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5aL@OoHF5Q
1ol00006obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L70Oo2`/;1_lK
6a/5ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6ooooo`Ko=cLg1oll
?3`7oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf=POo8R8R1ol0
000>oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8R0KoFUYJ1_oo
ool7oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`0000Oo@T921ole
=CD7o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5aL@OoHF5Q1ol0
0006obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L70Oo2`/;1_lK6a/5
ooooo`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6ooooo`Ko=cLg1oll?3`7
oa/K6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf=POo8R8R1ol0000>
oa@D50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8R0KoFUYJ1_ooool7
oeADE0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`0000Oo@T921ole=CD7
o`<30`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5aL@OoHF5Q1ol00006
obDU9@gooooo000;ooooo`OoMWIf1om>CTh7oeYJFPOo6ATI1olQ8B47oa`L70Oo2`/;1_lK6a/5oooo
o`OoIFEU1omDE5@7oginOPOoHf=S1omVIVH7oe5AD@OoM7Ad1_mDE5@6ooooo`Ko=cLg1oll?3`7oa/K
6`Oo5ADE1onATI47o`<30`Oo<30`1_m_Kfl6ooooo`Oo<c<c1olF5QH6ocHf=POo8R8R1ol0000>oa@D
50Ko6QXJ1_ooool7olC4a0OoS8b<1on^[Zh7ohV9R@KoPX:21om:BTX7ohR8R0KoFUYJ1_ooool7oeAD
E0OoPX:21onc/k<>ooooo`OoTI6A1_mDE5@6odA4A0Kooooo1olO7al7o`0000Oo@T921ole=CD7o`<3
0`Oo2@T91olU9BD6ocDe=@Gooooo1olI6AT7oeiNGPOo<C4a1olG5aL7og5aL@OoHF5Q1ol00006obDU
9@gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo000;ooooo`Oo;2`/1ol];Bd7oc@d=0OoBDU91om>CTh7oc@d=0OoD51@
1_m:BTX5ooooo`Oo0`<31olI6AT7oaLG5`Oo7AdM1olf=SH7od10@0Oo>SXj1_l:2PX6ooooo`Ko_kno
1omQHF47ofIVIPOoAdM71om]KFd7od=3@`Oo3`l?1_mJFUX6ooooo`Oo5ADE1olU9BD6o`h>3POo6QXJ
1ola<C47oc8b<POo>c/k1_l];Bd6ooooo`Oo6ATI1olY:BT7oaPH60Oo:RXZ1_m=CDd7obl_;`Oo<S8b
1_ll?3`6ooooo`Oo?Cdm1olh>3P7od51@@Oo3`l?1olK6a/7oa`L70Ko820P1_lI6AT6ooooo`Oo<30`
1on][Jd7ogMgM`Oo4Q8B1oooool7obDU9@Oo<30`1_mRHV85ooooo`OoMgMg1olH61P7ooooo`Oo8B4Q
1olB4Q87om3@d0Oo1@D51_lK6a/=ooooo`002oooool7ob`/;0Oo;Bd]1old=3@7odU9B@OoCTi>1old
=3@7oe1@D0KoBTY:1Oooool7o`<30`Oo6ATI1olG5aL7oadM7@Oo=SHf1om0@407ocXj>PKo2PX:1_oo
ool6okno_`OoHF5Q1omVIVH7odM7A`OoKFe]1om3@d<7o`l?3`KoFUYJ1_ooool7oaDE5@Oo9BDU1_l>
3Ph7oaXJ6POo<C4a1olb<S87oc/k>`Ko;Bd]1_ooool7oaTI6@Oo:BTY1olH61P7obXZ:PKoCDe=1ol_
;bl7oc8b<PKo?3`l1_ooool7ocdm?@Oo>3Ph1om1@D47o`l?3`Oo6a/K1olL71`6ob0P80Ko6ATI1_oo
ool7oc0`<0Oo[Jf]1omgMgL7oa8B4POooooo1olU9BD7oc0`<0KoHV9R1Oooool7ogMgM`Oo61PH1ooo
ool7ob4Q8@Oo4Q8B1oo@d=07o`D51@Ko6a/K3Oooool000_ooooo1ol/;2`7obd];@Oo=3@d1om9BDT7
odi>CPOo=3@d1om@D506odY:BPGooooo1ol30`<7oaTI6@Oo5aLG1olM7Ad7ocHf=POo@4101olj>SX6
o`X:2PKooooo1_no_kl7of5QH@OoIVIV1om7AdL7ofe]K@Oo@d=31ol?3`l6oeYJFPKooooo1olE5AD7
obDU9@Ko3Ph>1olJ6QX7oc4a<@Oo<S8b1olk>c/6obd];@Kooooo1olI6AT7obTY:@Oo61PH1olZ:RX6
ode=C@Oo;bl_1olb<S86oc`l?0Kooooo1olm?Cd7ocPh>0Oo@D511ol?3`l7oa/K6`Oo71`L1_lP8206
oaTI6@Kooooo1ol`<307ojf][@OoMgMg1olB4Q87ooooo`Oo9BDU1ol`<306of9RHPGooooo1omgMgL7
oaPH60Oooooo1olQ8B47oa8B4POod=3@1ol51@D6oa/K6`gooooo000;ooooo`Oo;2`/1ol];Bd7oc@d
=0OoBDU91om>CTh7oc@d=0OoD51@1_m:BTX5ooooo`Oo0`<31olI6AT7oaLG5`Oo7AdM1olf=SH7od10
@0Oo>SXj1_l:2PX6ooooo`Ko_kno1omQHF47ofIVIPOoAdM71om]KFd7od=3@`Oo3`l?1_mJFUX6oooo
o`Oo5ADE1olU9BD6o`h>3POo6QXJ1ola<C47oc8b<POo>c/k1_l];Bd6ooooo`Oo6ATI1olY:BT7oaPH
60Oo:RXZ1_m=CDd7obl_;`Oo<S8b1_ll?3`6ooooo`Oo?Cdm1olh>3P7od51@@Oo3`l?1olK6a/7oa`L
70Ko820P1_lI6AT6ooooo`Oo<30`1on][Jd7ogMgM`Oo4Q8B1oooool7obDU9@Oo<30`1_mRHV85oooo
o`OoMgMg1olH61P7ooooo`Oo8B4Q1olB4Q87om3@d0Oo1@D51_lK6a/=ooooo`002oooool7ob`/;0Oo
;Bd]1old=3@7odU9B@OoCTi>1old=3@7oe1@D0KoBTY:1Oooool7o`<30`Oo6ATI1olG5aL7oadM7@Oo
=SHf1om0@407ocXj>PKo2PX:1_ooool6okno_`OoHF5Q1omVIVH7odM7A`OoKFe]1om3@d<7o`l?3`Ko
FUYJ1_ooool7oaDE5@Oo9BDU1_l>3Ph7oaXJ6POo<C4a1olb<S87oc/k>`Ko;Bd]1_ooool7oaTI6@Oo
:BTY1olH61P7obXZ:PKoCDe=1ol_;bl7oc8b<PKo?3`l1_ooool7ocdm?@Oo>3Ph1om1@D47o`l?3`Oo
6a/K1olL71`6ob0P80Ko6ATI1_ooool7oc0`<0Oo[Jf]1omgMgL7oa8B4POooooo1olU9BD7oc0`<0Ko
HV9R1Oooool7ogMgM`Oo61PH1oooool7ob4Q8@Oo4Q8B1oo@d=07o`D51@Ko6a/K3Oooool000_ooooo
1ol/;2`7obd];@Oo=3@d1om9BDT7odi>CPOo=3@d1om@D506odY:BPGooooo1ol30`<7oaTI6@Oo5aLG
1olM7Ad7ocHf=POo@4101olj>SX6o`X:2PKooooo1_no_kl7of5QH@OoIVIV1om7AdL7ofe]K@Oo@d=3
1ol?3`l6oeYJFPKooooo1olE5AD7obDU9@Ko3Ph>1olJ6QX7oc4a<@Oo<S8b1olk>c/6obd];@Kooooo
1olI6AT7obTY:@Oo61PH1olZ:RX6ode=C@Oo;bl_1olb<S86oc`l?0Kooooo1olm?Cd7ocPh>0Oo@D51
1ol?3`l7oa/K6`Oo71`L1_lP8206oaTI6@Kooooo1ol`<307ojf][@OoMgMg1olB4Q87ooooo`Oo9BDU
1ol`<306of9RHPGooooo1omgMgL7oaPH60Oooooo1olQ8B47oa8B4POod=3@1ol51@D6oa/K6`gooooo
000;ooooo`Oo;2`/1ol];Bd7oc@d=0OoBDU91om>CTh7oc@d=0OoD51@1_m:BTX5ooooo`Oo0`<31olI
6AT7oaLG5`Oo7AdM1olf=SH7od10@0Oo>SXj1_l:2PX6ooooo`Ko_kno1omQHF47ofIVIPOoAdM71om]
KFd7od=3@`Oo3`l?1_mJFUX6ooooo`Oo5ADE1olU9BD6o`h>3POo6QXJ1ola<C47oc8b<POo>c/k1_l]
;Bd6ooooo`Oo6ATI1olY:BT7oaPH60Oo:RXZ1_m=CDd7obl_;`Oo<S8b1_ll?3`6ooooo`Oo?Cdm1olh
>3P7od51@@Oo3`l?1olK6a/7oa`L70Ko820P1_lI6AT6ooooo`Oo<30`1on][Jd7ogMgM`Oo4Q8B1ooo
ool7obDU9@Oo<30`1_mRHV85ooooo`OoMgMg1olH61P7ooooo`Oo8B4Q1olB4Q87om3@d0Oo1@D51_lK
6a/=ooooo`002oooool7o`L71`OoSXj>1om7AdL7o`h>3POoKFe]1onDU9@=ob`/;0Gooooo1olH61P7
oaDE5@Oo3Ph>1ol92@T7oa@D50Oo3`l?1ol:2PX6o`@410Kooooo1_mJFUX7oc0`<0Oooooo1ol?3`l7
ocLg=`OoWIfM1ol[:b/6oc<c<`Kooooo1olU9BD7obh^;PKo=3@d1om>CTh7ohR8R0OogmoO1oooool6
oiFEU@Kooooo1olU9BD7oa/K6`Oo8b<S1olc<c<6oalO7`Oo<30`1oooool6oeEEE@Kooooo1olK6a/7
oa@D50Oo5ADE1ol00007oa`L70Oo8B4Q1_l/;2`6obDU9@Kooooo1olQ8B47ogemO@OoYjNW1om3@d<7
ohf=S@OoADE51onh^;P6obDU9@Gooooo1onl_;`7obXZ:POoUiNG1omIFET7ojb/[0OoJFUY1ol[:b/6
ojn_[`gooooo000;ooooo`Oo1`L71on>SXh7odM7A`Oo3Ph>1om]KFd7oiBDU0go;2`/1Oooool7oaPH
60Oo5ADE1ol>3Ph7o`T92@Oo51@D1ol?3`l7o`X:2PKo10@41_ooool6oeYJFPOo<30`1oooool7o`l?
3`Oo=cLg1onMWId7ob/[:`Ko<c<c1_ooool7obDU9@Oo;Rh^1_ld=3@7odi>CPOoR8R81ooOgml7oooo
o`KoUIFE1_ooool7obDU9@Oo6a/K1olS8b<7oc<c<`Ko7alO1ol`<307ooooo`KoEEEE1_ooool7oa/K
6`Oo51@D1olE5AD7o`0000Oo71`L1olQ8B46ob`/;0Ko9BDU1_ooool7ob4Q8@OoOGem1onWYjL7od=3
@`OoSHf=1om5ADD7okRh^0Ko9BDU1Oooool7okbl_0Oo:RXZ1onGUiL7oeUIF@Oo[:b/1omYJFT7ob/[
:`Ko[jn_3Oooool000_ooooo1ol71`L7ohj>SPOoAdM71ol>3Ph7ofe]K@OoU9BD3Ol/;2`5ooooo`Oo
61PH1olE5AD7o`h>3POo2@T91olD51@7o`l?3`Oo2PX:1_l410@6ooooo`KoFUYJ1ol`<307ooooo`Oo
3`l?1olg=cL7oifMW@Oo:b/[1_lc<c<6ooooo`Oo9BDU1ol^;Rh6oc@d=0OoCTi>1on8R8P7omoOg`Oo
oooo1_nEUID6ooooo`Oo9BDU1olK6a/7ob<S8`Oo<c<c1_lO7al7oc0`<0Oooooo1_mEEED6ooooo`Oo
6a/K1olD51@7oaDE5@Oo00001olL71`7ob4Q8@Ko;2`/1_lU9BD6ooooo`Oo8B4Q1ommOGd7ojNWY`Oo
@d=31on=SHd7odE5A@Oo^;Rh1_lU9BD5ooooo`Oo_;bl1olZ:RX7oiNGU`OoFEUI1on/[:`7ofUYJ@Oo
:b/[1_n_[jl=ooooo`002oooool7o`L71`OoSXj>1om7AdL7o`h>3POoKFe]1onDU9@=ob`/;0Gooooo
1olH61P7oaDE5@Oo3Ph>1ol92@T7oa@D50Oo3`l?1ol:2PX6o`@410Kooooo1_mJFUX7oc0`<0Oooooo
1ol?3`l7ocLg=`OoWIfM1ol[:b/6oc<c<`Kooooo1olU9BD7obh^;PKo=3@d1om>CTh7ohR8R0OogmoO
1oooool6oiFEU@Kooooo1olU9BD7oa/K6`Oo8b<S1olc<c<6oalO7`Oo<30`1oooool6oeEEE@Kooooo
1olK6a/7oa@D50Oo5ADE1ol00007oa`L70Oo8B4Q1_l/;2`6obDU9@Kooooo1olQ8B47ogemO@OoYjNW
1om3@d<7ohf=S@OoADE51onh^;P6obDU9@Gooooo1onl_;`7obXZ:POoUiNG1omIFET7ojb/[0OoJFUY
1ol[:b/6ojn_[`gooooo000;ooooo`Oo1`L71on>SXh7odM7A`Oo3Ph>1om]KFd7oiBDU0go;2`/1Ooo
ool7oaPH60Oo5ADE1ol>3Ph7o`T92@Oo51@D1ol?3`l7o`X:2PKo10@41_ooool6oeYJFPOo<30`1ooo
ool7o`l?3`Oo=cLg1onMWId7ob/[:`Ko<c<c1_ooool7obDU9@Oo;Rh^1_ld=3@7odi>CPOoR8R81ooO
gml7ooooo`KoUIFE1_ooool7obDU9@Oo6a/K1olS8b<7oc<c<`Ko7alO1ol`<307ooooo`KoEEEE1_oo
ool7oa/K6`Oo51@D1olE5AD7o`0000Oo71`L1olQ8B46ob`/;0Ko9BDU1_ooool7ob4Q8@OoOGem1onW
YjL7od=3@`OoSHf=1om5ADD7okRh^0Ko9BDU1Oooool7okbl_0Oo:RXZ1onGUiL7oeUIF@Oo[:b/1omY
JFT7ob/[:`Ko[jn_3Oooool000_ooooo1ol71`L7ohj>SPOoAdM71ol>3Ph7ofe]K@OoU9BD3Ol/;2`5
ooooo`Oo61PH1olE5AD7o`h>3POo2@T91olD51@7o`l?3`Oo2PX:1_l410@6ooooo`KoFUYJ1ol`<307
ooooo`Oo3`l?1olg=cL7oifMW@Oo:b/[1_lc<c<6ooooo`Oo9BDU1ol^;Rh6oc@d=0OoCTi>1on8R8P7
omoOg`Oooooo1_nEUID6ooooo`Oo9BDU1olK6a/7ob<S8`Oo<c<c1_lO7al7oc0`<0Oooooo1_mEEED6
ooooo`Oo6a/K1olD51@7oaDE5@Oo00001olL71`7ob4Q8@Ko;2`/1_lU9BD6ooooo`Oo8B4Q1ommOGd7
ojNWY`Oo@d=31on=SHd7odE5A@Oo^;Rh1_lU9BD5ooooo`Oo_;bl1olZ:RX7oiNGU`OoFEUI1on/[:`7
ofUYJ@Oo:b/[1_n_[jl=ooooo`002oooool7o`L71`OoSXj>1om7AdL7o`h>3POoKFe]1onDU9@=ob`/
;0Gooooo1olH61P7oaDE5@Oo3Ph>1ol92@T7oa@D50Oo3`l?1ol:2PX6o`@410Kooooo1_mJFUX7oc0`
<0Oooooo1ol?3`l7ocLg=`OoWIfM1ol[:b/6oc<c<`Kooooo1olU9BD7obh^;PKo=3@d1om>CTh7ohR8
R0OogmoO1oooool6oiFEU@Kooooo1olU9BD7oa/K6`Oo8b<S1olc<c<6oalO7`Oo<30`1oooool6oeEE
E@Kooooo1olK6a/7oa@D50Oo5ADE1ol00007oa`L70Oo8B4Q1_l/;2`6obDU9@Kooooo1olQ8B47ogem
O@OoYjNW1om3@d<7ohf=S@OoADE51onh^;P6obDU9@Gooooo1onl_;`7obXZ:POoUiNG1omIFET7ojb/
[0OoJFUY1ol[:b/6ojn_[`gooooo000;ooooo`OoEeMG1om]KFd7obDU9@OoN7Qh1om8B4P7o`0000Oo
>SXj1_nLW9`5ooooo`Oo8B4Q1olK6a/7oa8B4POo3`l?1ol92@T7o`d=3@Oo1`L71_l00006ooooo`Ko
BTY:1omRHV87ok>c/`Oo6QXJ1ooShn<7od];B`Oo5ADE1_n][Jd6ooooo`Oo?clo1olf=SH6ocTi>@Oo
<C4a1oln?Sh7oe9BDPOoGUiN1_lZ:RX6ooooo`Oo4Q8B1olS8b<7oaLG5`Oo4Q8B1_lf=SH7oc<c<`Oo
GEeM1_ld=3@6ooooo`Oo71`L1ol>3Ph7o``<30Oo10@41olO7al7obHV9PKo;Bd]1_ln?Sh6ooooo`Oo
7QhN1onh^;P7oi2@T0Oo=CDe1oolo?`7ob@T90OoKFe]1_mKFe/5ooooo`Oo^KVi1olY:BT7om[JfPOo
;2`/1omLG5`7om3@d0Oo<C4a1_m:BTX=ooooo`002oooool7oeMGE`OoKFe]1olU9BD7ogQhN0OoB4Q8
1ol00007ocXj>PKoW9bL1Oooool7ob4Q8@Oo6a/K1olB4Q87o`l?3`Oo2@T91ol=3@d7o`L71`Ko0000
1_ooool6odY:BPOoHV9R1onc/k<7oaXJ6POohn?S1om;Bd/7oaDE5@Ko[Jf]1_ooool7oclo?`Oo=SHf
1_li>CT7oc4a<@Oo?Shn1omBDU87oeiNGPKo:RXZ1_ooool7oa8B4POo8b<S1olG5aL7oa8B4PKo=SHf
1olc<c<7oeeMG@Ko=3@d1_ooool7oa`L70Oo3Ph>1ol<30`7o`@410Oo7alO1olV9RH6obd];@Ko?Shn
1_ooool7oahN7POo^;Rh1on@T907ocDe=@Ooo?cl1olT92@7ofe]K@KoFe]K1Oooool7okVi^@Oo:BTY
1ooJf]X7ob`/;0OoG5aL1oo@d=07oc4a<@KoBTY:3Oooool000_ooooo1omGEeL7ofe]K@Oo9BDU1omh
N7P7odQ8B0Oo00001olj>SX6oibLW0Gooooo1olQ8B47oa/K6`Oo4Q8B1ol?3`l7o`T92@Oo3@d=1ol7
1`L6o`0000Kooooo1_m:BTX7of9RHPOo/k>c1olJ6QX7on?Sh`OoBd];1olE5AD6ojf][@Kooooo1olo
?cl7ocHf=PKo>CTi1ola<C47ochn?POoDU9B1omNGUh6obXZ:PKooooo1olB4Q87ob<S8`Oo5aLG1olB
4Q86ocHf=POo<c<c1omMGEd6oc@d=0Kooooo1olL71`7o`h>3POo30`<1ol410@7oalO7`Oo9RHV1_l]
;Bd6ochn?PKooooo1olN7Qh7okRh^0OoT92@1ole=CD7ooclo0Oo92@T1om]KFd6oe]KF`Gooooo1oni
^KT7obTY:@Oof][J1ol/;2`7oeaLG0Ood=3@1ola<C46odY:BPgooooo000;ooooo`OoEeMG1om]KFd7
obDU9@OoN7Qh1om8B4P7o`0000Oo>SXj1_nLW9`5ooooo`Oo8B4Q1olK6a/7oa8B4POo3`l?1ol92@T7
o`d=3@Oo1`L71_l00006ooooo`KoBTY:1omRHV87ok>c/`Oo6QXJ1ooShn<7od];B`Oo5ADE1_n][Jd6
ooooo`Oo?clo1olf=SH6ocTi>@Oo<C4a1oln?Sh7oe9BDPOoGUiN1_lZ:RX6ooooo`Oo4Q8B1olS8b<7
oaLG5`Oo4Q8B1_lf=SH7oc<c<`OoGEeM1_ld=3@6ooooo`Oo71`L1ol>3Ph7o``<30Oo10@41olO7al7
obHV9PKo;Bd]1_ln?Sh6ooooo`Oo7QhN1onh^;P7oi2@T0Oo=CDe1oolo?`7ob@T90OoKFe]1_mKFe/5
ooooo`Oo^KVi1olY:BT7om[JfPOo;2`/1omLG5`7om3@d0Oo<C4a1_m:BTX=ooooo`002oooool7oeMG
E`OoKFe]1olU9BD7ogQhN0OoB4Q81ol00007ocXj>PKoW9bL1Oooool7ob4Q8@Oo6a/K1olB4Q87o`l?
3`Oo2@T91ol=3@d7o`L71`Ko00001_ooool6odY:BPOoHV9R1onc/k<7oaXJ6POohn?S1om;Bd/7oaDE
5@Ko[Jf]1_ooool7oclo?`Oo=SHf1_li>CT7oc4a<@Oo?Shn1omBDU87oeiNGPKo:RXZ1_ooool7oa8B
4POo8b<S1olG5aL7oa8B4PKo=SHf1olc<c<7oeeMG@Ko=3@d1_ooool7oa`L70Oo3Ph>1ol<30`7o`@4
10Oo7alO1olV9RH6obd];@Ko?Shn1_ooool7oahN7POo^;Rh1on@T907ocDe=@Ooo?cl1olT92@7ofe]
K@KoFe]K1Oooool7okVi^@Oo:BTY1ooJf]X7ob`/;0OoG5aL1oo@d=07oc4a<@KoBTY:3Oooool000_o
oooo1omGEeL7ofe]K@Oo9BDU1omhN7P7odQ8B0Oo00001olj>SX6oibLW0Gooooo1olQ8B47oa/K6`Oo
4Q8B1ol?3`l7o`T92@Oo3@d=1ol71`L6o`0000Kooooo1_m:BTX7of9RHPOo/k>c1olJ6QX7on?Sh`Oo
Bd];1olE5AD6ojf][@Kooooo1olo?cl7ocHf=PKo>CTi1ola<C47ochn?POoDU9B1omNGUh6obXZ:PKo
oooo1olB4Q87ob<S8`Oo5aLG1olB4Q86ocHf=POo<c<c1omMGEd6oc@d=0Kooooo1olL71`7o`h>3POo
30`<1ol410@7oalO7`Oo9RHV1_l];Bd6ochn?PKooooo1olN7Qh7okRh^0OoT92@1ole=CD7ooclo0Oo
92@T1om]KFd6oe]KF`Gooooo1oni^KT7obTY:@Oof][J1ol/;2`7oeaLG0Ood=3@1ola<C46odY:BPgo
oooo000;ooooo`OoEeMG1om]KFd7obDU9@OoN7Qh1om8B4P7o`0000Oo>SXj1_nLW9`5ooooo`Oo8B4Q
1olK6a/7oa8B4POo3`l?1ol92@T7o`d=3@Oo1`L71_l00006ooooo`KoBTY:1omRHV87ok>c/`Oo6QXJ
1ooShn<7od];B`Oo5ADE1_n][Jd6ooooo`Oo?clo1olf=SH6ocTi>@Oo<C4a1oln?Sh7oe9BDPOoGUiN
1_lZ:RX6ooooo`Oo4Q8B1olS8b<7oaLG5`Oo4Q8B1_lf=SH7oc<c<`OoGEeM1_ld=3@6ooooo`Oo71`L
1ol>3Ph7o``<30Oo10@41olO7al7obHV9PKo;Bd]1_ln?Sh6ooooo`Oo7QhN1onh^;P7oi2@T0Oo=CDe
1oolo?`7ob@T90OoKFe]1_mKFe/5ooooo`Oo^KVi1olY:BT7om[JfPOo;2`/1omLG5`7om3@d0Oo<C4a
1_m:BTX=ooooo`002oooool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Ooo
ool7ob8R8POo71`L1olE5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF
5QH7ojRXZ0OoKFe]1omeMGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA
4A46o`D51@Kooooo1ol0000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK
6a/7ocdm?@Oo:b/[1olZ:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2
`/87oa@D50OoemOG1_l[:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn
_[h=ooooo`002oooool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Oooool7
ob8R8POo71`L1olE5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF5QH7
ojRXZ0OoKFe]1omeMGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA4A46
o`D51@Kooooo1ol0000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK6a/7
ocdm?@Oo:b/[1olZ:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2`/87
oa@D50OoemOG1_l[:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn_[h=
ooooo`002oooool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Oooool7ob8R
8POo71`L1olE5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF5QH7ojRX
Z0OoKFe]1omeMGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA4A46o`D5
1@Kooooo1ol0000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK6a/7ocdm
?@Oo:b/[1olZ:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2`/87oa@D
50OoemOG1_l[:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn_[h=oooo
o`002oooool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Oooool7ob8R8POo
71`L1olE5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF5QH7ojRXZ0Oo
KFe]1omeMGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA4A46o`D51@Ko
oooo1ol0000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK6a/7ocdm?@Oo
:b/[1olZ:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2`/87oa@D50Oo
emOG1_l[:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn_[h=ooooo`00
2oooool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Oooool7ob8R8POo71`L
1olE5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF5QH7ojRXZ0OoKFe]
1omeMGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA4A46o`D51@Kooooo
1ol0000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK6a/7ocdm?@Oo:b/[
1olZ:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2`/87oa@D50OoemOG
1_l[:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn_[h=ooooo`002ooo
ool7oa4A4@OoLg=c1om5ADD7oa<C4`OoGEeM1onYZJT7oaPH60Ko9RHV1Oooool7ob8R8POo71`L1olE
5AD7o`@410ko2PX:1ol`<306oa8B4PKooooo1_mBDU87ohj>SPOoYJFU1olF5QH7ojRXZ0OoKFe]1ome
MGD6oe5AD@Kooooo1olb<S87ob@T90Ko9RHV1ol>3Ph7o`X:2POo1`L71olA4A46o`D51@Kooooo1ol0
000>o`T92@Oo20P81_lH61P7ob`/;0Oo92@T1_lM7Ad6ooooo`Oo71`L1olK6a/7ocdm?@Oo:b/[1olZ
:RX7ode=C@KoEUIF1_m3@d<6ooooo`Oo5QHF1ooEeMD7oc4a<@Oo@d=31oo2`/87oa@D50OoemOG1_l[
:b/5ooooo`Oo:b/[1olU9BD7onWYj@Oo3@d=1onSXj<7oiZJVPOo6QXJ1_nn_[h=ooooo`002oooool7
oe]KF`Oono_k1om2@T87oo[jnPOoa/K61oll?3`7oeeMG@Ko^;Rh1Oooool7obDU9@Oo9bLW1olR8R87
ocPh>0Oo8R8R1om6ATH7odY:BPKo;Rh^1_ooool6o`L71`Oo?clo1onm_Kd7oaHF5POoYjNW1omSHf<7
oeYJFPKoKVi^1_ooool7oa@D50Oo8B4Q1_l61PH7o`l?3`Oo4Q8B1olG5aL7oaTI6@Ko7QhN1_ooool7
obTY:@Oo30`<1ol?3`l7oaDE5@KoBd];1olf=SH7odi>CPKo:BTY1_ooool7oeQHF0OoMWIf1onIVIT7
oe5AD@OoCDe=1oli>CT6obTY:@Ko<30`1_ooool7od=3@`OoDE5A1omWIfL7oh>3P`OoI6AT1olB4Q87
olW9b@Ko:b/[1Oooool7of5QH@OoKfm_1om?Cdl7oadM7@Oo`l?31om_Kfl7oaXJ6PKoRXZ:3Oooool0
00_ooooo1omKFe/7oo_kn`Oo@T921oojn_X7olK6aPOo?3`l1omMGEd6okRh^0Gooooo1olU9BD7obLW
9`Oo8R8R1olh>3P7ob8R8POoATI61om:BTX6obh^;PKooooo1_l71`L7oclo?`Oo_Kfm1olF5QH7ojNW
Y`OoHf=S1omJFUX6ofi^KPKooooo1olD51@7ob4Q8@Ko1PH61ol?3`l7oa8B4POo5aLG1olI6AT6oahN
7PKooooo1olY:BT7o``<30Oo3`l?1olE5AD6od];B`Oo=SHf1om>CTh6obTY:@Kooooo1omHF5P7ogIf
MPOoVIVI1omADE47ode=C@Oo>CTi1_lY:BT6oc0`<0Kooooo1om3@d<7oe5AD@OoIfMW1on3Ph<7ofAT
I0Oo4Q8B1oo9bLT6ob/[:`Gooooo1omQHF47ofm_K`OoCdm?1olM7Ad7ol?3``OoKfm_1olJ6QX6ohZ:
RPgooooo000;ooooo`OoFe]K1ookno/7od92@POon_[j1oo6a/H7oc`l?0OoGEeM1_nh^;P5ooooo`Oo
9BDU1olW9bL7ob8R8POo>3Ph1olR8R87odI6APOoBTY:1_l^;Rh6ooooo`Ko1`L71olo?cl7okfm_@Oo
5QHF1onWYjL7of=SH`OoFUYJ1_m^KVh6ooooo`Oo51@D1olQ8B46o`H61POo3`l?1olB4Q87oaLG5`Oo
6ATI1_lN7Qh6ooooo`Oo:BTY1ol<30`7o`l?3`Oo5ADE1_m;Bd/7ocHf=POoCTi>1_lY:BT6ooooo`Oo
F5QH1omfMWH7oiVIV@OoDE5A1om=CDd7ocTi>@Ko:BTY1_l`<306ooooo`Oo@d=31omADE47ofMWI`Oo
Ph>31omTI6@7oa8B4POobLW91_l[:b/5ooooo`OoHF5Q1om_Kfl7odm?C`Oo7AdM1oo3`l<7ofm_K`Oo
6QXJ1_n:RXX=ooooo`002oooool7oe]KF`Oono_k1om2@T87oo[jnPOoa/K61oll?3`7oeeMG@Ko^;Rh
1Oooool7obDU9@Oo9bLW1olR8R87ocPh>0Oo8R8R1om6ATH7odY:BPKo;Rh^1_ooool6o`L71`Oo?clo
1onm_Kd7oaHF5POoYjNW1omSHf<7oeYJFPKoKVi^1_ooool7oa@D50Oo8B4Q1_l61PH7o`l?3`Oo4Q8B
1olG5aL7oaTI6@Ko7QhN1_ooool7obTY:@Oo30`<1ol?3`l7oaDE5@KoBd];1olf=SH7odi>CPKo:BTY
1_ooool7oeQHF0OoMWIf1onIVIT7oe5AD@OoCDe=1oli>CT6obTY:@Ko<30`1_ooool7od=3@`OoDE5A
1omWIfL7oh>3P`OoI6AT1olB4Q87olW9b@Ko:b/[1Oooool7of5QH@OoKfm_1om?Cdl7oadM7@Oo`l?3
1om_Kfl7oaXJ6PKoRXZ:3Oooool000_ooooo1omKFe/7oo_kn`Oo@T921oojn_X7olK6aPOo?3`l1omM
GEd6okRh^0Gooooo1olU9BD7obLW9`Oo8R8R1olh>3P7ob8R8POoATI61om:BTX6obh^;PKooooo1_l7
1`L7oclo?`Oo_Kfm1olF5QH7ojNWY`OoHf=S1omJFUX6ofi^KPKooooo1olD51@7ob4Q8@Ko1PH61ol?
3`l7oa8B4POo5aLG1olI6AT6oahN7PKooooo1olY:BT7o``<30Oo3`l?1olE5AD6od];B`Oo=SHf1om>
CTh6obTY:@Kooooo1omHF5P7ogIfMPOoVIVI1omADE47ode=C@Oo>CTi1_lY:BT6oc0`<0Kooooo1om3
@d<7oe5AD@OoIfMW1on3Ph<7ofATI0Oo4Q8B1oo9bLT6ob/[:`Gooooo1omQHF47ofm_K`OoCdm?1olM
7Ad7ol?3``OoKfm_1olJ6QX6ohZ:RPgooooo000;ooooo`OoFe]K1ookno/7od92@POon_[j1oo6a/H7
oc`l?0OoGEeM1_nh^;P5ooooo`Oo9BDU1olW9bL7ob8R8POo>3Ph1olR8R87odI6APOoBTY:1_l^;Rh6
ooooo`Ko1`L71olo?cl7okfm_@Oo5QHF1onWYjL7of=SH`OoFUYJ1_m^KVh6ooooo`Oo51@D1olQ8B46
o`H61POo3`l?1olB4Q87oaLG5`Oo6ATI1_lN7Qh6ooooo`Oo:BTY1ol<30`7o`l?3`Oo5ADE1_m;Bd/7
ocHf=POoCTi>1_lY:BT6ooooo`OoF5QH1omfMWH7oiVIV@OoDE5A1om=CDd7ocTi>@Ko:BTY1_l`<306
ooooo`Oo@d=31omADE47ofMWI`OoPh>31omTI6@7oa8B4POobLW91_l[:b/5ooooo`OoHF5Q1om_Kfl7
odm?C`Oo7AdM1oo3`l<7ofm_K`Oo6QXJ1_n:RXX=ooooo`002oooool7oe]KF`Oono_k1om2@T87oo[j
nPOoa/K61oll?3`7oeeMG@Ko^;Rh1Oooool7obDU9@Oo9bLW1olR8R87ocPh>0Oo8R8R1om6ATH7odY:
BPKo;Rh^1_ooool6o`L71`Oo?clo1onm_Kd7oaHF5POoYjNW1omSHf<7oeYJFPKoKVi^1_ooool7oa@D
50Oo8B4Q1_l61PH7o`l?3`Oo4Q8B1olG5aL7oaTI6@Ko7QhN1_ooool7obTY:@Oo30`<1ol?3`l7oaDE
5@KoBd];1olf=SH7odi>CPKo:BTY1_ooool7oeQHF0OoMWIf1onIVIT7oe5AD@OoCDe=1oli>CT6obTY
:@Ko<30`1_ooool7od=3@`OoDE5A1omWIfL7oh>3P`OoI6AT1olB4Q87olW9b@Ko:b/[1Oooool7of5Q
H@OoKfm_1om?Cdl7oadM7@Oo`l?31om_Kfl7oaXJ6PKoRXZ:3Oooool000_ooooo1olB4Q87oc<c<`Oo
71`L1olK6a/7oc@d=0OoFEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90Oo
B4Q81ol^;Rh6oa/K6`Kooooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Ko
oooo1olF5QH7o``<30Ko1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko
;bl_1olZ:RX7om?Cd`Ko<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko
7AdM1_ooool7oalO7`OoV9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo
5ADE1on;Rh/7o`d=3@OoEeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L
1olK6a/7oc@d=0OoFEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q8
1ol^;Rh6oa/K6`Kooooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo
1olF5QH7o``<30Ko1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_
1olZ:RX7om?Cd`Ko<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM
1_ooool7oalO7`OoV9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE
1on;Rh/7o`d=3@OoEeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L1olK
6a/7oc@d=0OoFEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q81ol^
;Rh6oa/K6`Kooooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo1olF
5QH7o``<30Ko1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_1olZ
:RX7om?Cd`Ko<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM1_oo
ool7oalO7`OoV9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE1on;
Rh/7o`d=3@OoEeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L1olK6a/7
oc@d=0OoFEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q81ol^;Rh6
oa/K6`Kooooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo1olF5QH7
o``<30Ko1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_1olZ:RX7
om?Cd`Ko<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM1_ooool7
oalO7`OoV9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE1on;Rh/7
o`d=3@OoEeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L1olK6a/7oc@d
=0OoFEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q81ol^;Rh6oa/K
6`Kooooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo1olF5QH7o``<
30Ko1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_1olZ:RX7om?C
d`Ko<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM1_ooool7oalO
7`OoV9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE1on;Rh/7o`d=
3@OoEeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L1olK6a/7oc@d=0Oo
FEUI1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q81ol^;Rh6oa/K6`Ko
oooo1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo1olF5QH7o``<30Ko
1@D51ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_1olZ:RX7om?Cd`Ko
<C4a1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM1_ooool7oalO7`Oo
V9RH1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE1on;Rh/7o`d=3@Oo
EeMG1on0P807oeMGE`KoAdM73Oooool000_ooooo1olB4Q87oc<c<`Oo71`L1olK6a/7oc@d=0OoFEUI
1olI6AT6obPX:0Gooooo1ole=CD7obd];@Oo>3Ph1ol];Bd7ob@T90OoB4Q81ol^;Rh6oa/K6`Kooooo
1_lL71`7oiJFUPOo61PH1ol820P7omOGe`Oo8B4Q1om=CDd6ohN7Q`Kooooo1olF5QH7o``<30Ko1@D5
1ol:2PX7o`D51@ko6ATI1_lO7al6ooooo`Oo51@D3_lE5AD7ob<S8`Ko;bl_1olZ:RX7om?Cd`Ko<C4a
1_ooool7oe1@D0OoDe=C1omIFET7oc4a<@OoBTY:1om4A4@6ocDe=@Ko7AdM1_ooool7oalO7`OoV9RH
1ol>3Ph7ocPh>0OoVIVI1olV9RH7oi6AT@Ko:RXZ1Oooool7o`l?3`Oo5ADE1on;Rh/7o`d=3@OoEeMG
1on0P807oeMGE`KoAdM73Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol3
0`<6oeEEE@Gooooo1olY:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk
>c/7ocLg=`OoDU9B1om:BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;
2`/7obXZ:POo3Ph>1_lQ8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc
<c<6ooooo`Oo9RHV1olX:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL
71`7ohj>SPOo51@D1ol:2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol9
2@T7oaDE5@KoP8203Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol30`<6
oeEEE@Gooooo1olY:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk>c/7
ocLg=`OoDU9B1om:BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;2`/7
obXZ:POo3Ph>1_lQ8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc<c<6
ooooo`Oo9RHV1olX:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL71`7
ohj>SPOo51@D1ol:2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol92@T7
oaDE5@KoP8203Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol30`<6oeEE
E@Gooooo1olY:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk>c/7ocLg
=`OoDU9B1om:BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;2`/7obXZ
:POo3Ph>1_lQ8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc<c<6oooo
o`Oo9RHV1olX:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL71`7ohj>
SPOo51@D1ol:2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol92@T7oaDE
5@KoP8203Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol30`<6oeEEE@Go
oooo1olY:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk>c/7ocLg=`Oo
DU9B1om:BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;2`/7obXZ:POo
3Ph>1_lQ8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc<c<6ooooo`Oo
9RHV1olX:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL71`7ohj>SPOo
51@D1ol:2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol92@T7oaDE5@Ko
P8203Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol30`<6oeEEE@Gooooo
1olY:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk>c/7ocLg=`OoDU9B
1om:BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;2`/7obXZ:POo3Ph>
1_lQ8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc<c<6ooooo`Oo9RHV
1olX:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL71`7ohj>SPOo51@D
1ol:2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol92@T7oaDE5@KoP820
3Oooool000_ooooo1olW9bL7oc/k>`Oo30`<1omXJ6P7od=3@`Oo0P821ol30`<6oeEEE@Gooooo1olY
:BT7o`d=3@Oo7alO1ol@4107oaXJ6POo410@1ol>3Ph6oa@D50Kooooo1_lk>c/7ocLg=`OoDU9B1om:
BTX>oclo?`OoRh^;1_l;2`/6ooooo`Oo3`l?1olA4A46o`0000Oo5QHF1ol;2`/7obXZ:POo3Ph>1_lQ
8B46ooooo`Oo<c<c1ol[:b/7oalO7`Oo5aLG1_lV9RH7oeADE0OoIFEU1_lc<c<6ooooo`Oo9RHV1olX
:2P7oa`L70Oo<30`1olC4a<7obXZ:Pco820P1_ooool7oe5AD@Oo:RXZ1olL71`7ohj>SPOo51@D1ol:
2PX7olG5a@Ko410@1Oooool7oaXJ6POoC4a<1ol820P7o`L71`OoUYJF1ol92@T7oaDE5@KoP8203Ooo
ool000_ooooo1omQHF47oi2@T0OoP8201on@T907ooooo`OoVi^K1onIVIT6oj>SX`Gooooo1olh>3P7
odY:BPOo:RXZ1olc<c<7ofi^KPOob/[:1oooool6oeiNGPKooooo1_lL71`7ob@T90Oo;Rh^1ol;2`/7
oaXJ6POoA4A41ol_;bl6o`0000Kooooo1omKFe/=odU9B@Oo?Shn1om@D507odA4A0Oo@d=31_lm?Cd6
ooooo`Oo8B4Q1olI6AT7ob0P80Oo4a<C1_lg=cL7ocdm?@Oo@T921_ln?Sh6ooooo`Ooc<c<1oooool7
ol_;b`OoC4a<1om]KFd7ocLg=`KoADE51_m;Bd/6ooooo`Oo4Q8B1olH61P7ogYjNPOo<C4a1olB4Q87
ofIVIPOo=CDe1_l00005ooooo`OoLW9b1ol>3Ph7o`0000OoIVIV1olV9RH7o`P820Oo?clo1_lL71`=
ooooo`002oooool7of5QH@OoT92@1on0P807oi2@T0Oooooo1onKVi/7oiVIV@KoXj>S1Oooool7ocPh
>0OoBTY:1olZ:RX7oc<c<`OoKVi^1oo:b/X7ooooo`KoGUiN1_ooool6oa`L70Oo92@T1ol^;Rh7o`/;
2`Oo6QXJ1om4A4@7obl_;`Ko00001_ooool7oe]KF`goBDU91oln?Sh7oe1@D0OoA4A41om3@d<6ocdm
?@Kooooo1olQ8B47oaTI6@Oo820P1olC4a<6ocLg=`Oo?Cdm1om2@T86ochn?PKooooo1oo<c<`7oooo
o`Oobl_;1om<C4`7ofe]K@Oo=cLg1_m5ADD6od];B`Kooooo1olB4Q87oaPH60OoNWYj1ola<C47oa8B
4POoIVIV1ole=CD6o`0000Gooooo1ombLW87o`h>3POo00001omVIVH7obHV9POo20P81olo?cl6oa`L
70gooooo000;ooooo`OoHF5Q1on@T907oh20P0OoT92@1oooool7oi^KV`OoVIVI1_nSXj<5ooooo`Oo
>3Ph1om:BTX7obXZ:POo<c<c1om^KVh7ol[:bPOooooo1_mNGUh6ooooo`Ko71`L1olT92@7obh^;POo
2`/;1olJ6QX7odA4A0Oo;bl_1_l00006ooooo`OoFe]K3Om9BDT7ochn?POoD51@1om4A4@7od=3@`Ko
?Cdm1_ooool7ob4Q8@Oo6ATI1olP8207oa<C4`Ko=cLg1olm?Cd7od92@PKo?Shn1_ooool7olc<c0Oo
oooo1oo;bl/7oda<C0OoKFe]1olg=cL6odE5A@KoBd];1_ooool7oa8B4POo61PH1omjNWX7oc4a<@Oo
4Q8B1omVIVH7ocDe=@Ko00001Oooool7og9bLPOo3Ph>1ol00007ofIVIPOo9RHV1ol820P7oclo?`Ko
71`L3Oooool000_ooooo1omQHF47oi2@T0OoP8201on@T907ooooo`OoVi^K1onIVIT6oj>SX`Gooooo
1olh>3P7odY:BPOo:RXZ1olc<c<7ofi^KPOob/[:1oooool6oeiNGPKooooo1_lL71`7ob@T90Oo;Rh^
1ol;2`/7oaXJ6POoA4A41ol_;bl6o`0000Kooooo1omKFe/=odU9B@Oo?Shn1om@D507odA4A0Oo@d=3
1_lm?Cd6ooooo`Oo8B4Q1olI6AT7ob0P80Oo4a<C1_lg=cL7ocdm?@Oo@T921_ln?Sh6ooooo`Ooc<c<
1oooool7ol_;b`OoC4a<1om]KFd7ocLg=`KoADE51_m;Bd/6ooooo`Oo4Q8B1olH61P7ogYjNPOo<C4a
1olB4Q87ofIVIPOo=CDe1_l00005ooooo`OoLW9b1ol>3Ph7o`0000OoIVIV1olV9RH7o`P820Oo?clo
1_lL71`=ooooo`002oooool7of5QH@OoT92@1on0P807oi2@T0Oooooo1onKVi/7oiVIV@KoXj>S1Ooo
ool7ocPh>0OoBTY:1olZ:RX7oc<c<`OoKVi^1oo:b/X7ooooo`KoGUiN1_ooool6oa`L70Oo92@T1ol^
;Rh7o`/;2`Oo6QXJ1om4A4@7obl_;`Ko00001_ooool7oe]KF`goBDU91oln?Sh7oe1@D0OoA4A41om3
@d<6ocdm?@Kooooo1olQ8B47oaTI6@Oo820P1olC4a<6ocLg=`Oo?Cdm1om2@T86ochn?PKooooo1oo<
c<`7ooooo`Oobl_;1om<C4`7ofe]K@Oo=cLg1_m5ADD6od];B`Kooooo1olB4Q87oaPH60OoNWYj1ola
<C47oa8B4POoIVIV1ole=CD6o`0000Gooooo1ombLW87o`h>3POo00001omVIVH7obHV9POo20P81olo
?cl6oa`L70gooooo000;ooooo`OoHF5Q1on@T907oh20P0OoT92@1oooool7oi^KV`OoVIVI1_nSXj<5
ooooo`Oo>3Ph1om:BTX7obXZ:POo<c<c1om^KVh7ol[:bPOooooo1_mNGUh6ooooo`Ko71`L1olT92@7
obh^;POo2`/;1olJ6QX7odA4A0Oo;bl_1_l00006ooooo`OoFe]K3Om9BDT7ochn?POoD51@1om4A4@7
od=3@`Ko?Cdm1_ooool7ob4Q8@Oo6ATI1olP8207oa<C4`Ko=cLg1olm?Cd7od92@PKo?Shn1_ooool7
olc<c0Oooooo1oo;bl/7oda<C0OoKFe]1olg=cL6odE5A@KoBd];1_ooool7oa8B4POo61PH1omjNWX7
oc4a<@Oo4Q8B1omVIVH7ocDe=@Ko00001Oooool7og9bLPOo3Ph>1ol00007ofIVIPOo9RHV1ol820P7
oclo?`Ko71`L3Oooool000_ooooo1omQHF47oi2@T0OoP8201on@T907ooooo`OoVi^K1onIVIT6oj>S
X`Gooooo1olh>3P7odY:BPOo:RXZ1olc<c<7ofi^KPOob/[:1oooool6oeiNGPKooooo1_lL71`7ob@T
90Oo;Rh^1ol;2`/7oaXJ6POoA4A41ol_;bl6o`0000Kooooo1omKFe/=odU9B@Oo?Shn1om@D507odA4
A0Oo@d=31_lm?Cd6ooooo`Oo8B4Q1olI6AT7ob0P80Oo4a<C1_lg=cL7ocdm?@Oo@T921_ln?Sh6oooo
o`Ooc<c<1oooool7ol_;b`OoC4a<1om]KFd7ocLg=`KoADE51_m;Bd/6ooooo`Oo4Q8B1olH61P7ogYj
NPOo<C4a1olB4Q87ofIVIPOo=CDe1_l00005ooooo`OoLW9b1ol>3Ph7o`0000OoIVIV1olV9RH7o`P8
20Oo?clo1_lL71`=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002oooool7ofEUI@OomoOg1om2
@T87obXZ:POo4A4A1ol[:b/7o`D51@Ko0P821Oooool7omSHf0Oo9BDU1ooKfm/7oeiNGPOoN7Qh1ooj
n_X7oc`l?0KoKfm_1_ooool6oc@d=0Oo9bLW1olE5AD7o``<30Oo0`<31ol00007oa`L70Ko9bLW1_oo
ool7oc@d=0Oo<c<c1_l?3`l7ob@T90OoFe]K1ol410@7obd];@KoHf=S1_ooool7ob`/;0Oo5ADE1olL
71`7oahN7PKo4a<C1olD51@7o`0000Ko<C4a1_ooool7ob/[:`Oo8R8R1olO7al7obPX:0Oo<C4a1om5
ADD6obh^;PKo71`L1_ooool7oe]KF`OoKfm_1om?Cdl7ojb/[0OoF5QH1olL71`7ogmoO`Ko:BTY1Ooo
ool>odU9B@Oo?Cdm1olg=cL7oa`L70Oo>SXj1oln?Sh6o`<30`gooooo000;ooooo`OoIFEU1oogmoL7
od92@POo:RXZ1olA4A47ob/[:`Oo1@D51_l20P85ooooo`Oof=SH1olU9BD7om_Kf`OoGUiN1omhN7P7
oo[jnPOo?3`l1_m_Kfl6ooooo`Ko=3@d1olW9bL7oaDE5@Oo30`<1ol30`<7o`0000Oo71`L1_lW9bL6
ooooo`Oo=3@d1olc<c<6o`l?3`Oo92@T1omKFe/7o`@410Oo;Bd]1_mSHf<6ooooo`Oo;2`/1olE5AD7
oa`L70Oo7QhN1_lC4a<7oa@D50Oo00001_la<C46ooooo`Oo:b/[1olR8R87oalO7`Oo:2PX1ola<C47
odE5A@Ko;Rh^1_lL71`6ooooo`OoFe]K1om_Kfl7odm?C`Oo[:b/1omHF5P7oa`L70OoOgmo1_lY:BT5
ooooo`koBDU91olm?Cd7ocLg=`Oo71`L1olj>SX7ochn?PKo0`<33Oooool000_ooooo1omUIFD7ooOg
m`Oo@T921olZ:RX7oa4A4@Oo:b/[1ol51@D6o`820PGooooo1ooHf=P7obDU9@Oofm_K1omNGUh7ogQh
N0Oon_[j1oll?3`6ofm_K`Kooooo1_ld=3@7obLW9`Oo5ADE1ol<30`7o`<30`Oo00001olL71`6obLW
9`Kooooo1old=3@7oc<c<`Ko3`l?1olT92@7oe]KF`Oo10@41ol];Bd6of=SH`Kooooo1ol/;2`7oaDE
5@Oo71`L1olN7Qh6oa<C4`Oo51@D1ol00006oc4a<@Kooooo1ol[:b/7ob8R8POo7alO1olX:2P7oc4a
<@OoADE51_l^;Rh6oa`L70Kooooo1omKFe/7ofm_K`OoCdm?1on/[:`7oeQHF0Oo71`L1omoOgl6obTY
:@Gooooo3_m9BDT7ocdm?@Oo=cLg1olL71`7ocXj>POo?Shn1_l30`<=ooooo`002oooool7ofEUI@Oo
moOg1om2@T87obXZ:POo4A4A1ol[:b/7o`D51@Ko0P821Oooool7omSHf0Oo9BDU1ooKfm/7oeiNGPOo
N7Qh1oojn_X7oc`l?0KoKfm_1_ooool6oc@d=0Oo9bLW1olE5AD7o``<30Oo0`<31ol00007oa`L70Ko
9bLW1_ooool7oc@d=0Oo<c<c1_l?3`l7ob@T90OoFe]K1ol410@7obd];@KoHf=S1_ooool7ob`/;0Oo
5ADE1olL71`7oahN7PKo4a<C1olD51@7o`0000Ko<C4a1_ooool7ob/[:`Oo8R8R1olO7al7obPX:0Oo
<C4a1om5ADD6obh^;PKo71`L1_ooool7oe]KF`OoKfm_1om?Cdl7ojb/[0OoF5QH1olL71`7ogmoO`Ko
:BTY1Oooool>odU9B@Oo?Cdm1olg=cL7oa`L70Oo>SXj1oln?Sh6o`<30`gooooo000;ooooo`OoIFEU
1oogmoL7od92@POo:RXZ1olA4A47ob/[:`Oo1@D51_l20P85ooooo`Oof=SH1olU9BD7om_Kf`OoGUiN
1omhN7P7oo[jnPOo?3`l1_m_Kfl6ooooo`Ko=3@d1olW9bL7oaDE5@Oo30`<1ol30`<7o`0000Oo71`L
1_lW9bL6ooooo`Oo=3@d1olc<c<6o`l?3`Oo92@T1omKFe/7o`@410Oo;Bd]1_mSHf<6ooooo`Oo;2`/
1olE5AD7oa`L70Oo7QhN1_lC4a<7oa@D50Oo00001_la<C46ooooo`Oo:b/[1olR8R87oalO7`Oo:2PX
1ola<C47odE5A@Ko;Rh^1_lL71`6ooooo`OoFe]K1om_Kfl7odm?C`Oo[:b/1omHF5P7oa`L70OoOgmo
1_lY:BT5ooooo`koBDU91olm?Cd7ocLg=`Oo71`L1olj>SX7ochn?PKo0`<33Oooool000_ooooo1omU
IFD7ooOgm`Oo@T921olZ:RX7oa4A4@Oo:b/[1ol51@D6o`820PGooooo1ooHf=P7obDU9@Oofm_K1omN
GUh7ogQhN0Oon_[j1oll?3`6ofm_K`Kooooo1_ld=3@7obLW9`Oo5ADE1ol<30`7o`<30`Oo00001olL
71`6obLW9`Kooooo1old=3@7oc<c<`Ko3`l?1olT92@7oe]KF`Oo10@41ol];Bd6of=SH`Kooooo1ol/
;2`7oaDE5@Oo71`L1olN7Qh6oa<C4`Oo51@D1ol00006oc4a<@Kooooo1ol[:b/7ob8R8POo7alO1olX
:2P7oc4a<@OoADE51_l^;Rh6oa`L70Kooooo1omKFe/7ofm_K`OoCdm?1on/[:`7oeQHF0Oo71`L1omo
Ogl6obTY:@Gooooo3_m9BDT7ocdm?@Oo=cLg1olL71`7ocXj>POo?Shn1_l30`<=ooooo`002oooool7
odm?C`OoWinO1ol[:b/7o`P820Oo00001ol?3`l=o`@410Gooooo1olh>3P7oa`L70Oooooo1olP8207
oi2@T0OogMgM1olJ6QX6on7Qh@Kooooo1_m6ATH7ob/[:`Oo5ADE1olK6a/7o`/;2`Oo5ADE1ol?3`l6
obDU9@Kooooo1oli>CT7oh:2PPKo:2PX1olh>3P7od92@POo4Q8B1om:BTX6oaTI6@Kooooo1om<C4`7
oeiNGPOoLg=c3Om9BDT7odM7A`Oo?clo1_ln?Sh6ooooo`Oo:b/[1olg=cL7obd];@Oo8B4Q1olW9bL7
ob@T90Ko820P1_lE5AD6ooooo`Oo;bl_1ooTi>@7oa0@40OoBTY:1onn_[h7ocPh>0OoDE5A1_mEEED<
ooooo`Oo7alO1olQ8B47ojNWY`Oo6QXJ1olU9BD7oeYJFPKo=CDe3Oooool000_ooooo1om?Cdl7oinO
W`Oo:b/[1ol820P7o`0000Oo3`l?3Ol410@5ooooo`Oo>3Ph1olL71`7ooooo`Oo820P1on@T907omgM
g@Oo6QXJ1_oQhN46ooooo`KoATI61ol[:b/7oaDE5@Oo6a/K1ol;2`/7oaDE5@Oo3`l?1_lU9BD6oooo
o`Oo>CTi1on2PX86obPX:0Oo>3Ph1om2@T87oa8B4POoBTY:1_lI6AT6ooooo`OoC4a<1omNGUh7og=c
L`goBDU91om7AdL7oclo?`Ko?Shn1_ooool7ob/[:`Oo=cLg1ol];Bd7ob4Q8@Oo9bLW1olT92@6ob0P
80Ko5ADE1_ooool7obl_;`Ooi>CT1ol@4107odY:BPOo_[jn1olh>3P7oe5AD@KoEEEE3?ooool7oalO
7`Oo8B4Q1onWYjL7oaXJ6POo9BDU1omJFUX6ocDe=@gooooo000;ooooo`OoCdm?1onOWil7ob/[:`Oo
20P81ol00007o`l?3`go10@41Oooool7ocPh>0Oo71`L1oooool7ob0P80OoT92@1ooMgMd7oaXJ6PKo
hN7Q1_ooool6odI6APOo:b/[1olE5AD7oa/K6`Oo2`/;1olE5AD7o`l?3`Ko9BDU1_ooool7ocTi>@Oo
PX:21_lX:2P7ocPh>0Oo@T921olB4Q87odY:BPKo6ATI1_ooool7oda<C0OoGUiN1omcLg<=odU9B@Oo
AdM71olo?cl6ochn?PKooooo1ol[:b/7ocLg=`Oo;Bd]1olQ8B47obLW9`Oo92@T1_lP8206oaDE5@Ko
oooo1ol_;bl7onCTi0Oo410@1om:BTX7okjn_POo>3Ph1omADE46oeEEE@cooooo1olO7al7ob4Q8@Oo
YjNW1olJ6QX7obDU9@OoFUYJ1_le=CD=ooooo`002oooool7odm?C`OoWinO1ol[:b/7o`P820Oo0000
1ol?3`l=o`@410Gooooo1olh>3P7oa`L70Oooooo1olP8207oi2@T0OogMgM1olJ6QX6on7Qh@Kooooo
1_m6ATH7ob/[:`Oo5ADE1olK6a/7o`/;2`Oo5ADE1ol?3`l6obDU9@Kooooo1oli>CT7oh:2PPKo:2PX
1olh>3P7od92@POo4Q8B1om:BTX6oaTI6@Kooooo1om<C4`7oeiNGPOoLg=c3Om9BDT7odM7A`Oo?clo
1_ln?Sh6ooooo`Oo:b/[1olg=cL7obd];@Oo8B4Q1olW9bL7ob@T90Ko820P1_lE5AD6ooooo`Oo;bl_
1ooTi>@7oa0@40OoBTY:1onn_[h7ocPh>0OoDE5A1_mEEED<ooooo`Oo7alO1olQ8B47ojNWY`Oo6QXJ
1olU9BD7oeYJFPKo=CDe3Oooool000_ooooo1om?Cdl7oinOW`Oo:b/[1ol820P7o`0000Oo3`l?3Ol4
10@5ooooo`Oo>3Ph1olL71`7ooooo`Oo820P1on@T907omgMg@Oo6QXJ1_oQhN46ooooo`KoATI61ol[
:b/7oaDE5@Oo6a/K1ol;2`/7oaDE5@Oo3`l?1_lU9BD6ooooo`Oo>CTi1on2PX86obPX:0Oo>3Ph1om2
@T87oa8B4POoBTY:1_lI6AT6ooooo`OoC4a<1omNGUh7og=cL`goBDU91om7AdL7oclo?`Ko?Shn1_oo
ool7ob/[:`Oo=cLg1ol];Bd7ob4Q8@Oo9bLW1olT92@6ob0P80Ko5ADE1_ooool7obl_;`Ooi>CT1ol@
4107odY:BPOo_[jn1olh>3P7oe5AD@KoEEEE3?ooool7oalO7`Oo8B4Q1onWYjL7oaXJ6POo9BDU1omJ
FUX6ocDe=@gooooo000;ooooo`OoCdm?1onOWil7ob/[:`Oo20P81ol00007o`l?3`go10@41Oooool7
ocPh>0Oo71`L1oooool7ob0P80OoT92@1ooMgMd7oaXJ6PKohN7Q1_ooool6odI6APOo:b/[1olE5AD7
oa/K6`Oo2`/;1olE5AD7o`l?3`Ko9BDU1_ooool7ocTi>@OoPX:21_lX:2P7ocPh>0Oo@T921olB4Q87
odY:BPKo6ATI1_ooool7oda<C0OoGUiN1omcLg<=odU9B@OoAdM71olo?cl6ochn?PKooooo1ol[:b/7
ocLg=`Oo;Bd]1olQ8B47obLW9`Oo92@T1_lP8206oaDE5@Kooooo1ol_;bl7onCTi0Oo410@1om:BTX7
okjn_POo>3Ph1omADE46oeEEE@cooooo1olO7al7ob4Q8@OoYjNW1olJ6QX7obDU9@OoFUYJ1_le=CD=
ooooo`002oooool7odm?C`OoWinO1ol[:b/7o`P820Oo00001ol?3`l=o`@410Gooooo1olh>3P7oa`L
70Oooooo1olP8207oi2@T0OogMgM1olJ6QX6on7Qh@Kooooo1_m6ATH7ob/[:`Oo5ADE1olK6a/7o`/;
2`Oo5ADE1ol?3`l6obDU9@Kooooo1oli>CT7oh:2PPKo:2PX1olh>3P7od92@POo4Q8B1om:BTX6oaTI
6@Kooooo1om<C4`7oeiNGPOoLg=c3Om9BDT7odM7A`Oo?clo1_ln?Sh6ooooo`Oo:b/[1olg=cL7obd]
;@Oo8B4Q1olW9bL7ob@T90Ko820P1_lE5AD6ooooo`Oo;bl_1ooTi>@7oa0@40OoBTY:1onn_[h7ocPh
>0OoDE5A1_mEEED<ooooo`Oo7alO1olQ8B47ojNWY`Oo6QXJ1olU9BD7oeYJFPKo=CDe3Oooool000_o
oooo1om1@D47olc<c0OoG5aL1ol/;2`7oaDE5@Oo9RHV1ol?3`l6o`X:2PGooooo1omOGel7ogIfMPOo
@4101oll?3`7olG5a@OoK6a/1ol>3Ph6oj^[Z`Kooooo1_mBDU87od10@0Oo8B4Q1oln?Sh7oc/k>`Oo
DU9B1olg=cL6oeMGE`Kooooo1ooShn<7obXZ:PKo51@D1ooFe]H7o`X:2POo6ATI1omKFe/6oadM7@Ko
oooo1omYJFT7ooooo`OoinOW1oo:b/X6ohj>SPOoGUiN1ol_;bl6oclo?`Kooooo1olS8b<7obHV9POo
:BTY1oli>CT7obHV9POo820P1_l?3`l6ob`/;0Kooooo1om4A4@7ok:b/POo20P81ooMgMd7oginOPOo
:BTY1oooool6oaDE5@Gooooo1onKVi/7obl_;`Oob<S81omOGel7o`P820Ook^k^1olI6AT6obl_;`go
oooo000;ooooo`Oo@D511oo<c<`7oeaLG0Oo;2`/1olE5AD7obHV9POo3`l?1_l:2PX5ooooo`OoGemO
1omfMWH7od10@0Oo?3`l1oo5aLD7ofa/K0Oo3Ph>1_n[Zj/6ooooo`KoDU9B1om0@407ob4Q8@Oo?Shn
1olk>c/7oe9BDPOo=cLg1_mGEeL6ooooo`Oohn?S1olZ:RX6oa@D50Ooe]KF1ol:2PX7oaTI6@OoFe]K
1_lM7Ad6ooooo`OoJFUY1oooool7onOWi`Oob/[:1_n>SXh7oeiNGPOo;bl_1_lo?cl6ooooo`Oo8b<S
1olV9RH7obTY:@Oo>CTi1olV9RH7ob0P80Ko3`l?1_l/;2`6ooooo`OoA4A41onb/[87o`P820OogMgM
1omnOWh7obTY:@Oooooo1_lE5AD5ooooo`OoVi^K1ol_;bl7olS8b0OoGemO1ol820P7onk^kPOo6ATI
1_l_;bl=ooooo`002oooool7od51@@Ooc<c<1omLG5`7ob`/;0Oo5ADE1olV9RH7o`l?3`Ko2PX:1Ooo
ool7oemOG`OoMWIf1om0@407oc`l?0OoaLG51om/K6`7o`h>3PKoZj^[1_ooool6oe9BDPOo@4101olQ
8B47ochn?POo>c/k1omBDU87ocLg=`KoEeMG1_ooool7on?Sh`Oo:RXZ1_lD51@7omKFePOo2PX:1olI
6AT7oe]KF`Ko7AdM1_ooool7ofUYJ@Oooooo1ooWinL7ol[:bPKoSXj>1omNGUh7obl_;`Ko?clo1_oo
ool7ob<S8`Oo9RHV1olY:BT7ocTi>@Oo9RHV1olP8206o`l?3`Ko;2`/1_ooool7odA4A0Oo/[:b1ol8
20P7omgMg@OoOWin1olY:BT7ooooo`Ko5ADE1Oooool7oi^KV`Oo;bl_1oo8b<P7oemOG`Oo20P81oo^
k^h7oaTI6@Ko;bl_3Oooool000_ooooo1om1@D47olc<c0OoG5aL1ol/;2`7oaDE5@Oo9RHV1ol?3`l6
o`X:2PGooooo1omOGel7ogIfMPOo@4101oll?3`7olG5a@OoK6a/1ol>3Ph6oj^[Z`Kooooo1_mBDU87
od10@0Oo8B4Q1oln?Sh7oc/k>`OoDU9B1olg=cL6oeMGE`Kooooo1ooShn<7obXZ:PKo51@D1ooFe]H7
o`X:2POo6ATI1omKFe/6oadM7@Kooooo1omYJFT7ooooo`OoinOW1oo:b/X6ohj>SPOoGUiN1ol_;bl6
oclo?`Kooooo1olS8b<7obHV9POo:BTY1oli>CT7obHV9POo820P1_l?3`l6ob`/;0Kooooo1om4A4@7
ok:b/POo20P81ooMgMd7oginOPOo:BTY1oooool6oaDE5@Gooooo1onKVi/7obl_;`Oob<S81omOGel7
o`P820Ook^k^1olI6AT6obl_;`gooooo000;ooooo`Oo@D511oo<c<`7oeaLG0Oo;2`/1olE5AD7obHV
9POo3`l?1_l:2PX5ooooo`OoGemO1omfMWH7od10@0Oo?3`l1oo5aLD7ofa/K0Oo3Ph>1_n[Zj/6oooo
o`KoDU9B1om0@407ob4Q8@Oo?Shn1olk>c/7oe9BDPOo=cLg1_mGEeL6ooooo`Oohn?S1olZ:RX6oa@D
50Ooe]KF1ol:2PX7oaTI6@OoFe]K1_lM7Ad6ooooo`OoJFUY1oooool7onOWi`Oob/[:1_n>SXh7oeiN
GPOo;bl_1_lo?cl6ooooo`Oo8b<S1olV9RH7obTY:@Oo>CTi1olV9RH7ob0P80Ko3`l?1_l/;2`6oooo
o`OoA4A41onb/[87o`P820OogMgM1omnOWh7obTY:@Oooooo1_lE5AD5ooooo`OoVi^K1ol_;bl7olS8
b0OoGemO1ol820P7onk^kPOo6ATI1_l_;bl=ooooo`002oooool7od51@@Ooc<c<1omLG5`7ob`/;0Oo
5ADE1olV9RH7o`l?3`Ko2PX:1Oooool7oemOG`OoMWIf1om0@407oc`l?0OoaLG51om/K6`7o`h>3PKo
Zj^[1_ooool6oe9BDPOo@4101olQ8B47ochn?POo>c/k1omBDU87ocLg=`KoEeMG1_ooool7on?Sh`Oo
:RXZ1_lD51@7omKFePOo2PX:1olI6AT7oe]KF`Ko7AdM1_ooool7ofUYJ@Oooooo1ooWinL7ol[:bPKo
SXj>1omNGUh7obl_;`Ko?clo1_ooool7ob<S8`Oo9RHV1olY:BT7ocTi>@Oo9RHV1olP8206o`l?3`Ko
;2`/1_ooool7odA4A0Oo/[:b1ol820P7omgMg@OoOWin1olY:BT7ooooo`Ko5ADE1Oooool7oi^KV`Oo
;bl_1oo8b<P7oemOG`Oo20P81oo^k^h7oaTI6@Ko;bl_3Oooool000_ooooo1om1@D47olc<c0OoG5aL
1ol/;2`7oaDE5@Oo9RHV1ol?3`l6o`X:2PGooooo1omOGel7ogIfMPOo@4101oll?3`7olG5a@OoK6a/
1ol>3Ph6oj^[Z`Kooooo1_mBDU87od10@0Oo8B4Q1oln?Sh7oc/k>`OoDU9B1olg=cL6oeMGE`Kooooo
1ooShn<7obXZ:PKo51@D1ooFe]H7o`X:2POo6ATI1omKFe/6oadM7@Kooooo1omYJFT7ooooo`OoinOW
1oo:b/X6ohj>SPOoGUiN1ol_;bl6oclo?`Kooooo1olS8b<7obHV9POo:BTY1oli>CT7obHV9POo820P
1_l?3`l6ob`/;0Kooooo1om4A4@7ok:b/POo20P81ooMgMd7oginOPOo:BTY1oooool6oaDE5@Gooooo
1onKVi/7obl_;`Oob<S81omOGel7o`P820Ook^k^1olI6AT6obl_;`gooooo000;ooooo`OoYJFU1ooo
ool7ocLg=`Oo6ATI1ol410@7oaDE5@Oo30`<1_l=3@d5ooooo`Oo30`<1olK6a/7ohb<S0Oo4A4A1om>
CTh7oiFEU@OoBTY:1_mFEUH6ooooo`KoR8R81on>SXh7oh20P0OoT92@1onUYJD7oiFEU@OoMGEe1_m^
KVh6ooooo`OoOWin1om_Kfl6ofa/K0OoJFUY1old=3@7ol30`0Oo5QHF1_l?3`l6ooooo`OoCTi>1omf
MWH7oeeMG@OoNg]k1_lk>c/7of9RHPOoJ6QX1_mdM7@6ooooo`Oo820P1olQ8B47oa/K6`Oo61PH1olN
7Qh7oaPH60Ko5ADE1_lP8206ooooo`OoUYJF1on9RHT7o`d=3@Oodm?C1om/K6`7oeeMG@OoZj^[1_lQ
8B45ooooo`Ooa<C41ol?3`l7ogemO@OoXJ6Q1om6ATH7ogYjNPOoFEUI1_oBd]8=ooooo`002oooool7
ojFUY@Oooooo1olg=cL7oaTI6@Oo10@41olE5AD7o``<30Ko3@d=1Oooool7o``<30Oo6a/K1on<S8`7
oa4A4@OoCTi>1onEUID7odY:BPKoEUIF1_ooool6ohR8R0OoSXj>1on0P807oi2@T0OoYJFU1onEUID7
ogEeM@KoKVi^1_ooool7oginOPOoKfm_1_m/K6`7ofUYJ@Oo=3@d1oo0`<07oaHF5PKo3`l?1_ooool7
odi>CPOoMWIf1omMGEd7og]kN`Ko>c/k1omRHV87ofQXJ0KoM7Ad1_ooool7ob0P80Oo8B4Q1olK6a/7
oaPH60Oo7QhN1olH61P6oaDE5@Ko820P1_ooool7oiJFUPOoRHV91ol=3@d7om?Cd`OoK6a/1omMGEd7
oj^[Z`Ko8B4Q1Oooool7olC4a0Oo3`l?1ommOGd7oj6QX@OoATI61omjNWX7oeUIF@Kod];B3Oooool0
00_ooooo1onUYJD7ooooo`Oo=cLg1olI6AT7o`@410Oo5ADE1ol<30`6o`d=3@Gooooo1ol<30`7oa/K
6`OoS8b<1olA4A47odi>CPOoUIFE1om:BTX6oeIFEPKooooo1_n8R8P7ohj>SPOoP8201on@T907ojFU
Y@OoUIFE1omeMGD6ofi^KPKooooo1omnOWh7ofm_K`KoK6a/1omYJFT7oc@d=0Oo`<301olF5QH6o`l?
3`Kooooo1om>CTh7ogIfMPOoGEeM1omkNg/6oc/k>`OoHV9R1omXJ6P6ogAdM0Kooooo1olP8207ob4Q
8@Oo6a/K1olH61P7oahN7POo61PH1_lE5AD6ob0P80Kooooo1onFUYH7ohV9R@Oo3@d=1ooCdm<7ofa/
K0OoGEeM1on[Zj/6ob4Q8@Gooooo1oo4a<@7o`l?3`OoOGem1onQXJ47odI6APOoNWYj1omIFET6om;B
dPgooooo000;ooooo`OoYJFU1oooool7ocLg=`Oo6ATI1ol410@7oaDE5@Oo30`<1_l=3@d5ooooo`Oo
30`<1olK6a/7ohb<S0Oo4A4A1om>CTh7oiFEU@OoBTY:1_mFEUH6ooooo`KoR8R81on>SXh7oh20P0Oo
T92@1onUYJD7oiFEU@OoMGEe1_m^KVh6ooooo`OoOWin1om_Kfl6ofa/K0OoJFUY1old=3@7ol30`0Oo
5QHF1_l?3`l6ooooo`OoCTi>1omfMWH7oeeMG@OoNg]k1_lk>c/7of9RHPOoJ6QX1_mdM7@6ooooo`Oo
820P1olQ8B47oa/K6`Oo61PH1olN7Qh7oaPH60Ko5ADE1_lP8206ooooo`OoUYJF1on9RHT7o`d=3@Oo
dm?C1om/K6`7oeeMG@OoZj^[1_lQ8B45ooooo`Ooa<C41ol?3`l7ogemO@OoXJ6Q1om6ATH7ogYjNPOo
FEUI1_oBd]8=ooooo`002oooool7ojFUY@Oooooo1olg=cL7oaTI6@Oo10@41olE5AD7o``<30Ko3@d=
1Oooool7o``<30Oo6a/K1on<S8`7oa4A4@OoCTi>1onEUID7odY:BPKoEUIF1_ooool6ohR8R0OoSXj>
1on0P807oi2@T0OoYJFU1onEUID7ogEeM@KoKVi^1_ooool7oginOPOoKfm_1_m/K6`7ofUYJ@Oo=3@d
1oo0`<07oaHF5PKo3`l?1_ooool7odi>CPOoMWIf1omMGEd7og]kN`Ko>c/k1omRHV87ofQXJ0KoM7Ad
1_ooool7ob0P80Oo8B4Q1olK6a/7oaPH60Oo7QhN1olH61P6oaDE5@Ko820P1_ooool7oiJFUPOoRHV9
1ol=3@d7om?Cd`OoK6a/1omMGEd7oj^[Z`Ko8B4Q1Oooool7olC4a0Oo3`l?1ommOGd7oj6QX@OoATI6
1omjNWX7oeUIF@Kod];B3Oooool000_ooooo1onUYJD7ooooo`Oo=cLg1olI6AT7o`@410Oo5ADE1ol<
30`6o`d=3@Gooooo1ol<30`7oa/K6`OoS8b<1olA4A47odi>CPOoUIFE1om:BTX6oeIFEPKooooo1_n8
R8P7ohj>SPOoP8201on@T907ojFUY@OoUIFE1omeMGD6ofi^KPKooooo1omnOWh7ofm_K`KoK6a/1omY
JFT7oc@d=0Oo`<301olF5QH6o`l?3`Kooooo1om>CTh7ogIfMPOoGEeM1omkNg/6oc/k>`OoHV9R1omX
J6P6ogAdM0Kooooo1olP8207ob4Q8@Oo6a/K1olH61P7oahN7POo61PH1_lE5AD6ob0P80Kooooo1onF
UYH7ohV9R@Oo3@d=1ooCdm<7ofa/K0OoGEeM1on[Zj/6ob4Q8@Gooooo1oo4a<@7o`l?3`OoOGem1onQ
XJ47odI6APOoNWYj1omIFET6om;BdPgooooo000;ooooo`OoBDU91on4Q8@7odi>CPOo9bLW1ol=3@d7
ob0P80Oo30`<1_lL71`5ooooo`Oo5QHF1omEEED7oaXJ6POo0`<31on0P807o`0000Oo4A4A1_n2PX86
ooooo`KoLW9b1on9RHT7og]kN`Oo/K6a1on<S8`7okbl_0Oo/K6a1_nWYjL6ooooo`Ooclo?1olo?cl6
ocXj>POolo?c1ol/;2`7oe9BDPOoOgmo1_m[Jf/6ooooo`Oo=cLg1oli>CT7ocDe=@Oo@4101_lf=SH7
ofe]K@OoE5AD1_n5QHD6ooooo`Oo6a/K1ol>3Ph7o`P820ko51@D1olB4Q86o`h>3PKo5ADE1_ooool7
oc`l?0OoYJFU1olQ8B47okZj^POoN7Qh1omRHV87ol;2`PKo7alO1Oooool7ol;2`POo4a<C1onKVi/7
oh20P0Oo<c<c1oodm?@7ocDe=@KoGEeM3Oooool000_ooooo1om9BDT7ohB4Q0OoCTi>1olW9bL7o`d=
3@Oo820P1ol<30`6oa`L70Gooooo1olF5QH7oeEEE@Oo6QXJ1ol30`<7oh20P0Oo00001olA4A46oh:2
PPKooooo1_mbLW87ohV9R@OoNg]k1ona/K47ohb<S0Oo_;bl1ona/K46ojNWY`Kooooo1oo?cll7oclo
?`Ko>SXj1ooclo<7ob`/;0OoDU9B1omoOgl6of][J`Kooooo1olg=cL7ocTi>@Oo=CDe1om0@406ocHf
=POoKFe]1omDE5@6ohF5Q@Kooooo1olK6a/7o`h>3POo20P83_lD51@7oa8B4PKo3Ph>1_lE5AD6oooo
o`Oo?3`l1onUYJD7ob4Q8@Oo^[Zj1omhN7P7of9RHPOo`/;21_lO7al5ooooo`Oo`/;21olC4a<7oi^K
V`OoP8201olc<c<7ooCdm0Oo=CDe1_mMGEd=ooooo`002oooool7odU9B@OoQ8B41om>CTh7obLW9`Oo
3@d=1olP8207o``<30Ko71`L1Oooool7oaHF5POoEEEE1olJ6QX7o`<30`OoP8201ol00007oa4A4@Ko
PX:21_ooool6og9bLPOoRHV91omkNg/7ok6a/@OoS8b<1onl_;`7ok6a/@KoYjNW1_ooool7olo?c`Oo
?clo1_lj>SX7oo?cl`Oo;2`/1omBDU87ogmoO`KoJf][1_ooool7ocLg=`Oo>CTi1ole=CD7od10@0Ko
=SHf1om]KFd7oeADE0KoQHF51_ooool7oa/K6`Oo3Ph>1ol820P>oa@D50Oo4Q8B1_l>3Ph6oaDE5@Ko
oooo1oll?3`7ojFUY@Oo8B4Q1onj^[X7ogQhN0OoHV9R1oo2`/86oalO7`Gooooo1oo2`/87oa<C4`Oo
Vi^K1on0P807oc<c<`Oom?Cd1ole=CD6oeeMG@gooooo000;ooooo`OoBDU91on4Q8@7odi>CPOo9bLW
1ol=3@d7ob0P80Oo30`<1_lL71`5ooooo`Oo5QHF1omEEED7oaXJ6POo0`<31on0P807o`0000Oo4A4A
1_n2PX86ooooo`KoLW9b1on9RHT7og]kN`Oo/K6a1on<S8`7okbl_0Oo/K6a1_nWYjL6ooooo`Ooclo?
1olo?cl6ocXj>POolo?c1ol/;2`7oe9BDPOoOgmo1_m[Jf/6ooooo`Oo=cLg1oli>CT7ocDe=@Oo@410
1_lf=SH7ofe]K@OoE5AD1_n5QHD6ooooo`Oo6a/K1ol>3Ph7o`P820ko51@D1olB4Q86o`h>3PKo5ADE
1_ooool7oc`l?0OoYJFU1olQ8B47okZj^POoN7Qh1omRHV87ol;2`PKo7alO1Oooool7ol;2`POo4a<C
1onKVi/7oh20P0Oo<c<c1oodm?@7ocDe=@KoGEeM3Oooool000_ooooo1om9BDT7ohB4Q0OoCTi>1olW
9bL7o`d=3@Oo820P1ol<30`6oa`L70Gooooo1olF5QH7oeEEE@Oo6QXJ1ol30`<7oh20P0Oo00001olA
4A46oh:2PPKooooo1_mbLW87ohV9R@OoNg]k1ona/K47ohb<S0Oo_;bl1ona/K46ojNWY`Kooooo1oo?
cll7oclo?`Ko>SXj1ooclo<7ob`/;0OoDU9B1omoOgl6of][J`Kooooo1olg=cL7ocTi>@Oo=CDe1om0
@406ocHf=POoKFe]1omDE5@6ohF5Q@Kooooo1olK6a/7o`h>3POo20P83_lD51@7oa8B4PKo3Ph>1_lE
5AD6ooooo`Oo?3`l1onUYJD7ob4Q8@Oo^[Zj1omhN7P7of9RHPOo`/;21_lO7al5ooooo`Oo`/;21olC
4a<7oi^KV`OoP8201olc<c<7ooCdm0Oo=CDe1_mMGEd=ooooo`002oooool7odU9B@OoQ8B41om>CTh7
obLW9`Oo3@d=1olP8207o``<30Ko71`L1Oooool7oaHF5POoEEEE1olJ6QX7o`<30`OoP8201ol00007
oa4A4@KoPX:21_ooool6og9bLPOoRHV91omkNg/7ok6a/@OoS8b<1onl_;`7ok6a/@KoYjNW1_ooool7
olo?c`Oo?clo1_lj>SX7oo?cl`Oo;2`/1omBDU87ogmoO`KoJf][1_ooool7ocLg=`Oo>CTi1ole=CD7
od10@0Ko=SHf1om]KFd7oeADE0KoQHF51_ooool7oa/K6`Oo3Ph>1ol820P>oa@D50Oo4Q8B1_l>3Ph6
oaDE5@Kooooo1oll?3`7ojFUY@Oo8B4Q1onj^[X7ogQhN0OoHV9R1oo2`/86oalO7`Gooooo1oo2`/87
oa<C4`OoVi^K1on0P807oc<c<`Oom?Cd1ole=CD6oeeMG@gooooo000;ooooo`OoBDU91on4Q8@7odi>
CPOo9bLW1ol=3@d7ob0P80Oo30`<1_lL71`5ooooo`Oo5QHF1omEEED7oaXJ6POo0`<31on0P807o`00
00Oo4A4A1_n2PX86ooooo`KoLW9b1on9RHT7og]kN`Oo/K6a1on<S8`7okbl_0Oo/K6a1_nWYjL6oooo
o`Ooclo?1olo?cl6ocXj>POolo?c1ol/;2`7oe9BDPOoOgmo1_m[Jf/6ooooo`Oo=cLg1oli>CT7ocDe
=@Oo@4101_lf=SH7ofe]K@OoE5AD1_n5QHD6ooooo`Oo6a/K1ol>3Ph7o`P820ko51@D1olB4Q86o`h>
3PKo5ADE1_ooool7oc`l?0OoYJFU1olQ8B47okZj^POoN7Qh1omRHV87ol;2`PKo7alO1Oooool7ol;2
`POo4a<C1onKVi/7oh20P0Oo<c<c1oodm?@7ocDe=@KoGEeM3Oooool000_ooooo1onBTY87on7Qh@Oo
;bl_1olS8b<7o`T92@Oo:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo
3Ph>1omLG5`6o`<30`Kooooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Ko
oooo1ooBd]87obTY:@KoP8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko
>CTi1_m4A4@7oe1@D0OoAdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko
5aLG1_ooool7ojRXZ0Oo6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo
1@D51oo5aLD7ocXj>POo<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_
1olS8b<7o`T92@Oo:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>
1omLG5`6o`<30`Kooooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo
1ooBd]87obTY:@KoP8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi
1_m4A4@7oe1@D0OoAdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG
1_ooool7ojRXZ0Oo6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D5
1oo5aLD7ocXj>POo<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_1olS
8b<7o`T92@Oo:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>1omL
G5`6o`<30`Kooooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo1ooB
d]87obTY:@KoP8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi1_m4
A4@7oe1@D0OoAdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG1_oo
ool7ojRXZ0Oo6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D51oo5
aLD7ocXj>POo<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_1olS8b<7
o`T92@Oo:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>1omLG5`6
o`<30`Kooooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo1ooBd]87
obTY:@KoP8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi1_m4A4@7
oe1@D0OoAdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG1_ooool7
ojRXZ0Oo6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D51oo5aLD7
ocXj>POo<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_1olS8b<7o`T9
2@Oo:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>1omLG5`6o`<3
0`Kooooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo1ooBd]87obTY
:@KoP8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi1_m4A4@7oe1@
D0OoAdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG1_ooool7ojRX
Z0Oo6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D51oo5aLD7ocXj
>POo<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_1olS8b<7o`T92@Oo
:BTY1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>1omLG5`6o`<30`Ko
oooo1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo1ooBd]87obTY:@Ko
P8201onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi1_m4A4@7oe1@D0Oo
AdM71_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG1_ooool7ojRXZ0Oo
6QXJ1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D51oo5aLD7ocXj>POo
<c<c1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1onBTY87on7Qh@Oo;bl_1olS8b<7o`T92@Oo:BTY
1olC4a<6o`l?3`Gooooo1olY:BT7oi>CT`Oo6QXJ1olf=SH7obLW9`Oo3Ph>1omLG5`6o`<30`Kooooo
1_nGUiL7ok^k^`Ooe]KF1oooool7on[ZjPOon?Sh1ooinOT6om3@d0Kooooo1ooBd]87obTY:@KoP820
1onMWId7oa<C4`Oooooo1ole=CD6ob@T90Kooooo1olj>SX7oc`l?0ko>CTi1_m4A4@7oe1@D0OoAdM7
1_mHF5P6ooooo`Oo3`l?3_l00007o`T92@Oo410@1olF5QH6obDU9@Ko5aLG1_ooool7ojRXZ0Oo6QXJ
1olA4A47on[ZjPOo5ADE1omSHf<7om[JfPKo61PH1Oooool7ocTi>@Oo1@D51oo5aLD7ocXj>POo<c<c
1oo2`/87oaDE5@Kof=SH3Oooool000_ooooo1om>CTh7olc<c0OoCdm?1olc<c<7oa@D50Oo9bLW1ol>
3Ph6oa<C4`Gooooo1on_[jl7ocLg=`Oo71`L1onYZJT7obh^;POo7AdM1omCDe<6oaLG5`Kooooo1_m`
L707ok2`/0Oo_[jn1oo5aLD7okRh^0Oo`l?31ooBd]86oj:RXPKooooo1omBDU87obl_;`KoUYJF1omj
NWX7o`X:2POo];Bd1om@D506oi6AT@Kooooo1olX:2P7odY:BPOo8b<S1ol^;Rh6ob@T90Oo<c<c1olk
>c/6ochn?PKooooo1ol>3Ph7oa@D50Oo3Ph>1ol92@T7o`l?3`Oo5QHF3?lJ6QX6ooooo`OoDe=C1om7
AdL7oeYJFPOo:RXZ1olb<S87ok2`/0Oo?Shn1_lG5aL5ooooo`OoLG5a1ol];Bd7oe1@D0OoIVIV1ome
MGD7ofMWI`Oo5aLG1_nTY:@=ooooo`002oooool7odi>CPOoc<c<1om?Cdl7oc<c<`Oo51@D1olW9bL7
o`h>3PKo4a<C1Oooool7ojn_[`Oo=cLg1olL71`7ojVYZ@Oo;Rh^1olM7Ad7oe=CD`Ko5aLG1_ooool6
og1`L0Oo/;2`1onn_[h7olG5a@Oo^;Rh1oo3`l<7om;BdPKoXZ:R1_ooool7oe9BDPOo;bl_1_nFUYH7
ogYjNPOo2PX:1ond];@7oe1@D0KoTI6A1_ooool7obPX:0OoBTY:1olS8b<7obh^;PKo92@T1olc<c<7
oc/k>`Ko?Shn1_ooool7o`h>3POo51@D1ol>3Ph7o`T92@Oo3`l?1olF5QH<oaXJ6PKooooo1omCDe<7
odM7A`OoFUYJ1olZ:RX7oc8b<POo/;2`1oln?Sh6oaLG5`Gooooo1omaLG47obd];@OoD51@1omVIVH7
ogEeM@OoIfMW1olG5aL6ojBTY0gooooo000;ooooo`OoCTi>1oo<c<`7odm?C`Oo<c<c1olD51@7obLW
9`Oo3Ph>1_lC4a<5ooooo`Oo[jn_1olg=cL7oa`L70OoZJVY1ol^;Rh7oadM7@OoDe=C1_lG5aL6oooo
o`KoL71`1on`/;07okjn_POoaLG51onh^;P7ol?3``Ood];B1_nRXZ86ooooo`OoDU9B1ol_;bl6oiJF
UPOoNWYj1ol:2PX7okBd]0OoD51@1_nATI46ooooo`Oo:2PX1om:BTX7ob<S8`Oo;Rh^1_lT92@7oc<c
<`Oo>c/k1_ln?Sh6ooooo`Oo3Ph>1olD51@7o`h>3POo2@T91ol?3`l7oaHF5Pco6QXJ1_ooool7oe=C
D`OoAdM71omJFUX7obXZ:POo<S8b1on`/;07ochn?PKo5aLG1Oooool7og5aL@Oo;Bd]1om@D507ofIV
IPOoMGEe1omWIfL7oaLG5`KoY:BT3Oooool000_ooooo1om>CTh7olc<c0OoCdm?1olc<c<7oa@D50Oo
9bLW1ol>3Ph6oa<C4`Gooooo1on_[jl7ocLg=`Oo71`L1onYZJT7obh^;POo7AdM1omCDe<6oaLG5`Ko
oooo1_m`L707ok2`/0Oo_[jn1oo5aLD7okRh^0Oo`l?31ooBd]86oj:RXPKooooo1omBDU87obl_;`Ko
UYJF1omjNWX7o`X:2POo];Bd1om@D506oi6AT@Kooooo1olX:2P7odY:BPOo8b<S1ol^;Rh6ob@T90Oo
<c<c1olk>c/6ochn?PKooooo1ol>3Ph7oa@D50Oo3Ph>1ol92@T7o`l?3`Oo5QHF3?lJ6QX6ooooo`Oo
De=C1om7AdL7oeYJFPOo:RXZ1olb<S87ok2`/0Oo?Shn1_lG5aL5ooooo`OoLG5a1ol];Bd7oe1@D0Oo
IVIV1omeMGD7ofMWI`Oo5aLG1_nTY:@=ooooo`002oooool7odi>CPOoc<c<1om?Cdl7oc<c<`Oo51@D
1olW9bL7o`h>3PKo4a<C1Oooool7ojn_[`Oo=cLg1olL71`7ojVYZ@Oo;Rh^1olM7Ad7oe=CD`Ko5aLG
1_ooool6og1`L0Oo/;2`1onn_[h7olG5a@Oo^;Rh1oo3`l<7om;BdPKoXZ:R1_ooool7oe9BDPOo;bl_
1_nFUYH7ogYjNPOo2PX:1ond];@7oe1@D0KoTI6A1_ooool7obPX:0OoBTY:1olS8b<7obh^;PKo92@T
1olc<c<7oc/k>`Ko?Shn1_ooool7o`h>3POo51@D1ol>3Ph7o`T92@Oo3`l?1olF5QH<oaXJ6PKooooo
1omCDe<7odM7A`OoFUYJ1olZ:RX7oc8b<POo/;2`1oln?Sh6oaLG5`Gooooo1omaLG47obd];@OoD51@
1omVIVH7ogEeM@OoIfMW1olG5aL6ojBTY0gooooo000;ooooo`OoCTi>1oo<c<`7odm?C`Oo<c<c1olD
51@7obLW9`Oo3Ph>1_lC4a<5ooooo`Oo[jn_1olg=cL7oa`L70OoZJVY1ol^;Rh7oadM7@OoDe=C1_lG
5aL6ooooo`KoL71`1on`/;07okjn_POoaLG51onh^;P7ol?3``Ood];B1_nRXZ86ooooo`OoDU9B1ol_
;bl6oiJFUPOoNWYj1ol:2PX7okBd]0OoD51@1_nATI46ooooo`Oo:2PX1om:BTX7ob<S8`Oo;Rh^1_lT
92@7oc<c<`Oo>c/k1_ln?Sh6ooooo`Oo3Ph>1olD51@7o`h>3POo2@T91ol?3`l7oaHF5Pco6QXJ1_oo
ool7oe=CD`OoAdM71omJFUX7obXZ:POo<S8b1on`/;07ochn?PKo5aLG1Oooool7og5aL@Oo;Bd]1om@
D507ofIVIPOoMGEe1omWIfL7oaLG5`KoY:BT3Oooool000_ooooo1omQHF47ol;2`POo9RHV1olo?cl7
oa8B4POo820P1olF5QH6ob<S8`Gooooo1onVYZH7obh^;POoMWIf1omYJFT7og9bLPOoCDe=1om;Bd/6
ogUiN@Kooooo1_nc/k<7okFe]@OoHF5Q1omiNGT7ohJ6QPOo[jn_1on7QhL6omCDe0Kooooo1ol30`<7
obTY:@KoFe]K1ol00007ocTi>@OoP8201ol?3`l6oaHF5PKooooo1om[Jf/7ode=C@OoDE5A1om4A4@6
oeYJFPOoJf][1omNGUh6oeeMG@Kooooo1omfMWH7ocXj>POoC4a<1omNGUh7onSXj0Oooooo1_m=CDd6
odm?C`Kooooo1olP8207odI6APOo2`/;1ol=3@d7ocPh>0Oo?Cdm1ol00006oc8b<PGooooo1olO7al7
o`h>3POo3@d=1ol_;bl7oc0`<0Oo00001oll?3`6oeUIF@gooooo000;ooooo`OoHF5Q1oo2`/87obHV
9POo?clo1olB4Q87ob0P80Oo5QHF1_lS8b<5ooooo`OoYZJV1ol^;Rh7ogIfMPOoJFUY1ombLW87ode=
C@OoBd];1_miNGT6ooooo`Ko/k>c1one]KD7of5QH@OoNGUi1on6QXH7ojn_[`OoQhN71_oDe=@6oooo
o`Oo0`<31olY:BT6oe]KF`Oo00001oli>CT7oh20P0Oo3`l?1_lF5QH6ooooo`OoJf][1om=CDd7oe5A
D@OoA4A41_mJFUX7of][J`OoGUiN1_mMGEd6ooooo`OoMWIf1olj>SX7oda<C0OoGUiN1ooXj>P7oooo
o`KoCDe=1_m?Cdl6ooooo`Oo820P1om6ATH7o`/;2`Oo3@d=1olh>3P7ocdm?@Oo00001_lb<S85oooo
o`Oo7alO1ol>3Ph7o`d=3@Oo;bl_1ol`<307o`0000Oo?3`l1_mIFET=ooooo`002oooool7of5QH@Oo
`/;21olV9RH7oclo?`Oo4Q8B1olP8207oaHF5PKo8b<S1Oooool7ojJVYPOo;Rh^1omfMWH7ofUYJ@Oo
LW9b1om=CDd7od];B`KoNGUi1_ooool6ok>c/`Oo]KFe1omQHF47ogUiN@OoQXJ61on_[jl7ohN7Q`Ko
e=CD1_ooool7o`<30`Oo:BTY1_mKFe/7o`0000Oo>CTi1on0P807o`l?3`Ko5QHF1_ooool7of][J`Oo
CDe=1omADE47odA4A0KoFUYJ1om[Jf/7oeiNGPKoGEeM1_ooool7ogIfMPOo>SXj1om<C4`7oeiNGPOo
j>SX1oooool6ode=C@KoCdm?1_ooool7ob0P80OoATI61ol;2`/7o`d=3@Oo>3Ph1olm?Cd7o`0000Ko
<S8b1Oooool7oalO7`Oo3Ph>1ol=3@d7obl_;`Oo<30`1ol00007oc`l?0KoFEUI3Oooool000_ooooo
1omQHF47ol;2`POo9RHV1olo?cl7oa8B4POo820P1olF5QH6ob<S8`Gooooo1onVYZH7obh^;POoMWIf
1omYJFT7og9bLPOoCDe=1om;Bd/6ogUiN@Kooooo1_nc/k<7okFe]@OoHF5Q1omiNGT7ohJ6QPOo[jn_
1on7QhL6omCDe0Kooooo1ol30`<7obTY:@KoFe]K1ol00007ocTi>@OoP8201ol?3`l6oaHF5PKooooo
1om[Jf/7ode=C@OoDE5A1om4A4@6oeYJFPOoJf][1omNGUh6oeeMG@Kooooo1omfMWH7ocXj>POoC4a<
1omNGUh7onSXj0Oooooo1_m=CDd6odm?C`Kooooo1olP8207odI6APOo2`/;1ol=3@d7ocPh>0Oo?Cdm
1ol00006oc8b<PGooooo1olO7al7o`h>3POo3@d=1ol_;bl7oc0`<0Oo00001oll?3`6oeUIF@gooooo
000;ooooo`OoHF5Q1oo2`/87obHV9POo?clo1olB4Q87ob0P80Oo5QHF1_lS8b<5ooooo`OoYZJV1ol^
;Rh7ogIfMPOoJFUY1ombLW87ode=C@OoBd];1_miNGT6ooooo`Ko/k>c1one]KD7of5QH@OoNGUi1on6
QXH7ojn_[`OoQhN71_oDe=@6ooooo`Oo0`<31olY:BT6oe]KF`Oo00001oli>CT7oh20P0Oo3`l?1_lF
5QH6ooooo`OoJf][1om=CDd7oe5AD@OoA4A41_mJFUX7of][J`OoGUiN1_mMGEd6ooooo`OoMWIf1olj
>SX7oda<C0OoGUiN1ooXj>P7ooooo`KoCDe=1_m?Cdl6ooooo`Oo820P1om6ATH7o`/;2`Oo3@d=1olh
>3P7ocdm?@Oo00001_lb<S85ooooo`Oo7alO1ol>3Ph7o`d=3@Oo;bl_1ol`<307o`0000Oo?3`l1_mI
FET=ooooo`002oooool7of5QH@Oo`/;21olV9RH7oclo?`Oo4Q8B1olP8207oaHF5PKo8b<S1Oooool7
ojJVYPOo;Rh^1omfMWH7ofUYJ@OoLW9b1om=CDd7od];B`KoNGUi1_ooool6ok>c/`Oo]KFe1omQHF47
ogUiN@OoQXJ61on_[jl7ohN7Q`Koe=CD1_ooool7o`<30`Oo:BTY1_mKFe/7o`0000Oo>CTi1on0P807
o`l?3`Ko5QHF1_ooool7of][J`OoCDe=1omADE47odA4A0KoFUYJ1om[Jf/7oeiNGPKoGEeM1_ooool7
ogIfMPOo>SXj1om<C4`7oeiNGPOoj>SX1oooool6ode=C@KoCdm?1_ooool7ob0P80OoATI61ol;2`/7
o`d=3@Oo>3Ph1olm?Cd7o`0000Ko<S8b1Oooool7oalO7`Oo3Ph>1ol=3@d7obl_;`Oo<30`1ol00007
oc`l?0KoFEUI3Oooool000_ooooo1omQHF47ol;2`POo9RHV1olo?cl7oa8B4POo820P1olF5QH6ob<S
8`Gooooo1onVYZH7obh^;POoMWIf1omYJFT7og9bLPOoCDe=1om;Bd/6ogUiN@Kooooo1_nc/k<7okFe
]@OoHF5Q1omiNGT7ohJ6QPOo[jn_1on7QhL6omCDe0Kooooo1ol30`<7obTY:@KoFe]K1ol00007ocTi
>@OoP8201ol?3`l6oaHF5PKooooo1om[Jf/7ode=C@OoDE5A1om4A4@6oeYJFPOoJf][1omNGUh6oeeM
G@Kooooo1omfMWH7ocXj>POoC4a<1omNGUh7onSXj0Oooooo1_m=CDd6odm?C`Kooooo1olP8207odI6
APOo2`/;1ol=3@d7ocPh>0Oo?Cdm1ol00006oc8b<PGooooo1olO7al7o`h>3POo3@d=1ol_;bl7oc0`
<0Oo00001oll?3`6oeUIF@gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`Oo7QhN1om;
Bd/7of1PH0Oo7AdM1om>CTh7oaHF5POo3`l?1_lF5QH5ooooo`OoLW9b1on8R8P7oe1@D0OoI6AT1oli
>CT7oeaLG0OoC4a<1_lg=cL6ooooo`Ko820P1ol>3Ph7ofATI0Oo3@d=1olI6AT7oemOG`Oo7QhN1_l0
0006ooooo`Oo9RHV1ooNg]h6ocDe=@OoW9bL1onc/k<7oa8B4POooooo1_l?3`l6ooooo`Oo7AdM1olZ
:RX7odE5A@Oo;Rh^1_m9BDT7oiFEU@Oo>c/k1_lM7Ad6ooooo`Oo=3@d1olh>3P7ocLg=`OoATI61olg
=cL7obl_;`Ko8b<S1_lZ:RX6ooooo`Oo51@D1olV9RH7ofIVIPOo7alO1olj>SX7od=3@`Oo7AdM1_lN
7Qh5ooooo`OoalO71olK6a/7oi2@T0OobLW91om;Bd/7oh20P0OoL71`1_oGemL=ooooo`002oooool7
oahN7POoBd];1omPH607oadM7@OoCTi>1olF5QH7o`l?3`Ko5QHF1Oooool7og9bLPOoR8R81om@D507
ofATI0Oo>CTi1omLG5`7oda<C0Ko=cLg1_ooool6ob0P80Oo3Ph>1omTI6@7o`d=3@Oo6ATI1omOGel7
oahN7PKo00001_ooool7obHV9POog]kN1_le=CD7oibLW0Oo/k>c1olB4Q87ooooo`Ko3`l?1_ooool7
oadM7@Oo:RXZ1om5ADD7obh^;PKoBDU91onEUID7oc/k>`Ko7AdM1_ooool7oc@d=0Oo>3Ph1olg=cL7
odI6APOo=cLg1ol_;bl6ob<S8`Ko:RXZ1_ooool7oa@D50Oo9RHV1omVIVH7oalO7`Oo>SXj1om3@d<7
oadM7@Ko7QhN1Oooool7olO7a`Oo6a/K1on@T907olW9b@OoBd];1on0P807og1`L0KoemOG3Oooool0
00_ooooo1olN7Qh7od];B`OoH61P1olM7Ad7odi>CPOo5QHF1ol?3`l6oaHF5PGooooo1ombLW87ohR8
R0OoD51@1omTI6@7ocTi>@OoG5aL1om<C4`6ocLg=`Kooooo1_lP8207o`h>3POoI6AT1ol=3@d7oaTI
6@OoGemO1olN7Qh6o`0000Kooooo1olV9RH7omkNgPKo=CDe1onLW9`7ok>c/`Oo4Q8B1oooool6o`l?
3`Kooooo1olM7Ad7obXZ:POoADE51ol^;Rh6odU9B@OoUIFE1olk>c/6oadM7@Kooooo1old=3@7ocPh
>0Oo=cLg1om6ATH7ocLg=`Oo;bl_1_lS8b<6obXZ:PKooooo1olD51@7obHV9POoIVIV1olO7al7ocXj
>POo@d=31olM7Ad6oahN7PGooooo1oo7alL7oa/K6`OoT92@1oo9bLT7od];B`OoP8201om`L706omOG
e`gooooo000;ooooo`Oo7QhN1om;Bd/7of1PH0Oo7AdM1om>CTh7oaHF5POo3`l?1_lF5QH5ooooo`Oo
LW9b1on8R8P7oe1@D0OoI6AT1oli>CT7oeaLG0OoC4a<1_lg=cL6ooooo`Ko820P1ol>3Ph7ofATI0Oo
3@d=1olI6AT7oemOG`Oo7QhN1_l00006ooooo`Oo9RHV1ooNg]h6ocDe=@OoW9bL1onc/k<7oa8B4POo
oooo1_l?3`l6ooooo`Oo7AdM1olZ:RX7odE5A@Oo;Rh^1_m9BDT7oiFEU@Oo>c/k1_lM7Ad6ooooo`Oo
=3@d1olh>3P7ocLg=`OoATI61olg=cL7obl_;`Ko8b<S1_lZ:RX6ooooo`Oo51@D1olV9RH7ofIVIPOo
7alO1olj>SX7od=3@`Oo7AdM1_lN7Qh5ooooo`OoalO71olK6a/7oi2@T0OobLW91om;Bd/7oh20P0Oo
L71`1_oGemL=ooooo`002oooool7oahN7POoBd];1omPH607oadM7@OoCTi>1olF5QH7o`l?3`Ko5QHF
1Oooool7og9bLPOoR8R81om@D507ofATI0Oo>CTi1omLG5`7oda<C0Ko=cLg1_ooool6ob0P80Oo3Ph>
1omTI6@7o`d=3@Oo6ATI1omOGel7oahN7PKo00001_ooool7obHV9POog]kN1_le=CD7oibLW0Oo/k>c
1olB4Q87ooooo`Ko3`l?1_ooool7oadM7@Oo:RXZ1om5ADD7obh^;PKoBDU91onEUID7oc/k>`Ko7AdM
1_ooool7oc@d=0Oo>3Ph1olg=cL7odI6APOo=cLg1ol_;bl6ob<S8`Ko:RXZ1_ooool7oa@D50Oo9RHV
1omVIVH7oalO7`Oo>SXj1om3@d<7oadM7@Ko7QhN1Oooool7olO7a`Oo6a/K1on@T907olW9b@OoBd];
1on0P807og1`L0KoemOG3Oooool000_ooooo1olN7Qh7od];B`OoH61P1olM7Ad7odi>CPOo5QHF1ol?
3`l6oaHF5PGooooo1ombLW87ohR8R0OoD51@1omTI6@7ocTi>@OoG5aL1om<C4`6ocLg=`Kooooo1_lP
8207o`h>3POoI6AT1ol=3@d7oaTI6@OoGemO1olN7Qh6o`0000Kooooo1olV9RH7omkNgPKo=CDe1onL
W9`7ok>c/`Oo4Q8B1oooool6o`l?3`Kooooo1olM7Ad7obXZ:POoADE51ol^;Rh6odU9B@OoUIFE1olk
>c/6oadM7@Kooooo1old=3@7ocPh>0Oo=cLg1om6ATH7ocLg=`Oo;bl_1_lS8b<6obXZ:PKooooo1olD
51@7obHV9POoIVIV1olO7al7ocXj>POo@d=31olM7Ad6oahN7PGooooo1oo7alL7oa/K6`OoT92@1oo9
bLT7od];B`OoP8201om`L706omOGe`gooooo000;ooooo`OoB4Q81olE5AD7oeEEE@OoEUIF1ol<30`7
obd];@Oo8b<S1_l:2PX<ooooo`OoZJVY1omQHF47oeADE0Oo<S8b1ola<C47ocDe=@Ko9RHV1_ooool6
oahN7POo6QXJ1old=3@7obh^;POo:RXZ1olh>3P7oc8b<PKo8b<S1_ooool7ofUYJ@OoHF5Q1_li>CT7
olk>cPOoS8b<1olE5AD7om;BdPKo4Q8B1_ooool>ob4Q8@Oo?Cdm1om5ADD6oiVIV@OoMWIf1ol@4106
ocHf=PKooooo1ol/;2`7obPX:0ko<c<c1ola<C47ob4Q8@Ko5aLG1_lY:BT6ooooo`Oo<30`1ooIfMT7
ob/[:`Oo2PX:1on8R8P7obLW9`Oo4A4A1_lY:BT5ooooo`Ooj>SX1ol?3`l7ojJVYPOoX:2P1olR8R87
ooooo`Oo<C4a1_maLG4=ooooo`002oooool7odQ8B0Oo5ADE1omEEED7oeIFEPOo30`<1ol];Bd7ob<S
8`Ko2PX:3?ooool7ojVYZ@OoHF5Q1omDE5@7oc8b<POo<C4a1ole=CD6obHV9PKooooo1_lN7Qh7oaXJ
6POo=3@d1ol^;Rh7obXZ:POo>3Ph1olb<S86ob<S8`Kooooo1omYJFT7of5QH@Ko>CTi1oo>c/h7ohb<
S0Oo5ADE1ooBd]86oa8B4PKooooo3_lQ8B47ocdm?@OoADE51_nIVIT7ogIfMPOo410@1_lf=SH6oooo
o`Oo;2`/1olX:2P>oc<c<`Oo<C4a1olQ8B46oaLG5`Ko:BTY1_ooool7oc0`<0OofMWI1ol[:b/7o`X:
2POoR8R81olW9bL7oa4A4@Ko:BTY1Oooool7onSXj0Oo3`l?1onVYZH7oj2PX0Oo8R8R1oooool7oc4a
<@KoLG5a3Oooool000_ooooo1om8B4P7oaDE5@OoEEEE1omFEUH7o``<30Oo;Bd]1olS8b<6o`X:2Pco
oooo1onYZJT7of5QH@OoE5AD1olb<S87oc4a<@Oo=CDe1_lV9RH6ooooo`Ko7QhN1olJ6QX7oc@d=0Oo
;Rh^1olZ:RX7ocPh>0Oo<S8b1_lS8b<6ooooo`OoJFUY1omQHF46ocTi>@Ooc/k>1on<S8`7oaDE5@Oo
d];B1_lB4Q86ooooo`ko8B4Q1olm?Cd7odE5A@KoVIVI1omfMWH7oa0@40Ko=SHf1_ooool7ob`/;0Oo
:2PX3_lc<c<7oc4a<@Oo8B4Q1_lG5aL6obTY:@Kooooo1ol`<307omWIf@Oo:b/[1ol:2PX7ohR8R0Oo
9bLW1olA4A46obTY:@Gooooo1ooXj>P7o`l?3`OoYZJV1onPX:07ob8R8POooooo1ola<C46og5aL@go
oooo000;ooooo`OoB4Q81olE5AD7oeEEE@OoEUIF1ol<30`7obd];@Oo8b<S1_l:2PX<ooooo`OoZJVY
1omQHF47oeADE0Oo<S8b1ola<C47ocDe=@Ko9RHV1_ooool6oahN7POo6QXJ1old=3@7obh^;POo:RXZ
1olh>3P7oc8b<PKo8b<S1_ooool7ofUYJ@OoHF5Q1_li>CT7olk>cPOoS8b<1olE5AD7om;BdPKo4Q8B
1_ooool>ob4Q8@Oo?Cdm1om5ADD6oiVIV@OoMWIf1ol@4106ocHf=PKooooo1ol/;2`7obPX:0ko<c<c
1ola<C47ob4Q8@Ko5aLG1_lY:BT6ooooo`Oo<30`1ooIfMT7ob/[:`Oo2PX:1on8R8P7obLW9`Oo4A4A
1_lY:BT5ooooo`Ooj>SX1ol?3`l7ojJVYPOoX:2P1olR8R87ooooo`Oo<C4a1_maLG4=ooooo`002ooo
ool7odQ8B0Oo5ADE1omEEED7oeIFEPOo30`<1ol];Bd7ob<S8`Ko2PX:3?ooool7ojVYZ@OoHF5Q1omD
E5@7oc8b<POo<C4a1ole=CD6obHV9PKooooo1_lN7Qh7oaXJ6POo=3@d1ol^;Rh7obXZ:POo>3Ph1olb
<S86ob<S8`Kooooo1omYJFT7of5QH@Ko>CTi1oo>c/h7ohb<S0Oo5ADE1ooBd]86oa8B4PKooooo3_lQ
8B47ocdm?@OoADE51_nIVIT7ogIfMPOo410@1_lf=SH6ooooo`Oo;2`/1olX:2P>oc<c<`Oo<C4a1olQ
8B46oaLG5`Ko:BTY1_ooool7oc0`<0OofMWI1ol[:b/7o`X:2POoR8R81olW9bL7oa4A4@Ko:BTY1Ooo
ool7onSXj0Oo3`l?1onVYZH7oj2PX0Oo8R8R1oooool7oc4a<@KoLG5a3Oooool000_ooooo1om8B4P7
oaDE5@OoEEEE1omFEUH7o``<30Oo;Bd]1olS8b<6o`X:2Pcooooo1onYZJT7of5QH@OoE5AD1olb<S87
oc4a<@Oo=CDe1_lV9RH6ooooo`Ko7QhN1olJ6QX7oc@d=0Oo;Rh^1olZ:RX7ocPh>0Oo<S8b1_lS8b<6
ooooo`OoJFUY1omQHF46ocTi>@Ooc/k>1on<S8`7oaDE5@Ood];B1_lB4Q86ooooo`ko8B4Q1olm?Cd7
odE5A@KoVIVI1omfMWH7oa0@40Ko=SHf1_ooool7ob`/;0Oo:2PX3_lc<c<7oc4a<@Oo8B4Q1_lG5aL6
obTY:@Kooooo1ol`<307omWIf@Oo:b/[1ol:2PX7ohR8R0Oo9bLW1olA4A46obTY:@Gooooo1ooXj>P7
o`l?3`OoYZJV1onPX:07ob8R8POooooo1ola<C46og5aL@gooooo000;ooooo`OoB4Q81olE5AD7oeEE
E@OoEUIF1ol<30`7obd];@Oo8b<S1_l:2PX<ooooo`OoZJVY1omQHF47oeADE0Oo<S8b1ola<C47ocDe
=@Ko9RHV1_ooool6oahN7POo6QXJ1old=3@7obh^;POo:RXZ1olh>3P7oc8b<PKo8b<S1_ooool7ofUY
J@OoHF5Q1_li>CT7olk>cPOoS8b<1olE5AD7om;BdPKo4Q8B1_ooool>ob4Q8@Oo?Cdm1om5ADD6oiVI
V@OoMWIf1ol@4106ocHf=PKooooo1ol/;2`7obPX:0ko<c<c1ola<C47ob4Q8@Ko5aLG1_lY:BT6oooo
o`Oo<30`1ooIfMT7ob/[:`Oo2PX:1on8R8P7obLW9`Oo4A4A1_lY:BT5ooooo`Ooj>SX1ol?3`l7ojJV
YPOoX:2P1olR8R87ooooo`Oo<C4a1_maLG4=ooooo`002oooool7oaLG5`OoLG5a1om_Kfl7o`L71`Oo
?Cdm1omEEED7o`820PKo3@d=1Oooool7ogEeM@OoF5QH3_l/;2`7o``<30Oo7AdM1ol51@D6o``<30Ko
oooo1_lF5QH7oeiNGPOo<C4a1ol@4107obTY:@OoIFEU1olJ6QX6oaPH60Kooooo1olZ:RX7ojZZZPKo
5QHF1omLG5`7okJf]POo>c/k1onEUID6obPX:0Kooooo1olO7al7o`h>3POoBTY:1olO7al6oeEEE@Oo
Fe]K1olW9bL6oalO7`Kooooo1olH61P7ocLg=`Oo;Bd]1om=CDd7odM7A`OoEEEE1_ll?3`6obPX:0Ko
oooo1ol/;2`7oeeMG@OoPX:21omQHF47oemOG`Oo=SHf1omVIVH6o`@410Gooooo1old=3@7obPX:0Oo
g=cL1omIFET7oaDE5@Ooc/k>1olC4a<6okBd]0gooooo000;ooooo`Oo5aLG1omaLG47ofm_K`Oo1`L7
1olm?Cd7oeEEE@Oo0P821_l=3@d5ooooo`OoMGEe1omHF5P>ob`/;0Oo30`<1olM7Ad7o`D51@Ko30`<
1_ooool6oaHF5POoGUiN1ola<C47oa0@40Oo:BTY1omUIFD7oaXJ6PKo61PH1_ooool7obXZ:POoZZZZ
1_lF5QH7oeaLG0Oo][Jf1olk>c/7oiFEU@Ko:2PX1_ooool7oalO7`Oo3Ph>1om:BTX7oalO7`KoEEEE
1omKFe/7obLW9`Ko7alO1_ooool7oaPH60Oo=cLg1ol];Bd7ode=C@OoAdM71omEEED6oc`l?0Ko:2PX
1_ooool7ob`/;0OoGEeM1on2PX87of5QH@OoGemO1olf=SH7ofIVIPKo10@41Oooool7oc@d=0Oo:2PX
1ooLg=`7oeUIF@Oo5ADE1oo>c/h7oa<C4`Ko];Bd3Oooool000_ooooo1olG5aL7og5aL@OoKfm_1ol7
1`L7ocdm?@OoEEEE1ol20P86o`d=3@Gooooo1omeMGD7oeQHF0ko;2`/1ol<30`7oadM7@Oo1@D51_l<
30`6ooooo`Ko5QHF1omNGUh7oc4a<@Oo410@1olY:BT7ofEUI@Oo6QXJ1_lH61P6ooooo`Oo:RXZ1onZ
ZZX6oaHF5POoG5aL1onf][H7oc/k>`OoUIFE1_lX:2P6ooooo`Oo7alO1ol>3Ph7odY:BPOo7alO1_mE
EED7oe]KF`Oo9bLW1_lO7al6ooooo`Oo61PH1olg=cL7obd];@OoCDe=1om7AdL7oeEEE@Ko?3`l1_lX
:2P6ooooo`Oo;2`/1omMGEd7oh:2PPOoHF5Q1omOGel7ocHf=POoIVIV1_l410@5ooooo`Oo=3@d1olX
:2P7omcLg0OoFEUI1olE5AD7olk>cPOo4a<C1_nd];@=ooooo`002oooool7oaLG5`OoLG5a1om_Kfl7
o`L71`Oo?Cdm1omEEED7o`820PKo3@d=1Oooool7ogEeM@OoF5QH3_l/;2`7o``<30Oo7AdM1ol51@D6
o``<30Kooooo1_lF5QH7oeiNGPOo<C4a1ol@4107obTY:@OoIFEU1olJ6QX6oaPH60Kooooo1olZ:RX7
ojZZZPKo5QHF1omLG5`7okJf]POo>c/k1onEUID6obPX:0Kooooo1olO7al7o`h>3POoBTY:1olO7al6
oeEEE@OoFe]K1olW9bL6oalO7`Kooooo1olH61P7ocLg=`Oo;Bd]1om=CDd7odM7A`OoEEEE1_ll?3`6
obPX:0Kooooo1ol/;2`7oeeMG@OoPX:21omQHF47oemOG`Oo=SHf1omVIVH6o`@410Gooooo1old=3@7
obPX:0Oog=cL1omIFET7oaDE5@Ooc/k>1olC4a<6okBd]0gooooo000;ooooo`Oo5aLG1omaLG47ofm_
K`Oo1`L71olm?Cd7oeEEE@Oo0P821_l=3@d5ooooo`OoMGEe1omHF5P>ob`/;0Oo30`<1olM7Ad7o`D5
1@Ko30`<1_ooool6oaHF5POoGUiN1ola<C47oa0@40Oo:BTY1omUIFD7oaXJ6PKo61PH1_ooool7obXZ
:POoZZZZ1_lF5QH7oeaLG0Oo][Jf1olk>c/7oiFEU@Ko:2PX1_ooool7oalO7`Oo3Ph>1om:BTX7oalO
7`KoEEEE1omKFe/7obLW9`Ko7alO1_ooool7oaPH60Oo=cLg1ol];Bd7ode=C@OoAdM71omEEED6oc`l
?0Ko:2PX1_ooool7ob`/;0OoGEeM1on2PX87of5QH@OoGemO1olf=SH7ofIVIPKo10@41Oooool7oc@d
=0Oo:2PX1ooLg=`7oeUIF@Oo5ADE1oo>c/h7oa<C4`Ko];Bd3Oooool000_ooooo1olG5aL7og5aL@Oo
Kfm_1ol71`L7ocdm?@OoEEEE1ol20P86o`d=3@Gooooo1omeMGD7oeQHF0ko;2`/1ol<30`7oadM7@Oo
1@D51_l<30`6ooooo`Ko5QHF1omNGUh7oc4a<@Oo410@1olY:BT7ofEUI@Oo6QXJ1_lH61P6ooooo`Oo
:RXZ1onZZZX6oaHF5POoG5aL1onf][H7oc/k>`OoUIFE1_lX:2P6ooooo`Oo7alO1ol>3Ph7odY:BPOo
7alO1_mEEED7oe]KF`Oo9bLW1_lO7al6ooooo`Oo61PH1olg=cL7obd];@OoCDe=1om7AdL7oeEEE@Ko
?3`l1_lX:2P6ooooo`Oo;2`/1omMGEd7oh:2PPOoHF5Q1omOGel7ocHf=POoIVIV1_l410@5ooooo`Oo
=3@d1olX:2P7omcLg0OoFEUI1olE5AD7olk>cPOo4a<C1_nd];@=ooooo`002oooool7oaLG5`OoLG5a
1om_Kfl7o`L71`Oo?Cdm1omEEED7o`820PKo3@d=1Oooool7ogEeM@OoF5QH3_l/;2`7o``<30Oo7AdM
1ol51@D6o``<30Kooooo1_lF5QH7oeiNGPOo<C4a1ol@4107obTY:@OoIFEU1olJ6QX6oaPH60Kooooo
1olZ:RX7ojZZZPKo5QHF1omLG5`7okJf]POo>c/k1onEUID6obPX:0Kooooo1olO7al7o`h>3POoBTY:
1olO7al6oeEEE@OoFe]K1olW9bL6oalO7`Kooooo1olH61P7ocLg=`Oo;Bd]1om=CDd7odM7A`OoEEEE
1_ll?3`6obPX:0Kooooo1ol/;2`7oeeMG@OoPX:21omQHF47oemOG`Oo=SHf1omVIVH6o`@410Gooooo
1old=3@7obPX:0Oog=cL1omIFET7oaDE5@Ooc/k>1olC4a<6okBd]0gooooo000;ooooo`Oo?Shn1olR
8R87ohf=S@OoH61P1olU9BD7od51@@Oo;2`/1_l<30`5ooooo`Oo5QHF1olR8R87oa4A4@Oo6a/K1ol@
4107o`<30`go20P81_ooool6oaTI6@OoADE51om^KVh7oaDE5@Oo<c<c1om9BDT7oa/K6`Ko2@T91_oo
ool7oe=CD`Oo20P81_l51@D7ok6a/@Oo71`L1olH61P7omWIf@Ko410@1_ooool7obXZ:POo3`l?1olm
?Cd7ocHf=PKoBd];1omEEED7oaXJ6PKo92@T1_ooool7o`h>3POo51@D1ol:2PX7ob@T90Oo3Ph>1olN
7Qh6ob@T90Ko8R8R1_ooool7oaDE5@Oooooo1om6ATH7oc8b<POono_k1olG5aL7ob`/;0KoE5AD1Ooo
ool7ogQhN0Oo7AdM1omCDe<7oeYJFPOoMGEe1omNGUh7obd];@Ko^k^k3Oooool000_ooooo1oln?Sh7
ob8R8POoSHf=1omPH607obDU9@Oo@D511ol/;2`6o``<30Gooooo1olF5QH7ob8R8POo4A4A1olK6a/7
oa0@40Oo0`<33Ol820P6ooooo`Ko6ATI1om5ADD7ofi^KPOo5ADE1olc<c<7odU9B@Oo6a/K1_l92@T6
ooooo`OoDe=C1ol820P6o`D51@Oo/K6a1olL71`7oaPH60OofMWI1_l@4106ooooo`Oo:RXZ1ol?3`l7
ocdm?@Oo=SHf1_m;Bd/7oeEEE@Oo6QXJ1_lT92@6ooooo`Oo3Ph>1olD51@7o`X:2POo92@T1ol>3Ph7
oahN7PKo92@T1_lR8R86ooooo`Oo5ADE1oooool7odI6APOo<S8b1ookno/7oaLG5`Oo;2`/1_mDE5@5
ooooo`OoN7Qh1olM7Ad7oe=CD`OoFUYJ1omeMGD7oeiNGPOo;Bd]1_nk^k/=ooooo`002oooool7ochn
?POo8R8R1on=SHd7of1PH0Oo9BDU1om1@D47ob`/;0Ko30`<1Oooool7oaHF5POo8R8R1olA4A47oa/K
6`Oo410@1ol30`<=o`P820Kooooo1_lI6AT7odE5A@OoKVi^1olE5AD7oc<c<`OoBDU91olK6a/6o`T9
2@Kooooo1omCDe<7o`P820Ko1@D51ona/K47oa`L70Oo61PH1ooIfMT6oa0@40Kooooo1olZ:RX7o`l?
3`Oo?Cdm1olf=SH6od];B`OoEEEE1olJ6QX6ob@T90Kooooo1ol>3Ph7oa@D50Oo2PX:1olT92@7o`h>
3POo7QhN1_lT92@6ob8R8PKooooo1olE5AD7ooooo`OoATI61olb<S87oo_kn`Oo5aLG1ol/;2`6oeAD
E0Gooooo1omhN7P7oadM7@OoDe=C1omJFUX7ogEeM@OoGUiN1ol];Bd6ok^k^`gooooo000;ooooo`Oo
?Shn1olR8R87ohf=S@OoH61P1olU9BD7od51@@Oo;2`/1_l<30`5ooooo`Oo5QHF1olR8R87oa4A4@Oo
6a/K1ol@4107o`<30`go20P81_ooool6oaTI6@OoADE51om^KVh7oaDE5@Oo<c<c1om9BDT7oa/K6`Ko
2@T91_ooool7oe=CD`Oo20P81_l51@D7ok6a/@Oo71`L1olH61P7omWIf@Ko410@1_ooool7obXZ:POo
3`l?1olm?Cd7ocHf=PKoBd];1omEEED7oaXJ6PKo92@T1_ooool7o`h>3POo51@D1ol:2PX7ob@T90Oo
3Ph>1olN7Qh6ob@T90Ko8R8R1_ooool7oaDE5@Oooooo1om6ATH7oc8b<POono_k1olG5aL7ob`/;0Ko
E5AD1Oooool7ogQhN0Oo7AdM1omCDe<7oeYJFPOoMGEe1omNGUh7obd];@Ko^k^k3Oooool000_ooooo
1oln?Sh7ob8R8POoSHf=1omPH607obDU9@Oo@D511ol/;2`6o``<30Gooooo1olF5QH7ob8R8POo4A4A
1olK6a/7oa0@40Oo0`<33Ol820P6ooooo`Ko6ATI1om5ADD7ofi^KPOo5ADE1olc<c<7odU9B@Oo6a/K
1_l92@T6ooooo`OoDe=C1ol820P6o`D51@Oo/K6a1olL71`7oaPH60OofMWI1_l@4106ooooo`Oo:RXZ
1ol?3`l7ocdm?@Oo=SHf1_m;Bd/7oeEEE@Oo6QXJ1_lT92@6ooooo`Oo3Ph>1olD51@7o`X:2POo92@T
1ol>3Ph7oahN7PKo92@T1_lR8R86ooooo`Oo5ADE1oooool7odI6APOo<S8b1ookno/7oaLG5`Oo;2`/
1_mDE5@5ooooo`OoN7Qh1olM7Ad7oe=CD`OoFUYJ1omeMGD7oeiNGPOo;Bd]1_nk^k/=ooooo`002ooo
ool7ochn?POo8R8R1on=SHd7of1PH0Oo9BDU1om1@D47ob`/;0Ko30`<1Oooool7oaHF5POo8R8R1olA
4A47oa/K6`Oo410@1ol30`<=o`P820Kooooo1_lI6AT7odE5A@OoKVi^1olE5AD7oc<c<`OoBDU91olK
6a/6o`T92@Kooooo1omCDe<7o`P820Ko1@D51ona/K47oa`L70Oo61PH1ooIfMT6oa0@40Kooooo1olZ
:RX7o`l?3`Oo?Cdm1olf=SH6od];B`OoEEEE1olJ6QX6ob@T90Kooooo1ol>3Ph7oa@D50Oo2PX:1olT
92@7o`h>3POo7QhN1_lT92@6ob8R8PKooooo1olE5AD7ooooo`OoATI61olb<S87oo_kn`Oo5aLG1ol/
;2`6oeADE0Gooooo1omhN7P7oadM7@OoDe=C1omJFUX7ogEeM@OoGUiN1ol];Bd6ok^k^`gooooo000;
ooooo`Oo71`L1omHF5P7ogalO0Oo30`<3_lf=SH7o`d=3@Ko00001Oooool7ob0P80Oo;Rh^1olA4A47
ob4Q8@Oo4Q8B1ol00007o`820PKo8B4Q1_ooool6obPX:0Oooooo1ol[:b/7oaXJ6POoVYZJ1olM7Ad7
oaLG5`Ko?Cdm1_ooool7oc`l?0Oo:b/[1_lY:BT7obXZ:POo;Rh^1omaLG47oaTI6@Ko51@D1_ooool7
o`@410Oo1`L71omKFe/7obHV9PKo?Shn1omkNg/7oc0`<0Ko6ATI1_ooool7o`L71`Oo0P821ol30`<7
o`T92@Oo00001ol30`<6o`D51@Ko30`<1_ooool7ob0P80Oo`/;21om7AdL7oifMW@OoUiNG1olH61P7
omcLg0Ko3Ph>1Oooool7o`h>3POo4Q8B1on<S8`7o`0000Oo9RHV1on^[Zh7obd];@KoKVi^3Oooool0
00_ooooo1olL71`7oeQHF0OoO7al1ol<30`>ocHf=POo3@d=1_l00005ooooo`Oo820P1ol^;Rh7oa4A
4@Oo8B4Q1olB4Q87o`0000Oo0P821_lQ8B46ooooo`Ko:2PX1oooool7ob/[:`Oo6QXJ1onJVYX7oadM
7@Oo5aLG1_lm?Cd6ooooo`Oo?3`l1ol[:b/6obTY:@Oo:RXZ1ol^;Rh7og5aL@Oo6ATI1_lD51@6oooo
o`Oo10@41ol71`L7oe]KF`Oo9RHV1_ln?Sh7og]kN`Oo<30`1_lI6AT6ooooo`Oo1`L71ol20P87o`<3
0`Oo2@T91ol00007o`<30`Ko1@D51_l<30`6ooooo`Oo820P1oo2`/87odM7A`OoWIfM1onGUiL7oaPH
60Oog=cL1_l>3Ph5ooooo`Oo3Ph>1olB4Q87ohb<S0Oo00001olV9RH7ojj^[POo;Bd]1_m^KVh=oooo
o`002oooool7oa`L70OoF5QH1omlO7`7o``<30ko=SHf1ol=3@d6o`0000Gooooo1olP8207obh^;POo
4A4A1olQ8B47oa8B4POo00001ol20P86ob4Q8@Kooooo1_lX:2P7ooooo`Oo:b/[1olJ6QX7oiZJVPOo
7AdM1olG5aL6ocdm?@Kooooo1oll?3`7ob/[:`Ko:BTY1olZ:RX7obh^;POoLG5a1olI6AT6oa@D50Ko
oooo1ol410@7o`L71`OoFe]K1olV9RH6ochn?POoNg]k1ol`<306oaTI6@Kooooo1ol71`L7o`820POo
0`<31ol92@T7o`0000Oo0`<31_l51@D6o``<30Kooooo1olP8207ol;2`POoAdM71onMWId7oiNGU`Oo
61PH1ooLg=`6o`h>3PGooooo1ol>3Ph7oa8B4POoS8b<1ol00007obHV9POo[Zj^1ol];Bd6ofi^KPgo
oooo000;ooooo`Oo71`L1omHF5P7ogalO0Oo30`<3_lf=SH7o`d=3@Ko00001Oooool7ob0P80Oo;Rh^
1olA4A47ob4Q8@Oo4Q8B1ol00007o`820PKo8B4Q1_ooool6obPX:0Oooooo1ol[:b/7oaXJ6POoVYZJ
1olM7Ad7oaLG5`Ko?Cdm1_ooool7oc`l?0Oo:b/[1_lY:BT7obXZ:POo;Rh^1omaLG47oaTI6@Ko51@D
1_ooool7o`@410Oo1`L71omKFe/7obHV9PKo?Shn1omkNg/7oc0`<0Ko6ATI1_ooool7o`L71`Oo0P82
1ol30`<7o`T92@Oo00001ol30`<6o`D51@Ko30`<1_ooool7ob0P80Oo`/;21om7AdL7oifMW@OoUiNG
1olH61P7omcLg0Ko3Ph>1Oooool7o`h>3POo4Q8B1on<S8`7o`0000Oo9RHV1on^[Zh7obd];@KoKVi^
3Oooool000_ooooo1olL71`7oeQHF0OoO7al1ol<30`>ocHf=POo3@d=1_l00005ooooo`Oo820P1ol^
;Rh7oa4A4@Oo8B4Q1olB4Q87o`0000Oo0P821_lQ8B46ooooo`Ko:2PX1oooool7ob/[:`Oo6QXJ1onJ
VYX7oadM7@Oo5aLG1_lm?Cd6ooooo`Oo?3`l1ol[:b/6obTY:@Oo:RXZ1ol^;Rh7og5aL@Oo6ATI1_lD
51@6ooooo`Oo10@41ol71`L7oe]KF`Oo9RHV1_ln?Sh7og]kN`Oo<30`1_lI6AT6ooooo`Oo1`L71ol2
0P87o`<30`Oo2@T91ol00007o`<30`Ko1@D51_l<30`6ooooo`Oo820P1oo2`/87odM7A`OoWIfM1onG
UiL7oaPH60Oog=cL1_l>3Ph5ooooo`Oo3Ph>1olB4Q87ohb<S0Oo00001olV9RH7ojj^[POo;Bd]1_m^
KVh=ooooo`002oooool7oa`L70OoF5QH1omlO7`7o``<30ko=SHf1ol=3@d6o`0000Gooooo1olP8207
obh^;POo4A4A1olQ8B47oa8B4POo00001ol20P86ob4Q8@Kooooo1_lX:2P7ooooo`Oo:b/[1olJ6QX7
oiZJVPOo7AdM1olG5aL6ocdm?@Kooooo1oll?3`7ob/[:`Ko:BTY1olZ:RX7obh^;POoLG5a1olI6AT6
oa@D50Kooooo1ol410@7o`L71`OoFe]K1olV9RH6ochn?POoNg]k1ol`<306oaTI6@Kooooo1ol71`L7
o`820POo0`<31ol92@T7o`0000Oo0`<31_l51@D6o``<30Kooooo1olP8207ol;2`POoAdM71onMWId7
oiNGU`Oo61PH1ooLg=`6o`h>3PGooooo1ol>3Ph7oa8B4POoS8b<1ol00007obHV9POo[Zj^1ol];Bd6
ofi^KPgooooo000;ooooo`Oo71`L1omHF5P7ogalO0Oo30`<3_lf=SH7o`d=3@Ko00001Oooool7ob0P
80Oo;Rh^1olA4A47ob4Q8@Oo4Q8B1ol00007o`820PKo8B4Q1_ooool6obPX:0Oooooo1ol[:b/7oaXJ
6POoVYZJ1olM7Ad7oaLG5`Ko?Cdm1_ooool7oc`l?0Oo:b/[1_lY:BT7obXZ:POo;Rh^1omaLG47oaTI
6@Ko51@D1_ooool7o`@410Oo1`L71omKFe/7obHV9PKo?Shn1omkNg/7oc0`<0Ko6ATI1_ooool7o`L7
1`Oo0P821ol30`<7o`T92@Oo00001ol30`<6o`D51@Ko30`<1_ooool7ob0P80Oo`/;21om7AdL7oifM
W@OoUiNG1olH61P7omcLg0Ko3Ph>1Oooool7o`h>3POo4Q8B1on<S8`7o`0000Oo9RHV1on^[Zh7obd]
;@KoKVi^3Oooool000_ooooo1olf=SH7oaPH60Oo8R8R1olb<S87o`0000Oo10@41olF5QH6o`410@Go
oooo1ol92@T7obTY:@Oo;Bd]1ol^;Rh7oalO7`Oo0@411olD51@6oadM7@Kooooo1_lT92@7ojNWY`Oo
=cLg1om/K6`7obh^;POo=3@d1omYJFT6obDU9@Kooooo1olf=SH7oa4A4@Ko@d=31oli>CT7o`0000Oo
9BDU1omKFe/6o`h>3PKooooo1olZ:RX7ocPh>0Oo<30`1ol_;bl6ooooo`OoYJFU1olb<S86ocPh>0Ko
oooo1olF5QH7o`/;2`Oo3Ph>1ol71`L7o`d=3@Oo0@411_l20P86o`X:2PKooooo1om9BDT7oh>3P`Oo
<30`1on3Ph<7oj2PX0Oo51@D1onKVi/6obDU9@Gooooo1ol@4107obTY:@Oo6a/K1ol00007ogQhN0Oo
30`<1ol71`L6oi6AT@gooooo000;ooooo`Oo=SHf1olH61P7ob8R8POo<S8b1ol00007o`@410Oo5QHF
1_l10@45ooooo`Oo2@T91olY:BT7obd];@Oo;Rh^1olO7al7o`410@Oo51@D1_lM7Ad6ooooo`Ko92@T
1onWYjL7ocLg=`OoK6a/1ol^;Rh7oc@d=0OoJFUY1_lU9BD6ooooo`Oo=SHf1olA4A46od=3@`Oo>CTi
1ol00007obDU9@OoFe]K1_l>3Ph6ooooo`Oo:RXZ1olh>3P7oc0`<0Oo;bl_1_ooool7ojFUY@Oo<S8b
1_lh>3P6ooooo`Oo5QHF1ol;2`/7o`h>3POo1`L71ol=3@d7o`410@Ko0P821_l:2PX6ooooo`OoBDU9
1on3Ph<7oc0`<0OoPh>31onPX:07oa@D50OoVi^K1_lU9BD5ooooo`Oo410@1olY:BT7oa/K6`Oo0000
1omhN7P7o``<30Oo1`L71_nATI4=ooooo`002oooool7ocHf=POo61PH1olR8R87oc8b<POo00001ol4
10@7oaHF5PKo0@411Oooool7o`T92@Oo:BTY1ol];Bd7obh^;POo7alO1ol10@47oa@D50Ko7AdM1_oo
ool6ob@T90OoYjNW1olg=cL7ofa/K0Oo;Rh^1old=3@7ofUYJ@Ko9BDU1_ooool7ocHf=POo4A4A1_m3
@d<7ocTi>@Oo00001olU9BD7oe]KF`Ko3Ph>1_ooool7obXZ:POo>3Ph1ol`<307obl_;`Kooooo1onU
YJD7oc8b<PKo>3Ph1_ooool7oaHF5POo2`/;1ol>3Ph7o`L71`Oo3@d=1ol10@46o`820PKo2PX:1_oo
ool7odU9B@OoPh>31ol`<307oh>3P`OoX:2P1olD51@7oi^KV`Ko9BDU1Oooool7oa0@40Oo:BTY1olK
6a/7o`0000OoN7Qh1ol<30`7o`L71`KoTI6A3Oooool000_ooooo1olf=SH7oaPH60Oo8R8R1olb<S87
o`0000Oo10@41olF5QH6o`410@Gooooo1ol92@T7obTY:@Oo;Bd]1ol^;Rh7oalO7`Oo0@411olD51@6
oadM7@Kooooo1_lT92@7ojNWY`Oo=cLg1om/K6`7obh^;POo=3@d1omYJFT6obDU9@Kooooo1olf=SH7
oa4A4@Ko@d=31oli>CT7o`0000Oo9BDU1omKFe/6o`h>3PKooooo1olZ:RX7ocPh>0Oo<30`1ol_;bl6
ooooo`OoYJFU1olb<S86ocPh>0Kooooo1olF5QH7o`/;2`Oo3Ph>1ol71`L7o`d=3@Oo0@411_l20P86
o`X:2PKooooo1om9BDT7oh>3P`Oo<30`1on3Ph<7oj2PX0Oo51@D1onKVi/6obDU9@Gooooo1ol@4107
obTY:@Oo6a/K1ol00007ogQhN0Oo30`<1ol71`L6oi6AT@gooooo000;ooooo`Oo=SHf1olH61P7ob8R
8POo<S8b1ol00007o`@410Oo5QHF1_l10@45ooooo`Oo2@T91olY:BT7obd];@Oo;Rh^1olO7al7o`41
0@Oo51@D1_lM7Ad6ooooo`Ko92@T1onWYjL7ocLg=`OoK6a/1ol^;Rh7oc@d=0OoJFUY1_lU9BD6oooo
o`Oo=SHf1olA4A46od=3@`Oo>CTi1ol00007obDU9@OoFe]K1_l>3Ph6ooooo`Oo:RXZ1olh>3P7oc0`
<0Oo;bl_1_ooool7ojFUY@Oo<S8b1_lh>3P6ooooo`Oo5QHF1ol;2`/7o`h>3POo1`L71ol=3@d7o`41
0@Ko0P821_l:2PX6ooooo`OoBDU91on3Ph<7oc0`<0OoPh>31onPX:07oa@D50OoVi^K1_lU9BD5oooo
o`Oo410@1olY:BT7oa/K6`Oo00001omhN7P7o``<30Oo1`L71_nATI4=ooooo`002oooool7ocHf=POo
61PH1olR8R87oc8b<POo00001ol410@7oaHF5PKo0@411Oooool7o`T92@Oo:BTY1ol];Bd7obh^;POo
7alO1ol10@47oa@D50Ko7AdM1_ooool6ob@T90OoYjNW1olg=cL7ofa/K0Oo;Rh^1old=3@7ofUYJ@Ko
9BDU1_ooool7ocHf=POo4A4A1_m3@d<7ocTi>@Oo00001olU9BD7oe]KF`Ko3Ph>1_ooool7obXZ:POo
>3Ph1ol`<307obl_;`Kooooo1onUYJD7oc8b<PKo>3Ph1_ooool7oaHF5POo2`/;1ol>3Ph7o`L71`Oo
3@d=1ol10@46o`820PKo2PX:1_ooool7odU9B@OoPh>31ol`<307oh>3P`OoX:2P1olD51@7oi^KV`Ko
9BDU1Oooool7oa0@40Oo:BTY1olK6a/7o`0000OoN7Qh1ol<30`7o`L71`KoTI6A3Oooool000_ooooo
1olf=SH7oaPH60Oo8R8R1olb<S87o`0000Oo10@41olF5QH6o`410@Gooooo1ol92@T7obTY:@Oo;Bd]
1ol^;Rh7oalO7`Oo0@411olD51@6oadM7@Kooooo1_lT92@7ojNWY`Oo=cLg1om/K6`7obh^;POo=3@d
1omYJFT6obDU9@Kooooo1olf=SH7oa4A4@Ko@d=31oli>CT7o`0000Oo9BDU1omKFe/6o`h>3PKooooo
1olZ:RX7ocPh>0Oo<30`1ol_;bl6ooooo`OoYJFU1olb<S86ocPh>0Kooooo1olF5QH7o`/;2`Oo3Ph>
1ol71`L7o`d=3@Oo0@411_l20P86o`X:2PKooooo1om9BDT7oh>3P`Oo<30`1on3Ph<7oj2PX0Oo51@D
1onKVi/6obDU9@Gooooo1ol@4107obTY:@Oo6a/K1ol00007ogQhN0Oo30`<1ol71`L6oi6AT@gooooo
000;ooooo`Oo6QXJ1olP8207ofIVIPOo3Ph>1ol20P87odU9B@Oo6ATI1_l30`<5ooooo`Oo4Q8B1olJ
6QX7oa8B4POo6QXJ1olU9BD>ocXj>PKo>CTi1_ooool6obHV9POoVi^K1olM7Ad7oc4a<@OoS8b<1olV
9RH7odU9B@Ko?Cdm1_ooool7oh>3P`OoCTi>1_m7AdL7oe=CD`Oo7alO1om<C4`7oalO7`Ko6ATI1_oo
ool7ob0P80Oo00001om8B4P7oe9BDPKo@T921om3@d<7ocLg=`Ko7AdM1_ooool7oahN7POo51@D1ol@
4107oa/K6`Oo51@D1olZ:RX6ob@T90Ko820P1_ooool7oalO7`Oo[Zj^1ol00007ofYZJPOo^;Rh1olO
7al7ojNWY`Ko:RXZ1Oooool7oa8B4POoUIFE1olN7Qh7obXZ:POoFEUI1ol`<307ocTi>@Ko5aLG3Ooo
ool000_ooooo1olJ6QX7ob0P80OoIVIV1ol>3Ph7o`820POoBDU91olI6AT6o`<30`Gooooo1olB4Q87
oaXJ6POo4Q8B1olJ6QX7obDU9@ko>SXj1_li>CT6ooooo`Ko9RHV1onKVi/7oadM7@Oo<C4a1on<S8`7
obHV9POoBDU91_lm?Cd6ooooo`OoPh>31om>CTh6odM7A`OoDe=C1olO7al7oda<C0Oo7alO1_lI6AT6
ooooo`Oo820P1ol00007odQ8B0OoDU9B1_m2@T87od=3@`Oo=cLg1_lM7Ad6ooooo`Oo7QhN1olD51@7
oa0@40Oo6a/K1olD51@7obXZ:PKo92@T1_lP8206ooooo`Oo7alO1on^[Zh7o`0000OoJVYZ1onh^;P7
oalO7`OoYjNW1_lZ:RX5ooooo`Oo4Q8B1onEUID7oahN7POo:RXZ1omIFET7oc0`<0Oo>CTi1_lG5aL=
ooooo`002oooool7oaXJ6POo820P1omVIVH7o`h>3POo0P821om9BDT7oaTI6@Ko0`<31Oooool7oa8B
4POo6QXJ1olB4Q87oaXJ6POo9BDU3_lj>SX6ocTi>@Kooooo1_lV9RH7oi^KV`Oo7AdM1ola<C47ohb<
S0Oo9RHV1om9BDT6ocdm?@Kooooo1on3Ph<7odi>CPKoAdM71omCDe<7oalO7`OoC4a<1olO7al6oaTI
6@Kooooo1olP8207o`0000OoB4Q81omBDU86od92@POo@d=31olg=cL6oadM7@Kooooo1olN7Qh7oa@D
50Oo410@1olK6a/7oa@D50Oo:RXZ1_lT92@6ob0P80Kooooo1olO7al7ojj^[POo00001omZJVX7okRh
^0Oo7alO1onWYjL6obXZ:PGooooo1olB4Q87oiFEU@Oo7QhN1olZ:RX7oeUIF@Oo<30`1oli>CT6oaLG
5`gooooo000;ooooo`Oo6QXJ1olP8207ofIVIPOo3Ph>1ol20P87odU9B@Oo6ATI1_l30`<5ooooo`Oo
4Q8B1olJ6QX7oa8B4POo6QXJ1olU9BD>ocXj>PKo>CTi1_ooool6obHV9POoVi^K1olM7Ad7oc4a<@Oo
S8b<1olV9RH7odU9B@Ko?Cdm1_ooool7oh>3P`OoCTi>1_m7AdL7oe=CD`Oo7alO1om<C4`7oalO7`Ko
6ATI1_ooool7ob0P80Oo00001om8B4P7oe9BDPKo@T921om3@d<7ocLg=`Ko7AdM1_ooool7oahN7POo
51@D1ol@4107oa/K6`Oo51@D1olZ:RX6ob@T90Ko820P1_ooool7oalO7`Oo[Zj^1ol00007ofYZJPOo
^;Rh1olO7al7ojNWY`Ko:RXZ1Oooool7oa8B4POoUIFE1olN7Qh7obXZ:POoFEUI1ol`<307ocTi>@Ko
5aLG3Oooool000_ooooo1olJ6QX7ob0P80OoIVIV1ol>3Ph7o`820POoBDU91olI6AT6o`<30`Gooooo
1olB4Q87oaXJ6POo4Q8B1olJ6QX7obDU9@ko>SXj1_li>CT6ooooo`Ko9RHV1onKVi/7oadM7@Oo<C4a
1on<S8`7obHV9POoBDU91_lm?Cd6ooooo`OoPh>31om>CTh6odM7A`OoDe=C1olO7al7oda<C0Oo7alO
1_lI6AT6ooooo`Oo820P1ol00007odQ8B0OoDU9B1_m2@T87od=3@`Oo=cLg1_lM7Ad6ooooo`Oo7QhN
1olD51@7oa0@40Oo6a/K1olD51@7obXZ:PKo92@T1_lP8206ooooo`Oo7alO1on^[Zh7o`0000OoJVYZ
1onh^;P7oalO7`OoYjNW1_lZ:RX5ooooo`Oo4Q8B1onEUID7oahN7POo:RXZ1omIFET7oc0`<0Oo>CTi
1_lG5aL=ooooo`002oooool7oaXJ6POo820P1omVIVH7o`h>3POo0P821om9BDT7oaTI6@Ko0`<31Ooo
ool7oa8B4POo6QXJ1olB4Q87oaXJ6POo9BDU3_lj>SX6ocTi>@Kooooo1_lV9RH7oi^KV`Oo7AdM1ola
<C47ohb<S0Oo9RHV1om9BDT6ocdm?@Kooooo1on3Ph<7odi>CPKoAdM71omCDe<7oalO7`OoC4a<1olO
7al6oaTI6@Kooooo1olP8207o`0000OoB4Q81omBDU86od92@POo@d=31olg=cL6oadM7@Kooooo1olN
7Qh7oa@D50Oo410@1olK6a/7oa@D50Oo:RXZ1_lT92@6ob0P80Kooooo1olO7al7ojj^[POo00001omZ
JVX7okRh^0Oo7alO1onWYjL6obXZ:PGooooo1olB4Q87oiFEU@Oo7QhN1olZ:RX7oeUIF@Oo<30`1oli
>CT6oaLG5`gooooo000;ooooo`Oo6QXJ1olP8207ofIVIPOo3Ph>1ol20P87odU9B@Oo6ATI1_l30`<5
ooooo`Oo4Q8B1olJ6QX7oa8B4POo6QXJ1olU9BD>ocXj>PKo>CTi1_ooool6obHV9POoVi^K1olM7Ad7
oc4a<@OoS8b<1olV9RH7odU9B@Ko?Cdm1_ooool7oh>3P`OoCTi>1_m7AdL7oe=CD`Oo7alO1om<C4`7
oalO7`Ko6ATI1_ooool7ob0P80Oo00001om8B4P7oe9BDPKo@T921om3@d<7ocLg=`Ko7AdM1_ooool7
oahN7POo51@D1ol@4107oa/K6`Oo51@D1olZ:RX6ob@T90Ko820P1_ooool7oalO7`Oo[Zj^1ol00007
ofYZJPOo^;Rh1olO7al7ojNWY`Ko:RXZ1Oooool7oa8B4POoUIFE1olN7Qh7obXZ:POoFEUI1ol`<307
ocTi>@Ko5aLG3Oooool000_ooooo1oli>CT7oc`l?0Oooooo1omJFUX7oalO7`OoMgMg1om2@T86o`d=
3@Gooooo1omDE5@7odI6APOoJFUY1om;Bd/7ofATI0OoIFEU1onCTi<6okBd]0Kooooo1_ll?3`7o`P8
20Oo9bLW1omhN7P7o`<30`Oo92@T1omlO7`6ob`/;0Kooooo1olH61P7ohf=S@Ko=CDe1olG5aL7oiVI
V@Oo71`L1olT92@6obl_;`Kooooo1olT92@7oa/K6`OoA4A41olf=SH6oe]KF`OoK6a/1olZ:RX6obPX
:0Kooooo1omMGEd7ooooo`Oo^;Rh1onCTi<7of1PH0OoF5QH1_li>CT6ocPh>0Kooooo1om:BTX7obDU
9@Oo4Q8B1olH61P7ob0P80Oo?clo1olB4Q86oa/K6`Gooooo1on4Q8@7oc`l?0OoU9BD1om9BDT7oc4a
<@OoLW9b1ol00006o`d=3@gooooo000;ooooo`Oo>CTi1oll?3`7ooooo`OoFUYJ1olO7al7ogMgM`Oo
@T921_l=3@d5ooooo`OoE5AD1om6ATH7ofUYJ@OoBd];1omTI6@7ofEUI@OoTi>C1_nd];@6ooooo`Ko
?3`l1ol820P7obLW9`OoN7Qh1ol30`<7ob@T90OoO7al1_l/;2`6ooooo`Oo61PH1on=SHd6ocDe=@Oo
5aLG1onIVIT7oa`L70Oo92@T1_l_;bl6ooooo`Oo92@T1olK6a/7odA4A0Oo=SHf1_mKFe/7ofa/K0Oo
:RXZ1_lX:2P6ooooo`OoGEeM1oooool7okRh^0OoTi>C1omPH607oeQHF0Ko>CTi1_lh>3P6ooooo`Oo
BTY:1olU9BD7oa8B4POo61PH1olP8207oclo?`Oo4Q8B1_lK6a/5ooooo`OoQ8B41oll?3`7oiBDU0Oo
BDU91ola<C47og9bLPOo00001_l=3@d=ooooo`002oooool7ocTi>@Oo?3`l1oooool7oeYJFPOo7alO
1omgMgL7od92@PKo3@d=1Oooool7oeADE0OoATI61omYJFT7od];B`OoI6AT1omUIFD7oi>CT`Ko];Bd
1_ooool6oc`l?0Oo20P81olW9bL7ogQhN0Oo0`<31olT92@7ogalO0Ko;2`/1_ooool7oaPH60OoSHf=
1_le=CD7oaLG5`OoVIVI1olL71`7ob@T90Ko;bl_1_ooool7ob@T90Oo6a/K1om4A4@7ocHf=PKoFe]K
1om/K6`7obXZ:PKo:2PX1_ooool7oeeMG@Oooooo1onh^;P7oi>CT`OoH61P1omHF5P6ocTi>@Ko>3Ph
1_ooool7odY:BPOo9BDU1olB4Q87oaPH60Oo820P1olo?cl7oa8B4PKo6a/K1Oooool7ohB4Q0Oo?3`l
1onDU9@7odU9B@Oo<C4a1ombLW87o`0000Ko3@d=3Oooool000_ooooo1oli>CT7oc`l?0Oooooo1omJ
FUX7oalO7`OoMgMg1om2@T86o`d=3@Gooooo1omDE5@7odI6APOoJFUY1om;Bd/7ofATI0OoIFEU1onC
Ti<6okBd]0Kooooo1_ll?3`7o`P820Oo9bLW1omhN7P7o`<30`Oo92@T1omlO7`6ob`/;0Kooooo1olH
61P7ohf=S@Ko=CDe1olG5aL7oiVIV@Oo71`L1olT92@6obl_;`Kooooo1olT92@7oa/K6`OoA4A41olf
=SH6oe]KF`OoK6a/1olZ:RX6obPX:0Kooooo1omMGEd7ooooo`Oo^;Rh1onCTi<7of1PH0OoF5QH1_li
>CT6ocPh>0Kooooo1om:BTX7obDU9@Oo4Q8B1olH61P7ob0P80Oo?clo1olB4Q86oa/K6`Gooooo1on4
Q8@7oc`l?0OoU9BD1om9BDT7oc4a<@OoLW9b1ol00006o`d=3@gooooo000;ooooo`Oo>CTi1oll?3`7
ooooo`OoFUYJ1olO7al7ogMgM`Oo@T921_l=3@d5ooooo`OoE5AD1om6ATH7ofUYJ@OoBd];1omTI6@7
ofEUI@OoTi>C1_nd];@6ooooo`Ko?3`l1ol820P7obLW9`OoN7Qh1ol30`<7ob@T90OoO7al1_l/;2`6
ooooo`Oo61PH1on=SHd6ocDe=@Oo5aLG1onIVIT7oa`L70Oo92@T1_l_;bl6ooooo`Oo92@T1olK6a/7
odA4A0Oo=SHf1_mKFe/7ofa/K0Oo:RXZ1_lX:2P6ooooo`OoGEeM1oooool7okRh^0OoTi>C1omPH607
oeQHF0Ko>CTi1_lh>3P6ooooo`OoBTY:1olU9BD7oa8B4POo61PH1olP8207oclo?`Oo4Q8B1_lK6a/5
ooooo`OoQ8B41oll?3`7oiBDU0OoBDU91ola<C47og9bLPOo00001_l=3@d=ooooo`002oooool7ocTi
>@Oo?3`l1oooool7oeYJFPOo7alO1omgMgL7od92@PKo3@d=1Oooool7oeADE0OoATI61omYJFT7od];
B`OoI6AT1omUIFD7oi>CT`Ko];Bd1_ooool6oc`l?0Oo20P81olW9bL7ogQhN0Oo0`<31olT92@7ogal
O0Ko;2`/1_ooool7oaPH60OoSHf=1_le=CD7oaLG5`OoVIVI1olL71`7ob@T90Ko;bl_1_ooool7ob@T
90Oo6a/K1om4A4@7ocHf=PKoFe]K1om/K6`7obXZ:PKo:2PX1_ooool7oeeMG@Oooooo1onh^;P7oi>C
T`OoH61P1omHF5P6ocTi>@Ko>3Ph1_ooool7odY:BPOo9BDU1olB4Q87oaPH60Oo820P1olo?cl7oa8B
4PKo6a/K1Oooool7ohB4Q0Oo?3`l1onDU9@7odU9B@Oo<C4a1ombLW87o`0000Ko3@d=3Oooool00?oo
oooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oo
oooomOooool00?oooooomOooool000_ooooo1ol`<307o`l?3`Oo@d=31on3Ph<7ochn?POo5aLG1olP
8206obLW9`Gooooo1olk>c/7oeiNGPOoF5QH1om=CDd7og9bLPOoB4Q81omBDU86of5QH@Kooooo1_lF
5QH7oeMGE`Oo[Jf]1ol^;Rh7ohb<S0OoJf][1omIFET6ofYZJPKooooo1omHF5P7om3@d0Ko?clo1onO
Wil7om_Kf`Oo?Cdm1omWIfL6ob`/;0Kooooo1olK6a/7oahN7POo8B4Q1ol/;2`6ob0P80Oo410@1olR
8R86oa/K6`Kooooo1olV9RH7oahN7POo:2PX1oln?Sh7ocPh>0Oo=CDe1_l/;2`6obd];@Kooooo1ol<
30`7oaTI6@OoG5aL1ol00007ob@T90OoRHV91olD51@6ob/[:`Gooooo1oono_h7oaLG5`Oo7alO1onf
][H7oa4A4@Oo=3@d1omFEUH6obHV9Pgooooo000;ooooo`Oo<30`1ol?3`l7od=3@`OoPh>31oln?Sh7
oaLG5`Oo820P1_lW9bL5ooooo`Oo>c/k1omNGUh7oeQHF0OoCDe=1ombLW87odQ8B0OoDU9B1_mQHF46
ooooo`Ko5QHF1omGEeL7ojf][@Oo;Rh^1on<S8`7of][J`OoFEUI1_mZJVX6ooooo`OoF5QH1oo@d=06
oclo?`OoWinO1ooKfm/7ocdm?@OoIfMW1_l/;2`6ooooo`Oo6a/K1olN7Qh7ob4Q8@Oo;2`/1_lP8207
oa0@40Oo8R8R1_lK6a/6ooooo`Oo9RHV1olN7Qh7obPX:0Oo?Shn1olh>3P7ocDe=@Ko;2`/1_l];Bd6
ooooo`Oo30`<1olI6AT7oeaLG0Oo00001olT92@7ohV9R@Oo51@D1_l[:b/5ooooo`Ooo_kn1olG5aL7
oalO7`Oo][Jf1olA4A47oc@d=0OoEUIF1_lV9RH=ooooo`002oooool7oc0`<0Oo3`l?1om3@d<7oh>3
P`Oo?Shn1olG5aL7ob0P80Ko9bLW1Oooool7oc/k>`OoGUiN1omHF5P7ode=C@OoLW9b1om8B4P7oe9B
DPKoHF5Q1_ooool6oaHF5POoEeMG1on][Jd7obh^;POoS8b<1om[Jf/7oeUIF@KoJVYZ1_ooool7oeQH
F0Ood=3@1_lo?cl7oinOW`Oofm_K1olm?Cd7ofMWI`Ko;2`/1_ooool7oa/K6`Oo7QhN1olQ8B47ob`/
;0Ko820P1ol@4107ob8R8PKo6a/K1_ooool7obHV9POo7QhN1olX:2P7ochn?POo>3Ph1ole=CD6ob`/
;0Ko;Bd]1_ooool7o``<30Oo6ATI1omLG5`7o`0000Oo92@T1on9RHT7oa@D50Ko:b/[1Oooool7ookn
oPOo5aLG1olO7al7okJf]POo4A4A1old=3@7oeIFEPKo9RHV3Oooool000_ooooo1ol`<307o`l?3`Oo
@d=31on3Ph<7ochn?POo5aLG1olP8206obLW9`Gooooo1olk>c/7oeiNGPOoF5QH1om=CDd7og9bLPOo
B4Q81omBDU86of5QH@Kooooo1_lF5QH7oeMGE`Oo[Jf]1ol^;Rh7ohb<S0OoJf][1omIFET6ofYZJPKo
oooo1omHF5P7om3@d0Ko?clo1onOWil7om_Kf`Oo?Cdm1omWIfL6ob`/;0Kooooo1olK6a/7oahN7POo
8B4Q1ol/;2`6ob0P80Oo410@1olR8R86oa/K6`Kooooo1olV9RH7oahN7POo:2PX1oln?Sh7ocPh>0Oo
=CDe1_l/;2`6obd];@Kooooo1ol<30`7oaTI6@OoG5aL1ol00007ob@T90OoRHV91olD51@6ob/[:`Go
oooo1oono_h7oaLG5`Oo7alO1onf][H7oa4A4@Oo=3@d1omFEUH6obHV9Pgooooo000;ooooo`Oo<30`
1ol?3`l7od=3@`OoPh>31oln?Sh7oaLG5`Oo820P1_lW9bL5ooooo`Oo>c/k1omNGUh7oeQHF0OoCDe=
1ombLW87odQ8B0OoDU9B1_mQHF46ooooo`Ko5QHF1omGEeL7ojf][@Oo;Rh^1on<S8`7of][J`OoFEUI
1_mZJVX6ooooo`OoF5QH1oo@d=06oclo?`OoWinO1ooKfm/7ocdm?@OoIfMW1_l/;2`6ooooo`Oo6a/K
1olN7Qh7ob4Q8@Oo;2`/1_lP8207oa0@40Oo8R8R1_lK6a/6ooooo`Oo9RHV1olN7Qh7obPX:0Oo?Shn
1olh>3P7ocDe=@Ko;2`/1_l];Bd6ooooo`Oo30`<1olI6AT7oeaLG0Oo00001olT92@7ohV9R@Oo51@D
1_l[:b/5ooooo`Ooo_kn1olG5aL7oalO7`Oo][Jf1olA4A47oc@d=0OoEUIF1_lV9RH=ooooo`002ooo
ool7oc0`<0Oo3`l?1om3@d<7oh>3P`Oo?Shn1olG5aL7ob0P80Ko9bLW1Oooool7oc/k>`OoGUiN1omH
F5P7ode=C@OoLW9b1om8B4P7oe9BDPKoHF5Q1_ooool6oaHF5POoEeMG1on][Jd7obh^;POoS8b<1om[
Jf/7oeUIF@KoJVYZ1_ooool7oeQHF0Ood=3@1_lo?cl7oinOW`Oofm_K1olm?Cd7ofMWI`Ko;2`/1_oo
ool7oa/K6`Oo7QhN1olQ8B47ob`/;0Ko820P1ol@4107ob8R8PKo6a/K1_ooool7obHV9POo7QhN1olX
:2P7ochn?POo>3Ph1ole=CD6ob`/;0Ko;Bd]1_ooool7o``<30Oo6ATI1omLG5`7o`0000Oo92@T1on9
RHT7oa@D50Ko:b/[1Oooool7ooknoPOo5aLG1olO7al7okJf]POo4A4A1old=3@7oeIFEPKo9RHV3Ooo
ool000_ooooo1olF5QH7ocXj>POoCDe=1omBDU87oa@D50Oo;2`/1olI6AT6o`T92@Gooooo1omOGel7
ofEUI@OoM7Ad1ombLW87oiVIV@OoDE5A1om8B4P6od92@PKooooo1_lH61P7ohN7Q`Oo7AdM1ol410@7
olG5a@Oo6ATI1olg=cL6ohB4Q0Kooooo1oln?Sh7omCDe0Ko7AdM1ookno/7oiZJVPOo=cLg1oooool6
ob4Q8@Kooooo1olC4a<7o`l?3`Oo1@D51olI6AT6oa/K6`Oo3@d=1olI6AT6oaLG5`Kooooo1ol<30`7
ob8R8Pko5ADE1olL71`7oaLG5`Ko;bl_1_lI6AT6ooooo`Oo5aLG1olZ:RX7odm?C`Oo30`<1om2@T87
oaHF5POo1@D51_m2@T85ooooo`OoP8201om5ADD7oj^[Z`OoGemO1olN7Qh7ojj^[POo8R8R1_lB4Q8=
ooooo`002oooool7oaHF5POo>SXj1om=CDd7oe9BDPOo51@D1ol/;2`7oaTI6@Ko2@T91Oooool7oemO
G`OoIFEU1omdM7@7og9bLPOoVIVI1omADE47odQ8B0Ko@T921_ooool6oaPH60OoQhN71olM7Ad7o`@4
10OoaLG51olI6AT7ocLg=`KoQ8B41_ooool7ochn?POoe=CD1_lM7Ad7oo_kn`OoVYZJ1olg=cL7oooo
o`Ko8B4Q1_ooool7oa<C4`Oo3`l?1ol51@D7oaTI6@Ko6a/K1ol=3@d7oaTI6@Ko5aLG1_ooool7o``<
30Oo8R8R3_lE5AD7oa`L70Oo5aLG1_l_;bl6oaTI6@Kooooo1olG5aL7obXZ:POoCdm?1ol<30`7od92
@POo5QHF1ol51@D6od92@PGooooo1on0P807odE5A@OoZj^[1omOGel7oahN7POo[Zj^1olR8R86oa8B
4Pgooooo000;ooooo`Oo5QHF1olj>SX7ode=C@OoDU9B1olD51@7ob`/;0Oo6ATI1_l92@T5ooooo`Oo
GemO1omUIFD7ogAdM0OoLW9b1onIVIT7oe5AD@OoB4Q81_m2@T86ooooo`Ko61PH1on7QhL7oadM7@Oo
10@41oo5aLD7oaTI6@Oo=cLg1_n4Q8@6ooooo`Oo?Shn1ooDe=@6oadM7@Oono_k1onJVYX7ocLg=`Oo
oooo1_lQ8B46ooooo`Oo4a<C1ol?3`l7o`D51@Oo6ATI1_lK6a/7o`d=3@Oo6ATI1_lG5aL6ooooo`Oo
30`<1olR8R8>oaDE5@Oo71`L1olG5aL6obl_;`Ko6ATI1_ooool7oaLG5`Oo:RXZ1om?Cdl7o``<30Oo
@T921olF5QH7o`D51@Ko@T921Oooool7oh20P0OoADE51on[Zj/7oemOG`Oo7QhN1on^[Zh7ob8R8PKo
4Q8B3Oooool000_ooooo1olF5QH7ocXj>POoCDe=1omBDU87oa@D50Oo;2`/1olI6AT6o`T92@Gooooo
1omOGel7ofEUI@OoM7Ad1ombLW87oiVIV@OoDE5A1om8B4P6od92@PKooooo1_lH61P7ohN7Q`Oo7AdM
1ol410@7olG5a@Oo6ATI1olg=cL6ohB4Q0Kooooo1oln?Sh7omCDe0Ko7AdM1ookno/7oiZJVPOo=cLg
1oooool6ob4Q8@Kooooo1olC4a<7o`l?3`Oo1@D51olI6AT6oa/K6`Oo3@d=1olI6AT6oaLG5`Kooooo
1ol<30`7ob8R8Pko5ADE1olL71`7oaLG5`Ko;bl_1_lI6AT6ooooo`Oo5aLG1olZ:RX7odm?C`Oo30`<
1om2@T87oaHF5POo1@D51_m2@T85ooooo`OoP8201om5ADD7oj^[Z`OoGemO1olN7Qh7ojj^[POo8R8R
1_lB4Q8=ooooo`002oooool7oaHF5POo>SXj1om=CDd7oe9BDPOo51@D1ol/;2`7oaTI6@Ko2@T91Ooo
ool7oemOG`OoIFEU1omdM7@7og9bLPOoVIVI1omADE47odQ8B0Ko@T921_ooool6oaPH60OoQhN71olM
7Ad7o`@410OoaLG51olI6AT7ocLg=`KoQ8B41_ooool7ochn?POoe=CD1_lM7Ad7oo_kn`OoVYZJ1olg
=cL7ooooo`Ko8B4Q1_ooool7oa<C4`Oo3`l?1ol51@D7oaTI6@Ko6a/K1ol=3@d7oaTI6@Ko5aLG1_oo
ool7o``<30Oo8R8R3_lE5AD7oa`L70Oo5aLG1_l_;bl6oaTI6@Kooooo1olG5aL7obXZ:POoCdm?1ol<
30`7od92@POo5QHF1ol51@D6od92@PGooooo1on0P807odE5A@OoZj^[1omOGel7oahN7POo[Zj^1olR
8R86oa8B4Pgooooo000;ooooo`Oo5QHF1olj>SX7ode=C@OoDU9B1olD51@7ob`/;0Oo6ATI1_l92@T5
ooooo`OoGemO1omUIFD7ogAdM0OoLW9b1onIVIT7oe5AD@OoB4Q81_m2@T86ooooo`Ko61PH1on7QhL7
oadM7@Oo10@41oo5aLD7oaTI6@Oo=cLg1_n4Q8@6ooooo`Oo?Shn1ooDe=@6oadM7@Oono_k1onJVYX7
ocLg=`Oooooo1_lQ8B46ooooo`Oo4a<C1ol?3`l7o`D51@Oo6ATI1_lK6a/7o`d=3@Oo6ATI1_lG5aL6
ooooo`Oo30`<1olR8R8>oaDE5@Oo71`L1olG5aL6obl_;`Ko6ATI1_ooool7oaLG5`Oo:RXZ1om?Cdl7
o``<30Oo@T921olF5QH7o`D51@Ko@T921Oooool7oh20P0OoADE51on[Zj/7oemOG`Oo7QhN1on^[Zh7
ob8R8PKo4Q8B3Oooool000_ooooo1olF5QH7ocXj>POoCDe=1omBDU87oa@D50Oo;2`/1olI6AT6o`T9
2@Gooooo1omOGel7ofEUI@OoM7Ad1ombLW87oiVIV@OoDE5A1om8B4P6od92@PKooooo1_lH61P7ohN7
Q`Oo7AdM1ol410@7olG5a@Oo6ATI1olg=cL6ohB4Q0Kooooo1oln?Sh7omCDe0Ko7AdM1ookno/7oiZJ
VPOo=cLg1oooool6ob4Q8@Kooooo1olC4a<7o`l?3`Oo1@D51olI6AT6oa/K6`Oo3@d=1olI6AT6oaLG
5`Kooooo1ol<30`7ob8R8Pko5ADE1olL71`7oaLG5`Ko;bl_1_lI6AT6ooooo`Oo5aLG1olZ:RX7odm?
C`Oo30`<1om2@T87oaHF5POo1@D51_m2@T85ooooo`OoP8201om5ADD7oj^[Z`OoGemO1olN7Qh7ojj^
[POo8R8R1_lB4Q8=ooooo`002oooool7obLW9`Oo00001oln?Sh7oe9BDPOo;bl_1ol@4107oa@D50Ko
:b/[1Oooool7odm?C`OoFe]K1om?Cdl7ofe]K@OoHV9R1om;Bd/7oc`l?0KoBd];1_ooool6obXZ:POo
820P1olV9RH7odA4A0Oo8b<S1olf=SH7ohF5Q@Ko8b<S1_ooool7ohR8R0Oo@4101_lU9BD7ono_k`Oo
D51@1olk>c/7ol[:bPKo71`L1_ooool7obHV9POo:RXZ1olY:BT7obd];@Ko6ATI1olL71`7oalO7`Ko
6a/K1_ooool7o`/;2`Oo6a/K1ol?3`l7o`D51@Oo00001ol20P86oa4A4@Ko6ATI1_ooool7oalO7`Oo
`/;21olD51@7oalO7`OoIVIV1olM7Ad7ob0P80Ko;Bd]1Oooool7ooGem@Oo5aLG1omSHf<7ok6a/@Oo
ADE51omMGEd7odU9B@KoRh^;3Oooool000_ooooo1olW9bL7o`0000Oo?Shn1omBDU87obl_;`Oo410@
1olD51@6ob/[:`Gooooo1om?Cdl7oe]KF`OoCdm?1om]KFd7of9RHPOoBd];1oll?3`6od];B`Kooooo
1_lZ:RX7ob0P80Oo9RHV1om4A4@7ob<S8`Oo=SHf1on5QHD6ob<S8`Kooooo1on8R8P7od10@0Ko9BDU
1oo_knl7oe1@D0Oo>c/k1oo:b/X6oa`L70Kooooo1olV9RH7obXZ:POo:BTY1ol];Bd6oaTI6@Oo71`L
1olO7al6oa/K6`Kooooo1ol;2`/7oa/K6`Oo3`l?1ol51@D7o`0000Oo0P821_lA4A46oaTI6@Kooooo
1olO7al7ol;2`POo51@D1olO7al7ofIVIPOo7AdM1olP8206obd];@Gooooo1ooemOD7oaLG5`OoHf=S
1ona/K47odE5A@OoGEeM1om9BDT6oh^;R`gooooo000;ooooo`Oo9bLW1ol00007ochn?POoDU9B1ol_
;bl7oa0@40Oo51@D1_l[:b/5ooooo`OoCdm?1omKFe/7odm?C`OoKFe]1omRHV87od];B`Oo?3`l1_m;
Bd/6ooooo`Ko:RXZ1olP8207obHV9POoA4A41olS8b<7ocHf=POoQHF51_lS8b<6ooooo`OoR8R81om0
@406obDU9@Ookno_1om@D507oc/k>`Oob/[:1_lL71`6ooooo`Oo9RHV1olZ:RX7obTY:@Oo;Bd]1_lI
6AT7oa`L70Oo7alO1_lK6a/6ooooo`Oo2`/;1olK6a/7o`l?3`Oo1@D51ol00007o`820PKo4A4A1_lI
6AT6ooooo`Oo7alO1oo2`/87oa@D50Oo7alO1omVIVH7oadM7@Oo820P1_l];Bd5ooooo`OomOGe1olG
5aL7of=SH`Oo/K6a1om5ADD7oeeMG@OoBDU91_n;Rh/=ooooo`002oooool7obLW9`Oo00001oln?Sh7
oe9BDPOo;bl_1ol@4107oa@D50Ko:b/[1Oooool7odm?C`OoFe]K1om?Cdl7ofe]K@OoHV9R1om;Bd/7
oc`l?0KoBd];1_ooool6obXZ:POo820P1olV9RH7odA4A0Oo8b<S1olf=SH7ohF5Q@Ko8b<S1_ooool7
ohR8R0Oo@4101_lU9BD7ono_k`OoD51@1olk>c/7ol[:bPKo71`L1_ooool7obHV9POo:RXZ1olY:BT7
obd];@Ko6ATI1olL71`7oalO7`Ko6a/K1_ooool7o`/;2`Oo6a/K1ol?3`l7o`D51@Oo00001ol20P86
oa4A4@Ko6ATI1_ooool7oalO7`Oo`/;21olD51@7oalO7`OoIVIV1olM7Ad7ob0P80Ko;Bd]1Oooool7
ooGem@Oo5aLG1omSHf<7ok6a/@OoADE51omMGEd7odU9B@KoRh^;3Oooool000_ooooo1olW9bL7o`00
00Oo?Shn1omBDU87obl_;`Oo410@1olD51@6ob/[:`Gooooo1om?Cdl7oe]KF`OoCdm?1om]KFd7of9R
HPOoBd];1oll?3`6od];B`Kooooo1_lZ:RX7ob0P80Oo9RHV1om4A4@7ob<S8`Oo=SHf1on5QHD6ob<S
8`Kooooo1on8R8P7od10@0Ko9BDU1oo_knl7oe1@D0Oo>c/k1oo:b/X6oa`L70Kooooo1olV9RH7obXZ
:POo:BTY1ol];Bd6oaTI6@Oo71`L1olO7al6oa/K6`Kooooo1ol;2`/7oa/K6`Oo3`l?1ol51@D7o`00
00Oo0P821_lA4A46oaTI6@Kooooo1olO7al7ol;2`POo51@D1olO7al7ofIVIPOo7AdM1olP8206obd]
;@Gooooo1ooemOD7oaLG5`OoHf=S1ona/K47odE5A@OoGEeM1om9BDT6oh^;R`gooooo000;ooooo`Oo
9bLW1ol00007ochn?POoDU9B1ol_;bl7oa0@40Oo51@D1_l[:b/5ooooo`OoCdm?1omKFe/7odm?C`Oo
KFe]1omRHV87od];B`Oo?3`l1_m;Bd/6ooooo`Ko:RXZ1olP8207obHV9POoA4A41olS8b<7ocHf=POo
QHF51_lS8b<6ooooo`OoR8R81om0@406obDU9@Ookno_1om@D507oc/k>`Oob/[:1_lL71`6ooooo`Oo
9RHV1olZ:RX7obTY:@Oo;Bd]1_lI6AT7oa`L70Oo7alO1_lK6a/6ooooo`Oo2`/;1olK6a/7o`l?3`Oo
1@D51ol00007o`820PKo4A4A1_lI6AT6ooooo`Oo7alO1oo2`/87oa@D50Oo7alO1omVIVH7oadM7@Oo
820P1_l];Bd5ooooo`OomOGe1olG5aL7of=SH`Oo/K6a1om5ADD7oeeMG@OoBDU91_n;Rh/=ooooo`00
2oooool7obLW9`Oo00001oln?Sh7oe9BDPOo;bl_1ol@4107oa@D50Ko:b/[1Oooool7odm?C`OoFe]K
1om?Cdl7ofe]K@OoHV9R1om;Bd/7oc`l?0KoBd];1_ooool6obXZ:POo820P1olV9RH7odA4A0Oo8b<S
1olf=SH7ohF5Q@Ko8b<S1_ooool7ohR8R0Oo@4101_lU9BD7ono_k`OoD51@1olk>c/7ol[:bPKo71`L
1_ooool7obHV9POo:RXZ1olY:BT7obd];@Ko6ATI1olL71`7oalO7`Ko6a/K1_ooool7o`/;2`Oo6a/K
1ol?3`l7o`D51@Oo00001ol20P86oa4A4@Ko6ATI1_ooool7oalO7`Oo`/;21olD51@7oalO7`OoIVIV
1olM7Ad7ob0P80Ko;Bd]1Oooool7ooGem@Oo5aLG1omSHf<7ok6a/@OoADE51omMGEd7odU9B@KoRh^;
3Oooool000_ooooo1olQ8B47oahN7POo@d=31omKFe/7oaPH60Oo410@1ol>3Ph6oahN7PGooooo1olg
=cL7ocDe=@Oo>3Ph1olP8207oaPH60Oo820P1olR8R86oa`L70Kooooo1_m8B4P7ob<S8`Oo00001olW
9bL7odU9B@Oo2`/;1om3@d<6od10@0Kooooo1ol^;Rh7ohV9R@Ko:b/[1omIFET7oeMGE`OoOGem1omf
MWH6oa/K6`Kooooo1onSXj<7om_Kf`Oooooo1onFUYH6odQ8B0Oo8R8R1olW9bL6oaDE5@Kooooo1olQ
8B47oa`L70Oo4A4A1olJ6QX7obTY:@Oo7AdM1_lG5aL6ob4Q8@Kooooo3_mHF5P7od=3@`Oob<S81olb
<S87oa0@40OoJFUY1_lQ8B45ooooo`Ood];B1ol@4107on;RhPOoHf=S1olN7Qh7ooooo`Oo4Q8B1_m2
@T8=ooooo`002oooool7ob4Q8@Oo7QhN1om3@d<7oe]KF`Oo61PH1ol@4107o`h>3PKo7QhN1Oooool7
ocLg=`Oo=CDe1olh>3P7ob0P80Oo61PH1olP8207ob8R8PKo71`L1_ooool6odQ8B0Oo8b<S1ol00007
obLW9`OoBDU91ol;2`/7od=3@`Ko@4101_ooool7obh^;POoRHV91_l[:b/7oeUIF@OoEeMG1ommOGd7
ogIfMPKo6a/K1_ooool7oj>SX`Oofm_K1oooool7oiJFUPKoB4Q81olR8R87obLW9`Ko5ADE1_ooool7
ob4Q8@Oo71`L1olA4A47oaXJ6POo:BTY1olM7Ad6oaLG5`Ko8B4Q1_ooool>oeQHF0Oo@d=31oo8b<P7
oc8b<POo410@1omYJFT6ob4Q8@Gooooo1ooBd]87oa0@40Ooh^;R1omSHf<7oahN7POooooo1olB4Q86
od92@Pgooooo000;ooooo`Oo8B4Q1olN7Qh7od=3@`OoFe]K1olH61P7oa0@40Oo3Ph>1_lN7Qh5oooo
o`Oo=cLg1ole=CD7ocPh>0Oo820P1olH61P7ob0P80Oo8R8R1_lL71`6ooooo`KoB4Q81olS8b<7o`00
00Oo9bLW1om9BDT7o`/;2`Oo@d=31_m0@406ooooo`Oo;Rh^1on9RHT6ob/[:`OoFEUI1omGEeL7ogem
O@OoMWIf1_lK6a/6ooooo`OoXj>S1ooKfm/7ooooo`OoUYJF1_m8B4P7ob8R8POo9bLW1_lE5AD6oooo
o`Oo8B4Q1olL71`7oa4A4@Oo6QXJ1olY:BT7oadM7@Ko5aLG1_lQ8B46ooooo`koF5QH1om3@d<7olS8
b0Oo<S8b1ol@4107ofUYJ@Ko8B4Q1Oooool7om;BdPOo410@1ooRh^87of=SH`Oo7QhN1oooool7oa8B
4PKo@T923Oooool000_ooooo1olQ8B47oahN7POo@d=31omKFe/7oaPH60Oo410@1ol>3Ph6oahN7PGo
oooo1olg=cL7ocDe=@Oo>3Ph1olP8207oaPH60Oo820P1olR8R86oa`L70Kooooo1_m8B4P7ob<S8`Oo
00001olW9bL7odU9B@Oo2`/;1om3@d<6od10@0Kooooo1ol^;Rh7ohV9R@Ko:b/[1omIFET7oeMGE`Oo
OGem1omfMWH6oa/K6`Kooooo1onSXj<7om_Kf`Oooooo1onFUYH6odQ8B0Oo8R8R1olW9bL6oaDE5@Ko
oooo1olQ8B47oa`L70Oo4A4A1olJ6QX7obTY:@Oo7AdM1_lG5aL6ob4Q8@Kooooo3_mHF5P7od=3@`Oo
b<S81olb<S87oa0@40OoJFUY1_lQ8B45ooooo`Ood];B1ol@4107on;RhPOoHf=S1olN7Qh7ooooo`Oo
4Q8B1_m2@T8=ooooo`002oooool7ob4Q8@Oo7QhN1om3@d<7oe]KF`Oo61PH1ol@4107o`h>3PKo7QhN
1Oooool7ocLg=`Oo=CDe1olh>3P7ob0P80Oo61PH1olP8207ob8R8PKo71`L1_ooool6odQ8B0Oo8b<S
1ol00007obLW9`OoBDU91ol;2`/7od=3@`Ko@4101_ooool7obh^;POoRHV91_l[:b/7oeUIF@OoEeMG
1ommOGd7ogIfMPKo6a/K1_ooool7oj>SX`Oofm_K1oooool7oiJFUPKoB4Q81olR8R87obLW9`Ko5ADE
1_ooool7ob4Q8@Oo71`L1olA4A47oaXJ6POo:BTY1olM7Ad6oaLG5`Ko8B4Q1_ooool>oeQHF0Oo@d=3
1oo8b<P7oc8b<POo410@1omYJFT6ob4Q8@Gooooo1ooBd]87oa0@40Ooh^;R1omSHf<7oahN7POooooo
1olB4Q86od92@Pgooooo000;ooooo`Oo8B4Q1olN7Qh7od=3@`OoFe]K1olH61P7oa0@40Oo3Ph>1_lN
7Qh5ooooo`Oo=cLg1ole=CD7ocPh>0Oo820P1olH61P7ob0P80Oo8R8R1_lL71`6ooooo`KoB4Q81olS
8b<7o`0000Oo9bLW1om9BDT7o`/;2`Oo@d=31_m0@406ooooo`Oo;Rh^1on9RHT6ob/[:`OoFEUI1omG
EeL7ogemO@OoMWIf1_lK6a/6ooooo`OoXj>S1ooKfm/7ooooo`OoUYJF1_m8B4P7ob8R8POo9bLW1_lE
5AD6ooooo`Oo8B4Q1olL71`7oa4A4@Oo6QXJ1olY:BT7oadM7@Ko5aLG1_lQ8B46ooooo`koF5QH1om3
@d<7olS8b0Oo<S8b1ol@4107ofUYJ@Ko8B4Q1Oooool7om;BdPOo410@1ooRh^87of=SH`Oo7QhN1ooo
ool7oa8B4PKo@T923Oooool000_ooooo1olQ8B47oahN7POo@d=31omKFe/7oaPH60Oo410@1ol>3Ph6
oahN7PGooooo1olg=cL7ocDe=@Oo>3Ph1olP8207oaPH60Oo820P1olR8R86oa`L70Kooooo1_m8B4P7
ob<S8`Oo00001olW9bL7odU9B@Oo2`/;1om3@d<6od10@0Kooooo1ol^;Rh7ohV9R@Ko:b/[1omIFET7
oeMGE`OoOGem1omfMWH6oa/K6`Kooooo1onSXj<7om_Kf`Oooooo1onFUYH6odQ8B0Oo8R8R1olW9bL6
oaDE5@Kooooo1olQ8B47oa`L70Oo4A4A1olJ6QX7obTY:@Oo7AdM1_lG5aL6ob4Q8@Kooooo3_mHF5P7
od=3@`Oob<S81olb<S87oa0@40OoJFUY1_lQ8B45ooooo`Ood];B1ol@4107on;RhPOoHf=S1olN7Qh7
ooooo`Oo4Q8B1_m2@T8=ooooo`002oooool7obh^;POo5aLG1ol_;bl7oe1@D0Oo:b/[1olH61P7obPX
:0Ko410@1Oooool7oc0`<0Oo7alO1olY:BT7o`0000Oo3Ph>1ol30`<7o`/;2`Ko4A4A1_ooool6oeaL
G0OoE5AD1olc<c<7obXZ:POo7AdM1olC4a<7odY:BPKo00001_ooool7of1PH0Oo51@D1_lJ6QX7okjn
_POo2@T91olZ:RX7okno_`Ko9BDU1_ooool7oc`l?0Oo?Cdm1om4A4@7obTY:@Ko7QhN1ol[:b/7o`l?
3`Ko4A4A1_ooool7obDU9@Oo@T921oli>CT7of=SH`OoGUiN1omFEUH6ocTi>@Ko<C4a1_ooool7obXZ
:POogMgM1olR8R87ochn?POoQ8B41om9BDT7oda<C0Ko;2`/1Oooool7ofEUI@Oo410@1ooBd]87ofEU
I@Oo@d=31onUYJD7oadM7@Kob/[:3Oooool000_ooooo1ol^;Rh7oaLG5`Oo;bl_1om@D507ob/[:`Oo
61PH1olX:2P6oa0@40Gooooo1ol`<307oalO7`Oo:BTY1ol00007o`h>3POo0`<31ol;2`/6oa4A4@Ko
oooo1_mLG5`7oeADE0Oo<c<c1olZ:RX7oadM7@Oo4a<C1om:BTX6o`0000Kooooo1omPH607oa@D50Ko
6QXJ1onn_[h7o`T92@Oo:RXZ1ono_kl6obDU9@Kooooo1oll?3`7ocdm?@OoA4A41olY:BT6oahN7POo
:b/[1ol?3`l6oa4A4@Kooooo1olU9BD7od92@POo>CTi1omSHf<7oeiNGPOoEUIF1_li>CT6oc4a<@Ko
oooo1olZ:RX7omgMg@Oo8R8R1oln?Sh7ohB4Q0OoBDU91om<C4`6ob`/;0Gooooo1omUIFD7oa0@40Oo
d];B1omUIFD7od=3@`OoYJFU1olM7Ad6ol[:bPgooooo000;ooooo`Oo;Rh^1olG5aL7obl_;`OoD51@
1ol[:b/7oaPH60Oo:2PX1_l@4105ooooo`Oo<30`1olO7al7obTY:@Oo00001ol>3Ph7o`<30`Oo2`/;
1_lA4A46ooooo`KoG5aL1omDE5@7oc<c<`Oo:RXZ1olM7Ad7oa<C4`OoBTY:1_l00006ooooo`OoH61P
1olD51@6oaXJ6POo_[jn1ol92@T7obXZ:POo_kno1_lU9BD6ooooo`Oo?3`l1olm?Cd7odA4A0Oo:BTY
1_lN7Qh7ob/[:`Oo3`l?1_lA4A46ooooo`Oo9BDU1om2@T87ocTi>@OoHf=S1omNGUh7oeIFEPKo>CTi
1_la<C46ooooo`Oo:RXZ1ooMgMd7ob8R8POo?Shn1on4Q8@7odU9B@OoC4a<1_l/;2`5ooooo`OoIFEU
1ol@4107om;BdPOoIFEU1om3@d<7ojFUY@Oo7AdM1_o:b/X=ooooo`002oooool7obh^;POo5aLG1ol_
;bl7oe1@D0Oo:b/[1olH61P7obPX:0Ko410@1Oooool7oc0`<0Oo7alO1olY:BT7o`0000Oo3Ph>1ol3
0`<7o`/;2`Ko4A4A1_ooool6oeaLG0OoE5AD1olc<c<7obXZ:POo7AdM1olC4a<7odY:BPKo00001_oo
ool7of1PH0Oo51@D1_lJ6QX7okjn_POo2@T91olZ:RX7okno_`Ko9BDU1_ooool7oc`l?0Oo?Cdm1om4
A4@7obTY:@Ko7QhN1ol[:b/7o`l?3`Ko4A4A1_ooool7obDU9@Oo@T921oli>CT7of=SH`OoGUiN1omF
EUH6ocTi>@Ko<C4a1_ooool7obXZ:POogMgM1olR8R87ochn?POoQ8B41om9BDT7oda<C0Ko;2`/1Ooo
ool7ofEUI@Oo410@1ooBd]87ofEUI@Oo@d=31onUYJD7oadM7@Kob/[:3Oooool000_ooooo1ol^;Rh7
oaLG5`Oo;bl_1om@D507ob/[:`Oo61PH1olX:2P6oa0@40Gooooo1ol`<307oalO7`Oo:BTY1ol00007
o`h>3POo0`<31ol;2`/6oa4A4@Kooooo1_mLG5`7oeADE0Oo<c<c1olZ:RX7oadM7@Oo4a<C1om:BTX6
o`0000Kooooo1omPH607oa@D50Ko6QXJ1onn_[h7o`T92@Oo:RXZ1ono_kl6obDU9@Kooooo1oll?3`7
ocdm?@OoA4A41olY:BT6oahN7POo:b/[1ol?3`l6oa4A4@Kooooo1olU9BD7od92@POo>CTi1omSHf<7
oeiNGPOoEUIF1_li>CT6oc4a<@Kooooo1olZ:RX7omgMg@Oo8R8R1oln?Sh7ohB4Q0OoBDU91om<C4`6
ob`/;0Gooooo1omUIFD7oa0@40Ood];B1omUIFD7od=3@`OoYJFU1olM7Ad6ol[:bPgooooo000;oooo
o`Oo;Rh^1olG5aL7obl_;`OoD51@1ol[:b/7oaPH60Oo:2PX1_l@4105ooooo`Oo<30`1olO7al7obTY
:@Oo00001ol>3Ph7o`<30`Oo2`/;1_lA4A46ooooo`KoG5aL1omDE5@7oc<c<`Oo:RXZ1olM7Ad7oa<C
4`OoBTY:1_l00006ooooo`OoH61P1olD51@6oaXJ6POo_[jn1ol92@T7obXZ:POo_kno1_lU9BD6oooo
o`Oo?3`l1olm?Cd7odA4A0Oo:BTY1_lN7Qh7ob/[:`Oo3`l?1_lA4A46ooooo`Oo9BDU1om2@T87ocTi
>@OoHf=S1omNGUh7oeIFEPKo>CTi1_la<C46ooooo`Oo:RXZ1ooMgMd7ob8R8POo?Shn1on4Q8@7odU9
B@OoC4a<1_l/;2`5ooooo`OoIFEU1ol@4107om;BdPOoIFEU1om3@d<7ojFUY@Oo7AdM1_o:b/X=oooo
o`002oooool7odQ8B0Oo;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo
;2`/1om>CTh7ocHf=POoEeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo
92@T1olh>3P6o`h>3PKooooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKo
oooo1ol92@T7o`0000Oo6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo
>3Ph1olo?cl7ob0P80Ko<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oo
hn?S1_lD51@5ooooo`OoT92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`00
2oooool7odQ8B0Oo;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/
1om>CTh7ocHf=POoEeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T
1olh>3P6o`h>3PKooooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo
1ol92@T7o`0000Oo6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph
1olo?cl7ob0P80Ko<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S
1_lD51@5ooooo`OoT92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002ooo
ool7odQ8B0Oo;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/1om>
CTh7ocHf=POoEeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T1olh
>3P6o`h>3PKooooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo1ol9
2@T7o`0000Oo6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph1olo
?cl7ob0P80Ko<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S1_lD
51@5ooooo`OoT92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002oooool7
odQ8B0Oo;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/1om>CTh7
ocHf=POoEeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T1olh>3P6
o`h>3PKooooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo1ol92@T7
o`0000Oo6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph1olo?cl7
ob0P80Ko<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S1_lD51@5
ooooo`OoT92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002oooool7odQ8
B0Oo;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/1om>CTh7ocHf
=POoEeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T1olh>3P6o`h>
3PKooooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo1ol92@T7o`00
00Oo6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph1olo?cl7ob0P
80Ko<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S1_lD51@5oooo
o`OoT92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002oooool7odQ8B0Oo
;2`/1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/1om>CTh7ocHf=POo
EeMG1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T1olh>3P6o`h>3PKo
oooo1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo1ol92@T7o`0000Oo
6a/K1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph1olo?cl7ob0P80Ko
<c<c1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S1_lD51@5ooooo`Oo
T92@1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002oooool7odQ8B0Oo;2`/
1oooool7oi^KV`Oo:b/[1olk>c/7obXZ:PKo<S8b1Oooool7oc0`<0Oo;2`/1om>CTh7ocHf=POoEeMG
1omPH607ochn?PKoBDU93?ooool7obTY:@Oo820P1onRXZ87oaPH60Oo92@T1olh>3P6o`h>3PKooooo
1om1@D47oa`L70KoB4Q81oli>CT7oa4A4@OoH61P1olP8206o`h>3PKooooo1ol92@T7o`0000Oo6a/K
1ol51@D6o`d=3@Oo1PH63OlF5QH6ooooo`Oo71`L1olT92@7oc4a<@Oo>3Ph1olo?cl7ob0P80Ko<c<c
1_lU9BD6ooooo`OoUYJF1onPX:07oa`L70Oooooo1om2@T87ob0P80Oohn?S1_lD51@5ooooo`OoT92@
1olX:2P7ogMgM`OoEEEE1om]KFd7oj>SX`Oo6a/K1_n>SXh=ooooo`002oooool7oalO7`Oo;2`/1om@
D507ochn?POo;Bd]1olG5aL7oa`L70Ko;Rh^1Oooool7ohN7Q`Ood];B1ooXj>P7ooooo`OokNg]1ooC
dm<7oj^[Z`KoQHF51_ooool6ohj>SPOo=cLg1ooXj>P7odU9B@Oo7AdM1ooUiND7oaTI6@Ko7alO1_oo
ool7ob@T90Oo:2PX1_meMGD7obXZ:POo5QHF1oll?3`7od92@PKo5ADE1_ooool7obHV9POo51@D1olL
71`7oa/K6`Ko410@1olG5aL7o`h>3PKo71`L1_ooool7ob@T90Oo9BDU1olL71`7oahN7POo5aLG1ol_
;bl6ob8R8PKo9RHV1_ooool7ohR8R0OoOgmo1olI6AT7ok6a/@OoDe=C1om]KFd7ogYjNPKo4A4A1Ooo
ool7o`T92@Oo3Ph>1onf][H7o`h>3POo=CDe1onc/k<7oaPH60KoXj>S3Oooool000_ooooo1olO7al7
ob`/;0OoD51@1oln?Sh7obd];@Oo5aLG1olL71`6obh^;PGooooo1on7QhL7om;BdPOoj>SX1oooool7
ong]k@Oodm?C1on[Zj/6ohF5Q@Kooooo1_n>SXh7ocLg=`Ooj>SX1om9BDT7oadM7@OoiNGU1olI6AT6
oalO7`Kooooo1olT92@7obPX:0KoMGEe1olZ:RX7oaHF5POo?3`l1om2@T86oaDE5@Kooooo1olV9RH7
oa@D50Oo71`L1olK6a/6oa0@40Oo5aLG1ol>3Ph6oa`L70Kooooo1olT92@7obDU9@Oo71`L1olN7Qh7
oaLG5`Oo;bl_1_lR8R86obHV9PKooooo1on8R8P7ogmoO`Oo6ATI1ona/K47oe=CD`OoKFe]1omjNWX6
oa4A4@Gooooo1ol92@T7o`h>3POo][Jf1ol>3Ph7ocDe=@Oo/k>c1olH61P6oj>SX`gooooo000;oooo
o`Oo7alO1ol/;2`7oe1@D0Oo?Shn1ol];Bd7oaLG5`Oo71`L1_l^;Rh5ooooo`OoQhN71ooBd]87onSX
j0Oooooo1oo]kNd7om?Cd`OoZj^[1_n5QHD6ooooo`KoSXj>1olg=cL7onSXj0OoBDU91olM7Ad7onGU
i@Oo6ATI1_lO7al6ooooo`Oo92@T1olX:2P6ogEeM@Oo:RXZ1olF5QH7oc`l?0Oo@T921_lE5AD6oooo
o`Oo9RHV1olD51@7oa`L70Oo6a/K1_l@4107oaLG5`Oo3Ph>1_lL71`6ooooo`Oo92@T1olU9BD7oa`L
70Oo7QhN1olG5aL7obl_;`Ko8R8R1_lV9RH6ooooo`OoR8R81omoOgl7oaTI6@Oo/K6a1omCDe<7ofe]
K@OoNWYj1_lA4A45ooooo`Oo2@T91ol>3Ph7okJf]POo3Ph>1ole=CD7ok>c/`Oo61PH1_nSXj<=oooo
o`002oooool7oalO7`Oo;2`/1om@D507ochn?POo;Bd]1olG5aL7oa`L70Ko;Rh^1Oooool7ohN7Q`Oo
d];B1ooXj>P7ooooo`OokNg]1ooCdm<7oj^[Z`KoQHF51_ooool6ohj>SPOo=cLg1ooXj>P7odU9B@Oo
7AdM1ooUiND7oaTI6@Ko7alO1_ooool7ob@T90Oo:2PX1_meMGD7obXZ:POo5QHF1oll?3`7od92@PKo
5ADE1_ooool7obHV9POo51@D1olL71`7oa/K6`Ko410@1olG5aL7o`h>3PKo71`L1_ooool7ob@T90Oo
9BDU1olL71`7oahN7POo5aLG1ol_;bl6ob8R8PKo9RHV1_ooool7ohR8R0OoOgmo1olI6AT7ok6a/@Oo
De=C1om]KFd7ogYjNPKo4A4A1Oooool7o`T92@Oo3Ph>1onf][H7o`h>3POo=CDe1onc/k<7oaPH60Ko
Xj>S3Oooool000_ooooo1olO7al7ob`/;0OoD51@1oln?Sh7obd];@Oo5aLG1olL71`6obh^;PGooooo
1on7QhL7om;BdPOoj>SX1oooool7ong]k@Oodm?C1on[Zj/6ohF5Q@Kooooo1_n>SXh7ocLg=`Ooj>SX
1om9BDT7oadM7@OoiNGU1olI6AT6oalO7`Kooooo1olT92@7obPX:0KoMGEe1olZ:RX7oaHF5POo?3`l
1om2@T86oaDE5@Kooooo1olV9RH7oa@D50Oo71`L1olK6a/6oa0@40Oo5aLG1ol>3Ph6oa`L70Kooooo
1olT92@7obDU9@Oo71`L1olN7Qh7oaLG5`Oo;bl_1_lR8R86obHV9PKooooo1on8R8P7ogmoO`Oo6ATI
1ona/K47oe=CD`OoKFe]1omjNWX6oa4A4@Gooooo1ol92@T7o`h>3POo][Jf1ol>3Ph7ocDe=@Oo/k>c
1olH61P6oj>SX`gooooo000;ooooo`Oo7alO1ol/;2`7oe1@D0Oo?Shn1ol];Bd7oaLG5`Oo71`L1_l^
;Rh5ooooo`OoQhN71ooBd]87onSXj0Oooooo1oo]kNd7om?Cd`OoZj^[1_n5QHD6ooooo`KoSXj>1olg
=cL7onSXj0OoBDU91olM7Ad7onGUi@Oo6ATI1_lO7al6ooooo`Oo92@T1olX:2P6ogEeM@Oo:RXZ1olF
5QH7oc`l?0Oo@T921_lE5AD6ooooo`Oo9RHV1olD51@7oa`L70Oo6a/K1_l@4107oaLG5`Oo3Ph>1_lL
71`6ooooo`Oo92@T1olU9BD7oa`L70Oo7QhN1olG5aL7obl_;`Ko8R8R1_lV9RH6ooooo`OoR8R81omo
Ogl7oaTI6@Oo/K6a1omCDe<7ofe]K@OoNWYj1_lA4A45ooooo`Oo2@T91ol>3Ph7okJf]POo3Ph>1ole
=CD7ok>c/`Oo61PH1_nSXj<=ooooo`002oooool7oalO7`Oo;2`/1om@D507ochn?POo;Bd]1olG5aL7
oa`L70Ko;Rh^1Oooool7ohN7Q`Ood];B1ooXj>P7ooooo`OokNg]1ooCdm<7oj^[Z`KoQHF51_ooool6
ohj>SPOo=cLg1ooXj>P7odU9B@Oo7AdM1ooUiND7oaTI6@Ko7alO1_ooool7ob@T90Oo:2PX1_meMGD7
obXZ:POo5QHF1oll?3`7od92@PKo5ADE1_ooool7obHV9POo51@D1olL71`7oa/K6`Ko410@1olG5aL7
o`h>3PKo71`L1_ooool7ob@T90Oo9BDU1olL71`7oahN7POo5aLG1ol_;bl6ob8R8PKo9RHV1_ooool7
ohR8R0OoOgmo1olI6AT7ok6a/@OoDe=C1om]KFd7ogYjNPKo4A4A1Oooool7o`T92@Oo3Ph>1onf][H7
o`h>3POo=CDe1onc/k<7oaPH60KoXj>S3Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd]
;@Oo92@T1olO7al6ob`/;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;
R`Kooooo1_mRHV87ocLg=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l
?0Oo[Zj^1olo?cl7oc0`<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj
>PKoFe]K1_ooool7oeADE0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5A
D@Oo0P821olk>c/7ohB4Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T9
2@Oo<C4a1olG5aL7obXZ:PKo00003Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd];@Oo
92@T1olO7al6ob`/;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;R`Ko
oooo1_mRHV87ocLg=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l?0Oo
[Zj^1olo?cl7oc0`<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj>PKo
Fe]K1_ooool7oeADE0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5AD@Oo
0P821olk>c/7ohB4Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T92@Oo
<C4a1olG5aL7obXZ:PKo00003Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd];@Oo92@T
1olO7al6ob`/;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;R`Kooooo
1_mRHV87ocLg=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l?0Oo[Zj^
1olo?cl7oc0`<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj>PKoFe]K
1_ooool7oeADE0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5AD@Oo0P82
1olk>c/7ohB4Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T92@Oo<C4a
1olG5aL7obXZ:PKo00003Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd];@Oo92@T1olO
7al6ob`/;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;R`Kooooo1_mR
HV87ocLg=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l?0Oo[Zj^1olo
?cl7oc0`<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj>PKoFe]K1_oo
ool7oeADE0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5AD@Oo0P821olk
>c/7ohB4Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T92@Oo<C4a1olG
5aL7obXZ:PKo00003Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd];@Oo92@T1olO7al6
ob`/;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;R`Kooooo1_mRHV87
ocLg=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l?0Oo[Zj^1olo?cl7
oc0`<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj>PKoFe]K1_ooool7
oeADE0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5AD@Oo0P821olk>c/7
ohB4Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T92@Oo<C4a1olG5aL7
obXZ:PKo00003Oooool000_ooooo1olT92@7ob4Q8@Oo>CTi1omaLG47obd];@Oo92@T1olO7al6ob`/
;0Gooooo1onVYZH7ojZZZPOoX:2P1onKVi/7ojFUY@OoU9BD1onc/k<6oh^;R`Kooooo1_mRHV87ocLg
=`OoADE51olX:2P7og=cL`koAdM71_lg=cL6ooooo`OoD51@1omOGel6oc`l?0Oo[Zj^1olo?cl7oc0`
<0OoBTY:1_l00006ooooo`OoKfm_1omEEED7oeIFEPOoBDU91_mHF5P>ocXj>PKoFe]K1_ooool7oeAD
E0Oo>CTi1on_[jl7ooooo`OoS8b<1omUIFD6og5aL@KoD51@1_ooool7oe5AD@Oo0P821olk>c/7ohB4
Q0Oo3`l?1olR8R87oeaLG0KoB4Q81Oooool7o`l?3`OoJFUY1olW9bL7o`T92@Oo<C4a1olG5aL7obXZ
:PKo00003Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo1olb<S87oalO7`Oo<C4a1om6
ATH7oalO7`OoFe]K1omGEeL6odA4A0Gooooo1olJ6QX7oahN7Pko820P1olT92@7oa`L70Oo:BTY1_lV
9RH6ooooo`KoJFUY1ol[:b/7oclo?`OoBd];1olR8R87oeaLG0Oo<S8b1_lK6a/6ooooo`Oo_;bl1ola
<C46ob0P80Oooooo1ola<C47oeADE0OomOGe1_lS8b<6ooooo`Oo8B4Q1olP8207obTY:@Oo8b<S1_l_
;bl7obLW9`OoVYZJ1_mDE5@6ooooo`Oo820P1olW9bL7oaDE5@Oo92@T1olC4a<7oaHF5PKo3@d=1_l>
3Ph6ooooo`Oo>3Ph1on9RHT7oo?cl`Oo1PH61ooDe=@7oi>CT`Oo6QXJ1_oBd]85ooooo`Oob<S81omF
EUH7og5aL@OoUiNG1ol>3Ph7ooooo`OoE5AD1_lT92@=ooooo`002oooool7oc8b<POo7alO1ola<C47
odI6APOo7alO1omKFe/7oeMGE`KoA4A41Oooool7oaXJ6POo7QhN3_lP8207ob@T90Oo71`L1olY:BT6
obHV9PKooooo1_mYJFT7ob/[:`Oo?clo1om;Bd/7ob8R8POoG5aL1olb<S86oa/K6`Kooooo1onl_;`7
oc4a<@Ko820P1oooool7oc4a<@OoE5AD1ooemOD6ob<S8`Kooooo1olQ8B47ob0P80Oo:BTY1olS8b<6
obl_;`Oo9bLW1onJVYX6oeADE0Kooooo1olP8207obLW9`Oo5ADE1olT92@7oa<C4`Oo5QHF1_l=3@d6
o`h>3PKooooo1olh>3P7ohV9R@Oolo?c1ol61PH7omCDe0OoTi>C1olJ6QX6om;BdPGooooo1oo8b<P7
oeIFEPOoLG5a1onGUiL7o`h>3POooooo1omDE5@6ob@T90gooooo000;ooooo`Oo<S8b1olO7al7oc4a
<@OoATI61olO7al7oe]KF`OoEeMG1_m4A4@5ooooo`Oo6QXJ1olN7Qh>ob0P80Oo92@T1olL71`7obTY
:@Ko9RHV1_ooool6ofUYJ@Oo:b/[1olo?cl7od];B`Oo8R8R1omLG5`7oc8b<PKo6a/K1_ooool7okbl
_0Oo<C4a1_lP8207ooooo`Oo<C4a1omDE5@7ooGem@Ko8b<S1_ooool7ob4Q8@Oo820P1olY:BT7ob<S
8`Ko;bl_1olW9bL7oiZJVPKoE5AD1_ooool7ob0P80Oo9bLW1olE5AD7ob@T90Oo4a<C1olF5QH6o`d=
3@Ko3Ph>1_ooool7ocPh>0OoRHV91ooclo<7o`H61POoe=CD1onCTi<7oaXJ6PKod];B1Oooool7olS8
b0OoEUIF1omaLG47oiNGU`Oo3Ph>1oooool7oeADE0Ko92@T3Oooool000_ooooo1olb<S87oalO7`Oo
<C4a1om6ATH7oalO7`OoFe]K1omGEeL6odA4A0Gooooo1olJ6QX7oahN7Pko820P1olT92@7oa`L70Oo
:BTY1_lV9RH6ooooo`KoJFUY1ol[:b/7oclo?`OoBd];1olR8R87oeaLG0Oo<S8b1_lK6a/6ooooo`Oo
_;bl1ola<C46ob0P80Oooooo1ola<C47oeADE0OomOGe1_lS8b<6ooooo`Oo8B4Q1olP8207obTY:@Oo
8b<S1_l_;bl7obLW9`OoVYZJ1_mDE5@6ooooo`Oo820P1olW9bL7oaDE5@Oo92@T1olC4a<7oaHF5PKo
3@d=1_l>3Ph6ooooo`Oo>3Ph1on9RHT7oo?cl`Oo1PH61ooDe=@7oi>CT`Oo6QXJ1_oBd]85ooooo`Oo
b<S81omFEUH7og5aL@OoUiNG1ol>3Ph7ooooo`OoE5AD1_lT92@=ooooo`002oooool7oc8b<POo7alO
1ola<C47odI6APOo7alO1omKFe/7oeMGE`KoA4A41Oooool7oaXJ6POo7QhN3_lP8207ob@T90Oo71`L
1olY:BT6obHV9PKooooo1_mYJFT7ob/[:`Oo?clo1om;Bd/7ob8R8POoG5aL1olb<S86oa/K6`Kooooo
1onl_;`7oc4a<@Ko820P1oooool7oc4a<@OoE5AD1ooemOD6ob<S8`Kooooo1olQ8B47ob0P80Oo:BTY
1olS8b<6obl_;`Oo9bLW1onJVYX6oeADE0Kooooo1olP8207obLW9`Oo5ADE1olT92@7oa<C4`Oo5QHF
1_l=3@d6o`h>3PKooooo1olh>3P7ohV9R@Oolo?c1ol61PH7omCDe0OoTi>C1olJ6QX6om;BdPGooooo
1oo8b<P7oeIFEPOoLG5a1onGUiL7o`h>3POooooo1omDE5@6ob@T90gooooo000;ooooo`Oo<S8b1olO
7al7oc4a<@OoATI61olO7al7oe]KF`OoEeMG1_m4A4@5ooooo`Oo6QXJ1olN7Qh>ob0P80Oo92@T1olL
71`7obTY:@Ko9RHV1_ooool6ofUYJ@Oo:b/[1olo?cl7od];B`Oo8R8R1omLG5`7oc8b<PKo6a/K1_oo
ool7okbl_0Oo<C4a1_lP8207ooooo`Oo<C4a1omDE5@7ooGem@Ko8b<S1_ooool7ob4Q8@Oo820P1olY
:BT7ob<S8`Ko;bl_1olW9bL7oiZJVPKoE5AD1_ooool7ob0P80Oo9bLW1olE5AD7ob@T90Oo4a<C1olF
5QH6o`d=3@Ko3Ph>1_ooool7ocPh>0OoRHV91ooclo<7o`H61POoe=CD1onCTi<7oaXJ6PKod];B1Ooo
ool7olS8b0OoEUIF1omaLG47oiNGU`Oo3Ph>1oooool7oeADE0Ko92@T3Oooool000_ooooo1olb<S87
oalO7`Oo<C4a1om6ATH7oalO7`OoFe]K1omGEeL6odA4A0Gooooo1olJ6QX7oahN7Pko820P1olT92@7
oa`L70Oo:BTY1_lV9RH6ooooo`KoJFUY1ol[:b/7oclo?`OoBd];1olR8R87oeaLG0Oo<S8b1_lK6a/6
ooooo`Oo_;bl1ola<C46ob0P80Oooooo1ola<C47oeADE0OomOGe1_lS8b<6ooooo`Oo8B4Q1olP8207
obTY:@Oo8b<S1_l_;bl7obLW9`OoVYZJ1_mDE5@6ooooo`Oo820P1olW9bL7oaDE5@Oo92@T1olC4a<7
oaHF5PKo3@d=1_l>3Ph6ooooo`Oo>3Ph1on9RHT7oo?cl`Oo1PH61ooDe=@7oi>CT`Oo6QXJ1_oBd]85
ooooo`Oob<S81omFEUH7og5aL@OoUiNG1ol>3Ph7ooooo`OoE5AD1_lT92@=ooooo`002oooool7oaTI
6@Oo9bLW1ol00007obh^;POo8B4Q1olL71`7ob@T90Ko@d=31Oooool7o`l?3`Oo51@D1olR8R87ob@T
90Oo9RHV1olL71`7oadM7@Ko8b<S1_ooool6obDU9@Oo61PH1ono_kl7oadM7@Oo8B4Q1on9RHT7oaDE
5@Ko5aLG1_ooool7odY:BPOoGEeM1_m6ATH7odM7A`Oo?Shn1onTY:@7og=cL`Ko61PH1_ooool7ob<S
8`Oo3`l?1ol30`<7o`l?3`Ko410@1olG5aL7obLW9`Ko9BDU1_ooool7o`h>3POo51@D1olE5AD7o`/;
2`Oo2@T91ol410@6o`L71`Ko410@1_ooool7odY:BPOobl_;1on0P807o`l?3`Ooc<c<1on?Shl7oeeM
G@KoVIVI1Oooool7ogmoO`Oo<30`1on9RHT7ojb/[0Oo51@D1onXZ:P7ogMgM`KoRXZ:3Oooool000_o
oooo1olI6AT7obLW9`Oo00001ol^;Rh7ob4Q8@Oo71`L1olT92@6od=3@`Gooooo1ol?3`l7oa@D50Oo
8R8R1olT92@7obHV9POo71`L1olM7Ad6ob<S8`Kooooo1_lU9BD7oaPH60Oo_kno1olM7Ad7ob4Q8@Oo
RHV91olE5AD6oaLG5`Kooooo1om:BTX7oeeMG@KoATI61om7AdL7ochn?POoY:BT1omcLg<6oaPH60Ko
oooo1olS8b<7o`l?3`Oo0`<31ol?3`l6oa0@40Oo5aLG1olW9bL6obDU9@Kooooo1ol>3Ph7oa@D50Oo
5ADE1ol;2`/7o`T92@Oo10@41_l71`L6oa0@40Kooooo1om:BTX7ol_;b`OoP8201ol?3`l7olc<c0Oo
Shn?1omMGEd6oiVIV@Gooooo1omoOgl7oc0`<0OoRHV91on/[:`7oa@D50OoZ:RX1omgMgL6ohZ:RPgo
oooo000;ooooo`Oo6ATI1olW9bL7o`0000Oo;Rh^1olQ8B47oa`L70Oo92@T1_m3@d<5ooooo`Oo3`l?
1olD51@7ob8R8POo92@T1olV9RH7oa`L70Oo7AdM1_lS8b<6ooooo`Ko9BDU1olH61P7okno_`Oo7AdM
1olQ8B47ohV9R@Oo5ADE1_lG5aL6ooooo`OoBTY:1omMGEd6odI6APOoAdM71oln?Sh7ojBTY0OoLg=c
1_lH61P6ooooo`Oo8b<S1ol?3`l7o`<30`Oo3`l?1_l@4107oaLG5`Oo9bLW1_lU9BD6ooooo`Oo3Ph>
1olD51@7oaDE5@Oo2`/;1ol92@T7o`@410Ko1`L71_l@4106ooooo`OoBTY:1oo;bl/7oh20P0Oo3`l?
1oo<c<`7ohn?S`OoGEeM1_nIVIT5ooooo`OoOgmo1ol`<307ohV9R@Oo[:b/1olD51@7ojRXZ0OoMgMg
1_n:RXX=ooooo`002oooool7oaTI6@Oo9bLW1ol00007obh^;POo8B4Q1olL71`7ob@T90Ko@d=31Ooo
ool7o`l?3`Oo51@D1olR8R87ob@T90Oo9RHV1olL71`7oadM7@Ko8b<S1_ooool6obDU9@Oo61PH1ono
_kl7oadM7@Oo8B4Q1on9RHT7oaDE5@Ko5aLG1_ooool7odY:BPOoGEeM1_m6ATH7odM7A`Oo?Shn1onT
Y:@7og=cL`Ko61PH1_ooool7ob<S8`Oo3`l?1ol30`<7o`l?3`Ko410@1olG5aL7obLW9`Ko9BDU1_oo
ool7o`h>3POo51@D1olE5AD7o`/;2`Oo2@T91ol410@6o`L71`Ko410@1_ooool7odY:BPOobl_;1on0
P807o`l?3`Ooc<c<1on?Shl7oeeMG@KoVIVI1Oooool7ogmoO`Oo<30`1on9RHT7ojb/[0Oo51@D1onX
Z:P7ogMgM`KoRXZ:3Oooool000_ooooo1olI6AT7obLW9`Oo00001ol^;Rh7ob4Q8@Oo71`L1olT92@6
od=3@`Gooooo1ol?3`l7oa@D50Oo8R8R1olT92@7obHV9POo71`L1olM7Ad6ob<S8`Kooooo1_lU9BD7
oaPH60Oo_kno1olM7Ad7ob4Q8@OoRHV91olE5AD6oaLG5`Kooooo1om:BTX7oeeMG@KoATI61om7AdL7
ochn?POoY:BT1omcLg<6oaPH60Kooooo1olS8b<7o`l?3`Oo0`<31ol?3`l6oa0@40Oo5aLG1olW9bL6
obDU9@Kooooo1ol>3Ph7oa@D50Oo5ADE1ol;2`/7o`T92@Oo10@41_l71`L6oa0@40Kooooo1om:BTX7
ol_;b`OoP8201ol?3`l7olc<c0OoShn?1omMGEd6oiVIV@Gooooo1omoOgl7oc0`<0OoRHV91on/[:`7
oa@D50OoZ:RX1omgMgL6ohZ:RPgooooo000;ooooo`Oo6ATI1olW9bL7o`0000Oo;Rh^1olQ8B47oa`L
70Oo92@T1_m3@d<5ooooo`Oo3`l?1olD51@7ob8R8POo92@T1olV9RH7oa`L70Oo7AdM1_lS8b<6oooo
o`Ko9BDU1olH61P7okno_`Oo7AdM1olQ8B47ohV9R@Oo5ADE1_lG5aL6ooooo`OoBTY:1omMGEd6odI6
APOoAdM71oln?Sh7ojBTY0OoLg=c1_lH61P6ooooo`Oo8b<S1ol?3`l7o`<30`Oo3`l?1_l@4107oaLG
5`Oo9bLW1_lU9BD6ooooo`Oo3Ph>1olD51@7oaDE5@Oo2`/;1ol92@T7o`@410Ko1`L71_l@4106oooo
o`OoBTY:1oo;bl/7oh20P0Oo3`l?1oo<c<`7ohn?S`OoGEeM1_nIVIT5ooooo`OoOgmo1ol`<307ohV9
R@Oo[:b/1olD51@7ojRXZ0OoMgMg1_n:RXX=ooooo`002oooool7odi>CPOoD51@1omNGUh7on[ZjPOo
BTY:1ooXj>P7ooooo`KoCDe=1Oooool7o`H61POo2`/;1olG5aL7ob8R8POo8b<S1olg=cL7ob`/;0Ko
8R8R1_ooool6ohB4Q0OoVYZJ1om]KFd7od10@0Oo[Zj^1oll?3`7oa@D50KoHf=S1_ooool7oeaLG0Oo
1PH61_ld=3@7oiVIV@Oo30`<1om;Bd/7okZj^PKo;Bd]1_ooool7obTY:@ko30`<1ol:2PX6oc4a<@Oo
3@d=1ol`<306oc8b<PKooooo1olJ6QX7oa0@40Oo4A4A1ol=3@d7o`@410Oo0@411_l820P6o`L71`Ko
oooo1olO7al7oe5AD@Oob/[:1olV9RH7oiBDU0OoMgMg1om^KVh6ohR8R0Gooooo1onl_;`7o`H61POo
GEeM1onIVIT7oaXJ6POoa<C41om=CDd6oeIFEPgooooo000;ooooo`OoCTi>1om@D507oeiNGPOoj^[Z
1om:BTX7onSXj0Oooooo1_m=CDd5ooooo`Oo1PH61ol;2`/7oaLG5`Oo8R8R1olS8b<7ocLg=`Oo;2`/
1_lR8R86ooooo`KoQ8B41onJVYX7ofe]K@Oo@4101on^[Zh7oc`l?0Oo51@D1_mSHf<6ooooo`OoG5aL
1ol61PH6oc@d=0OoVIVI1ol<30`7od];B`Oo^[Zj1_l];Bd6ooooo`Oo:BTY3_l<30`7o`X:2PKo<C4a
1ol=3@d7oc0`<0Ko<S8b1_ooool7oaXJ6POo410@1olA4A47o`d=3@Oo10@41ol10@46o`P820Ko1`L7
1_ooool7oalO7`OoDE5A1oo:b/X7obHV9POoU9BD1omgMgL7ofi^KPKoR8R81Oooool7okbl_0Oo1PH6
1omMGEd7oiVIV@Oo6QXJ1oo4a<@7ode=C@KoEUIF3Oooool000_ooooo1om>CTh7oe1@D0OoGUiN1ooZ
j^X7odY:BPOoj>SX1oooool6ode=C@Gooooo1ol61PH7o`/;2`Oo5aLG1olR8R87ob<S8`Oo=cLg1ol/
;2`6ob8R8PKooooo1_n4Q8@7oiZJVPOoKFe]1om0@407ojj^[POo?3`l1olD51@6of=SH`Kooooo1omL
G5`7o`H61PKo=3@d1onIVIT7o``<30OoBd];1onj^[X6obd];@Kooooo1olY:BT>o``<30Oo2PX:1_la
<C47o`d=3@Oo<30`1_lb<S86ooooo`Oo6QXJ1ol@4107oa4A4@Oo3@d=1ol410@7o`410@Ko20P81_l7
1`L6ooooo`Oo7alO1omADE47ol[:bPOo9RHV1onDU9@7ogMgM`OoKVi^1_n8R8P5ooooo`Oo_;bl1ol6
1PH7oeeMG@OoVIVI1olJ6QX7olC4a0OoCDe=1_mFEUH=ooooo`002oooool7odi>CPOoD51@1omNGUh7
on[ZjPOoBTY:1ooXj>P7ooooo`KoCDe=1Oooool7o`H61POo2`/;1olG5aL7ob8R8POo8b<S1olg=cL7
ob`/;0Ko8R8R1_ooool6ohB4Q0OoVYZJ1om]KFd7od10@0Oo[Zj^1oll?3`7oa@D50KoHf=S1_ooool7
oeaLG0Oo1PH61_ld=3@7oiVIV@Oo30`<1om;Bd/7okZj^PKo;Bd]1_ooool7obTY:@ko30`<1ol:2PX6
oc4a<@Oo3@d=1ol`<306oc8b<PKooooo1olJ6QX7oa0@40Oo4A4A1ol=3@d7o`@410Oo0@411_l820P6
o`L71`Kooooo1olO7al7oe5AD@Oob/[:1olV9RH7oiBDU0OoMgMg1om^KVh6ohR8R0Gooooo1onl_;`7
o`H61POoGEeM1onIVIT7oaXJ6POoa<C41om=CDd6oeIFEPgooooo000;ooooo`OoCTi>1om@D507oeiN
GPOoj^[Z1om:BTX7onSXj0Oooooo1_m=CDd5ooooo`Oo1PH61ol;2`/7oaLG5`Oo8R8R1olS8b<7ocLg
=`Oo;2`/1_lR8R86ooooo`KoQ8B41onJVYX7ofe]K@Oo@4101on^[Zh7oc`l?0Oo51@D1_mSHf<6oooo
o`OoG5aL1ol61PH6oc@d=0OoVIVI1ol<30`7od];B`Oo^[Zj1_l];Bd6ooooo`Oo:BTY3_l<30`7o`X:
2PKo<C4a1ol=3@d7oc0`<0Ko<S8b1_ooool7oaXJ6POo410@1olA4A47o`d=3@Oo10@41ol10@46o`P8
20Ko1`L71_ooool7oalO7`OoDE5A1oo:b/X7obHV9POoU9BD1omgMgL7ofi^KPKoR8R81Oooool7okbl
_0Oo1PH61omMGEd7oiVIV@Oo6QXJ1oo4a<@7ode=C@KoEUIF3Oooool000_ooooo1om>CTh7oe1@D0Oo
GUiN1ooZj^X7odY:BPOoj>SX1oooool6ode=C@Gooooo1ol61PH7o`/;2`Oo5aLG1olR8R87ob<S8`Oo
=cLg1ol/;2`6ob8R8PKooooo1_n4Q8@7oiZJVPOoKFe]1om0@407ojj^[POo?3`l1olD51@6of=SH`Ko
oooo1omLG5`7o`H61PKo=3@d1onIVIT7o``<30OoBd];1onj^[X6obd];@Kooooo1olY:BT>o``<30Oo
2PX:1_la<C47o`d=3@Oo<30`1_lb<S86ooooo`Oo6QXJ1ol@4107oa4A4@Oo3@d=1ol410@7o`410@Ko
20P81_l71`L6ooooo`Oo7alO1omADE47ol[:bPOo9RHV1onDU9@7ogMgM`OoKVi^1_n8R8P5ooooo`Oo
_;bl1ol61PH7oeeMG@OoVIVI1olJ6QX7olC4a0OoCDe=1_mFEUH=ooooo`002oooool7odi>CPOoD51@
1omNGUh7on[ZjPOoBTY:1ooXj>P7ooooo`KoCDe=1Oooool7o`H61POo2`/;1olG5aL7ob8R8POo8b<S
1olg=cL7ob`/;0Ko8R8R1_ooool6ohB4Q0OoVYZJ1om]KFd7od10@0Oo[Zj^1oll?3`7oa@D50KoHf=S
1_ooool7oeaLG0Oo1PH61_ld=3@7oiVIV@Oo30`<1om;Bd/7okZj^PKo;Bd]1_ooool7obTY:@ko30`<
1ol:2PX6oc4a<@Oo3@d=1ol`<306oc8b<PKooooo1olJ6QX7oa0@40Oo4A4A1ol=3@d7o`@410Oo0@41
1_l820P6o`L71`Kooooo1olO7al7oe5AD@Oob/[:1olV9RH7oiBDU0OoMgMg1om^KVh6ohR8R0Gooooo
1onl_;`7o`H61POoGEeM1onIVIT7oaXJ6POoa<C41om=CDd6oeIFEPgooooo000;ooooo`Oo2@T91om7
AdL7o`d=3@Oo9bLW1om2@T87obLW9`Oo?Cdm1_lb<S85ooooo`Oo5QHF1ol=3@d7o`h>3POo5aLG1olK
6a/7obLW9`Oo61PH1_lT92@6ooooo`KoADE51omKFe/7ooooo`Oo6QXJ1om<C4`7ojVYZ@OoEeMG1_l_
;bl6ooooo`Oo>CTi1ol?3`l6odE5A@Oo:b/[1ol=3@d7og=cL`Oo71`L1_l20P86ooooo`OoB4Q81ol=
3@d7obPX:0OoATI61_m4A4@7ocTi>@Oooooo1_mRHV86ooooo`Oo92@T1ol<30`>o`L71`Oo0P821ol0
0006o`L71`Ko00001_ooool7o`0000OoSXj>1ola<C47o`<30`Oooooo1ol[:b/7oa/K6`Ko_Kfm1Ooo
ool7ocPh>0Oo2`/;1on`/;07ob<S8`Oo410@1ooVi^H7oa@D50KoOWin3Oooool000_ooooo1ol92@T7
odM7A`Oo3@d=1olW9bL7od92@POo9bLW1olm?Cd6oc8b<PGooooo1olF5QH7o`d=3@Oo3Ph>1olG5aL7
oa/K6`Oo9bLW1olH61P6ob@T90Kooooo1_m5ADD7oe]KF`Oooooo1olJ6QX7oda<C0OoZJVY1omGEeL6
obl_;`Kooooo1oli>CT7o`l?3`KoADE51ol[:b/7o`d=3@OoLg=c1olL71`6o`820PKooooo1om8B4P7
o`d=3@Oo:2PX1om6ATH6odA4A0Oo>CTi1oooool6of9RHPKooooo1olT92@7o``<30ko1`L71ol20P87
o`0000Ko1`L71_l00006ooooo`Oo00001on>SXh7oc4a<@Oo0`<31oooool7ob/[:`Oo6a/K1_nm_Kd5
ooooo`Oo>3Ph1ol;2`/7ok2`/0Oo8b<S1ol@4107onKViPOo51@D1_mnOWh=ooooo`002oooool7o`T9
2@OoAdM71ol=3@d7obLW9`Oo@T921olW9bL7ocdm?@Ko<S8b1Oooool7oaHF5POo3@d=1ol>3Ph7oaLG
5`Oo6a/K1olW9bL7oaPH60Ko92@T1_ooool6odE5A@OoFe]K1oooool7oaXJ6POoC4a<1onYZJT7oeMG
E`Ko;bl_1_ooool7ocTi>@Oo3`l?1_m5ADD7ob/[:`Oo3@d=1omcLg<7oa`L70Ko0P821_ooool7odQ8
B0Oo3@d=1olX:2P7odI6APKoA4A41oli>CT7ooooo`KoHV9R1_ooool7ob@T90Oo30`<3_l71`L7o`82
0POo00001_l71`L6o`0000Kooooo1ol00007ohj>SPOo<C4a1ol30`<7ooooo`Oo:b/[1olK6a/6okfm
_@Gooooo1olh>3P7o`/;2`Oo/;2`1olS8b<7oa0@40Ooi^KV1olD51@6oginOPgooooo000;ooooo`Oo
2@T91om7AdL7o`d=3@Oo9bLW1om2@T87obLW9`Oo?Cdm1_lb<S85ooooo`Oo5QHF1ol=3@d7o`h>3POo
5aLG1olK6a/7obLW9`Oo61PH1_lT92@6ooooo`KoADE51omKFe/7ooooo`Oo6QXJ1om<C4`7ojVYZ@Oo
EeMG1_l_;bl6ooooo`Oo>CTi1ol?3`l6odE5A@Oo:b/[1ol=3@d7og=cL`Oo71`L1_l20P86ooooo`Oo
B4Q81ol=3@d7obPX:0OoATI61_m4A4@7ocTi>@Oooooo1_mRHV86ooooo`Oo92@T1ol<30`>o`L71`Oo
0P821ol00006o`L71`Ko00001_ooool7o`0000OoSXj>1ola<C47o`<30`Oooooo1ol[:b/7oa/K6`Ko
_Kfm1Oooool7ocPh>0Oo2`/;1on`/;07ob<S8`Oo410@1ooVi^H7oa@D50KoOWin3Oooool000_ooooo
1ol92@T7odM7A`Oo3@d=1olW9bL7od92@POo9bLW1olm?Cd6oc8b<PGooooo1olF5QH7o`d=3@Oo3Ph>
1olG5aL7oa/K6`Oo9bLW1olH61P6ob@T90Kooooo1_m5ADD7oe]KF`Oooooo1olJ6QX7oda<C0OoZJVY
1omGEeL6obl_;`Kooooo1oli>CT7o`l?3`KoADE51ol[:b/7o`d=3@OoLg=c1olL71`6o`820PKooooo
1om8B4P7o`d=3@Oo:2PX1om6ATH6odA4A0Oo>CTi1oooool6of9RHPKooooo1olT92@7o``<30ko1`L7
1ol20P87o`0000Ko1`L71_l00006ooooo`Oo00001on>SXh7oc4a<@Oo0`<31oooool7ob/[:`Oo6a/K
1_nm_Kd5ooooo`Oo>3Ph1ol;2`/7ok2`/0Oo8b<S1ol@4107onKViPOo51@D1_mnOWh=ooooo`002ooo
ool7o`T92@OoAdM71ol=3@d7obLW9`Oo@T921olW9bL7ocdm?@Ko<S8b1Oooool7oaHF5POo3@d=1ol>
3Ph7oaLG5`Oo6a/K1olW9bL7oaPH60Ko92@T1_ooool6odE5A@OoFe]K1oooool7oaXJ6POoC4a<1onY
ZJT7oeMGE`Ko;bl_1_ooool7ocTi>@Oo3`l?1_m5ADD7ob/[:`Oo3@d=1omcLg<7oa`L70Ko0P821_oo
ool7odQ8B0Oo3@d=1olX:2P7odI6APKoA4A41oli>CT7ooooo`KoHV9R1_ooool7ob@T90Oo30`<3_l7
1`L7o`820POo00001_l71`L6o`0000Kooooo1ol00007ohj>SPOo<C4a1ol30`<7ooooo`Oo:b/[1olK
6a/6okfm_@Gooooo1olh>3P7o`/;2`Oo/;2`1olS8b<7oa0@40Ooi^KV1olD51@6oginOPgooooo000;
ooooo`Oo2@T91om7AdL7o`d=3@Oo9bLW1om2@T87obLW9`Oo?Cdm1_lb<S85ooooo`Oo5QHF1ol=3@d7
o`h>3POo5aLG1olK6a/7obLW9`Oo61PH1_lT92@6ooooo`KoADE51omKFe/7ooooo`Oo6QXJ1om<C4`7
ojVYZ@OoEeMG1_l_;bl6ooooo`Oo>CTi1ol?3`l6odE5A@Oo:b/[1ol=3@d7og=cL`Oo71`L1_l20P86
ooooo`OoB4Q81ol=3@d7obPX:0OoATI61_m4A4@7ocTi>@Oooooo1_mRHV86ooooo`Oo92@T1ol<30`>
o`L71`Oo0P821ol00006o`L71`Ko00001_ooool7o`0000OoSXj>1ola<C47o`<30`Oooooo1ol[:b/7
oa/K6`Ko_Kfm1Oooool7ocPh>0Oo2`/;1on`/;07ob<S8`Oo410@1ooVi^H7oa@D50KoOWin3Oooool0
00_ooooo1ol[:b/7ob8R8POo=cLg1om^KVh7ob8R8POoJFUY1omTI6@6ocTi>@Gooooo1olF5QH7obDU
9@Oo51@D1ol:2PX7o`/;2`Oo3@d=1ol820P6o``<30Kooooo1_ln?Sh7oh^;R`Oo^[Zj1ol;2`/7ooCd
m0OoDe=C1olN7Qh6ojNWY`Kooooo1olO7al7oahN7PKoJVYZ1olM7Ad7oa`L70OoA4A41ol_;bl6oaPH
60Kooooo1ol`<307ob0P80Oo<C4a1ol:2PX6ocLg=`Oo<30`1on1PH46odA4A0Kooooo1olG5aL7o`/;
2`Oo0@411ol@4107o`@410Oo2PX:1_lK6a/6oa@D50Kooooo1ol^;Rh7odU9B@Oo:b/[1om8B4P7odI6
APOo<c<c1on8R8P6oa@D50Gooooo1om8B4P7ob<S8`OoADE51omNGUh7oeIFEPOoADE51olU9BD6ohn?
S`gooooo000;ooooo`Oo:b/[1olR8R87ocLg=`OoKVi^1olR8R87ofUYJ@OoI6AT1_li>CT5ooooo`Oo
5QHF1olU9BD7oa@D50Oo2PX:1ol;2`/7o`d=3@Oo20P81_l<30`6ooooo`Ko?Shn1on;Rh/7okZj^POo
2`/;1oodm?@7oe=CD`Oo7QhN1_nWYjL6ooooo`Oo7alO1olN7Qh6ofYZJPOo7AdM1olL71`7odA4A0Oo
;bl_1_lH61P6ooooo`Oo<30`1olP8207oc4a<@Oo2PX:1_lg=cL7oc0`<0OoPH611_m4A4@6ooooo`Oo
5aLG1ol;2`/7o`410@Oo410@1ol410@7o`X:2PKo6a/K1_lD51@6ooooo`Oo;Rh^1om9BDT7ob/[:`Oo
B4Q81om6ATH7oc<c<`OoR8R81_lD51@5ooooo`OoB4Q81olS8b<7odE5A@OoGUiN1omFEUH7odE5A@Oo
9BDU1_n?Shl=ooooo`002oooool7ob/[:`Oo8R8R1olg=cL7ofi^KPOo8R8R1omYJFT7ofATI0Ko>CTi
1Oooool7oaHF5POo9BDU1olD51@7o`X:2POo2`/;1ol=3@d7o`P820Ko30`<1_ooool6ochn?POoRh^;
1onj^[X7o`/;2`Oom?Cd1omCDe<7oahN7PKoYjNW1_ooool7oalO7`Oo7QhN1_mZJVX7oadM7@Oo71`L
1om4A4@7obl_;`Ko61PH1_ooool7oc0`<0Oo820P1ola<C47o`X:2PKo=cLg1ol`<307oh61P@KoA4A4
1_ooool7oaLG5`Oo2`/;1ol10@47oa0@40Oo10@41ol:2PX6oa/K6`Ko51@D1_ooool7obh^;POoBDU9
1ol[:b/7odQ8B0OoATI61olc<c<7ohR8R0Ko51@D1Oooool7odQ8B0Oo8b<S1om5ADD7oeiNGPOoEUIF
1om5ADD7obDU9@KoShn?3Oooool000_ooooo1ol[:b/7ob8R8POo=cLg1om^KVh7ob8R8POoJFUY1omT
I6@6ocTi>@Gooooo1olF5QH7obDU9@Oo51@D1ol:2PX7o`/;2`Oo3@d=1ol820P6o``<30Kooooo1_ln
?Sh7oh^;R`Oo^[Zj1ol;2`/7ooCdm0OoDe=C1olN7Qh6ojNWY`Kooooo1olO7al7oahN7PKoJVYZ1olM
7Ad7oa`L70OoA4A41ol_;bl6oaPH60Kooooo1ol`<307ob0P80Oo<C4a1ol:2PX6ocLg=`Oo<30`1on1
PH46odA4A0Kooooo1olG5aL7o`/;2`Oo0@411ol@4107o`@410Oo2PX:1_lK6a/6oa@D50Kooooo1ol^
;Rh7odU9B@Oo:b/[1om8B4P7odI6APOo<c<c1on8R8P6oa@D50Gooooo1om8B4P7ob<S8`OoADE51omN
GUh7oeIFEPOoADE51olU9BD6ohn?S`gooooo000;ooooo`Oo:b/[1olR8R87ocLg=`OoKVi^1olR8R87
ofUYJ@OoI6AT1_li>CT5ooooo`Oo5QHF1olU9BD7oa@D50Oo2PX:1ol;2`/7o`d=3@Oo20P81_l<30`6
ooooo`Ko?Shn1on;Rh/7okZj^POo2`/;1oodm?@7oe=CD`Oo7QhN1_nWYjL6ooooo`Oo7alO1olN7Qh6
ofYZJPOo7AdM1olL71`7odA4A0Oo;bl_1_lH61P6ooooo`Oo<30`1olP8207oc4a<@Oo2PX:1_lg=cL7
oc0`<0OoPH611_m4A4@6ooooo`Oo5aLG1ol;2`/7o`410@Oo410@1ol410@7o`X:2PKo6a/K1_lD51@6
ooooo`Oo;Rh^1om9BDT7ob/[:`OoB4Q81om6ATH7oc<c<`OoR8R81_lD51@5ooooo`OoB4Q81olS8b<7
odE5A@OoGUiN1omFEUH7odE5A@Oo9BDU1_n?Shl=ooooo`002oooool7ob/[:`Oo8R8R1olg=cL7ofi^
KPOo8R8R1omYJFT7ofATI0Ko>CTi1Oooool7oaHF5POo9BDU1olD51@7o`X:2POo2`/;1ol=3@d7o`P8
20Ko30`<1_ooool6ochn?POoRh^;1onj^[X7o`/;2`Oom?Cd1omCDe<7oahN7PKoYjNW1_ooool7oalO
7`Oo7QhN1_mZJVX7oadM7@Oo71`L1om4A4@7obl_;`Ko61PH1_ooool7oc0`<0Oo820P1ola<C47o`X:
2PKo=cLg1ol`<307oh61P@KoA4A41_ooool7oaLG5`Oo2`/;1ol10@47oa0@40Oo10@41ol:2PX6oa/K
6`Ko51@D1_ooool7obh^;POoBDU91ol[:b/7odQ8B0OoATI61olc<c<7ohR8R0Ko51@D1Oooool7odQ8
B0Oo8b<S1om5ADD7oeiNGPOoEUIF1om5ADD7obDU9@KoShn?3Oooool000_ooooo1ol@4107odA4A0Oo
5QHF1olb<S87ob/[:`OoD51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo
0@411ol61PH6oa4A4@Kooooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Ko
oooo1om>CTh7olS8b0KoADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo
6a/K1_lP8207oaXJ6POoBTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko
5QHF1_ooool7ofa/K0Oo?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo
4A4A1omHF5P7o`820POo410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF
1olb<S87ob/[:`OoD51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@41
1ol61PH6oa4A4@Kooooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo
1om>CTh7olS8b0KoADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K
1_lP8207oaXJ6POoBTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF
1_ooool7ofa/K0Oo?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A
1omHF5P7o`820POo410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF1olb
<S87ob/[:`OoD51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@411ol6
1PH6oa4A4@Kooooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo1om>
CTh7olS8b0KoADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K1_lP
8207oaXJ6POoBTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF1_oo
ool7ofa/K0Oo?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A1omH
F5P7o`820POo410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF1olb<S87
ob/[:`OoD51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@411ol61PH6
oa4A4@Kooooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo1om>CTh7
olS8b0KoADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K1_lP8207
oaXJ6POoBTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF1_ooool7
ofa/K0Oo?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A1omHF5P7
o`820POo410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF1olb<S87ob/[
:`OoD51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@411ol61PH6oa4A
4@Kooooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo1om>CTh7olS8
b0KoADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K1_lP8207oaXJ
6POoBTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF1_ooool7ofa/
K0Oo?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A1omHF5P7o`82
0POo410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF1olb<S87ob/[:`Oo
D51@1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@411ol61PH6oa4A4@Ko
oooo1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo1om>CTh7olS8b0Ko
ADE51olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K1_lP8207oaXJ6POo
BTY:1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF1_ooool7ofa/K0Oo
?Shn1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A1omHF5P7o`820POo
410@1on2PX87o`P820Ko<C4a3Oooool000_ooooo1ol@4107odA4A0Oo5QHF1olb<S87ob/[:`OoD51@
1olT92@6oc0`<0Gooooo1olR8R87obDU9@Oo3`l?1ol00007o`P820Oo0@411ol61PH6oa4A4@Kooooo
1_lj>SX7ok2`/0OoXj>S1olA4A47onOWi`OoH61P1onOWil6oe5AD@Kooooo1om>CTh7olS8b0KoADE5
1olE5AD7og=cL`Oo>SXj3OlB4Q86ooooo`Oo7QhN1olD51@7o`0000Oo6a/K1_lP8207oaXJ6POoBTY:
1_ld=3@6ooooo`Oo3`l?1ol>3Ph7oaDE5@Oo4A4A3_lO7al6obPX:0Ko5QHF1_ooool7ofa/K0Oo?Shn
1ol92@T7obHV9POoEeMG1ol>3Ph7oaTI6@KoATI61Oooool7o`/;2`Oo4A4A1omHF5P7o`820POo410@
1on2PX87o`P820Ko<C4a3Oooool000_ooooo1olE5AD7ob@T90Oo9RHV1om>CTh7ob@T90OoIfMW1onB
TY86obl_;`Gooooo1olD51@7oaTI6@Oo410@1ol92@T7o`D51@Oo0`<31ol;2`/6oaXJ6PKooooo1_l<
30`7oe]KF`Oo^KVi1oli>CT7okBd]0OoDe=C1on5QHD6ogemO@Kooooo1ol^;Rh7oe]KF`Ko]KFe1om@
D507ofATI0OoJf][1om;Bd/6o`H61PKooooo1olW9bL7oa<C4`Oo5ADE1olB4Q86obLW9`Oo:RXZ1omA
DE46od92@PKooooo1ol410@7oadM7@Oo7alO1olW9bL7ob<S8`Oo410@1_lN7Qh6oaXJ6PKooooo1om1
@D47oeMGE`Oo6a/K1olf=SH7obTY:@Oo8R8R1om:BTX6o`T92@Gooooo1olI6AT7ocPh>0Oo=3@d1olR
8R87odU9B@Oo1@D51ol00006oeEEE@gooooo000;ooooo`Oo5ADE1olT92@7obHV9POoCTi>1olT92@7
ofMWI`OoTY:B1_l_;bl5ooooo`Oo51@D1olI6AT7oa0@40Oo2@T91ol51@D7o`<30`Oo2`/;1_lJ6QX6
ooooo`Ko30`<1omKFe/7okVi^@Oo>CTi1ond];@7oe=CD`OoQHF51_mmOGd6ooooo`Oo;Rh^1omKFe/6
okFe]@OoD51@1omTI6@7of][J`OoBd];1_l61PH6ooooo`Oo9bLW1olC4a<7oaDE5@Oo4Q8B1_lW9bL7
obXZ:POoDE5A1_m2@T86ooooo`Oo10@41olM7Ad7oalO7`Oo9bLW1olS8b<7oa0@40Ko7QhN1_lJ6QX6
ooooo`Oo@D511omGEeL7oa/K6`Oo=SHf1olY:BT7ob8R8POoBTY:1_l92@T5ooooo`Oo6ATI1olh>3P7
oc@d=0Oo8R8R1om9BDT7o`D51@Oo00001_mEEED=ooooo`002oooool7oaDE5@Oo92@T1olV9RH7odi>
CPOo92@T1omWIfL7oi:BTPKo;bl_1Oooool7oa@D50Oo6ATI1ol@4107o`T92@Oo1@D51ol30`<7o`/;
2`Ko6QXJ1_ooool6o``<30OoFe]K1oni^KT7ocTi>@Oo];Bd1omCDe<7ohF5Q@KoOGem1_ooool7obh^
;POoFe]K1_ne]KD7oe1@D0OoI6AT1om[Jf/7od];B`Ko1PH61_ooool7obLW9`Oo4a<C1olE5AD7oa8B
4PKo9bLW1olZ:RX7oe5AD@Ko@T921_ooool7o`@410Oo7AdM1olO7al7obLW9`Oo8b<S1ol@4106oahN
7PKo6QXJ1_ooool7od51@@OoEeMG1olK6a/7ocHf=POo:BTY1olR8R87odY:BPKo2@T91Oooool7oaTI
6@Oo>3Ph1old=3@7ob8R8POoBDU91ol51@D7o`0000KoEEEE3Oooool000_ooooo1olE5AD7ob@T90Oo
9RHV1om>CTh7ob@T90OoIfMW1onBTY86obl_;`Gooooo1olD51@7oaTI6@Oo410@1ol92@T7o`D51@Oo
0`<31ol;2`/6oaXJ6PKooooo1_l<30`7oe]KF`Oo^KVi1oli>CT7okBd]0OoDe=C1on5QHD6ogemO@Ko
oooo1ol^;Rh7oe]KF`Ko]KFe1om@D507ofATI0OoJf][1om;Bd/6o`H61PKooooo1olW9bL7oa<C4`Oo
5ADE1olB4Q86obLW9`Oo:RXZ1omADE46od92@PKooooo1ol410@7oadM7@Oo7alO1olW9bL7ob<S8`Oo
410@1_lN7Qh6oaXJ6PKooooo1om1@D47oeMGE`Oo6a/K1olf=SH7obTY:@Oo8R8R1om:BTX6o`T92@Go
oooo1olI6AT7ocPh>0Oo=3@d1olR8R87odU9B@Oo1@D51ol00006oeEEE@gooooo000;ooooo`Oo5ADE
1olT92@7obHV9POoCTi>1olT92@7ofMWI`OoTY:B1_l_;bl5ooooo`Oo51@D1olI6AT7oa0@40Oo2@T9
1ol51@D7o`<30`Oo2`/;1_lJ6QX6ooooo`Ko30`<1omKFe/7okVi^@Oo>CTi1ond];@7oe=CD`OoQHF5
1_mmOGd6ooooo`Oo;Rh^1omKFe/6okFe]@OoD51@1omTI6@7of][J`OoBd];1_l61PH6ooooo`Oo9bLW
1olC4a<7oaDE5@Oo4Q8B1_lW9bL7obXZ:POoDE5A1_m2@T86ooooo`Oo10@41olM7Ad7oalO7`Oo9bLW
1olS8b<7oa0@40Ko7QhN1_lJ6QX6ooooo`Oo@D511omGEeL7oa/K6`Oo=SHf1olY:BT7ob8R8POoBTY:
1_l92@T5ooooo`Oo6ATI1olh>3P7oc@d=0Oo8R8R1om9BDT7o`D51@Oo00001_mEEED=ooooo`002ooo
ool7oaDE5@Oo92@T1olV9RH7odi>CPOo92@T1omWIfL7oi:BTPKo;bl_1Oooool7oa@D50Oo6ATI1ol@
4107o`T92@Oo1@D51ol30`<7o`/;2`Ko6QXJ1_ooool6o``<30OoFe]K1oni^KT7ocTi>@Oo];Bd1omC
De<7ohF5Q@KoOGem1_ooool7obh^;POoFe]K1_ne]KD7oe1@D0OoI6AT1om[Jf/7od];B`Ko1PH61_oo
ool7obLW9`Oo4a<C1olE5AD7oa8B4PKo9bLW1olZ:RX7oe5AD@Ko@T921_ooool7o`@410Oo7AdM1olO
7al7obLW9`Oo8b<S1ol@4106oahN7PKo6QXJ1_ooool7od51@@OoEeMG1olK6a/7ocHf=POo:BTY1olR
8R87odY:BPKo2@T91Oooool7oaTI6@Oo>3Ph1old=3@7ob8R8POoBDU91ol51@D7o`0000KoEEEE3Ooo
ool000_ooooo1olE5AD7ob@T90Oo9RHV1om>CTh7ob@T90OoIfMW1onBTY86obl_;`Gooooo1olD51@7
oaTI6@Oo410@1ol92@T7o`D51@Oo0`<31ol;2`/6oaXJ6PKooooo1_l<30`7oe]KF`Oo^KVi1oli>CT7
okBd]0OoDe=C1on5QHD6ogemO@Kooooo1ol^;Rh7oe]KF`Ko]KFe1om@D507ofATI0OoJf][1om;Bd/6
o`H61PKooooo1olW9bL7oa<C4`Oo5ADE1olB4Q86obLW9`Oo:RXZ1omADE46od92@PKooooo1ol410@7
oadM7@Oo7alO1olW9bL7ob<S8`Oo410@1_lN7Qh6oaXJ6PKooooo1om1@D47oeMGE`Oo6a/K1olf=SH7
obTY:@Oo8R8R1om:BTX6o`T92@Gooooo1olI6AT7ocPh>0Oo=3@d1olR8R87odU9B@Oo1@D51ol00006
oeEEE@gooooo000;ooooo`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5oooo
o`OoBDU91om0@407ofIVIPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B
4POoATI61ol51@D7oaXJ6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF
5POoSXj>1_lN7Qh6ooooo`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/
[0Oo@D511olg=cL7oalO7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T
90OoKfm_1olm?Cd6o`l?3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5
A@gooooo000;ooooo`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5ooooo`Oo
BDU91om0@407ofIVIPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B4POo
ATI61ol51@D7oaXJ6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF5POo
SXj>1_lN7Qh6ooooo`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/[0Oo
@D511olg=cL7oalO7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T90Oo
Kfm_1olm?Cd6o`l?3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5A@go
oooo000;ooooo`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5ooooo`OoBDU9
1om0@407ofIVIPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B4POoATI6
1ol51@D7oaXJ6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF5POoSXj>
1_lN7Qh6ooooo`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/[0Oo@D51
1olg=cL7oalO7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T90OoKfm_
1olm?Cd6o`l?3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5A@gooooo
000;ooooo`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5ooooo`OoBDU91om0
@407ofIVIPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B4POoATI61ol5
1@D7oaXJ6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF5POoSXj>1_lN
7Qh6ooooo`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/[0Oo@D511olg
=cL7oalO7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T90OoKfm_1olm
?Cd6o`l?3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5A@gooooo000;
ooooo`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5ooooo`OoBDU91om0@407
ofIVIPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B4POoATI61ol51@D7
oaXJ6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF5POoSXj>1_lN7Qh6
ooooo`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/[0Oo@D511olg=cL7
oalO7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T90OoKfm_1olm?Cd6
o`l?3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5A@gooooo000;oooo
o`Oo8R8R1olj>SX7oaHF5POoA4A41olm?Cd7oe]KF`OoADE51_m<C4`5ooooo`OoBDU91om0@407ofIV
IPOoBDU91om6ATH7ofATI0Oooooo1_nh^;P6ooooo`Ko10@41olK6a/7oa8B4POoATI61ol51@D7oaXJ
6POoPX:21_l00006ooooo`OoDe=C1onf][H6o`0000OoY:BT1on1PH47oaHF5POoSXj>1_lN7Qh6oooo
o`Oo<30`1olZ:RX>obHV9PKo;Bd]1olC4a<7ojBTY0Ko9bLW3Oooool7ojb/[0Oo@D511olg=cL7oalO
7`Oo:2PX1_lY:BT6oc4a<@Kooooo1omDE5@7obLW9`OoUYJF1ol:2PX7ob@T90OoKfm_1olm?Cd6o`l?
3`Gooooo1ombLW87ob@T90Oo30`<1om`L707o`P820Oo6QXJ1omZJVX6odE5A@gooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`Oof][J1ol^;Rh7ocTi>@OoAdM71olW9bL7obTY:@Oo820P1_l[
:b/5ooooo`OoMGEe1omBDU87ocDe=@OoEEEE1on8R8P7oi6AT@Oo61PH1_nDU9@6ooooo`Ko6ATI1olG
5aL7o`/;2`Oo3Ph>1olF5QH7ob<S8`Oo:b/[1_lf=SH6ooooo`Oo6ATI1om^KVh6oaTI6@Oo1`L71onJ
VYX7oaPH60Oo51@D1_mgMgL6ooooo`Oo30`<1ol;2`/7o`820POo1`L71_lD51@7obXZ:POo>SXj1_li
>CT6ooooo`Oo9bLW1olP8207oc4a<@Oo=CDe1oli>CT7ocPh>0Ko9BDU1_lK6a/6ooooo`Oo:b/[1om]
KFd7ol?3``Oo;bl_1omKFe/7od51@@OoN7Qh1_l?3`l5ooooo`Oo>3Ph1olC4a<7oaLG5`Oo?Shn1ol0
0007ob4Q8@OoKVi^1_l30`<=ooooo`002oooool7om[JfPOo;Rh^1oli>CT7odM7A`Oo9bLW1olY:BT7
ob0P80Ko:b/[1Oooool7ogEeM@OoDU9B1ole=CD7oeEEE@OoR8R81onATI47oaPH60KoU9BD1_ooool6
oaTI6@Oo5aLG1ol;2`/7o`h>3POo5QHF1olS8b<7ob/[:`Ko=SHf1_ooool7oaTI6@OoKVi^1_lI6AT7
o`L71`OoVYZJ1olH61P7oa@D50KoMgMg1_ooool7o``<30Oo2`/;1ol20P87o`L71`Ko51@D1olZ:RX7
ocXj>PKo>CTi1_ooool7obLW9`Oo820P1ola<C47ocDe=@Oo>CTi1olh>3P6obDU9@Ko6a/K1_ooool7
ob/[:`OoKFe]1oo3`l<7obl_;`OoFe]K1om1@D47ogQhN0Ko3`l?1Oooool7ocPh>0Oo4a<C1olG5aL7
ochn?POo00001olQ8B47ofi^KPKo0`<33Oooool000_ooooo1ooJf]X7obh^;POo>CTi1om7AdL7obLW
9`Oo:BTY1olP8206ob/[:`Gooooo1omeMGD7oe9BDPOo=CDe1omEEED7ohR8R0OoTI6A1olH61P6oiBD
U0Kooooo1_lI6AT7oaLG5`Oo2`/;1ol>3Ph7oaHF5POo8b<S1ol[:b/6ocHf=PKooooo1olI6AT7ofi^
KPKo6ATI1ol71`L7oiZJVPOo61PH1olD51@6ogMgM`Kooooo1ol<30`7o`/;2`Oo0P821ol71`L6oa@D
50Oo:RXZ1olj>SX6ocTi>@Kooooo1olW9bL7ob0P80Oo<C4a1ole=CD7ocTi>@Oo>3Ph1_lU9BD6oa/K
6`Kooooo1ol[:b/7ofe]K@Oo`l?31ol_;bl7oe]KF`Oo@D511omhN7P6o`l?3`Gooooo1olh>3P7oa<C
4`Oo5aLG1oln?Sh7o`0000Oo8B4Q1om^KVh6o`<30`gooooo000;ooooo`Oof][J1ol^;Rh7ocTi>@Oo
AdM71olW9bL7obTY:@Oo820P1_l[:b/5ooooo`OoMGEe1omBDU87ocDe=@OoEEEE1on8R8P7oi6AT@Oo
61PH1_nDU9@6ooooo`Ko6ATI1olG5aL7o`/;2`Oo3Ph>1olF5QH7ob<S8`Oo:b/[1_lf=SH6ooooo`Oo
6ATI1om^KVh6oaTI6@Oo1`L71onJVYX7oaPH60Oo51@D1_mgMgL6ooooo`Oo30`<1ol;2`/7o`820POo
1`L71_lD51@7obXZ:POo>SXj1_li>CT6ooooo`Oo9bLW1olP8207oc4a<@Oo=CDe1oli>CT7ocPh>0Ko
9BDU1_lK6a/6ooooo`Oo:b/[1om]KFd7ol?3``Oo;bl_1omKFe/7od51@@OoN7Qh1_l?3`l5ooooo`Oo
>3Ph1olC4a<7oaLG5`Oo?Shn1ol00007ob4Q8@OoKVi^1_l30`<=ooooo`002oooool7om[JfPOo;Rh^
1oli>CT7odM7A`Oo9bLW1olY:BT7ob0P80Ko:b/[1Oooool7ogEeM@OoDU9B1ole=CD7oeEEE@OoR8R8
1onATI47oaPH60KoU9BD1_ooool6oaTI6@Oo5aLG1ol;2`/7o`h>3POo5QHF1olS8b<7ob/[:`Ko=SHf
1_ooool7oaTI6@OoKVi^1_lI6AT7o`L71`OoVYZJ1olH61P7oa@D50KoMgMg1_ooool7o``<30Oo2`/;
1ol20P87o`L71`Ko51@D1olZ:RX7ocXj>PKo>CTi1_ooool7obLW9`Oo820P1ola<C47ocDe=@Oo>CTi
1olh>3P6obDU9@Ko6a/K1_ooool7ob/[:`OoKFe]1oo3`l<7obl_;`OoFe]K1om1@D47ogQhN0Ko3`l?
1Oooool7ocPh>0Oo4a<C1olG5aL7ochn?POo00001olQ8B47ofi^KPKo0`<33Oooool000_ooooo1ooJ
f]X7obh^;POo>CTi1om7AdL7obLW9`Oo:BTY1olP8206ob/[:`Gooooo1omeMGD7oe9BDPOo=CDe1omE
EED7ohR8R0OoTI6A1olH61P6oiBDU0Kooooo1_lI6AT7oaLG5`Oo2`/;1ol>3Ph7oaHF5POo8b<S1ol[
:b/6ocHf=PKooooo1olI6AT7ofi^KPKo6ATI1ol71`L7oiZJVPOo61PH1olD51@6ogMgM`Kooooo1ol<
30`7o`/;2`Oo0P821ol71`L6oa@D50Oo:RXZ1olj>SX6ocTi>@Kooooo1olW9bL7ob0P80Oo<C4a1ole
=CD7ocTi>@Oo>3Ph1_lU9BD6oa/K6`Kooooo1ol[:b/7ofe]K@Oo`l?31ol_;bl7oe]KF`Oo@D511omh
N7P6o`l?3`Gooooo1olh>3P7oa<C4`Oo5aLG1oln?Sh7o`0000Oo8B4Q1om^KVh6o`<30`gooooo000;
ooooo`Oof][J1ol^;Rh7ocTi>@OoAdM71olW9bL7obTY:@Oo820P1_l[:b/5ooooo`OoMGEe1omBDU87
ocDe=@OoEEEE1on8R8P7oi6AT@Oo61PH1_nDU9@6ooooo`Ko6ATI1olG5aL7o`/;2`Oo3Ph>1olF5QH7
ob<S8`Oo:b/[1_lf=SH6ooooo`Oo6ATI1om^KVh6oaTI6@Oo1`L71onJVYX7oaPH60Oo51@D1_mgMgL6
ooooo`Oo30`<1ol;2`/7o`820POo1`L71_lD51@7obXZ:POo>SXj1_li>CT6ooooo`Oo9bLW1olP8207
oc4a<@Oo=CDe1oli>CT7ocPh>0Ko9BDU1_lK6a/6ooooo`Oo:b/[1om]KFd7ol?3``Oo;bl_1omKFe/7
od51@@OoN7Qh1_l?3`l5ooooo`Oo>3Ph1olC4a<7oaLG5`Oo?Shn1ol00007ob4Q8@OoKVi^1_l30`<=
ooooo`002oooool7oijNWPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?
3`Oo00001ommOGd7oa0@40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:
2POo1`L71olL71`6ob4Q8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE
5@Kooooo1olS8b<7ob8R8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG
5`Oo4A4A1olH61P7ob0P80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7oooo
o`Oo2`/;1olh>3P6ofEUI@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=oooo
o`002oooool7oijNWPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?3`Oo
00001ommOGd7oa0@40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:2POo
1`L71olL71`6ob4Q8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE5@Ko
oooo1olS8b<7ob8R8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG5`Oo
4A4A1olH61P7ob0P80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7ooooo`Oo
2`/;1olh>3P6ofEUI@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=ooooo`00
2oooool7oijNWPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?3`Oo0000
1ommOGd7oa0@40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:2POo1`L7
1olL71`6ob4Q8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE5@Kooooo
1olS8b<7ob8R8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG5`Oo4A4A
1olH61P7ob0P80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7ooooo`Oo2`/;
1olh>3P6ofEUI@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=ooooo`002ooo
ool7oijNWPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?3`Oo00001omm
OGd7oa0@40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:2POo1`L71olL
71`6ob4Q8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE5@Kooooo1olS
8b<7ob8R8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG5`Oo4A4A1olH
61P7ob0P80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7ooooo`Oo2`/;1olh
>3P6ofEUI@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=ooooo`002oooool7
oijNWPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?3`Oo00001ommOGd7
oa0@40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:2POo1`L71olL71`6
ob4Q8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE5@Kooooo1olS8b<7
ob8R8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG5`Oo4A4A1olH61P7
ob0P80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7ooooo`Oo2`/;1olh>3P6
ofEUI@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=ooooo`002oooool7oijN
WPOo;Bd]1olS8b<7oc`l?0Oo7QhN1olV9RH7oahN7PKo;bl_1Oooool7o`l?3`Oo00001ommOGd7oa0@
40Oo:2PX1on[Zj/7oc<c<`KoI6AT1_ooool6oa@D50Oo10@43_l00007o`X:2POo1`L71olL71`6ob4Q
8@Kooooo1olB4Q87og1`L0Ko5aLG1olH61P7ochn?POo;Rh^1oll?3`6oaDE5@Kooooo1olS8b<7ob8R
8POo6ATI1olb<S86oc4a<@OoJf][1olf=SH6oda<C0Kooooo1olN7Qh7oaLG5`Oo4A4A1olH61P7ob0P
80Oo92@T1_lM7Ad6oa`L70Kooooo1olJ6QX7onKViPOoO7al1olS8b<7ooooo`Oo2`/;1olh>3P6ofEU
I@Gooooo1onNWYh7oaPH60Oo92@T1omQHF47oaHF5POo=cLg3Ol0000=ooooo`002oooool7ol30`0Oo
6a/K1olg=cL7ocDe=@Oo4a<C1olZ:RX7ob<S8`Ko820P1Oooool7oa@D50Oo?clo1olE5AD7o`H61POo
MGEe1olI6AT7oa<C4`KoRh^;1_ooool6ob@T90Oo8B4Q3_lW9bL7oaTI6@Oo71`L1ola<C46oclo?`Ko
oooo1om3@d<7od92@PKo6QXJ1oln?Sh7oeYJFPOo20P81olZ:RX6od51@@Kooooo1on5QHD7og=cL`Oo
O7al1onOWil6oj6QX@OoV9RH1onEUID6ofYZJPKooooo1olE5AD7oa<C4`Oo00001ol?3`l7o``<30Oo
4Q8B1_lI6AT6oaXJ6PKooooo1olL71`7ol30`0OoDe=C1om<C4`7ojf][@Oo5ADE1oo0`<06obDU9@Go
oooo1om@D507o`h>3POoalO71ol820P7o`0000OoRHV91olR8R86o`820Pgooooo000;ooooo`Oo`<30
1olK6a/7ocLg=`Oo=CDe1olC4a<7obXZ:POo8b<S1_lP8205ooooo`Oo51@D1olo?cl7oaDE5@Oo1PH6
1omeMGD7oaTI6@Oo4a<C1_n;Rh/6ooooo`Ko92@T1olQ8B4>obLW9`Oo6ATI1olL71`7oc4a<@Ko?clo
1_ooool7od=3@`Oo@T921_lJ6QX7ochn?POoFUYJ1ol820P7obXZ:PKo@D511_ooool7ohF5Q@OoLg=c
1omlO7`7oinOW`KoXJ6Q1onHV9P7oiFEU@KoJVYZ1_ooool7oaDE5@Oo4a<C1ol00007o`l?3`Oo30`<
1olB4Q86oaTI6@Ko6QXJ1_ooool7oa`L70Oo`<301omCDe<7oda<C0Oo[Jf]1olE5AD7ol30`0Ko9BDU
1Oooool7oe1@D0Oo3Ph>1oo7alL7o`P820Oo00001on9RHT7ob8R8PKo0P823Oooool000_ooooo1oo0
`<07oa/K6`Oo=cLg1ole=CD7oa<C4`Oo:RXZ1olS8b<6ob0P80Gooooo1olD51@7oclo?`Oo5ADE1ol6
1PH7ogEeM@Oo6ATI1olC4a<6oh^;R`Kooooo1_lT92@7ob4Q8@ko9bLW1olI6AT7oa`L70Oo<C4a1_lo
?cl6ooooo`Oo@d=31om2@T86oaXJ6POo?Shn1omJFUX7o`P820Oo:RXZ1_m1@D46ooooo`OoQHF51omc
Lg<7ogalO0OoWinO1_nQXJ47oiRHV0OoUIFE1_mZJVX6ooooo`Oo5ADE1olC4a<7o`0000Oo3`l?1ol<
30`7oa8B4PKo6ATI1_lJ6QX6ooooo`Oo71`L1oo0`<07oe=CD`OoC4a<1on][Jd7oaDE5@Oo`<301_lU
9BD5ooooo`OoD51@1ol>3Ph7olO7a`Oo20P81ol00007ohV9R@Oo8R8R1_l20P8=ooooo`002oooool7
ol30`0Oo6a/K1olg=cL7ocDe=@Oo4a<C1olZ:RX7ob<S8`Ko820P1Oooool7oa@D50Oo?clo1olE5AD7
o`H61POoMGEe1olI6AT7oa<C4`KoRh^;1_ooool6ob@T90Oo8B4Q3_lW9bL7oaTI6@Oo71`L1ola<C46
oclo?`Kooooo1om3@d<7od92@PKo6QXJ1oln?Sh7oeYJFPOo20P81olZ:RX6od51@@Kooooo1on5QHD7
og=cL`OoO7al1onOWil6oj6QX@OoV9RH1onEUID6ofYZJPKooooo1olE5AD7oa<C4`Oo00001ol?3`l7
o``<30Oo4Q8B1_lI6AT6oaXJ6PKooooo1olL71`7ol30`0OoDe=C1om<C4`7ojf][@Oo5ADE1oo0`<06
obDU9@Gooooo1om@D507o`h>3POoalO71ol820P7o`0000OoRHV91olR8R86o`820Pgooooo000;oooo
o`Oo`<301olK6a/7ocLg=`Oo=CDe1olC4a<7obXZ:POo8b<S1_lP8205ooooo`Oo51@D1olo?cl7oaDE
5@Oo1PH61omeMGD7oaTI6@Oo4a<C1_n;Rh/6ooooo`Ko92@T1olQ8B4>obLW9`Oo6ATI1olL71`7oc4a
<@Ko?clo1_ooool7od=3@`Oo@T921_lJ6QX7ochn?POoFUYJ1ol820P7obXZ:PKo@D511_ooool7ohF5
Q@OoLg=c1omlO7`7oinOW`KoXJ6Q1onHV9P7oiFEU@KoJVYZ1_ooool7oaDE5@Oo4a<C1ol00007o`l?
3`Oo30`<1olB4Q86oaTI6@Ko6QXJ1_ooool7oa`L70Oo`<301omCDe<7oda<C0Oo[Jf]1olE5AD7ol30
`0Ko9BDU1Oooool7oe1@D0Oo3Ph>1oo7alL7o`P820Oo00001on9RHT7ob8R8PKo0P823Oooool000_o
oooo1oo0`<07oa/K6`Oo=cLg1ole=CD7oa<C4`Oo:RXZ1olS8b<6ob0P80Gooooo1olD51@7oclo?`Oo
5ADE1ol61PH7ogEeM@Oo6ATI1olC4a<6oh^;R`Kooooo1_lT92@7ob4Q8@ko9bLW1olI6AT7oa`L70Oo
<C4a1_lo?cl6ooooo`Oo@d=31om2@T86oaXJ6POo?Shn1omJFUX7o`P820Oo:RXZ1_m1@D46ooooo`Oo
QHF51omcLg<7ogalO0OoWinO1_nQXJ47oiRHV0OoUIFE1_mZJVX6ooooo`Oo5ADE1olC4a<7o`0000Oo
3`l?1ol<30`7oa8B4PKo6ATI1_lJ6QX6ooooo`Oo71`L1oo0`<07oe=CD`OoC4a<1on][Jd7oaDE5@Oo
`<301_lU9BD5ooooo`OoD51@1ol>3Ph7olO7a`Oo20P81ol00007ohV9R@Oo8R8R1_l20P8=ooooo`00
2oooool7ol30`0Oo6a/K1olg=cL7ocDe=@Oo4a<C1olZ:RX7ob<S8`Ko820P1Oooool7oa@D50Oo?clo
1olE5AD7o`H61POoMGEe1olI6AT7oa<C4`KoRh^;1_ooool6ob@T90Oo8B4Q3_lW9bL7oaTI6@Oo71`L
1ola<C46oclo?`Kooooo1om3@d<7od92@PKo6QXJ1oln?Sh7oeYJFPOo20P81olZ:RX6od51@@Kooooo
1on5QHD7og=cL`OoO7al1onOWil6oj6QX@OoV9RH1onEUID6ofYZJPKooooo1olE5AD7oa<C4`Oo0000
1ol?3`l7o``<30Oo4Q8B1_lI6AT6oaXJ6PKooooo1olL71`7ol30`0OoDe=C1om<C4`7ojf][@Oo5ADE
1oo0`<06obDU9@Gooooo1om@D507o`h>3POoalO71ol820P7o`0000OoRHV91olR8R86o`820Pgooooo
000;ooooo`OoPX:21olP8207oaHF5POo:BTY1olU9BD7oaTI6@Oo00001_l^;Rh5ooooo`Oo61PH1omB
DU8>oa`L70Oo<c<c1ol^;Rh7ochn?PKo4a<C1_ooool6oda<C0Oo=SHf1olk>c/7ochn?POo;2`/1ola
<C47od];B`KoIFEU1_ooool7oc/k>`OoW9bL1_lO7al7ocTi>@OoHF5Q1ol@4107odY:BPKo;Rh^1_oo
ool7ogmoO`OoQHF51omaLG47oiRHV0Kooooo1oo2`/87om[JfPKoUiNG1_ooool7o`/;2`Oo5ADE1ol>
3Ph7o`P820Oo5aLG1ol<30`6oalO7`Ko820P1_ooool7ob`/;0OoG5aL1omCDe<7ofYZJPOoSHf=1ol3
0`<7ojVYZ@Ko8R8R1Oooool7ojFUY@Oo>CTi1omSHf<7odY:BPOoMWIf1omGEeL7ob4Q8@KoAdM73Ooo
ool000_ooooo1on2PX87ob0P80Oo5QHF1olY:BT7obDU9@Oo6ATI1ol00006obh^;PGooooo1olH61P7
oe9BDPko71`L1olc<c<7obh^;POo?Shn1_lC4a<6ooooo`KoC4a<1olf=SH7oc/k>`Oo?Shn1ol/;2`7
oc4a<@OoBd];1_mUIFD6ooooo`Oo>c/k1onLW9`6oalO7`Oo>CTi1omQHF47oa0@40OoBTY:1_l^;Rh6
ooooo`OoOgmo1on5QHD7og5aL@OoV9RH1_ooool7ol;2`POof][J1_nGUiL6ooooo`Oo2`/;1olE5AD7
o`h>3POo20P81olG5aL7o``<30Ko7alO1_lP8206ooooo`Oo;2`/1omLG5`7oe=CD`OoJVYZ1on=SHd7
o`<30`OoZJVY1_lR8R85ooooo`OoYJFU1oli>CT7of=SH`OoBTY:1omfMWH7oeMGE`Oo8B4Q1_m7AdL=
ooooo`002oooool7oh:2PPOo820P1olF5QH7obTY:@Oo9BDU1olI6AT7o`0000Ko;Rh^1Oooool7oaPH
60OoDU9B3_lL71`7oc<c<`Oo;Rh^1oln?Sh6oa<C4`Kooooo1_m<C4`7ocHf=POo>c/k1oln?Sh7ob`/
;0Oo<C4a1om;Bd/6ofEUI@Kooooo1olk>c/7oibLW0Ko7alO1oli>CT7of5QH@Oo410@1om:BTX6obh^
;PKooooo1omoOgl7ohF5Q@OoLG5a1onHV9P6ooooo`Oo`/;21ooJf]X6oiNGU`Kooooo1ol;2`/7oaDE
5@Oo3Ph>1ol820P7oaLG5`Oo30`<1_lO7al6ob0P80Kooooo1ol/;2`7oeaLG0OoDe=C1omZJVX7ohf=
S@Oo0`<31onYZJT6ob8R8PGooooo1onUYJD7ocTi>@OoHf=S1om:BTX7ogIfMPOoEeMG1olQ8B46odM7
A`gooooo000;ooooo`OoPX:21olP8207oaHF5POo:BTY1olU9BD7oaTI6@Oo00001_l^;Rh5ooooo`Oo
61PH1omBDU8>oa`L70Oo<c<c1ol^;Rh7ochn?PKo4a<C1_ooool6oda<C0Oo=SHf1olk>c/7ochn?POo
;2`/1ola<C47od];B`KoIFEU1_ooool7oc/k>`OoW9bL1_lO7al7ocTi>@OoHF5Q1ol@4107odY:BPKo
;Rh^1_ooool7ogmoO`OoQHF51omaLG47oiRHV0Kooooo1oo2`/87om[JfPKoUiNG1_ooool7o`/;2`Oo
5ADE1ol>3Ph7o`P820Oo5aLG1ol<30`6oalO7`Ko820P1_ooool7ob`/;0OoG5aL1omCDe<7ofYZJPOo
SHf=1ol30`<7ojVYZ@Ko8R8R1Oooool7ojFUY@Oo>CTi1omSHf<7odY:BPOoMWIf1omGEeL7ob4Q8@Ko
AdM73Oooool000_ooooo1on2PX87ob0P80Oo5QHF1olY:BT7obDU9@Oo6ATI1ol00006obh^;PGooooo
1olH61P7oe9BDPko71`L1olc<c<7obh^;POo?Shn1_lC4a<6ooooo`KoC4a<1olf=SH7oc/k>`Oo?Shn
1ol/;2`7oc4a<@OoBd];1_mUIFD6ooooo`Oo>c/k1onLW9`6oalO7`Oo>CTi1omQHF47oa0@40OoBTY:
1_l^;Rh6ooooo`OoOgmo1on5QHD7og5aL@OoV9RH1_ooool7ol;2`POof][J1_nGUiL6ooooo`Oo2`/;
1olE5AD7o`h>3POo20P81olG5aL7o``<30Ko7alO1_lP8206ooooo`Oo;2`/1omLG5`7oe=CD`OoJVYZ
1on=SHd7o`<30`OoZJVY1_lR8R85ooooo`OoYJFU1oli>CT7of=SH`OoBTY:1omfMWH7oeMGE`Oo8B4Q
1_m7AdL=ooooo`002oooool7oh:2PPOo820P1olF5QH7obTY:@Oo9BDU1olI6AT7o`0000Ko;Rh^1Ooo
ool7oaPH60OoDU9B3_lL71`7oc<c<`Oo;Rh^1oln?Sh6oa<C4`Kooooo1_m<C4`7ocHf=POo>c/k1oln
?Sh7ob`/;0Oo<C4a1om;Bd/6ofEUI@Kooooo1olk>c/7oibLW0Ko7alO1oli>CT7of5QH@Oo410@1om:
BTX6obh^;PKooooo1omoOgl7ohF5Q@OoLG5a1onHV9P6ooooo`Oo`/;21ooJf]X6oiNGU`Kooooo1ol;
2`/7oaDE5@Oo3Ph>1ol820P7oaLG5`Oo30`<1_lO7al6ob0P80Kooooo1ol/;2`7oeaLG0OoDe=C1omZ
JVX7ohf=S@Oo0`<31onYZJT6ob8R8PGooooo1onUYJD7ocTi>@OoHf=S1om:BTX7ogIfMPOoEeMG1olQ
8B46odM7A`gooooo000;ooooo`OoPX:21olP8207oaHF5POo:BTY1olU9BD7oaTI6@Oo00001_l^;Rh5
ooooo`Oo61PH1omBDU8>oa`L70Oo<c<c1ol^;Rh7ochn?PKo4a<C1_ooool6oda<C0Oo=SHf1olk>c/7
ochn?POo;2`/1ola<C47od];B`KoIFEU1_ooool7oc/k>`OoW9bL1_lO7al7ocTi>@OoHF5Q1ol@4107
odY:BPKo;Rh^1_ooool7ogmoO`OoQHF51omaLG47oiRHV0Kooooo1oo2`/87om[JfPKoUiNG1_ooool7
o`/;2`Oo5ADE1ol>3Ph7o`P820Oo5aLG1ol<30`6oalO7`Ko820P1_ooool7ob`/;0OoG5aL1omCDe<7
ofYZJPOoSHf=1ol30`<7ojVYZ@Ko8R8R1Oooool7ojFUY@Oo>CTi1omSHf<7odY:BPOoMWIf1omGEeL7
ob4Q8@KoAdM73Oooool000_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S
8`Gooooo1omgMgL7obTY:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAd
M0OoPh>31ombLW87oe]KF`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L
70OoVYZJ1_lK6a/6ooooo`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606oooo
o`Oo4a<C1olK6a/7oa8B4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T
90Oo^;Rh1ol:2PX7ohZ:RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW
9`Ko5QHF3Oooool000_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S8`Go
oooo1omgMgL7obTY:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAdM0Oo
Ph>31ombLW87oe]KF`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L70Oo
VYZJ1_lK6a/6ooooo`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606ooooo`Oo
4a<C1olK6a/7oa8B4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T90Oo
^;Rh1ol:2PX7ohZ:RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW9`Ko
5QHF3Oooool000_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S8`Gooooo
1omgMgL7obTY:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAdM0OoPh>3
1ombLW87oe]KF`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L70OoVYZJ
1_lK6a/6ooooo`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606ooooo`Oo4a<C
1olK6a/7oa8B4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T90Oo^;Rh
1ol:2PX7ohZ:RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW9`Ko5QHF
3Oooool000_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S8`Gooooo1omg
MgL7obTY:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAdM0OoPh>31omb
LW87oe]KF`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L70OoVYZJ1_lK
6a/6ooooo`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606ooooo`Oo4a<C1olK
6a/7oa8B4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T90Oo^;Rh1ol:
2PX7ohZ:RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW9`Ko5QHF3Ooo
ool000_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S8`Gooooo1omgMgL7
obTY:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAdM0OoPh>31ombLW87
oe]KF`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L70OoVYZJ1_lK6a/6
ooooo`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606ooooo`Oo4a<C1olK6a/7
oa8B4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T90Oo^;Rh1ol:2PX7
ohZ:RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW9`Ko5QHF3Oooool0
00_ooooo1oo^k^h7ob<S8`Oo=CDe1om8B4P7oa/K6`Oo=SHf1olU9BD6ob<S8`Gooooo1omgMgL7obTY
:@Oo6a/K1omXJ6P7obd];@Oo92@T1ol];Bd6obTY:@Kooooo3On6QXH7ogAdM0OoPh>31ombLW87oe]K
F`OoHV9R1_mNGUh6ooooo`Oog=cL1om;Bd/6o`P820Oooooo1ol>3Ph7oa`L70OoVYZJ1_lK6a/6oooo
o`OoPH611omXJ6P7og=cL`OoPh>31_n2PX87ohn?S`OoUIFE1_mPH606ooooo`Oo4a<C1olK6a/7oa8B
4POo61PH1olK6a/7oahN7Pco8R8R1_ooool7oaLG5`OoW9bL1ol10@47ob@T90Oo^;Rh1ol:2PX7ohZ:
RPKo<S8b1Oooool7oi6AT@Oo<c<c1oooool7o`/;2`Oo@d=31ooclo<7obLW9`Ko5QHF3Oooool000_o
oooo1on<S8`7oc4a<@Oo61PH1ol`<307ob/[:`Oo9BDU1olB4Q86oahN7PGooooo1olo?cl7oiRHV0Oo
?Cdm1om0@407ofATI0OoBDU91oli>CT6obXZ:PKooooo1_n`/;07oj6QX@OoW9bL1on`/;07oh:2PPOo
JFUY1om5ADD6of1PH0Kooooo1onFUYH7oeADE0KoI6AT1on=SHd7oc<c<`OoXJ6Q1olQ8B46oahN7PKo
oooo1olg=cL>obXZ:POo;Bd]1_m4A4@7oc8b<POo@T921_lh>3P6ooooo`Oo92@T1olN7Qh7ob/[:`Oo
71`L1olQ8B47obTY:@Ko;Bd]1_lF5QH6ooooo`Oo;2`/1olI6AT7oa/K6`OoLg=c1olI6AT7o`0000Oo
/;2`1_l00005ooooo`Oo?Shn1om4A4@7omCDe0Oo3@d=1oo8b<P7og]kN`Oo51@D1_nMWId=ooooo`00
2oooool7ohb<S0Oo<C4a1olH61P7oc0`<0Oo:b/[1olU9BD7oa8B4PKo7QhN1Oooool7oclo?`OoV9RH
1olm?Cd7od10@0OoI6AT1om9BDT7ocTi>@Ko:RXZ1_ooool6ok2`/0OoXJ6Q1onLW9`7ok2`/0OoPX:2
1omYJFT7odE5A@KoH61P1_ooool7oiJFUPOoE5AD1_mTI6@7ohf=S@Oo<c<c1onQXJ47ob4Q8@Ko7QhN
1_ooool7ocLg=`ko:RXZ1ol];Bd6odA4A0Oo<S8b1om2@T86ocPh>0Kooooo1olT92@7oahN7POo:b/[
1olL71`7ob4Q8@Oo:BTY1_l];Bd6oaHF5PKooooo1ol/;2`7oaTI6@Oo6a/K1omcLg<7oaTI6@Oo0000
1on`/;06o`0000Gooooo1oln?Sh7odA4A0Ooe=CD1ol=3@d7olS8b0OoNg]k1olD51@6oifMW@gooooo
000;ooooo`OoS8b<1ola<C47oaPH60Oo<30`1ol[:b/7obDU9@Oo4Q8B1_lN7Qh5ooooo`Oo?clo1onH
V9P7ocdm?@Oo@4101omTI6@7odU9B@Oo>CTi1_lZ:RX6ooooo`Ko/;2`1onQXJ47oibLW0Oo/;2`1on2
PX87ofUYJ@OoADE51_mPH606ooooo`OoUYJF1omDE5@6ofATI0OoSHf=1olc<c<7oj6QX@Oo8B4Q1_lN
7Qh6ooooo`Oo=cLg3_lZ:RX7obd];@KoA4A41olb<S87od92@PKo>3Ph1_ooool7ob@T90Oo7QhN1ol[
:b/7oa`L70Oo8B4Q1olY:BT6obd];@Ko5QHF1_ooool7ob`/;0Oo6ATI1olK6a/7og=cL`Oo6ATI1ol0
0007ok2`/0Ko00001Oooool7ochn?POoA4A41ooDe=@7o`d=3@Oob<S81omkNg/7oa@D50KoWIfM3Ooo
ool000_ooooo1on<S8`7oc4a<@Oo61PH1ol`<307ob/[:`Oo9BDU1olB4Q86oahN7PGooooo1olo?cl7
oiRHV0Oo?Cdm1om0@407ofATI0OoBDU91oli>CT6obXZ:PKooooo1_n`/;07oj6QX@OoW9bL1on`/;07
oh:2PPOoJFUY1om5ADD6of1PH0Kooooo1onFUYH7oeADE0KoI6AT1on=SHd7oc<c<`OoXJ6Q1olQ8B46
oahN7PKooooo1olg=cL>obXZ:POo;Bd]1_m4A4@7oc8b<POo@T921_lh>3P6ooooo`Oo92@T1olN7Qh7
ob/[:`Oo71`L1olQ8B47obTY:@Ko;Bd]1_lF5QH6ooooo`Oo;2`/1olI6AT7oa/K6`OoLg=c1olI6AT7
o`0000Oo/;2`1_l00005ooooo`Oo?Shn1om4A4@7omCDe0Oo3@d=1oo8b<P7og]kN`Oo51@D1_nMWId=
ooooo`002oooool7ohb<S0Oo<C4a1olH61P7oc0`<0Oo:b/[1olU9BD7oa8B4PKo7QhN1Oooool7oclo
?`OoV9RH1olm?Cd7od10@0OoI6AT1om9BDT7ocTi>@Ko:RXZ1_ooool6ok2`/0OoXJ6Q1onLW9`7ok2`
/0OoPX:21omYJFT7odE5A@KoH61P1_ooool7oiJFUPOoE5AD1_mTI6@7ohf=S@Oo<c<c1onQXJ47ob4Q
8@Ko7QhN1_ooool7ocLg=`ko:RXZ1ol];Bd6odA4A0Oo<S8b1om2@T86ocPh>0Kooooo1olT92@7oahN
7POo:b/[1olL71`7ob4Q8@Oo:BTY1_l];Bd6oaHF5PKooooo1ol/;2`7oaTI6@Oo6a/K1omcLg<7oaTI
6@Oo00001on`/;06o`0000Gooooo1oln?Sh7odA4A0Ooe=CD1ol=3@d7olS8b0OoNg]k1olD51@6oifM
W@gooooo000;ooooo`OoS8b<1ola<C47oaPH60Oo<30`1ol[:b/7obDU9@Oo4Q8B1_lN7Qh5ooooo`Oo
?clo1onHV9P7ocdm?@Oo@4101omTI6@7odU9B@Oo>CTi1_lZ:RX6ooooo`Ko/;2`1onQXJ47oibLW0Oo
/;2`1on2PX87ofUYJ@OoADE51_mPH606ooooo`OoUYJF1omDE5@6ofATI0OoSHf=1olc<c<7oj6QX@Oo
8B4Q1_lN7Qh6ooooo`Oo=cLg3_lZ:RX7obd];@KoA4A41olb<S87od92@PKo>3Ph1_ooool7ob@T90Oo
7QhN1ol[:b/7oa`L70Oo8B4Q1olY:BT6obd];@Ko5QHF1_ooool7ob`/;0Oo6ATI1olK6a/7og=cL`Oo
6ATI1ol00007ok2`/0Ko00001Oooool7ochn?POoA4A41ooDe=@7o`d=3@Oob<S81omkNg/7oa@D50Ko
WIfM3Oooool000_ooooo1on<S8`7oc4a<@Oo61PH1ol`<307ob/[:`Oo9BDU1olB4Q86oahN7PGooooo
1olo?cl7oiRHV0Oo?Cdm1om0@407ofATI0OoBDU91oli>CT6obXZ:PKooooo1_n`/;07oj6QX@OoW9bL
1on`/;07oh:2PPOoJFUY1om5ADD6of1PH0Kooooo1onFUYH7oeADE0KoI6AT1on=SHd7oc<c<`OoXJ6Q
1olQ8B46oahN7PKooooo1olg=cL>obXZ:POo;Bd]1_m4A4@7oc8b<POo@T921_lh>3P6ooooo`Oo92@T
1olN7Qh7ob/[:`Oo71`L1olQ8B47obTY:@Ko;Bd]1_lF5QH6ooooo`Oo;2`/1olI6AT7oa/K6`OoLg=c
1olI6AT7o`0000Oo/;2`1_l00005ooooo`Oo?Shn1om4A4@7omCDe0Oo3@d=1oo8b<P7og]kN`Oo51@D
1_nMWId=ooooo`004_ooool7od92@POoC4a<1omKFe/7oadM7@Oo=CDe1ol[:b/6oaPH60Gooooo1ooa
lO47oeMGE`Oo:BTY1oooool7oa@D50Oo:b/[1om_Kfl6obd];@Kooooo1_nBTY87oh>3P`OoNWYj1onP
X:07oiFEU@OoShn?1omWIfL6ohZ:RPKooooo1onh^;P7od92@PKo=SHf1ooHf=P7obTY:@OoB4Q81onO
Wil6of9RHPKooooo1olQ8B47oadM7@Oo00001ol71`L6o`0000Oo20P81ol61PH6oaLG5`Kooooo1olX
:2P7obLW9`ko=3@d1olM7Ad7ocTi>@Ko:BTY1_lL71`6ooooo`Oo@4101olm?Cd7obDU9@Oo=SHf1om9
BDT7oc`l?0Oo@4101_lG5aL5ooooo`koLG5a1on0P807o`820POoVi^K1omoOgl7oc<c<`KoDE5A3Ooo
ool001;ooooo1om2@T87oda<C0OoFe]K1olM7Ad7ocDe=@Oo:b/[1_lH61P5ooooo`OolO7a1omGEeL7
obTY:@Oooooo1olD51@7ob/[:`OoKfm_1_l];Bd6ooooo`KoTY:B1on3Ph<7ogYjNPOoX:2P1onEUID7
ohn?S`OoIfMW1_n:RXX6ooooo`Oo^;Rh1om2@T86ocHf=POof=SH1olY:BT7odQ8B0OoWinO1_mRHV86
ooooo`Oo8B4Q1olM7Ad7o`0000Oo1`L71_l00007o`P820Oo1PH61_lG5aL6ooooo`Oo:2PX1olW9bL>
oc@d=0Oo7AdM1oli>CT6obTY:@Ko71`L1_ooool7od10@0Oo?Cdm1olU9BD7ocHf=POoBDU91oll?3`7
od10@0Ko5aLG1Oooool>og5aL@OoP8201ol20P87oi^KV`OoOgmo1olc<c<6oe5AD@gooooo000Boooo
o`Oo@T921om<C4`7oe]KF`Oo7AdM1ole=CD7ob/[:`Ko61PH1Oooool7oo7al@OoEeMG1olY:BT7oooo
o`Oo51@D1ol[:b/7ofm_K`Ko;Bd]1_ooool6oi:BTPOoPh>31omjNWX7oj2PX0OoUIFE1on?Shl7ofMW
I`KoRXZ:1_ooool7okRh^0Oo@T921_lf=SH7omSHf0Oo:BTY1om8B4P7oinOW`KoHV9R1_ooool7ob4Q
8@Oo7AdM1ol00007o`L71`Ko00001ol820P7o`H61PKo5aLG1_ooool7obPX:0Oo9bLW3_ld=3@7oadM
7@Oo>CTi1_lY:BT6oa`L70Kooooo1om0@407ocdm?@Oo9BDU1olf=SH7odU9B@Oo?3`l1om0@406oaLG
5`Gooooo3_maLG47oh20P0Oo0P821onKVi/7ogmoO`Oo<c<c1_mADE4=ooooo`004_ooool7od92@POo
C4a<1omKFe/7oadM7@Oo=CDe1ol[:b/6oaPH60Gooooo1ooalO47oeMGE`Oo:BTY1oooool7oa@D50Oo
:b/[1om_Kfl6obd];@Kooooo1_nBTY87oh>3P`OoNWYj1onPX:07oiFEU@OoShn?1omWIfL6ohZ:RPKo
oooo1onh^;P7od92@PKo=SHf1ooHf=P7obTY:@OoB4Q81onOWil6of9RHPKooooo1olQ8B47oadM7@Oo
00001ol71`L6o`0000Oo20P81ol61PH6oaLG5`Kooooo1olX:2P7obLW9`ko=3@d1olM7Ad7ocTi>@Ko
:BTY1_lL71`6ooooo`Oo@4101olm?Cd7obDU9@Oo=SHf1om9BDT7oc`l?0Oo@4101_lG5aL5ooooo`ko
LG5a1on0P807o`820POoVi^K1omoOgl7oc<c<`KoDE5A3Oooool001;ooooo1om2@T87oda<C0OoFe]K
1olM7Ad7ocDe=@Oo:b/[1_lH61P5ooooo`OolO7a1omGEeL7obTY:@Oooooo1olD51@7ob/[:`OoKfm_
1_l];Bd6ooooo`KoTY:B1on3Ph<7ogYjNPOoX:2P1onEUID7ohn?S`OoIfMW1_n:RXX6ooooo`Oo^;Rh
1om2@T86ocHf=POof=SH1olY:BT7odQ8B0OoWinO1_mRHV86ooooo`Oo8B4Q1olM7Ad7o`0000Oo1`L7
1_l00007o`P820Oo1PH61_lG5aL6ooooo`Oo:2PX1olW9bL>oc@d=0Oo7AdM1oli>CT6obTY:@Ko71`L
1_ooool7od10@0Oo?Cdm1olU9BD7ocHf=POoBDU91oll?3`7od10@0Ko5aLG1Oooool>og5aL@OoP820
1ol20P87oi^KV`OoOgmo1olc<c<6oe5AD@gooooo000Booooo`Oo@T921om<C4`7oe]KF`Oo7AdM1ole
=CD7ob/[:`Ko61PH1Oooool7oo7al@OoEeMG1olY:BT7ooooo`Oo51@D1ol[:b/7ofm_K`Ko;Bd]1_oo
ool6oi:BTPOoPh>31omjNWX7oj2PX0OoUIFE1on?Shl7ofMWI`KoRXZ:1_ooool7okRh^0Oo@T921_lf
=SH7omSHf0Oo:BTY1om8B4P7oinOW`KoHV9R1_ooool7ob4Q8@Oo7AdM1ol00007o`L71`Ko00001ol8
20P7o`H61PKo5aLG1_ooool7obPX:0Oo9bLW3_ld=3@7oadM7@Oo>CTi1_lY:BT6oa`L70Kooooo1om0
@407ocdm?@Oo9BDU1olf=SH7odU9B@Oo?3`l1om0@406oaLG5`Gooooo3_maLG47oh20P0Oo0P821onK
Vi/7ogmoO`Oo<c<c1_mADE4=ooooo`004_ooool7od92@POoC4a<1omKFe/7oadM7@Oo=CDe1ol[:b/6
oaPH60Gooooo1ooalO47oeMGE`Oo:BTY1oooool7oa@D50Oo:b/[1om_Kfl6obd];@Kooooo1_nBTY87
oh>3P`OoNWYj1onPX:07oiFEU@OoShn?1omWIfL6ohZ:RPKooooo1onh^;P7od92@PKo=SHf1ooHf=P7
obTY:@OoB4Q81onOWil6of9RHPKooooo1olQ8B47oadM7@Oo00001ol71`L6o`0000Oo20P81ol61PH6
oaLG5`Kooooo1olX:2P7obLW9`ko=3@d1olM7Ad7ocTi>@Ko:BTY1_lL71`6ooooo`Oo@4101olm?Cd7
obDU9@Oo=SHf1om9BDT7oc`l?0Oo@4101_lG5aL5ooooo`koLG5a1on0P807o`820POoVi^K1omoOgl7
oc<c<`KoDE5A3Oooool000_ooooo1oo=cLd7oeADE0Oo<30`1omIFET7oc@d=0Oo7QhN1olQ8B46od10
@0Gooooo1ol/;2`7ob0P80OoXj>S1olS8b<7ode=C@OoW9bL1olQ8B46oiNGU`Kooooo1_mnOWh7ok6a
/@Oo]kNg1on][Jd7oi2@T0Oooooo1ooIfMT6ohB4Q0Kooooo1ol30`<7ob<S8`KoLg=c1ol00007ocXj
>POoT92@1ol00006ob@T90Kooooo1om_Kfl7oe1@D0Oo@D511omTI6@6od=3@`OoPH611omYJFT6og9b
LPKooooo1om2@T87oe9BDPOo<30`1omjNWX7ooooo`OoKFe]1_m5ADD6oclo?`Kooooo1olk>c/7ohV9
R@Oo:BTY1olP8207oc8b<POo10@41ol=3@d6ob4Q8@Gooooo1ol30`<7odE5A@Oo1`L71olR8R87ofm_
K`Oo1@D51ol];Bd6obDU9@gooooo000;ooooo`OocLg=1omDE5@7oc0`<0OoFEUI1old=3@7oahN7POo
8B4Q1_m0@405ooooo`Oo;2`/1olP8207oj>SX`Oo8b<S1om=CDd7oibLW0Oo8B4Q1_nGUiL6ooooo`Ko
OWin1ona/K47okNg]`Oo[Jf]1on@T907ooooo`OofMWI1_n4Q8@6ooooo`Oo0`<31olS8b<6og=cL`Oo
00001olj>SX7oi2@T0Oo00001_lT92@6ooooo`OoKfm_1om@D507od51@@OoI6AT1_m3@d<7oh61P@Oo
JFUY1_mbLW86ooooo`Oo@T921omBDU87oc0`<0OoNWYj1oooool7ofe]K@KoADE51_lo?cl6ooooo`Oo
>c/k1on9RHT7obTY:@Oo820P1olb<S87o`@410Oo3@d=1_lQ8B45ooooo`Oo0`<31om5ADD7o`L71`Oo
8R8R1om_Kfl7o`D51@Oo;Bd]1_lU9BD=ooooo`002oooool7olg=c@OoE5AD1ol`<307oeUIF@Oo=3@d
1olN7Qh7ob4Q8@Ko@4101Oooool7ob`/;0Oo820P1onSXj<7ob<S8`OoCDe=1onLW9`7ob4Q8@KoUiNG
1_ooool6oginOPOo/K6a1ong]kL7ojf][@OoT92@1oooool7omWIf@KoQ8B41_ooool7o`<30`Oo8b<S
1_mcLg<7o`0000Oo>SXj1on@T907o`0000Ko92@T1_ooool7ofm_K`OoD51@1om1@D47ofATI0Ko@d=3
1on1PH47ofUYJ@KoLW9b1_ooool7od92@POoDU9B1ol`<307ogYjNPOooooo1om]KFd6odE5A@Ko?clo
1_ooool7oc/k>`OoRHV91olY:BT7ob0P80Oo<S8b1ol410@7o`d=3@Ko8B4Q1Oooool7o`<30`OoADE5
1ol71`L7ob8R8POoKfm_1ol51@D7obd];@Ko9BDU3Oooool000_ooooo1oo=cLd7oeADE0Oo<30`1omI
FET7oc@d=0Oo7QhN1olQ8B46od10@0Gooooo1ol/;2`7ob0P80OoXj>S1olS8b<7ode=C@OoW9bL1olQ
8B46oiNGU`Kooooo1_mnOWh7ok6a/@Oo]kNg1on][Jd7oi2@T0Oooooo1ooIfMT6ohB4Q0Kooooo1ol3
0`<7ob<S8`KoLg=c1ol00007ocXj>POoT92@1ol00006ob@T90Kooooo1om_Kfl7oe1@D0Oo@D511omT
I6@6od=3@`OoPH611omYJFT6og9bLPKooooo1om2@T87oe9BDPOo<30`1omjNWX7ooooo`OoKFe]1_m5
ADD6oclo?`Kooooo1olk>c/7ohV9R@Oo:BTY1olP8207oc8b<POo10@41ol=3@d6ob4Q8@Gooooo1ol3
0`<7odE5A@Oo1`L71olR8R87ofm_K`Oo1@D51ol];Bd6obDU9@gooooo000;ooooo`OocLg=1omDE5@7
oc0`<0OoFEUI1old=3@7oahN7POo8B4Q1_m0@405ooooo`Oo;2`/1olP8207oj>SX`Oo8b<S1om=CDd7
oibLW0Oo8B4Q1_nGUiL6ooooo`KoOWin1ona/K47okNg]`Oo[Jf]1on@T907ooooo`OofMWI1_n4Q8@6
ooooo`Oo0`<31olS8b<6og=cL`Oo00001olj>SX7oi2@T0Oo00001_lT92@6ooooo`OoKfm_1om@D507
od51@@OoI6AT1_m3@d<7oh61P@OoJFUY1_mbLW86ooooo`Oo@T921omBDU87oc0`<0OoNWYj1oooool7
ofe]K@KoADE51_lo?cl6ooooo`Oo>c/k1on9RHT7obTY:@Oo820P1olb<S87o`@410Oo3@d=1_lQ8B45
ooooo`Oo0`<31om5ADD7o`L71`Oo8R8R1om_Kfl7o`D51@Oo;Bd]1_lU9BD=ooooo`002oooool7olg=
c@OoE5AD1ol`<307oeUIF@Oo=3@d1olN7Qh7ob4Q8@Ko@4101Oooool7ob`/;0Oo820P1onSXj<7ob<S
8`OoCDe=1onLW9`7ob4Q8@KoUiNG1_ooool6oginOPOo/K6a1ong]kL7ojf][@OoT92@1oooool7omWI
f@KoQ8B41_ooool7o`<30`Oo8b<S1_mcLg<7o`0000Oo>SXj1on@T907o`0000Ko92@T1_ooool7ofm_
K`OoD51@1om1@D47ofATI0Ko@d=31on1PH47ofUYJ@KoLW9b1_ooool7od92@POoDU9B1ol`<307ogYj
NPOooooo1om]KFd6odE5A@Ko?clo1_ooool7oc/k>`OoRHV91olY:BT7ob0P80Oo<S8b1ol410@7o`d=
3@Ko8B4Q1Oooool7o`<30`OoADE51ol71`L7ob8R8POoKfm_1ol51@D7obd];@Ko9BDU3Oooool000_o
oooo1oo=cLd7oeADE0Oo<30`1omIFET7oc@d=0Oo7QhN1olQ8B46od10@0Gooooo1ol/;2`7ob0P80Oo
Xj>S1olS8b<7ode=C@OoW9bL1olQ8B46oiNGU`Kooooo1_mnOWh7ok6a/@Oo]kNg1on][Jd7oi2@T0Oo
oooo1ooIfMT6ohB4Q0Kooooo1ol30`<7ob<S8`KoLg=c1ol00007ocXj>POoT92@1ol00006ob@T90Ko
oooo1om_Kfl7oe1@D0Oo@D511omTI6@6od=3@`OoPH611omYJFT6og9bLPKooooo1om2@T87oe9BDPOo
<30`1omjNWX7ooooo`OoKFe]1_m5ADD6oclo?`Kooooo1olk>c/7ohV9R@Oo:BTY1olP8207oc8b<POo
10@41ol=3@d6ob4Q8@Gooooo1ol30`<7odE5A@Oo1`L71olR8R87ofm_K`Oo1@D51ol];Bd6obDU9@go
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`Oo;Rh^1om[Jf/7oa/K6`Oo<S8b1ole=CD7oe5AD@OoNWYj1_mH
F5P5ooooo`Oo:b/[1olT92@7obHV9POo:BTY1olI6AT7obHV9POo@D511_m0@406ooooo`Ko?Shn1omX
J6P7odI6APOo>c/k1omCDe<7ofi^KPgo:RXZ1_ooool7obPX:0Oo/k>c1_l92@T7oeIFEPOoaLG51olg
=cL7oijNWPKo=cLg1_ooool7o`h>3POo5aLG1oli>CT7oc4a<@KoD51@1om:BTX7ocDe=@Ko8B4Q1_oo
ool7obh^;POo?Shn1olc<c<7obl_;`Oo3@d=1olA4A46o`d=3@Ko3`l?1_ooool7odm?C`Oo10@41ol^
;Rh7oh>3P`Oo4A4A1olk>c/7ohB4Q0Ko;Rh^1Oooool7ob@T90Oo?Cdm1on`/;07ofQXJ0Oo1`L71onm
_Kd7odI6APKoMWIf3Oooool000_ooooo1ol^;Rh7of][J`Oo6a/K1olb<S87ocDe=@OoDE5A1omjNWX6
oeQHF0Gooooo1ol[:b/7ob@T90Oo9RHV1olY:BT7oaTI6@Oo9RHV1om1@D46od10@0Kooooo1_ln?Sh7
ofQXJ0OoATI61olk>c/7oe=CD`OoKVi^3OlZ:RX6ooooo`Oo:2PX1onc/k<6o`T92@OoEUIF1oo5aLD7
ocLg=`OoWYjN1_lg=cL6ooooo`Oo3Ph>1olG5aL7ocTi>@Oo<C4a1_m@D507odY:BPOo=CDe1_lQ8B46
ooooo`Oo;Rh^1oln?Sh7oc<c<`Oo;bl_1ol=3@d7oa4A4@Ko3@d=1_l?3`l6ooooo`OoCdm?1ol410@7
obh^;POoPh>31olA4A47oc/k>`OoQ8B41_l^;Rh5ooooo`Oo92@T1olm?Cd7ok2`/0OoJ6QX1ol71`L7
okfm_@OoATI61_mfMWH=ooooo`002oooool7obh^;POoJf][1olK6a/7oc8b<POo=CDe1omADE47ogYj
NPKoF5QH1Oooool7ob/[:`Oo92@T1olV9RH7obTY:@Oo6ATI1olV9RH7od51@@Ko@4101_ooool6ochn
?POoJ6QX1om6ATH7oc/k>`OoDe=C1om^KVh=obXZ:PKooooo1olX:2P7ok>c/`Ko2@T91omFEUH7olG5
a@Oo=cLg1onNWYh6ocLg=`Kooooo1ol>3Ph7oaLG5`Oo>CTi1ola<C46oe1@D0OoBTY:1ole=CD6ob4Q
8@Kooooo1ol^;Rh7ochn?POo<c<c1ol_;bl7o`d=3@Oo4A4A1_l=3@d6o`l?3`Kooooo1om?Cdl7o`@4
10Oo;Rh^1on3Ph<7oa4A4@Oo>c/k1on4Q8@6obh^;PGooooo1olT92@7ocdm?@Oo/;2`1omXJ6P7o`L7
1`Oo_Kfm1om6ATH6ogIfMPgooooo000;ooooo`Oo;Rh^1om[Jf/7oa/K6`Oo<S8b1ole=CD7oe5AD@Oo
NWYj1_mHF5P5ooooo`Oo:b/[1olT92@7obHV9POo:BTY1olI6AT7obHV9POo@D511_m0@406ooooo`Ko
?Shn1omXJ6P7odI6APOo>c/k1omCDe<7ofi^KPgo:RXZ1_ooool7obPX:0Oo/k>c1_l92@T7oeIFEPOo
aLG51olg=cL7oijNWPKo=cLg1_ooool7o`h>3POo5aLG1oli>CT7oc4a<@KoD51@1om:BTX7ocDe=@Ko
8B4Q1_ooool7obh^;POo?Shn1olc<c<7obl_;`Oo3@d=1olA4A46o`d=3@Ko3`l?1_ooool7odm?C`Oo
10@41ol^;Rh7oh>3P`Oo4A4A1olk>c/7ohB4Q0Ko;Rh^1Oooool7ob@T90Oo?Cdm1on`/;07ofQXJ0Oo
1`L71onm_Kd7odI6APKoMWIf3Oooool000_ooooo1ol^;Rh7of][J`Oo6a/K1olb<S87ocDe=@OoDE5A
1omjNWX6oeQHF0Gooooo1ol[:b/7ob@T90Oo9RHV1olY:BT7oaTI6@Oo9RHV1om1@D46od10@0Kooooo
1_ln?Sh7ofQXJ0OoATI61olk>c/7oe=CD`OoKVi^3OlZ:RX6ooooo`Oo:2PX1onc/k<6o`T92@OoEUIF
1oo5aLD7ocLg=`OoWYjN1_lg=cL6ooooo`Oo3Ph>1olG5aL7ocTi>@Oo<C4a1_m@D507odY:BPOo=CDe
1_lQ8B46ooooo`Oo;Rh^1oln?Sh7oc<c<`Oo;bl_1ol=3@d7oa4A4@Ko3@d=1_l?3`l6ooooo`OoCdm?
1ol410@7obh^;POoPh>31olA4A47oc/k>`OoQ8B41_l^;Rh5ooooo`Oo92@T1olm?Cd7ok2`/0OoJ6QX
1ol71`L7okfm_@OoATI61_mfMWH=ooooo`002oooool7obh^;POoJf][1olK6a/7oc8b<POo=CDe1omA
DE47ogYjNPKoF5QH1Oooool7ob/[:`Oo92@T1olV9RH7obTY:@Oo6ATI1olV9RH7od51@@Ko@4101_oo
ool6ochn?POoJ6QX1om6ATH7oc/k>`OoDe=C1om^KVh=obXZ:PKooooo1olX:2P7ok>c/`Ko2@T91omF
EUH7olG5a@Oo=cLg1onNWYh6ocLg=`Kooooo1ol>3Ph7oaLG5`Oo>CTi1ola<C46oe1@D0OoBTY:1ole
=CD6ob4Q8@Kooooo1ol^;Rh7ochn?POo<c<c1ol_;bl7o`d=3@Oo4A4A1_l=3@d6o`l?3`Kooooo1om?
Cdl7o`@410Oo;Rh^1on3Ph<7oa4A4@Oo>c/k1on4Q8@6obh^;PGooooo1olT92@7ocdm?@Oo/;2`1omX
J6P7o`L71`Oo_Kfm1om6ATH6ogIfMPgooooo000;ooooo`Oo;Rh^1om[Jf/7oa/K6`Oo<S8b1ole=CD7
oe5AD@OoNWYj1_mHF5P5ooooo`Oo:b/[1olT92@7obHV9POo:BTY1olI6AT7obHV9POo@D511_m0@406
ooooo`Ko?Shn1omXJ6P7odI6APOo>c/k1omCDe<7ofi^KPgo:RXZ1_ooool7obPX:0Oo/k>c1_l92@T7
oeIFEPOoaLG51olg=cL7oijNWPKo=cLg1_ooool7o`h>3POo5aLG1oli>CT7oc4a<@KoD51@1om:BTX7
ocDe=@Ko8B4Q1_ooool7obh^;POo?Shn1olc<c<7obl_;`Oo3@d=1olA4A46o`d=3@Ko3`l?1_ooool7
odm?C`Oo10@41ol^;Rh7oh>3P`Oo4A4A1olk>c/7ohB4Q0Ko;Rh^1Oooool7ob@T90Oo?Cdm1on`/;07
ofQXJ0Oo1`L71onm_Kd7odI6APKoMWIf3Oooool000_ooooo1ombLW8>oi^KV`OoN7Qh1omdM7@7oi^K
V`Ooa<C41_mlO7`5ooooo`Oo8R8R1olc<c<7obDU9@Oo<c<c1olI6AT7ob0P80Oo:b/[1_lc<c<6oooo
o`Ko@D511olO7al7ocDe=@OoDU9B1olF5QH7obl_;`OoKFe]1_lN7Qh6ooooo`OoB4Q81olB4Q86o`h>
3POoTI6A1olE5AD7oadM7@Ooe=CD1_l10@46ooooo`Oo2@T91olM7Ad7obHV9POo4A4A1_mbLW87oa@D
50Oo3Ph>1_lH61P6ooooo`Oo5QHF1olI6AT7oalO7`Oo61PH1olG5aL7o``<30Ko6QXJ1_lD51@6oooo
o`Oo=3@d1olE5AD7odm?C`Oo2@T91ol:2PX7ofe]K@Oo3@d=1_l00005ooooo`OoFEUI1ol20P87obl_
;`OoQ8B41ola<C47ofa/K0OoE5AD1_n4Q8@=ooooo`002oooool7og9bLPkoVi^K1omhN7P7ogAdM0Oo
Vi^K1oo4a<@6ogalO0Gooooo1olR8R87oc<c<`Oo9BDU1olc<c<7oaTI6@Oo820P1ol[:b/6oc<c<`Ko
oooo1_m1@D47oalO7`Oo=CDe1omBDU87oaHF5POo;bl_1om]KFd6oahN7PKooooo1om8B4P7oa8B4PKo
3Ph>1onATI47oaDE5@Oo7AdM1ooDe=@6o`410@Kooooo1ol92@T7oadM7@Oo9RHV1olA4A46og9bLPOo
51@D1ol>3Ph6oaPH60Kooooo1olF5QH7oaTI6@Oo7alO1olH61P7oaLG5`Oo30`<1_lJ6QX6oa@D50Ko
oooo1old=3@7oaDE5@OoCdm?1ol92@T7o`X:2POoKFe]1ol=3@d6o`0000Gooooo1omIFET7o`820POo
;bl_1on4Q8@7oc4a<@OoK6a/1omDE5@6ohB4Q0gooooo000;ooooo`OoLW9b3_nKVi/7ogQhN0OoM7Ad
1onKVi/7olC4a0KoO7al1Oooool7ob8R8POo<c<c1olU9BD7oc<c<`Oo6ATI1olP8207ob/[:`Ko<c<c
1_ooool6od51@@Oo7alO1ole=CD7oe9BDPOo5QHF1ol_;bl7ofe]K@Ko7QhN1_ooool7odQ8B0Oo4Q8B
1_l>3Ph7oi6AT@Oo5ADE1olM7Ad7omCDe0Ko0@411_ooool7o`T92@Oo7AdM1olV9RH7oa4A4@KoLW9b
1olD51@7o`h>3PKo61PH1_ooool7oaHF5POo6ATI1olO7al7oaPH60Oo5aLG1ol<30`6oaXJ6PKo51@D
1_ooool7oc@d=0Oo5ADE1om?Cdl7o`T92@Oo2PX:1om]KFd7o`d=3@Ko00001Oooool7oeUIF@Oo0P82
1ol_;bl7ohB4Q0Oo<C4a1om/K6`7oeADE0KoQ8B43Oooool000_ooooo1ombLW8>oi^KV`OoN7Qh1omd
M7@7oi^KV`Ooa<C41_mlO7`5ooooo`Oo8R8R1olc<c<7obDU9@Oo<c<c1olI6AT7ob0P80Oo:b/[1_lc
<c<6ooooo`Ko@D511olO7al7ocDe=@OoDU9B1olF5QH7obl_;`OoKFe]1_lN7Qh6ooooo`OoB4Q81olB
4Q86o`h>3POoTI6A1olE5AD7oadM7@Ooe=CD1_l10@46ooooo`Oo2@T91olM7Ad7obHV9POo4A4A1_mb
LW87oa@D50Oo3Ph>1_lH61P6ooooo`Oo5QHF1olI6AT7oalO7`Oo61PH1olG5aL7o``<30Ko6QXJ1_lD
51@6ooooo`Oo=3@d1olE5AD7odm?C`Oo2@T91ol:2PX7ofe]K@Oo3@d=1_l00005ooooo`OoFEUI1ol2
0P87obl_;`OoQ8B41ola<C47ofa/K0OoE5AD1_n4Q8@=ooooo`002oooool7og9bLPkoVi^K1omhN7P7
ogAdM0OoVi^K1oo4a<@6ogalO0Gooooo1olR8R87oc<c<`Oo9BDU1olc<c<7oaTI6@Oo820P1ol[:b/6
oc<c<`Kooooo1_m1@D47oalO7`Oo=CDe1omBDU87oaHF5POo;bl_1om]KFd6oahN7PKooooo1om8B4P7
oa8B4PKo3Ph>1onATI47oaDE5@Oo7AdM1ooDe=@6o`410@Kooooo1ol92@T7oadM7@Oo9RHV1olA4A46
og9bLPOo51@D1ol>3Ph6oaPH60Kooooo1olF5QH7oaTI6@Oo7alO1olH61P7oaLG5`Oo30`<1_lJ6QX6
oa@D50Kooooo1old=3@7oaDE5@OoCdm?1ol92@T7o`X:2POoKFe]1ol=3@d6o`0000Gooooo1omIFET7
o`820POo;bl_1on4Q8@7oc4a<@OoK6a/1omDE5@6ohB4Q0gooooo000;ooooo`OoLW9b3_nKVi/7ogQh
N0OoM7Ad1onKVi/7olC4a0KoO7al1Oooool7ob8R8POo<c<c1olU9BD7oc<c<`Oo6ATI1olP8207ob/[
:`Ko<c<c1_ooool6od51@@Oo7alO1ole=CD7oe9BDPOo5QHF1ol_;bl7ofe]K@Ko7QhN1_ooool7odQ8
B0Oo4Q8B1_l>3Ph7oi6AT@Oo5ADE1olM7Ad7omCDe0Ko0@411_ooool7o`T92@Oo7AdM1olV9RH7oa4A
4@KoLW9b1olD51@7o`h>3PKo61PH1_ooool7oaHF5POo6ATI1olO7al7oaPH60Oo5aLG1ol<30`6oaXJ
6PKo51@D1_ooool7oc@d=0Oo5ADE1om?Cdl7o`T92@Oo2PX:1om]KFd7o`d=3@Ko00001Oooool7oeUI
F@Oo0P821ol_;bl7ohB4Q0Oo<C4a1om/K6`7oeADE0KoQ8B43Oooool000_ooooo1olI6AT7ocDe=@Oo
;bl_1ol/;2`7oeUIF@Oo71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo
3Ph>1ol<30`6o`X:2PKooooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Ko
oooo1ol[:b/7ocLg=`Ko9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKo
DU9B1ol?3`l7ob/[:`Ko1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo
92@T1_ooool7oa8B4POo;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo
00001omgMgL7o`P820Oo4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_
1ol/;2`7oeUIF@Oo71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>
1ol<30`6o`X:2PKooooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo
1ol[:b/7ocLg=`Ko9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B
1ol?3`l7ob/[:`Ko1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T
1_ooool7oa8B4POo;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo0000
1omgMgL7o`P820Oo4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_1ol/
;2`7oeUIF@Oo71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>1ol<
30`6o`X:2PKooooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo1ol[
:b/7ocLg=`Ko9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B1ol?
3`l7ob/[:`Ko1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T1_oo
ool7oa8B4POo;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo00001omg
MgL7o`P820Oo4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_1ol/;2`7
oeUIF@Oo71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>1ol<30`6
o`X:2PKooooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo1ol[:b/7
ocLg=`Ko9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B1ol?3`l7
ob/[:`Ko1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T1_ooool7
oa8B4POo;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo00001omgMgL7
o`P820Oo4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_1ol/;2`7oeUI
F@Oo71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>1ol<30`6o`X:
2PKooooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo1ol[:b/7ocLg
=`Ko9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B1ol?3`l7ob/[
:`Ko1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T1_ooool7oa8B
4POo;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo00001omgMgL7o`P8
20Oo4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_1ol/;2`7oeUIF@Oo
71`L1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>1ol<30`6o`X:2PKo
oooo1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo1ol[:b/7ocLg=`Ko
9bLW1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B1ol?3`l7ob/[:`Ko
1PH61_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T1_ooool7oa8B4POo
;Rh^1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo00001omgMgL7o`P820Oo
4Q8B1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1olI6AT7ocDe=@Oo;bl_1ol/;2`7oeUIF@Oo71`L
1om=CDd6oibLW0Gooooo1ol@4107ob<S8`Oo1@D51ol<30`7o`<30`Oo3Ph>1ol<30`6o`X:2PKooooo
1_n3Ph<7ocLg=`OoAdM71omBDU87oaXJ6POoB4Q81olW9bL6oaLG5`Kooooo1ol[:b/7ocLg=`Ko9bLW
1ol/;2`7odA4A0OoCdm?3OlT92@6ooooo`ko6ATI1olF5QH7o`h>3PKoDU9B1ol?3`l7ob/[:`Ko1PH6
1_ooool7o`H61POo5QHF1olB4Q87o`d=3@Oo30`<1olQ8B46obXZ:PKo92@T1_ooool7oa8B4POo;Rh^
1omOGel7oa@D50Oo8B4Q1ola<C47oadM7@Ko7QhN1Oooool7o`@410Oo00001omgMgL7o`P820Oo4Q8B
1onUYJD7oa/K6`Ko>3Ph3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onR
XZ86ogmoO`Gooooo1olC4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF
5QH7ol;2`POo;Bd]1ol_;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol0
0007ob@T90OoFUYJ1_l820P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_oo
ool7o`@410Oo00001olC4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS
8b<7o`@410OoNGUi1olR8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC
4a<7oaTI6@KoL71`3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86
ogmoO`Gooooo1olC4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7
ol;2`POo;Bd]1ol_;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007
ob@T90OoFUYJ1_l820P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7
o`@410Oo00001olC4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7
o`@410OoNGUi1olR8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7
oaTI6@KoL71`3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86ogmo
O`Gooooo1olC4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7ol;2
`POo;Bd]1ol_;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007ob@T
90OoFUYJ1_l820P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7o`@4
10Oo00001olC4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7o`@4
10OoNGUi1olR8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7oaTI
6@KoL71`3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86ogmoO`Go
oooo1olC4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7ol;2`POo
;Bd]1ol_;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007ob@T90Oo
FUYJ1_l820P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7o`@410Oo
00001olC4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7o`@410Oo
NGUi1olR8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7oaTI6@Ko
L71`3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86ogmoO`Gooooo
1olC4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7ol;2`POo;Bd]
1ol_;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007ob@T90OoFUYJ
1_l820P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7o`@410Oo0000
1olC4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7o`@410OoNGUi
1olR8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7oaTI6@KoL71`
3Oooool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86ogmoO`Gooooo1olC
4a<7o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7ol;2`POo;Bd]1ol_
;bl7ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007ob@T90OoFUYJ1_l8
20P6ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7o`@410Oo00001olC
4a<7o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7o`@410OoNGUi1olR
8R87o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7oaTI6@KoL71`3Ooo
ool000_ooooo1omoOgl7okFe]@OoP8201omiNGT7ogYjNPOoP8201onRXZ86ogmoO`Gooooo1olC4a<7
o`H61POo00003_l<30`7o`d=3@Oo5aLG1_lJ6QX6ooooo`Ko:BTY1olF5QH7ol;2`POo;Bd]1ol_;bl7
ohZ:RPOo92@T1_lD51@6ooooo`Oo<C4a1olF5QH6ocTi>@Oo>c/k1ol00007ob@T90OoFUYJ1_l820P6
ooooo`Oo6ATI1ol<30`>oaLG5`KoAdM71ol@4107o`D51@Ko6QXJ1_ooool7o`@410Oo00001olC4a<7
o`P820Oo3@d=1olF5QH6o`l?3`Ko6ATI1_ooool7oc0`<0Ooclo?1olS8b<7o`@410OoNGUi1olR8R87
o`L71`Ko92@T1Oooool7o`l?3`Oo61PH1ol^;Rh7oadM7@Oo>SXj1olC4a<7oaTI6@KoL71`3Oooool0
00_ooooo1olB4Q87oeaLG0Oo?Shn1ol`<307odQ8B0OoKFe]1on4Q8@6oh61P@Gooooo1ol820P7o`T9
2@Oo1@D51ol:2PX7o`820POo820P1olM7Ad6oa`L70Kooooo1_n;Rh/7ohj>SPOoP8201om8B4P7ok^k
^`Oo?clo1olF5QH6ofYZJPKooooo1on?Shl7obl_;`KoD51@1om;Bd/7obDU9@Oo>c/k1olN7Qh6oa8B
4PKooooo1ol820P7o`d=3@Oo3`l?1ol=3@d6obl_;`Oo4A4A1olO7al6oaHF5PKooooo1ol10@47o`@4
10Oo1PH61ol;2`/7o`@410Oo5ADE1_l20P86o`l?3`Kooooo1olW9bL7oeUIF@OoRXZ:1om@D507oeeM
G@Oo>SXj1omQHF46o`0000Gooooo1ol92@T7ohJ6QPOo7QhN1ol71`L7obd];@Oo=SHf1olE5AD6oaTI
6@gooooo000;ooooo`Oo4Q8B1omLG5`7ochn?POo<30`1om8B4P7ofe]K@OoQ8B41_n1PH45ooooo`Oo
20P81ol92@T7o`D51@Oo2PX:1ol20P87ob0P80Oo7AdM1_lL71`6ooooo`KoRh^;1on>SXh7oh20P0Oo
B4Q81onk^k/7oclo?`Oo5QHF1_mZJVX6ooooo`OoShn?1ol_;bl6oe1@D0OoBd];1olU9BD7oc/k>`Oo
7QhN1_lB4Q86ooooo`Oo20P81ol=3@d7o`l?3`Oo3@d=1_l_;bl7oa4A4@Oo7alO1_lF5QH6ooooo`Oo
0@411ol410@7o`H61POo2`/;1ol410@7oaDE5@Ko0P821_l?3`l6ooooo`Oo9bLW1omIFET7ohZ:RPOo
D51@1omMGEd7ocXj>POoHF5Q1_l00005ooooo`Oo2@T91on6QXH7oahN7POo1`L71ol];Bd7ocHf=POo
5ADE1_lI6AT=ooooo`002oooool7oa8B4POoG5aL1oln?Sh7oc0`<0OoB4Q81om]KFd7ohB4Q0KoPH61
1Oooool7o`P820Oo2@T91ol51@D7o`X:2POo0P821olP8207oadM7@Ko71`L1_ooool6oh^;R`OoSXj>
1on0P807odQ8B0Oo^k^k1olo?cl7oaHF5PKoJVYZ1_ooool7ohn?S`Oo;bl_1_m@D507od];B`Oo9BDU
1olk>c/7oahN7PKo4Q8B1_ooool7o`P820Oo3@d=1ol?3`l7o`d=3@Ko;bl_1olA4A47oalO7`Ko5QHF
1_ooool7o`410@Oo10@41ol61PH7o`/;2`Oo10@41olE5AD6o`820PKo3`l?1_ooool7obLW9`OoFEUI
1on:RXX7oe1@D0OoGEeM1olj>SX7of5QH@Ko00001Oooool7o`T92@OoQXJ61olN7Qh7o`L71`Oo;Bd]
1olf=SH7oaDE5@Ko6ATI3Oooool000_ooooo1olB4Q87oeaLG0Oo?Shn1ol`<307odQ8B0OoKFe]1on4
Q8@6oh61P@Gooooo1ol820P7o`T92@Oo1@D51ol:2PX7o`820POo820P1olM7Ad6oa`L70Kooooo1_n;
Rh/7ohj>SPOoP8201om8B4P7ok^k^`Oo?clo1olF5QH6ofYZJPKooooo1on?Shl7obl_;`KoD51@1om;
Bd/7obDU9@Oo>c/k1olN7Qh6oa8B4PKooooo1ol820P7o`d=3@Oo3`l?1ol=3@d6obl_;`Oo4A4A1olO
7al6oaHF5PKooooo1ol10@47o`@410Oo1PH61ol;2`/7o`@410Oo5ADE1_l20P86o`l?3`Kooooo1olW
9bL7oeUIF@OoRXZ:1om@D507oeeMG@Oo>SXj1omQHF46o`0000Gooooo1ol92@T7ohJ6QPOo7QhN1ol7
1`L7obd];@Oo=SHf1olE5AD6oaTI6@gooooo000;ooooo`Oo4Q8B1omLG5`7ochn?POo<30`1om8B4P7
ofe]K@OoQ8B41_n1PH45ooooo`Oo20P81ol92@T7o`D51@Oo2PX:1ol20P87ob0P80Oo7AdM1_lL71`6
ooooo`KoRh^;1on>SXh7oh20P0OoB4Q81onk^k/7oclo?`Oo5QHF1_mZJVX6ooooo`OoShn?1ol_;bl6
oe1@D0OoBd];1olU9BD7oc/k>`Oo7QhN1_lB4Q86ooooo`Oo20P81ol=3@d7o`l?3`Oo3@d=1_l_;bl7
oa4A4@Oo7alO1_lF5QH6ooooo`Oo0@411ol410@7o`H61POo2`/;1ol410@7oaDE5@Ko0P821_l?3`l6
ooooo`Oo9bLW1omIFET7ohZ:RPOoD51@1omMGEd7ocXj>POoHF5Q1_l00005ooooo`Oo2@T91on6QXH7
oahN7POo1`L71ol];Bd7ocHf=POo5ADE1_lI6AT=ooooo`002oooool7oa8B4POoG5aL1oln?Sh7oc0`
<0OoB4Q81om]KFd7ohB4Q0KoPH611Oooool7o`P820Oo2@T91ol51@D7o`X:2POo0P821olP8207oadM
7@Ko71`L1_ooool6oh^;R`OoSXj>1on0P807odQ8B0Oo^k^k1olo?cl7oaHF5PKoJVYZ1_ooool7ohn?
S`Oo;bl_1_m@D507od];B`Oo9BDU1olk>c/7oahN7PKo4Q8B1_ooool7o`P820Oo3@d=1ol?3`l7o`d=
3@Ko;bl_1olA4A47oalO7`Ko5QHF1_ooool7o`410@Oo10@41ol61PH7o`/;2`Oo10@41olE5AD6o`82
0PKo3`l?1_ooool7obLW9`OoFEUI1on:RXX7oe1@D0OoGEeM1olj>SX7of5QH@Ko00001Oooool7o`T9
2@OoQXJ61olN7Qh7o`L71`Oo;Bd]1olf=SH7oaDE5@Ko6ATI3Oooool000_ooooo1olB4Q87oeaLG0Oo
?Shn1ol`<307odQ8B0OoKFe]1on4Q8@6oh61P@Gooooo1ol820P7o`T92@Oo1@D51ol:2PX7o`820POo
820P1olM7Ad6oa`L70Kooooo1_n;Rh/7ohj>SPOoP8201om8B4P7ok^k^`Oo?clo1olF5QH6ofYZJPKo
oooo1on?Shl7obl_;`KoD51@1om;Bd/7obDU9@Oo>c/k1olN7Qh6oa8B4PKooooo1ol820P7o`d=3@Oo
3`l?1ol=3@d6obl_;`Oo4A4A1olO7al6oaHF5PKooooo1ol10@47o`@410Oo1PH61ol;2`/7o`@410Oo
5ADE1_l20P86o`l?3`Kooooo1olW9bL7oeUIF@OoRXZ:1om@D507oeeMG@Oo>SXj1omQHF46o`0000Go
oooo1ol92@T7ohJ6QPOo7QhN1ol71`L7obd];@Oo=SHf1olE5AD6oaTI6@gooooo000;ooooo`OoX:2P
1ono_kl7olW9b@OoOGem1onm_Kd7ohN7Q`OogmoO1_nWYjL5ooooo`Oo8B4Q1olG5aL7oa/K6`Oo7AdM
1olA4A4>ob8R8PKoDU9B1_ooool=oeQHF0OogmoO1olX:2P7of1PH0OoTI6A1om^KVh6oc<c<`Kooooo
1oli>CT7obDU9@Kooooo1olB4Q87oaPH60OoZJVY1olA4A46o`<30`Kooooo1ol00007o`410@Oo6ATI
1olC4a<6oaDE5@Oo30`<3OlH61P6ooooo`Oo410@1ol51@D7o`<30`Oo4a<C1ol?3`l7o`h>3PKo<C4a
1_l[:b/6ooooo`Oo5QHF1oooool7odI6APOo:BTY1oobl_87oa@D50Oo7QhN1_mEEED5ooooo`OoF5QH
1olj>SX7oe5AD@OoK6a/1ol[:b/7o`L71`Oo;2`/1_lJ6QX=ooooo`002oooool7oj2PX0Oo_kno1oo9
bLT7ogemO@Oo_Kfm1on7QhL7omoOg`KoYjNW1Oooool7ob4Q8@Oo5aLG1olK6a/7oadM7@Oo4A4A3_lR
8R86oe9BDPKooooo3OmHF5P7omoOg`Oo:2PX1omPH607oi6AT@OoKVi^1_lc<c<6ooooo`Oo>CTi1olU
9BD6ooooo`Oo4Q8B1olH61P7ojVYZ@Oo4A4A1_l30`<6ooooo`Oo00001ol10@47oaTI6@Oo4a<C1_lE
5AD7o``<30go61PH1_ooool7oa0@40Oo1@D51ol30`<7oa<C4`Oo3`l?1ol>3Ph6oc4a<@Ko:b/[1_oo
ool7oaHF5POooooo1om6ATH7obTY:@Ool_;b1olD51@7oahN7PKoEEEE1Oooool7oeQHF0Oo>SXj1omA
DE47ofa/K0Oo:b/[1ol71`L7ob`/;0Ko6QXJ3Oooool000_ooooo1onPX:07okno_`OobLW91ommOGd7
okfm_@OoQhN71ooOgml6ojNWY`Gooooo1olQ8B47oaLG5`Oo6a/K1olM7Ad7oa4A4@ko8R8R1_mBDU86
ooooo`goF5QH1ooOgml7obPX:0OoH61P1onATI47ofi^KPKo<c<c1_ooool7ocTi>@Oo9BDU1_ooool7
oa8B4POo61PH1onYZJT7oa4A4@Ko0`<31_ooool7o`0000Oo0@411olI6AT7oa<C4`Ko5ADE1ol<30`=
oaPH60Kooooo1ol@4107o`D51@Oo0`<31olC4a<7o`l?3`Oo3Ph>1_la<C46ob/[:`Kooooo1olF5QH7
ooooo`OoATI61olY:BT7oo;blPOo51@D1olN7Qh6oeEEE@Gooooo1omHF5P7ocXj>POoDE5A1om/K6`7
ob/[:`Oo1`L71ol/;2`6oaXJ6Pgooooo000;ooooo`OoX:2P1ono_kl7olW9b@OoOGem1onm_Kd7ohN7
Q`OogmoO1_nWYjL5ooooo`Oo8B4Q1olG5aL7oa/K6`Oo7AdM1olA4A4>ob8R8PKoDU9B1_ooool=oeQH
F0OogmoO1olX:2P7of1PH0OoTI6A1om^KVh6oc<c<`Kooooo1oli>CT7obDU9@Kooooo1olB4Q87oaPH
60OoZJVY1olA4A46o`<30`Kooooo1ol00007o`410@Oo6ATI1olC4a<6oaDE5@Oo30`<3OlH61P6oooo
o`Oo410@1ol51@D7o`<30`Oo4a<C1ol?3`l7o`h>3PKo<C4a1_l[:b/6ooooo`Oo5QHF1oooool7odI6
APOo:BTY1oobl_87oa@D50Oo7QhN1_mEEED5ooooo`OoF5QH1olj>SX7oe5AD@OoK6a/1ol[:b/7o`L7
1`Oo;2`/1_lJ6QX=ooooo`002oooool7oj2PX0Oo_kno1oo9bLT7ogemO@Oo_Kfm1on7QhL7omoOg`Ko
YjNW1Oooool7ob4Q8@Oo5aLG1olK6a/7oadM7@Oo4A4A3_lR8R86oe9BDPKooooo3OmHF5P7omoOg`Oo
:2PX1omPH607oi6AT@OoKVi^1_lc<c<6ooooo`Oo>CTi1olU9BD6ooooo`Oo4Q8B1olH61P7ojVYZ@Oo
4A4A1_l30`<6ooooo`Oo00001ol10@47oaTI6@Oo4a<C1_lE5AD7o``<30go61PH1_ooool7oa0@40Oo
1@D51ol30`<7oa<C4`Oo3`l?1ol>3Ph6oc4a<@Ko:b/[1_ooool7oaHF5POooooo1om6ATH7obTY:@Oo
l_;b1olD51@7oahN7PKoEEEE1Oooool7oeQHF0Oo>SXj1omADE47ofa/K0Oo:b/[1ol71`L7ob`/;0Ko
6QXJ3Oooool000_ooooo1onPX:07okno_`OobLW91ommOGd7okfm_@OoQhN71ooOgml6ojNWY`Gooooo
1olQ8B47oaLG5`Oo6a/K1olM7Ad7oa4A4@ko8R8R1_mBDU86ooooo`goF5QH1ooOgml7obPX:0OoH61P
1onATI47ofi^KPKo<c<c1_ooool7ocTi>@Oo9BDU1_ooool7oa8B4POo61PH1onYZJT7oa4A4@Ko0`<3
1_ooool7o`0000Oo0@411olI6AT7oa<C4`Ko5ADE1ol<30`=oaPH60Kooooo1ol@4107o`D51@Oo0`<3
1olC4a<7o`l?3`Oo3Ph>1_la<C46ob/[:`Kooooo1olF5QH7ooooo`OoATI61olY:BT7oo;blPOo51@D
1olN7Qh6oeEEE@Gooooo1omHF5P7ocXj>POoDE5A1om/K6`7ob/[:`Oo1`L71ol/;2`6oaXJ6Pgooooo
000;ooooo`Oo5aLG1omNGUh7oc4a<@Oo@d=31ol00007oe5AD@OoH61P1_meMGD5ooooo`Oo6QXJ1olP
8207obPX:0Oo71`L1olo?cl7oc`l?0Oo>c/k1_mKFe/6ooooo`Ko=CDe1on4Q8@7ol71`@Oo:RXZ1ooo
ool7odY:BPOo>CTi1_n;Rh/6ooooo`OoP8201on?Shl6ohf=S@Oo9BDU1ooIfMT7oda<C0Oo8B4Q1_n9
RHT6ooooo`Oo=3@d1omVIVH7odm?C`OoD51@1_ooool7od];B`OoDe=C1_m0@406ooooo`Oo:2PX1olO
7al7oaXJ6POo:BTY1olW9bL7oaXJ6PKo9RHV1_lB4Q86ooooo`Oo7QhN1onm_Kd7odM7A`koOgmo1ol>
3Ph7on7Qh@Ko3@d=1Oooool7ocDe=@Oooooo1olC4a<7obXZ:POoLG5a1olZ:RX7oc0`<0Ko>CTi3Ooo
ool000_ooooo1olG5aL7oeiNGPOo<C4a1om3@d<7o`0000OoDE5A1omPH606ogEeM@Gooooo1olJ6QX7
ob0P80Oo:2PX1olL71`7oclo?`Oo?3`l1olk>c/6oe]KF`Kooooo1_le=CD7ohB4Q0Oo`L711olZ:RX7
ooooo`OoBTY:1oli>CT6oh^;R`Kooooo1on0P807ohn?S`KoSHf=1olU9BD7omWIf@OoC4a<1olQ8B46
ohV9R@Kooooo1old=3@7ofIVIPOoCdm?1om@D506ooooo`OoBd];1omCDe<6od10@0Kooooo1olX:2P7
oalO7`Oo6QXJ1olY:BT7obLW9`Oo6QXJ1_lV9RH6oa8B4PKooooo1olN7Qh7okfm_@OoAdM73_moOgl7
o`h>3POohN7Q1_l=3@d5ooooo`Oo=CDe1oooool7oa<C4`Oo:RXZ1omaLG47obXZ:POo<30`1_li>CT=
ooooo`002oooool7oaLG5`OoGUiN1ola<C47od=3@`Oo00001omADE47of1PH0KoMGEe1Oooool7oaXJ
6POo820P1olX:2P7oa`L70Oo?clo1oll?3`7oc/k>`KoFe]K1_ooool6ocDe=@OoQ8B41oo1`L47obXZ
:POooooo1om:BTX7ocTi>@KoRh^;1_ooool7oh20P0OoShn?1_n=SHd7obDU9@OofMWI1om<C4`7ob4Q
8@KoRHV91_ooool7oc@d=0OoIVIV1om?Cdl7oe1@D0Kooooo1om;Bd/7oe=CD`Ko@4101_ooool7obPX
:0Oo7alO1olJ6QX7obTY:@Oo9bLW1olJ6QX6obHV9PKo4Q8B1_ooool7oahN7POo_Kfm1om7AdL>ogmo
O`Oo3Ph>1ooQhN46o`d=3@Gooooo1ole=CD7ooooo`Oo4a<C1olZ:RX7og5aL@Oo:RXZ1ol`<306ocTi
>@gooooo000;ooooo`Oo5aLG1omNGUh7oc4a<@Oo@d=31ol00007oe5AD@OoH61P1_meMGD5ooooo`Oo
6QXJ1olP8207obPX:0Oo71`L1olo?cl7oc`l?0Oo>c/k1_mKFe/6ooooo`Ko=CDe1on4Q8@7ol71`@Oo
:RXZ1oooool7odY:BPOo>CTi1_n;Rh/6ooooo`OoP8201on?Shl6ohf=S@Oo9BDU1ooIfMT7oda<C0Oo
8B4Q1_n9RHT6ooooo`Oo=3@d1omVIVH7odm?C`OoD51@1_ooool7od];B`OoDe=C1_m0@406ooooo`Oo
:2PX1olO7al7oaXJ6POo:BTY1olW9bL7oaXJ6PKo9RHV1_lB4Q86ooooo`Oo7QhN1onm_Kd7odM7A`ko
Ogmo1ol>3Ph7on7Qh@Ko3@d=1Oooool7ocDe=@Oooooo1olC4a<7obXZ:POoLG5a1olZ:RX7oc0`<0Ko
>CTi3Oooool000_ooooo1olG5aL7oeiNGPOo<C4a1om3@d<7o`0000OoDE5A1omPH606ogEeM@Gooooo
1olJ6QX7ob0P80Oo:2PX1olL71`7oclo?`Oo?3`l1olk>c/6oe]KF`Kooooo1_le=CD7ohB4Q0Oo`L71
1olZ:RX7ooooo`OoBTY:1oli>CT6oh^;R`Kooooo1on0P807ohn?S`KoSHf=1olU9BD7omWIf@OoC4a<
1olQ8B46ohV9R@Kooooo1old=3@7ofIVIPOoCdm?1om@D506ooooo`OoBd];1omCDe<6od10@0Kooooo
1olX:2P7oalO7`Oo6QXJ1olY:BT7obLW9`Oo6QXJ1_lV9RH6oa8B4PKooooo1olN7Qh7okfm_@OoAdM7
3_moOgl7o`h>3POohN7Q1_l=3@d5ooooo`Oo=CDe1oooool7oa<C4`Oo:RXZ1omaLG47obXZ:POo<30`
1_li>CT=ooooo`002oooool7oaLG5`OoGUiN1ola<C47od=3@`Oo00001omADE47of1PH0KoMGEe1Ooo
ool7oaXJ6POo820P1olX:2P7oa`L70Oo?clo1oll?3`7oc/k>`KoFe]K1_ooool6ocDe=@OoQ8B41oo1
`L47obXZ:POooooo1om:BTX7ocTi>@KoRh^;1_ooool7oh20P0OoShn?1_n=SHd7obDU9@OofMWI1om<
C4`7ob4Q8@KoRHV91_ooool7oc@d=0OoIVIV1om?Cdl7oe1@D0Kooooo1om;Bd/7oe=CD`Ko@4101_oo
ool7obPX:0Oo7alO1olJ6QX7obTY:@Oo9bLW1olJ6QX6obHV9PKo4Q8B1_ooool7oahN7POo_Kfm1om7
AdL>ogmoO`Oo3Ph>1ooQhN46o`d=3@Gooooo1ole=CD7ooooo`Oo4a<C1olZ:RX7og5aL@Oo:RXZ1ol`
<306ocTi>@gooooo000;ooooo`Oo5aLG1omNGUh7oc4a<@Oo@d=31ol00007oe5AD@OoH61P1_meMGD5
ooooo`Oo6QXJ1olP8207obPX:0Oo71`L1olo?cl7oc`l?0Oo>c/k1_mKFe/6ooooo`Ko=CDe1on4Q8@7
ol71`@Oo:RXZ1oooool7odY:BPOo>CTi1_n;Rh/6ooooo`OoP8201on?Shl6ohf=S@Oo9BDU1ooIfMT7
oda<C0Oo8B4Q1_n9RHT6ooooo`Oo=3@d1omVIVH7odm?C`OoD51@1_ooool7od];B`OoDe=C1_m0@406
ooooo`Oo:2PX1olO7al7oaXJ6POo:BTY1olW9bL7oaXJ6PKo9RHV1_lB4Q86ooooo`Oo7QhN1onm_Kd7
odM7A`koOgmo1ol>3Ph7on7Qh@Ko3@d=1Oooool7ocDe=@Oooooo1olC4a<7obXZ:POoLG5a1olZ:RX7
oc0`<0Ko>CTi3Oooool000_ooooo1on8R8P7ono_k`Oo>3Ph1ooDe=@7oi6AT@ko/k>c2oooool7og]k
N`OoDe=C1olh>3P7od];B`Oo>c/k1omkNg/7omcLg0cooooo1_lW9bL7o`l?3`OoBDU91omPH607ob0P
80Oo9BDU1on/[:`6o`0000Kooooo1olL71`7ochn?PKoGUiN1olf=SH7oemOG`Oo:BTY1om_Kfl6oalO
7`Kooooo1olI6AT7ocPh>0Oo3Ph>1olN7Qh6odi>CPOo=3@d1olD51@6ob/[:`Kooooo1olb<S87oeMG
E`Oooooo1onOWil7oc0`<0Oo;Bd]1_l?3`l6oc8b<PKooooo1olm?Cd7ogAdM0Oo5ADE1olD51@7odE5
A@Oo@4101olY:BT6oa@D50Gooooo1ong]kL7o`l?3`OoB4Q81on][Jd7o``<30OoTi>C1olh>3P6oadM
7@gooooo000;ooooo`OoR8R81oo_knl7ocPh>0Ooe=CD1onATI4>ok>c/`_ooooo1omkNg/7oe=CD`Oo
>3Ph1om;Bd/7oc/k>`OoNg]k1ooLg=`<ooooo`Ko9bLW1ol?3`l7odU9B@OoH61P1olP8207obDU9@Oo
[:b/1_l00006ooooo`Oo71`L1oln?Sh6oeiNGPOo=SHf1omOGel7obTY:@OoKfm_1_lO7al6ooooo`Oo
6ATI1olh>3P7o`h>3POo7QhN1_m>CTh7oc@d=0Oo51@D1_l[:b/6ooooo`Oo<S8b1omGEeL7ooooo`Oo
WinO1ol`<307obd];@Ko3`l?1_lb<S86ooooo`Oo?Cdm1omdM7@7oaDE5@Oo51@D1om5ADD7od10@0Oo
:BTY1_lD51@5ooooo`Oo]kNg1ol?3`l7odQ8B0Oo[Jf]1ol<30`7oi>CT`Oo>3Ph1_lM7Ad=ooooo`00
2oooool7ohR8R0Ookno_1olh>3P7omCDe0OoTI6A3_nc/k<;ooooo`OoNg]k1omCDe<7ocPh>0OoBd];
1olk>c/7og]kN`Oog=cL3?ooool6obLW9`Oo3`l?1om9BDT7of1PH0Oo820P1olU9BD7ojb/[0Ko0000
1_ooool7oa`L70Oo?Shn1_mNGUh7ocHf=POoGemO1olY:BT7ofm_K`Ko7alO1_ooool7oaTI6@Oo>3Ph
1ol>3Ph7oahN7PKoCTi>1old=3@7oa@D50Ko:b/[1_ooool7oc8b<POoEeMG1oooool7oinOW`Oo<30`
1ol];Bd6o`l?3`Ko<S8b1_ooool7ocdm?@OoM7Ad1olE5AD7oa@D50OoADE51om0@407obTY:@Ko51@D
1Oooool7okNg]`Oo3`l?1om8B4P7ojf][@Oo30`<1onCTi<7ocPh>0Ko7AdM3Oooool000_ooooo1on8
R8P7ono_k`Oo>3Ph1ooDe=@7oi6AT@ko/k>c2oooool7og]kN`OoDe=C1olh>3P7od];B`Oo>c/k1omk
Ng/7omcLg0cooooo1_lW9bL7o`l?3`OoBDU91omPH607ob0P80Oo9BDU1on/[:`6o`0000Kooooo1olL
71`7ochn?PKoGUiN1olf=SH7oemOG`Oo:BTY1om_Kfl6oalO7`Kooooo1olI6AT7ocPh>0Oo3Ph>1olN
7Qh6odi>CPOo=3@d1olD51@6ob/[:`Kooooo1olb<S87oeMGE`Oooooo1onOWil7oc0`<0Oo;Bd]1_l?
3`l6oc8b<PKooooo1olm?Cd7ogAdM0Oo5ADE1olD51@7odE5A@Oo@4101olY:BT6oa@D50Gooooo1ong
]kL7o`l?3`OoB4Q81on][Jd7o``<30OoTi>C1olh>3P6oadM7@gooooo000;ooooo`OoR8R81oo_knl7
ocPh>0Ooe=CD1onATI4>ok>c/`_ooooo1omkNg/7oe=CD`Oo>3Ph1om;Bd/7oc/k>`OoNg]k1ooLg=`<
ooooo`Ko9bLW1ol?3`l7odU9B@OoH61P1olP8207obDU9@Oo[:b/1_l00006ooooo`Oo71`L1oln?Sh6
oeiNGPOo=SHf1omOGel7obTY:@OoKfm_1_lO7al6ooooo`Oo6ATI1olh>3P7o`h>3POo7QhN1_m>CTh7
oc@d=0Oo51@D1_l[:b/6ooooo`Oo<S8b1omGEeL7ooooo`OoWinO1ol`<307obd];@Ko3`l?1_lb<S86
ooooo`Oo?Cdm1omdM7@7oaDE5@Oo51@D1om5ADD7od10@0Oo:BTY1_lD51@5ooooo`Oo]kNg1ol?3`l7
odQ8B0Oo[Jf]1ol<30`7oi>CT`Oo>3Ph1_lM7Ad=ooooo`002oooool7ohR8R0Ookno_1olh>3P7omCD
e0OoTI6A3_nc/k<;ooooo`OoNg]k1omCDe<7ocPh>0OoBd];1olk>c/7og]kN`Oog=cL3?ooool6obLW
9`Oo3`l?1om9BDT7of1PH0Oo820P1olU9BD7ojb/[0Ko00001_ooool7oa`L70Oo?Shn1_mNGUh7ocHf
=POoGemO1olY:BT7ofm_K`Ko7alO1_ooool7oaTI6@Oo>3Ph1ol>3Ph7oahN7PKoCTi>1old=3@7oa@D
50Ko:b/[1_ooool7oc8b<POoEeMG1oooool7oinOW`Oo<30`1ol];Bd6o`l?3`Ko<S8b1_ooool7ocdm
?@OoM7Ad1olE5AD7oa@D50OoADE51om0@407obTY:@Ko51@D1Oooool7okNg]`Oo3`l?1om8B4P7ojf]
[@Oo30`<1onCTi<7ocPh>0Ko7AdM3Oooool000_ooooo1on8R8P7ono_k`Oo>3Ph1ooDe=@7oi6AT@ko
/k>c2oooool7og]kN`OoDe=C1olh>3P7od];B`Oo>c/k1omkNg/7omcLg0cooooo1_lW9bL7o`l?3`Oo
BDU91omPH607ob0P80Oo9BDU1on/[:`6o`0000Kooooo1olL71`7ochn?PKoGUiN1olf=SH7oemOG`Oo
:BTY1om_Kfl6oalO7`Kooooo1olI6AT7ocPh>0Oo3Ph>1olN7Qh6odi>CPOo=3@d1olD51@6ob/[:`Ko
oooo1olb<S87oeMGE`Oooooo1onOWil7oc0`<0Oo;Bd]1_l?3`l6oc8b<PKooooo1olm?Cd7ogAdM0Oo
5ADE1olD51@7odE5A@Oo@4101olY:BT6oa@D50Gooooo1ong]kL7o`l?3`OoB4Q81on][Jd7o``<30Oo
Ti>C1olh>3P6oadM7@gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-1.73919, -1.74834, \
0.146455, 0.146455}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-10.5356, \
-1.74834, 0.146455, 0.146455}, {{132, 186.625}, {487.062, 432.438}} -> \
{-19.332, -1.74834, 0.146455, 0.146455}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-28.1376, -1.74834, 0.146455, 0.146455}, {{252.188, 306.812}, \
{487.062, 432.438}} -> {-36.934, -1.74834, 0.146455, 0.146455}, {{312.312, \
366.938}, {487.062, 432.438}} -> {-45.7396, -1.74834, 0.146455, 0.146455}, \
{{372.375, 427}, {487.062, 432.438}} -> {-54.5361, -1.74834, 0.146455, \
0.146455}, {{432.438, 487.062}, {487.062, 432.438}} -> {-63.3325, -1.74834, \
0.146455, 0.146455}, {{11.875, 66.5}, {427, 372.375}} -> {-1.73919, -10.5448, \
0.146455, 0.146455}, {{71.9375, 126.562}, {427, 372.375}} -> {-10.5356, \
-10.5448, 0.146455, 0.146455}, {{132, 186.625}, {427, 372.375}} -> {-19.332, \
-10.5448, 0.146455, 0.146455}, {{192.125, 246.75}, {427, 372.375}} -> \
{-28.1376, -10.5448, 0.146455, 0.146455}, {{252.188, 306.812}, {427, \
372.375}} -> {-36.934, -10.5448, 0.146455, 0.146455}, {{312.312, 366.938}, \
{427, 372.375}} -> {-45.7396, -10.5448, 0.146455, 0.146455}, {{372.375, 427}, \
{427, 372.375}} -> {-54.5361, -10.5448, 0.146455, 0.146455}, {{432.438, \
487.062}, {427, 372.375}} -> {-63.3325, -10.5448, 0.146455, 0.146455}, \
{{11.875, 66.5}, {366.938, 312.312}} -> {-1.73919, -19.3412, 0.146455, \
0.146455}, {{71.9375, 126.562}, {366.938, 312.312}} -> {-10.5356, -19.3412, \
0.146455, 0.146455}, {{132, 186.625}, {366.938, 312.312}} -> {-19.332, \
-19.3412, 0.146455, 0.146455}, {{192.125, 246.75}, {366.938, 312.312}} -> \
{-28.1376, -19.3412, 0.146455, 0.146455}, {{252.188, 306.812}, {366.938, \
312.312}} -> {-36.934, -19.3412, 0.146455, 0.146455}, {{312.312, 366.938}, \
{366.938, 312.312}} -> {-45.7396, -19.3412, 0.146455, 0.146455}, {{372.375, \
427}, {366.938, 312.312}} -> {-54.5361, -19.3412, 0.146455, 0.146455}, \
{{432.438, 487.062}, {366.938, 312.312}} -> {-63.3325, -19.3412, 0.146455, \
0.146455}, {{11.875, 66.5}, {306.812, 252.188}} -> {-1.73919, -28.1468, \
0.146455, 0.146455}, {{71.9375, 126.562}, {306.812, 252.188}} -> {-10.5356, \
-28.1468, 0.146455, 0.146455}, {{132, 186.625}, {306.812, 252.188}} -> \
{-19.332, -28.1468, 0.146455, 0.146455}, {{192.125, 246.75}, {306.812, \
252.188}} -> {-28.1376, -28.1468, 0.146455, 0.146455}, {{252.188, 306.812}, \
{306.812, 252.188}} -> {-36.934, -28.1468, 0.146455, 0.146455}, {{312.312, \
366.938}, {306.812, 252.188}} -> {-45.7396, -28.1468, 0.146455, 0.146455}, \
{{372.375, 427}, {306.812, 252.188}} -> {-54.5361, -28.1468, 0.146455, \
0.146455}, {{432.438, 487.062}, {306.812, 252.188}} -> {-63.3325, -28.1468, \
0.146455, 0.146455}, {{11.875, 66.5}, {246.75, 192.125}} -> {-1.73919, \
-36.9432, 0.146455, 0.146455}, {{71.9375, 126.562}, {246.75, 192.125}} -> \
{-10.5356, -36.9432, 0.146455, 0.146455}, {{132, 186.625}, {246.75, 192.125}} -> \
{-19.332, -36.9432, 0.146455, 0.146455}, {{192.125, 246.75}, {246.75, \
192.125}} -> {-28.1376, -36.9432, 0.146455, 0.146455}, {{252.188, 306.812}, \
{246.75, 192.125}} -> {-36.934, -36.9432, 0.146455, 0.146455}, {{312.312, \
366.938}, {246.75, 192.125}} -> {-45.7396, -36.9432, 0.146455, 0.146455}, \
{{372.375, 427}, {246.75, 192.125}} -> {-54.5361, -36.9432, 0.146455, \
0.146455}, {{432.438, 487.062}, {246.75, 192.125}} -> {-63.3325, -36.9432, \
0.146455, 0.146455}, {{11.875, 66.5}, {186.625, 132}} -> {-1.73919, -45.7488, \
0.146455, 0.146455}, {{71.9375, 126.562}, {186.625, 132}} -> {-10.5356, \
-45.7488, 0.146455, 0.146455}, {{132, 186.625}, {186.625, 132}} -> {-19.332, \
-45.7488, 0.146455, 0.146455}, {{192.125, 246.75}, {186.625, 132}} -> \
{-28.1376, -45.7488, 0.146455, 0.146455}, {{252.188, 306.812}, {186.625, 132}}
   -> {-36.934, -45.7488, 0.146455, 0.146455}, {{312.312, 366.938}, {186.625, \
132}} -> {-45.7396, -45.7488, 0.146455, 0.146455}, {{372.375, 427}, {186.625, \
132}} -> {-54.5361, -45.7488, 0.146455, 0.146455}, {{432.438, 487.062}, \
{186.625, 132}} -> {-63.3325, -45.7488, 0.146455, 0.146455}, {{11.875, 66.5}, \
{126.562, 71.9375}} -> {-1.73919, -54.5452, 0.146455, 0.146455}, {{71.9375, \
126.562}, {126.562, 71.9375}} -> {-10.5356, -54.5452, 0.146455, 0.146455}, \
{{132, 186.625}, {126.562, 71.9375}} -> {-19.332, -54.5452, 0.146455, \
0.146455}, {{192.125, 246.75}, {126.562, 71.9375}} -> {-28.1376, -54.5452, \
0.146455, 0.146455}, {{252.188, 306.812}, {126.562, 71.9375}} -> {-36.934, \
-54.5452, 0.146455, 0.146455}, {{312.312, 366.938}, {126.562, 71.9375}} -> \
{-45.7396, -54.5452, 0.146455, 0.146455}, {{372.375, 427}, {126.562, \
71.9375}} -> {-54.5361, -54.5452, 0.146455, 0.146455}, {{432.438, 487.062}, \
{126.562, 71.9375}} -> {-63.3325, -54.5452, 0.146455, 0.146455}, {{11.875, \
66.5}, {66.5, 11.875}} -> {-1.73919, -63.3416, 0.146455, 0.146455}, \
{{71.9375, 126.562}, {66.5, 11.875}} -> {-10.5356, -63.3416, 0.146455, \
0.146455}, {{132, 186.625}, {66.5, 11.875}} -> {-19.332, -63.3416, 0.146455, \
0.146455}, {{192.125, 246.75}, {66.5, 11.875}} -> {-28.1376, -63.3416, \
0.146455, 0.146455}, {{252.188, 306.812}, {66.5, 11.875}} -> {-36.934, \
-63.3416, 0.146455, 0.146455}, {{312.312, 366.938}, {66.5, 11.875}} -> \
{-45.7396, -63.3416, 0.146455, 0.146455}, {{372.375, 427}, {66.5, 11.875}} -> \
{-54.5361, -63.3416, 0.146455, 0.146455}, {{432.438, 487.062}, {66.5, \
11.875}} -> {-63.3325, -63.3416, 0.146455, 0.146455}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B0884BD39DE582E
150481BE3BE54D0A
170088A21BF03619
0B0875A925FF4A02
031A5F852FF62D03
1231818238D93C17
102D527036CC2910
213C636557C73E17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
61F76B365B875038
8F504B2F004DFFA0
6EF34D0D859A4C38
9F3F292D2269FC7F
77CB2B278B9A4673
9A270F295D7EE362
7A901D5377A233CB
781D00267173D260
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4E0F3E92665611FF
15120E4EBB6E2049
3600668C603510F3
020C2B76AD550D39
161C6B874B110CCA
00134E86943F1130
0A4A647835110A87
060E5C7379292A1E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D19052C6AD1EF11
0B27032C62E6F91B
022B003688F7F615
0A2C083886F0E111
10390A47A3FFE20A
1D39205299DEB411
26521164ABE6A419
244625608AAE7F12
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6330548D197419D7
4E2D5A93146113DE
4C24649F146B10F7
362C6D9E074A0CF7
3629818C0A5A00FF
254A6D81115203FF
26457B702E5000F9
2E525956314001E0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3D27AFD23FD72B06
3B1EA9D532D84827
4223CEF221FD2327
2D16C7FD01DD252F
3E23D0FF08FF0C51
3310C2F200CA184F
3412BDE60FDA1161
1107ACD500A6095D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
66271A0B544A8B17
61641934226B39C5
6028090D955A700A
69401A4C226336FC
4F1B001AB65A5104
55191E57255730F0
37190932C6532B1B
46123473144635FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B83E9B6BB444EE88
BF3E9971AF49F8B8
B81AB28EB52CFF9E
D0269E88A53BFCBE
BE13AB94A51AEDAB
C9179365932CDF96
AA009C6C8C0CBAA3
B10085316B17AB6B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C6504352161734A
165300610C5B8E2C
228A134E24595637
129E0673135B6231
19C9448D2E4C3C33
22FF3CA914513735
2CF850B626423E34
2BBA4D7F1956332A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9BE084C05A243143
9BE27BB057111E3B
ABFF79C9481E1C48
A6F367AB46021144
BEFC62C534121653
B8E34EAD2B011C44
C5E24ABB230E1D4B
AFB83E9A1F001D3D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
15167B97922B3530
2199B3B93A1811BE
1B2BA9A87B198120
37D3B08916281D76
2C4CBE954925C723
69E9A65300332B2C
3E72BA751C47E523
92FF912A1A43202C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C8234271E694EA2
7166241881778F08
775B224614685EE5
68601211B57C6F10
7A2B1F541A6862FF
55590020C87A4521
650A2654335D62DD
4159032AE87D291B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
804B43310A2137CA
7A374F38081929D6
7742532A011626DB
803A542A000E20C0
7D4141270E1A2CFF
903B431D01142ED1
723A3B2D1C2229BD
75393B28161832A4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4EABBF2D133B8629
38C9CF640D51C03F
67B0B107123DB12D
49F0B43B1C61C432
72AB96001553D34E
68FF9B215580B32E
89AB72122E77CE6A
7FEE781F72A39B30
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
77653A2CD02D4E64
7A812C25E115496F
6C6C2A1BF3215964
7D721B20FB00547E
6F5B241BFF15535D
7C53142AF609536A
74431B27E0165651
673B0E26CB095057
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B2B7FB8F33D2412
0D3176C8F7182212
08419FE4FF2F2C1F
16419CDEEB142B0E
175DB5E3E3212C24
2A57ACCBBC082415
226CB4C19A102727
2768999E84001D17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2523090E345DAD8C
371E08042661CB9E
2E1812071C5AD6A7
402615091A48E79B
441C1508154EFF8F
42251A001545DE8D
4C111D132746C688
4408210B11329778
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DD858418461D7626
3183390814CA7B13
FF834E095D22703B
44712E0028EE7B1A
F57917186B2B626B
5B5625133FF9782C
CD5C0C296E3D5386
3B2F211F47F9752D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4B182ACE59192529
520824F643142B21
48062EEB330F211E
600927FF1A033013
4B0A3BE3140B2816
6A0F2EF413003B0B
550E48BD08163C18
64173ECF060A4C17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A608042273AE092
1F5472461D1BF492
0E646C421915F7AC
145C68410D0FFFA2
0C5660360E09FAB0
154A69390510F6A2
114A562D0D20EEA4
0F3C512C0017CF87
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
100C0C1610000958
080908150D070C86
130918150C1107D3
16020818101309FF
12050E131217108C
0A09041A0E100948
1E0D10151C150842
0804070E120E0131
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C46DC633D7E3858
1057E42A3A732648
125EFF2F42811B3F
1875F20C3D68133F
1D8EFF0E44680836
1CA8E000464A1B30
2CBACE0E47401525
25A6A20936312126
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
44090C6663322177
480E78A597341DDF
211D166B61211D52
3800B5AD741E3AF2
06232D715C1D262A
2007E1AF3E1645FD
0C26467654033E1F
1B1EEDA72B3162FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E1284D1531425C92
FF073E0C3D4673AF
FD153D0E3E5164D0
ED0A2D035E5873DC
D70D2C0053526EF9
C6092D00655289E8
9F222700664E7EED
800A1500634977CA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E5290A1A1D29484F
F53803121B365D3D
FB2B060A1A324345
FA35030E14314645
FF310A00121D3241
DA3F0A0B1814424D
E543190A191D304D
C63F140F1F283A5A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
24C72811412C1533
19E122113E232039
24E01414371D172B
14FF0C01311A272B
2EE305102F19292E
26EA090035103322
3CC60E18321F3528
2FC7060C3C1A321E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B458D2C160E2A5E
0E47B53E18101A6C
0623BA6B1F0C3779
032EFF591B19236F
0F1FBC4D180A307B
0826672F17242665
051F43181608394C
002C2B1F0A052350
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
494325251F97BCB3
67451E003CBC97D3
3C351B3037BBB3B8
48292F0442E97BD2
3328244466C478A6
36185B146BFF44B5
38222C6886BA5687
2817612A70DA3193
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
18261E131710043C
1628281A13080037
1E32231A1503083E
0A1E111D120C0E5B
13151F1D16061582
1F111515191612E0
28142318111917FF
1012160F13161771
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
308E7A9C511D1C8B
4E137E8D38278028
22C98C762E3E1367
5F1985801A18C12A
2CEB923F1E551542
623076730126DB20
43DF8B101C582A24
713059780029FF23
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
13002357995B63B9
08130D6FD86A7E8B
030C0A69CF59579D
0207026EFF5F658D
1110105ADB5350BA
20161872D14752C6
2121195DA0394FBA
2314175D793537C8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A5404342D3C8425D
A74A3B48E6C9304F
B74A3933F6CB265A
B0572948FFC31253
AC552937FCBF1651
98581059EAA50B3D
90541A4EE798133D
7D580060CA88022C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1623321540BD5079
0E17311E42B04971
050A1B1146E14F83
0A11231349F55A81
03000A123EFA588D
0407110E4AFF7890
0A020C1842FB717D
12140F204ED18381
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
33863924165C6C1B
B98995122D378222
25843312109F7C1E
E58268014E36822D
3579320424D68129
F975331064407B59
45642B003BE87C2C
FF6C1F3A7C295976
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E0BDFC26A1E68FA
0347487931152C2B
1C24FEB0332E6CFF
00545667331A3E0E
1C5DEA961B4270D7
0658764B29276106
488ACE66254E6596
145B4D2C2033541C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
223514761B66C729
16321C771D7BC931
0F3214790E88ED15
0D321A700FA8F422
002B16730FAEFF13
062F206C0BC5FD15
1A34226621C2EB18
132B205B20C0DC1F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F341630581922E5
1D200014621920F5
06220025640C25F2
1414031C71171EE9
0819062E6A102FFF
0B0E0E32641024F7
06171944610F27EC
0F0B0F2E531926D9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2627B3BD20322F27
122BDBC40D302F15
0D28EBC708313127
002BF6B30432341E
022AFFAD05352B1E
003DEA7B0239331F
143DE36A09382B21
084CC53909393A1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
805F12005EBF6A7B
E857257F9F8F6D85
63311C0669D65A78
C53314CAB0684CBF
3C102E3076D54678
A81C29E3BD4131ED
0E0A316779C12879
951541EBB9191FFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
73C4E71C4C456829
7ED9F703524D7B1D
9CF1F70F605E772E
9AF0FF0464699128
BDFEF211715F8136
ADECEA0070689A4E
C4DED8156F628A5A
A5C6BC0C67569154
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
60EC60AD2C1B0B90
5FF058A727090DA6
4AEC53A732000D8E
58EF36A320160692
4AFF4A99270D168D
66D93D91252B1A92
61CE588627202672
5FC24881262D2594
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9ECA30490617054D
BACC29340A1A0E42
DBD9283D06100449
F1B41B2B0B1D163D
FFB91A350017104B
F98A1E2F0E281952
F47F3128092D1969
D255292B0E2C1D66
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5CAA88FF563F183F
69F489EB67330034
61D582FF4B200E3E
6DED86EE5D26002C
5DD594E2421C1939
62D0A3CB431E1232
65C3A9C13A2B224A
61A1A68D321F1F41
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AF6C0A4BC9702B66
7C09012C61844178
9F470E77BF5421AC
590D004C707C3266
8C244A91A94924E7
370C0277746B225B
7A0C8F9291262BFF
2023038063582532
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9E622913101D36DC
B955200C06122FD3
C461160602162DE2
C2681F01061C34FF
B57A2700032730D6
B76A25100A2C43F8
9C823819162A53AC
8D6B2E2D1D4744B5
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3D5A9E7D254ACC35
60AD812211404332
567D8B681757BE31
789A6C20004D5F61
689B703D3D6CA32B
8E8C4129085F7EB3
829E5D26797D8B2B
986435430E677BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C16593DEE356E33
4C136027E3325312
38006331F21F690A
4C0E5733FC225004
3614663FF0135709
4A145C38FF254600
3F20674DDD1A4B05
491C5949E6223A05
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2760057FC0494009
2A5E0A8CCB253C19
235800AEDF1E470E
1B5B0FBDEE14511D
205B18E5EE194B0B
1A5128F3E31C5519
2D684CFFD2324918
295551EAAF2A4411
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17282013462CD025
16121D1C3F2ADC32
15100F124221EB2B
0C020F0C3A30FF24
07050302372DF32D
0E00141E412BFB1A
100B16154531EA2D
0F0D141D4431E030
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DF23301F321F1C17
E70F1E19300C190E
F41321152B1B1204
FF061C1B200E0603
FB05161423201307
E2000E22221A0904
C906121C1D251210
B6071321231A0D15
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
162339A0782B2958
0B1531BD6438204A
071131C76D332D42
02052BEF77281F51
01122DE4762A2135
000641FF80251F36
0E1C3CF38931233A
0D214BE1792D1C3C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A84D0C8172278623
7557126A51124A11
CC2E029E5400B62A
6B370E713900840E
A01611A51909EF42
592519751E07C739
681B3B8B0030FF61
3815283F0505A437
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D0E22201B1E10FF
2317141621230FE3
18110F0C15201485
0E1E0A1519190C3C
15161A1529110A31
000F10152014073A
0213191822110E3E
010A111E220B0339
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2C26C7155E16271B
2F20D8095F1B2D1A
3519E1086B131D0C
351BF40056252613
3710F9066426270E
2E18FF0858313A07
3C1DFC07543B2E17
2F2BDB0A46393613
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2E24398BBCDE4786
75226CBEAB4D34FF
2E1150D0B4C22E86
4951969EAA3F10DB
361E8FFFAD833686
2F97AA8C882F05AC
4337ADFD9D4A6086
29E4BB75633F0081
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C8354B2918429714
E821512A1748970C
EE245D2210579C0B
FF0A632A25619213
F90D69212579A117
E70864243E7C8025
C50261253A838D2D
AA0056223B767838
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
264A5AAD98D3F0CE
1249558B8DE6CBF6
042C588B68C9CDBE
144C598074BFC8FF
0023509B6CBCD49C
1944679667BAC1EB
1C30549D76B1CEAA
435A6E9688AFC6F1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26D66C1A1F1A184A
34D35E030E1D1D47
2EFF62111C192350
37E662000D1D234D
39FA5A0A1027185B
3FE25800101E1A48
3BDF5A0619251868
4ABC4E01101F225E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E24C15212271532
271ED045021F062C
3A26D73507220728
2917D13C061E022B
4225DC3D03140430
2D21FF500D250040
382AE35215200C49
3124D7540D2C1544
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
25112E0B25DE3222
20052B002CF52424
2B072C012CFA1D24
180334022AFF1422
17082D0232FA0B27
1501310C25F90920
1C0F330535E3172D
14092D1238CE0626
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E140B0E1E26417F
000B05061A233B6E
100D04101B1C3491
110E070C170B2382
21110D12120915D8
1F2108070E0620A2
2E120A090E0517D0
39301716090B1AFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
527C83A10D1E2E8E
004AD7868D1D5919
899D6C8A110E3845
0760FF744F43811F
BDA755611B06431D
2B85F45C2B749A27
B9AB3C3D20136033
277AEC4A23A9B123
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D2B482CD4440D23
142E3026E8510116
15304123FC470917
0838361EF645000C
16283425F1560F10
092F291AFF54110B
142D3228E8651A1A
0936332DD5581D1B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2DB65B21A9FF3632
2E8423338BDE0B19
3EC92F29CFFA0D17
3B9103399CC00417
57B50950DFB3030B
40730047B07C080C
6683036FD06B2625
4247104E9D481B1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool7ob/[:`Oo20P81on4Q8@7okfm_@Oo>CTi
1ooNg]h7oeQHF0Ko;Rh^1Oooool7of5QH@OomoOg1om[Jf/7ocHf=POoFe]K1on7QhL7oe1@D0Ko>3Ph
1_ooool6odi>CPOo3`l?1oln?Sh7oi:BTPOoIVIV1omFEUH7oa4A4@cooooo1ol=3@d7oaTI6@Ko1@D5
1ol/;2`7ofYZJPOodM7A1oo_knl6oa4A4@Kooooo1omSHf<7oc0`<0OoE5AD1on=SHd6oaTI6@OoM7Ad
1olI6AT6omOGe`Kooooo1olm?Cd7obLW9`Oo[jn_1ooBd]87oclo?`OoemOG1_l[:b/6o`H61PKooooo
1omVIVH7obLW9`Oo6QXJ1ol;2`/7oeADE0OoBTY:1on;Rh/6oaLG5`Gooooo1onh^;P7ochn?POoVi^K
1om[Jf/7okBd]0OoA4A41oo^k^h6ohR8R0gooooo000;ooooo`Oo:b/[1ol820P7ohB4Q0Oo_Kfm1oli
>CT7omkNgPOoF5QH1_l^;Rh5ooooo`OoHF5Q1oogmoL7of][J`Oo=SHf1omKFe/7ohN7Q`OoD51@1_lh
>3P6ooooo`KoCTi>1ol?3`l7ochn?POoTY:B1omVIVH7oeIFEPOo4A4A3?ooool7o`d=3@Oo6ATI1_l5
1@D7ob`/;0OoJVYZ1ooAdM47ono_k`Ko4A4A1_ooool7of=SH`Oo<30`1omDE5@7ohf=S@Ko6ATI1omd
M7@7oaTI6@KoemOG1_ooool7ocdm?@Oo9bLW1on_[jl7om;BdPOo?clo1ooGemL6ob/[:`Ko1PH61_oo
ool7ofIVIPOo9bLW1olJ6QX7o`/;2`OoE5AD1om:BTX7oh^;R`Ko5aLG1Oooool7okRh^0Oo?Shn1onK
Vi/7of][J`Oo];Bd1om4A4@7onk^kPKoR8R83Oooool000_ooooo1ol[:b/7o`P820OoQ8B41onm_Kd7
ocTi>@Oog]kN1omHF5P6obh^;PGooooo1omQHF47ooOgm`OoJf][1olf=SH7oe]KF`OoQhN71om@D506
ocPh>0Kooooo1_m>CTh7o`l?3`Oo?Shn1onBTY87ofIVIPOoEUIF1olA4A4<ooooo`Oo3@d=1olI6AT6
o`D51@Oo;2`/1omZJVX7om7Ad@Ookno_1_lA4A46ooooo`OoHf=S1ol`<307oeADE0OoSHf=1_lI6AT7
ogAdM0Oo6ATI1_oGemL6ooooo`Oo?Cdm1olW9bL7ojn_[`Ood];B1olo?cl7omOGe`Ko:b/[1_l61PH6
ooooo`OoIVIV1olW9bL7oaXJ6POo2`/;1omDE5@7odY:BPOoRh^;1_lG5aL5ooooo`Oo^;Rh1oln?Sh7
oi^KV`OoJf][1ond];@7odA4A0Ook^k^1_n8R8P=ooooo`002oooool7ob/[:`Oo20P81on4Q8@7okfm
_@Oo>CTi1ooNg]h7oeQHF0Ko;Rh^1Oooool7of5QH@OomoOg1om[Jf/7ocHf=POoFe]K1on7QhL7oe1@
D0Ko>3Ph1_ooool6odi>CPOo3`l?1oln?Sh7oi:BTPOoIVIV1omFEUH7oa4A4@cooooo1ol=3@d7oaTI
6@Ko1@D51ol/;2`7ofYZJPOodM7A1oo_knl6oa4A4@Kooooo1omSHf<7oc0`<0OoE5AD1on=SHd6oaTI
6@OoM7Ad1olI6AT6omOGe`Kooooo1olm?Cd7obLW9`Oo[jn_1ooBd]87oclo?`OoemOG1_l[:b/6o`H6
1PKooooo1omVIVH7obLW9`Oo6QXJ1ol;2`/7oeADE0OoBTY:1on;Rh/6oaLG5`Gooooo1onh^;P7ochn
?POoVi^K1om[Jf/7okBd]0OoA4A41oo^k^h6ohR8R0gooooo000;ooooo`Oo:b/[1ol820P7ohB4Q0Oo
_Kfm1oli>CT7omkNgPOoF5QH1_l^;Rh5ooooo`OoHF5Q1oogmoL7of][J`Oo=SHf1omKFe/7ohN7Q`Oo
D51@1_lh>3P6ooooo`KoCTi>1ol?3`l7ochn?POoTY:B1omVIVH7oeIFEPOo4A4A3?ooool7o`d=3@Oo
6ATI1_l51@D7ob`/;0OoJVYZ1ooAdM47ono_k`Ko4A4A1_ooool7of=SH`Oo<30`1omDE5@7ohf=S@Ko
6ATI1omdM7@7oaTI6@KoemOG1_ooool7ocdm?@Oo9bLW1on_[jl7om;BdPOo?clo1ooGemL6ob/[:`Ko
1PH61_ooool7ofIVIPOo9bLW1olJ6QX7o`/;2`OoE5AD1om:BTX7oh^;R`Ko5aLG1Oooool7okRh^0Oo
?Shn1onKVi/7of][J`Oo];Bd1om4A4@7onk^kPKoR8R83Oooool000_ooooo1ol[:b/7o`P820OoQ8B4
1onm_Kd7ocTi>@Oog]kN1omHF5P6obh^;PGooooo1omQHF47ooOgm`OoJf][1olf=SH7oe]KF`OoQhN7
1om@D506ocPh>0Kooooo1_m>CTh7o`l?3`Oo?Shn1onBTY87ofIVIPOoEUIF1olA4A4<ooooo`Oo3@d=
1olI6AT6o`D51@Oo;2`/1omZJVX7om7Ad@Ookno_1_lA4A46ooooo`OoHf=S1ol`<307oeADE0OoSHf=
1_lI6AT7ogAdM0Oo6ATI1_oGemL6ooooo`Oo?Cdm1olW9bL7ojn_[`Ood];B1olo?cl7omOGe`Ko:b/[
1_l61PH6ooooo`OoIVIV1olW9bL7oaXJ6POo2`/;1omDE5@7odY:BPOoRh^;1_lG5aL5ooooo`Oo^;Rh
1oln?Sh7oi^KV`OoJf][1ond];@7odA4A0Ook^k^1_n8R8P=ooooo`002oooool7ob/[:`Oo20P81on4
Q8@7okfm_@Oo>CTi1ooNg]h7oeQHF0Ko;Rh^1Oooool7of5QH@OomoOg1om[Jf/7ocHf=POoFe]K1on7
QhL7oe1@D0Ko>3Ph1_ooool6odi>CPOo3`l?1oln?Sh7oi:BTPOoIVIV1omFEUH7oa4A4@cooooo1ol=
3@d7oaTI6@Ko1@D51ol/;2`7ofYZJPOodM7A1oo_knl6oa4A4@Kooooo1omSHf<7oc0`<0OoE5AD1on=
SHd6oaTI6@OoM7Ad1olI6AT6omOGe`Kooooo1olm?Cd7obLW9`Oo[jn_1ooBd]87oclo?`OoemOG1_l[
:b/6o`H61PKooooo1omVIVH7obLW9`Oo6QXJ1ol;2`/7oeADE0OoBTY:1on;Rh/6oaLG5`Gooooo1onh
^;P7ochn?POoVi^K1om[Jf/7okBd]0OoA4A41oo^k^h6ohR8R0gooooo000;ooooo`Oo5ADE1ol410@7
oh61P@Oo_[jn1olk>c/7onGUi@OoCDe=1_l:2PX5ooooo`OoShn?1om@D507od];B`Oo;bl_1ol00007
ode=C@Oooooo1_nPX:06ooooo`Ko5ADE1olB4Q87o`h>3POoCTi>1onk^k/7ofi^KPOo820P1_m9BDT6
ooooo`Oo2`/;1olW9bL6o`<30`Oo;2`/1omRHV87onKViPOonOWi1_lK6a/6ooooo`OoCTi>1ol];Bd7
oeYJFPOoTi>C1_lD51@7of5QH@Oo4a<C1_oNg]h6ooooo`Oo>c/k1olN7Qh7ojVYZ@OoeMGE1olb<S87
omSHf0KoB4Q81_lW9bL6ooooo`OoHF5Q1omTI6@7oaTI6@Oo=3@d1olR8R87of][J`Oo>CTi1_o5aLD5
ooooo`Oo_kno1oln?Sh7oiVIV@OoLG5a1on_[jl7odU9B@Oon?Sh1_nh^;P=ooooo`002oooool7oaDE
5@Oo10@41on1PH47okjn_POo>c/k1ooUiND7ode=C@Ko2PX:1Oooool7ohn?S`OoD51@1om;Bd/7obl_
;`Oo00001om=CDd7ooooo`KoX:2P1_ooool6oaDE5@Oo4Q8B1ol>3Ph7odi>CPOo^k^k1om^KVh7ob0P
80KoBDU91_ooool7o`/;2`Oo9bLW1_l30`<7ob`/;0OoHV9R1ooVi^H7ooWin@Ko6a/K1_ooool7odi>
CPOo;Bd]1omJFUX7oi>CT`Ko51@D1omQHF47oa<C4`Kog]kN1_ooool7oc/k>`Oo7QhN1onYZJT7omGE
e@Oo<S8b1ooHf=P6odQ8B0Ko9bLW1_ooool7of5QH@OoI6AT1olI6AT7oc@d=0Oo8R8R1om[Jf/7ocTi
>@KoaLG51Oooool7okno_`Oo?Shn1onIVIT7og5aL@Oo[jn_1om9BDT7ooShn0Ko^;Rh3Oooool000_o
oooo1olE5AD7o`@410OoPH611onn_[h7oc/k>`OoiNGU1om=CDd6o`X:2PGooooo1on?Shl7oe1@D0Oo
Bd];1ol_;bl7o`0000OoCDe=1oooool6oj2PX0Kooooo1_lE5AD7oa8B4POo3Ph>1om>CTh7ok^k^`Oo
KVi^1olP8206odU9B@Kooooo1ol;2`/7obLW9`Ko0`<31ol/;2`7of9RHPOoi^KV1ooinOT6oa/K6`Ko
oooo1om>CTh7obd];@OoFUYJ1onCTi<6oa@D50OoHF5Q1olC4a<6omkNgPKooooo1olk>c/7oahN7POo
ZJVY1ooEeMD7oc8b<POof=SH1_m8B4P6obLW9`Kooooo1omQHF47ofATI0Oo6ATI1old=3@7ob8R8POo
Jf][1oli>CT6olG5a@Gooooo1ono_kl7ochn?POoVIVI1omaLG47ojn_[`OoBDU91oohn?P6okRh^0go
oooo000;ooooo`Oo5ADE1ol410@7oh61P@Oo_[jn1olk>c/7onGUi@OoCDe=1_l:2PX5ooooo`OoShn?
1om@D507od];B`Oo;bl_1ol00007ode=C@Oooooo1_nPX:06ooooo`Ko5ADE1olB4Q87o`h>3POoCTi>
1onk^k/7ofi^KPOo820P1_m9BDT6ooooo`Oo2`/;1olW9bL6o`<30`Oo;2`/1omRHV87onKViPOonOWi
1_lK6a/6ooooo`OoCTi>1ol];Bd7oeYJFPOoTi>C1_lD51@7of5QH@Oo4a<C1_oNg]h6ooooo`Oo>c/k
1olN7Qh7ojVYZ@OoeMGE1olb<S87omSHf0KoB4Q81_lW9bL6ooooo`OoHF5Q1omTI6@7oaTI6@Oo=3@d
1olR8R87of][J`Oo>CTi1_o5aLD5ooooo`Oo_kno1oln?Sh7oiVIV@OoLG5a1on_[jl7odU9B@Oon?Sh
1_nh^;P=ooooo`002oooool7oaDE5@Oo10@41on1PH47okjn_POo>c/k1ooUiND7ode=C@Ko2PX:1Ooo
ool7ohn?S`OoD51@1om;Bd/7obl_;`Oo00001om=CDd7ooooo`KoX:2P1_ooool6oaDE5@Oo4Q8B1ol>
3Ph7odi>CPOo^k^k1om^KVh7ob0P80KoBDU91_ooool7o`/;2`Oo9bLW1_l30`<7ob`/;0OoHV9R1ooV
i^H7ooWin@Ko6a/K1_ooool7odi>CPOo;Bd]1omJFUX7oi>CT`Ko51@D1omQHF47oa<C4`Kog]kN1_oo
ool7oc/k>`Oo7QhN1onYZJT7omGEe@Oo<S8b1ooHf=P6odQ8B0Ko9bLW1_ooool7of5QH@OoI6AT1olI
6AT7oc@d=0Oo8R8R1om[Jf/7ocTi>@KoaLG51Oooool7okno_`Oo?Shn1onIVIT7og5aL@Oo[jn_1om9
BDT7ooShn0Ko^;Rh3Oooool000_ooooo1olE5AD7o`@410OoPH611onn_[h7oc/k>`OoiNGU1om=CDd6
o`X:2PGooooo1on?Shl7oe1@D0OoBd];1ol_;bl7o`0000OoCDe=1oooool6oj2PX0Kooooo1_lE5AD7
oa8B4POo3Ph>1om>CTh7ok^k^`OoKVi^1olP8206odU9B@Kooooo1ol;2`/7obLW9`Ko0`<31ol/;2`7
of9RHPOoi^KV1ooinOT6oa/K6`Kooooo1om>CTh7obd];@OoFUYJ1onCTi<6oa@D50OoHF5Q1olC4a<6
omkNgPKooooo1olk>c/7oahN7POoZJVY1ooEeMD7oc8b<POof=SH1_m8B4P6obLW9`Kooooo1omQHF47
ofATI0Oo6ATI1old=3@7ob8R8POoJf][1oli>CT6olG5a@Gooooo1ono_kl7ochn?POoVIVI1omaLG47
ojn_[`OoBDU91oohn?P6okRh^0gooooo000;ooooo`Oo5ADE1ol410@7oh61P@Oo_[jn1olk>c/7onGU
i@OoCDe=1_l:2PX5ooooo`OoShn?1om@D507od];B`Oo;bl_1ol00007ode=C@Oooooo1_nPX:06oooo
o`Ko5ADE1olB4Q87o`h>3POoCTi>1onk^k/7ofi^KPOo820P1_m9BDT6ooooo`Oo2`/;1olW9bL6o`<3
0`Oo;2`/1omRHV87onKViPOonOWi1_lK6a/6ooooo`OoCTi>1ol];Bd7oeYJFPOoTi>C1_lD51@7of5Q
H@Oo4a<C1_oNg]h6ooooo`Oo>c/k1olN7Qh7ojVYZ@OoeMGE1olb<S87omSHf0KoB4Q81_lW9bL6oooo
o`OoHF5Q1omTI6@7oaTI6@Oo=3@d1olR8R87of][J`Oo>CTi1_o5aLD5ooooo`Oo_kno1oln?Sh7oiVI
V@OoLG5a1on_[jl7odU9B@Oon?Sh1_nh^;P=ooooo`002oooool7oaLG5`Oo00001on8R8P7oj:RXPOo
6a/K1oo`l?07ocHf=PKo6ATI1Oooool7ofi^KPOolo?c1om=CDd7o`d=3@OoQHF51onJVYX7oda<C0Ko
>3Ph1_ooool6ocHf=POo00001omVIVH7ohb<S0OoH61P1ole=CD7oa0@40Kolo?c1_ooool7o`820POo
:b/[1_l00007ocHf=POoR8R81oogmoL7ooKfmPKo5ADE1_ooool7oda<C0Oo92@T1omTI6@7oinOW`Ko
51@D1om[Jf/7oa0@40KomoOg1_ooool7od92@POo8b<S1oo>c/h7oo;blPOo8B4Q1oomoOd6ob<S8`Ko
9bLW1_ooool7of1PH0Oo:2PX1ol92@T7o`d=3@OoUIFE1omJFUX7og1`L0Ko2PX:1Oooool7okRh^0Oo
6QXJ1onb/[87ohj>SPOo]KFe1ol/;2`7ooooo`KoWYjN3Oooool000_ooooo1olG5aL7o`0000OoR8R8
1onRXZ87oa/K6`Ool?3`1olf=SH6oaTI6@Gooooo1om^KVh7oo?cl`OoCDe=1ol=3@d7ohF5Q@OoVYZJ
1om<C4`6ocPh>0Kooooo1_lf=SH7o`0000OoIVIV1on<S8`7of1PH0Oo=CDe1ol@4106oo?cl`Kooooo
1ol20P87ob/[:`Ko00001olf=SH7ohR8R0OomoOg1oofm_H6oaDE5@Kooooo1om<C4`7ob@T90OoI6AT
1onOWil6oa@D50OoJf][1ol@4106ooOgm`Kooooo1om2@T87ob<S8`Ooc/k>1oobl_87ob4Q8@OooOgm
1_lS8b<6obLW9`Kooooo1omPH607obPX:0Oo2@T91ol=3@d7oiFEU@OoFUYJ1om`L706o`X:2PGooooo
1onh^;P7oaXJ6POo/[:b1on>SXh7okFe]@Oo;2`/1oooool6oijNWPgooooo000;ooooo`Oo5aLG1ol0
0007ohR8R0OoXZ:R1olK6a/7oo3`l0Oo=SHf1_lI6AT5ooooo`OoKVi^1ooclo<7ode=C@Oo3@d=1on5
QHD7oiZJVPOoC4a<1_lh>3P6ooooo`Ko=SHf1ol00007ofIVIPOoS8b<1omPH607ocDe=@Oo410@1_oc
lo<6ooooo`Oo0P821ol[:b/6o`0000Oo=SHf1on8R8P7ooOgm`Oom_Kf1_lE5AD6ooooo`OoC4a<1olT
92@7ofATI0OoWinO1_lD51@7of][J`Oo410@1_ogmoL6ooooo`Oo@T921olS8b<7olk>cPOol_;b1olQ
8B47oogmo@Ko8b<S1_lW9bL6ooooo`OoH61P1olX:2P7o`T92@Oo3@d=1onEUID7oeYJFPOoL71`1_l:
2PX5ooooo`Oo^;Rh1olJ6QX7ok:b/POoSXj>1one]KD7ob`/;0Oooooo1_nNWYh=ooooo`002oooool7
oaLG5`Oo00001on8R8P7oj:RXPOo6a/K1oo`l?07ocHf=PKo6ATI1Oooool7ofi^KPOolo?c1om=CDd7
o`d=3@OoQHF51onJVYX7oda<C0Ko>3Ph1_ooool6ocHf=POo00001omVIVH7ohb<S0OoH61P1ole=CD7
oa0@40Kolo?c1_ooool7o`820POo:b/[1_l00007ocHf=POoR8R81oogmoL7ooKfmPKo5ADE1_ooool7
oda<C0Oo92@T1omTI6@7oinOW`Ko51@D1om[Jf/7oa0@40KomoOg1_ooool7od92@POo8b<S1oo>c/h7
oo;blPOo8B4Q1oomoOd6ob<S8`Ko9bLW1_ooool7of1PH0Oo:2PX1ol92@T7o`d=3@OoUIFE1omJFUX7
og1`L0Ko2PX:1Oooool7okRh^0Oo6QXJ1onb/[87ohj>SPOo]KFe1ol/;2`7ooooo`KoWYjN3Oooool0
00_ooooo1olG5aL7o`0000OoR8R81onRXZ87oa/K6`Ool?3`1olf=SH6oaTI6@Gooooo1om^KVh7oo?c
l`OoCDe=1ol=3@d7ohF5Q@OoVYZJ1om<C4`6ocPh>0Kooooo1_lf=SH7o`0000OoIVIV1on<S8`7of1P
H0Oo=CDe1ol@4106oo?cl`Kooooo1ol20P87ob/[:`Ko00001olf=SH7ohR8R0OomoOg1oofm_H6oaDE
5@Kooooo1om<C4`7ob@T90OoI6AT1onOWil6oa@D50OoJf][1ol@4106ooOgm`Kooooo1om2@T87ob<S
8`Ooc/k>1oobl_87ob4Q8@OooOgm1_lS8b<6obLW9`Kooooo1omPH607obPX:0Oo2@T91ol=3@d7oiFE
U@OoFUYJ1om`L706o`X:2PGooooo1onh^;P7oaXJ6POo/[:b1on>SXh7okFe]@Oo;2`/1oooool6oijN
WPgooooo000;ooooo`Oo5aLG1ol00007ohR8R0OoXZ:R1olK6a/7oo3`l0Oo=SHf1_lI6AT5ooooo`Oo
KVi^1ooclo<7ode=C@Oo3@d=1on5QHD7oiZJVPOoC4a<1_lh>3P6ooooo`Ko=SHf1ol00007ofIVIPOo
S8b<1omPH607ocDe=@Oo410@1_oclo<6ooooo`Oo0P821ol[:b/6o`0000Oo=SHf1on8R8P7ooOgm`Oo
m_Kf1_lE5AD6ooooo`OoC4a<1olT92@7ofATI0OoWinO1_lD51@7of][J`Oo410@1_ogmoL6ooooo`Oo
@T921olS8b<7olk>cPOol_;b1olQ8B47oogmo@Ko8b<S1_lW9bL6ooooo`OoH61P1olX:2P7o`T92@Oo
3@d=1onEUID7oeYJFPOoL71`1_l:2PX5ooooo`Oo^;Rh1olJ6QX7ok:b/POoSXj>1one]KD7ob`/;0Oo
oooo1_nNWYh=ooooo`002oooool7oaLG5`Oo00001on8R8P7oj:RXPOo6a/K1oo`l?07ocHf=PKo6ATI
1Oooool7ofi^KPOolo?c1om=CDd7o`d=3@OoQHF51onJVYX7oda<C0Ko>3Ph1_ooool6ocHf=POo0000
1omVIVH7ohb<S0OoH61P1ole=CD7oa0@40Kolo?c1_ooool7o`820POo:b/[1_l00007ocHf=POoR8R8
1oogmoL7ooKfmPKo5ADE1_ooool7oda<C0Oo92@T1omTI6@7oinOW`Ko51@D1om[Jf/7oa0@40KomoOg
1_ooool7od92@POo8b<S1oo>c/h7oo;blPOo8B4Q1oomoOd6ob<S8`Ko9bLW1_ooool7of1PH0Oo:2PX
1ol92@T7o`d=3@OoUIFE1omJFUX7og1`L0Ko2PX:1Oooool7okRh^0Oo6QXJ1onb/[87ohj>SPOo]KFe
1ol/;2`7ooooo`KoWYjN3Oooool000_ooooo1ol;2`/7o`P820OoMGEe1onYZJT7obDU9@Oooooo1om:
BTX6o`820PGooooo1onOWil7oclo?`Oo:BTY1ol];Bd7ob8R8POoJFUY1oolo?`6ogmoO`Kooooo1_l2
0P87o``<30Oo:b/[1omfMWH7ojf][@OoEEEE1ol=3@d6ocTi>@Kooooo1ol:2PX7ob`/;0Ko20P81olh
>3P7ohJ6QPOol?3`1ooQhN46oa4A4@Kooooo1olf=SH7ob`/;0OoKFe]1onNWYh6o`L71`OoBTY:1ol<
30`6ooOgm`Kooooo1ol];Bd7oaHF5POoalO71oomoOd7o`410@OogMgM1_lU9BD6obl_;`Kooooo1omY
JFT7od10@0Oo6QXJ1om<C4`7ob8R8POoHf=S1olf=SH6ooclo0Gooooo1oo@d=07obHV9POoWYjN1on8
R8P7ojFUY@Oo>c/k1oolo?`6okjn_Pgooooo000;ooooo`Oo2`/;1ol820P7ogEeM@OoZJVY1olU9BD7
ooooo`OoBTY:1_l20P85ooooo`OoWinO1olo?cl7obTY:@Oo;Bd]1olR8R87ofUYJ@Ooo?cl1_moOgl6
ooooo`Ko0P821ol<30`7ob/[:`OoMWIf1on][Jd7oeEEE@Oo3@d=1_li>CT6ooooo`Oo2PX:1ol/;2`6
o`P820Oo>3Ph1on6QXH7oo3`l0OohN7Q1_lA4A46ooooo`Oo=SHf1ol/;2`7ofe]K@OoWYjN1_l71`L7
odY:BPOo30`<1_ogmoL6ooooo`Oo;Bd]1olF5QH7olO7a`OooOgm1ol10@47omgMg@Ko9BDU1_l_;bl6
ooooo`OoJFUY1om0@407oaXJ6POoC4a<1olR8R87of=SH`Oo=SHf1_olo?`5ooooo`Ood=3@1olV9RH7
oijNWPOoR8R81onUYJD7oc/k>`Ooo?cl1_nn_[h=ooooo`002oooool7o`/;2`Oo20P81omeMGD7ojVY
Z@Oo9BDU1oooool7odY:BPKo0P821Oooool7oinOW`Oo?clo1olY:BT7obd];@Oo8R8R1omYJFT7oocl
o0KoOgmo1_ooool6o`820POo30`<1ol[:b/7ogIfMPOo[Jf]1omEEED7o`d=3@Ko>CTi1_ooool7o`X:
2POo;2`/1_l820P7ocPh>0OoQXJ61oo`l?07on7Qh@Ko4A4A1_ooool7ocHf=POo;2`/1om]KFd7oijN
WPKo1`L71om:BTX7o``<30KomoOg1_ooool7obd];@Oo5QHF1oo7alL7oogmo@Oo0@411ooMgMd6obDU
9@Ko;bl_1_ooool7ofUYJ@Oo@4101olJ6QX7oda<C0Oo8R8R1omSHf<7ocHf=PKoo?cl1Oooool7om3@
d0Oo9RHV1onNWYh7ohR8R0OoYJFU1olk>c/7ooclo0Ko_[jn3Oooool000_ooooo1ol;2`/7o`P820Oo
MGEe1onYZJT7obDU9@Oooooo1om:BTX6o`820PGooooo1onOWil7oclo?`Oo:BTY1ol];Bd7ob8R8POo
JFUY1oolo?`6ogmoO`Kooooo1_l20P87o``<30Oo:b/[1omfMWH7ojf][@OoEEEE1ol=3@d6ocTi>@Ko
oooo1ol:2PX7ob`/;0Ko20P81olh>3P7ohJ6QPOol?3`1ooQhN46oa4A4@Kooooo1olf=SH7ob`/;0Oo
KFe]1onNWYh6o`L71`OoBTY:1ol<30`6ooOgm`Kooooo1ol];Bd7oaHF5POoalO71oomoOd7o`410@Oo
gMgM1_lU9BD6obl_;`Kooooo1omYJFT7od10@0Oo6QXJ1om<C4`7ob8R8POoHf=S1olf=SH6ooclo0Go
oooo1oo@d=07obHV9POoWYjN1on8R8P7ojFUY@Oo>c/k1oolo?`6okjn_Pgooooo000;ooooo`Oo2`/;
1ol820P7ogEeM@OoZJVY1olU9BD7ooooo`OoBTY:1_l20P85ooooo`OoWinO1olo?cl7obTY:@Oo;Bd]
1olR8R87ofUYJ@Ooo?cl1_moOgl6ooooo`Ko0P821ol<30`7ob/[:`OoMWIf1on][Jd7oeEEE@Oo3@d=
1_li>CT6ooooo`Oo2PX:1ol/;2`6o`P820Oo>3Ph1on6QXH7oo3`l0OohN7Q1_lA4A46ooooo`Oo=SHf
1ol/;2`7ofe]K@OoWYjN1_l71`L7odY:BPOo30`<1_ogmoL6ooooo`Oo;Bd]1olF5QH7olO7a`OooOgm
1ol10@47omgMg@Ko9BDU1_l_;bl6ooooo`OoJFUY1om0@407oaXJ6POoC4a<1olR8R87of=SH`Oo=SHf
1_olo?`5ooooo`Ood=3@1olV9RH7oijNWPOoR8R81onUYJD7oc/k>`Ooo?cl1_nn_[h=ooooo`002ooo
ool7o`/;2`Oo20P81omeMGD7ojVYZ@Oo9BDU1oooool7odY:BPKo0P821Oooool7oinOW`Oo?clo1olY
:BT7obd];@Oo8R8R1omYJFT7ooclo0KoOgmo1_ooool6o`820POo30`<1ol[:b/7ogIfMPOo[Jf]1omE
EED7o`d=3@Ko>CTi1_ooool7o`X:2POo;2`/1_l820P7ocPh>0OoQXJ61oo`l?07on7Qh@Ko4A4A1_oo
ool7ocHf=POo;2`/1om]KFd7oijNWPKo1`L71om:BTX7o``<30KomoOg1_ooool7obd];@Oo5QHF1oo7
alL7oogmo@Oo0@411ooMgMd6obDU9@Ko;bl_1_ooool7ofUYJ@Oo@4101olJ6QX7oda<C0Oo8R8R1omS
Hf<7ocHf=PKoo?cl1Oooool7om3@d0Oo9RHV1onNWYh7ohR8R0OoYJFU1olk>c/7ooclo0Ko_[jn3Ooo
ool000_ooooo1ol30`<7oaXJ6POoGemO1on5QHD7obl_;`Oom_Kf1ol];Bd6o`<30`Gooooo1omgMgL7
ol_;b`Oo:b/[1olW9bL7oh^;R`OoVYZJ1om6ATH6og=cL`Kooooo1_lF5QH7oa`L70OoJf][1on7QhL7
od];B`Oo4A4A1ol<30`6ol[:bPKooooo1ol@4107ocTi>@Ko2PX:1om7AdL7oj>SX`Oooooo1ooRh^86
o`X:2PKooooo1olf=SH7obTY:@OoPH611on<S8`6o`X:2POoFUYJ1ol0000<ooooo`Oo?Shn1olS8b<7
om3@d0Oooooo1ol820P7ooooo`Ko30`<1_mADE46ooooo`OoCdm?1olK6a/7o`0000Oo6QXJ1onf][H7
oeYJFPOoDE5A1_l410@5ooooo`Oo_[jn1olC4a<7oj^[Z`OoU9BD1onUYJD7oaXJ6POokNg]1_n[Zj/=
ooooo`002oooool7o`<30`Oo6QXJ1omOGel7ohF5Q@Oo;bl_1oofm_H7obd];@Ko0`<31Oooool7ogMg
M`Oobl_;1ol[:b/7obLW9`OoRh^;1onJVYX7odI6APKoLg=c1_ooool6oaHF5POo71`L1om[Jf/7ohN7
Q`OoBd];1olA4A47o``<30Kob/[:1_ooool7oa0@40Oo>CTi1_l:2PX7odM7A`OoXj>S1oooool7on;R
hPKo2PX:1_ooool7ocHf=POo:BTY1on1PH47ohb<S0Ko2PX:1omJFUX7o`0000cooooo1oln?Sh7ob<S
8`Ood=3@1oooool7o`P820Oooooo1_l<30`6oe5AD@Kooooo1om?Cdl7oa/K6`Oo00001olJ6QX7okJf
]POoFUYJ1omADE46o`@410Gooooo1onn_[h7oa<C4`OoZj^[1onDU9@7ojFUY@Oo6QXJ1oo]kNd6oj^[
Z`gooooo000;ooooo`Oo0`<31olJ6QX7oemOG`OoQHF51ol_;bl7ooKfmPOo;Bd]1_l30`<5ooooo`Oo
MgMg1oo;bl/7ob/[:`Oo9bLW1on;Rh/7oiZJVPOoATI61_mcLg<6ooooo`Ko5QHF1olL71`7of][J`Oo
QhN71om;Bd/7oa4A4@Oo30`<1_o:b/X6ooooo`Oo410@1oli>CT6o`X:2POoAdM71onSXj<7ooooo`Oo
h^;R1_l:2PX6ooooo`Oo=SHf1olY:BT7oh61P@OoS8b<1_l:2PX7oeYJFPOo00003?ooool7ochn?POo
8b<S1oo@d=07ooooo`Oo20P81oooool6o``<30KoDE5A1_ooool7odm?C`Oo6a/K1ol00007oaXJ6POo
][Jf1omJFUX7oe5AD@Ko10@41Oooool7okjn_POo4a<C1on[Zj/7oiBDU0OoYJFU1olJ6QX7ong]k@Ko
Zj^[3Oooool000_ooooo1ol30`<7oaXJ6POoGemO1on5QHD7obl_;`Oom_Kf1ol];Bd6o`<30`Gooooo
1omgMgL7ol_;b`Oo:b/[1olW9bL7oh^;R`OoVYZJ1om6ATH6og=cL`Kooooo1_lF5QH7oa`L70OoJf][
1on7QhL7od];B`Oo4A4A1ol<30`6ol[:bPKooooo1ol@4107ocTi>@Ko2PX:1om7AdL7oj>SX`Oooooo
1ooRh^86o`X:2PKooooo1olf=SH7obTY:@OoPH611on<S8`6o`X:2POoFUYJ1ol0000<ooooo`Oo?Shn
1olS8b<7om3@d0Oooooo1ol820P7ooooo`Ko30`<1_mADE46ooooo`OoCdm?1olK6a/7o`0000Oo6QXJ
1onf][H7oeYJFPOoDE5A1_l410@5ooooo`Oo_[jn1olC4a<7oj^[Z`OoU9BD1onUYJD7oaXJ6POokNg]
1_n[Zj/=ooooo`002oooool7o`<30`Oo6QXJ1omOGel7ohF5Q@Oo;bl_1oofm_H7obd];@Ko0`<31Ooo
ool7ogMgM`Oobl_;1ol[:b/7obLW9`OoRh^;1onJVYX7odI6APKoLg=c1_ooool6oaHF5POo71`L1om[
Jf/7ohN7Q`OoBd];1olA4A47o``<30Kob/[:1_ooool7oa0@40Oo>CTi1_l:2PX7odM7A`OoXj>S1ooo
ool7on;RhPKo2PX:1_ooool7ocHf=POo:BTY1on1PH47ohb<S0Ko2PX:1omJFUX7o`0000cooooo1oln
?Sh7ob<S8`Ood=3@1oooool7o`P820Oooooo1_l<30`6oe5AD@Kooooo1om?Cdl7oa/K6`Oo00001olJ
6QX7okJf]POoFUYJ1omADE46o`@410Gooooo1onn_[h7oa<C4`OoZj^[1onDU9@7ojFUY@Oo6QXJ1oo]
kNd6oj^[Z`gooooo000;ooooo`Oo0`<31olJ6QX7oemOG`OoQHF51ol_;bl7ooKfmPOo;Bd]1_l30`<5
ooooo`OoMgMg1oo;bl/7ob/[:`Oo9bLW1on;Rh/7oiZJVPOoATI61_mcLg<6ooooo`Ko5QHF1olL71`7
of][J`OoQhN71om;Bd/7oa4A4@Oo30`<1_o:b/X6ooooo`Oo410@1oli>CT6o`X:2POoAdM71onSXj<7
ooooo`Ooh^;R1_l:2PX6ooooo`Oo=SHf1olY:BT7oh61P@OoS8b<1_l:2PX7oeYJFPOo00003?ooool7
ochn?POo8b<S1oo@d=07ooooo`Oo20P81oooool6o``<30KoDE5A1_ooool7odm?C`Oo6a/K1ol00007
oaXJ6POo][Jf1omJFUX7oe5AD@Ko10@41Oooool7okjn_POo4a<C1on[Zj/7oiBDU0OoYJFU1olJ6QX7
ong]k@KoZj^[3Oooool000_ooooo1ol30`<7oaXJ6POoGemO1on5QHD7obl_;`Oom_Kf1ol];Bd6o`<3
0`Gooooo1omgMgL7ol_;b`Oo:b/[1olW9bL7oh^;R`OoVYZJ1om6ATH6og=cL`Kooooo1_lF5QH7oa`L
70OoJf][1on7QhL7od];B`Oo4A4A1ol<30`6ol[:bPKooooo1ol@4107ocTi>@Ko2PX:1om7AdL7oj>S
X`Oooooo1ooRh^86o`X:2PKooooo1olf=SH7obTY:@OoPH611on<S8`6o`X:2POoFUYJ1ol0000<oooo
o`Oo?Shn1olS8b<7om3@d0Oooooo1ol820P7ooooo`Ko30`<1_mADE46ooooo`OoCdm?1olK6a/7o`00
00Oo6QXJ1onf][H7oeYJFPOoDE5A1_l410@5ooooo`Oo_[jn1olC4a<7oj^[Z`OoU9BD1onUYJD7oaXJ
6POokNg]1_n[Zj/=ooooo`002oooool7oa8B4POo<C4a1on1PH47oh:2PPOo>3Ph1ooIfMT7oc`l?0Ko
5aLG1Oooool7oiZJVPOo9bLW1ol?3`l7obTY:@OoGEeM1omnOWh7on?Sh`KoHV9R1_ooool6o`0000Oo
4a<C1om>CTh7ohJ6QPOoU9BD1olo?cl7oa4A4@Ko<30`1_ooool7oadM7@Oo>CTi1_lP8207oe9BDPOo
VIVI1ooNg]h7okBd]0Ko4A4A1_ooool7obDU9@OoBTY:1om]KFd7oh61P@Ko4A4A1omBDU87o`<30`co
oooo1olc<c<7oa0@40Oo`/;21oobl_87o`0000Oob/[:1_lH61P6odm?C`Kooooo1omEEED7oaTI6@Oo
7QhN1omGEeL7obDU9@OoEeMG1ol`<306oo3`l0Gooooo1oo9bLT7oaLG5`OoTi>C1omUIFD7oi>CT`Oo
;2`/1ooOgml6oiJFUPgooooo000;ooooo`Oo4Q8B1ola<C47oh61P@OoPX:21olh>3P7omWIf@Oo?3`l
1_lG5aL5ooooo`OoVYZJ1olW9bL7o`l?3`Oo:BTY1omMGEd7oginOPOohn?S1_mRHV86ooooo`Ko0000
1olC4a<7odi>CPOoQXJ61onDU9@7oclo?`Oo4A4A1_l`<306ooooo`Oo7AdM1oli>CT6ob0P80OoDU9B
1onIVIT7omkNgPOo];Bd1_lA4A46ooooo`Oo9BDU1om:BTX7ofe]K@OoPH611_lA4A47oe9BDPOo0`<3
3?ooool7oc<c<`Oo410@1oo2`/87oo;blPOo00001oo:b/X6oaPH60KoCdm?1_ooool7oeEEE@Oo6ATI
1olN7Qh7oeMGE`Oo9BDU1omGEeL7oc0`<0Kol?3`1Oooool7olW9b@Oo5aLG1onCTi<7ofEUI@OoTi>C
1ol/;2`7omoOg`KoUYJF3Oooool000_ooooo1olB4Q87oc4a<@OoPH611on2PX87ocPh>0OofMWI1oll
?3`6oaLG5`Gooooo1onJVYX7obLW9`Oo3`l?1olY:BT7oeeMG@OoOWin1ooShn<6of9RHPKooooo1_l0
0007oa<C4`OoCTi>1on6QXH7oiBDU0Oo?clo1olA4A46oc0`<0Kooooo1olM7Ad7ocTi>@Ko820P1omB
DU87oiVIV@Oog]kN1ond];@6oa4A4@Kooooo1olU9BD7odY:BPOoKFe]1on1PH46oa4A4@OoDU9B1ol3
0`<<ooooo`Oo<c<c1ol@4107ol;2`POol_;b1ol00007ol[:bPKo61PH1_m?Cdl6ooooo`OoEEEE1olI
6AT7oahN7POoEeMG1olU9BD7oeMGE`Oo<30`1_o`l?05ooooo`OobLW91olG5aL7oi>CT`OoIFEU1onC
Ti<7ob`/;0OogmoO1_nFUYH=ooooo`002oooool7oa8B4POo<C4a1on1PH47oh:2PPOo>3Ph1ooIfMT7
oc`l?0Ko5aLG1Oooool7oiZJVPOo9bLW1ol?3`l7obTY:@OoGEeM1omnOWh7on?Sh`KoHV9R1_ooool6
o`0000Oo4a<C1om>CTh7ohJ6QPOoU9BD1olo?cl7oa4A4@Ko<30`1_ooool7oadM7@Oo>CTi1_lP8207
oe9BDPOoVIVI1ooNg]h7okBd]0Ko4A4A1_ooool7obDU9@OoBTY:1om]KFd7oh61P@Ko4A4A1omBDU87
o`<30`cooooo1olc<c<7oa0@40Oo`/;21oobl_87o`0000Oob/[:1_lH61P6odm?C`Kooooo1omEEED7
oaTI6@Oo7QhN1omGEeL7obDU9@OoEeMG1ol`<306oo3`l0Gooooo1oo9bLT7oaLG5`OoTi>C1omUIFD7
oi>CT`Oo;2`/1ooOgml6oiJFUPgooooo000;ooooo`Oo4Q8B1ola<C47oh61P@OoPX:21olh>3P7omWI
f@Oo?3`l1_lG5aL5ooooo`OoVYZJ1olW9bL7o`l?3`Oo:BTY1omMGEd7oginOPOohn?S1_mRHV86oooo
o`Ko00001olC4a<7odi>CPOoQXJ61onDU9@7oclo?`Oo4A4A1_l`<306ooooo`Oo7AdM1oli>CT6ob0P
80OoDU9B1onIVIT7omkNgPOo];Bd1_lA4A46ooooo`Oo9BDU1om:BTX7ofe]K@OoPH611_lA4A47oe9B
DPOo0`<33?ooool7oc<c<`Oo410@1oo2`/87oo;blPOo00001oo:b/X6oaPH60KoCdm?1_ooool7oeEE
E@Oo6ATI1olN7Qh7oeMGE`Oo9BDU1omGEeL7oc0`<0Kol?3`1Oooool7olW9b@Oo5aLG1onCTi<7ofEU
I@OoTi>C1ol/;2`7omoOg`KoUYJF3Oooool000_ooooo1olB4Q87oc4a<@OoPH611on2PX87ocPh>0Oo
fMWI1oll?3`6oaLG5`Gooooo1onJVYX7obLW9`Oo3`l?1olY:BT7oeeMG@OoOWin1ooShn<6of9RHPKo
oooo1_l00007oa<C4`OoCTi>1on6QXH7oiBDU0Oo?clo1olA4A46oc0`<0Kooooo1olM7Ad7ocTi>@Ko
820P1omBDU87oiVIV@Oog]kN1ond];@6oa4A4@Kooooo1olU9BD7odY:BPOoKFe]1on1PH46oa4A4@Oo
DU9B1ol30`<<ooooo`Oo<c<c1ol@4107ol;2`POol_;b1ol00007ol[:bPKo61PH1_m?Cdl6ooooo`Oo
EEEE1olI6AT7oahN7POoEeMG1olU9BD7oeMGE`Oo<30`1_o`l?05ooooo`OobLW91olG5aL7oi>CT`Oo
IFEU1onCTi<7ob`/;0OogmoO1_nFUYH=ooooo`002oooool7oa8B4POo<C4a1on1PH47oh:2PPOo>3Ph
1ooIfMT7oc`l?0Ko5aLG1Oooool7oiZJVPOo9bLW1ol?3`l7obTY:@OoGEeM1omnOWh7on?Sh`KoHV9R
1_ooool6o`0000Oo4a<C1om>CTh7ohJ6QPOoU9BD1olo?cl7oa4A4@Ko<30`1_ooool7oadM7@Oo>CTi
1_lP8207oe9BDPOoVIVI1ooNg]h7okBd]0Ko4A4A1_ooool7obDU9@OoBTY:1om]KFd7oh61P@Ko4A4A
1omBDU87o`<30`cooooo1olc<c<7oa0@40Oo`/;21oobl_87o`0000Oob/[:1_lH61P6odm?C`Kooooo
1omEEED7oaTI6@Oo7QhN1omGEeL7obDU9@OoEeMG1ol`<306oo3`l0Gooooo1oo9bLT7oaLG5`OoTi>C
1omUIFD7oi>CT`Oo;2`/1ooOgml6oiJFUPgooooo000;ooooo`Oo410@1ol];Bd7oe9BDPOoL71`1olf
=SH7olc<c0Oo:BTY1_l@4105ooooo`OoNWYj1on@T907oadM7@OoDe=C1omgMgL7oj:RXPOo<c<c1_o;
bl/6ooooo`Ko2PX:1om:BTX7ofATI0OoN7Qh1ole=CD7oa4A4@Oo2PX:1_n7QhL6ooooo`Oo9RHV1omB
DU86oa4A4@OoI6AT1on[Zj/7onKViPOoY:BT1_lI6AT6ooooo`Oo9RHV1om5ADD7og]kN`OoL71`1_l^
;Rh7oe1@D0Oo00001_oinOT6ooooo`Oo=3@d1olB4Q87okfm_@Ooi^KV1ol?3`l7om[JfPKo4A4A1_mQ
HF46ooooo`Oo=cLg1olI6AT7o`T92@Oo<S8b1oo6a/H7oe=CD`Oo:b/[1_lK6a/5ooooo`OoZZZZ1ol0
0007oibLW0OoK6a/1on<S8`7o``<30Oo^[Zj1_nSXj<=ooooo`002oooool7oa0@40Oo;Bd]1omBDU87
og1`L0Oo=SHf1oo<c<`7obTY:@Ko410@1Oooool7ogYjNPOoT92@1olM7Ad7oe=CD`OoMgMg1onRXZ87
oc<c<`Kobl_;1_ooool6o`X:2POoBTY:1omTI6@7ogQhN0Oo=CDe1olA4A47o`X:2PKoQhN71_ooool7
obHV9POoDU9B1_lA4A47ofATI0OoZj^[1ooVi^H7ojBTY0Ko6ATI1_ooool7obHV9POoADE51omkNg/7
og1`L0Ko;Rh^1om@D507o`0000KonOWi1_ooool7oc@d=0Oo4Q8B1onm_Kd7onKViPOo3`l?1ooJf]X6
oa4A4@KoHF5Q1_ooool7ocLg=`Oo6ATI1ol92@T7oc8b<POoa/K61omCDe<7ob/[:`Ko6a/K1Oooool7
ojZZZPOo00001onLW9`7ofa/K0OoS8b<1ol<30`7okZj^PKoXj>S3Oooool000_ooooo1ol@4107obd]
;@OoDU9B1om`L707ocHf=POoc<c<1olY:BT6oa0@40Gooooo1omjNWX7oi2@T0Oo7AdM1omCDe<7ogMg
M`OoXZ:R1olc<c<6ol_;b`Kooooo1_l:2PX7odY:BPOoI6AT1omhN7P7ocDe=@Oo4A4A1ol:2PX6ohN7
Q`Kooooo1olV9RH7oe9BDPKo4A4A1omTI6@7oj^[Z`Ooi^KV1onTY:@6oaTI6@Kooooo1olV9RH7odE5
A@OoNg]k1om`L706obh^;POoD51@1ol00006ooWin@Kooooo1old=3@7oa8B4POo_Kfm1ooVi^H7o`l?
3`Oof][J1_lA4A46of5QH@Kooooo1olg=cL7oaTI6@Oo2@T91olb<S87olK6aPOoDe=C1ol[:b/6oa/K
6`Gooooo1onZZZX7o`0000OoW9bL1om/K6`7ohb<S0Oo30`<1onj^[X6oj>SX`gooooo000;ooooo`Oo
410@1ol];Bd7oe9BDPOoL71`1olf=SH7olc<c0Oo:BTY1_l@4105ooooo`OoNWYj1on@T907oadM7@Oo
De=C1omgMgL7oj:RXPOo<c<c1_o;bl/6ooooo`Ko2PX:1om:BTX7ofATI0OoN7Qh1ole=CD7oa4A4@Oo
2PX:1_n7QhL6ooooo`Oo9RHV1omBDU86oa4A4@OoI6AT1on[Zj/7onKViPOoY:BT1_lI6AT6ooooo`Oo
9RHV1om5ADD7og]kN`OoL71`1_l^;Rh7oe1@D0Oo00001_oinOT6ooooo`Oo=3@d1olB4Q87okfm_@Oo
i^KV1ol?3`l7om[JfPKo4A4A1_mQHF46ooooo`Oo=cLg1olI6AT7o`T92@Oo<S8b1oo6a/H7oe=CD`Oo
:b/[1_lK6a/5ooooo`OoZZZZ1ol00007oibLW0OoK6a/1on<S8`7o``<30Oo^[Zj1_nSXj<=ooooo`00
2oooool7oa0@40Oo;Bd]1omBDU87og1`L0Oo=SHf1oo<c<`7obTY:@Ko410@1Oooool7ogYjNPOoT92@
1olM7Ad7oe=CD`OoMgMg1onRXZ87oc<c<`Kobl_;1_ooool6o`X:2POoBTY:1omTI6@7ogQhN0Oo=CDe
1olA4A47o`X:2PKoQhN71_ooool7obHV9POoDU9B1_lA4A47ofATI0OoZj^[1ooVi^H7ojBTY0Ko6ATI
1_ooool7obHV9POoADE51omkNg/7og1`L0Ko;Rh^1om@D507o`0000KonOWi1_ooool7oc@d=0Oo4Q8B
1onm_Kd7onKViPOo3`l?1ooJf]X6oa4A4@KoHF5Q1_ooool7ocLg=`Oo6ATI1ol92@T7oc8b<POoa/K6
1omCDe<7ob/[:`Ko6a/K1Oooool7ojZZZPOo00001onLW9`7ofa/K0OoS8b<1ol<30`7okZj^PKoXj>S
3Oooool000_ooooo1ol@4107obd];@OoDU9B1om`L707ocHf=POoc<c<1olY:BT6oa0@40Gooooo1omj
NWX7oi2@T0Oo7AdM1omCDe<7ogMgM`OoXZ:R1olc<c<6ol_;b`Kooooo1_l:2PX7odY:BPOoI6AT1omh
N7P7ocDe=@Oo4A4A1ol:2PX6ohN7Q`Kooooo1olV9RH7oe9BDPKo4A4A1omTI6@7oj^[Z`Ooi^KV1onT
Y:@6oaTI6@Kooooo1olV9RH7odE5A@OoNg]k1om`L706obh^;POoD51@1ol00006ooWin@Kooooo1old
=3@7oa8B4POo_Kfm1ooVi^H7o`l?3`Oof][J1_lA4A46of5QH@Kooooo1olg=cL7oaTI6@Oo2@T91olb
<S87olK6aPOoDe=C1ol[:b/6oa/K6`Gooooo1onZZZX7o`0000OoW9bL1om/K6`7ohb<S0Oo30`<1onj
^[X6oj>SX`gooooo000;ooooo`Oo8B4Q1oll?3`7of=SH`OoIFEU1omGEeL7olO7a`Oo?Shn1_lG5aL5
ooooo`OoN7Qh1olM7Ad7o`0000Oo9RHV1omaLG47og=cL`Ood];B1_mPH606ooooo`Ko1PH61ol>3Ph7
oeaLG0OoLg=c1omiNGT7obTY:@Oo:RXZ1_lN7Qh6ooooo`Oo92@T1om6ATH6obDU9@OoH61P1on:RXX7
ojj^[POoOgmo1_lB4Q86ooooo`Oo;Rh^1omBDU87oeUIF@OoEUIF1_la<C47od10@0Oo0@411_oPh>06
ooooo`Oo4A4A1ol71`L7ojb/[0OoeMGE1ol00007ojJVYPKo2@T91_mMGEd6ooooo`OoATI61olB4Q87
oc@d=0OoLg=c1olD51@7odI6APOo=CDe2oooool7ok6a/@Oo00001on5QHD7oc4a<@OoJf][1olG5aL7
oj^[Z`KoJf][3Oooool000_ooooo1olQ8B47oc`l?0OoHf=S1omUIFD7oeMGE`OoalO71oln?Sh6oaLG
5`Gooooo1omhN7P7oadM7@Oo00001olV9RH7og5aL@OoLg=c1ooBd]86of1PH0Kooooo1_l61PH7o`h>
3POoG5aL1omcLg<7ogUiN@Oo:BTY1olZ:RX6oahN7PKooooo1olT92@7odI6APKo9BDU1omPH607ohZ:
RPOo[Zj^1omoOgl6oa8B4PKooooo1ol^;Rh7oe9BDPOoFEUI1omFEUH6oc4a<@Oo@4101ol10@46on3P
h0Kooooo1olA4A47o`L71`Oo[:b/1ooEeMD7o`0000OoYZJV1_l92@T6oeeMG@Kooooo1om6ATH7oa8B
4POo=3@d1omcLg<7oa@D50OoATI61ole=CD;ooooo`Oo/K6a1ol00007ohF5Q@Oo<C4a1om[Jf/7oaLG
5`OoZj^[1_m[Jf/=ooooo`002oooool7ob4Q8@Oo?3`l1omSHf<7ofEUI@OoEeMG1oo7alL7ochn?PKo
5aLG1Oooool7ogQhN0Oo7AdM1ol00007obHV9POoLG5a1omcLg<7om;BdPKoH61P1_ooool6o`H61POo
3Ph>1omLG5`7og=cL`OoNGUi1olY:BT7obXZ:PKo7QhN1_ooool7ob@T90OoATI61_lU9BD7of1PH0Oo
RXZ:1on^[Zh7ogmoO`Ko4Q8B1_ooool7obh^;POoDU9B1omIFET7oeIFEPKo<C4a1om0@407o`410@Ko
h>3P1_ooool7oa4A4@Oo1`L71on/[:`7omGEe@Oo00001onVYZH6o`T92@KoGEeM1_ooool7odI6APOo
4Q8B1old=3@7og=cL`Oo51@D1om6ATH7ocDe=@_ooooo1ona/K47o`0000OoQHF51ola<C47of][J`Oo
5aLG1on[Zj/6of][J`gooooo000;ooooo`Oo8B4Q1oll?3`7of=SH`OoIFEU1omGEeL7olO7a`Oo?Shn
1_lG5aL5ooooo`OoN7Qh1olM7Ad7o`0000Oo9RHV1omaLG47og=cL`Ood];B1_mPH606ooooo`Ko1PH6
1ol>3Ph7oeaLG0OoLg=c1omiNGT7obTY:@Oo:RXZ1_lN7Qh6ooooo`Oo92@T1om6ATH6obDU9@OoH61P
1on:RXX7ojj^[POoOgmo1_lB4Q86ooooo`Oo;Rh^1omBDU87oeUIF@OoEUIF1_la<C47od10@0Oo0@41
1_oPh>06ooooo`Oo4A4A1ol71`L7ojb/[0OoeMGE1ol00007ojJVYPKo2@T91_mMGEd6ooooo`OoATI6
1olB4Q87oc@d=0OoLg=c1olD51@7odI6APOo=CDe2oooool7ok6a/@Oo00001on5QHD7oc4a<@OoJf][
1olG5aL7oj^[Z`KoJf][3Oooool000_ooooo1olQ8B47oc`l?0OoHf=S1omUIFD7oeMGE`OoalO71oln
?Sh6oaLG5`Gooooo1omhN7P7oadM7@Oo00001olV9RH7og5aL@OoLg=c1ooBd]86of1PH0Kooooo1_l6
1PH7o`h>3POoG5aL1omcLg<7ogUiN@Oo:BTY1olZ:RX6oahN7PKooooo1olT92@7odI6APKo9BDU1omP
H607ohZ:RPOo[Zj^1omoOgl6oa8B4PKooooo1ol^;Rh7oe9BDPOoFEUI1omFEUH6oc4a<@Oo@4101ol1
0@46on3Ph0Kooooo1olA4A47o`L71`Oo[:b/1ooEeMD7o`0000OoYZJV1_l92@T6oeeMG@Kooooo1om6
ATH7oa8B4POo=3@d1omcLg<7oa@D50OoATI61ole=CD;ooooo`Oo/K6a1ol00007ohF5Q@Oo<C4a1om[
Jf/7oaLG5`OoZj^[1_m[Jf/=ooooo`002oooool7ob4Q8@Oo?3`l1omSHf<7ofEUI@OoEeMG1oo7alL7
ochn?PKo5aLG1Oooool7ogQhN0Oo7AdM1ol00007obHV9POoLG5a1omcLg<7om;BdPKoH61P1_ooool6
o`H61POo3Ph>1omLG5`7og=cL`OoNGUi1olY:BT7obXZ:PKo7QhN1_ooool7ob@T90OoATI61_lU9BD7
of1PH0OoRXZ:1on^[Zh7ogmoO`Ko4Q8B1_ooool7obh^;POoDU9B1omIFET7oeIFEPKo<C4a1om0@407
o`410@Koh>3P1_ooool7oa4A4@Oo1`L71on/[:`7omGEe@Oo00001onVYZH6o`T92@KoGEeM1_ooool7
odI6APOo4Q8B1old=3@7og=cL`Oo51@D1om6ATH7ocDe=@_ooooo1ona/K47o`0000OoQHF51ola<C47
of][J`Oo5aLG1on[Zj/6of][J`gooooo000;ooooo`Oo8B4Q1oll?3`7of=SH`OoIFEU1omGEeL7olO7
a`Oo?Shn1_lG5aL5ooooo`OoN7Qh1olM7Ad7o`0000Oo9RHV1omaLG47og=cL`Ood];B1_mPH606oooo
o`Ko1PH61ol>3Ph7oeaLG0OoLg=c1omiNGT7obTY:@Oo:RXZ1_lN7Qh6ooooo`Oo92@T1om6ATH6obDU
9@OoH61P1on:RXX7ojj^[POoOgmo1_lB4Q86ooooo`Oo;Rh^1omBDU87oeUIF@OoEUIF1_la<C47od10
@0Oo0@411_oPh>06ooooo`Oo4A4A1ol71`L7ojb/[0OoeMGE1ol00007ojJVYPKo2@T91_mMGEd6oooo
o`OoATI61olB4Q87oc@d=0OoLg=c1olD51@7odI6APOo=CDe2oooool7ok6a/@Oo00001on5QHD7oc4a
<@OoJf][1olG5aL7oj^[Z`KoJf][3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo1oll?3`7ofEUI@Oo10@4
1ole=CD7ob4Q8@OoHF5Q1omcLg<6odY:BPGooooo1onKVi/7on3Ph0OoQ8B41oo0`<07oeYJFPOo92@T
1ola<C46od=3@`Kooooo1_lE5AD7oaHF5POoNg]k1onGUiL7oi:BTPOo:b/[1ole=CD6oc0`<0Kooooo
1om/K6`7oh:2PPKo=3@d1olW9bL7oahN7POoJFUY1om>CTh6oj:RXPKooooo1on0P807od];B`Oo@d=3
1ola<C46o`X:2POo8B4Q1olg=cL6ol[:bPKooooo1om>CTh7oj^[Z`Oo_kno1ol];Bd7oa<C4`Oo>c/k
1_n6QXH6obTY:@Kooooo1omgMgL7ofEUI@Oo>SXj1ol/;2`7om3@d0Oo;Bd]1om>CTh6ofATI0Gooooo
1ol;2`/7ob/[:`OoOgmo1onh^;P7oo?cl`Oo?Cdm1olT92@6oa8B4Pgooooo000;ooooo`Oo?3`l1omU
IFD7o`@410Oo=CDe1olQ8B47of5QH@OoLg=c1_m:BTX5ooooo`OoVi^K1ooPh>07ohB4Q0Oo`<301omJ
FUX7ob@T90Oo<C4a1_m3@d<6ooooo`Ko5ADE1olF5QH7og]kN`OoUiNG1onBTY87ob/[:`Oo=CDe1_l`
<306ooooo`OoK6a/1on2PX86oc@d=0Oo9bLW1olN7Qh7ofUYJ@OoCTi>1_nRXZ86ooooo`OoP8201om;
Bd/7od=3@`Oo<C4a1_l:2PX7ob4Q8@Oo=cLg1_o:b/X6ooooo`OoCTi>1on[Zj/7okno_`Oo;Bd]1olC
4a<7oc/k>`KoQXJ61_lY:BT6ooooo`OoMgMg1omUIFD7ocXj>POo;2`/1oo@d=07obd];@OoCTi>1_mT
I6@5ooooo`Oo2`/;1ol[:b/7ogmoO`Oo^;Rh1ooclo<7ocdm?@Oo92@T1_lB4Q8=ooooo`002oooool7
oc`l?0OoIFEU1ol410@7ocDe=@Oo8B4Q1omQHF47og=cL`KoBTY:1Oooool7oi^KV`Ooh>3P1on4Q8@7
ol30`0OoFUYJ1olT92@7oc4a<@Ko@d=31_ooool6oaDE5@Oo5QHF1omkNg/7oiNGU`OoTY:B1ol[:b/7
ocDe=@Ko<30`1_ooool7ofa/K0OoPX:21_ld=3@7obLW9`Oo7QhN1omYJFT7odi>CPKoXZ:R1_ooool7
oh20P0OoBd];1om3@d<7oc4a<@Ko2PX:1olQ8B47ocLg=`Kob/[:1_ooool7odi>CPOoZj^[1ono_kl7
obd];@Oo4a<C1olk>c/6ohJ6QPKo:BTY1_ooool7ogMgM`OoIFEU1olj>SX7ob`/;0Ood=3@1ol];Bd7
odi>CPKoI6AT1Oooool7o`/;2`Oo:b/[1omoOgl7okRh^0Oolo?c1olm?Cd7ob@T90Ko4Q8B3Oooool0
00_ooooo1oll?3`7ofEUI@Oo10@41ole=CD7ob4Q8@OoHF5Q1omcLg<6odY:BPGooooo1onKVi/7on3P
h0OoQ8B41oo0`<07oeYJFPOo92@T1ola<C46od=3@`Kooooo1_lE5AD7oaHF5POoNg]k1onGUiL7oi:B
TPOo:b/[1ole=CD6oc0`<0Kooooo1om/K6`7oh:2PPKo=3@d1olW9bL7oahN7POoJFUY1om>CTh6oj:R
XPKooooo1on0P807od];B`Oo@d=31ola<C46o`X:2POo8B4Q1olg=cL6ol[:bPKooooo1om>CTh7oj^[
Z`Oo_kno1ol];Bd7oa<C4`Oo>c/k1_n6QXH6obTY:@Kooooo1omgMgL7ofEUI@Oo>SXj1ol/;2`7om3@
d0Oo;Bd]1om>CTh6ofATI0Gooooo1ol;2`/7ob/[:`OoOgmo1onh^;P7oo?cl`Oo?Cdm1olT92@6oa8B
4Pgooooo000;ooooo`Oo?3`l1omUIFD7o`@410Oo=CDe1olQ8B47of5QH@OoLg=c1_m:BTX5ooooo`Oo
Vi^K1ooPh>07ohB4Q0Oo`<301omJFUX7ob@T90Oo<C4a1_m3@d<6ooooo`Ko5ADE1olF5QH7og]kN`Oo
UiNG1onBTY87ob/[:`Oo=CDe1_l`<306ooooo`OoK6a/1on2PX86oc@d=0Oo9bLW1olN7Qh7ofUYJ@Oo
CTi>1_nRXZ86ooooo`OoP8201om;Bd/7od=3@`Oo<C4a1_l:2PX7ob4Q8@Oo=cLg1_o:b/X6ooooo`Oo
CTi>1on[Zj/7okno_`Oo;Bd]1olC4a<7oc/k>`KoQXJ61_lY:BT6ooooo`OoMgMg1omUIFD7ocXj>POo
;2`/1oo@d=07obd];@OoCTi>1_mTI6@5ooooo`Oo2`/;1ol[:b/7ogmoO`Oo^;Rh1ooclo<7ocdm?@Oo
92@T1_lB4Q8=ooooo`002oooool7oc`l?0OoIFEU1ol410@7ocDe=@Oo8B4Q1omQHF47og=cL`KoBTY:
1Oooool7oi^KV`Ooh>3P1on4Q8@7ol30`0OoFUYJ1olT92@7oc4a<@Ko@d=31_ooool6oaDE5@Oo5QHF
1omkNg/7oiNGU`OoTY:B1ol[:b/7ocDe=@Ko<30`1_ooool7ofa/K0OoPX:21_ld=3@7obLW9`Oo7QhN
1omYJFT7odi>CPKoXZ:R1_ooool7oh20P0OoBd];1om3@d<7oc4a<@Ko2PX:1olQ8B47ocLg=`Kob/[:
1_ooool7odi>CPOoZj^[1ono_kl7obd];@Oo4a<C1olk>c/6ohJ6QPKo:BTY1_ooool7ogMgM`OoIFEU
1olj>SX7ob`/;0Ood=3@1ol];Bd7odi>CPKoI6AT1Oooool7o`/;2`Oo:b/[1omoOgl7okRh^0Oolo?c
1olm?Cd7ob@T90Ko4Q8B3Oooool000_ooooo1oll?3`7ofEUI@Oo10@41ole=CD7ob4Q8@OoHF5Q1omc
Lg<6odY:BPGooooo1onKVi/7on3Ph0OoQ8B41oo0`<07oeYJFPOo92@T1ola<C46od=3@`Kooooo1_lE
5AD7oaHF5POoNg]k1onGUiL7oi:BTPOo:b/[1ole=CD6oc0`<0Kooooo1om/K6`7oh:2PPKo=3@d1olW
9bL7oahN7POoJFUY1om>CTh6oj:RXPKooooo1on0P807od];B`Oo@d=31ola<C46o`X:2POo8B4Q1olg
=cL6ol[:bPKooooo1om>CTh7oj^[Z`Oo_kno1ol];Bd7oa<C4`Oo>c/k1_n6QXH6obTY:@Kooooo1omg
MgL7ofEUI@Oo>SXj1ol/;2`7om3@d0Oo;Bd]1om>CTh6ofATI0Gooooo1ol;2`/7ob/[:`OoOgmo1onh
^;P7oo?cl`Oo?Cdm1olT92@6oa8B4Pgooooo000;ooooo`Oo5QHF1omCDe<7o`0000OoHF5Q1ol<30`7
oe]KF`OoSXj>1_l/;2`5ooooo`OoVi^K1ooRh^87og]kN`Oo/;2`1omGEeL7oa4A4@Oo7QhN1_lk>c/6
ooooo`Ko8B4Q1onIVIT7ok>c/`Oo^KVi1olj>SX7oaPH60Oo4A4A1_nn_[h6ooooo`OoLG5a1omVIVH6
ob@T90Oo61PH1on1PH47ogMgM`OoShn?1_l820P6ooooo`OoNWYj1olg=cL7odm?C`Oo>3Ph1_l820P7
oaTI6@Oo:BTY1_oFe]H6ooooo`Oo>3Ph1oo9bLT7olo?c`OoI6AT1ol=3@d7oe5AD@Ko`<301_lo?cl6
ooooo`OoNWYj1on1PH47ob`/;0Oo9BDU1ooQhN47oaDE5@OoBDU91_m_Kfl5ooooo`Oo3@d=1ola<C47
ogIfMPOob<S81oogmoL7oaPH60Oo8R8R1_lB4Q8=ooooo`002oooool7oaHF5POoDe=C1ol00007of5Q
H@Oo30`<1omKFe/7ohj>SPKo;2`/1Oooool7oi^KV`Ooh^;R1omkNg/7ok2`/0OoEeMG1olA4A47oahN
7PKo>c/k1_ooool6ob4Q8@OoVIVI1onc/k<7okVi^@Oo>SXj1olH61P7oa4A4@Ko_[jn1_ooool7og5a
L@OoIVIV1_lT92@7oaPH60OoPH611omgMgL7ohn?S`Ko20P81_ooool7ogYjNPOo=cLg1om?Cdl7ocPh
>0Ko20P81olI6AT7obTY:@Koe]KF1_ooool7ocPh>0OobLW91oo?cll7ofATI0Oo3@d=1omADE46ol30
`0Ko?clo1_ooool7ogYjNPOoPH611ol/;2`7obDU9@OohN7Q1olE5AD7odU9B@KoKfm_1Oooool7o`d=
3@Oo<C4a1omfMWH7olS8b0OomoOg1olH61P7ob8R8PKo4Q8B3Oooool000_ooooo1olF5QH7oe=CD`Oo
00001omQHF47o``<30OoFe]K1on>SXh6ob`/;0Gooooo1onKVi/7on;RhPOoNg]k1on`/;07oeMGE`Oo
4A4A1olN7Qh6oc/k>`Kooooo1_lQ8B47oiVIV@Oo/k>c1oni^KT7ocXj>POo61PH1olA4A46okjn_PKo
oooo1omaLG47ofIVIPKo92@T1olH61P7oh61P@OoMgMg1on?Shl6o`P820Kooooo1omjNWX7ocLg=`Oo
Cdm?1olh>3P6o`P820Oo6ATI1olY:BT6omKFePKooooo1olh>3P7olW9b@Ooclo?1omTI6@7o`d=3@Oo
DE5A1_o0`<06oclo?`Kooooo1omjNWX7oh61P@Oo;2`/1olU9BD7on7Qh@Oo5ADE1om9BDT6ofm_K`Go
oooo1ol=3@d7oc4a<@OoMWIf1oo8b<P7ooOgm`Oo61PH1olR8R86oa8B4Pgooooo000;ooooo`Oo5QHF
1omCDe<7o`0000OoHF5Q1ol<30`7oe]KF`OoSXj>1_l/;2`5ooooo`OoVi^K1ooRh^87og]kN`Oo/;2`
1omGEeL7oa4A4@Oo7QhN1_lk>c/6ooooo`Ko8B4Q1onIVIT7ok>c/`Oo^KVi1olj>SX7oaPH60Oo4A4A
1_nn_[h6ooooo`OoLG5a1omVIVH6ob@T90Oo61PH1on1PH47ogMgM`OoShn?1_l820P6ooooo`OoNWYj
1olg=cL7odm?C`Oo>3Ph1_l820P7oaTI6@Oo:BTY1_oFe]H6ooooo`Oo>3Ph1oo9bLT7olo?c`OoI6AT
1ol=3@d7oe5AD@Ko`<301_lo?cl6ooooo`OoNWYj1on1PH47ob`/;0Oo9BDU1ooQhN47oaDE5@OoBDU9
1_m_Kfl5ooooo`Oo3@d=1ola<C47ogIfMPOob<S81oogmoL7oaPH60Oo8R8R1_lB4Q8=ooooo`002ooo
ool7oaHF5POoDe=C1ol00007of5QH@Oo30`<1omKFe/7ohj>SPKo;2`/1Oooool7oi^KV`Ooh^;R1omk
Ng/7ok2`/0OoEeMG1olA4A47oahN7PKo>c/k1_ooool6ob4Q8@OoVIVI1onc/k<7okVi^@Oo>SXj1olH
61P7oa4A4@Ko_[jn1_ooool7og5aL@OoIVIV1_lT92@7oaPH60OoPH611omgMgL7ohn?S`Ko20P81_oo
ool7ogYjNPOo=cLg1om?Cdl7ocPh>0Ko20P81olI6AT7obTY:@Koe]KF1_ooool7ocPh>0OobLW91oo?
cll7ofATI0Oo3@d=1omADE46ol30`0Ko?clo1_ooool7ogYjNPOoPH611ol/;2`7obDU9@OohN7Q1olE
5AD7odU9B@KoKfm_1Oooool7o`d=3@Oo<C4a1omfMWH7olS8b0OomoOg1olH61P7ob8R8PKo4Q8B3Ooo
ool000_ooooo1olF5QH7oe=CD`Oo00001omQHF47o``<30OoFe]K1on>SXh6ob`/;0Gooooo1onKVi/7
on;RhPOoNg]k1on`/;07oeMGE`Oo4A4A1olN7Qh6oc/k>`Kooooo1_lQ8B47oiVIV@Oo/k>c1oni^KT7
ocXj>POo61PH1olA4A46okjn_PKooooo1omaLG47ofIVIPKo92@T1olH61P7oh61P@OoMgMg1on?Shl6
o`P820Kooooo1omjNWX7ocLg=`OoCdm?1olh>3P6o`P820Oo6ATI1olY:BT6omKFePKooooo1olh>3P7
olW9b@Ooclo?1omTI6@7o`d=3@OoDE5A1_o0`<06oclo?`Kooooo1omjNWX7oh61P@Oo;2`/1olU9BD7
on7Qh@Oo5ADE1om9BDT6ofm_K`Gooooo1ol=3@d7oc4a<@OoMWIf1oo8b<P7ooOgm`Oo61PH1olR8R86
oa8B4Pgooooo000;ooooo`Oo5QHF1omCDe<7o`0000OoHF5Q1ol<30`7oe]KF`OoSXj>1_l/;2`5oooo
o`OoVi^K1ooRh^87og]kN`Oo/;2`1omGEeL7oa4A4@Oo7QhN1_lk>c/6ooooo`Ko8B4Q1onIVIT7ok>c
/`Oo^KVi1olj>SX7oaPH60Oo4A4A1_nn_[h6ooooo`OoLG5a1omVIVH6ob@T90Oo61PH1on1PH47ogMg
M`OoShn?1_l820P6ooooo`OoNWYj1olg=cL7odm?C`Oo>3Ph1_l820P7oaTI6@Oo:BTY1_oFe]H6oooo
o`Oo>3Ph1oo9bLT7olo?c`OoI6AT1ol=3@d7oe5AD@Ko`<301_lo?cl6ooooo`OoNWYj1on1PH47ob`/
;0Oo9BDU1ooQhN47oaDE5@OoBDU91_m_Kfl5ooooo`Oo3@d=1ola<C47ogIfMPOob<S81oogmoL7oaPH
60Oo8R8R1_lB4Q8=ooooo`002oooool7ob8R8POoRXZ:1olC4a<7odi>CPOo92@T1omIFET7oeIFEPKo
=cLg1Oooool7oj^[Z`Oooooo1omiNGT7olW9b@OoB4Q81olN7Qh7oa`L70KoB4Q81_ooool6oa/K6`Oo
:b/[1onYZJT7ojRXZ0OoNg]k1olI6AT7oh61P@Ko820P1_ooool7ogMgM`OoFe]K1_lR8R87odI6APOo
51@D1omXJ6P7oeiNGPKoiNGU1_ooool7ogMgM`Oo@T921omCDe<7obXZ:PKo0@411olF5QH7obHV9PKo
fm_K1_ooool7ofMWI`Oo/;2`1ona/K47o`L71`Oo4Q8B1olm?Cd6ok6a/@Ko;Bd]1_ooool>ofa/K0Oo
:RXZ1olK6a/7oo?cl`Oo8B4Q1omIFET6ofATI0Gooooo1ol820P7od51@@OoWinO1ooTi>@7ooooo`Oo
;bl_1ol/;2`6oalO7`gooooo000;ooooo`Oo8R8R1on:RXX7oa<C4`OoCTi>1olT92@7oeUIF@OoEUIF
1_lg=cL5ooooo`OoZj^[1oooool7ogUiN@OobLW91om8B4P7oahN7POo71`L1_m8B4P6ooooo`Ko6a/K
1ol[:b/7ojVYZ@OoZ:RX1omkNg/7oaTI6@OoPH611_lP8206ooooo`OoMgMg1omKFe/6ob8R8POoATI6
1olD51@7ofQXJ0OoGUiN1_oUiND6ooooo`OoMgMg1om2@T87oe=CD`Oo:RXZ1_l10@47oaHF5POo9RHV
1_oKfm/6ooooo`OoIfMW1on`/;07ok6a/@Oo1`L71olB4Q87ocdm?@Ko/K6a1_l];Bd6ooooo`koK6a/
1olZ:RX7oa/K6`Oolo?c1olQ8B47oeUIF@KoI6AT1Oooool7o`P820Oo@D511onOWil7onCTi0Oooooo
1ol_;bl7ob`/;0Ko7alO3Oooool000_ooooo1olR8R87ohZ:RPOo4a<C1om>CTh7ob@T90OoFEUI1omF
EUH6ocLg=`Gooooo1on[Zj/7ooooo`OoNGUi1oo9bLT7odQ8B0Oo7QhN1olL71`6odQ8B0Kooooo1_lK
6a/7ob/[:`OoZJVY1onXZ:P7og]kN`Oo6ATI1on1PH46ob0P80Kooooo1omgMgL7oe]KF`Ko8R8R1om6
ATH7oa@D50OoJ6QX1omNGUh6onGUi@Kooooo1omgMgL7od92@POoDe=C1olZ:RX6o`410@Oo5QHF1olV
9RH6om_Kf`Kooooo1omWIfL7ok2`/0Oo/K6a1ol71`L7oa8B4POo?Cdm1_na/K46obd];@Kooooo3_m/
K6`7obXZ:POo6a/K1ooclo<7ob4Q8@OoFEUI1_mTI6@5ooooo`Oo20P81om1@D47oinOW`Ooi>CT1ooo
ool7obl_;`Oo;2`/1_lO7al=ooooo`002oooool7ob8R8POoRXZ:1olC4a<7odi>CPOo92@T1omIFET7
oeIFEPKo=cLg1Oooool7oj^[Z`Oooooo1omiNGT7olW9b@OoB4Q81olN7Qh7oa`L70KoB4Q81_ooool6
oa/K6`Oo:b/[1onYZJT7ojRXZ0OoNg]k1olI6AT7oh61P@Ko820P1_ooool7ogMgM`OoFe]K1_lR8R87
odI6APOo51@D1omXJ6P7oeiNGPKoiNGU1_ooool7ogMgM`Oo@T921omCDe<7obXZ:PKo0@411olF5QH7
obHV9PKofm_K1_ooool7ofMWI`Oo/;2`1ona/K47o`L71`Oo4Q8B1olm?Cd6ok6a/@Ko;Bd]1_ooool>
ofa/K0Oo:RXZ1olK6a/7oo?cl`Oo8B4Q1omIFET6ofATI0Gooooo1ol820P7od51@@OoWinO1ooTi>@7
ooooo`Oo;bl_1ol/;2`6oalO7`gooooo000;ooooo`Oo8R8R1on:RXX7oa<C4`OoCTi>1olT92@7oeUI
F@OoEUIF1_lg=cL5ooooo`OoZj^[1oooool7ogUiN@OobLW91om8B4P7oahN7POo71`L1_m8B4P6oooo
o`Ko6a/K1ol[:b/7ojVYZ@OoZ:RX1omkNg/7oaTI6@OoPH611_lP8206ooooo`OoMgMg1omKFe/6ob8R
8POoATI61olD51@7ofQXJ0OoGUiN1_oUiND6ooooo`OoMgMg1om2@T87oe=CD`Oo:RXZ1_l10@47oaHF
5POo9RHV1_oKfm/6ooooo`OoIfMW1on`/;07ok6a/@Oo1`L71olB4Q87ocdm?@Ko/K6a1_l];Bd6oooo
o`koK6a/1olZ:RX7oa/K6`Oolo?c1olQ8B47oeUIF@KoI6AT1Oooool7o`P820Oo@D511onOWil7onCT
i0Oooooo1ol_;bl7ob`/;0Ko7alO3Oooool000_ooooo1olR8R87ohZ:RPOo4a<C1om>CTh7ob@T90Oo
FEUI1omFEUH6ocLg=`Gooooo1on[Zj/7ooooo`OoNGUi1oo9bLT7odQ8B0Oo7QhN1olL71`6odQ8B0Ko
oooo1_lK6a/7ob/[:`OoZJVY1onXZ:P7og]kN`Oo6ATI1on1PH46ob0P80Kooooo1omgMgL7oe]KF`Ko
8R8R1om6ATH7oa@D50OoJ6QX1omNGUh6onGUi@Kooooo1omgMgL7od92@POoDe=C1olZ:RX6o`410@Oo
5QHF1olV9RH6om_Kf`Kooooo1omWIfL7ok2`/0Oo/K6a1ol71`L7oa8B4POo?Cdm1_na/K46obd];@Ko
oooo3_m/K6`7obXZ:POo6a/K1ooclo<7ob4Q8@OoFEUI1_mTI6@5ooooo`Oo20P81om1@D47oinOW`Oo
i>CT1oooool7obl_;`Oo;2`/1_lO7al=ooooo`002oooool7ob8R8POoRXZ:1olC4a<7odi>CPOo92@T
1omIFET7oeIFEPKo=cLg1Oooool7oj^[Z`Oooooo1omiNGT7olW9b@OoB4Q81olN7Qh7oa`L70KoB4Q8
1_ooool6oa/K6`Oo:b/[1onYZJT7ojRXZ0OoNg]k1olI6AT7oh61P@Ko820P1_ooool7ogMgM`OoFe]K
1_lR8R87odI6APOo51@D1omXJ6P7oeiNGPKoiNGU1_ooool7ogMgM`Oo@T921omCDe<7obXZ:PKo0@41
1olF5QH7obHV9PKofm_K1_ooool7ofMWI`Oo/;2`1ona/K47o`L71`Oo4Q8B1olm?Cd6ok6a/@Ko;Bd]
1_ooool>ofa/K0Oo:RXZ1olK6a/7oo?cl`Oo8B4Q1omIFET6ofATI0Gooooo1ol820P7od51@@OoWinO
1ooTi>@7ooooo`Oo;bl_1ol/;2`6oalO7`gooooo000;ooooo`Oo4Q8B1onNWYh7o`H61POoLg=c1olC
4a<7oe]KF`OoHV9R1_la<C45ooooo`OoYZJV1ooclo<7ofMWI`OoZj^[1om6ATH7o`820POo4A4A1_m4
A4@6ooooo`Ko=cLg1ooCdm<7ok2`/0OoRHV91olF5QH7obPX:0Oo7AdM1_mfMWH6ooooo`OoJ6QX1omP
H606oa8B4POo4A4A1one]KD7ogalO0OoKfm_1_l@4106ooooo`OoP8201olj>SX7oeADE0Oo:RXZ1_l0
0007o`h>3POo820P1_o0`<06ooooo`OoBDU91oo`l?07okBd]0Oo>c/k1olL71`7of5QH@Koa<C41_lb
<S86ooooo`OoOGem1ombLW87oa/K6`Oo820P1ookno/7o`0000OoE5AD1_mnOWh5ooooo`Oo5QHF1om1
@D47oibLW0Oog]kN1oo[jn/7oa@D50Oo:b/[1_l>3Ph=ooooo`002oooool7oa8B4POoWYjN1ol61PH7
og=cL`Oo4a<C1omKFe/7of9RHPKo<C4a1Oooool7ojJVYPOolo?c1omWIfL7oj^[Z`OoATI61ol20P87
oa4A4@KoA4A41_ooool6ocLg=`Oodm?C1on`/;07ohV9R@Oo5QHF1olX:2P7oadM7@KoMWIf1_ooool7
ofQXJ0OoH61P1_lB4Q87oa4A4@Oo]KFe1omlO7`7ofm_K`Ko410@1_ooool7oh20P0Oo>SXj1omDE5@7
obXZ:PKo00001ol>3Ph7ob0P80Ko`<301_ooool7odU9B@Ool?3`1ond];@7oc/k>`Oo71`L1omQHF46
olC4a0Ko<S8b1_ooool7ogemO@OoLW9b1olK6a/7ob0P80Oono_k1ol00007oeADE0KoOWin1Oooool7
oaHF5POo@D511onLW9`7omkNgPOojn_[1olD51@7ob/[:`Ko3Ph>3Oooool000_ooooo1olB4Q87oijN
WPOo1PH61omcLg<7oa<C4`OoFe]K1omRHV86oc4a<@Gooooo1onVYZH7oo?cl`OoIfMW1on[Zj/7odI6
APOo0P821olA4A46odA4A0Kooooo1_lg=cL7om?Cd`Oo/;2`1on9RHT7oaHF5POo:2PX1olM7Ad6ogIf
MPKooooo1omXJ6P7of1PH0Ko4Q8B1olA4A47okFe]@OoO7al1om_Kfl6oa0@40Kooooo1on0P807ocXj
>POoE5AD1olZ:RX6o`0000Oo3Ph>1olP8206ol30`0Kooooo1om9BDT7oo3`l0Oo];Bd1olk>c/7oa`L
70OoHF5Q1_o4a<@6oc8b<PKooooo1ommOGd7og9bLPOo6a/K1olP8207oo_kn`Oo00001omDE5@6ogin
OPGooooo1olF5QH7od51@@OoW9bL1ooNg]h7on_[j`Oo51@D1ol[:b/6o`h>3Pgooooo000;ooooo`Oo
4Q8B1onNWYh7o`H61POoLg=c1olC4a<7oe]KF`OoHV9R1_la<C45ooooo`OoYZJV1ooclo<7ofMWI`Oo
Zj^[1om6ATH7o`820POo4A4A1_m4A4@6ooooo`Ko=cLg1ooCdm<7ok2`/0OoRHV91olF5QH7obPX:0Oo
7AdM1_mfMWH6ooooo`OoJ6QX1omPH606oa8B4POo4A4A1one]KD7ogalO0OoKfm_1_l@4106ooooo`Oo
P8201olj>SX7oeADE0Oo:RXZ1_l00007o`h>3POo820P1_o0`<06ooooo`OoBDU91oo`l?07okBd]0Oo
>c/k1olL71`7of5QH@Koa<C41_lb<S86ooooo`OoOGem1ombLW87oa/K6`Oo820P1ookno/7o`0000Oo
E5AD1_mnOWh5ooooo`Oo5QHF1om1@D47oibLW0Oog]kN1oo[jn/7oa@D50Oo:b/[1_l>3Ph=ooooo`00
2oooool7oa8B4POoWYjN1ol61PH7og=cL`Oo4a<C1omKFe/7of9RHPKo<C4a1Oooool7ojJVYPOolo?c
1omWIfL7oj^[Z`OoATI61ol20P87oa4A4@KoA4A41_ooool6ocLg=`Oodm?C1on`/;07ohV9R@Oo5QHF
1olX:2P7oadM7@KoMWIf1_ooool7ofQXJ0OoH61P1_lB4Q87oa4A4@Oo]KFe1omlO7`7ofm_K`Ko410@
1_ooool7oh20P0Oo>SXj1omDE5@7obXZ:PKo00001ol>3Ph7ob0P80Ko`<301_ooool7odU9B@Ool?3`
1ond];@7oc/k>`Oo71`L1omQHF46olC4a0Ko<S8b1_ooool7ogemO@OoLW9b1olK6a/7ob0P80Oono_k
1ol00007oeADE0KoOWin1Oooool7oaHF5POo@D511onLW9`7omkNgPOojn_[1olD51@7ob/[:`Ko3Ph>
3Oooool000_ooooo1olB4Q87oijNWPOo1PH61omcLg<7oa<C4`OoFe]K1omRHV86oc4a<@Gooooo1onV
YZH7oo?cl`OoIfMW1on[Zj/7odI6APOo0P821olA4A46odA4A0Kooooo1_lg=cL7om?Cd`Oo/;2`1on9
RHT7oaHF5POo:2PX1olM7Ad6ogIfMPKooooo1omXJ6P7of1PH0Ko4Q8B1olA4A47okFe]@OoO7al1om_
Kfl6oa0@40Kooooo1on0P807ocXj>POoE5AD1olZ:RX6o`0000Oo3Ph>1olP8206ol30`0Kooooo1om9
BDT7oo3`l0Oo];Bd1olk>c/7oa`L70OoHF5Q1_o4a<@6oc8b<PKooooo1ommOGd7og9bLPOo6a/K1olP
8207oo_kn`Oo00001omDE5@6oginOPGooooo1olF5QH7od51@@OoW9bL1ooNg]h7on_[j`Oo51@D1ol[
:b/6o`h>3Pgooooo000;ooooo`Oo6ATI1oo9bLT7odA4A0OoSHf=1ol^;Rh7oda<C0Oo?3`l1_lc<c<5
ooooo`Oo_[jn1oolo?`7of9RHPOoaLG51old=3@7oa8B4POo5QHF1_mCDe<6ooooo`Ko;2`/1om<C4`7
okjn_POoUIFE1om9BDT7obDU9@OoalO71_lS8b<6ooooo`OoNWYj1ol[:b/6oalO7`OoE5AD1olJ6QX7
ofQXJ0OoHV9R3?ooool7ogemO@ko@D511olW9bL6o`h>3POo6QXJ1ol/;2`<ooooo`OoLW9b1on[Zj/7
oiJFUPOo00001olE5AD7oe=CD`Kodm?C1_m>CTh6ooooo`OoKfm_1omKFe/7ob@T90Oo6a/K1oooool7
oaDE5@OoDe=C1_mMGEd5ooooo`Oo5aLG1omMGEd7okFe]@kohn?S1olQ8B47ob`/;0Ko92@T3Oooool0
00_ooooo1olI6AT7olW9b@OoA4A41on=SHd7obh^;POoC4a<1oll?3`6oc<c<`Gooooo1onn_[h7oocl
o0OoHV9R1oo5aLD7oc@d=0Oo4Q8B1olF5QH6oe=CD`Kooooo1_l/;2`7oda<C0Oo_[jn1onEUID7odU9
B@Oo9BDU1oo7alL6ob<S8`Kooooo1omjNWX7ob/[:`Ko7alO1omDE5@7oaXJ6POoJ6QX1omRHV8<oooo
o`OoOGem3_m1@D47obLW9`Ko3Ph>1olJ6QX7ob`/;0cooooo1ombLW87oj^[Z`OoUYJF1ol00007oaDE
5@OoDe=C1_oCdm<6odi>CPKooooo1om_Kfl7oe]KF`Oo92@T1olK6a/7ooooo`Oo5ADE1omCDe<6oeeM
G@Gooooo1olG5aL7oeeMG@Oo]KFe3_oShn<7ob4Q8@Oo;2`/1_lT92@=ooooo`002oooool7oaTI6@Oo
bLW91om4A4@7ohf=S@Oo;Rh^1om<C4`7oc`l?0Ko<c<c1Oooool7okjn_POoo?cl1omRHV87olG5a@Oo
=3@d1olB4Q87oaHF5PKoDe=C1_ooool6ob`/;0OoC4a<1onn_[h7oiFEU@OoBDU91olU9BD7olO7a`Ko
8b<S1_ooool7ogYjNPOo:b/[1_lO7al7oeADE0Oo6QXJ1omXJ6P7of9RHPcooooo1ommOGd>od51@@Oo
9bLW1_l>3Ph7oaXJ6POo;2`/3?ooool7og9bLPOoZj^[1onFUYH7o`0000Oo5ADE1omCDe<6om?Cd`Ko
CTi>1_ooool7ofm_K`OoFe]K1olT92@7oa/K6`Oooooo1olE5AD7oe=CD`KoGEeM1Oooool7oaLG5`Oo
GEeM1one]KD>on?Sh`Oo8B4Q1ol/;2`6ob@T90gooooo000;ooooo`Oo6ATI1oo9bLT7odA4A0OoSHf=
1ol^;Rh7oda<C0Oo?3`l1_lc<c<5ooooo`Oo_[jn1oolo?`7of9RHPOoaLG51old=3@7oa8B4POo5QHF
1_mCDe<6ooooo`Ko;2`/1om<C4`7okjn_POoUIFE1om9BDT7obDU9@OoalO71_lS8b<6ooooo`OoNWYj
1ol[:b/6oalO7`OoE5AD1olJ6QX7ofQXJ0OoHV9R3?ooool7ogemO@ko@D511olW9bL6o`h>3POo6QXJ
1ol/;2`<ooooo`OoLW9b1on[Zj/7oiJFUPOo00001olE5AD7oe=CD`Kodm?C1_m>CTh6ooooo`OoKfm_
1omKFe/7ob@T90Oo6a/K1oooool7oaDE5@OoDe=C1_mMGEd5ooooo`Oo5aLG1omMGEd7okFe]@kohn?S
1olQ8B47ob`/;0Ko92@T3Oooool000_ooooo1olI6AT7olW9b@OoA4A41on=SHd7obh^;POoC4a<1oll
?3`6oc<c<`Gooooo1onn_[h7ooclo0OoHV9R1oo5aLD7oc@d=0Oo4Q8B1olF5QH6oe=CD`Kooooo1_l/
;2`7oda<C0Oo_[jn1onEUID7odU9B@Oo9BDU1oo7alL6ob<S8`Kooooo1omjNWX7ob/[:`Ko7alO1omD
E5@7oaXJ6POoJ6QX1omRHV8<ooooo`OoOGem3_m1@D47obLW9`Ko3Ph>1olJ6QX7ob`/;0cooooo1omb
LW87oj^[Z`OoUYJF1ol00007oaDE5@OoDe=C1_oCdm<6odi>CPKooooo1om_Kfl7oe]KF`Oo92@T1olK
6a/7ooooo`Oo5ADE1omCDe<6oeeMG@Gooooo1olG5aL7oeeMG@Oo]KFe3_oShn<7ob4Q8@Oo;2`/1_lT
92@=ooooo`002oooool7oaTI6@OobLW91om4A4@7ohf=S@Oo;Rh^1om<C4`7oc`l?0Ko<c<c1Oooool7
okjn_POoo?cl1omRHV87olG5a@Oo=3@d1olB4Q87oaHF5PKoDe=C1_ooool6ob`/;0OoC4a<1onn_[h7
oiFEU@OoBDU91olU9BD7olO7a`Ko8b<S1_ooool7ogYjNPOo:b/[1_lO7al7oeADE0Oo6QXJ1omXJ6P7
of9RHPcooooo1ommOGd>od51@@Oo9bLW1_l>3Ph7oaXJ6POo;2`/3?ooool7og9bLPOoZj^[1onFUYH7
o`0000Oo5ADE1omCDe<6om?Cd`KoCTi>1_ooool7ofm_K`OoFe]K1olT92@7oa/K6`Oooooo1olE5AD7
oe=CD`KoGEeM1Oooool7oaLG5`OoGEeM1one]KD>on?Sh`Oo8B4Q1ol/;2`6ob@T90gooooo000;oooo
o`Oo6ATI1oo9bLT7odA4A0OoSHf=1ol^;Rh7oda<C0Oo?3`l1_lc<c<5ooooo`Oo_[jn1oolo?`7of9R
HPOoaLG51old=3@7oa8B4POo5QHF1_mCDe<6ooooo`Ko;2`/1om<C4`7okjn_POoUIFE1om9BDT7obDU
9@OoalO71_lS8b<6ooooo`OoNWYj1ol[:b/6oalO7`OoE5AD1olJ6QX7ofQXJ0OoHV9R3?ooool7ogem
O@ko@D511olW9bL6o`h>3POo6QXJ1ol/;2`<ooooo`OoLW9b1on[Zj/7oiJFUPOo00001olE5AD7oe=C
D`Kodm?C1_m>CTh6ooooo`OoKfm_1omKFe/7ob@T90Oo6a/K1oooool7oaDE5@OoDe=C1_mMGEd5oooo
o`Oo5aLG1omMGEd7okFe]@kohn?S1olQ8B47ob`/;0Ko92@T3Oooool000_ooooo1olR8R87ooooo`Oo
?3`l1onYZJT7oa@D50OoDE5A1olg=cL6ocDe=@Gooooo1onh^;P7on?Sh`OoCTi>1on][Jd7ob/[:`Oo
0@411olL71`6odA4A0Kooooo1_mYJFT7onWYj@OoYZJV1omCDe<7o`0000Oo<c<c1ol[:b/6ob`/;0Ko
oooo1omEEED7oeUIF@Ko00001olP8207olS8b0OoNWYj1om5ADD6ob4Q8@Kooooo1on@T907oc/k>`Oo
@d=31olM7Ad6o`410@Oo51@D1ol^;Rh6om7Ad@Kooooo1omXJ6P7ooooo`OoVi^K1olQ8B47oeEEE@Oo
P8201_nc/k<6obh^;PKooooo1omlO7`7oe=CD`Oo51@D1olZ:RX7ooKfmPOo2@T91omCDe<6ofYZJPGo
oooo1olZ:RX7oeMGE`Oo[:b/1oo;bl/7okbl_0Oo20P81olT92@6oaDE5@gooooo000;ooooo`Oo8R8R
1oooool7oc`l?0OoZJVY1olD51@7oe5AD@Oo=cLg1_le=CD5ooooo`Oo^;Rh1ooShn<7odi>CPOo[Jf]
1ol[:b/7o`410@Oo71`L1_m4A4@6ooooo`KoJFUY1ooYjNT7ojJVYPOoDe=C1ol00007oc<c<`Oo:b/[
1_l/;2`6ooooo`OoEEEE1omIFET6o`0000Oo820P1oo8b<P7ogYjNPOoADE51_lQ8B46ooooo`OoT92@
1olk>c/7od=3@`Oo7AdM1_l10@47oa@D50Oo;Rh^1_oAdM46ooooo`OoJ6QX1oooool7oi^KV`Oo8B4Q
1omEEED7oh20P0Ko/k>c1_l^;Rh6ooooo`OoO7al1omCDe<7oa@D50Oo:RXZ1oofm_H7o`T92@OoDe=C
1_mZJVX5ooooo`Oo:RXZ1omGEeL7ojb/[0Oobl_;1onl_;`7o`P820Oo92@T1_lE5AD=ooooo`002ooo
ool7ob8R8POooooo1oll?3`7ojVYZ@Oo51@D1omADE47ocLg=`Ko=CDe1Oooool7okRh^0Oohn?S1om>
CTh7ojf][@Oo:b/[1ol10@47oa`L70KoA4A41_ooool6ofUYJ@OojNWY1onVYZH7oe=CD`Oo00001olc
<c<7ob/[:`Ko;2`/1_ooool7oeEEE@OoFEUI1_l00007ob0P80Oob<S81omjNWX7odE5A@Ko8B4Q1_oo
ool7oi2@T0Oo>c/k1om3@d<7oadM7@Ko0@411olD51@7obh^;PKodM7A1_ooool7ofQXJ0Oooooo1onK
Vi/7ob4Q8@OoEEEE1on0P806ok>c/`Ko;Rh^1_ooool7ogalO0OoDe=C1olD51@7obXZ:POom_Kf1ol9
2@T7oe=CD`KoJVYZ1Oooool7obXZ:POoEeMG1on/[:`7ol_;b`Oo_;bl1ol820P7ob@T90Ko5ADE3Ooo
ool000_ooooo1olR8R87ooooo`Oo?3`l1onYZJT7oa@D50OoDE5A1olg=cL6ocDe=@Gooooo1onh^;P7
on?Sh`OoCTi>1on][Jd7ob/[:`Oo0@411olL71`6odA4A0Kooooo1_mYJFT7onWYj@OoYZJV1omCDe<7
o`0000Oo<c<c1ol[:b/6ob`/;0Kooooo1omEEED7oeUIF@Ko00001olP8207olS8b0OoNWYj1om5ADD6
ob4Q8@Kooooo1on@T907oc/k>`Oo@d=31olM7Ad6o`410@Oo51@D1ol^;Rh6om7Ad@Kooooo1omXJ6P7
ooooo`OoVi^K1olQ8B47oeEEE@OoP8201_nc/k<6obh^;PKooooo1omlO7`7oe=CD`Oo51@D1olZ:RX7
ooKfmPOo2@T91omCDe<6ofYZJPGooooo1olZ:RX7oeMGE`Oo[:b/1oo;bl/7okbl_0Oo20P81olT92@6
oaDE5@gooooo000;ooooo`Oo8R8R1oooool7oc`l?0OoZJVY1olD51@7oe5AD@Oo=cLg1_le=CD5oooo
o`Oo^;Rh1ooShn<7odi>CPOo[Jf]1ol[:b/7o`410@Oo71`L1_m4A4@6ooooo`KoJFUY1ooYjNT7ojJV
YPOoDe=C1ol00007oc<c<`Oo:b/[1_l/;2`6ooooo`OoEEEE1omIFET6o`0000Oo820P1oo8b<P7ogYj
NPOoADE51_lQ8B46ooooo`OoT92@1olk>c/7od=3@`Oo7AdM1_l10@47oa@D50Oo;Rh^1_oAdM46oooo
o`OoJ6QX1oooool7oi^KV`Oo8B4Q1omEEED7oh20P0Ko/k>c1_l^;Rh6ooooo`OoO7al1omCDe<7oa@D
50Oo:RXZ1oofm_H7o`T92@OoDe=C1_mZJVX5ooooo`Oo:RXZ1omGEeL7ojb/[0Oobl_;1onl_;`7o`P8
20Oo92@T1_lE5AD=ooooo`002oooool7ob8R8POooooo1oll?3`7ojVYZ@Oo51@D1omADE47ocLg=`Ko
=CDe1Oooool7okRh^0Oohn?S1om>CTh7ojf][@Oo:b/[1ol10@47oa`L70KoA4A41_ooool6ofUYJ@Oo
jNWY1onVYZH7oe=CD`Oo00001olc<c<7ob/[:`Ko;2`/1_ooool7oeEEE@OoFEUI1_l00007ob0P80Oo
b<S81omjNWX7odE5A@Ko8B4Q1_ooool7oi2@T0Oo>c/k1om3@d<7oadM7@Ko0@411olD51@7obh^;PKo
dM7A1_ooool7ofQXJ0Oooooo1onKVi/7ob4Q8@OoEEEE1on0P806ok>c/`Ko;Rh^1_ooool7ogalO0Oo
De=C1olD51@7obXZ:POom_Kf1ol92@T7oe=CD`KoJVYZ1Oooool7obXZ:POoEeMG1on/[:`7ol_;b`Oo
_;bl1ol820P7ob@T90Ko5ADE3Oooool000_ooooo1olR8R87ooooo`Oo?3`l1onYZJT7oa@D50OoDE5A
1olg=cL6ocDe=@Gooooo1onh^;P7on?Sh`OoCTi>1on][Jd7ob/[:`Oo0@411olL71`6odA4A0Kooooo
1_mYJFT7onWYj@OoYZJV1omCDe<7o`0000Oo<c<c1ol[:b/6ob`/;0Kooooo1omEEED7oeUIF@Ko0000
1olP8207olS8b0OoNWYj1om5ADD6ob4Q8@Kooooo1on@T907oc/k>`Oo@d=31olM7Ad6o`410@Oo51@D
1ol^;Rh6om7Ad@Kooooo1omXJ6P7ooooo`OoVi^K1olQ8B47oeEEE@OoP8201_nc/k<6obh^;PKooooo
1omlO7`7oe=CD`Oo51@D1olZ:RX7ooKfmPOo2@T91omCDe<6ofYZJPGooooo1olZ:RX7oeMGE`Oo[:b/
1oo;bl/7okbl_0Oo20P81olT92@6oaDE5@gooooo000;ooooo`Oo;2`/1oohn?P7oe1@D0Oo][Jf1olV
9RH7od92@POo?Shn1_ld=3@5ooooo`OoaLG51ooRh^87odY:BPOo^k^k1olS8b<7o`h>3POo7AdM1_m;
Bd/6ooooo`Ko?Shn1ombLW87okZj^POoMGEe1olL71`7odM7A`OoiNGU1_lS8b<6ooooo`OoIFEU1ol:
2PX6obHV9POoE5AD1olc<c<7oeeMG@OoHV9R1_oMgMd6ooooo`OoLW9b1olj>SX7oc/k>`Oo;Bd]1_lL
71`7ob8R8POo:BTY1_nm_Kd6ooooo`OoRHV91on[Zj/7og9bLPOo4Q8B1ol^;Rh7ogMgM`Koc/k>1_mZ
JVX6ooooo`OoM7Ad1om3@d<7oa/K6`Oo9bLW1ooPh>07oaHF5POoEUIF1_mADE45ooooo`Oo8R8R1om/
K6`7okBd]0Oo`L711onJVYX7oa0@40go9bLW3Oooool000_ooooo1ol/;2`7ooShn0OoD51@1onf][H7
obHV9POo@T921oln?Sh6oc@d=0Gooooo1oo5aLD7on;RhPOoBTY:1onk^k/7ob<S8`Oo3Ph>1olM7Ad6
od];B`Kooooo1_ln?Sh7og9bLPOo^[Zj1omeMGD7oa`L70OoAdM71ooUiND6ob<S8`Kooooo1omUIFD7
o`X:2PKo9RHV1omDE5@7oc<c<`OoGEeM1omRHV86omgMg@Kooooo1ombLW87ocXj>POo>c/k1ol];Bd6
oa`L70Oo8R8R1olY:BT6okfm_@Kooooo1on9RHT7oj^[Z`OoLW9b1olB4Q87obh^;POoMgMg1_o>c/h6
ofYZJPKooooo1omdM7@7od=3@`Oo6a/K1olW9bL7on3Ph0Oo5QHF1omFEUH6oe5AD@Gooooo1olR8R87
ofa/K0Oo];Bd1oo1`L47oiZJVPOo410@3OlW9bL=ooooo`002oooool7ob`/;0Oon?Sh1om@D507okJf
]POo9RHV1om2@T87ochn?PKo=3@d1Oooool7olG5a@Ooh^;R1om:BTX7ok^k^`Oo8b<S1ol>3Ph7oadM
7@KoBd];1_ooool6ochn?POoLW9b1onj^[X7ogEeM@Oo71`L1om7AdL7onGUi@Ko8b<S1_ooool7ofEU
I@Oo2PX:1_lV9RH7oeADE0Oo<c<c1omMGEd7of9RHPKogMgM1_ooool7og9bLPOo>SXj1olk>c/7obd]
;@Ko71`L1olR8R87obTY:@Ko_Kfm1_ooool7ohV9R@OoZj^[1ombLW87oa8B4POo;Rh^1omgMgL6olk>
cPKoJVYZ1_ooool7ogAdM0Oo@d=31olK6a/7obLW9`Ooh>3P1olF5QH7oeIFEPKoDE5A1Oooool7ob8R
8POoK6a/1ond];@7ol71`@OoVYZJ1ol@410=obLW9`gooooo000;ooooo`Oo;2`/1oohn?P7oe1@D0Oo
][Jf1olV9RH7od92@POo?Shn1_ld=3@5ooooo`OoaLG51ooRh^87odY:BPOo^k^k1olS8b<7o`h>3POo
7AdM1_m;Bd/6ooooo`Ko?Shn1ombLW87okZj^POoMGEe1olL71`7odM7A`OoiNGU1_lS8b<6ooooo`Oo
IFEU1ol:2PX6obHV9POoE5AD1olc<c<7oeeMG@OoHV9R1_oMgMd6ooooo`OoLW9b1olj>SX7oc/k>`Oo
;Bd]1_lL71`7ob8R8POo:BTY1_nm_Kd6ooooo`OoRHV91on[Zj/7og9bLPOo4Q8B1ol^;Rh7ogMgM`Ko
c/k>1_mZJVX6ooooo`OoM7Ad1om3@d<7oa/K6`Oo9bLW1ooPh>07oaHF5POoEUIF1_mADE45ooooo`Oo
8R8R1om/K6`7okBd]0Oo`L711onJVYX7oa0@40go9bLW3Oooool000_ooooo1ol/;2`7ooShn0OoD51@
1onf][H7obHV9POo@T921oln?Sh6oc@d=0Gooooo1oo5aLD7on;RhPOoBTY:1onk^k/7ob<S8`Oo3Ph>
1olM7Ad6od];B`Kooooo1_ln?Sh7og9bLPOo^[Zj1omeMGD7oa`L70OoAdM71ooUiND6ob<S8`Kooooo
1omUIFD7o`X:2PKo9RHV1omDE5@7oc<c<`OoGEeM1omRHV86omgMg@Kooooo1ombLW87ocXj>POo>c/k
1ol];Bd6oa`L70Oo8R8R1olY:BT6okfm_@Kooooo1on9RHT7oj^[Z`OoLW9b1olB4Q87obh^;POoMgMg
1_o>c/h6ofYZJPKooooo1omdM7@7od=3@`Oo6a/K1olW9bL7on3Ph0Oo5QHF1omFEUH6oe5AD@Gooooo
1olR8R87ofa/K0Oo];Bd1oo1`L47oiZJVPOo410@3OlW9bL=ooooo`002oooool7ob`/;0Oon?Sh1om@
D507okJf]POo9RHV1om2@T87ochn?PKo=3@d1Oooool7olG5a@Ooh^;R1om:BTX7ok^k^`Oo8b<S1ol>
3Ph7oadM7@KoBd];1_ooool6ochn?POoLW9b1onj^[X7ogEeM@Oo71`L1om7AdL7onGUi@Ko8b<S1_oo
ool7ofEUI@Oo2PX:1_lV9RH7oeADE0Oo<c<c1omMGEd7of9RHPKogMgM1_ooool7og9bLPOo>SXj1olk
>c/7obd];@Ko71`L1olR8R87obTY:@Ko_Kfm1_ooool7ohV9R@OoZj^[1ombLW87oa8B4POo;Rh^1omg
MgL6olk>cPKoJVYZ1_ooool7ogAdM0Oo@d=31olK6a/7obLW9`Ooh>3P1olF5QH7oeIFEPKoDE5A1Ooo
ool7ob8R8POoK6a/1ond];@7ol71`@OoVYZJ1ol@410=obLW9`gooooo000;ooooo`Oo:b/[1onj^[X7
ode=C@OoOgmo1olI6AT7oeIFEPOo<c<c1_lZ:RX5ooooo`Oo[jn_1onh^;P7ochn?POoVYZJ1olO7al7
o`0000Oo7AdM1_lm?Cd6ooooo`KoTY:B1oooool7oi6AT@Oo:RXZ1olJ6QX7od=3@`Oo820P1_l/;2`6
ooooo`Oo@D511omIFET6o`<30`Oo:RXZ1ooXj>P7ogemO@Oo:BTY1_lK6a/6ooooo`OoMGEe1oli>CT7
oc/k>`Oo:2PX1_lF5QH7oaPH60Oo<S8b1_nTY:@6ooooo`OoOgmo1oo^k^h7ogQhN0Oo7alO1ombLW87
oj>SX`KoVi^K1_l`<306ooooo`OoIfMW1olk>c/7o`h>3POo9RHV1oo;bl/7o`T92@OoD51@1_mGEeL5
ooooo`Oo9bLW1omXJ6P7oiVIV@OoWYjN1on4Q8@7o`0000Oo7AdM1_lG5aL=ooooo`002oooool7ob/[
:`Oo^[Zj1om=CDd7ogmoO`Oo6ATI1omFEUH7oc<c<`Ko:RXZ1Oooool7ojn_[`Oo^;Rh1oln?Sh7oiZJ
VPOo7alO1ol00007oadM7@Ko?Cdm1_ooool6oi:BTPOooooo1onATI47obXZ:POo6QXJ1om3@d<7ob0P
80Ko;2`/1_ooool7od51@@OoFEUI1_l30`<7obXZ:POoj>SX1ommOGd7obTY:@Ko6a/K1_ooool7ogEe
M@Oo>CTi1olk>c/7obPX:0Ko5QHF1olH61P7oc8b<PKoY:BT1_ooool7ogmoO`Ook^k^1omhN7P7oalO
7`OoLW9b1onSXj<6oi^KV`Ko<30`1_ooool7ofMWI`Oo>c/k1ol>3Ph7obHV9POobl_;1ol92@T7oe1@
D0KoEeMG1Oooool7obLW9`OoJ6QX1onIVIT7oijNWPOoQ8B41ol00007oadM7@Ko5aLG3Oooool000_o
oooo1ol[:b/7okZj^POoCDe=1omoOgl7oaTI6@OoEUIF1olc<c<6obXZ:PGooooo1on_[jl7okRh^0Oo
?Shn1onJVYX7oalO7`Oo00001olM7Ad6ocdm?@Kooooo1_nBTY87ooooo`OoTI6A1olZ:RX7oaXJ6POo
@d=31olP8206ob`/;0Kooooo1om1@D47oeUIF@Ko0`<31olZ:RX7onSXj0OoOGem1olY:BT6oa/K6`Ko
oooo1omeMGD7ocTi>@Oo>c/k1olX:2P6oaHF5POo61PH1olb<S86ojBTY0Kooooo1omoOgl7onk^kPOo
N7Qh1olO7al7og9bLPOoXj>S1_nKVi/6oc0`<0Kooooo1omWIfL7oc/k>`Oo3Ph>1olV9RH7ol_;b`Oo
2@T91om@D506oeMGE`Gooooo1olW9bL7ofQXJ0OoVIVI1onNWYh7ohB4Q0Oo00001olM7Ad6oaLG5`go
oooo000;ooooo`Oo:b/[1onj^[X7ode=C@OoOgmo1olI6AT7oeIFEPOo<c<c1_lZ:RX5ooooo`Oo[jn_
1onh^;P7ochn?POoVYZJ1olO7al7o`0000Oo7AdM1_lm?Cd6ooooo`KoTY:B1oooool7oi6AT@Oo:RXZ
1olJ6QX7od=3@`Oo820P1_l/;2`6ooooo`Oo@D511omIFET6o`<30`Oo:RXZ1ooXj>P7ogemO@Oo:BTY
1_lK6a/6ooooo`OoMGEe1oli>CT7oc/k>`Oo:2PX1_lF5QH7oaPH60Oo<S8b1_nTY:@6ooooo`OoOgmo
1oo^k^h7ogQhN0Oo7alO1ombLW87oj>SX`KoVi^K1_l`<306ooooo`OoIfMW1olk>c/7o`h>3POo9RHV
1oo;bl/7o`T92@OoD51@1_mGEeL5ooooo`Oo9bLW1omXJ6P7oiVIV@OoWYjN1on4Q8@7o`0000Oo7AdM
1_lG5aL=ooooo`002oooool7ob/[:`Oo^[Zj1om=CDd7ogmoO`Oo6ATI1omFEUH7oc<c<`Ko:RXZ1Ooo
ool7ojn_[`Oo^;Rh1oln?Sh7oiZJVPOo7alO1ol00007oadM7@Ko?Cdm1_ooool6oi:BTPOooooo1onA
TI47obXZ:POo6QXJ1om3@d<7ob0P80Ko;2`/1_ooool7od51@@OoFEUI1_l30`<7obXZ:POoj>SX1omm
OGd7obTY:@Ko6a/K1_ooool7ogEeM@Oo>CTi1olk>c/7obPX:0Ko5QHF1olH61P7oc8b<PKoY:BT1_oo
ool7ogmoO`Ook^k^1omhN7P7oalO7`OoLW9b1onSXj<6oi^KV`Ko<30`1_ooool7ofMWI`Oo>c/k1ol>
3Ph7obHV9POobl_;1ol92@T7oe1@D0KoEeMG1Oooool7obLW9`OoJ6QX1onIVIT7oijNWPOoQ8B41ol0
0007oadM7@Ko5aLG3Oooool000_ooooo1ol[:b/7okZj^POoCDe=1omoOgl7oaTI6@OoEUIF1olc<c<6
obXZ:PGooooo1on_[jl7okRh^0Oo?Shn1onJVYX7oalO7`Oo00001olM7Ad6ocdm?@Kooooo1_nBTY87
ooooo`OoTI6A1olZ:RX7oaXJ6POo@d=31olP8206ob`/;0Kooooo1om1@D47oeUIF@Ko0`<31olZ:RX7
onSXj0OoOGem1olY:BT6oa/K6`Kooooo1omeMGD7ocTi>@Oo>c/k1olX:2P6oaHF5POo61PH1olb<S86
ojBTY0Kooooo1omoOgl7onk^kPOoN7Qh1olO7al7og9bLPOoXj>S1_nKVi/6oc0`<0Kooooo1omWIfL7
oc/k>`Oo3Ph>1olV9RH7ol_;b`Oo2@T91om@D506oeMGE`Gooooo1olW9bL7ofQXJ0OoVIVI1onNWYh7
ohB4Q0Oo00001olM7Ad6oaLG5`gooooo000;ooooo`Oo:b/[1onj^[X7ode=C@OoOgmo1olI6AT7oeIF
EPOo<c<c1_lZ:RX5ooooo`Oo[jn_1onh^;P7ochn?POoVYZJ1olO7al7o`0000Oo7AdM1_lm?Cd6oooo
o`KoTY:B1oooool7oi6AT@Oo:RXZ1olJ6QX7od=3@`Oo820P1_l/;2`6ooooo`Oo@D511omIFET6o`<3
0`Oo:RXZ1ooXj>P7ogemO@Oo:BTY1_lK6a/6ooooo`OoMGEe1oli>CT7oc/k>`Oo:2PX1_lF5QH7oaPH
60Oo<S8b1_nTY:@6ooooo`OoOgmo1oo^k^h7ogQhN0Oo7alO1ombLW87oj>SX`KoVi^K1_l`<306oooo
o`OoIfMW1olk>c/7o`h>3POo9RHV1oo;bl/7o`T92@OoD51@1_mGEeL5ooooo`Oo9bLW1omXJ6P7oiVI
V@OoWYjN1on4Q8@7o`0000Oo7AdM1_lG5aL=ooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002ooo
ool7obDU9@Oo8b<S1ol92@T7o`h>3POo=3@d1omMGEd7ojf][@KoS8b<1Oooool7omgMg@OoQHF51on4
Q8@7oaPH60OoATI61olM7Ad7ogIfMPKo9RHV1_ooool6od];B`Oo61PH1olZ:RX7olk>cPOoFEUI1olI
6AT7obDU9@Ko:BTY1_ooool7oaXJ6POoH61P1_n0P807od92@POo9bLW1olj>SX7on3Ph0KoTY:B1_oo
ool7oa0@40ko30`<1olF5QH6oa0@40Oo00001ol92@T6oeQHF0Kooooo1olL71`7odI6APOog=cL1omS
Hf<7ocdm?@OoOWin1_lh>3P6oeQHF0Kooooo1om4A4@7o`T92@Oo30`<1omVIVH7of=SH`Oo<S8b1olQ
8B46ogMgM`Gooooo1ooQhN47obPX:0OoCDe=1olE5AD7oc4a<@Oo@T921omLG5`6oi:BTPgooooo000;
ooooo`Oo9BDU1olS8b<7o`T92@Oo3Ph>1old=3@7oeeMG@Oo[Jf]1_n<S8`5ooooo`OogMgM1on5QHD7
ohB4Q0Oo61PH1om6ATH7oadM7@OoMWIf1_lV9RH6ooooo`KoBd];1olH61P7obXZ:POoc/k>1omIFET7
oaTI6@Oo9BDU1_lY:BT6ooooo`Oo6QXJ1omPH606oh20P0Oo@T921olW9bL7ocXj>POoh>3P1_nBTY86
ooooo`Oo410@3_l<30`7oaHF5PKo410@1ol00007o`T92@KoF5QH1_ooool7oa`L70OoATI61ooLg=`7
of=SH`Oo?Cdm1omnOWh6ocPh>0KoF5QH1_ooool7odA4A0Oo2@T91ol<30`7ofIVIPOoHf=S1olb<S87
ob4Q8@KoMgMg1Oooool7on7Qh@Oo:2PX1om=CDd7oaDE5@Oo<C4a1om2@T87oeaLG0KoTY:B3Oooool0
00_ooooo1olU9BD7ob<S8`Oo2@T91ol>3Ph7oc@d=0OoGEeM1on][Jd6ohb<S0Gooooo1ooMgMd7ohF5
Q@OoQ8B41olH61P7odI6APOo7AdM1omfMWH6obHV9PKooooo1_m;Bd/7oaPH60Oo:RXZ1oo>c/h7oeUI
F@Oo6ATI1olU9BD6obTY:@Kooooo1olJ6QX7of1PH0KoP8201om2@T87obLW9`Oo>SXj1ooPh>06oi:B
TPKooooo1ol@410>o``<30Oo5QHF1_l@4107o`0000Oo2@T91_mHF5P6ooooo`Oo71`L1om6ATH7omcL
g0OoHf=S1olm?Cd7oginOPKo>3Ph1_mHF5P6ooooo`OoA4A41ol92@T7o``<30OoIVIV1omSHf<7oc8b
<POo8B4Q1_mgMgL5ooooo`OohN7Q1olX:2P7ode=C@Oo5ADE1ola<C47od92@POoG5aL1_nBTY8=oooo
o`002oooool7obDU9@Oo8b<S1ol92@T7o`h>3POo=3@d1omMGEd7ojf][@KoS8b<1Oooool7omgMg@Oo
QHF51on4Q8@7oaPH60OoATI61olM7Ad7ogIfMPKo9RHV1_ooool6od];B`Oo61PH1olZ:RX7olk>cPOo
FEUI1olI6AT7obDU9@Ko:BTY1_ooool7oaXJ6POoH61P1_n0P807od92@POo9bLW1olj>SX7on3Ph0Ko
TY:B1_ooool7oa0@40ko30`<1olF5QH6oa0@40Oo00001ol92@T6oeQHF0Kooooo1olL71`7odI6APOo
g=cL1omSHf<7ocdm?@OoOWin1_lh>3P6oeQHF0Kooooo1om4A4@7o`T92@Oo30`<1omVIVH7of=SH`Oo
<S8b1olQ8B46ogMgM`Gooooo1ooQhN47obPX:0OoCDe=1olE5AD7oc4a<@Oo@T921omLG5`6oi:BTPgo
oooo000;ooooo`Oo9BDU1olS8b<7o`T92@Oo3Ph>1old=3@7oeeMG@Oo[Jf]1_n<S8`5ooooo`OogMgM
1on5QHD7ohB4Q0Oo61PH1om6ATH7oadM7@OoMWIf1_lV9RH6ooooo`KoBd];1olH61P7obXZ:POoc/k>
1omIFET7oaTI6@Oo9BDU1_lY:BT6ooooo`Oo6QXJ1omPH606oh20P0Oo@T921olW9bL7ocXj>POoh>3P
1_nBTY86ooooo`Oo410@3_l<30`7oaHF5PKo410@1ol00007o`T92@KoF5QH1_ooool7oa`L70OoATI6
1ooLg=`7of=SH`Oo?Cdm1omnOWh6ocPh>0KoF5QH1_ooool7odA4A0Oo2@T91ol<30`7ofIVIPOoHf=S
1olb<S87ob4Q8@KoMgMg1Oooool7on7Qh@Oo:2PX1om=CDd7oaDE5@Oo<C4a1om2@T87oeaLG0KoTY:B
3Oooool000_ooooo1olU9BD7ob<S8`Oo2@T91ol>3Ph7oc@d=0OoGEeM1on][Jd6ohb<S0Gooooo1ooM
gMd7ohF5Q@OoQ8B41olH61P7odI6APOo7AdM1omfMWH6obHV9PKooooo1_m;Bd/7oaPH60Oo:RXZ1oo>
c/h7oeUIF@Oo6ATI1olU9BD6obTY:@Kooooo1olJ6QX7of1PH0KoP8201om2@T87obLW9`Oo>SXj1ooP
h>06oi:BTPKooooo1ol@410>o``<30Oo5QHF1_l@4107o`0000Oo2@T91_mHF5P6ooooo`Oo71`L1om6
ATH7omcLg0OoHf=S1olm?Cd7oginOPKo>3Ph1_mHF5P6ooooo`OoA4A41ol92@T7o``<30OoIVIV1omS
Hf<7oc8b<POo8B4Q1_mgMgL5ooooo`OohN7Q1olX:2P7ode=C@Oo5ADE1ola<C47od92@POoG5aL1_nB
TY8=ooooo`002oooool7ocLg=`Oo7QhN1ol820P7o`@410Oo9RHV1omQHF47ol_;b`KoWYjN1Oooool7
oc4a<@OoPh>31oli>CT7o`P820Oo51@D1oo:b/X7og]kN`Ko4a<C1_ooool6oe9BDPOo20P81olT92@7
ooKfmPOo@d=31olD51@7ob/[:`Ko8B4Q1_ooool7oalO7`OoE5AD1_mbLW87odI6APOo7AdM1olK6a/7
ooCdm0KoTY:B1_ooool7o`P820Oo2@T91ol820P7oaDE5@Ko3@d=1ol71`L7o``<30KoQXJ61_ooool7
oa0@40OoEeMG1ooTi>@7obXZ:POo>SXj1omcLg<6obHV9PKoB4Q81_ooool7odQ8B0Oo3Ph>1omhN7P7
ojFUY@OoUiNG1old=3@7oadM7@KogmoO3?ooool7o`L71`Oo?Shn1ol<30`7ocdm?@OoATI61omcLg<6
ojn_[`gooooo000;ooooo`Oo=cLg1olN7Qh7o`P820Oo10@41olV9RH7of5QH@Oobl_;1_nNWYh5oooo
o`Oo<C4a1on3Ph<7ocTi>@Oo20P81olD51@7ol[:bPOoNg]k1_lC4a<6ooooo`KoDU9B1ol820P7ob@T
90Oom_Kf1om3@d<7oa@D50Oo:b/[1_lQ8B46ooooo`Oo7alO1omDE5@6og9bLPOoATI61olM7Ad7oa/K
6`Oom?Cd1_nBTY86ooooo`Oo20P81ol92@T7o`P820Oo5ADE1_l=3@d7o`L71`Oo30`<1_n6QXH6oooo
o`Oo410@1omGEeL7onCTi0Oo:RXZ1olj>SX7og=cL`Ko9RHV1_m8B4P6ooooo`OoB4Q81ol>3Ph7ogQh
N0OoYJFU1onGUiL7oc@d=0Oo7AdM1_oOgml<ooooo`Oo1`L71oln?Sh7o``<30Oo?Cdm1om6ATH7og=c
L`Ko[jn_3Oooool000_ooooo1olg=cL7oahN7POo20P81ol410@7obHV9POoHF5Q1oo;bl/6oijNWPGo
oooo1ola<C47oh>3P`Oo>CTi1ol820P7oa@D50Oob/[:1omkNg/6oa<C4`Kooooo1_mBDU87o`P820Oo
92@T1oofm_H7od=3@`Oo51@D1ol[:b/6ob4Q8@Kooooo1olO7al7oeADE0KoLW9b1om6ATH7oadM7@Oo
6a/K1oodm?@6oi:BTPKooooo1ol820P7o`T92@Oo20P81olE5AD6o`d=3@Oo1`L71ol<30`6ohJ6QPKo
oooo1ol@4107oeMGE`Ooi>CT1olZ:RX7ocXj>POoLg=c1_lV9RH6odQ8B0Kooooo1om8B4P7o`h>3POo
N7Qh1onUYJD7oiNGU`Oo=3@d1olM7Ad6omoOg`cooooo1ol71`L7ochn?POo30`<1olm?Cd7odI6APOo
Lg=c1_n_[jl=ooooo`002oooool7ocLg=`Oo7QhN1ol820P7o`@410Oo9RHV1omQHF47ol_;b`KoWYjN
1Oooool7oc4a<@OoPh>31oli>CT7o`P820Oo51@D1oo:b/X7og]kN`Ko4a<C1_ooool6oe9BDPOo20P8
1olT92@7ooKfmPOo@d=31olD51@7ob/[:`Ko8B4Q1_ooool7oalO7`OoE5AD1_mbLW87odI6APOo7AdM
1olK6a/7ooCdm0KoTY:B1_ooool7o`P820Oo2@T91ol820P7oaDE5@Ko3@d=1ol71`L7o``<30KoQXJ6
1_ooool7oa0@40OoEeMG1ooTi>@7obXZ:POo>SXj1omcLg<6obHV9PKoB4Q81_ooool7odQ8B0Oo3Ph>
1omhN7P7ojFUY@OoUiNG1old=3@7oadM7@KogmoO3?ooool7o`L71`Oo?Shn1ol<30`7ocdm?@OoATI6
1omcLg<6ojn_[`gooooo000;ooooo`Oo=cLg1olN7Qh7o`P820Oo10@41olV9RH7of5QH@Oobl_;1_nN
WYh5ooooo`Oo<C4a1on3Ph<7ocTi>@Oo20P81olD51@7ol[:bPOoNg]k1_lC4a<6ooooo`KoDU9B1ol8
20P7ob@T90Oom_Kf1om3@d<7oa@D50Oo:b/[1_lQ8B46ooooo`Oo7alO1omDE5@6og9bLPOoATI61olM
7Ad7oa/K6`Oom?Cd1_nBTY86ooooo`Oo20P81ol92@T7o`P820Oo5ADE1_l=3@d7o`L71`Oo30`<1_n6
QXH6ooooo`Oo410@1omGEeL7onCTi0Oo:RXZ1olj>SX7og=cL`Ko9RHV1_m8B4P6ooooo`OoB4Q81ol>
3Ph7ogQhN0OoYJFU1onGUiL7oc@d=0Oo7AdM1_oOgml<ooooo`Oo1`L71oln?Sh7o``<30Oo?Cdm1om6
ATH7og=cL`Ko[jn_3Oooool000_ooooo1olg=cL7oahN7POo20P81ol410@7obHV9POoHF5Q1oo;bl/6
oijNWPGooooo1ola<C47oh>3P`Oo>CTi1ol820P7oa@D50Oob/[:1omkNg/6oa<C4`Kooooo1_mBDU87
o`P820Oo92@T1oofm_H7od=3@`Oo51@D1ol[:b/6ob4Q8@Kooooo1olO7al7oeADE0KoLW9b1om6ATH7
oadM7@Oo6a/K1oodm?@6oi:BTPKooooo1ol820P7o`T92@Oo20P81olE5AD6o`d=3@Oo1`L71ol<30`6
ohJ6QPKooooo1ol@4107oeMGE`Ooi>CT1olZ:RX7ocXj>POoLg=c1_lV9RH6odQ8B0Kooooo1om8B4P7
o`h>3POoN7Qh1onUYJD7oiNGU`Oo=3@d1olM7Ad6omoOg`cooooo1ol71`L7ochn?POo30`<1olm?Cd7
odI6APOoLg=c1_n_[jl=ooooo`002oooool7ocLg=`Oo7QhN1ol820P7o`@410Oo9RHV1omQHF47ol_;
b`KoWYjN1Oooool7oc4a<@OoPh>31oli>CT7o`P820Oo51@D1oo:b/X7og]kN`Ko4a<C1_ooool6oe9B
DPOo20P81olT92@7ooKfmPOo@d=31olD51@7ob/[:`Ko8B4Q1_ooool7oalO7`OoE5AD1_mbLW87odI6
APOo7AdM1olK6a/7ooCdm0KoTY:B1_ooool7o`P820Oo2@T91ol820P7oaDE5@Ko3@d=1ol71`L7o``<
30KoQXJ61_ooool7oa0@40OoEeMG1ooTi>@7obXZ:POo>SXj1omcLg<6obHV9PKoB4Q81_ooool7odQ8
B0Oo3Ph>1omhN7P7ojFUY@OoUiNG1old=3@7oadM7@KogmoO3?ooool7o`L71`Oo?Shn1ol<30`7ocdm
?@OoATI61omcLg<6ojn_[`gooooo000;ooooo`Oo;Rh^1olH61P7oa8B4POo1`L71olL71`7oeYJFPOo
e]KF1_nWYjL<ooooo`OoPh>31om>CTh7o`T92@OoGEeM1olR8R87og1`L0Ko>c/k1_ooool6odQ8B0Oo
1PH61ol^;Rh7on_[j`Oo<c<c1ol?3`l7ob4Q8@Ko7QhN1_ooool7o`h>3POoI6AT1_m/K6`7od92@POo
6ATI1olE5AD7ooOgm`Ko[:b/1_ooool7oa<C4`Oo2@T91olH61P7oaDE5@Ko30`<1olA4A47o`L71`Ko
dm?C1_ooool7oa8B4POoGUiN1oooool7obl_;`Oo@T921on1PH46oa/K6`Ko?clo1_ooool7ob4Q8@Oo
7AdM1olF5QH7of][J`OoHF5Q1olQ8B47oadM7@KoDU9B1Oooool7oogmo@Oo5ADE1olm?Cd7o`h>3POo
?Shn1omADE47ofATI0Kod=3@3Oooool000_ooooo1ol^;Rh7oaPH60Oo4Q8B1ol71`L7oa`L70OoFUYJ
1ooFe]H6ojNWY`cooooo1on3Ph<7odi>CPOo2@T91omMGEd7ob8R8POoL71`1_lk>c/6ooooo`KoB4Q8
1ol61PH7obh^;POojn_[1olc<c<7o`l?3`Oo8B4Q1_lN7Qh6ooooo`Oo3Ph>1omTI6@6ofa/K0Oo@T92
1olI6AT7oaDE5@OomoOg1_n/[:`6ooooo`Oo4a<C1ol92@T7oaPH60Oo5ADE1_l<30`7oa4A4@Oo1`L7
1_oCdm<6ooooo`Oo4Q8B1omNGUh7ooooo`Oo;bl_1om2@T87oh61P@Ko6a/K1_lo?cl6ooooo`Oo8B4Q
1olM7Ad7oaHF5POoJf][1omQHF47ob4Q8@Oo7AdM1_mBDU85ooooo`OooOgm1olE5AD7ocdm?@Oo3Ph>
1oln?Sh7oe5AD@OoI6AT1_o@d=0=ooooo`002oooool7obh^;POo61PH1olB4Q87o`L71`Oo71`L1omJ
FUX7omKFePKoYjNW3?ooool7oh>3P`OoCTi>1ol92@T7oeeMG@Oo8R8R1om`L706oc/k>`Kooooo1_m8
B4P7o`H61POo;Rh^1oo[jn/7oc<c<`Oo3`l?1olQ8B46oahN7PKooooo1ol>3Ph7ofATI0KoK6a/1om2
@T87oaTI6@Oo5ADE1oogmoL6ojb/[0Kooooo1olC4a<7o`T92@Oo61PH1olE5AD6o``<30Oo4A4A1ol7
1`L6om?Cd`Kooooo1olB4Q87oeiNGPOooooo1ol_;bl7od92@POoPH611_lK6a/6oclo?`Kooooo1olQ
8B47oadM7@Oo5QHF1om[Jf/7of5QH@Oo8B4Q1olM7Ad6oe9BDPGooooo1oomoOd7oaDE5@Oo?Cdm1ol>
3Ph7ochn?POoDE5A1omTI6@6om3@d0gooooo000;ooooo`Oo;Rh^1olH61P7oa8B4POo1`L71olL71`7
oeYJFPOoe]KF1_nWYjL<ooooo`OoPh>31om>CTh7o`T92@OoGEeM1olR8R87og1`L0Ko>c/k1_ooool6
odQ8B0Oo1PH61ol^;Rh7on_[j`Oo<c<c1ol?3`l7ob4Q8@Ko7QhN1_ooool7o`h>3POoI6AT1_m/K6`7
od92@POo6ATI1olE5AD7ooOgm`Ko[:b/1_ooool7oa<C4`Oo2@T91olH61P7oaDE5@Ko30`<1olA4A47
o`L71`Kodm?C1_ooool7oa8B4POoGUiN1oooool7obl_;`Oo@T921on1PH46oa/K6`Ko?clo1_ooool7
ob4Q8@Oo7AdM1olF5QH7of][J`OoHF5Q1olQ8B47oadM7@KoDU9B1Oooool7oogmo@Oo5ADE1olm?Cd7
o`h>3POo?Shn1omADE47ofATI0Kod=3@3Oooool000_ooooo1ol^;Rh7oaPH60Oo4Q8B1ol71`L7oa`L
70OoFUYJ1ooFe]H6ojNWY`cooooo1on3Ph<7odi>CPOo2@T91omMGEd7ob8R8POoL71`1_lk>c/6oooo
o`KoB4Q81ol61PH7obh^;POojn_[1olc<c<7o`l?3`Oo8B4Q1_lN7Qh6ooooo`Oo3Ph>1omTI6@6ofa/
K0Oo@T921olI6AT7oaDE5@OomoOg1_n/[:`6ooooo`Oo4a<C1ol92@T7oaPH60Oo5ADE1_l<30`7oa4A
4@Oo1`L71_oCdm<6ooooo`Oo4Q8B1omNGUh7ooooo`Oo;bl_1om2@T87oh61P@Ko6a/K1_lo?cl6oooo
o`Oo8B4Q1olM7Ad7oaHF5POoJf][1omQHF47ob4Q8@Oo7AdM1_mBDU85ooooo`OooOgm1olE5AD7ocdm
?@Oo3Ph>1oln?Sh7oe5AD@OoI6AT1_o@d=0=ooooo`002oooool7obh^;POo61PH1olB4Q87o`L71`Oo
71`L1omJFUX7omKFePKoYjNW3?ooool7oh>3P`OoCTi>1ol92@T7oeeMG@Oo8R8R1om`L706oc/k>`Ko
oooo1_m8B4P7o`H61POo;Rh^1oo[jn/7oc<c<`Oo3`l?1olQ8B46oahN7PKooooo1ol>3Ph7ofATI0Ko
K6a/1om2@T87oaTI6@Oo5ADE1oogmoL6ojb/[0Kooooo1olC4a<7o`T92@Oo61PH1olE5AD6o``<30Oo
4A4A1ol71`L6om?Cd`Kooooo1olB4Q87oeiNGPOooooo1ol_;bl7od92@POoPH611_lK6a/6oclo?`Ko
oooo1olQ8B47oadM7@Oo5QHF1om[Jf/7of5QH@Oo8B4Q1olM7Ad6oe9BDPGooooo1oomoOd7oaDE5@Oo
?Cdm1ol>3Ph7ochn?POoDE5A1omTI6@6om3@d0gooooo000;ooooo`Oo;Rh^1olH61P7oa8B4POo1`L7
1olL71`7oeYJFPOoe]KF1_nWYjL<ooooo`OoPh>31om>CTh7o`T92@OoGEeM1olR8R87og1`L0Ko>c/k
1_ooool6odQ8B0Oo1PH61ol^;Rh7on_[j`Oo<c<c1ol?3`l7ob4Q8@Ko7QhN1_ooool7o`h>3POoI6AT
1_m/K6`7od92@POo6ATI1olE5AD7ooOgm`Ko[:b/1_ooool7oa<C4`Oo2@T91olH61P7oaDE5@Ko30`<
1olA4A47o`L71`Kodm?C1_ooool7oa8B4POoGUiN1oooool7obl_;`Oo@T921on1PH46oa/K6`Ko?clo
1_ooool7ob4Q8@Oo7AdM1olF5QH7of][J`OoHF5Q1olQ8B47oadM7@KoDU9B1Oooool7oogmo@Oo5ADE
1olm?Cd7o`h>3POo?Shn1omADE47ofATI0Kod=3@3Oooool000_ooooo1om0@407obHV9POo5ADE1ol9
2@T7oaXJ6POoB4Q81ooWinL6oi^KV`Gooooo1om4A4@7og5aL@Oo;Rh^1ol00007obPX:0Ook^k^1omk
Ng/6oaXJ6PKooooo1_mPH607o`T92@Oo9bLW1oooool7oaXJ6POo0`<31ol`<306oa<C4`Kooooo1olD
51@7oeaLG0KoJ6QX1om1@D47o`d=3@Oo3`l?1oooool6oj:RXPKooooo1olF5QH7o`820POo20P81olH
61P6oa0@40Oo4a<C1ol92@T<ooooo`Oo61PH1omeMGD7oo;blPOo30`<1olm?Cd7ofQXJ0Ko4a<C1_lo
?cl6ooooo`Oo>3Ph1ol00007okFe]@Oo[Jf]1omdM7@7oahN7POo>SXj1_obl_85ooooo`OokNg]1ol:
2PX7obd];@Oo0`<31omNGUh7oeQHF0OoLg=c1_oLg=`=ooooo`002oooool7od10@0Oo9RHV1olE5AD7
o`T92@Oo6QXJ1om8B4P7onOWi`KoVi^K1Oooool7odA4A0OoLG5a1ol^;Rh7o`0000Oo:2PX1oo^k^h7
og]kN`Ko6QXJ1_ooool6of1PH0Oo2@T91olW9bL7ooooo`Oo6QXJ1ol30`<7oc0`<0Ko4a<C1_ooool7
oa@D50OoG5aL1_mXJ6P7od51@@Oo3@d=1ol?3`l7ooooo`KoXZ:R1_ooool7oaHF5POo0P821ol820P7
oaPH60Ko410@1olC4a<7o`T92@cooooo1olH61P7ogEeM@Ool_;b1ol<30`7ocdm?@OoJ6QX1_lC4a<6
oclo?`Kooooo1olh>3P7o`0000Oo]KFe1on][Jd7ogAdM0Oo7QhN1olj>SX6oo;blPGooooo1oo]kNd7
o`X:2POo;Bd]1ol30`<7oeiNGPOoF5QH1omcLg<6omcLg0gooooo000;ooooo`Oo@4101olV9RH7oaDE
5@Oo2@T91olJ6QX7odQ8B0OoinOW1_nKVi/5ooooo`OoA4A41omaLG47obh^;POo00001olX:2P7onk^
kPOoNg]k1_lJ6QX6ooooo`KoH61P1ol92@T7obLW9`Oooooo1olJ6QX7o`<30`Oo<30`1_lC4a<6oooo
o`Oo51@D1omLG5`6ofQXJ0Oo@D511ol=3@d7o`l?3`Oooooo1_nRXZ86ooooo`Oo5QHF1ol20P87o`P8
20Oo61PH1_l@4107oa<C4`Oo2@T93?ooool7oaPH60OoMGEe1oobl_87o``<30Oo?Cdm1omXJ6P6oa<C
4`Ko?clo1_ooool7ocPh>0Oo00001one]KD7ojf][@OoM7Ad1olN7Qh7ocXj>PKol_;b1Oooool7ong]
k@Oo2PX:1ol];Bd7o`<30`OoGUiN1omHF5P7og=cL`Kog=cL3Oooool000_ooooo1om0@407obHV9POo
5ADE1ol92@T7oaXJ6POoB4Q81ooWinL6oi^KV`Gooooo1om4A4@7og5aL@Oo;Rh^1ol00007obPX:0Oo
k^k^1omkNg/6oaXJ6PKooooo1_mPH607o`T92@Oo9bLW1oooool7oaXJ6POo0`<31ol`<306oa<C4`Ko
oooo1olD51@7oeaLG0KoJ6QX1om1@D47o`d=3@Oo3`l?1oooool6oj:RXPKooooo1olF5QH7o`820POo
20P81olH61P6oa0@40Oo4a<C1ol92@T<ooooo`Oo61PH1omeMGD7oo;blPOo30`<1olm?Cd7ofQXJ0Ko
4a<C1_lo?cl6ooooo`Oo>3Ph1ol00007okFe]@Oo[Jf]1omdM7@7oahN7POo>SXj1_obl_85ooooo`Oo
kNg]1ol:2PX7obd];@Oo0`<31omNGUh7oeQHF0OoLg=c1_oLg=`=ooooo`002oooool7od10@0Oo9RHV
1olE5AD7o`T92@Oo6QXJ1om8B4P7onOWi`KoVi^K1Oooool7odA4A0OoLG5a1ol^;Rh7o`0000Oo:2PX
1oo^k^h7og]kN`Ko6QXJ1_ooool6of1PH0Oo2@T91olW9bL7ooooo`Oo6QXJ1ol30`<7oc0`<0Ko4a<C
1_ooool7oa@D50OoG5aL1_mXJ6P7od51@@Oo3@d=1ol?3`l7ooooo`KoXZ:R1_ooool7oaHF5POo0P82
1ol820P7oaPH60Ko410@1olC4a<7o`T92@cooooo1olH61P7ogEeM@Ool_;b1ol<30`7ocdm?@OoJ6QX
1_lC4a<6oclo?`Kooooo1olh>3P7o`0000Oo]KFe1on][Jd7ogAdM0Oo7QhN1olj>SX6oo;blPGooooo
1oo]kNd7o`X:2POo;Bd]1ol30`<7oeiNGPOoF5QH1omcLg<6omcLg0gooooo000;ooooo`Oo@4101olV
9RH7oaDE5@Oo2@T91olJ6QX7odQ8B0OoinOW1_nKVi/5ooooo`OoA4A41omaLG47obh^;POo00001olX
:2P7onk^kPOoNg]k1_lJ6QX6ooooo`KoH61P1ol92@T7obLW9`Oooooo1olJ6QX7o`<30`Oo<30`1_lC
4a<6ooooo`Oo51@D1omLG5`6ofQXJ0Oo@D511ol=3@d7o`l?3`Oooooo1_nRXZ86ooooo`Oo5QHF1ol2
0P87o`P820Oo61PH1_l@4107oa<C4`Oo2@T93?ooool7oaPH60OoMGEe1oobl_87o``<30Oo?Cdm1omX
J6P6oa<C4`Ko?clo1_ooool7ocPh>0Oo00001one]KD7ojf][@OoM7Ad1olN7Qh7ocXj>PKol_;b1Ooo
ool7ong]k@Oo2PX:1ol];Bd7o`<30`OoGUiN1omHF5P7og=cL`Kog=cL3Oooool000_ooooo1om4A4@7
oa`L70Oo5ADE1ol820P7oaDE5@OoCTi>1oooool6ohn?S`Gooooo1ooemOD7ogUiN@Oo5aLG1olH61P7
of][J`Oo:b/[1omRHV86of][J`Kooooo1_m;Bd/7o`X:2POo>c/k1ooShn<7oa@D50Oo2`/;1olX:2P6
oaHF5PKooooo1ol<30`7oeIFEPKoH61P1olf=SH7o`h>3POo2@T91oojn_X6ok2`/0Kooooo1olB4Q87
o`D51@Oo3Ph>1olC4a<6oa8B4POo5aLG1ol@4106ohb<S0Kooooo1olM7Ad7ohj>SPOooooo1ol>3Ph7
odA4A0OoJ6QX1_l820P6ocHf=PKooooo1ol61PH7ob<S8`Oo;Bd]1omaLG47oeaLG0Oo7AdM1olV9RH6
obXZ:PGooooo1ooGemL7o`d=3@Oo;2`/1ol00007oe=CD`OoDU9B1om^KVh6ooWin@gooooo000;oooo
o`OoA4A41olL71`7oaDE5@Oo20P81olE5AD7odi>CPOooooo1_n?Shl5ooooo`OomOGe1omiNGT7oaLG
5`Oo61PH1om[Jf/7ob/[:`OoHV9R1_m[Jf/6ooooo`KoBd];1ol:2PX7oc/k>`Oohn?S1olD51@7o`/;
2`Oo:2PX1_lF5QH6ooooo`Oo30`<1omFEUH6of1PH0Oo=SHf1ol>3Ph7o`T92@Oon_[j1_n`/;06oooo
o`Oo4Q8B1ol51@D7o`h>3POo4a<C1_lB4Q87oaLG5`Oo410@1_n<S8`6ooooo`Oo7AdM1on>SXh7oooo
o`Oo3Ph>1om4A4@7ofQXJ0Ko20P81_lf=SH6ooooo`Oo1PH61olS8b<7obd];@OoLG5a1omLG5`7oadM
7@Oo9RHV1_lZ:RX5ooooo`OoemOG1ol=3@d7ob`/;0Oo00001omCDe<7oe9BDPOoKVi^1_oinOT=oooo
o`002oooool7odA4A0Oo71`L1olE5AD7o`P820Oo5ADE1om>CTh7ooooo`KoShn?1Oooool7ooGem@Oo
NGUi1olG5aL7oaPH60OoJf][1ol[:b/7of9RHPKoJf][1_ooool6od];B`Oo2PX:1olk>c/7on?Sh`Oo
51@D1ol;2`/7obPX:0Ko5QHF1_ooool7o``<30OoEUIF1_mPH607ocHf=POo3Ph>1ol92@T7oo[jnPKo
/;2`1_ooool7oa8B4POo1@D51ol>3Ph7oa<C4`Ko4Q8B1olG5aL7oa0@40KoS8b<1_ooool7oadM7@Oo
SXj>1oooool7o`h>3POoA4A41omXJ6P6o`P820Ko=SHf1_ooool7o`H61POo8b<S1ol];Bd7og5aL@Oo
G5aL1olM7Ad7obHV9PKo:RXZ1Oooool7omOGe`Oo3@d=1ol/;2`7o`0000OoDe=C1omBDU87ofi^KPKo
nOWi3Oooool000_ooooo1om4A4@7oa`L70Oo5ADE1ol820P7oaDE5@OoCTi>1oooool6ohn?S`Gooooo
1ooemOD7ogUiN@Oo5aLG1olH61P7of][J`Oo:b/[1omRHV86of][J`Kooooo1_m;Bd/7o`X:2POo>c/k
1ooShn<7oa@D50Oo2`/;1olX:2P6oaHF5PKooooo1ol<30`7oeIFEPKoH61P1olf=SH7o`h>3POo2@T9
1oojn_X6ok2`/0Kooooo1olB4Q87o`D51@Oo3Ph>1olC4a<6oa8B4POo5aLG1ol@4106ohb<S0Kooooo
1olM7Ad7ohj>SPOooooo1ol>3Ph7odA4A0OoJ6QX1_l820P6ocHf=PKooooo1ol61PH7ob<S8`Oo;Bd]
1omaLG47oeaLG0Oo7AdM1olV9RH6obXZ:PGooooo1ooGemL7o`d=3@Oo;2`/1ol00007oe=CD`OoDU9B
1om^KVh6ooWin@gooooo000;ooooo`OoA4A41olL71`7oaDE5@Oo20P81olE5AD7odi>CPOooooo1_n?
Shl5ooooo`OomOGe1omiNGT7oaLG5`Oo61PH1om[Jf/7ob/[:`OoHV9R1_m[Jf/6ooooo`KoBd];1ol:
2PX7oc/k>`Oohn?S1olD51@7o`/;2`Oo:2PX1_lF5QH6ooooo`Oo30`<1omFEUH6of1PH0Oo=SHf1ol>
3Ph7o`T92@Oon_[j1_n`/;06ooooo`Oo4Q8B1ol51@D7o`h>3POo4a<C1_lB4Q87oaLG5`Oo410@1_n<
S8`6ooooo`Oo7AdM1on>SXh7ooooo`Oo3Ph>1om4A4@7ofQXJ0Ko20P81_lf=SH6ooooo`Oo1PH61olS
8b<7obd];@OoLG5a1omLG5`7oadM7@Oo9RHV1_lZ:RX5ooooo`OoemOG1ol=3@d7ob`/;0Oo00001omC
De<7oe9BDPOoKVi^1_oinOT=ooooo`002oooool7odA4A0Oo71`L1olE5AD7o`P820Oo5ADE1om>CTh7
ooooo`KoShn?1Oooool7ooGem@OoNGUi1olG5aL7oaPH60OoJf][1ol[:b/7of9RHPKoJf][1_ooool6
od];B`Oo2PX:1olk>c/7on?Sh`Oo51@D1ol;2`/7obPX:0Ko5QHF1_ooool7o``<30OoEUIF1_mPH607
ocHf=POo3Ph>1ol92@T7oo[jnPKo/;2`1_ooool7oa8B4POo1@D51ol>3Ph7oa<C4`Ko4Q8B1olG5aL7
oa0@40KoS8b<1_ooool7oadM7@OoSXj>1oooool7o`h>3POoA4A41omXJ6P6o`P820Ko=SHf1_ooool7
o`H61POo8b<S1ol];Bd7og5aL@OoG5aL1olM7Ad7obHV9PKo:RXZ1Oooool7omOGe`Oo3@d=1ol/;2`7
o`0000OoDe=C1omBDU87ofi^KPKonOWi3Oooool000_ooooo1om4A4@7oa`L70Oo5ADE1ol820P7oaDE
5@OoCTi>1oooool6ohn?S`Gooooo1ooemOD7ogUiN@Oo5aLG1olH61P7of][J`Oo:b/[1omRHV86of][
J`Kooooo1_m;Bd/7o`X:2POo>c/k1ooShn<7oa@D50Oo2`/;1olX:2P6oaHF5PKooooo1ol<30`7oeIF
EPKoH61P1olf=SH7o`h>3POo2@T91oojn_X6ok2`/0Kooooo1olB4Q87o`D51@Oo3Ph>1olC4a<6oa8B
4POo5aLG1ol@4106ohb<S0Kooooo1olM7Ad7ohj>SPOooooo1ol>3Ph7odA4A0OoJ6QX1_l820P6ocHf
=PKooooo1ol61PH7ob<S8`Oo;Bd]1omaLG47oeaLG0Oo7AdM1olV9RH6obXZ:PGooooo1ooGemL7o`d=
3@Oo;2`/1ol00007oe=CD`OoDU9B1om^KVh6ooWin@gooooo000;ooooo`Oo@T921olU9BD7oaXJ6POo
00001olE5AD7odE5A@Oog]kN1_n=SHd5ooooo`OoFe]K1omFEUH7obDU9@Oo4a<C1olo?cl7ooWin@Oo
N7Qh1_l/;2`6ooooo`KoJVYZ1ol?3`l7obh^;POom?Cd1olC4a<7o`0000Oo>c/k1_l;2`/6ooooo`Oo
5ADE1om:BTX6ofUYJ@Oo>CTi1ol51@D7oa0@40Oom_Kf1_nRXZ86ooooo`Oo2PX:1ol92@T7o`@410Oo
6QXJ1_l>3Ph7oa0@40Oo2@T91_m8B4P6ooooo`Oo71`L1onXZ:P7on3Ph0Oo00001om6ATH7odY:BPKo
6a/K1_l`<306ooooo`Oo820P1ol71`L7on7Qh@Oo[jn_1oln?Sh7oaHF5POoADE51_omoOd5ooooo`Oo
a/K61ol92@T7obd];@Oo00001omUIFD7oe9BDPOoRHV91_oXj>P=ooooo`002oooool7od92@POo9BDU
1olJ6QX7o`0000Oo5ADE1om5ADD7omkNgPKoSHf=1Oooool7oe]KF`OoEUIF1olU9BD7oa<C4`Oo?clo
1ooinOT7ogQhN0Ko;2`/1_ooool6ofYZJPOo3`l?1ol^;Rh7ooCdm0Oo4a<C1ol00007oc/k>`Ko2`/;
1_ooool7oaDE5@OoBTY:1_mYJFT7ocTi>@Oo1@D51ol@4107ooKfmPKoXZ:R1_ooool7o`X:2POo2@T9
1ol410@7oaXJ6PKo3Ph>1ol@4107o`T92@KoB4Q81_ooool7oa`L70OoZ:RX1ooPh>07o`0000OoATI6
1om:BTX6oa/K6`Ko<30`1_ooool7ob0P80Oo1`L71ooQhN47ojn_[`Oo?Shn1olF5QH7odE5A@KooOgm
1Oooool7olK6aPOo2@T91ol];Bd7o`0000OoIFEU1omBDU87ohV9R@Koj>SX3Oooool000_ooooo1om2
@T87obDU9@Oo6QXJ1ol00007oaDE5@OoADE51ooNg]h6ohf=S@Gooooo1omKFe/7oeIFEPOo9BDU1olC
4a<7oclo?`OonOWi1omhN7P6ob`/;0Kooooo1_mZJVX7o`l?3`Oo;Rh^1oodm?@7oa<C4`Oo00001olk
>c/6o`/;2`Kooooo1olE5AD7odY:BPKoJFUY1oli>CT7o`D51@Oo410@1oofm_H6oj:RXPKooooo1ol:
2PX7o`T92@Oo10@41olJ6QX6o`h>3POo410@1ol92@T6odQ8B0Kooooo1olL71`7ojRXZ0Ooh>3P1ol0
0007odI6APOoBTY:1_lK6a/6oc0`<0Kooooo1olP8207o`L71`OohN7Q1on_[jl7ochn?POo5QHF1om5
ADD6oogmo@Gooooo1oo6a/H7o`T92@Oo;Bd]1ol00007ofEUI@OoDU9B1on9RHT6onSXj0gooooo000;
ooooo`Oo@T921olU9BD7oaXJ6POo00001olE5AD7odE5A@Oog]kN1_n=SHd5ooooo`OoFe]K1omFEUH7
obDU9@Oo4a<C1olo?cl7ooWin@OoN7Qh1_l/;2`6ooooo`KoJVYZ1ol?3`l7obh^;POom?Cd1olC4a<7
o`0000Oo>c/k1_l;2`/6ooooo`Oo5ADE1om:BTX6ofUYJ@Oo>CTi1ol51@D7oa0@40Oom_Kf1_nRXZ86
ooooo`Oo2PX:1ol92@T7o`@410Oo6QXJ1_l>3Ph7oa0@40Oo2@T91_m8B4P6ooooo`Oo71`L1onXZ:P7
on3Ph0Oo00001om6ATH7odY:BPKo6a/K1_l`<306ooooo`Oo820P1ol71`L7on7Qh@Oo[jn_1oln?Sh7
oaHF5POoADE51_omoOd5ooooo`Ooa/K61ol92@T7obd];@Oo00001omUIFD7oe9BDPOoRHV91_oXj>P=
ooooo`002oooool7od92@POo9BDU1olJ6QX7o`0000Oo5ADE1om5ADD7omkNgPKoSHf=1Oooool7oe]K
F`OoEUIF1olU9BD7oa<C4`Oo?clo1ooinOT7ogQhN0Ko;2`/1_ooool6ofYZJPOo3`l?1ol^;Rh7ooCd
m0Oo4a<C1ol00007oc/k>`Ko2`/;1_ooool7oaDE5@OoBTY:1_mYJFT7ocTi>@Oo1@D51ol@4107ooKf
mPKoXZ:R1_ooool7o`X:2POo2@T91ol410@7oaXJ6PKo3Ph>1ol@4107o`T92@KoB4Q81_ooool7oa`L
70OoZ:RX1ooPh>07o`0000OoATI61om:BTX6oa/K6`Ko<30`1_ooool7ob0P80Oo1`L71ooQhN47ojn_
[`Oo?Shn1olF5QH7odE5A@KooOgm1Oooool7olK6aPOo2@T91ol];Bd7o`0000OoIFEU1omBDU87ohV9
R@Koj>SX3Oooool000_ooooo1om2@T87obDU9@Oo6QXJ1ol00007oaDE5@OoADE51ooNg]h6ohf=S@Go
oooo1omKFe/7oeIFEPOo9BDU1olC4a<7oclo?`OonOWi1omhN7P6ob`/;0Kooooo1_mZJVX7o`l?3`Oo
;Rh^1oodm?@7oa<C4`Oo00001olk>c/6o`/;2`Kooooo1olE5AD7odY:BPKoJFUY1oli>CT7o`D51@Oo
410@1oofm_H6oj:RXPKooooo1ol:2PX7o`T92@Oo10@41olJ6QX6o`h>3POo410@1ol92@T6odQ8B0Ko
oooo1olL71`7ojRXZ0Ooh>3P1ol00007odI6APOoBTY:1_lK6a/6oc0`<0Kooooo1olP8207o`L71`Oo
hN7Q1on_[jl7ochn?POo5QHF1om5ADD6oogmo@Gooooo1oo6a/H7o`T92@Oo;Bd]1ol00007ofEUI@Oo
DU9B1on9RHT6onSXj0gooooo000;ooooo`Oo@T921olU9BD7oaXJ6POo00001olE5AD7odE5A@Oog]kN
1_n=SHd5ooooo`OoFe]K1omFEUH7obDU9@Oo4a<C1olo?cl7ooWin@OoN7Qh1_l/;2`6ooooo`KoJVYZ
1ol?3`l7obh^;POom?Cd1olC4a<7o`0000Oo>c/k1_l;2`/6ooooo`Oo5ADE1om:BTX6ofUYJ@Oo>CTi
1ol51@D7oa0@40Oom_Kf1_nRXZ86ooooo`Oo2PX:1ol92@T7o`@410Oo6QXJ1_l>3Ph7oa0@40Oo2@T9
1_m8B4P6ooooo`Oo71`L1onXZ:P7on3Ph0Oo00001om6ATH7odY:BPKo6a/K1_l`<306ooooo`Oo820P
1ol71`L7on7Qh@Oo[jn_1oln?Sh7oaHF5POoADE51_omoOd5ooooo`Ooa/K61ol92@T7obd];@Oo0000
1omUIFD7oe9BDPOoRHV91_oXj>P=ooooo`002oooool7oda<C0Oo4A4A1olM7Ad7oa<C4`Oo9bLW1om6
ATH7olK6aPKoR8R81Oooool7olg=c@OoG5aL1ol<30`7obTY:@OoKVi^1olm?Cd7oe=CD`KoQXJ61_oo
ool6oeEEE@Oo3Ph>1om8B4P7okfm_@Oo20P81olF5QH7oc`l?0Ko61PH1_ooool7oa4A4@OoBTY:1_mF
EUH7obd];@Oo3@d=1olP8207onk^kPKoY:BT1_ooool7oahN7POo3@d=1ol@4107oaDE5@Ko71`L1olE
5AD7o`P820Ko@T921_ooool7ob`/;0Oo^[Zj1oo>c/h7o`h>3POoAdM71om0@406oaDE5@Ko9BDU1_oo
ool7o``<30Oo9RHV1om6ATH7ogIfMPOoE5AD1ol30`<7ochn?PKo7alO1Oooool7oinOW`Oo8R8R1olW
9bL7o`0000OoIVIV1om>CTh7oginOPKokNg]3Oooool000_ooooo1om<C4`7oa4A4@Oo7AdM1olC4a<7
obLW9`OoATI61oo6a/H6ohR8R0Gooooo1oo=cLd7oeaLG0Oo30`<1olY:BT7ofi^KPOo?Cdm1omCDe<6
ohJ6QPKooooo1_mEEED7o`h>3POoB4Q81onm_Kd7o`P820Oo5QHF1oll?3`6oaPH60Kooooo1olA4A47
odY:BPKoEUIF1ol];Bd7o`d=3@Oo820P1oo^k^h6ojBTY0Kooooo1olN7Qh7o`d=3@Oo410@1olE5AD6
oa`L70Oo5ADE1ol820P6od92@PKooooo1ol/;2`7okZj^POoc/k>1ol>3Ph7odM7A`Oo@4101_lE5AD6
obDU9@Kooooo1ol<30`7obHV9POoATI61omfMWH7oeADE0Oo0`<31oln?Sh6oalO7`Gooooo1onOWil7
ob8R8POo9bLW1ol00007ofIVIPOoCTi>1omnOWh6ong]k@gooooo000;ooooo`OoC4a<1olA4A47oadM
7@Oo4a<C1olW9bL7odI6APOoa/K61_n8R8P5ooooo`OocLg=1omLG5`7o``<30Oo:BTY1om^KVh7ocdm
?@OoDe=C1_n6QXH6ooooo`KoEEEE1ol>3Ph7odQ8B0Oo_Kfm1ol820P7oaHF5POo?3`l1_lH61P6oooo
o`Oo4A4A1om:BTX6oeIFEPOo;Bd]1ol=3@d7ob0P80Ook^k^1_nTY:@6ooooo`Oo7QhN1ol=3@d7oa0@
40Oo5ADE1_lL71`7oaDE5@Oo20P81_m2@T86ooooo`Oo;2`/1onj^[X7olk>cPOo3Ph>1om7AdL7od10
@0Ko5ADE1_lU9BD6ooooo`Oo30`<1olV9RH7odI6APOoMWIf1omDE5@7o`<30`Oo?Shn1_lO7al5oooo
o`OoWinO1olR8R87obLW9`Oo00001omVIVH7odi>CPOoOWin1_o]kNd=ooooo`002oooool7oda<C0Oo
4A4A1olM7Ad7oa<C4`Oo9bLW1om6ATH7olK6aPKoR8R81Oooool7olg=c@OoG5aL1ol<30`7obTY:@Oo
KVi^1olm?Cd7oe=CD`KoQXJ61_ooool6oeEEE@Oo3Ph>1om8B4P7okfm_@Oo20P81olF5QH7oc`l?0Ko
61PH1_ooool7oa4A4@OoBTY:1_mFEUH7obd];@Oo3@d=1olP8207onk^kPKoY:BT1_ooool7oahN7POo
3@d=1ol@4107oaDE5@Ko71`L1olE5AD7o`P820Ko@T921_ooool7ob`/;0Oo^[Zj1oo>c/h7o`h>3POo
AdM71om0@406oaDE5@Ko9BDU1_ooool7o``<30Oo9RHV1om6ATH7ogIfMPOoE5AD1ol30`<7ochn?PKo
7alO1Oooool7oinOW`Oo8R8R1olW9bL7o`0000OoIVIV1om>CTh7oginOPKokNg]3Oooool000_ooooo
1om<C4`7oa4A4@Oo7AdM1olC4a<7obLW9`OoATI61oo6a/H6ohR8R0Gooooo1oo=cLd7oeaLG0Oo30`<
1olY:BT7ofi^KPOo?Cdm1omCDe<6ohJ6QPKooooo1_mEEED7o`h>3POoB4Q81onm_Kd7o`P820Oo5QHF
1oll?3`6oaPH60Kooooo1olA4A47odY:BPKoEUIF1ol];Bd7o`d=3@Oo820P1oo^k^h6ojBTY0Kooooo
1olN7Qh7o`d=3@Oo410@1olE5AD6oa`L70Oo5ADE1ol820P6od92@PKooooo1ol/;2`7okZj^POoc/k>
1ol>3Ph7odM7A`Oo@4101_lE5AD6obDU9@Kooooo1ol<30`7obHV9POoATI61omfMWH7oeADE0Oo0`<3
1oln?Sh6oalO7`Gooooo1onOWil7ob8R8POo9bLW1ol00007ofIVIPOoCTi>1omnOWh6ong]k@gooooo
000;ooooo`OoC4a<1olA4A47oadM7@Oo4a<C1olW9bL7odI6APOoa/K61_n8R8P5ooooo`OocLg=1omL
G5`7o``<30Oo:BTY1om^KVh7ocdm?@OoDe=C1_n6QXH6ooooo`KoEEEE1ol>3Ph7odQ8B0Oo_Kfm1ol8
20P7oaHF5POo?3`l1_lH61P6ooooo`Oo4A4A1om:BTX6oeIFEPOo;Bd]1ol=3@d7ob0P80Ook^k^1_nT
Y:@6ooooo`Oo7QhN1ol=3@d7oa0@40Oo5ADE1_lL71`7oaDE5@Oo20P81_m2@T86ooooo`Oo;2`/1onj
^[X7olk>cPOo3Ph>1om7AdL7od10@0Ko5ADE1_lU9BD6ooooo`Oo30`<1olV9RH7odI6APOoMWIf1omD
E5@7o`<30`Oo?Shn1_lO7al5ooooo`OoWinO1olR8R87obLW9`Oo00001omVIVH7odi>CPOoOWin1_o]
kNd=ooooo`002oooool7odA4A0Oo20P81olQ8B47o`/;2`Oo4A4A1olb<S87oiNGU`KoN7Qh1Oooool7
oc/k>`Oo;bl_1olQ8B47oalO7`OoAdM71ooinOT7ogEeM@Ko;Bd]1_ooool6ofATI0Oo5aLG1oln?Sh7
olo?c`Oo1PH61ol:2PX7oda<C0Ko5aLG1_ooool7o`l?3`Oo?3`l1_mADE47ob`/;0Oo00001olG5aL7
olo?c`KoQhN71_ooool7o`P820Oo10@41ol71`L7o`h>3PKo4Q8B1ol>3Ph7o`410@Ko<C4a1_ooool7
obDU9@OoYZJV1onRXZ87o`T92@Oo=SHf1ola<C46ob4Q8@Ko9RHV1_ooool7oa/K6`Oo7QhN1oo]kNd7
ojNWY`Oo:b/[1ola<C47of9RHP_ooooo1on0P807o`X:2POo5ADE1ol00007of=SH`OoBDU91omgMgL6
ol[:bPgooooo000;ooooo`OoA4A41ol820P7ob4Q8@Oo2`/;1olA4A47oc8b<POoUiNG1_mhN7P5oooo
o`Oo>c/k1ol_;bl7ob4Q8@Oo7alO1om7AdL7ooWin@OoMGEe1_l];Bd6ooooo`KoI6AT1olG5aL7ochn
?POoclo?1ol61PH7o`X:2POoC4a<1_lG5aL6ooooo`Oo3`l?1oll?3`6oe5AD@Oo;2`/1ol00007oaLG
5`Ooclo?1_n7QhL6ooooo`Oo20P81ol410@7o`L71`Oo3Ph>1_lB4Q87o`h>3POo0@411_la<C46oooo
o`Oo9BDU1onVYZH7oj:RXPOo2@T91olf=SH7oc4a<@Ko8B4Q1_lV9RH6ooooo`Oo6a/K1olN7Qh7ong]
k@OoYjNW1ol[:b/7oc4a<@OoHV9R2oooool7oh20P0Oo2PX:1olE5AD7o`0000OoHf=S1om9BDT7ogMg
M`Kob/[:3Oooool000_ooooo1om4A4@7o`P820Oo8B4Q1ol;2`/7oa4A4@Oo<S8b1onGUiL6ogQhN0Go
oooo1olk>c/7obl_;`Oo8B4Q1olO7al7odM7A`OonOWi1omeMGD6obd];@Kooooo1_mTI6@7oaLG5`Oo
?Shn1oo?cll7o`H61POo2PX:1om<C4`6oaLG5`Kooooo1ol?3`l7oc`l?0KoDE5A1ol/;2`7o`0000Oo
5aLG1oo?cll6ohN7Q`Kooooo1ol820P7o`@410Oo1`L71ol>3Ph6oa8B4POo3Ph>1ol10@46oc4a<@Ko
oooo1olU9BD7ojJVYPOoXZ:R1ol92@T7ocHf=POo<C4a1_lQ8B46obHV9PKooooo1olK6a/7oahN7POo
kNg]1onWYjL7ob/[:`Oo<C4a1omRHV8;ooooo`OoP8201ol:2PX7oaDE5@Oo00001omSHf<7odU9B@Oo
MgMg1_o:b/X=ooooo`002oooool7odA4A0Oo20P81olQ8B47o`/;2`Oo4A4A1olb<S87oiNGU`KoN7Qh
1Oooool7oc/k>`Oo;bl_1olQ8B47oalO7`OoAdM71ooinOT7ogEeM@Ko;Bd]1_ooool6ofATI0Oo5aLG
1oln?Sh7olo?c`Oo1PH61ol:2PX7oda<C0Ko5aLG1_ooool7o`l?3`Oo?3`l1_mADE47ob`/;0Oo0000
1olG5aL7olo?c`KoQhN71_ooool7o`P820Oo10@41ol71`L7o`h>3PKo4Q8B1ol>3Ph7o`410@Ko<C4a
1_ooool7obDU9@OoYZJV1onRXZ87o`T92@Oo=SHf1ola<C46ob4Q8@Ko9RHV1_ooool7oa/K6`Oo7QhN
1oo]kNd7ojNWY`Oo:b/[1ola<C47of9RHP_ooooo1on0P807o`X:2POo5ADE1ol00007of=SH`OoBDU9
1omgMgL6ol[:bPgooooo000;ooooo`OoA4A41ol820P7ob4Q8@Oo2`/;1olA4A47oc8b<POoUiNG1_mh
N7P5ooooo`Oo>c/k1ol_;bl7ob4Q8@Oo7alO1om7AdL7ooWin@OoMGEe1_l];Bd6ooooo`KoI6AT1olG
5aL7ochn?POoclo?1ol61PH7o`X:2POoC4a<1_lG5aL6ooooo`Oo3`l?1oll?3`6oe5AD@Oo;2`/1ol0
0007oaLG5`Ooclo?1_n7QhL6ooooo`Oo20P81ol410@7o`L71`Oo3Ph>1_lB4Q87o`h>3POo0@411_la
<C46ooooo`Oo9BDU1onVYZH7oj:RXPOo2@T91olf=SH7oc4a<@Ko8B4Q1_lV9RH6ooooo`Oo6a/K1olN
7Qh7ong]k@OoYjNW1ol[:b/7oc4a<@OoHV9R2oooool7oh20P0Oo2PX:1olE5AD7o`0000OoHf=S1om9
BDT7ogMgM`Kob/[:3Oooool000_ooooo1om4A4@7o`P820Oo8B4Q1ol;2`/7oa4A4@Oo<S8b1onGUiL6
ogQhN0Gooooo1olk>c/7obl_;`Oo8B4Q1olO7al7odM7A`OonOWi1omeMGD6obd];@Kooooo1_mTI6@7
oaLG5`Oo?Shn1oo?cll7o`H61POo2PX:1om<C4`6oaLG5`Kooooo1ol?3`l7oc`l?0KoDE5A1ol/;2`7
o`0000Oo5aLG1oo?cll6ohN7Q`Kooooo1ol820P7o`@410Oo1`L71ol>3Ph6oa8B4POo3Ph>1ol10@46
oc4a<@Kooooo1olU9BD7ojJVYPOoXZ:R1ol92@T7ocHf=POo<C4a1_lQ8B46obHV9PKooooo1olK6a/7
oahN7POokNg]1onWYjL7ob/[:`Oo<C4a1omRHV8;ooooo`OoP8201ol:2PX7oaDE5@Oo00001omSHf<7
odU9B@OoMgMg1_o:b/X=ooooo`002oooool7odA4A0Oo20P81olQ8B47o`/;2`Oo4A4A1olb<S87oiNG
U`KoN7Qh1Oooool7oc/k>`Oo;bl_1olQ8B47oalO7`OoAdM71ooinOT7ogEeM@Ko;Bd]1_ooool6ofAT
I0Oo5aLG1oln?Sh7olo?c`Oo1PH61ol:2PX7oda<C0Ko5aLG1_ooool7o`l?3`Oo?3`l1_mADE47ob`/
;0Oo00001olG5aL7olo?c`KoQhN71_ooool7o`P820Oo10@41ol71`L7o`h>3PKo4Q8B1ol>3Ph7o`41
0@Ko<C4a1_ooool7obDU9@OoYZJV1onRXZ87o`T92@Oo=SHf1ola<C46ob4Q8@Ko9RHV1_ooool7oa/K
6`Oo7QhN1oo]kNd7ojNWY`Oo:b/[1ola<C47of9RHP_ooooo1on0P807o`X:2POo5ADE1ol00007of=S
H`OoBDU91omgMgL6ol[:bPgooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`OoiNGU1olY
:BT7o`X:2POo6QXJ1olM7Ad7obTY:@OoB4Q81_m?Cdl5ooooo`Oo92@T1oo7alL7obPX:0Oo4A4A1om1
@D47ob`/;0Oo5ADE1_lc<c<6ooooo`Ko6a/K1om5ADD7ohf=S@Oo;2`/1olF5QH7o`h>3POo:RXZ1_mN
GUh6ooooo`OoBDU91om3@d<=obDU9@Oo7alO1onGUiL7okbl_0Ko/k>c1_ooool7oaPH60Oo9RHV1olN
7Qh7oa<C4`Ko5aLG1ol@4107o`@410Ko?3`l1_ooool7oc0`<0OoSXj>1omjNWX7oibLW0OoDE5A1olM
7Ad6oa`L70KoRh^;1_ooool7oa<C4`Oo00001olS8b<7oeMGE`OoVIVI1omKFe/7of=SH`Ko^KVi1Ooo
ool7ojFUY@Oo@4101om3@d<7od92@POodm?C1oo8b<P7od92@PKoGEeM3Oooool000_ooooo1ooUiND7
obTY:@Oo2PX:1olJ6QX7oadM7@Oo:BTY1om8B4P6odm?C`Gooooo1olT92@7olO7a`Oo:2PX1olA4A47
od51@@Oo;2`/1olE5AD6oc<c<`Kooooo1_lK6a/7odE5A@OoSHf=1ol/;2`7oaHF5POo3Ph>1olZ:RX6
oeiNGPKooooo1om9BDT7od=3@`go9BDU1olO7al7oiNGU`Oo_;bl1_nc/k<6ooooo`Oo61PH1olV9RH7
oahN7POo4a<C1_lG5aL7oa0@40Oo10@41_ll?3`6ooooo`Oo<30`1on>SXh7ogYjNPOoW9bL1omADE47
oadM7@Ko71`L1_n;Rh/6ooooo`Oo4a<C1ol00007ob<S8`OoEeMG1onIVIT7oe]KF`OoHf=S1_ni^KT5
ooooo`OoYJFU1om0@407od=3@`Oo@T921ooCdm<7olS8b0Oo@T921_mMGEd=ooooo`002oooool7onGU
i@Oo:BTY1ol:2PX7oaXJ6POo7AdM1olY:BT7odQ8B0KoCdm?1Oooool7ob@T90OoalO71olX:2P7oa4A
4@Oo@D511ol/;2`7oaDE5@Ko<c<c1_ooool6oa/K6`OoADE51on=SHd7ob`/;0Oo5QHF1ol>3Ph7obXZ
:PKoGUiN1_ooool7odU9B@Oo@d=33OlU9BD7oalO7`OoUiNG1onl_;`6ok>c/`Kooooo1olH61P7obHV
9POo7QhN1olC4a<6oaLG5`Oo410@1ol410@6oc`l?0Kooooo1ol`<307ohj>SPOoNWYj1onLW9`7oe5A
D@Oo7AdM1_lL71`6oh^;R`Kooooo1olC4a<7o`0000Oo8b<S1omGEeL7oiVIV@OoFe]K1omSHf<6okVi
^@Gooooo1onUYJD7od10@0Oo@d=31om2@T87om?Cd`Oob<S81om2@T86oeeMG@gooooo000;ooooo`Oo
iNGU1olY:BT7o`X:2POo6QXJ1olM7Ad7obTY:@OoB4Q81_m?Cdl5ooooo`Oo92@T1oo7alL7obPX:0Oo
4A4A1om1@D47ob`/;0Oo5ADE1_lc<c<6ooooo`Ko6a/K1om5ADD7ohf=S@Oo;2`/1olF5QH7o`h>3POo
:RXZ1_mNGUh6ooooo`OoBDU91om3@d<=obDU9@Oo7alO1onGUiL7okbl_0Ko/k>c1_ooool7oaPH60Oo
9RHV1olN7Qh7oa<C4`Ko5aLG1ol@4107o`@410Ko?3`l1_ooool7oc0`<0OoSXj>1omjNWX7oibLW0Oo
DE5A1olM7Ad6oa`L70KoRh^;1_ooool7oa<C4`Oo00001olS8b<7oeMGE`OoVIVI1omKFe/7of=SH`Ko
^KVi1Oooool7ojFUY@Oo@4101om3@d<7od92@POodm?C1oo8b<P7od92@PKoGEeM3Oooool000_ooooo
1ooUiND7obTY:@Oo2PX:1olJ6QX7oadM7@Oo:BTY1om8B4P6odm?C`Gooooo1olT92@7olO7a`Oo:2PX
1olA4A47od51@@Oo;2`/1olE5AD6oc<c<`Kooooo1_lK6a/7odE5A@OoSHf=1ol/;2`7oaHF5POo3Ph>
1olZ:RX6oeiNGPKooooo1om9BDT7od=3@`go9BDU1olO7al7oiNGU`Oo_;bl1_nc/k<6ooooo`Oo61PH
1olV9RH7oahN7POo4a<C1_lG5aL7oa0@40Oo10@41_ll?3`6ooooo`Oo<30`1on>SXh7ogYjNPOoW9bL
1omADE47oadM7@Ko71`L1_n;Rh/6ooooo`Oo4a<C1ol00007ob<S8`OoEeMG1onIVIT7oe]KF`OoHf=S
1_ni^KT5ooooo`OoYJFU1om0@407od=3@`Oo@T921ooCdm<7olS8b0Oo@T921_mMGEd=ooooo`002ooo
ool7onGUi@Oo:BTY1ol:2PX7oaXJ6POo7AdM1olY:BT7odQ8B0KoCdm?1Oooool7ob@T90OoalO71olX
:2P7oa4A4@Oo@D511ol/;2`7oaDE5@Ko<c<c1_ooool6oa/K6`OoADE51on=SHd7ob`/;0Oo5QHF1ol>
3Ph7obXZ:PKoGUiN1_ooool7odU9B@Oo@d=33OlU9BD7oalO7`OoUiNG1onl_;`6ok>c/`Kooooo1olH
61P7obHV9POo7QhN1olC4a<6oaLG5`Oo410@1ol410@6oc`l?0Kooooo1ol`<307ohj>SPOoNWYj1onL
W9`7oe5AD@Oo7AdM1_lL71`6oh^;R`Kooooo1olC4a<7o`0000Oo8b<S1omGEeL7oiVIV@OoFe]K1omS
Hf<6okVi^@Gooooo1onUYJD7od10@0Oo@d=31om2@T87om?Cd`Oob<S81om2@T86oeeMG@gooooo000;
ooooo`OomOGe1olh>3P7o`<30`Oo4Q8B1olK6a/7ocHf=POoGEeM1_lm?Cd5ooooo`Oo6ATI1ooQhN47
ob8R8POo4A4A1oln?Sh7ob<S8`Oo820P1_li>CT6ooooo`Ko3Ph>1om7AdL7okFe]@Oo?Shn1olH61P7
oa0@40Oo6QXJ1_m/K6`6ooooo`OoIfMW1om5ADD6oahN7POo00001oll?3`7okbl_0OoUiNG1_oCdm<6
ooooo`Oo5QHF3_lX:2P7oaXJ6PKo4a<C1ol820P7o`0000Ko=cLg1_ooool7odi>CPOo4a<C1omnOWh7
ohf=S@Oo>3Ph1olW9bL6oh20P0Ko:2PX1_ooool7o`P820Oo4a<C1ol=3@d7ofm_K`Oof=SH1omZJVX7
oginOPKoRh^;1Oooool7ojNWY`OoBTY:1olk>c/7odQ8B0Ooi^KV1oo9bLT7oc0`<0KoCdm?3Oooool0
00_ooooo1ooemOD7ocPh>0Oo0`<31olB4Q87oa/K6`Oo=SHf1omMGEd6ocdm?@Gooooo1olI6AT7on7Q
h@Oo8R8R1olA4A47ochn?POo8b<S1olP8206ocTi>@Kooooo1_l>3Ph7odM7A`Oo]KFe1oln?Sh7oaPH
60Oo410@1olJ6QX6ofa/K0Kooooo1omWIfL7odE5A@Ko7QhN1ol00007oc`l?0Oo_;bl1onGUiL6om?C
d`Kooooo1olF5QH>obPX:0Oo6QXJ1_lC4a<7o`P820Oo00001_lg=cL6ooooo`OoCTi>1olC4a<7ogin
OPOoSHf=1olh>3P7obLW9`KoP8201_lX:2P6ooooo`Oo20P81olC4a<7o`d=3@OoKfm_1ooHf=P7ofYZ
JPOoOWin1_n;Rh/5ooooo`OoYjNW1om:BTX7oc/k>`OoB4Q81ooVi^H7olW9b@Oo<30`1_m?Cdl=oooo
o`002oooool7ooGem@Oo>3Ph1ol30`<7oa8B4POo6a/K1olf=SH7oeeMG@Ko?Cdm1Oooool7oaTI6@Oo
hN7Q1olR8R87oa4A4@Oo?Shn1olS8b<7ob0P80Ko>CTi1_ooool6o`h>3POoAdM71one]KD7ochn?POo
61PH1ol@4107oaXJ6PKoK6a/1_ooool7ofMWI`OoADE51_lN7Qh7o`0000Oo?3`l1onl_;`7oiNGU`Ko
dm?C1_ooool7oaHF5Pko:2PX1olJ6QX6oa<C4`Oo20P81ol00006ocLg=`Kooooo1om>CTh7oa<C4`Oo
OWin1on=SHd7ocPh>0Oo9bLW1_n0P806obPX:0Kooooo1ol820P7oa<C4`Oo3@d=1om_Kfl7omSHf0Oo
JVYZ1omnOWh6oh^;R`Gooooo1onWYjL7odY:BPOo>c/k1om8B4P7onKViPOobLW91ol`<306odm?C`go
oooo000;ooooo`OomOGe1olh>3P7o`<30`Oo4Q8B1olK6a/7ocHf=POoGEeM1_lm?Cd5ooooo`Oo6ATI
1ooQhN47ob8R8POo4A4A1oln?Sh7ob<S8`Oo820P1_li>CT6ooooo`Ko3Ph>1om7AdL7okFe]@Oo?Shn
1olH61P7oa0@40Oo6QXJ1_m/K6`6ooooo`OoIfMW1om5ADD6oahN7POo00001oll?3`7okbl_0OoUiNG
1_oCdm<6ooooo`Oo5QHF3_lX:2P7oaXJ6PKo4a<C1ol820P7o`0000Ko=cLg1_ooool7odi>CPOo4a<C
1omnOWh7ohf=S@Oo>3Ph1olW9bL6oh20P0Ko:2PX1_ooool7o`P820Oo4a<C1ol=3@d7ofm_K`Oof=SH
1omZJVX7oginOPKoRh^;1Oooool7ojNWY`OoBTY:1olk>c/7odQ8B0Ooi^KV1oo9bLT7oc0`<0KoCdm?
3Oooool000_ooooo1ooemOD7ocPh>0Oo0`<31olB4Q87oa/K6`Oo=SHf1omMGEd6ocdm?@Gooooo1olI
6AT7on7Qh@Oo8R8R1olA4A47ochn?POo8b<S1olP8206ocTi>@Kooooo1_l>3Ph7odM7A`Oo]KFe1oln
?Sh7oaPH60Oo410@1olJ6QX6ofa/K0Kooooo1omWIfL7odE5A@Ko7QhN1ol00007oc`l?0Oo_;bl1onG
UiL6om?Cd`Kooooo1olF5QH>obPX:0Oo6QXJ1_lC4a<7o`P820Oo00001_lg=cL6ooooo`OoCTi>1olC
4a<7oginOPOoSHf=1olh>3P7obLW9`KoP8201_lX:2P6ooooo`Oo20P81olC4a<7o`d=3@OoKfm_1ooH
f=P7ofYZJPOoOWin1_n;Rh/5ooooo`OoYjNW1om:BTX7oc/k>`OoB4Q81ooVi^H7olW9b@Oo<30`1_m?
Cdl=ooooo`002oooool7ooGem@Oo>3Ph1ol30`<7oa8B4POo6a/K1olf=SH7oeeMG@Ko?Cdm1Oooool7
oaTI6@OohN7Q1olR8R87oa4A4@Oo?Shn1olS8b<7ob0P80Ko>CTi1_ooool6o`h>3POoAdM71one]KD7
ochn?POo61PH1ol@4107oaXJ6PKoK6a/1_ooool7ofMWI`OoADE51_lN7Qh7o`0000Oo?3`l1onl_;`7
oiNGU`Kodm?C1_ooool7oaHF5Pko:2PX1olJ6QX6oa<C4`Oo20P81ol00006ocLg=`Kooooo1om>CTh7
oa<C4`OoOWin1on=SHd7ocPh>0Oo9bLW1_n0P806obPX:0Kooooo1ol820P7oa<C4`Oo3@d=1om_Kfl7
omSHf0OoJVYZ1omnOWh6oh^;R`Gooooo1onWYjL7odY:BPOo>c/k1om8B4P7onKViPOobLW91ol`<306
odm?C`gooooo000;ooooo`OomOGe1olh>3P7o`<30`Oo4Q8B1olK6a/7ocHf=POoGEeM1_lm?Cd5oooo
o`Oo6ATI1ooQhN47ob8R8POo4A4A1oln?Sh7ob<S8`Oo820P1_li>CT6ooooo`Ko3Ph>1om7AdL7okFe
]@Oo?Shn1olH61P7oa0@40Oo6QXJ1_m/K6`6ooooo`OoIfMW1om5ADD6oahN7POo00001oll?3`7okbl
_0OoUiNG1_oCdm<6ooooo`Oo5QHF3_lX:2P7oaXJ6PKo4a<C1ol820P7o`0000Ko=cLg1_ooool7odi>
CPOo4a<C1omnOWh7ohf=S@Oo>3Ph1olW9bL6oh20P0Ko:2PX1_ooool7o`P820Oo4a<C1ol=3@d7ofm_
K`Oof=SH1omZJVX7oginOPKoRh^;1Oooool7ojNWY`OoBTY:1olk>c/7odQ8B0Ooi^KV1oo9bLT7oc0`
<0KoCdm?3Oooool000_ooooo1ookno/7ob/[:`Oo1PH61ol:2PX7oaXJ6POo<S8b1om3@d<6odE5A@Go
oooo1olT92@7on3Ph0ko51@D1olg=cL7oadM7@Oo5aLG1_l[:b/6ooooo`Ko1PH61olS8b<7okZj^POo
Jf][1olO7al7o``<30Oo=cLg1_miNGT6ooooo`Oo?3`l1ole=CD6oa/K6`Oo<30`1olg=cL7ok^k^`Oo
/k>c1_nh^;P6ooooo`Oo7QhN1olb<S87ob<S8`Oo6QXJ1_lE5AD7o`<30`Oo20P81_ln?Sh6ooooo`Oo
8R8R1oo9bLT7ohb<S0OoMWIf1ol^;Rh7ochn?PKo4a<C1_mWIfL6ooooo`Oo0`<31ol<30`7o`X:2POo
JFUY1oo?cll7oeUIF@OoEeMG1_nMWId5ooooo`Oo]kNg1om:BTX7ocTi>@Oo<c<c1oofm_H7ol_;b`Oo
9RHV1_mJFUX=ooooo`002oooool7oo_kn`Oo:b/[1ol61PH7o`X:2POo6QXJ1olb<S87od=3@`KoADE5
1Oooool7ob@T90Ooh>3P3_lD51@7ocLg=`Oo7AdM1olG5aL6ob/[:`Kooooo1_l61PH7ob<S8`Oo^[Zj
1om[Jf/7oalO7`Oo30`<1olg=cL6ogUiN@Kooooo1oll?3`7ocDe=@Ko6a/K1ol`<307ocLg=`Oo^k^k
1onc/k<6okRh^0Kooooo1olN7Qh7oc8b<POo8b<S1olJ6QX6oaDE5@Oo0`<31ol820P6ochn?PKooooo
1olR8R87olW9b@OoS8b<1omfMWH7obh^;POo?Shn1_lC4a<6ofMWI`Kooooo1ol30`<7o``<30Oo2PX:
1omYJFT7olo?c`OoFEUI1omGEeL6oifMW@Gooooo1ong]kL7odY:BPOo>CTi1olc<c<7ooKfmPOobl_;
1olV9RH6oeYJFPgooooo000;ooooo`Oono_k1ol[:b/7o`H61POo2PX:1olJ6QX7oc8b<POo@d=31_m5
ADD5ooooo`Oo92@T1ooPh>0>oa@D50Oo=cLg1olM7Ad7oaLG5`Ko:b/[1_ooool6o`H61POo8b<S1onj
^[X7of][J`Oo7alO1ol<30`7ocLg=`KoNGUi1_ooool7oc`l?0Oo=CDe1_lK6a/7oc0`<0Oo=cLg1onk
^k/7ok>c/`Ko^;Rh1_ooool7oahN7POo<S8b1olS8b<7oaXJ6PKo5ADE1ol30`<7o`P820Ko?Shn1_oo
ool7ob8R8POobLW91on<S8`7ogIfMPOo;Rh^1oln?Sh6oa<C4`KoIfMW1_ooool7o`<30`Oo30`<1ol:
2PX7ofUYJ@Ooclo?1omIFET7oeMGE`KoWIfM1Oooool7okNg]`OoBTY:1oli>CT7oc<c<`Oom_Kf1oo;
bl/7obHV9PKoFUYJ3Oooool000_ooooo1ookno/7ob/[:`Oo1PH61ol:2PX7oaXJ6POo<S8b1om3@d<6
odE5A@Gooooo1olT92@7on3Ph0ko51@D1olg=cL7oadM7@Oo5aLG1_l[:b/6ooooo`Ko1PH61olS8b<7
okZj^POoJf][1olO7al7o``<30Oo=cLg1_miNGT6ooooo`Oo?3`l1ole=CD6oa/K6`Oo<30`1olg=cL7
ok^k^`Oo/k>c1_nh^;P6ooooo`Oo7QhN1olb<S87ob<S8`Oo6QXJ1_lE5AD7o`<30`Oo20P81_ln?Sh6
ooooo`Oo8R8R1oo9bLT7ohb<S0OoMWIf1ol^;Rh7ochn?PKo4a<C1_mWIfL6ooooo`Oo0`<31ol<30`7
o`X:2POoJFUY1oo?cll7oeUIF@OoEeMG1_nMWId5ooooo`Oo]kNg1om:BTX7ocTi>@Oo<c<c1oofm_H7
ol_;b`Oo9RHV1_mJFUX=ooooo`002oooool7oo_kn`Oo:b/[1ol61PH7o`X:2POo6QXJ1olb<S87od=3
@`KoADE51Oooool7ob@T90Ooh>3P3_lD51@7ocLg=`Oo7AdM1olG5aL6ob/[:`Kooooo1_l61PH7ob<S
8`Oo^[Zj1om[Jf/7oalO7`Oo30`<1olg=cL6ogUiN@Kooooo1oll?3`7ocDe=@Ko6a/K1ol`<307ocLg
=`Oo^k^k1onc/k<6okRh^0Kooooo1olN7Qh7oc8b<POo8b<S1olJ6QX6oaDE5@Oo0`<31ol820P6ochn
?PKooooo1olR8R87olW9b@OoS8b<1omfMWH7obh^;POo?Shn1_lC4a<6ofMWI`Kooooo1ol30`<7o``<
30Oo2PX:1omYJFT7olo?c`OoFEUI1omGEeL6oifMW@Gooooo1ong]kL7odY:BPOo>CTi1olc<c<7ooKf
mPOobl_;1olV9RH6oeYJFPgooooo000;ooooo`Oono_k1ol[:b/7o`H61POo2PX:1olJ6QX7oc8b<POo
@d=31_m5ADD5ooooo`Oo92@T1ooPh>0>oa@D50Oo=cLg1olM7Ad7oaLG5`Ko:b/[1_ooool6o`H61POo
8b<S1onj^[X7of][J`Oo7alO1ol<30`7ocLg=`KoNGUi1_ooool7oc`l?0Oo=CDe1_lK6a/7oc0`<0Oo
=cLg1onk^k/7ok>c/`Ko^;Rh1_ooool7oahN7POo<S8b1olS8b<7oaXJ6PKo5ADE1ol30`<7o`P820Ko
?Shn1_ooool7ob8R8POobLW91on<S8`7ogIfMPOo;Rh^1oln?Sh6oa<C4`KoIfMW1_ooool7o`<30`Oo
30`<1ol:2PX7ofUYJ@Ooclo?1omIFET7oeMGE`KoWIfM1Oooool7okNg]`OoBTY:1oli>CT7oc<c<`Oo
m_Kf1oo;bl/7obHV9PKoFUYJ3Oooool000_ooooo1ookno/7ob/[:`Oo1PH61ol:2PX7oaXJ6POo<S8b
1om3@d<6odE5A@Gooooo1olT92@7on3Ph0ko51@D1olg=cL7oadM7@Oo5aLG1_l[:b/6ooooo`Ko1PH6
1olS8b<7okZj^POoJf][1olO7al7o``<30Oo=cLg1_miNGT6ooooo`Oo?3`l1ole=CD6oa/K6`Oo<30`
1olg=cL7ok^k^`Oo/k>c1_nh^;P6ooooo`Oo7QhN1olb<S87ob<S8`Oo6QXJ1_lE5AD7o`<30`Oo20P8
1_ln?Sh6ooooo`Oo8R8R1oo9bLT7ohb<S0OoMWIf1ol^;Rh7ochn?PKo4a<C1_mWIfL6ooooo`Oo0`<3
1ol<30`7o`X:2POoJFUY1oo?cll7oeUIF@OoEeMG1_nMWId5ooooo`Oo]kNg1om:BTX7ocTi>@Oo<c<c
1oofm_H7ol_;b`Oo9RHV1_mJFUX=ooooo`002oooool7oo[jnPOo=CDe1ol30`<7o`h>3POo51@D1ola
<C47odI6APKoADE51Oooool7oa@D50Oooooo1ol<30`7o`410@Oo<C4a1olJ6QX7obLW9`Ko:b/[1_oo
ool6o`<30`Oo;Rh^1oooool7oeUIF@Oo6a/K1olI6AT7ob<S8`KoKfm_1_ooool7odQ8B0Oo:BTY1_l_
;bl7o`@410Oo@T921ooYjNT7og]kN`Kod];B1_ooool7o`X:2POo7QhN1olA4A47oadM7@Ko4Q8B1ol<
30`7o`h>3PKoFe]K1_ooool7oemOG`Oo6ATI1on5QHD7oh20P0Oo6QXJ1olH61P6ol71`@Ko:RXZ1_oo
ool7o`820POo1`L71ol20P87ofi^KPOooooo1omOGel7ofEUI@KoSHf=1Oooool7ok2`/0OoEeMG1olY
:BT7odQ8B0Oooooo1oo3`l<7oa8B4PKoDe=C3Oooool000_ooooo1oojn_X7ocDe=@Oo0`<31ol>3Ph7
oa@D50Oo<C4a1om6ATH6odE5A@Gooooo1olD51@7ooooo`Oo30`<1ol10@47oc4a<@Oo6QXJ1olW9bL6
ob/[:`Kooooo1_l30`<7obh^;POooooo1omIFET7oa/K6`Oo6ATI1olS8b<6ofm_K`Kooooo1om8B4P7
obTY:@Ko;bl_1ol410@7od92@POojNWY1omkNg/6om;BdPKooooo1ol:2PX7oahN7POo4A4A1olM7Ad6
oa8B4POo30`<1ol>3Ph6oe]KF`Kooooo1omOGel7oaTI6@OoQHF51on0P807oaXJ6POo61PH1_o1`L46
obXZ:PKooooo1ol20P87o`L71`Oo0P821om^KVh7ooooo`OoGemO1omUIFD6ohf=S@Gooooo1on`/;07
oeMGE`Oo:BTY1om8B4P7ooooo`Oo`l?31olB4Q86oe=CD`gooooo000;ooooo`Oon_[j1ole=CD7o`<3
0`Oo3Ph>1olD51@7oc4a<@OoATI61_m5ADD5ooooo`Oo51@D1oooool7o``<30Oo0@411ola<C47oaXJ
6POo9bLW1_l[:b/6ooooo`Ko0`<31ol^;Rh7ooooo`OoFEUI1olK6a/7oaTI6@Oo8b<S1_m_Kfl6oooo
o`OoB4Q81olY:BT6obl_;`Oo10@41om2@T87onWYj@OoNg]k1_oBd]86ooooo`Oo2PX:1olN7Qh7oa4A
4@Oo7AdM1_lB4Q87o``<30Oo3Ph>1_mKFe/6ooooo`OoGemO1olI6AT7ohF5Q@OoP8201olJ6QX7oaPH
60Ko`L711_lZ:RX6ooooo`Oo0P821ol71`L7o`820POoKVi^1oooool7oemOG`OoIFEU1_n=SHd5oooo
o`Oo/;2`1omGEeL7obTY:@OoB4Q81oooool7ol?3``Oo4Q8B1_mCDe<=ooooo`002oooool7oo[jnPOo
=CDe1ol30`<7o`h>3POo51@D1ola<C47odI6APKoADE51Oooool7oa@D50Oooooo1ol<30`7o`410@Oo
<C4a1olJ6QX7obLW9`Ko:b/[1_ooool6o`<30`Oo;Rh^1oooool7oeUIF@Oo6a/K1olI6AT7ob<S8`Ko
Kfm_1_ooool7odQ8B0Oo:BTY1_l_;bl7o`@410Oo@T921ooYjNT7og]kN`Kod];B1_ooool7o`X:2POo
7QhN1olA4A47oadM7@Ko4Q8B1ol<30`7o`h>3PKoFe]K1_ooool7oemOG`Oo6ATI1on5QHD7oh20P0Oo
6QXJ1olH61P6ol71`@Ko:RXZ1_ooool7o`820POo1`L71ol20P87ofi^KPOooooo1omOGel7ofEUI@Ko
SHf=1Oooool7ok2`/0OoEeMG1olY:BT7odQ8B0Oooooo1oo3`l<7oa8B4PKoDe=C3Oooool000_ooooo
1oojn_X7ocDe=@Oo0`<31ol>3Ph7oa@D50Oo<C4a1om6ATH6odE5A@Gooooo1olD51@7ooooo`Oo30`<
1ol10@47oc4a<@Oo6QXJ1olW9bL6ob/[:`Kooooo1_l30`<7obh^;POooooo1omIFET7oa/K6`Oo6ATI
1olS8b<6ofm_K`Kooooo1om8B4P7obTY:@Ko;bl_1ol410@7od92@POojNWY1omkNg/6om;BdPKooooo
1ol:2PX7oahN7POo4A4A1olM7Ad6oa8B4POo30`<1ol>3Ph6oe]KF`Kooooo1omOGel7oaTI6@OoQHF5
1on0P807oaXJ6POo61PH1_o1`L46obXZ:PKooooo1ol20P87o`L71`Oo0P821om^KVh7ooooo`OoGemO
1omUIFD6ohf=S@Gooooo1on`/;07oeMGE`Oo:BTY1om8B4P7ooooo`Oo`l?31olB4Q86oe=CD`gooooo
000;ooooo`Oon_[j1ole=CD7o`<30`Oo3Ph>1olD51@7oc4a<@OoATI61_m5ADD5ooooo`Oo51@D1ooo
ool7o``<30Oo0@411ola<C47oaXJ6POo9bLW1_l[:b/6ooooo`Ko0`<31ol^;Rh7ooooo`OoFEUI1olK
6a/7oaTI6@Oo8b<S1_m_Kfl6ooooo`OoB4Q81olY:BT6obl_;`Oo10@41om2@T87onWYj@OoNg]k1_oB
d]86ooooo`Oo2PX:1olN7Qh7oa4A4@Oo7AdM1_lB4Q87o``<30Oo3Ph>1_mKFe/6ooooo`OoGemO1olI
6AT7ohF5Q@OoP8201olJ6QX7oaPH60Ko`L711_lZ:RX6ooooo`Oo0P821ol71`L7o`820POoKVi^1ooo
ool7oemOG`OoIFEU1_n=SHd5ooooo`Oo/;2`1omGEeL7obTY:@OoB4Q81oooool7ol?3``Oo4Q8B1_mC
De<=ooooo`004_ooool7oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7
on?Sh`Oo1@D51ol@4107obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7
oaPH60Oo2PX:1ol`<306og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6
ojJVYPKooooo1olC4a<7oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7
on_[j`OoTY:B1olo?cl7oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7
oe=CD`OoD51@1_nj^[X5ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=
ooooo`004_ooool7oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?S
h`Oo1@D51ol@4107obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH
60Oo2PX:1ol`<306og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJV
YPKooooo1olC4a<7oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[
j`OoTY:B1olo?cl7oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=C
D`OoD51@1_nj^[X5ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=oooo
o`004_ooool7oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?Sh`Oo
1@D51ol@4107obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH60Oo
2PX:1ol`<306og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJVYPKo
oooo1olC4a<7oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[j`Oo
TY:B1olo?cl7oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=CD`Oo
D51@1_nj^[X5ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=ooooo`00
4_ooool7oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?Sh`Oo1@D5
1ol@4107obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH60Oo2PX:
1ol`<306og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJVYPKooooo
1olC4a<7oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[j`OoTY:B
1olo?cl7oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=CD`OoD51@
1_nj^[X5ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=ooooo`004_oo
ool7oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?Sh`Oo1@D51ol@
4107obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH60Oo2PX:1ol`
<306og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJVYPKooooo1olC
4a<7oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[j`OoTY:B1olo
?cl7oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=CD`OoD51@1_nj
^[X5ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=ooooo`004_ooool7
oc4a<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?Sh`Oo1@D51ol@4107
obl_;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH60Oo2PX:1ol`<306
og]kN`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJVYPKooooo1olC4a<7
oaDE5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[j`OoTY:B1olo?cl7
oahN7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=CD`OoD51@1_nj^[X5
ooooo`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=ooooo`004_ooool7oc4a
<@Oo2PX:1ol00007oa8B4POo7AdM1olb<S86od51@@Gooooo1ol^;Rh7on?Sh`Oo1@D51ol@4107obl_
;`Oo6ATI1olY:BT6obh^;PKooooo1_l?3`l7oalO7`Oo_;bl1om=CDd7oaPH60Oo2PX:1ol`<306og]k
N`Kooooo1olc<c<7obPX:0Ko92@T1om4A4@7ofIVIPOoa<C41omhN7P6ojJVYPKooooo1olC4a<7oaDE
5@Oo7alO1olM7Ad6oaHF5POo1PH61olE5AD6oh:2PPKooooo1ol/;2`7on_[j`OoTY:B1olo?cl7oahN
7POoEEEE1_lE5AD6od92@PKooooo1olA4A4>oa0@40OoFUYJ1ooKfm/7oe=CD`OoD51@1_nj^[X5oooo
o`Oo[:b/1omEEED7obTY:@Oo=cLg1oolo?`7okno_`Oo5QHF1_mADE4=ooooo`002oooool7om[JfPOo
?clo1ol:2PX7o`/;2`Oo61PH1olD51@7od92@PKoCDe=1Oooool7obHV9POoj^[Z1ol92@T7o`0000Oo
=CDe1ol@4107oc<c<`Ko8R8R1_ooool6o`P820Oo9RHV1omWIfL7obl_;`Oo5aLG1olT92@7obHV9PKo
IFEU1_ooool7ocHf=POo61PH1_mKFe/7oa@D50OoJf][1oooool7odA4A0Ko]KFe1_ooool7oalO7`Oo
4A4A3_lE5AD6oaTI6@Oo5QHF1olB4Q86on3Ph0Kooooo1omRHV87oc0`<0OoMWIf1omcLg<7o`410@Oo
9RHV1_oKfm/6ob0P80Kooooo1olP8207oaHF5POo61PH1ombLW87om7Ad@OoAdM71omBDU86olK6aPGo
oooo1onHV9P7oeQHF0Oo410@1omIFET7on[ZjPOoYJFU1ol;2`/6ocdm?@gooooo000;ooooo`Oof][J
1olo?cl7o`X:2POo2`/;1olH61P7oa@D50Oo@T921_m=CDd5ooooo`Oo9RHV1ooZj^X7o`T92@Oo0000
1ole=CD7oa0@40Oo<c<c1_lR8R86ooooo`Ko20P81olV9RH7ofMWI`Oo;bl_1olG5aL7ob@T90Oo9RHV
1_mUIFD6ooooo`Oo=SHf1olH61P6oe]KF`Oo51@D1om[Jf/7ooooo`OoA4A41_ne]KD6ooooo`Oo7alO
1olA4A4>oaDE5@Ko6ATI1olF5QH7oa8B4PKoh>3P1_ooool7of9RHPOo<30`1omfMWH7og=cL`Oo0@41
1olV9RH6om_Kf`Ko820P1_ooool7ob0P80Oo5QHF1olH61P7og9bLPOodM7A1om7AdL7oe9BDPKoa/K6
1Oooool7oiRHV0OoF5QH1ol@4107oeUIF@Ooj^[Z1onUYJD7o`/;2`Ko?Cdm3Oooool000_ooooo1ooJ
f]X7oclo?`Oo2PX:1ol;2`/7oaPH60Oo51@D1om2@T86ode=C@Gooooo1olV9RH7on[ZjPOo2@T91ol0
0007ocDe=@Oo410@1olc<c<6ob8R8PKooooo1_l820P7obHV9POoIfMW1ol_;bl7oaLG5`Oo92@T1olV
9RH6ofEUI@Kooooo1olf=SH7oaPH60KoFe]K1olD51@7of][J`Oooooo1om4A4@6okFe]@Kooooo1olO
7al7oa4A4@ko5ADE1_lI6AT7oaHF5POo4Q8B1_oPh>06ooooo`OoHV9R1ol`<307ogIfMPOoLg=c1ol1
0@47obHV9PKofm_K1_lP8206ooooo`Oo820P1olF5QH7oaPH60OoLW9b1ooAdM47odM7A`OoDU9B1_o6
a/H5ooooo`OoV9RH1omHF5P7oa0@40OoFEUI1ooZj^X7ojFUY@Oo2`/;1_lm?Cd=ooooo`002oooool7
om[JfPOo?clo1ol:2PX7o`/;2`Oo61PH1olD51@7od92@PKoCDe=1Oooool7obHV9POoj^[Z1ol92@T7
o`0000Oo=CDe1ol@4107oc<c<`Ko8R8R1_ooool6o`P820Oo9RHV1omWIfL7obl_;`Oo5aLG1olT92@7
obHV9PKoIFEU1_ooool7ocHf=POo61PH1_mKFe/7oa@D50OoJf][1oooool7odA4A0Ko]KFe1_ooool7
oalO7`Oo4A4A3_lE5AD6oaTI6@Oo5QHF1olB4Q86on3Ph0Kooooo1omRHV87oc0`<0OoMWIf1omcLg<7
o`410@Oo9RHV1_oKfm/6ob0P80Kooooo1olP8207oaHF5POo61PH1ombLW87om7Ad@OoAdM71omBDU86
olK6aPGooooo1onHV9P7oeQHF0Oo410@1omIFET7on[ZjPOoYJFU1ol;2`/6ocdm?@gooooo000;oooo
o`Oof][J1olo?cl7o`X:2POo2`/;1olH61P7oa@D50Oo@T921_m=CDd5ooooo`Oo9RHV1ooZj^X7o`T9
2@Oo00001ole=CD7oa0@40Oo<c<c1_lR8R86ooooo`Ko20P81olV9RH7ofMWI`Oo;bl_1olG5aL7ob@T
90Oo9RHV1_mUIFD6ooooo`Oo=SHf1olH61P6oe]KF`Oo51@D1om[Jf/7ooooo`OoA4A41_ne]KD6oooo
o`Oo7alO1olA4A4>oaDE5@Ko6ATI1olF5QH7oa8B4PKoh>3P1_ooool7of9RHPOo<30`1omfMWH7og=c
L`Oo0@411olV9RH6om_Kf`Ko820P1_ooool7ob0P80Oo5QHF1olH61P7og9bLPOodM7A1om7AdL7oe9B
DPKoa/K61Oooool7oiRHV0OoF5QH1ol@4107oeUIF@Ooj^[Z1onUYJD7o`/;2`Ko?Cdm3Oooool000_o
oooo1ooJf]X7oclo?`Oo2PX:1ol;2`/7oaPH60Oo51@D1om2@T86ode=C@Gooooo1olV9RH7on[ZjPOo
2@T91ol00007ocDe=@Oo410@1olc<c<6ob8R8PKooooo1_l820P7obHV9POoIfMW1ol_;bl7oaLG5`Oo
92@T1olV9RH6ofEUI@Kooooo1olf=SH7oaPH60KoFe]K1olD51@7of][J`Oooooo1om4A4@6okFe]@Ko
oooo1olO7al7oa4A4@ko5ADE1_lI6AT7oaHF5POo4Q8B1_oPh>06ooooo`OoHV9R1ol`<307ogIfMPOo
Lg=c1ol10@47obHV9PKofm_K1_lP8206ooooo`Oo820P1olF5QH7oaPH60OoLW9b1ooAdM47odM7A`Oo
DU9B1_o6a/H5ooooo`OoV9RH1omHF5P7oa0@40OoFEUI1ooZj^X7ojFUY@Oo2`/;1_lm?Cd=ooooo`00
2oooool7om[JfPOo?clo1ol:2PX7o`/;2`Oo61PH1olD51@7od92@PKoCDe=1Oooool7obHV9POoj^[Z
1ol92@T7o`0000Oo=CDe1ol@4107oc<c<`Ko8R8R1_ooool6o`P820Oo9RHV1omWIfL7obl_;`Oo5aLG
1olT92@7obHV9PKoIFEU1_ooool7ocHf=POo61PH1_mKFe/7oa@D50OoJf][1oooool7odA4A0Ko]KFe
1_ooool7oalO7`Oo4A4A3_lE5AD6oaTI6@Oo5QHF1olB4Q86on3Ph0Kooooo1omRHV87oc0`<0OoMWIf
1omcLg<7o`410@Oo9RHV1_oKfm/6ob0P80Kooooo1olP8207oaHF5POo61PH1ombLW87om7Ad@OoAdM7
1omBDU86olK6aPGooooo1onHV9P7oeQHF0Oo410@1omIFET7on[ZjPOoYJFU1ol;2`/6ocdm?@gooooo
000;ooooo`OoiNGU1om3@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6
a/H7o`h>3POo61PH1olb<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF
5QH7o`P820Oo>CTi1_m<C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7
QhL6ooooo`Oo:2PX1olD51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;
Rh/7oa0@40Oo71`L1omHF5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?
Cdl6okZj^PGooooo1on@T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;
ooooo`OoiNGU1om3@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7
o`h>3POo61PH1olb<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7
o`P820Oo>CTi1_m<C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6
ooooo`Oo:2PX1olD51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7
oa0@40Oo71`L1omHF5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6
okZj^PGooooo1on@T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;oooo
o`OoiNGU1om3@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7o`h>
3POo61PH1olb<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7o`P8
20Oo>CTi1_m<C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6oooo
o`Oo:2PX1olD51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7oa0@
40Oo71`L1omHF5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6okZj
^PGooooo1on@T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;ooooo`Oo
iNGU1om3@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7o`h>3POo
61PH1olb<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7o`P820Oo
>CTi1_m<C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6ooooo`Oo
:2PX1olD51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7oa0@40Oo
71`L1omHF5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6okZj^PGo
oooo1on@T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;ooooo`OoiNGU
1om3@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7o`h>3POo61PH
1olb<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7o`P820Oo>CTi
1_m<C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6ooooo`Oo:2PX
1olD51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7oa0@40Oo71`L
1omHF5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6okZj^PGooooo
1on@T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;ooooo`OoiNGU1om3
@d<7oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7o`h>3POo61PH1olb
<S87oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7o`P820Oo>CTi1_m<
C4`6ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6ooooo`Oo:2PX1olD
51@7ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7oa0@40Oo71`L1omH
F5P6obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6okZj^PGooooo1on@
T907oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;ooooo`OoiNGU1om3@d<7
oaTI6@Oo2PX:1olI6AT7oadM7@Oo<30`1_m=CDd5ooooo`Oo?3`l1oo6a/H7o`h>3POo61PH1olb<S87
oalO7`Oo=CDe1_lX:2P6ooooo`Ko1@D51olO7al7od=3@`Oo61PH1olF5QH7o`P820Oo>CTi1_m<C4`6
ooooo`Oo>3Ph1olR8R86ob`/;0OoJ6QX1on6QXH7okZj^POoEUIF1_n7QhL6ooooo`Oo:2PX1olD51@7
ob<S8`Oo61PH1_lA4A47oaTI6@Oo5aLG3?ooool7od=3@`OogmoO1on;Rh/7oa0@40Oo71`L1omHF5P6
obXZ:PKo92@T1_ooool>ob4Q8@Oo6ATI1omMGEd7oj2PX0Oo>CTi1om?Cdl6okZj^PGooooo1on@T907
oeADE0Oo6QXJ1om>CTh7onOWi`OoV9RH1olC4a<6ocdm?@gooooo000;ooooo`Ooa/K61olo?cl7oa@D
50Oo3`l?1olO7al7obPX:0Oo>SXj1_mJFUX5ooooo`Oo;bl_1oo7alL7o`H61POo30`<1oll?3`7oaXJ
6POo<S8b1_lN7Qh6ooooo`Ko00001ol/;2`7ob/[:`Oo7alO1ol:2PX7o`D51@Oo8b<S1_m@D506oooo
o`Oo:2PX1olG5aL6of5QH@Oo:RXZ1om`L707om[JfPOo<C4a1_nCTi<6ooooo`Oo410@1olB4Q87oaHF
5POo3`l?1_lC4a<7oaHF5POo5aLG1_maLG46ooooo`OoLG5a1ol`<307oeUIF@OoN7Qh1ol00007obTY
:@Kooooo1_lS8b<6ooooo`Oo8b<S1olD51@7oaLG5`OoGEeM1omiNGT7ocDe=@Oo=cLg1_o8b<P5oooo
o`OoOGem1omHF5P7o`0000OoH61P1oo:b/X7ohR8R0Oo0P821_l/;2`=ooooo`002oooool7olK6aPOo
?clo1olD51@7o`l?3`Oo7alO1olX:2P7ocXj>PKoFUYJ1Oooool7obl_;`OoalO71ol61PH7o``<30Oo
?3`l1olJ6QX7oc8b<PKo7QhN1_ooool6o`0000Oo;2`/1ol[:b/7oalO7`Oo2PX:1ol51@D7ob<S8`Ko
D51@1_ooool7obPX:0Oo5aLG1_mQHF47obXZ:POoL71`1ooJf]X7oc4a<@KoTi>C1_ooool7oa0@40Oo
4Q8B1olF5QH7o`l?3`Ko4a<C1olF5QH7oaLG5`KoLG5a1_ooool7og5aL@Oo<30`1omIFET7ogQhN0Oo
00001olY:BT6ooooo`Ko8b<S1_ooool7ob<S8`Oo51@D1olG5aL7oeeMG@OoNGUi1ole=CD7ocLg=`Ko
b<S81Oooool7ogemO@OoF5QH1ol00007of1PH0Oob/[:1on8R8P7o`820PKo;2`/3Oooool000_ooooo
1oo6a/H7oclo?`Oo51@D1ol?3`l7oalO7`Oo:2PX1olj>SX6oeYJFPGooooo1ol_;bl7olO7a`Oo1PH6
1ol<30`7oc`l?0Oo6QXJ1olb<S86oahN7PKooooo1_l00007ob`/;0Oo:b/[1olO7al7o`X:2POo1@D5
1olS8b<6oe1@D0Kooooo1olX:2P7oaLG5`KoHF5Q1olZ:RX7og1`L0Oof][J1ola<C46oi>CT`Kooooo
1ol@4107oa8B4POo5QHF1ol?3`l6oa<C4`Oo5QHF1olG5aL6og5aL@Kooooo1omaLG47oc0`<0OoFEUI
1omhN7P7o`0000Oo:BTY1_ooool6ob<S8`Kooooo1olS8b<7oa@D50Oo5aLG1omMGEd7ogUiN@Oo=CDe
1olg=cL6olS8b0Gooooo1ommOGd7oeQHF0Oo00001omPH607ol[:bPOoR8R81ol20P86ob`/;0gooooo
000;ooooo`Ooa/K61olo?cl7oa@D50Oo3`l?1olO7al7obPX:0Oo>SXj1_mJFUX5ooooo`Oo;bl_1oo7
alL7o`H61POo30`<1oll?3`7oaXJ6POo<S8b1_lN7Qh6ooooo`Ko00001ol/;2`7ob/[:`Oo7alO1ol:
2PX7o`D51@Oo8b<S1_m@D506ooooo`Oo:2PX1olG5aL6of5QH@Oo:RXZ1om`L707om[JfPOo<C4a1_nC
Ti<6ooooo`Oo410@1olB4Q87oaHF5POo3`l?1_lC4a<7oaHF5POo5aLG1_maLG46ooooo`OoLG5a1ol`
<307oeUIF@OoN7Qh1ol00007obTY:@Kooooo1_lS8b<6ooooo`Oo8b<S1olD51@7oaLG5`OoGEeM1omi
NGT7ocDe=@Oo=cLg1_o8b<P5ooooo`OoOGem1omHF5P7o`0000OoH61P1oo:b/X7ohR8R0Oo0P821_l/
;2`=ooooo`002oooool7olK6aPOo?clo1olD51@7o`l?3`Oo7alO1olX:2P7ocXj>PKoFUYJ1Oooool7
obl_;`OoalO71ol61PH7o``<30Oo?3`l1olJ6QX7oc8b<PKo7QhN1_ooool6o`0000Oo;2`/1ol[:b/7
oalO7`Oo2PX:1ol51@D7ob<S8`KoD51@1_ooool7obPX:0Oo5aLG1_mQHF47obXZ:POoL71`1ooJf]X7
oc4a<@KoTi>C1_ooool7oa0@40Oo4Q8B1olF5QH7o`l?3`Ko4a<C1olF5QH7oaLG5`KoLG5a1_ooool7
og5aL@Oo<30`1omIFET7ogQhN0Oo00001olY:BT6ooooo`Ko8b<S1_ooool7ob<S8`Oo51@D1olG5aL7
oeeMG@OoNGUi1ole=CD7ocLg=`Kob<S81Oooool7ogemO@OoF5QH1ol00007of1PH0Oob/[:1on8R8P7
o`820PKo;2`/3Oooool000_ooooo1oo6a/H7oclo?`Oo51@D1ol?3`l7oalO7`Oo:2PX1olj>SX6oeYJ
FPGooooo1ol_;bl7olO7a`Oo1PH61ol<30`7oc`l?0Oo6QXJ1olb<S86oahN7PKooooo1_l00007ob`/
;0Oo:b/[1olO7al7o`X:2POo1@D51olS8b<6oe1@D0Kooooo1olX:2P7oaLG5`KoHF5Q1olZ:RX7og1`
L0Oof][J1ola<C46oi>CT`Kooooo1ol@4107oa8B4POo5QHF1ol?3`l6oa<C4`Oo5QHF1olG5aL6og5a
L@Kooooo1omaLG47oc0`<0OoFEUI1omhN7P7o`0000Oo:BTY1_ooool6ob<S8`Kooooo1olS8b<7oa@D
50Oo5aLG1omMGEd7ogUiN@Oo=CDe1olg=cL6olS8b0Gooooo1ommOGd7oeQHF0Oo00001omPH607ol[:
bPOoR8R81ol20P86ob`/;0gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`Oo5QHF1olS
8b<7oc8b<POo5ADE1om0@407okfm_@OoD51@1_miNGT5ooooo`Oo<c<c1on6QXH7ocTi>@Oo92@T1olF
5QH7oeaLG0OoK6a/1_lK6a/6ooooo`Ko?Shn1ol;2`/7omoOg`Oo`/;21omZJVX7oahN7POoJ6QX1_oj
n_X6ooooo`Oo8R8R1ole=CD6oa@D50OoMWIf1olK6a/7ofIVIPOoalO71_lY:BT6ooooo`Oo7alO1old
=3@7oaHF5POo<30`1_mHF5P7oaTI6@Oo8R8R1_oUiND6ooooo`Oo9RHV1olW9bL7ok>c/`Oo_Kfm1olP
8207oc8b<PKo;bl_1_lW9bL6ooooo`OoP8201omOGel7oa8B4POo00001omNGUh7okno_`OoJVYZ1_mk
Ng/5ooooo`OoLg=c1oo4a<@7onOWi`Oo71`L1om<C4`7odE5A@OoJ6QX1_lY:BT=ooooo`002oooool7
oaHF5POo8b<S1olb<S87oaDE5@Oo@4101onm_Kd7oe1@D0KoNGUi1Oooool7oc<c<`OoQXJ61oli>CT7
ob@T90Oo5QHF1omLG5`7ofa/K0Ko6a/K1_ooool6ochn?POo2`/;1ooOgml7ol;2`POoJVYZ1olN7Qh7
ofQXJ0Kon_[j1_ooool7ob8R8POo=CDe1_lD51@7ogIfMPOo6a/K1omVIVH7olO7a`Ko:BTY1_ooool7
oalO7`Oo=3@d1olF5QH7oc0`<0KoF5QH1olI6AT7ob8R8PKoiNGU1_ooool7obHV9POo9bLW1onc/k<7
okfm_@Oo820P1olb<S86obl_;`Ko9bLW1_ooool7oh20P0OoGemO1olB4Q87o`0000OoGUiN1ono_kl7
ofYZJPKoNg]k1Oooool7og=cL`Ooa<C41ooWinL7oa`L70OoC4a<1om5ADD7ofQXJ0Ko:BTY3Oooool0
00_ooooo1olF5QH7ob<S8`Oo<S8b1olE5AD7od10@0Oo_Kfm1om@D506ogUiN@Gooooo1olc<c<7ohJ6
QPOo>CTi1olT92@7oaHF5POoG5aL1om/K6`6oa/K6`Kooooo1_ln?Sh7o`/;2`OogmoO1oo2`/87ofYZ
JPOo7QhN1omXJ6P6oo[jnPKooooo1olR8R87ocDe=@Ko51@D1omfMWH7oa/K6`OoIVIV1oo7alL6obTY
:@Kooooo1olO7al7oc@d=0Oo5QHF1ol`<306oeQHF0Oo6ATI1olR8R86onGUi@Kooooo1olV9RH7obLW
9`Oo/k>c1onm_Kd7ob0P80Oo<S8b1_l_;bl6obLW9`Kooooo1on0P807oemOG`Oo4Q8B1ol00007oeiN
GPOo_kno1omZJVX6og]kN`Gooooo1omcLg<7olC4a0OoinOW1olL71`7oda<C0OoADE51omXJ6P6obTY
:@gooooo000;ooooo`Oo5QHF1olS8b<7oc8b<POo5ADE1om0@407okfm_@OoD51@1_miNGT5ooooo`Oo
<c<c1on6QXH7ocTi>@Oo92@T1olF5QH7oeaLG0OoK6a/1_lK6a/6ooooo`Ko?Shn1ol;2`/7omoOg`Oo
`/;21omZJVX7oahN7POoJ6QX1_ojn_X6ooooo`Oo8R8R1ole=CD6oa@D50OoMWIf1olK6a/7ofIVIPOo
alO71_lY:BT6ooooo`Oo7alO1old=3@7oaHF5POo<30`1_mHF5P7oaTI6@Oo8R8R1_oUiND6ooooo`Oo
9RHV1olW9bL7ok>c/`Oo_Kfm1olP8207oc8b<PKo;bl_1_lW9bL6ooooo`OoP8201omOGel7oa8B4POo
00001omNGUh7okno_`OoJVYZ1_mkNg/5ooooo`OoLg=c1oo4a<@7onOWi`Oo71`L1om<C4`7odE5A@Oo
J6QX1_lY:BT=ooooo`002oooool7oaHF5POo8b<S1olb<S87oaDE5@Oo@4101onm_Kd7oe1@D0KoNGUi
1Oooool7oc<c<`OoQXJ61oli>CT7ob@T90Oo5QHF1omLG5`7ofa/K0Ko6a/K1_ooool6ochn?POo2`/;
1ooOgml7ol;2`POoJVYZ1olN7Qh7ofQXJ0Kon_[j1_ooool7ob8R8POo=CDe1_lD51@7ogIfMPOo6a/K
1omVIVH7olO7a`Ko:BTY1_ooool7oalO7`Oo=3@d1olF5QH7oc0`<0KoF5QH1olI6AT7ob8R8PKoiNGU
1_ooool7obHV9POo9bLW1onc/k<7okfm_@Oo820P1olb<S86obl_;`Ko9bLW1_ooool7oh20P0OoGemO
1olB4Q87o`0000OoGUiN1ono_kl7ofYZJPKoNg]k1Oooool7og=cL`Ooa<C41ooWinL7oa`L70OoC4a<
1om5ADD7ofQXJ0Ko:BTY3Oooool000_ooooo1olF5QH7ob<S8`Oo<S8b1olE5AD7od10@0Oo_Kfm1om@
D506ogUiN@Gooooo1olc<c<7ohJ6QPOo>CTi1olT92@7oaHF5POoG5aL1om/K6`6oa/K6`Kooooo1_ln
?Sh7o`/;2`OogmoO1oo2`/87ofYZJPOo7QhN1omXJ6P6oo[jnPKooooo1olR8R87ocDe=@Ko51@D1omf
MWH7oa/K6`OoIVIV1oo7alL6obTY:@Kooooo1olO7al7oc@d=0Oo5QHF1ol`<306oeQHF0Oo6ATI1olR
8R86onGUi@Kooooo1olV9RH7obLW9`Oo/k>c1onm_Kd7ob0P80Oo<S8b1_l_;bl6obLW9`Kooooo1on0
P807oemOG`Oo4Q8B1ol00007oeiNGPOo_kno1omZJVX6og]kN`Gooooo1omcLg<7olC4a0OoinOW1olL
71`7oda<C0OoADE51omXJ6P6obTY:@gooooo000;ooooo`Oo3Ph>1olG5aL7oc4a<@Oo7QhN1om2@T87
ok2`/0OoBDU91_maLG45ooooo`Oo^KVi1on9RHT7oiFEU@Oo4Q8B1ol];Bd7ocLg=`OoPX:21_lR8R86
ooooo`Ko0`<31om7AdL7odQ8B0OoNGUi1ola<C47oaDE5@Oo;2`/1_l[:b/6ooooo`Oo5QHF1olb<S86
oa`L70OoMgMg1olM7Ad7og]kN`OobLW91_la<C46ooooo`Oo7AdM1olP8207o`0000Oo51@D1_mRHV87
oaTI6@Oo820P1_oemOD6ooooo`Oo4Q8B1ol[:b/7om_Kf`Ooa<C41ol=3@d7oc0`<0Ko;bl_1_lE5AD6
ooooo`Ooj>SX1omGEeL7obDU9@OoOgmo1onOWil7ohn?S`OoKFe]1_n5QHD5ooooo`OoOWin1ooIfMT7
ooOgm`Oo0`<31omBDU87ode=C@OoNg]k1_lM7Ad=ooooo`002oooool7o`h>3POo5aLG1ola<C47oahN
7POo@T921on`/;07odU9B@KoLG5a1Oooool7okVi^@OoRHV91onEUID7oa8B4POo;Bd]1olg=cL7oh:2
PPKo8R8R1_ooool6o`<30`OoAdM71om8B4P7ogUiN@Oo<C4a1olE5AD7ob`/;0Ko:b/[1_ooool7oaHF
5POo<S8b1_lL71`7ogMgM`Oo7AdM1omkNg/7olW9b@Ko<C4a1_ooool7oadM7@Oo820P1ol00007oa@D
50KoHV9R1olI6AT7ob0P80KomOGe1_ooool7oa8B4POo:b/[1ooKfm/7olC4a0Oo3@d=1ol`<306obl_
;`Ko5ADE1_ooool7onSXj0OoEeMG1olU9BD7ogmoO`OoWinO1on?Shl7ofe]K@KoQHF51Oooool7ogin
OPOofMWI1oogmoL7o`<30`OoDU9B1om=CDd7og]kN`Ko7AdM3Oooool000_ooooo1ol>3Ph7oaLG5`Oo
<C4a1olN7Qh7od92@POo/;2`1om9BDT6og5aL@Gooooo1oni^KT7ohV9R@OoUIFE1olB4Q87obd];@Oo
=cLg1on2PX86ob8R8PKooooo1_l30`<7odM7A`OoB4Q81omiNGT7oc4a<@Oo5ADE1ol/;2`6ob/[:`Ko
oooo1olF5QH7oc8b<PKo71`L1omgMgL7oadM7@OoNg]k1oo9bLT6oc4a<@Kooooo1olM7Ad7ob0P80Oo
00001olD51@6of9RHPOo6ATI1olP8206ooGem@Kooooo1olB4Q87ob/[:`Oofm_K1oo4a<@7o`d=3@Oo
<30`1_l_;bl6oaDE5@Kooooo1ooXj>P7oeMGE`Oo9BDU1omoOgl7oinOW`OoShn?1om]KFd6ohF5Q@Go
oooo1omnOWh7omWIf@OomoOg1ol30`<7oe9BDPOoCDe=1omkNg/6oadM7@gooooo000;ooooo`Oo3Ph>
1olG5aL7oc4a<@Oo7QhN1om2@T87ok2`/0OoBDU91_maLG45ooooo`Oo^KVi1on9RHT7oiFEU@Oo4Q8B
1ol];Bd7ocLg=`OoPX:21_lR8R86ooooo`Ko0`<31om7AdL7odQ8B0OoNGUi1ola<C47oaDE5@Oo;2`/
1_l[:b/6ooooo`Oo5QHF1olb<S86oa`L70OoMgMg1olM7Ad7og]kN`OobLW91_la<C46ooooo`Oo7AdM
1olP8207o`0000Oo51@D1_mRHV87oaTI6@Oo820P1_oemOD6ooooo`Oo4Q8B1ol[:b/7om_Kf`Ooa<C4
1ol=3@d7oc0`<0Ko;bl_1_lE5AD6ooooo`Ooj>SX1omGEeL7obDU9@OoOgmo1onOWil7ohn?S`OoKFe]
1_n5QHD5ooooo`OoOWin1ooIfMT7ooOgm`Oo0`<31omBDU87ode=C@OoNg]k1_lM7Ad=ooooo`002ooo
ool7o`h>3POo5aLG1ola<C47oahN7POo@T921on`/;07odU9B@KoLG5a1Oooool7okVi^@OoRHV91onE
UID7oa8B4POo;Bd]1olg=cL7oh:2PPKo8R8R1_ooool6o`<30`OoAdM71om8B4P7ogUiN@Oo<C4a1olE
5AD7ob`/;0Ko:b/[1_ooool7oaHF5POo<S8b1_lL71`7ogMgM`Oo7AdM1omkNg/7olW9b@Ko<C4a1_oo
ool7oadM7@Oo820P1ol00007oa@D50KoHV9R1olI6AT7ob0P80KomOGe1_ooool7oa8B4POo:b/[1ooK
fm/7olC4a0Oo3@d=1ol`<306obl_;`Ko5ADE1_ooool7onSXj0OoEeMG1olU9BD7ogmoO`OoWinO1on?
Shl7ofe]K@KoQHF51Oooool7oginOPOofMWI1oogmoL7o`<30`OoDU9B1om=CDd7og]kN`Ko7AdM3Ooo
ool000_ooooo1ol>3Ph7oaLG5`Oo<C4a1olN7Qh7od92@POo/;2`1om9BDT6og5aL@Gooooo1oni^KT7
ohV9R@OoUIFE1olB4Q87obd];@Oo=cLg1on2PX86ob8R8PKooooo1_l30`<7odM7A`OoB4Q81omiNGT7
oc4a<@Oo5ADE1ol/;2`6ob/[:`Kooooo1olF5QH7oc8b<PKo71`L1omgMgL7oadM7@OoNg]k1oo9bLT6
oc4a<@Kooooo1olM7Ad7ob0P80Oo00001olD51@6of9RHPOo6ATI1olP8206ooGem@Kooooo1olB4Q87
ob/[:`Oofm_K1oo4a<@7o`d=3@Oo<30`1_l_;bl6oaDE5@Kooooo1ooXj>P7oeMGE`Oo9BDU1omoOgl7
oinOW`OoShn?1om]KFd6ohF5Q@Gooooo1omnOWh7omWIf@OomoOg1ol30`<7oe9BDPOoCDe=1omkNg/6
oadM7@gooooo000;ooooo`Oo3Ph>1olG5aL7oc4a<@Oo7QhN1om2@T87ok2`/0OoBDU91_maLG45oooo
o`Oo^KVi1on9RHT7oiFEU@Oo4Q8B1ol];Bd7ocLg=`OoPX:21_lR8R86ooooo`Ko0`<31om7AdL7odQ8
B0OoNGUi1ola<C47oaDE5@Oo;2`/1_l[:b/6ooooo`Oo5QHF1olb<S86oa`L70OoMgMg1olM7Ad7og]k
N`OobLW91_la<C46ooooo`Oo7AdM1olP8207o`0000Oo51@D1_mRHV87oaTI6@Oo820P1_oemOD6oooo
o`Oo4Q8B1ol[:b/7om_Kf`Ooa<C41ol=3@d7oc0`<0Ko;bl_1_lE5AD6ooooo`Ooj>SX1omGEeL7obDU
9@OoOgmo1onOWil7ohn?S`OoKFe]1_n5QHD5ooooo`OoOWin1ooIfMT7ooOgm`Oo0`<31omBDU87ode=
C@OoNg]k1_lM7Ad=ooooo`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`Ko
Ph>31Oooool7obDU9@OoQ8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo
92@T1oono_h7ok2`/0Oo<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POo
R8R81oo]kNd6oaDE5@Kooooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKo
oooo1ol=3@d7obPX:0Oojn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo
1PH61omYJFT7omKFePOoFUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOo
MgMg1_l^;Rh=ooooo`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>3
1Oooool7obDU9@OoQ8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T
1oono_h7ok2`/0Oo<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R8
1oo]kNd6oaDE5@Kooooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo
1ol=3@d7obPX:0Oojn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH6
1omYJFT7omKFePOoFUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg
1_l^;Rh=ooooo`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>31Ooo
ool7obDU9@OoQ8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T1oon
o_h7ok2`/0Oo<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R81oo]
kNd6oaDE5@Kooooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo1ol=
3@d7obPX:0Oojn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH61omY
JFT7omKFePOoFUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg1_l^
;Rh=ooooo`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>31Oooool7
obDU9@OoQ8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T1oono_h7
ok2`/0Oo<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R81oo]kNd6
oaDE5@Kooooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo1ol=3@d7
obPX:0Oojn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH61omYJFT7
omKFePOoFUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg1_l^;Rh=
ooooo`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>31Oooool7obDU
9@OoQ8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T1oono_h7ok2`
/0Oo<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R81oo]kNd6oaDE
5@Kooooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo1ol=3@d7obPX
:0Oojn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH61omYJFT7omKF
ePOoFUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg1_l^;Rh=oooo
o`002oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>31Oooool7obDU9@Oo
Q8B41olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T1oono_h7ok2`/0Oo
<c<c1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R81oo]kNd6oaDE5@Ko
oooo1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo1ol=3@d7obPX:0Oo
jn_[1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH61omYJFT7omKFePOo
FUYJ1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg1_l^;Rh=ooooo`00
2oooool7o`D51@Oo2PX:1olK6a/7oa4A4@OoATI61ooQhN47odm?C`KoPh>31Oooool7obDU9@OoQ8B4
1olc<c<7oa8B4POo410@1onOWil7ogalO0Ko7QhN1_ooool6oa`L70Oo92@T1oono_h7ok2`/0Oo<c<c
1ol^;Rh7ofa/K0cooooo1ol?3`l7oc8b<PKo51@D1omiNGT7o`h>3POoR8R81oo]kNd6oaDE5@Kooooo
1ol61PH7ob8R8POo00001olU9BD6ofATI0Oo30`<1olU9BD6oo;blPKooooo1ol=3@d7obPX:0Oojn_[
1oo7alL7o`P820go<C4a1_lW9bL6ooooo`OoHf=S1ola<C47oa`L70Oo1PH61omYJFT7omKFePOoFUYJ
1_mhN7P5ooooo`OoW9bL1ooalO47ooOgm`Oo3`l?1omPH607oeiNGPOoMgMg1_l^;Rh=ooooo`002ooo
ool7o`X:2POo4A4A1olS8b<7oa<C4`OoBDU91ooemOD7oeYJFPKoPH611Oooool7onGUi@OoPX:21omX
J6P7o`410@OoCTi>1olf=SH7oh:2PPKo;Bd]1_ooool6o`0000OoE5AD1omFEUH7ofMWI`Oo<c<c1olJ
6QX7ochn?PKo3Ph>1_ooool7o`d=3@Oo<S8b1_lJ6QX7og1`L0Oo3`l?1onXZ:P7ooCdm0Ko8R8R1_oo
ool>oa@D50Oo0`<31olL71`6og5aL@Oo5aLG1olN7Qh6onWYj@Kooooo1ol00007ob/[:`Oom_Kf1onc
/k<7o`@410Oo<S8b1_ld=3@6oahN7PKooooo1oo5aLD7oc<c<`Oo51@D1oo:b/X7ok2`/0OoJ6QX1om<
C4`6okno_`Gooooo1onJVYX7oo3`l0Oooooo1ol410@7ofATI0OoJFUY1onATI46obPX:0gooooo000;
ooooo`Oo2PX:1olA4A47ob<S8`Oo4a<C1om9BDT7ooGem@OoFUYJ1_n1PH45ooooo`OoiNGU1on2PX87
ofQXJ0Oo0@411om>CTh7ocHf=POoPX:21_l];Bd6ooooo`Ko00001omDE5@7oeIFEPOoIfMW1olc<c<7
oaXJ6POo?Shn1_l>3Ph6ooooo`Oo3@d=1olb<S86oaXJ6POoL71`1ol?3`l7ojRXZ0Oom?Cd1_lR8R86
ooooo`ko51@D1ol30`<7oa`L70KoLG5a1olG5aL7oahN7PKojNWY1_ooool7o`0000Oo:b/[1oofm_H7
ok>c/`Oo10@41olb<S86oc@d=0Ko7QhN1_ooool7olG5a@Oo<c<c1olD51@7ol[:bPOo/;2`1omXJ6P7
oda<C0Ko_kno1Oooool7oiZJVPOol?3`1oooool7o`@410OoI6AT1omYJFT7oi6AT@Ko:2PX3Oooool0
00_ooooo1ol:2PX7oa4A4@Oo8b<S1olC4a<7odU9B@OomOGe1omJFUX6oh61P@Gooooo1ooUiND7oh:2
PPOoJ6QX1ol10@47odi>CPOo=SHf1on2PX86obd];@Kooooo1_l00007oeADE0OoEUIF1omWIfL7oc<c
<`Oo6QXJ1oln?Sh6o`h>3PKooooo1ol=3@d7oc8b<PKo6QXJ1om`L707o`l?3`OoZ:RX1oodm?@6ob8R
8PKooooo3_lD51@7o`<30`Oo71`L1_maLG47oaLG5`Oo7QhN1_oYjNT6ooooo`Oo00001ol[:b/7ooKf
mPOo/k>c1ol410@7oc8b<PKo=3@d1_lN7Qh6ooooo`OoaLG51olc<c<7oa@D50Oob/[:1on`/;07ofQX
J0OoC4a<1_no_kl5ooooo`OoVYZJ1oo`l?07ooooo`Oo10@41omTI6@7ofUYJ@OoTI6A1_lX:2P=oooo
o`002oooool7o`X:2POo4A4A1olS8b<7oa<C4`OoBDU91ooemOD7oeYJFPKoPH611Oooool7onGUi@Oo
PX:21omXJ6P7o`410@OoCTi>1olf=SH7oh:2PPKo;Bd]1_ooool6o`0000OoE5AD1omFEUH7ofMWI`Oo
<c<c1olJ6QX7ochn?PKo3Ph>1_ooool7o`d=3@Oo<S8b1_lJ6QX7og1`L0Oo3`l?1onXZ:P7ooCdm0Ko
8R8R1_ooool>oa@D50Oo0`<31olL71`6og5aL@Oo5aLG1olN7Qh6onWYj@Kooooo1ol00007ob/[:`Oo
m_Kf1onc/k<7o`@410Oo<S8b1_ld=3@6oahN7PKooooo1oo5aLD7oc<c<`Oo51@D1oo:b/X7ok2`/0Oo
J6QX1om<C4`6okno_`Gooooo1onJVYX7oo3`l0Oooooo1ol410@7ofATI0OoJFUY1onATI46obPX:0go
oooo000;ooooo`Oo2PX:1olA4A47ob<S8`Oo4a<C1om9BDT7ooGem@OoFUYJ1_n1PH45ooooo`OoiNGU
1on2PX87ofQXJ0Oo0@411om>CTh7ocHf=POoPX:21_l];Bd6ooooo`Ko00001omDE5@7oeIFEPOoIfMW
1olc<c<7oaXJ6POo?Shn1_l>3Ph6ooooo`Oo3@d=1olb<S86oaXJ6POoL71`1ol?3`l7ojRXZ0Oom?Cd
1_lR8R86ooooo`ko51@D1ol30`<7oa`L70KoLG5a1olG5aL7oahN7PKojNWY1_ooool7o`0000Oo:b/[
1oofm_H7ok>c/`Oo10@41olb<S86oc@d=0Ko7QhN1_ooool7olG5a@Oo<c<c1olD51@7ol[:bPOo/;2`
1omXJ6P7oda<C0Ko_kno1Oooool7oiZJVPOol?3`1oooool7o`@410OoI6AT1omYJFT7oi6AT@Ko:2PX
3Oooool000_ooooo1ol:2PX7oa4A4@Oo8b<S1olC4a<7odU9B@OomOGe1omJFUX6oh61P@Gooooo1ooU
iND7oh:2PPOoJ6QX1ol10@47odi>CPOo=SHf1on2PX86obd];@Kooooo1_l00007oeADE0OoEUIF1omW
IfL7oc<c<`Oo6QXJ1oln?Sh6o`h>3PKooooo1ol=3@d7oc8b<PKo6QXJ1om`L707o`l?3`OoZ:RX1ood
m?@6ob8R8PKooooo3_lD51@7o`<30`Oo71`L1_maLG47oaLG5`Oo7QhN1_oYjNT6ooooo`Oo00001ol[
:b/7ooKfmPOo/k>c1ol410@7oc8b<PKo=3@d1_lN7Qh6ooooo`OoaLG51olc<c<7oa@D50Oob/[:1on`
/;07ofQXJ0OoC4a<1_no_kl5ooooo`OoVYZJ1oo`l?07ooooo`Oo10@41omTI6@7ofUYJ@OoTI6A1_lX
:2P=ooooo`002oooool7o`X:2POo4A4A1olS8b<7oa<C4`OoBDU91ooemOD7oeYJFPKoPH611Oooool7
onGUi@OoPX:21omXJ6P7o`410@OoCTi>1olf=SH7oh:2PPKo;Bd]1_ooool6o`0000OoE5AD1omFEUH7
ofMWI`Oo<c<c1olJ6QX7ochn?PKo3Ph>1_ooool7o`d=3@Oo<S8b1_lJ6QX7og1`L0Oo3`l?1onXZ:P7
ooCdm0Ko8R8R1_ooool>oa@D50Oo0`<31olL71`6og5aL@Oo5aLG1olN7Qh6onWYj@Kooooo1ol00007
ob/[:`Oom_Kf1onc/k<7o`@410Oo<S8b1_ld=3@6oahN7PKooooo1oo5aLD7oc<c<`Oo51@D1oo:b/X7
ok2`/0OoJ6QX1om<C4`6okno_`Gooooo1onJVYX7oo3`l0Oooooo1ol410@7ofATI0OoJFUY1onATI46
obPX:0gooooo000;ooooo`Oo0`<31ol00007o`X:2POo4Q8B1oln?Sh7oo[jnPOoF5QH1_n=SHd5oooo
o`Oo=CDe1omiNGT7oc8b<POo10@41olT92@7omKFePOoPH611_lY:BT6ooooo`Ko71`L1omMGEd7on[Z
jPOoUYJF1olK6a/7od92@POoL71`1_oGemL6ooooo`Oo00001ol[:b/6oaHF5POoLg=c1ol?3`l7ojj^
[POooooo1_lC4a<6ooooo`Oo20P81olI6AT7o`H61POo;Rh^1_mZJVX7oa0@40Oo;bl_3?ooool7o`82
0POo:RXZ1oooool7ojf][@Oo1@D51ole=CD6ob/[:`Ko7QhN1_ooool7oc`l?0Oo410@1ol^;Rh7oc0`
<0OoMWIf1ooEeMD7odI6APKoN7Qh1Oooool7okfm_@Ooo_kn1oobl_87oa4A4@OoLG5a1omOGel7oh61
P@Ko=SHf3Oooool000_ooooo1ol30`<7o`0000Oo2PX:1olB4Q87ochn?POon_[j1omHF5P6ohf=S@Go
oooo1ole=CD7ogUiN@Oo<S8b1ol410@7ob@T90Ooe]KF1on1PH46obTY:@Kooooo1_lL71`7oeeMG@Oo
j^[Z1onFUYH7oa/K6`Oo@T921om`L706omOGe`Kooooo1ol00007ob/[:`Ko5QHF1omcLg<7o`l?3`Oo
[Zj^1oooool6oa<C4`Kooooo1ol820P7oaTI6@Oo1PH61ol^;Rh6ofYZJPOo410@1ol_;bl<ooooo`Oo
0P821olZ:RX7ooooo`Oo[Jf]1ol51@D7ocDe=@Ko:b/[1_lN7Qh6ooooo`Oo?3`l1ol@4107obh^;POo
<30`1omfMWH7omGEe@OoATI61_mhN7P5ooooo`Oo_Kfm1oono_h7oo;blPOo4A4A1omaLG47oemOG`Oo
PH611_lf=SH=ooooo`002oooool7o`<30`Oo00001ol:2PX7oa8B4POo?Shn1oojn_X7oeQHF0KoSHf=
1Oooool7ocDe=@OoNGUi1olb<S87o`@410Oo92@T1ooFe]H7oh61P@Ko:BTY1_ooool6oa`L70OoGEeM
1ooZj^X7oiJFUPOo6a/K1om2@T87og1`L0KoemOG1_ooool7o`0000Oo:b/[1_lF5QH7og=cL`Oo3`l?
1on^[Zh7ooooo`Ko4a<C1_ooool7o`P820Oo6ATI1ol61PH7obh^;PKoJVYZ1ol@4107obl_;`cooooo
1ol20P87obXZ:POooooo1on][Jd7o`D51@Oo=CDe1_l[:b/6oahN7PKooooo1oll?3`7oa0@40Oo;Rh^
1ol`<307ogIfMPOoeMGE1om6ATH6ogQhN0Gooooo1onm_Kd7ooknoPOol_;b1olA4A47og5aL@OoGemO
1on1PH46ocHf=Pgooooo000;ooooo`Oo0`<31ol00007o`X:2POo4Q8B1oln?Sh7oo[jnPOoF5QH1_n=
SHd5ooooo`Oo=CDe1omiNGT7oc8b<POo10@41olT92@7omKFePOoPH611_lY:BT6ooooo`Ko71`L1omM
GEd7on[ZjPOoUYJF1olK6a/7od92@POoL71`1_oGemL6ooooo`Oo00001ol[:b/6oaHF5POoLg=c1ol?
3`l7ojj^[POooooo1_lC4a<6ooooo`Oo20P81olI6AT7o`H61POo;Rh^1_mZJVX7oa0@40Oo;bl_3?oo
ool7o`820POo:RXZ1oooool7ojf][@Oo1@D51ole=CD6ob/[:`Ko7QhN1_ooool7oc`l?0Oo410@1ol^
;Rh7oc0`<0OoMWIf1ooEeMD7odI6APKoN7Qh1Oooool7okfm_@Ooo_kn1oobl_87oa4A4@OoLG5a1omO
Gel7oh61P@Ko=SHf3Oooool000_ooooo1ol30`<7o`0000Oo2PX:1olB4Q87ochn?POon_[j1omHF5P6
ohf=S@Gooooo1ole=CD7ogUiN@Oo<S8b1ol410@7ob@T90Ooe]KF1on1PH46obTY:@Kooooo1_lL71`7
oeeMG@Ooj^[Z1onFUYH7oa/K6`Oo@T921om`L706omOGe`Kooooo1ol00007ob/[:`Ko5QHF1omcLg<7
o`l?3`Oo[Zj^1oooool6oa<C4`Kooooo1ol820P7oaTI6@Oo1PH61ol^;Rh6ofYZJPOo410@1ol_;bl<
ooooo`Oo0P821olZ:RX7ooooo`Oo[Jf]1ol51@D7ocDe=@Ko:b/[1_lN7Qh6ooooo`Oo?3`l1ol@4107
obh^;POo<30`1omfMWH7omGEe@OoATI61_mhN7P5ooooo`Oo_Kfm1oono_h7oo;blPOo4A4A1omaLG47
oemOG`OoPH611_lf=SH=ooooo`002oooool7o`<30`Oo00001ol:2PX7oa8B4POo?Shn1oojn_X7oeQH
F0KoSHf=1Oooool7ocDe=@OoNGUi1olb<S87o`@410Oo92@T1ooFe]H7oh61P@Ko:BTY1_ooool6oa`L
70OoGEeM1ooZj^X7oiJFUPOo6a/K1om2@T87og1`L0KoemOG1_ooool7o`0000Oo:b/[1_lF5QH7og=c
L`Oo3`l?1on^[Zh7ooooo`Ko4a<C1_ooool7o`P820Oo6ATI1ol61PH7obh^;PKoJVYZ1ol@4107obl_
;`cooooo1ol20P87obXZ:POooooo1on][Jd7o`D51@Oo=CDe1_l[:b/6oahN7PKooooo1oll?3`7oa0@
40Oo;Rh^1ol`<307ogIfMPOoeMGE1om6ATH6ogQhN0Gooooo1onm_Kd7ooknoPOol_;b1olA4A47og5a
L@OoGemO1on1PH46ocHf=Pgooooo000;ooooo`Oo10@41ol71`L7oa4A4@Oo3Ph>1om:BTX7ooooo`Oo
N7Qh1_n@T905ooooo`OonOWi1omeMGD7oc<c<`Oo410@1omTI6@7od10@0OoNg]k1_mIFET6ooooo`Ko
1PH61omHF5P7ogIfMPOoBd];1olY:BT7obLW9`OoHF5Q1_l61PH6ooooo`Oo1PH61ol_;bl6ob0P80Oo
K6a/1ol;2`/7olG5a@OooOgm1_lE5AD6ooooo`Oo2`/;3_l>3Ph7oc8b<PKoI6AT1ol@4107ob@T90Ko
moOg1_ooool7o`0000Oo?Cdm1ooZj^X7og]kN`Oo0P821oli>CT6oc<c<`Ko7alO1_ooool7ojRXZ0Oo
71`L1olY:BT7on?Sh`Oo_Kfm1om1@D47oc4a<@KokNg]1Oooool7ojf][@Ook>c/1ooZj^X7o`0000Oo
L71`1omXJ6P7oiZJVPKoCTi>3Oooool000_ooooo1ol410@7o`L71`Oo4A4A1ol>3Ph7odY:BPOooooo
1omhN7P6oi2@T0Gooooo1ooinOT7ogEeM@Oo<c<c1ol@4107ofATI0Oo@4101omkNg/6oeUIF@Kooooo
1_l61PH7oeQHF0OoMWIf1om;Bd/7obTY:@Oo9bLW1omQHF46o`H61PKooooo1ol61PH7obl_;`Ko820P
1om/K6`7o`/;2`OoaLG51oomoOd6oaDE5@Kooooo1ol;2`/>o`h>3POo<S8b1_mTI6@7oa0@40Oo92@T
1_ogmoL6ooooo`Oo00001olm?Cd7on[ZjPOoNg]k1ol20P87ocTi>@Ko<c<c1_lO7al6ooooo`OoZ:RX
1olL71`7obTY:@Oohn?S1onm_Kd7od51@@Oo<C4a1_o]kNd5ooooo`Oo[Jf]1oo/k>`7on[ZjPOo0000
1om`L707ofQXJ0OoVYZJ1_m>CTh=ooooo`002oooool7o`@410Oo1`L71olA4A47o`h>3POoBTY:1ooo
ool7ogQhN0KoT92@1Oooool7ooWin@OoMGEe1olc<c<7oa0@40OoI6AT1om0@407og]kN`KoFEUI1_oo
ool6o`H61POoF5QH1omfMWH7od];B`Oo:BTY1olW9bL7of5QH@Ko1PH61_ooool7o`H61POo;bl_1_lP
8207ofa/K0Oo2`/;1oo5aLD7oogmo@Ko5ADE1_ooool7o`/;2`ko3Ph>1olb<S86ofATI0Oo410@1olT
92@6ooOgm`Kooooo1ol00007ocdm?@Ooj^[Z1omkNg/7o`820POo>CTi1_lc<c<6oalO7`Kooooo1onX
Z:P7oa`L70Oo:BTY1ooShn<7okfm_@Oo@D511ola<C46ong]k@Gooooo1on][Jd7onc/k0Ooj^[Z1ol0
0007og1`L0OoJ6QX1onJVYX6odi>CPgooooo000;ooooo`Oo10@41ol71`L7oa4A4@Oo3Ph>1om:BTX7
ooooo`OoN7Qh1_n@T905ooooo`OonOWi1omeMGD7oc<c<`Oo410@1omTI6@7od10@0OoNg]k1_mIFET6
ooooo`Ko1PH61omHF5P7ogIfMPOoBd];1olY:BT7obLW9`OoHF5Q1_l61PH6ooooo`Oo1PH61ol_;bl6
ob0P80OoK6a/1ol;2`/7olG5a@OooOgm1_lE5AD6ooooo`Oo2`/;3_l>3Ph7oc8b<PKoI6AT1ol@4107
ob@T90KomoOg1_ooool7o`0000Oo?Cdm1ooZj^X7og]kN`Oo0P821oli>CT6oc<c<`Ko7alO1_ooool7
ojRXZ0Oo71`L1olY:BT7on?Sh`Oo_Kfm1om1@D47oc4a<@KokNg]1Oooool7ojf][@Ook>c/1ooZj^X7
o`0000OoL71`1omXJ6P7oiZJVPKoCTi>3Oooool000_ooooo1ol410@7o`L71`Oo4A4A1ol>3Ph7odY:
BPOooooo1omhN7P6oi2@T0Gooooo1ooinOT7ogEeM@Oo<c<c1ol@4107ofATI0Oo@4101omkNg/6oeUI
F@Kooooo1_l61PH7oeQHF0OoMWIf1om;Bd/7obTY:@Oo9bLW1omQHF46o`H61PKooooo1ol61PH7obl_
;`Ko820P1om/K6`7o`/;2`OoaLG51oomoOd6oaDE5@Kooooo1ol;2`/>o`h>3POo<S8b1_mTI6@7oa0@
40Oo92@T1_ogmoL6ooooo`Oo00001olm?Cd7on[ZjPOoNg]k1ol20P87ocTi>@Ko<c<c1_lO7al6oooo
o`OoZ:RX1olL71`7obTY:@Oohn?S1onm_Kd7od51@@Oo<C4a1_o]kNd5ooooo`Oo[Jf]1oo/k>`7on[Z
jPOo00001om`L707ofQXJ0OoVYZJ1_m>CTh=ooooo`002oooool7o`@410Oo1`L71olA4A47o`h>3POo
BTY:1oooool7ogQhN0KoT92@1Oooool7ooWin@OoMGEe1olc<c<7oa0@40OoI6AT1om0@407og]kN`Ko
FEUI1_ooool6o`H61POoF5QH1omfMWH7od];B`Oo:BTY1olW9bL7of5QH@Ko1PH61_ooool7o`H61POo
;bl_1_lP8207ofa/K0Oo2`/;1oo5aLD7oogmo@Ko5ADE1_ooool7o`/;2`ko3Ph>1olb<S86ofATI0Oo
410@1olT92@6ooOgm`Kooooo1ol00007ocdm?@Ooj^[Z1omkNg/7o`820POo>CTi1_lc<c<6oalO7`Ko
oooo1onXZ:P7oa`L70Oo:BTY1ooShn<7okfm_@Oo@D511ola<C46ong]k@Gooooo1on][Jd7onc/k0Oo
j^[Z1ol00007og1`L0OoJ6QX1onJVYX6odi>CPgooooo000;ooooo`Oo10@41ol71`L7oa4A4@Oo3Ph>
1om:BTX7ooooo`OoN7Qh1_n@T905ooooo`OonOWi1omeMGD7oc<c<`Oo410@1omTI6@7od10@0OoNg]k
1_mIFET6ooooo`Ko1PH61omHF5P7ogIfMPOoBd];1olY:BT7obLW9`OoHF5Q1_l61PH6ooooo`Oo1PH6
1ol_;bl6ob0P80OoK6a/1ol;2`/7olG5a@OooOgm1_lE5AD6ooooo`Oo2`/;3_l>3Ph7oc8b<PKoI6AT
1ol@4107ob@T90KomoOg1_ooool7o`0000Oo?Cdm1ooZj^X7og]kN`Oo0P821oli>CT6oc<c<`Ko7alO
1_ooool7ojRXZ0Oo71`L1olY:BT7on?Sh`Oo_Kfm1om1@D47oc4a<@KokNg]1Oooool7ojf][@Ook>c/
1ooZj^X7o`0000OoL71`1omXJ6P7oiZJVPKoCTi>3Oooool000_ooooo1ol:2PX7o`820POo30`<1olH
61P7od92@POono_k1omaLG46ogemO@Gooooo1om5ADD7ofATI0Oo:b/[1ol00007oc/k>`Ooj>SX1oml
O7`6ob`/;0Kooooo1_m8B4P7ohZ:RPOoc/k>1omVIVH7obDU9@OoCTi>1omUIFD6oiJFUPKooooo1olJ
6QX7oc@d=0Ko8R8R1omVIVH7ob4Q8@Oo`/;21oo[jn/6oaPH60Kooooo1ol61PH7oaLG5`Oo6ATI1om4
A4@6of5QH@Oo3`l?1olW9bL6onc/k0Kooooo1olD51@7ocdm?@Oohn?S1omZJVX7o`T92@Oo>3Ph1_l[
:b/6ob4Q8@Kooooo1ol>3Ph7o`X:2POo<C4a1omWIfL7ogUiN@Oo`L711olX:2P6ogUiN@Gooooo1oo4
a<@7omkNgPOof=SH1olE5AD7ofm_K`OoHV9R1on:RXX6oeYJFPgooooo000;ooooo`Oo2PX:1ol20P87
o``<30Oo61PH1om2@T87oo_kn`OoLG5a1_mmOGd5ooooo`OoADE51omTI6@7ob/[:`Oo00001olk>c/7
onSXj0OoO7al1_l/;2`6ooooo`KoB4Q81on:RXX7olk>cPOoIVIV1olU9BD7odi>CPOoIFEU1_nFUYH6
ooooo`Oo6QXJ1old=3@6ob8R8POoIVIV1olQ8B47ol;2`POojn_[1_lH61P6ooooo`Oo1PH61olG5aL7
oaTI6@OoA4A41_mQHF47o`l?3`Oo9bLW1_o/k>`6ooooo`Oo51@D1olm?Cd7on?Sh`OoJVYZ1ol92@T7
ocPh>0Ko:b/[1_lQ8B46ooooo`Oo3Ph>1ol:2PX7oc4a<@OoIfMW1omiNGT7ol71`@Oo:2PX1_miNGT5
ooooo`Ooa<C41ooNg]h7omSHf0Oo5ADE1om_Kfl7of9RHPOoRXZ:1_mJFUX=ooooo`002oooool7o`X:
2POo0P821ol<30`7oaPH60Oo@T921ookno/7og5aL@KoOGem1Oooool7odE5A@OoI6AT1ol[:b/7o`00
00Oo>c/k1ooXj>P7ogalO0Ko;2`/1_ooool6odQ8B0OoRXZ:1oo>c/h7ofIVIPOo9BDU1om>CTh7ofEU
I@KoUYJF1_ooool7oaXJ6POo=3@d1_lR8R87ofIVIPOo8B4Q1oo2`/87on_[j`Ko61PH1_ooool7o`H6
1POo5aLG1olI6AT7odA4A0KoHF5Q1ol?3`l7obLW9`Kok>c/1_ooool7oa@D50Oo?Cdm1ooShn<7ofYZ
JPOo2@T91olh>3P6ob/[:`Ko8B4Q1_ooool7o`h>3POo2PX:1ola<C47ofMWI`OoNGUi1oo1`L47obPX
:0KoNGUi1Oooool7olC4a0Oog]kN1ooHf=P7oaDE5@OoKfm_1omRHV87ohZ:RPKoFUYJ3Oooool000_o
oooo1ol:2PX7o`820POo30`<1olH61P7od92@POono_k1omaLG46ogemO@Gooooo1om5ADD7ofATI0Oo
:b/[1ol00007oc/k>`Ooj>SX1omlO7`6ob`/;0Kooooo1_m8B4P7ohZ:RPOoc/k>1omVIVH7obDU9@Oo
CTi>1omUIFD6oiJFUPKooooo1olJ6QX7oc@d=0Ko8R8R1omVIVH7ob4Q8@Oo`/;21oo[jn/6oaPH60Ko
oooo1ol61PH7oaLG5`Oo6ATI1om4A4@6of5QH@Oo3`l?1olW9bL6onc/k0Kooooo1olD51@7ocdm?@Oo
hn?S1omZJVX7o`T92@Oo>3Ph1_l[:b/6ob4Q8@Kooooo1ol>3Ph7o`X:2POo<C4a1omWIfL7ogUiN@Oo
`L711olX:2P6ogUiN@Gooooo1oo4a<@7omkNgPOof=SH1olE5AD7ofm_K`OoHV9R1on:RXX6oeYJFPgo
oooo000;ooooo`Oo2PX:1ol20P87o``<30Oo61PH1om2@T87oo_kn`OoLG5a1_mmOGd5ooooo`OoADE5
1omTI6@7ob/[:`Oo00001olk>c/7onSXj0OoO7al1_l/;2`6ooooo`KoB4Q81on:RXX7olk>cPOoIVIV
1olU9BD7odi>CPOoIFEU1_nFUYH6ooooo`Oo6QXJ1old=3@6ob8R8POoIVIV1olQ8B47ol;2`POojn_[
1_lH61P6ooooo`Oo1PH61olG5aL7oaTI6@OoA4A41_mQHF47o`l?3`Oo9bLW1_o/k>`6ooooo`Oo51@D
1olm?Cd7on?Sh`OoJVYZ1ol92@T7ocPh>0Ko:b/[1_lQ8B46ooooo`Oo3Ph>1ol:2PX7oc4a<@OoIfMW
1omiNGT7ol71`@Oo:2PX1_miNGT5ooooo`Ooa<C41ooNg]h7omSHf0Oo5ADE1om_Kfl7of9RHPOoRXZ:
1_mJFUX=ooooo`002oooool7o`X:2POo0P821ol<30`7oaPH60Oo@T921ookno/7og5aL@KoOGem1Ooo
ool7odE5A@OoI6AT1ol[:b/7o`0000Oo>c/k1ooXj>P7ogalO0Ko;2`/1_ooool6odQ8B0OoRXZ:1oo>
c/h7ofIVIPOo9BDU1om>CTh7ofEUI@KoUYJF1_ooool7oaXJ6POo=3@d1_lR8R87ofIVIPOo8B4Q1oo2
`/87on_[j`Ko61PH1_ooool7o`H61POo5aLG1olI6AT7odA4A0KoHF5Q1ol?3`l7obLW9`Kok>c/1_oo
ool7oa@D50Oo?Cdm1ooShn<7ofYZJPOo2@T91olh>3P6ob/[:`Ko8B4Q1_ooool7o`h>3POo2PX:1ola
<C47ofMWI`OoNGUi1oo1`L47obPX:0KoNGUi1Oooool7olC4a0Oog]kN1ooHf=P7oaDE5@OoKfm_1omR
HV87ohZ:RPKoFUYJ3Oooool000_ooooo1ol:2PX7o`820POo30`<1olH61P7od92@POono_k1omaLG46
ogemO@Gooooo1om5ADD7ofATI0Oo:b/[1ol00007oc/k>`Ooj>SX1omlO7`6ob`/;0Kooooo1_m8B4P7
ohZ:RPOoc/k>1omVIVH7obDU9@OoCTi>1omUIFD6oiJFUPKooooo1olJ6QX7oc@d=0Ko8R8R1omVIVH7
ob4Q8@Oo`/;21oo[jn/6oaPH60Kooooo1ol61PH7oaLG5`Oo6ATI1om4A4@6of5QH@Oo3`l?1olW9bL6
onc/k0Kooooo1olD51@7ocdm?@Oohn?S1omZJVX7o`T92@Oo>3Ph1_l[:b/6ob4Q8@Kooooo1ol>3Ph7
o`X:2POo<C4a1omWIfL7ogUiN@Oo`L711olX:2P6ogUiN@Gooooo1oo4a<@7omkNgPOof=SH1olE5AD7
ofm_K`OoHV9R1on:RXX6oeYJFPgooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7A
d@OoPh>31_n1PH4<ooooo`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D
50OoFe]K1om=CDd7ob`/;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]K
F`Oo820P1oo0`<07omcLg0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV
9PKofMWI1_ooool7o`P820OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFE
U@Oo5ADE1om1@D47on_[j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMW
I`OoEUIF1onATI46oeADE0gooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7Ad@Oo
Ph>31_n1PH4<ooooo`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D50Oo
Fe]K1om=CDd7ob`/;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]KF`Oo
820P1oo0`<07omcLg0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV9PKo
fMWI1_ooool7o`P820OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFEU@Oo
5ADE1om1@D47on_[j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMWI`Oo
EUIF1onATI46oeADE0gooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7Ad@OoPh>3
1_n1PH4<ooooo`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D50OoFe]K
1om=CDd7ob`/;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]KF`Oo820P
1oo0`<07omcLg0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV9PKofMWI
1_ooool7o`P820OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFEU@Oo5ADE
1om1@D47on_[j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMWI`OoEUIF
1onATI46oeADE0gooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7Ad@OoPh>31_n1
PH4<ooooo`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D50OoFe]K1om=
CDd7ob`/;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]KF`Oo820P1oo0
`<07omcLg0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV9PKofMWI1_oo
ool7o`P820OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFEU@Oo5ADE1om1
@D47on_[j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMWI`OoEUIF1onA
TI46oeADE0gooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7Ad@OoPh>31_n1PH4<
ooooo`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D50OoFe]K1om=CDd7
ob`/;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]KF`Oo820P1oo0`<07
omcLg0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV9PKofMWI1_ooool7
o`P820OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFEU@Oo5ADE1om1@D47
on_[j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMWI`OoEUIF1onATI46
oeADE0gooooo000;ooooo`Oo4Q8B1olD51@7o`l?3`Oo820P1om>CTh7om7Ad@OoPh>31_n1PH4<oooo
o`OoK6a/1olO7al7ocXj>POoO7al1olY:BT7oeUIF@KoMWIf1_ooool6oa@D50OoFe]K1om=CDd7ob`/
;0Oo820P1olc<c<7oeADE0Ko71`L1_ooool7oa<C4`Oo:b/[1_lP8207oe]KF`Oo820P1oo0`<07omcL
g0Ko7alO1_ooool7o`l?3`Oo2`/;1ol?3`l7obh^;PKoDe=C1olI6AT7obHV9PKofMWI1_ooool7o`P8
20OoC4a<1oo5aLD7ocTi>@Oo2@T91oli>CT6ocXj>PKo7AdM1_ooool7oiFEU@Oo5ADE1om1@D47on_[
j`Oo^KVi1olI6AT7oalO7`_ooooo1onUYJD7olK6aPOo_;bl1ol<30`7ofMWI`OoEUIF1onATI46oeAD
E0gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`OoH61P1oo/k>`7of1PH0Oo[Jf]1ol/
;2`7oa/K6`Oo2`/;1_n@T905ooooo`OoWYjN1oo:b/X7oc0`<0OoBDU91ol61PH7oaLG5`Oo1@D51_m=
CDd6ooooo`KoG5aL1onZZZX7ohR8R0Oooooo1omFEUH7oclo?`Oo61PH1_lo?cl6ooooo`Oo[jn_1om/
K6`6o`X:2POoBd];1oo9bLT7og1`L0Oo:b/[1_mVIVH6ooooo`OoWYjN1omRHV87obTY:@Oo4a<C1_l@
4107oadM7@Oo=SHf1_oLg=`6ooooo`Oo?Cdm1omJFUX7oijNWPOoOGem1olU9BD7odY:BPKoc<c<1_le
=CD6ooooo`Oo?3`l1olF5QH7oeUIF@Oo?Cdm1oo^k^h7ocDe=@OoKVi^1_lc<c<5ooooo`Oo9bLW1omP
H607o`D51@OoOgmo1oo0`<07odU9B@Oo@4101_l92@T=ooooo`002oooool7of1PH0Ook>c/1omPH607
ojf][@Oo;2`/1olK6a/7o`/;2`KoT92@1Oooool7oijNWPOob/[:1ol`<307odU9B@Oo1PH61olG5aL7
o`D51@KoCDe=1_ooool6oeaLG0OoZZZZ1on8R8P7ooooo`OoEUIF1olo?cl7oaPH60Ko?clo1_ooool7
ojn_[`OoK6a/1_l:2PX7od];B`OobLW91om`L707ob/[:`KoIVIV1_ooool7oijNWPOoHV9R1olY:BT7
oa<C4`Ko410@1olM7Ad7ocHf=PKog=cL1_ooool7ocdm?@OoFUYJ1onNWYh7ogemO@Oo9BDU1om:BTX6
olc<c0Ko=CDe1_ooool7oc`l?0Oo5QHF1omIFET7ocdm?@Ook^k^1ole=CD7ofi^KPKo<c<c1Oooool7
obLW9`OoH61P1ol51@D7ogmoO`Oo`<301om9BDT7od10@0Ko2@T93Oooool000_ooooo1omPH607onc/
k0OoH61P1on][Jd7ob`/;0Oo6a/K1ol;2`/6oi2@T0Gooooo1onNWYh7ol[:bPOo<30`1om9BDT7o`H6
1POo5aLG1ol51@D6ode=C@Kooooo1_mLG5`7ojZZZPOoR8R81oooool7oeIFEPOo?clo1olH61P6oclo
?`Kooooo1on_[jl7ofa/K0Ko2PX:1om;Bd/7olW9b@OoL71`1ol[:b/6ofIVIPKooooo1onNWYh7of9R
HPOo:BTY1olC4a<6oa0@40Oo7AdM1olf=SH6omcLg0Kooooo1olm?Cd7oeYJFPOoWYjN1ommOGd7obDU
9@OoBTY:1_o<c<`6ocDe=@Kooooo1oll?3`7oaHF5POoFEUI1olm?Cd7onk^kPOo=CDe1om^KVh6oc<c
<`Gooooo1olW9bL7of1PH0Oo1@D51omoOgl7ol30`0OoBDU91om0@406o`T92@gooooo000;ooooo`Oo
H61P1oo/k>`7of1PH0Oo[Jf]1ol/;2`7oa/K6`Oo2`/;1_n@T905ooooo`OoWYjN1oo:b/X7oc0`<0Oo
BDU91ol61PH7oaLG5`Oo1@D51_m=CDd6ooooo`KoG5aL1onZZZX7ohR8R0Oooooo1omFEUH7oclo?`Oo
61PH1_lo?cl6ooooo`Oo[jn_1om/K6`6o`X:2POoBd];1oo9bLT7og1`L0Oo:b/[1_mVIVH6ooooo`Oo
WYjN1omRHV87obTY:@Oo4a<C1_l@4107oadM7@Oo=SHf1_oLg=`6ooooo`Oo?Cdm1omJFUX7oijNWPOo
OGem1olU9BD7odY:BPKoc<c<1_le=CD6ooooo`Oo?3`l1olF5QH7oeUIF@Oo?Cdm1oo^k^h7ocDe=@Oo
KVi^1_lc<c<5ooooo`Oo9bLW1omPH607o`D51@OoOgmo1oo0`<07odU9B@Oo@4101_l92@T=ooooo`00
2oooool7of1PH0Ook>c/1omPH607ojf][@Oo;2`/1olK6a/7o`/;2`KoT92@1Oooool7oijNWPOob/[:
1ol`<307odU9B@Oo1PH61olG5aL7o`D51@KoCDe=1_ooool6oeaLG0OoZZZZ1on8R8P7ooooo`OoEUIF
1olo?cl7oaPH60Ko?clo1_ooool7ojn_[`OoK6a/1_l:2PX7od];B`OobLW91om`L707ob/[:`KoIVIV
1_ooool7oijNWPOoHV9R1olY:BT7oa<C4`Ko410@1olM7Ad7ocHf=PKog=cL1_ooool7ocdm?@OoFUYJ
1onNWYh7ogemO@Oo9BDU1om:BTX6olc<c0Ko=CDe1_ooool7oc`l?0Oo5QHF1omIFET7ocdm?@Ook^k^
1ole=CD7ofi^KPKo<c<c1Oooool7obLW9`OoH61P1ol51@D7ogmoO`Oo`<301om9BDT7od10@0Ko2@T9
3Oooool000_ooooo1omPH607onc/k0OoH61P1on][Jd7ob`/;0Oo6a/K1ol;2`/6oi2@T0Gooooo1onN
WYh7ol[:bPOo<30`1om9BDT7o`H61POo5aLG1ol51@D6ode=C@Kooooo1_mLG5`7ojZZZPOoR8R81ooo
ool7oeIFEPOo?clo1olH61P6oclo?`Kooooo1on_[jl7ofa/K0Ko2PX:1om;Bd/7olW9b@OoL71`1ol[
:b/6ofIVIPKooooo1onNWYh7of9RHPOo:BTY1olC4a<6oa0@40Oo7AdM1olf=SH6omcLg0Kooooo1olm
?Cd7oeYJFPOoWYjN1ommOGd7obDU9@OoBTY:1_o<c<`6ocDe=@Kooooo1oll?3`7oaHF5POoFEUI1olm
?Cd7onk^kPOo=CDe1om^KVh6oc<c<`Gooooo1olW9bL7of1PH0Oo1@D51omoOgl7ol30`0OoBDU91om0
@406o`T92@gooooo000;ooooo`OoH61P1oo/k>`7of1PH0Oo[Jf]1ol/;2`7oa/K6`Oo2`/;1_n@T905
ooooo`OoWYjN1oo:b/X7oc0`<0OoBDU91ol61PH7oaLG5`Oo1@D51_m=CDd6ooooo`KoG5aL1onZZZX7
ohR8R0Oooooo1omFEUH7oclo?`Oo61PH1_lo?cl6ooooo`Oo[jn_1om/K6`6o`X:2POoBd];1oo9bLT7
og1`L0Oo:b/[1_mVIVH6ooooo`OoWYjN1omRHV87obTY:@Oo4a<C1_l@4107oadM7@Oo=SHf1_oLg=`6
ooooo`Oo?Cdm1omJFUX7oijNWPOoOGem1olU9BD7odY:BPKoc<c<1_le=CD6ooooo`Oo?3`l1olF5QH7
oeUIF@Oo?Cdm1oo^k^h7ocDe=@OoKVi^1_lc<c<5ooooo`Oo9bLW1omPH607o`D51@OoOgmo1oo0`<07
odU9B@Oo@4101_l92@T=ooooo`002oooool7oemOG`Ool?3`1omHF5P7ojNWY`Oo9bLW1ol92@T7o`d=
3@KoYZJV1Oooool7okZj^POoc<c<1olY:BT7oc@d=0Oo2PX:1olJ6QX7o`h>3PKo@T921_ooool6ofUY
J@Oom?Cd1on9RHT7on_[j`OoIfMW1olc<c<7o`0000Ko=3@d1_ooool7ogalO0Oo2@T91_l10@47ob`/
;0OoHF5Q1on4Q8@7od51@@KoN7Qh1_ooool7okVi^@OoEEEE1olP8207o``<30Ko1PH61olB4Q87obl_
;`Kodm?C1_ooool7of1PH0Oo[Jf]1on1PH47ob8R8POo4A4A1om0@406od=3@`Ko<S8b1_ooool7oda<
C0Oo4a<C1omPH607obLW9`Oohn?S1olb<S87oe=CD`Ko4Q8B1Oooool7obXZ:POoGUiN1ol:2PX7ohb<
S0Oobl_;1olU9BD7oc`l?0Ko6ATI3Oooool000_ooooo1omOGel7oo3`l0OoF5QH1onWYjL7obLW9`Oo
2@T91ol=3@d6ojJVYPGooooo1onj^[X7olc<c0Oo:BTY1old=3@7o`X:2POo6QXJ1ol>3Ph6od92@PKo
oooo1_mYJFT7ooCdm0OoRHV91oo[jn/7ofMWI`Oo<c<c1ol00006oc@d=0Kooooo1omlO7`7o`T92@Ko
0@411ol/;2`7of5QH@OoQ8B41om1@D46ogQhN0Kooooo1oni^KT7oeEEE@Oo820P1ol<30`6o`H61POo
4Q8B1ol_;bl6om?Cd`Kooooo1omPH607ojf][@OoPH611olR8R87oa4A4@Oo@4101_m3@d<6oc8b<PKo
oooo1om<C4`7oa<C4`OoH61P1olW9bL7on?Sh`Oo<S8b1omCDe<6oa8B4PGooooo1olZ:RX7oeiNGPOo
2PX:1on<S8`7ol_;b`Oo9BDU1oll?3`6oaTI6@gooooo000;ooooo`OoGemO1oo`l?07oeQHF0OoYjNW
1olW9bL7o`T92@Oo3@d=1_nVYZH5ooooo`Oo^[Zj1oo<c<`7obTY:@Oo=3@d1ol:2PX7oaXJ6POo3Ph>
1_m2@T86ooooo`KoJFUY1oodm?@7ohV9R@Oojn_[1omWIfL7oc<c<`Oo00001_ld=3@6ooooo`OoO7al
1ol92@T6o`410@Oo;2`/1omQHF47ohB4Q0Oo@D511_mhN7P6ooooo`Oo^KVi1omEEED7ob0P80Oo30`<
1_l61PH7oa8B4POo;bl_1_oCdm<6ooooo`OoH61P1on][Jd7oh61P@Oo8R8R1olA4A47od10@0Ko@d=3
1_lb<S86ooooo`OoC4a<1olC4a<7of1PH0Oo9bLW1ooShn<7oc8b<POoDe=C1_lB4Q85ooooo`Oo:RXZ
1omNGUh7o`X:2POoS8b<1oo;bl/7obDU9@Oo?3`l1_lI6AT=ooooo`002oooool7oemOG`Ool?3`1omH
F5P7ojNWY`Oo9bLW1ol92@T7o`d=3@KoYZJV1Oooool7okZj^POoc<c<1olY:BT7oc@d=0Oo2PX:1olJ
6QX7o`h>3PKo@T921_ooool6ofUYJ@Oom?Cd1on9RHT7on_[j`OoIfMW1olc<c<7o`0000Ko=3@d1_oo
ool7ogalO0Oo2@T91_l10@47ob`/;0OoHF5Q1on4Q8@7od51@@KoN7Qh1_ooool7okVi^@OoEEEE1olP
8207o``<30Ko1PH61olB4Q87obl_;`Kodm?C1_ooool7of1PH0Oo[Jf]1on1PH47ob8R8POo4A4A1om0
@406od=3@`Ko<S8b1_ooool7oda<C0Oo4a<C1omPH607obLW9`Oohn?S1olb<S87oe=CD`Ko4Q8B1Ooo
ool7obXZ:POoGUiN1ol:2PX7ohb<S0Oobl_;1olU9BD7oc`l?0Ko6ATI3Oooool000_ooooo1omOGel7
oo3`l0OoF5QH1onWYjL7obLW9`Oo2@T91ol=3@d6ojJVYPGooooo1onj^[X7olc<c0Oo:BTY1old=3@7
o`X:2POo6QXJ1ol>3Ph6od92@PKooooo1_mYJFT7ooCdm0OoRHV91oo[jn/7ofMWI`Oo<c<c1ol00006
oc@d=0Kooooo1omlO7`7o`T92@Ko0@411ol/;2`7of5QH@OoQ8B41om1@D46ogQhN0Kooooo1oni^KT7
oeEEE@Oo820P1ol<30`6o`H61POo4Q8B1ol_;bl6om?Cd`Kooooo1omPH607ojf][@OoPH611olR8R87
oa4A4@Oo@4101_m3@d<6oc8b<PKooooo1om<C4`7oa<C4`OoH61P1olW9bL7on?Sh`Oo<S8b1omCDe<6
oa8B4PGooooo1olZ:RX7oeiNGPOo2PX:1on<S8`7ol_;b`Oo9BDU1oll?3`6oaTI6@gooooo000;oooo
o`OoGemO1oo`l?07oeQHF0OoYjNW1olW9bL7o`T92@Oo3@d=1_nVYZH5ooooo`Oo^[Zj1oo<c<`7obTY
:@Oo=3@d1ol:2PX7oaXJ6POo3Ph>1_m2@T86ooooo`KoJFUY1oodm?@7ohV9R@Oojn_[1omWIfL7oc<c
<`Oo00001_ld=3@6ooooo`OoO7al1ol92@T6o`410@Oo;2`/1omQHF47ohB4Q0Oo@D511_mhN7P6oooo
o`Oo^KVi1omEEED7ob0P80Oo30`<1_l61PH7oa8B4POo;bl_1_oCdm<6ooooo`OoH61P1on][Jd7oh61
P@Oo8R8R1olA4A47od10@0Ko@d=31_lb<S86ooooo`OoC4a<1olC4a<7of1PH0Oo9bLW1ooShn<7oc8b
<POoDe=C1_lB4Q85ooooo`Oo:RXZ1omNGUh7o`X:2POoS8b<1oo;bl/7obDU9@Oo?3`l1_lI6AT=oooo
o`002oooool7odY:BPOok>c/1omCDe<7ojNWY`Oo<S8b1ol00007o`d=3@KoSXj>1Oooool7om_Kf`Oo
fMWI1olX:2P7ocdm?@Oo1PH61ol@4107o`@410KoBDU91_ooool6of5QH@OoeMGE1on2PX87ooooo`Oo
Bd];1olP8207o`h>3PKo?Shn1_ooool7oinOW`OoAdM71_l>3Ph7ogMgM`Oo_kno1omDE5@7ob4Q8@Ko
[:b/1_ooool7olC4a0OoHF5Q1olF5QH7o`H61PKo0P821olF5QH7obd];@Koh^;R1_ooool7oeIFEPOo
OGem1on;Rh/7ofQXJ0Oo5aLG1omGEeL6okjn_PKo<C4a1_ooool7ocPh>0Oo00001omSHf<7oc4a<@Oo
l_;b1olO7al7ofUYJ@Ko2PX:1Oooool7ob<S8`OoF5QH1ol00007ojj^[POogmoO1olN7Qh7odM7A`Ko
3Ph>3Oooool000_ooooo1om:BTX7onc/k0OoDe=C1onWYjL7oc8b<POo00001ol=3@d6ohj>SPGooooo
1ooKfm/7omWIf@Oo:2PX1olm?Cd7o`H61POo410@1ol410@6odU9B@Kooooo1_mQHF47omGEe@OoPX:2
1oooool7od];B`Oo820P1ol>3Ph6ochn?PKooooo1onOWil7odM7A`Ko3Ph>1omgMgL7okno_`OoE5AD
1olQ8B46ojb/[0Kooooo1oo4a<@7of5QH@Oo5QHF1ol61PH6o`820POo5QHF1ol];Bd6on;RhPKooooo
1omFEUH7ogemO@OoRh^;1omXJ6P7oaLG5`OoEeMG1_nn_[h6oc4a<@Kooooo1olh>3P7o`0000OoHf=S
1ola<C47oo;blPOo7alO1omYJFT6o`X:2PGooooo1olS8b<7oeQHF0Oo00001on^[Zh7omoOg`Oo7QhN
1om7AdL6o`h>3Pgooooo000;ooooo`OoBTY:1oo/k>`7oe=CD`OoYjNW1olb<S87o`0000Oo3@d=1_n>
SXh5ooooo`Oofm_K1ooIfMT7obPX:0Oo?Cdm1ol61PH7oa0@40Oo10@41_m9BDT6ooooo`KoHF5Q1ooE
eMD7oh:2PPOooooo1om;Bd/7ob0P80Oo3Ph>1_ln?Sh6ooooo`OoWinO1om7AdL6o`h>3POoMgMg1ono
_kl7oeADE0Oo8B4Q1_n/[:`6ooooo`Ooa<C41omQHF47oaHF5POo1PH61_l20P87oaHF5POo;Bd]1_oR
h^86ooooo`OoEUIF1ommOGd7oh^;R`OoJ6QX1olG5aL7oeMGE`Ko_[jn1_la<C46ooooo`Oo>3Ph1ol0
0007of=SH`Oo<C4a1oobl_87oalO7`OoJFUY1_l:2PX5ooooo`Oo8b<S1omHF5P7o`0000Oo[Zj^1ooO
gml7oahN7POoAdM71_l>3Ph=ooooo`002oooool7odY:BPOok>c/1omCDe<7ojNWY`Oo<S8b1ol00007
o`d=3@KoSXj>1Oooool7om_Kf`OofMWI1olX:2P7ocdm?@Oo1PH61ol@4107o`@410KoBDU91_ooool6
of5QH@OoeMGE1on2PX87ooooo`OoBd];1olP8207o`h>3PKo?Shn1_ooool7oinOW`OoAdM71_l>3Ph7
ogMgM`Oo_kno1omDE5@7ob4Q8@Ko[:b/1_ooool7olC4a0OoHF5Q1olF5QH7o`H61PKo0P821olF5QH7
obd];@Koh^;R1_ooool7oeIFEPOoOGem1on;Rh/7ofQXJ0Oo5aLG1omGEeL6okjn_PKo<C4a1_ooool7
ocPh>0Oo00001omSHf<7oc4a<@Ool_;b1olO7al7ofUYJ@Ko2PX:1Oooool7ob<S8`OoF5QH1ol00007
ojj^[POogmoO1olN7Qh7odM7A`Ko3Ph>3Oooool000_ooooo1om:BTX7onc/k0OoDe=C1onWYjL7oc8b
<POo00001ol=3@d6ohj>SPGooooo1ooKfm/7omWIf@Oo:2PX1olm?Cd7o`H61POo410@1ol410@6odU9
B@Kooooo1_mQHF47omGEe@OoPX:21oooool7od];B`Oo820P1ol>3Ph6ochn?PKooooo1onOWil7odM7
A`Ko3Ph>1omgMgL7okno_`OoE5AD1olQ8B46ojb/[0Kooooo1oo4a<@7of5QH@Oo5QHF1ol61PH6o`82
0POo5QHF1ol];Bd6on;RhPKooooo1omFEUH7ogemO@OoRh^;1omXJ6P7oaLG5`OoEeMG1_nn_[h6oc4a
<@Kooooo1olh>3P7o`0000OoHf=S1ola<C47oo;blPOo7alO1omYJFT6o`X:2PGooooo1olS8b<7oeQH
F0Oo00001on^[Zh7omoOg`Oo7QhN1om7AdL6o`h>3Pgooooo000;ooooo`OoBTY:1oo/k>`7oe=CD`Oo
YjNW1olb<S87o`0000Oo3@d=1_n>SXh5ooooo`Oofm_K1ooIfMT7obPX:0Oo?Cdm1ol61PH7oa0@40Oo
10@41_m9BDT6ooooo`KoHF5Q1ooEeMD7oh:2PPOooooo1om;Bd/7ob0P80Oo3Ph>1_ln?Sh6ooooo`Oo
WinO1om7AdL6o`h>3POoMgMg1ono_kl7oeADE0Oo8B4Q1_n/[:`6ooooo`Ooa<C41omQHF47oaHF5POo
1PH61_l20P87oaHF5POo;Bd]1_oRh^86ooooo`OoEUIF1ommOGd7oh^;R`OoJ6QX1olG5aL7oeMGE`Ko
_[jn1_la<C46ooooo`Oo>3Ph1ol00007of=SH`Oo<C4a1oobl_87oalO7`OoJFUY1_l:2PX5ooooo`Oo
8b<S1omHF5P7o`0000Oo[Zj^1ooOgml7oahN7POoAdM71_l>3Ph=ooooo`002oooool7odY:BPOok>c/
1omCDe<7ojNWY`Oo<S8b1ol00007o`d=3@KoSXj>1Oooool7om_Kf`OofMWI1olX:2P7ocdm?@Oo1PH6
1ol@4107o`@410KoBDU91_ooool6of5QH@OoeMGE1on2PX87ooooo`OoBd];1olP8207o`h>3PKo?Shn
1_ooool7oinOW`OoAdM71_l>3Ph7ogMgM`Oo_kno1omDE5@7ob4Q8@Ko[:b/1_ooool7olC4a0OoHF5Q
1olF5QH7o`H61PKo0P821olF5QH7obd];@Koh^;R1_ooool7oeIFEPOoOGem1on;Rh/7ofQXJ0Oo5aLG
1omGEeL6okjn_PKo<C4a1_ooool7ocPh>0Oo00001omSHf<7oc4a<@Ool_;b1olO7al7ofUYJ@Ko2PX:
1Oooool7ob<S8`OoF5QH1ol00007ojj^[POogmoO1olN7Qh7odM7A`Ko3Ph>3Oooool000_ooooo1omH
F5P7ono_k`Oo=SHf1onSXj<7ob0P80Oo5QHF1ol61PH6oi:BTPGooooo1ooalO47okBd]0Oo6a/K1ol[
:b/7o`/;2`Oo7AdM1olF5QH6ocdm?@Kooooo1_m]KFd7ong]k@OoQXJ61oo^k^h7oeeMG@Oo9RHV1ol0
0006ob`/;0Kooooo1omIFET7o`d=3@Ko00001om<C4`7og1`L0OoO7al1olb<S86ofIVIPKooooo1oo2
`/87ofQXJ0Oo7alO1ol10@46o`H61POo71`L1old=3@<ooooo`OoN7Qh1onJVYX7ofa/K0Oo820P1ol0
0007ode=C@KoGemO1_mQHF46ooooo`OoC4a<1ol>3Ph7oeMGE`Oo<c<c1oolo?`7ob8R8POoD51@1_l4
10@5ooooo`Oo6a/K1omKFe/7o`l?3`Oo_Kfm1oo^k^h7oa@D50OoDE5A1_lM7Ad=ooooo`002oooool7
oeQHF0Ookno_1olf=SH7oj>SX`Oo820P1olF5QH7o`H61PKoTY:B1Oooool7oo7al@Oo];Bd1olK6a/7
ob/[:`Oo2`/;1olM7Ad7oaHF5PKo?Cdm1_ooool6ofe]K@OokNg]1on6QXH7onk^kPOoGEeM1olV9RH7
o`0000Ko;2`/1_ooool7oeUIF@Oo3@d=1_l00007oda<C0OoL71`1omlO7`7oc8b<PKoIVIV1_ooool7
ol;2`POoJ6QX1olO7al7o`410@Ko1PH61olL71`7oc@d=0cooooo1omhN7P7oiZJVPOoK6a/1olP8207
o`0000OoCDe=1_mOGel6of5QH@Kooooo1om<C4`7o`h>3POoEeMG1olc<c<7ooclo0Oo8R8R1om@D506
o`@410Gooooo1olK6a/7oe]KF`Oo3`l?1onm_Kd7onk^kPOo51@D1omADE46oadM7@gooooo000;oooo
o`OoF5QH1oo_knl7ocHf=POoXj>S1olP8207oaHF5POo1PH61_nBTY85ooooo`OolO7a1ond];@7oa/K
6`Oo:b/[1ol;2`/7oadM7@Oo5QHF1_lm?Cd6ooooo`KoKFe]1oo]kNd7ohJ6QPOok^k^1omMGEd7obHV
9POo00001_l/;2`6ooooo`OoFEUI1ol=3@d6o`0000OoC4a<1om`L707ogalO0Oo<S8b1_mVIVH6oooo
o`Oo`/;21omXJ6P7oalO7`Oo0@411_l61PH7oa`L70Oo=3@d3?ooool7ogQhN0OoVYZJ1om/K6`7ob0P
80Oo00001om=CDd6oemOG`KoHF5Q1_ooool7oda<C0Oo3Ph>1omGEeL7oc<c<`Ooo?cl1olR8R87oe1@
D0Ko10@41Oooool7oa/K6`OoFe]K1ol?3`l7okfm_@Ook^k^1olD51@7oe5AD@Ko7AdM3Oooool000_o
oooo1omHF5P7ono_k`Oo=SHf1onSXj<7ob0P80Oo5QHF1ol61PH6oi:BTPGooooo1ooalO47okBd]0Oo
6a/K1ol[:b/7o`/;2`Oo7AdM1olF5QH6ocdm?@Kooooo1_m]KFd7ong]k@OoQXJ61oo^k^h7oeeMG@Oo
9RHV1ol00006ob`/;0Kooooo1omIFET7o`d=3@Ko00001om<C4`7og1`L0OoO7al1olb<S86ofIVIPKo
oooo1oo2`/87ofQXJ0Oo7alO1ol10@46o`H61POo71`L1old=3@<ooooo`OoN7Qh1onJVYX7ofa/K0Oo
820P1ol00007ode=C@KoGemO1_mQHF46ooooo`OoC4a<1ol>3Ph7oeMGE`Oo<c<c1oolo?`7ob8R8POo
D51@1_l410@5ooooo`Oo6a/K1omKFe/7o`l?3`Oo_Kfm1oo^k^h7oa@D50OoDE5A1_lM7Ad=ooooo`00
2oooool7oeQHF0Ookno_1olf=SH7oj>SX`Oo820P1olF5QH7o`H61PKoTY:B1Oooool7oo7al@Oo];Bd
1olK6a/7ob/[:`Oo2`/;1olM7Ad7oaHF5PKo?Cdm1_ooool6ofe]K@OokNg]1on6QXH7onk^kPOoGEeM
1olV9RH7o`0000Ko;2`/1_ooool7oeUIF@Oo3@d=1_l00007oda<C0OoL71`1omlO7`7oc8b<PKoIVIV
1_ooool7ol;2`POoJ6QX1olO7al7o`410@Ko1PH61olL71`7oc@d=0cooooo1omhN7P7oiZJVPOoK6a/
1olP8207o`0000OoCDe=1_mOGel6of5QH@Kooooo1om<C4`7o`h>3POoEeMG1olc<c<7ooclo0Oo8R8R
1om@D506o`@410Gooooo1olK6a/7oe]KF`Oo3`l?1onm_Kd7onk^kPOo51@D1omADE46oadM7@gooooo
000;ooooo`OoF5QH1oo_knl7ocHf=POoXj>S1olP8207oaHF5POo1PH61_nBTY85ooooo`OolO7a1ond
];@7oa/K6`Oo:b/[1ol;2`/7oadM7@Oo5QHF1_lm?Cd6ooooo`KoKFe]1oo]kNd7ohJ6QPOok^k^1omM
GEd7obHV9POo00001_l/;2`6ooooo`OoFEUI1ol=3@d6o`0000OoC4a<1om`L707ogalO0Oo<S8b1_mV
IVH6ooooo`Oo`/;21omXJ6P7oalO7`Oo0@411_l61PH7oa`L70Oo=3@d3?ooool7ogQhN0OoVYZJ1om/
K6`7ob0P80Oo00001om=CDd6oemOG`KoHF5Q1_ooool7oda<C0Oo3Ph>1omGEeL7oc<c<`Ooo?cl1olR
8R87oe1@D0Ko10@41Oooool7oa/K6`OoFe]K1ol?3`l7okfm_@Ook^k^1olD51@7oe5AD@Ko7AdM3Ooo
ool000_ooooo1omHF5P7ono_k`Oo=SHf1onSXj<7ob0P80Oo5QHF1ol61PH6oi:BTPGooooo1ooalO47
okBd]0Oo6a/K1ol[:b/7o`/;2`Oo7AdM1olF5QH6ocdm?@Kooooo1_m]KFd7ong]k@OoQXJ61oo^k^h7
oeeMG@Oo9RHV1ol00006ob`/;0Kooooo1omIFET7o`d=3@Ko00001om<C4`7og1`L0OoO7al1olb<S86
ofIVIPKooooo1oo2`/87ofQXJ0Oo7alO1ol10@46o`H61POo71`L1old=3@<ooooo`OoN7Qh1onJVYX7
ofa/K0Oo820P1ol00007ode=C@KoGemO1_mQHF46ooooo`OoC4a<1ol>3Ph7oeMGE`Oo<c<c1oolo?`7
ob8R8POoD51@1_l410@5ooooo`Oo6a/K1omKFe/7o`l?3`Oo_Kfm1oo^k^h7oa@D50OoDE5A1_lM7Ad=
ooooo`002oooool7odY:BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi
^@Oo6QXJ1ole=CD7o`0000Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92
@POo71`L1olI6AT6ocTi>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOW
i`Kooooo1one]KD7ogYjNPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^K
V`OoL71`3_lm?Cd7ofa/K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C
4`OoEeMG1_l92@T5ooooo`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=oooo
o`002oooool7odY:BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi^@Oo
6QXJ1ole=CD7o`0000Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92@POo
71`L1olI6AT6ocTi>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOWi`Ko
oooo1one]KD7ogYjNPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^KV`Oo
L71`3_lm?Cd7ofa/K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C4`Oo
EeMG1_l92@T5ooooo`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=ooooo`00
2oooool7odY:BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi^@Oo6QXJ
1ole=CD7o`0000Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92@POo71`L
1olI6AT6ocTi>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOWi`Kooooo
1one]KD7ogYjNPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^KV`OoL71`
3_lm?Cd7ofa/K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C4`OoEeMG
1_l92@T5ooooo`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=ooooo`002ooo
ool7odY:BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi^@Oo6QXJ1ole
=CD7o`0000Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92@POo71`L1olI
6AT6ocTi>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOWi`Kooooo1one
]KD7ogYjNPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^KV`OoL71`3_lm
?Cd7ofa/K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C4`OoEeMG1_l9
2@T5ooooo`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=ooooo`002oooool7
odY:BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi^@Oo6QXJ1ole=CD7
o`0000Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92@POo71`L1olI6AT6
ocTi>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOWi`Kooooo1one]KD7
ogYjNPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^KV`OoL71`3_lm?Cd7
ofa/K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C4`OoEeMG1_l92@T5
ooooo`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=ooooo`002oooool7odY:
BPOooooo1om:BTX7oiVIV@Oo9bLW1ol=3@d7oaHF5PKoSHf=3?ooool7okVi^@Oo6QXJ1ole=CD7o`00
00Oo5aLG1ol@4106od];B`Kooooo1_mMGEd7omGEe@OoU9BD1ooRh^87od92@POo71`L1olI6AT6ocTi
>@Kooooo1on<S8`7ob@T90KoBTY:1onATI47ojVYZ@OoBDU91olT92@6onOWi`Kooooo1one]KD7ogYj
NPOo9bLW1ol00006o`<30`Oo9bLW1ol`<306omKFePKooooo1omXJ6P7oi^KV`OoL71`3_lm?Cd7ofa/
K0KoXj>S1_l[:b/6ooooo`Oo=SHf1olD51@7ofIVIPOo?clo1oo`l?07oa<C4`OoEeMG1_l92@T5oooo
o`Oo820P1omKFe/7oaPH60OoiNGU1oo^k^h7oaTI6@OoBd];1_l;2`/=ooooo`002oooool7ofIVIPOo
fMWI1olm?Cd7oi6AT@Oo9BDU1ol[:b/7oaXJ6PKoTY:B1Oooool7ooWin@OoRXZ:1olN7Qh7obl_;`Oo
3Ph>1olX:2P7oaTI6@KoDU9B1_ooool6of9RHPOod=3@1onSXj<7ol_;b`Oo@d=31olN7Qh7oa8B4PKo
<S8b1_ooool7ocLg=`Oo30`<1_l20P87ogMgM`OoM7Ad1om[Jf/7ob8R8PKoFe]K1_ooool7okNg]`Oo
JVYZ1olU9BD7oa0@40Ko2PX:1ol/;2`7od=3@`Kon?Sh1_ooool7ohj>SPOoS8b<1om1@D47obTY:@Oo
20P81omOGel6oginOPKo/k>c1_ooool7odY:BPOo51@D1omLG5`7ocPh>0Oooooo1olU9BD7odI6APKo
00001Oooool7oaXJ6POoDE5A1olX:2P7oo?cl`Oohn?S1olL71`7oeEEE@Ko6ATI3Oooool000_ooooo
1omVIVH7omWIf@Oo?Cdm1onATI47obDU9@Oo:b/[1olJ6QX6oi:BTPGooooo1ooinOT7ohZ:RPOo7QhN
1ol_;bl7o`h>3POo:2PX1olI6AT6oe9BDPKooooo1_mRHV87om3@d0OoXj>S1oo;bl/7od=3@`Oo7QhN
1olB4Q86oc8b<PKooooo1olg=cL7o``<30Ko0P821omgMgL7ogAdM0OoJf][1olR8R86oe]KF`Kooooo
1ong]kL7ofYZJPOo9BDU1ol@4106o`X:2POo;2`/1om3@d<6ooShn0Kooooo1on>SXh7ohb<S0Oo@D51
1olY:BT7o`P820OoGemO1_mnOWh6ok>c/`Kooooo1om:BTX7oa@D50OoG5aL1olh>3P7ooooo`Oo9BDU
1om6ATH6o`0000Gooooo1olJ6QX7oe5AD@Oo:2PX1ooclo<7on?Sh`Oo71`L1omEEED6oaTI6@gooooo
000;ooooo`OoIVIV1ooIfMT7ocdm?@OoTI6A1olU9BD7ob/[:`Oo6QXJ1_nBTY85ooooo`OonOWi1on:
RXX7oahN7POo;bl_1ol>3Ph7obPX:0Oo6ATI1_mBDU86ooooo`KoHV9R1oo@d=07oj>SX`Oobl_;1om3
@d<7oahN7POo4Q8B1_lb<S86ooooo`Oo=cLg1ol<30`6o`820POoMgMg1omdM7@7of][J`Oo8R8R1_mK
Fe/6ooooo`Oo]kNg1omZJVX7obDU9@Oo410@1_l:2PX7ob`/;0Oo@d=31_ohn?P6ooooo`OoSXj>1on<
S8`7od51@@Oo:BTY1ol820P7oemOG`KoOWin1_nc/k<6ooooo`OoBTY:1olD51@7oeaLG0Oo>3Ph1ooo
ool7obDU9@OoATI61_l00005ooooo`Oo6QXJ1omADE47obPX:0Oolo?c1ooShn<7oa`L70OoEEEE1_lI
6AT=ooooo`002oooool7ofIVIPOofMWI1olm?Cd7oi6AT@Oo9BDU1ol[:b/7oaXJ6PKoTY:B1Oooool7
ooWin@OoRXZ:1olN7Qh7obl_;`Oo3Ph>1olX:2P7oaTI6@KoDU9B1_ooool6of9RHPOod=3@1onSXj<7
ol_;b`Oo@d=31olN7Qh7oa8B4PKo<S8b1_ooool7ocLg=`Oo30`<1_l20P87ogMgM`OoM7Ad1om[Jf/7
ob8R8PKoFe]K1_ooool7okNg]`OoJVYZ1olU9BD7oa0@40Ko2PX:1ol/;2`7od=3@`Kon?Sh1_ooool7
ohj>SPOoS8b<1om1@D47obTY:@Oo20P81omOGel6oginOPKo/k>c1_ooool7odY:BPOo51@D1omLG5`7
ocPh>0Oooooo1olU9BD7odI6APKo00001Oooool7oaXJ6POoDE5A1olX:2P7oo?cl`Oohn?S1olL71`7
oeEEE@Ko6ATI3Oooool000_ooooo1omVIVH7omWIf@Oo?Cdm1onATI47obDU9@Oo:b/[1olJ6QX6oi:B
TPGooooo1ooinOT7ohZ:RPOo7QhN1ol_;bl7o`h>3POo:2PX1olI6AT6oe9BDPKooooo1_mRHV87om3@
d0OoXj>S1oo;bl/7od=3@`Oo7QhN1olB4Q86oc8b<PKooooo1olg=cL7o``<30Ko0P821omgMgL7ogAd
M0OoJf][1olR8R86oe]KF`Kooooo1ong]kL7ofYZJPOo9BDU1ol@4106o`X:2POo;2`/1om3@d<6ooSh
n0Kooooo1on>SXh7ohb<S0Oo@D511olY:BT7o`P820OoGemO1_mnOWh6ok>c/`Kooooo1om:BTX7oa@D
50OoG5aL1olh>3P7ooooo`Oo9BDU1om6ATH6o`0000Gooooo1olJ6QX7oe5AD@Oo:2PX1ooclo<7on?S
h`Oo71`L1omEEED6oaTI6@gooooo000;ooooo`OoIVIV1ooIfMT7ocdm?@OoTI6A1olU9BD7ob/[:`Oo
6QXJ1_nBTY85ooooo`OonOWi1on:RXX7oahN7POo;bl_1ol>3Ph7obPX:0Oo6ATI1_mBDU86ooooo`Ko
HV9R1oo@d=07oj>SX`Oobl_;1om3@d<7oahN7POo4Q8B1_lb<S86ooooo`Oo=cLg1ol<30`6o`820POo
MgMg1omdM7@7of][J`Oo8R8R1_mKFe/6ooooo`Oo]kNg1omZJVX7obDU9@Oo410@1_l:2PX7ob`/;0Oo
@d=31_ohn?P6ooooo`OoSXj>1on<S8`7od51@@Oo:BTY1ol820P7oemOG`KoOWin1_nc/k<6ooooo`Oo
BTY:1olD51@7oeaLG0Oo>3Ph1oooool7obDU9@OoATI61_l00005ooooo`Oo6QXJ1omADE47obPX:0Oo
lo?c1ooShn<7oa`L70OoEEEE1_lI6AT=ooooo`002oooool7ofIVIPOofMWI1olm?Cd7oi6AT@Oo9BDU
1ol[:b/7oaXJ6PKoTY:B1Oooool7ooWin@OoRXZ:1olN7Qh7obl_;`Oo3Ph>1olX:2P7oaTI6@KoDU9B
1_ooool6of9RHPOod=3@1onSXj<7ol_;b`Oo@d=31olN7Qh7oa8B4PKo<S8b1_ooool7ocLg=`Oo30`<
1_l20P87ogMgM`OoM7Ad1om[Jf/7ob8R8PKoFe]K1_ooool7okNg]`OoJVYZ1olU9BD7oa0@40Ko2PX:
1ol/;2`7od=3@`Kon?Sh1_ooool7ohj>SPOoS8b<1om1@D47obTY:@Oo20P81omOGel6oginOPKo/k>c
1_ooool7odY:BPOo51@D1omLG5`7ocPh>0Oooooo1olU9BD7odI6APKo00001Oooool7oaXJ6POoDE5A
1olX:2P7oo?cl`Oohn?S1olL71`7oeEEE@Ko6ATI3Oooool000_ooooo1omQHF47olk>cPOoF5QH1on6
QXH7obLW9`Oo820P1olV9RH6og9bLPGooooo1oodm?@7ogmoO`Oo<C4a1olX:2P7o`T92@Oo;Bd]1olI
6AT6ofUYJ@Kooooo1_mUIFD7ol?3``OoZJVY1oo1`L47ocXj>POo:b/[1olR8R86odY:BPKooooo1omj
NWX7o``<30KoShn?1onBTY87oi6AT@Oo9RHV1ol[:b/<ooooo`OoW9bL1on2PX87ocPh>0Oo6ATI1_lF
5QH7obXZ:POoDe=C1_n/[:`6ooooo`OoPX:21onNWYh7oeeMG@Oo9RHV1omiNGT7ogemO@KoRh^;1_l[
:b/6ooooo`Oo?clo1olP8207ofMWI`OoCDe=1ooMgMd7oaXJ6POoBd];1_l51@D5ooooo`Oo;Bd]1omX
J6P7oda<C0Oooooo1ooBd]87oc8b<POoBDU91_lH61P=ooooo`002oooool7of5QH@Ooc/k>1omHF5P7
ohJ6QPOo9bLW1olP8207obHV9PKoLW9b1Oooool7ooCdm0OoOgmo1ola<C47obPX:0Oo2@T91ol];Bd7
oaTI6@KoJFUY1_ooool6ofEUI@Oo`l?31onYZJT7ol71`@Oo>SXj1ol[:b/7ob8R8PKoBTY:1_ooool7
ogYjNPOo30`<1_n?Shl7oi:BTPOoTI6A1olV9RH7ob/[:`cooooo1onLW9`7oh:2PPOo>3Ph1olI6AT6
oaHF5POo:RXZ1omCDe<6ojb/[0Kooooo1on2PX87oijNWPOoGEeM1olV9RH7ogUiN@OoOGem1_n;Rh/6
ob/[:`Kooooo1olo?cl7ob0P80OoIfMW1om=CDd7omgMg@Oo6QXJ1om;Bd/6o`D51@Gooooo1ol];Bd7
ofQXJ0OoC4a<1oooool7om;BdPOo<S8b1om9BDT6oaPH60gooooo000;ooooo`OoHF5Q1oo>c/h7oeQH
F0OoQXJ61olW9bL7ob0P80Oo9RHV1_mbLW85ooooo`Oom?Cd1omoOgl7oc4a<@Oo:2PX1ol92@T7obd]
;@Oo6ATI1_mYJFT6ooooo`KoIFEU1oo3`l<7ojVYZ@Oo`L711olj>SX7ob/[:`Oo8R8R1_m:BTX6oooo
o`OoNWYj1ol<30`6ohn?S`OoTY:B1onATI47obHV9POo:b/[3?ooool7oibLW0OoPX:21olh>3P7oaTI
6@Ko5QHF1olZ:RX7oe=CD`Ko[:b/1_ooool7oh:2PPOoWYjN1omMGEd7obHV9POoNGUi1ommOGd6oh^;
R`Ko:b/[1_ooool7oclo?`Oo820P1omWIfL7ode=C@OogMgM1olJ6QX7od];B`Ko1@D51Oooool7obd]
;@OoJ6QX1om<C4`7ooooo`Ood];B1olb<S87odU9B@Ko61PH3Oooool000_ooooo1omQHF47olk>cPOo
F5QH1on6QXH7obLW9`Oo820P1olV9RH6og9bLPGooooo1oodm?@7ogmoO`Oo<C4a1olX:2P7o`T92@Oo
;Bd]1olI6AT6ofUYJ@Kooooo1_mUIFD7ol?3``OoZJVY1oo1`L47ocXj>POo:b/[1olR8R86odY:BPKo
oooo1omjNWX7o``<30KoShn?1onBTY87oi6AT@Oo9RHV1ol[:b/<ooooo`OoW9bL1on2PX87ocPh>0Oo
6ATI1_lF5QH7obXZ:POoDe=C1_n/[:`6ooooo`OoPX:21onNWYh7oeeMG@Oo9RHV1omiNGT7ogemO@Ko
Rh^;1_l[:b/6ooooo`Oo?clo1olP8207ofMWI`OoCDe=1ooMgMd7oaXJ6POoBd];1_l51@D5ooooo`Oo
;Bd]1omXJ6P7oda<C0Oooooo1ooBd]87oc8b<POoBDU91_lH61P=ooooo`002oooool7of5QH@Ooc/k>
1omHF5P7ohJ6QPOo9bLW1olP8207obHV9PKoLW9b1Oooool7ooCdm0OoOgmo1ola<C47obPX:0Oo2@T9
1ol];Bd7oaTI6@KoJFUY1_ooool6ofEUI@Oo`l?31onYZJT7ol71`@Oo>SXj1ol[:b/7ob8R8PKoBTY:
1_ooool7ogYjNPOo30`<1_n?Shl7oi:BTPOoTI6A1olV9RH7ob/[:`cooooo1onLW9`7oh:2PPOo>3Ph
1olI6AT6oaHF5POo:RXZ1omCDe<6ojb/[0Kooooo1on2PX87oijNWPOoGEeM1olV9RH7ogUiN@OoOGem
1_n;Rh/6ob/[:`Kooooo1olo?cl7ob0P80OoIfMW1om=CDd7omgMg@Oo6QXJ1om;Bd/6o`D51@Gooooo
1ol];Bd7ofQXJ0OoC4a<1oooool7om;BdPOo<S8b1om9BDT6oaPH60gooooo000;ooooo`OoHF5Q1oo>
c/h7oeQHF0OoQXJ61olW9bL7ob0P80Oo9RHV1_mbLW85ooooo`Oom?Cd1omoOgl7oc4a<@Oo:2PX1ol9
2@T7obd];@Oo6ATI1_mYJFT6ooooo`KoIFEU1oo3`l<7ojVYZ@Oo`L711olj>SX7ob/[:`Oo8R8R1_m:
BTX6ooooo`OoNWYj1ol<30`6ohn?S`OoTY:B1onATI47obHV9POo:b/[3?ooool7oibLW0OoPX:21olh
>3P7oaTI6@Ko5QHF1olZ:RX7oe=CD`Ko[:b/1_ooool7oh:2PPOoWYjN1omMGEd7obHV9POoNGUi1omm
OGd6oh^;R`Ko:b/[1_ooool7oclo?`Oo820P1omWIfL7ode=C@OogMgM1olJ6QX7od];B`Ko1@D51Ooo
ool7obd];@OoJ6QX1om<C4`7ooooo`Ood];B1olb<S87odU9B@Ko61PH3Oooool000_ooooo1omQHF47
olk>cPOoF5QH1on6QXH7obLW9`Oo820P1olV9RH6og9bLPGooooo1oodm?@7ogmoO`Oo<C4a1olX:2P7
o`T92@Oo;Bd]1olI6AT6ofUYJ@Kooooo1_mUIFD7ol?3``OoZJVY1oo1`L47ocXj>POo:b/[1olR8R86
odY:BPKooooo1omjNWX7o``<30KoShn?1onBTY87oi6AT@Oo9RHV1ol[:b/<ooooo`OoW9bL1on2PX87
ocPh>0Oo6ATI1_lF5QH7obXZ:POoDe=C1_n/[:`6ooooo`OoPX:21onNWYh7oeeMG@Oo9RHV1omiNGT7
ogemO@KoRh^;1_l[:b/6ooooo`Oo?clo1olP8207ofMWI`OoCDe=1ooMgMd7oaXJ6POoBd];1_l51@D5
ooooo`Oo;Bd]1omXJ6P7oda<C0Oooooo1ooBd]87oc8b<POoBDU91_lH61P=ooooo`002oooool7oemO
G`Oo`/;21om8B4P7oh61P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[
:`Oo3Ph>1ol/;2`7oadM7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51
@@Kooooo1olP8207ob<S8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][
J`Oo;Rh^1ol];Bd6oadM7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>
3POoIfMW1_mkNg/<ooooo`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5oooo
o`Oo:BTY1omEEED7oe5AD@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`002oooool7oemOG`Oo
`/;21om8B4P7oh61P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[:`Oo
3Ph>1ol/;2`7oadM7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51@@Ko
oooo1olP8207ob<S8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][J`Oo
;Rh^1ol];Bd6oadM7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>3POo
IfMW1_mkNg/<ooooo`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5ooooo`Oo
:BTY1omEEED7oe5AD@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`002oooool7oemOG`Oo`/;2
1om8B4P7oh61P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[:`Oo3Ph>
1ol/;2`7oadM7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51@@Kooooo
1olP8207ob<S8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][J`Oo;Rh^
1ol];Bd6oadM7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>3POoIfMW
1_mkNg/<ooooo`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5ooooo`Oo:BTY
1omEEED7oe5AD@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`002oooool7oemOG`Oo`/;21om8
B4P7oh61P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[:`Oo3Ph>1ol/
;2`7oadM7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51@@Kooooo1olP
8207ob<S8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][J`Oo;Rh^1ol]
;Bd6oadM7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>3POoIfMW1_mk
Ng/<ooooo`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5ooooo`Oo:BTY1omE
EED7oe5AD@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`002oooool7oemOG`Oo`/;21om8B4P7
oh61P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[:`Oo3Ph>1ol/;2`7
oadM7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51@@Kooooo1olP8207
ob<S8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][J`Oo;Rh^1ol];Bd6
oadM7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>3POoIfMW1_mkNg/<
ooooo`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5ooooo`Oo:BTY1omEEED7
oe5AD@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`002oooool7oemOG`Oo`/;21om8B4P7oh61
P@Oo9RHV1ol];Bd7obDU9@KoU9BD1Oooool7om;BdPOoEEEE1olY:BT7ob/[:`Oo3Ph>1ol/;2`7oadM
7@KoIVIV1_ooool6of5QH@OoXJ6Q1onVYZH7ohf=S@Oo<S8b3_lO7al6od51@@Kooooo1olP8207ob<S
8`Ko0`<31on0P807of=SH`OoF5QH1olU9BD6oc8b<PKooooo1on=SHd7of][J`Oo;Rh^1ol];Bd6oadM
7@OoAdM71om4A4@6okFe]@Kooooo1onHV9P7ofATI0Oo=CDe1om3@d<7o`h>3POoIfMW1_mkNg/<oooo
o`OoBDU91olL71`7oeUIF@OoBDU91ooVi^H7ob8R8POo>SXj1_l51@D5ooooo`Oo:BTY1omEEED7oe5A
D@Ooj^[Z1on_[jl7obXZ:POoA4A41_lA4A4=ooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002ooo
ool7oaLG5`Oo:2PX1olP8207oa<C4`OoATI61ol/;2`7om3@d0Ko9BDU1Oooool7omoOg`Oo8b<S1ol`
<307oalO7`Oo<S8b1olO7al7oa`L70Ko5aLG1_ooool6oaHF5POo8b<S1oli>CT7oj2PX0OoN7Qh1ol[
:b/7obTY:@KoF5QH1_ooool7ojRXZ0OoCDe=1_l<30`7oh61P@OoLW9b1olW9bL7ohJ6QPKo8b<S1_oo
ool7obd];@Oo3Ph>1olR8R87ob0P80Ko6a/K1olN7Qh7oa0@40cooooo1ol/;2`7obHV9POoalO71olE
5AD7oeiNGPOo5QHF1_lW9bL6oa/K6`Kooooo1ol^;Rh7ob@T90Oo>CTi1on;Rh/7okbl_0Oog]kN1om7
AdL6ohJ6QPGooooo1oo8b<P7ocDe=@OoBd];1olY:BT7oaPH60Oo@T921onGUiL6oa@D50gooooo000;
ooooo`Oo5aLG1olX:2P7ob0P80Oo4a<C1om6ATH7ob`/;0Ood=3@1_lU9BD5ooooo`OogmoO1olS8b<7
oc0`<0Oo7alO1olb<S87oalO7`Oo71`L1_lG5aL6ooooo`Ko5QHF1olS8b<7ocTi>@OoX:2P1omhN7P7
ob/[:`Oo:BTY1_mHF5P6ooooo`OoZ:RX1om=CDd6o``<30OoPH611ombLW87obLW9`OoQXJ61_lS8b<6
ooooo`Oo;Bd]1ol>3Ph7ob8R8POo820P1_lK6a/7oahN7POo410@3?ooool7ob`/;0Oo9RHV1oo7alL7
oaDE5@OoGUiN1olF5QH6obLW9`Ko6a/K1_ooool7obh^;POo92@T1oli>CT7oh^;R`Oo_;bl1ooNg]h7
odM7A`KoQXJ61Oooool7olS8b0Oo=CDe1om;Bd/7obTY:@Oo61PH1om2@T87oiNGU`Ko51@D3Oooool0
00_ooooo1olG5aL7obPX:0Oo820P1olC4a<7odI6APOo;2`/1oo@d=06obDU9@Gooooo1ooOgml7ob<S
8`Oo<30`1olO7al7oc8b<POo7alO1olL71`6oaLG5`Kooooo1_lF5QH7ob<S8`Oo>CTi1onPX:07ogQh
N0Oo:b/[1olY:BT6oeQHF0Kooooo1onXZ:P7ode=C@Ko30`<1on1PH47og9bLPOo9bLW1on6QXH6ob<S
8`Kooooo1ol];Bd7o`h>3POo8R8R1olP8206oa/K6`Oo7QhN1ol@410<ooooo`Oo;2`/1olV9RH7olO7
a`Oo5ADE1omNGUh7oaHF5PKo9bLW1_lK6a/6ooooo`Oo;Rh^1olT92@7ocTi>@OoRh^;1onl_;`7omkN
gPOoAdM71_n6QXH5ooooo`Oob<S81ole=CD7od];B`Oo:BTY1olH61P7od92@POoUiNG1_lD51@=oooo
o`002oooool7oaLG5`Oo:2PX1olP8207oa<C4`OoATI61ol/;2`7om3@d0Ko9BDU1Oooool7omoOg`Oo
8b<S1ol`<307oalO7`Oo<S8b1olO7al7oa`L70Ko5aLG1_ooool6oaHF5POo8b<S1oli>CT7oj2PX0Oo
N7Qh1ol[:b/7obTY:@KoF5QH1_ooool7ojRXZ0OoCDe=1_l<30`7oh61P@OoLW9b1olW9bL7ohJ6QPKo
8b<S1_ooool7obd];@Oo3Ph>1olR8R87ob0P80Ko6a/K1olN7Qh7oa0@40cooooo1ol/;2`7obHV9POo
alO71olE5AD7oeiNGPOo5QHF1_lW9bL6oa/K6`Kooooo1ol^;Rh7ob@T90Oo>CTi1on;Rh/7okbl_0Oo
g]kN1om7AdL6ohJ6QPGooooo1oo8b<P7ocDe=@OoBd];1olY:BT7oaPH60Oo@T921onGUiL6oa@D50go
oooo000;ooooo`Oo5aLG1olX:2P7ob0P80Oo4a<C1om6ATH7ob`/;0Ood=3@1_lU9BD5ooooo`OogmoO
1olS8b<7oc0`<0Oo7alO1olb<S87oalO7`Oo71`L1_lG5aL6ooooo`Ko5QHF1olS8b<7ocTi>@OoX:2P
1omhN7P7ob/[:`Oo:BTY1_mHF5P6ooooo`OoZ:RX1om=CDd6o``<30OoPH611ombLW87obLW9`OoQXJ6
1_lS8b<6ooooo`Oo;Bd]1ol>3Ph7ob8R8POo820P1_lK6a/7oahN7POo410@3?ooool7ob`/;0Oo9RHV
1oo7alL7oaDE5@OoGUiN1olF5QH6obLW9`Ko6a/K1_ooool7obh^;POo92@T1oli>CT7oh^;R`Oo_;bl
1ooNg]h7odM7A`KoQXJ61Oooool7olS8b0Oo=CDe1om;Bd/7obTY:@Oo61PH1om2@T87oiNGU`Ko51@D
3Oooool000_ooooo1olG5aL7obPX:0Oo820P1olC4a<7odI6APOo;2`/1oo@d=06obDU9@Gooooo1ooO
gml7ob<S8`Oo<30`1olO7al7oc8b<POo7alO1olL71`6oaLG5`Kooooo1_lF5QH7ob<S8`Oo>CTi1onP
X:07ogQhN0Oo:b/[1olY:BT6oeQHF0Kooooo1onXZ:P7ode=C@Ko30`<1on1PH47og9bLPOo9bLW1on6
QXH6ob<S8`Kooooo1ol];Bd7o`h>3POo8R8R1olP8206oa/K6`Oo7QhN1ol@410<ooooo`Oo;2`/1olV
9RH7olO7a`Oo5ADE1omNGUh7oaHF5PKo9bLW1_lK6a/6ooooo`Oo;Rh^1olT92@7ocTi>@OoRh^;1onl
_;`7omkNgPOoAdM71_n6QXH5ooooo`Oob<S81ole=CD7od];B`Oo:BTY1olH61P7od92@POoUiNG1_lD
51@=ooooo`002oooool7oaLG5`Oo:2PX1olP8207oa<C4`OoATI61ol/;2`7om3@d0Ko9BDU1Oooool7
omoOg`Oo8b<S1ol`<307oalO7`Oo<S8b1olO7al7oa`L70Ko5aLG1_ooool6oaHF5POo8b<S1oli>CT7
oj2PX0OoN7Qh1ol[:b/7obTY:@KoF5QH1_ooool7ojRXZ0OoCDe=1_l<30`7oh61P@OoLW9b1olW9bL7
ohJ6QPKo8b<S1_ooool7obd];@Oo3Ph>1olR8R87ob0P80Ko6a/K1olN7Qh7oa0@40cooooo1ol/;2`7
obHV9POoalO71olE5AD7oeiNGPOo5QHF1_lW9bL6oa/K6`Kooooo1ol^;Rh7ob@T90Oo>CTi1on;Rh/7
okbl_0Oog]kN1om7AdL6ohJ6QPGooooo1oo8b<P7ocDe=@OoBd];1olY:BT7oaPH60Oo@T921onGUiL6
oa@D50gooooo000;ooooo`Oo5QHF1olB4Q87oadM7@Oo71`L1olo?cl7obXZ:POog=cL1_lb<S85oooo
o`OoinOW1ol?3`l7oahN7POo6ATI1ol`<307o``<30Oo6ATI1_l>3Ph6ooooo`Ko2`/;1olE5AD7oc4a
<@Oo_Kfm1omTI6@7ocPh>0Oo820P1_m:BTX6ooooo`OoMGEe1omGEeL6oa8B4POoJVYZ1omADE47oa8B
4POoBTY:1_lA4A46ooooo`Oo8b<S1olG5aL7oa@D50Oo5QHF1_lQ8B47ob<S8`Oo3`l?1_oShn<6oooo
o`Oo;bl_1olP8207omSHf0Oo2@T91omOGel7oa/K6`Ko;Bd]1_lJ6QX6ooooo`OoMGEe1olR8R87ofa/
K0Oo_[jn1on[Zj/7ode=C@Oo=3@d2oooool7onSXj0Oo8B4Q1omADE47obXZ:POo5aLG1om8B4P7oiNG
U`Ko30`<3Oooool000_ooooo1olF5QH7oa8B4POo7AdM1olL71`7oclo?`Oo:RXZ1ooLg=`6oc8b<PGo
oooo1ooWinL7o`l?3`Oo7QhN1olI6AT7oc0`<0Oo30`<1olI6AT6o`h>3PKooooo1_l;2`/7oaDE5@Oo
<C4a1onm_Kd7ofATI0Oo>3Ph1olP8206odY:BPKooooo1omeMGD7oeMGE`Ko4Q8B1omZJVX7oe5AD@Oo
4Q8B1om:BTX6oa4A4@Kooooo1olS8b<7oaLG5`Oo51@D1olF5QH6ob4Q8@Oo8b<S1ol?3`l6on?Sh`Ko
oooo1ol_;bl7ob0P80Oof=SH1ol92@T7oemOG`Oo6a/K1_l];Bd6oaXJ6PKooooo1omeMGD7ob8R8POo
K6a/1onn_[h7oj^[Z`OoCDe=1old=3@;ooooo`Ooj>SX1olQ8B47oe5AD@Oo:RXZ1olG5aL7odQ8B0Oo
UiNG1_l<30`=ooooo`002oooool7oaHF5POo4Q8B1olM7Ad7oa`L70Oo?clo1olZ:RX7omcLg0Ko<S8b
1Oooool7onOWi`Oo3`l?1olN7Qh7oaTI6@Oo<30`1ol<30`7oaTI6@Ko3Ph>1_ooool6o`/;2`Oo5ADE
1ola<C47okfm_@OoI6AT1olh>3P7ob0P80KoBTY:1_ooool7ogEeM@OoEeMG1_lB4Q87ofYZJPOoDE5A
1olB4Q87odY:BPKo4A4A1_ooool7ob<S8`Oo5aLG1olD51@7oaHF5PKo8B4Q1olS8b<7o`l?3`Kohn?S
1_ooool7obl_;`Oo820P1ooHf=P7o`T92@OoGemO1olK6a/6obd];@Ko6QXJ1_ooool7ogEeM@Oo8R8R
1om/K6`7okjn_POoZj^[1om=CDd7oc@d=0_ooooo1ooXj>P7ob4Q8@OoDE5A1olZ:RX7oaLG5`OoB4Q8
1onGUiL6o``<30gooooo000;ooooo`Oo5QHF1olB4Q87oadM7@Oo71`L1olo?cl7obXZ:POog=cL1_lb
<S85ooooo`OoinOW1ol?3`l7oahN7POo6ATI1ol`<307o``<30Oo6ATI1_l>3Ph6ooooo`Ko2`/;1olE
5AD7oc4a<@Oo_Kfm1omTI6@7ocPh>0Oo820P1_m:BTX6ooooo`OoMGEe1omGEeL6oa8B4POoJVYZ1omA
DE47oa8B4POoBTY:1_lA4A46ooooo`Oo8b<S1olG5aL7oa@D50Oo5QHF1_lQ8B47ob<S8`Oo3`l?1_oS
hn<6ooooo`Oo;bl_1olP8207omSHf0Oo2@T91omOGel7oa/K6`Ko;Bd]1_lJ6QX6ooooo`OoMGEe1olR
8R87ofa/K0Oo_[jn1on[Zj/7ode=C@Oo=3@d2oooool7onSXj0Oo8B4Q1omADE47obXZ:POo5aLG1om8
B4P7oiNGU`Ko30`<3Oooool000_ooooo1olF5QH7oa8B4POo7AdM1olL71`7oclo?`Oo:RXZ1ooLg=`6
oc8b<PGooooo1ooWinL7o`l?3`Oo7QhN1olI6AT7oc0`<0Oo30`<1olI6AT6o`h>3PKooooo1_l;2`/7
oaDE5@Oo<C4a1onm_Kd7ofATI0Oo>3Ph1olP8206odY:BPKooooo1omeMGD7oeMGE`Ko4Q8B1omZJVX7
oe5AD@Oo4Q8B1om:BTX6oa4A4@Kooooo1olS8b<7oaLG5`Oo51@D1olF5QH6ob4Q8@Oo8b<S1ol?3`l6
on?Sh`Kooooo1ol_;bl7ob0P80Oof=SH1ol92@T7oemOG`Oo6a/K1_l];Bd6oaXJ6PKooooo1omeMGD7
ob8R8POoK6a/1onn_[h7oj^[Z`OoCDe=1old=3@;ooooo`Ooj>SX1olQ8B47oe5AD@Oo:RXZ1olG5aL7
odQ8B0OoUiNG1_l<30`=ooooo`002oooool7oaHF5POo4Q8B1olM7Ad7oa`L70Oo?clo1olZ:RX7omcL
g0Ko<S8b1Oooool7onOWi`Oo3`l?1olN7Qh7oaTI6@Oo<30`1ol<30`7oaTI6@Ko3Ph>1_ooool6o`/;
2`Oo5ADE1ola<C47okfm_@OoI6AT1olh>3P7ob0P80KoBTY:1_ooool7ogEeM@OoEeMG1_lB4Q87ofYZ
JPOoDE5A1olB4Q87odY:BPKo4A4A1_ooool7ob<S8`Oo5aLG1olD51@7oaHF5PKo8B4Q1olS8b<7o`l?
3`Kohn?S1_ooool7obl_;`Oo820P1ooHf=P7o`T92@OoGemO1olK6a/6obd];@Ko6QXJ1_ooool7ogEe
M@Oo8R8R1om/K6`7okjn_POoZj^[1om=CDd7oc@d=0_ooooo1ooXj>P7ob4Q8@OoDE5A1olZ:RX7oaLG
5`OoB4Q81onGUiL6o``<30gooooo000;ooooo`Oo5ADE1ol@4107o`l?3`Oo4Q8B1om2@T87ob4Q8@Oo
jn_[1_l[:b/5ooooo`Oom?Cd1olC4a<7ob4Q8@Oo5ADE1ol[:b/7oa/K6`Oo4Q8B1_l410@6ooooo`Ko
1`L71olA4A47oc4a<@OoalO71om]KFd7oc<c<`Oo;Bd]1_m2@T86ooooo`Ooc<c<1ol^;Rh6o`820POo
WYjN1omDE5@7o`0000Oo][Jf1_lZ:RX6ooooo`Oo61PH1olA4A47o`l?3`Oo30`<1_lE5AD7ob0P80Oo
51@D1_n5QHD6ooooo`Oo=CDe1olI6AT7on7Qh@Oo20P81om[Jf/7oa<C4`Ko7AdM1_l<30`6ooooo`Oo
;Rh^1olA4A47oe1@D0Ood=3@1ond];@7ol;2`POo;Rh^1_n6QXH5ooooo`Ook^k^1olT92@7oeeMG@Oo
8R8R1ol@4107oeMGE`OoW9bL1_l;2`/=ooooo`002oooool7oaDE5@Oo410@1ol?3`l7oa8B4POo@T92
1olQ8B47on_[j`Ko:b/[1Oooool7ooCdm0Oo4a<C1olQ8B47oaDE5@Oo:b/[1olK6a/7oa8B4PKo10@4
1_ooool6o`L71`Oo4A4A1ola<C47olO7a`OoKFe]1olc<c<7obd];@Ko@T921_ooool7olc<c0Oo;Rh^
1_l20P87oijNWPOoE5AD1ol00007okJf]PKo:RXZ1_ooool7oaPH60Oo4A4A1ol?3`l7o``<30Ko5ADE
1olP8207oa@D50KoQHF51_ooool7ocDe=@Oo6ATI1ooQhN47o`P820OoJf][1olC4a<6oadM7@Ko30`<
1_ooool7obh^;POo4A4A1om@D507om3@d0Oo];Bd1oo2`/87obh^;PKoQXJ61Oooool7onk^kPOo92@T
1omMGEd7ob8R8POo410@1omGEeL7oibLW0Ko2`/;3Oooool000_ooooo1olE5AD7oa0@40Oo3`l?1olB
4Q87od92@POo8B4Q1oo[jn/6ob/[:`Gooooo1oodm?@7oa<C4`Oo8B4Q1olE5AD7ob/[:`Oo6a/K1olB
4Q86o`@410Kooooo1_l71`L7oa4A4@Oo<C4a1oo7alL7ofe]K@Oo<c<c1ol];Bd6od92@PKooooo1oo<
c<`7obh^;PKo0P821onNWYh7oeADE0Oo00001onf][H6obXZ:PKooooo1olH61P7oa4A4@Oo3`l?1ol<
30`6oaDE5@Oo820P1olD51@6ohF5Q@Kooooo1ole=CD7oaTI6@OohN7Q1ol820P7of][J`Oo4a<C1_lM
7Ad6o``<30Kooooo1ol^;Rh7oa4A4@OoD51@1oo@d=07okBd]0Oo`/;21ol^;Rh6ohJ6QPGooooo1oo^
k^h7ob@T90OoGEeM1olR8R87oa0@40OoEeMG1onLW9`6o`/;2`gooooo000;ooooo`Oo5ADE1ol@4107
o`l?3`Oo4Q8B1om2@T87ob4Q8@Oojn_[1_l[:b/5ooooo`Oom?Cd1olC4a<7ob4Q8@Oo5ADE1ol[:b/7
oa/K6`Oo4Q8B1_l410@6ooooo`Ko1`L71olA4A47oc4a<@OoalO71om]KFd7oc<c<`Oo;Bd]1_m2@T86
ooooo`Ooc<c<1ol^;Rh6o`820POoWYjN1omDE5@7o`0000Oo][Jf1_lZ:RX6ooooo`Oo61PH1olA4A47
o`l?3`Oo30`<1_lE5AD7ob0P80Oo51@D1_n5QHD6ooooo`Oo=CDe1olI6AT7on7Qh@Oo20P81om[Jf/7
oa<C4`Ko7AdM1_l<30`6ooooo`Oo;Rh^1olA4A47oe1@D0Ood=3@1ond];@7ol;2`POo;Rh^1_n6QXH5
ooooo`Ook^k^1olT92@7oeeMG@Oo8R8R1ol@4107oeMGE`OoW9bL1_l;2`/=ooooo`002oooool7oaDE
5@Oo410@1ol?3`l7oa8B4POo@T921olQ8B47on_[j`Ko:b/[1Oooool7ooCdm0Oo4a<C1olQ8B47oaDE
5@Oo:b/[1olK6a/7oa8B4PKo10@41_ooool6o`L71`Oo4A4A1ola<C47olO7a`OoKFe]1olc<c<7obd]
;@Ko@T921_ooool7olc<c0Oo;Rh^1_l20P87oijNWPOoE5AD1ol00007okJf]PKo:RXZ1_ooool7oaPH
60Oo4A4A1ol?3`l7o``<30Ko5ADE1olP8207oa@D50KoQHF51_ooool7ocDe=@Oo6ATI1ooQhN47o`P8
20OoJf][1olC4a<6oadM7@Ko30`<1_ooool7obh^;POo4A4A1om@D507om3@d0Oo];Bd1oo2`/87obh^
;PKoQXJ61Oooool7onk^kPOo92@T1omMGEd7ob8R8POo410@1omGEeL7oibLW0Ko2`/;3Oooool000_o
oooo1olE5AD7oa0@40Oo3`l?1olB4Q87od92@POo8B4Q1oo[jn/6ob/[:`Gooooo1oodm?@7oa<C4`Oo
8B4Q1olE5AD7ob/[:`Oo6a/K1olB4Q86o`@410Kooooo1_l71`L7oa4A4@Oo<C4a1oo7alL7ofe]K@Oo
<c<c1ol];Bd6od92@PKooooo1oo<c<`7obh^;PKo0P821onNWYh7oeADE0Oo00001onf][H6obXZ:PKo
oooo1olH61P7oa4A4@Oo3`l?1ol<30`6oaDE5@Oo820P1olD51@6ohF5Q@Kooooo1ole=CD7oaTI6@Oo
hN7Q1ol820P7of][J`Oo4a<C1_lM7Ad6o``<30Kooooo1ol^;Rh7oa4A4@OoD51@1oo@d=07okBd]0Oo
`/;21ol^;Rh6ohJ6QPGooooo1oo^k^h7ob@T90OoGEeM1olR8R87oa0@40OoEeMG1onLW9`6o`/;2`go
oooo000;ooooo`Oo5ADE1ol@4107o`l?3`Oo4Q8B1om2@T87ob4Q8@Oojn_[1_l[:b/5ooooo`Oom?Cd
1olC4a<7ob4Q8@Oo5ADE1ol[:b/7oa/K6`Oo4Q8B1_l410@6ooooo`Ko1`L71olA4A47oc4a<@OoalO7
1om]KFd7oc<c<`Oo;Bd]1_m2@T86ooooo`Ooc<c<1ol^;Rh6o`820POoWYjN1omDE5@7o`0000Oo][Jf
1_lZ:RX6ooooo`Oo61PH1olA4A47o`l?3`Oo30`<1_lE5AD7ob0P80Oo51@D1_n5QHD6ooooo`Oo=CDe
1olI6AT7on7Qh@Oo20P81om[Jf/7oa<C4`Ko7AdM1_l<30`6ooooo`Oo;Rh^1olA4A47oe1@D0Ood=3@
1ond];@7ol;2`POo;Rh^1_n6QXH5ooooo`Ook^k^1olT92@7oeeMG@Oo8R8R1ol@4107oeMGE`OoW9bL
1_l;2`/=ooooo`002oooool7o``<30Oo0P821ol?3`l7o``<30Oo>SXj1ol`<307ooooo`Ko92@T3?oo
ool7o`H61POo71`L1olK6a/7ob0P80Oo3Ph>1ol61PH6o`<30`Kooooo1_l20P87o`D51@Oo:b/[1oo_
knl7ogMgM`Oo:2PX1olO7al6oe5AD@Kooooo1om[Jf/7ocLg=`Ko3Ph>1omaLG47ocTi>@Oo00001on4
Q8@6o`h>3PKooooo1ol>3Ph7oahN7POo2PX:1olE5AD=oaTI6@Oo30`<1_ll?3`6ooooo`Oo=CDe1olK
6a/7ooCdm0Oo00001omFEUH7obDU9@Ko9RHV1_lC4a<6ooooo`OoBDU91omADE47oiJFUPOoWYjN1onZ
ZZX7oclo?`Oo410@1_oKfm/<ooooo`Oo2PX:1omSHf<7obXZ:POo9BDU1omQHF47oi:BTPKo4a<C3Ooo
ool000_ooooo1ol<30`7o`820POo3`l?1ol<30`7ocXj>POo<30`1oooool6ob@T90cooooo1ol61PH7
oa`L70Oo6a/K1olP8207o`h>3POo1PH61_l30`<6ooooo`Ko0P821ol51@D7ob/[:`Ookno_1omgMgL7
obPX:0Oo7alO1_mADE46ooooo`OoJf][1olg=cL6o`h>3POoLG5a1oli>CT7o`0000OoQ8B41_l>3Ph6
ooooo`Oo3Ph>1olN7Qh7o`X:2POo5ADE3OlI6AT7o``<30Ko?3`l1_ooool7ocDe=@Oo6a/K1oodm?@7
o`0000OoEUIF1olU9BD6obHV9PKo4a<C1_ooool7odU9B@OoDE5A1onFUYH7oijNWPOoZZZZ1olo?cl7
oa0@40Kofm_K3?ooool7o`X:2POoHf=S1olZ:RX7obDU9@OoHF5Q1onBTY86oa<C4`gooooo000;oooo
o`Oo30`<1ol20P87o`l?3`Oo30`<1olj>SX7oc0`<0Oooooo1_lT92@<ooooo`Oo1PH61olL71`7oa/K
6`Oo820P1ol>3Ph7o`H61PKo0`<31_ooool6o`820POo1@D51ol[:b/7ono_k`OoMgMg1olX:2P7oalO
7`KoDE5A1_ooool7of][J`Oo=cLg1_l>3Ph7og5aL@Oo>CTi1ol00007ohB4Q0Ko3Ph>1_ooool7o`h>
3POo7QhN1ol:2PX7oaDE5@go6ATI1ol<30`6oc`l?0Kooooo1ole=CD7oa/K6`Oom?Cd1ol00007oeIF
EPOo9BDU1_lV9RH6oa<C4`Kooooo1om9BDT7oe5AD@OoUYJF1onNWYh7ojZZZPOo?clo1ol@4106om_K
f`cooooo1ol:2PX7of=SH`Oo:RXZ1olU9BD7of5QH@OoTY:B1_lC4a<=ooooo`002oooool7o``<30Oo
0P821ol?3`l7o``<30Oo>SXj1ol`<307ooooo`Ko92@T3?ooool7o`H61POo71`L1olK6a/7ob0P80Oo
3Ph>1ol61PH6o`<30`Kooooo1_l20P87o`D51@Oo:b/[1oo_knl7ogMgM`Oo:2PX1olO7al6oe5AD@Ko
oooo1om[Jf/7ocLg=`Ko3Ph>1omaLG47ocTi>@Oo00001on4Q8@6o`h>3PKooooo1ol>3Ph7oahN7POo
2PX:1olE5AD=oaTI6@Oo30`<1_ll?3`6ooooo`Oo=CDe1olK6a/7ooCdm0Oo00001omFEUH7obDU9@Ko
9RHV1_lC4a<6ooooo`OoBDU91omADE47oiJFUPOoWYjN1onZZZX7oclo?`Oo410@1_oKfm/<ooooo`Oo
2PX:1omSHf<7obXZ:POo9BDU1omQHF47oi:BTPKo4a<C3Oooool000_ooooo1ol<30`7o`820POo3`l?
1ol<30`7ocXj>POo<30`1oooool6ob@T90cooooo1ol61PH7oa`L70Oo6a/K1olP8207o`h>3POo1PH6
1_l30`<6ooooo`Ko0P821ol51@D7ob/[:`Ookno_1omgMgL7obPX:0Oo7alO1_mADE46ooooo`OoJf][
1olg=cL6o`h>3POoLG5a1oli>CT7o`0000OoQ8B41_l>3Ph6ooooo`Oo3Ph>1olN7Qh7o`X:2POo5ADE
3OlI6AT7o``<30Ko?3`l1_ooool7ocDe=@Oo6a/K1oodm?@7o`0000OoEUIF1olU9BD6obHV9PKo4a<C
1_ooool7odU9B@OoDE5A1onFUYH7oijNWPOoZZZZ1olo?cl7oa0@40Kofm_K3?ooool7o`X:2POoHf=S
1olZ:RX7obDU9@OoHF5Q1onBTY86oa<C4`gooooo000;ooooo`Oo30`<1ol20P87o`l?3`Oo30`<1olj
>SX7oc0`<0Oooooo1_lT92@<ooooo`Oo1PH61olL71`7oa/K6`Oo820P1ol>3Ph7o`H61PKo0`<31_oo
ool6o`820POo1@D51ol[:b/7ono_k`OoMgMg1olX:2P7oalO7`KoDE5A1_ooool7of][J`Oo=cLg1_l>
3Ph7og5aL@Oo>CTi1ol00007ohB4Q0Ko3Ph>1_ooool7o`h>3POo7QhN1ol:2PX7oaDE5@go6ATI1ol<
30`6oc`l?0Kooooo1ole=CD7oa/K6`Oom?Cd1ol00007oeIFEPOo9BDU1_lV9RH6oa<C4`Kooooo1om9
BDT7oe5AD@OoUYJF1onNWYh7ojZZZPOo?clo1ol@4106om_Kf`cooooo1ol:2PX7of=SH`Oo:RXZ1olU
9BD7of5QH@OoTY:B1_lC4a<=ooooo`002oooool7o``<30Oo0P821ol?3`l7o``<30Oo>SXj1ol`<307
ooooo`Ko92@T3?ooool7o`H61POo71`L1olK6a/7ob0P80Oo3Ph>1ol61PH6o`<30`Kooooo1_l20P87
o`D51@Oo:b/[1oo_knl7ogMgM`Oo:2PX1olO7al6oe5AD@Kooooo1om[Jf/7ocLg=`Ko3Ph>1omaLG47
ocTi>@Oo00001on4Q8@6o`h>3PKooooo1ol>3Ph7oahN7POo2PX:1olE5AD=oaTI6@Oo30`<1_ll?3`6
ooooo`Oo=CDe1olK6a/7ooCdm0Oo00001omFEUH7obDU9@Ko9RHV1_lC4a<6ooooo`OoBDU91omADE47
oiJFUPOoWYjN1onZZZX7oclo?`Oo410@1_oKfm/<ooooo`Oo2PX:1omSHf<7obXZ:POo9BDU1omQHF47
oi:BTPKo4a<C3Oooool000_ooooo1ol71`L7o`D51@Oo0`<31ol20P87ocLg=`Oo;Bd]1ooclo<6obd]
;@Gooooo1ookno/7o`D51@Oo5QHF1olD51@7ob<S8`Oo820P1olC4a<6o`L71`Kooooo1_l10@47oa8B
4POo;Bd]1ooTi>@7ogIfMPOo:RXZ1olQ8B46ocDe=@Kooooo1onPX:07oaHF5PKo4A4A1onUYJD7oaTI
6@Oo2@T91oo_knl6od92@PKooooo1olE5AD7oaHF5POo6QXJ1olE5AD6obTY:@Oo4A4A1ol:2PX6oc4a
<@Kooooo1olg=cL7oa0@40OonOWi1ol61PH7ofATI0Oo9RHV1_lW9bL6o`h>3PKooooo1olf=SH7oahN
7POoShn?1oooool7ojf][@OoPh>31olf=SH6ohJ6QPGooooo1ooinOT7o`d=3@OoJFUY1olQ8B47obDU
9@OoNGUi1onQXJ46oaLG5`gooooo000;ooooo`Oo1`L71ol51@D7o`<30`Oo0P821olg=cL7obd];@Oo
lo?c1_l];Bd5ooooo`Oono_k1ol51@D7oaHF5POo51@D1olS8b<7ob0P80Oo4a<C1_l71`L6ooooo`Ko
0@411olB4Q87obd];@Ooi>CT1omfMWH7obXZ:POo8B4Q1_le=CD6ooooo`OoX:2P1olF5QH6oa4A4@Oo
YJFU1olI6AT7o`T92@Ookno_1_m2@T86ooooo`Oo5ADE1olF5QH7oaXJ6POo5ADE1_lY:BT7oa4A4@Oo
2PX:1_la<C46ooooo`Oo=cLg1ol@4107ooWin@Oo1PH61omTI6@7obHV9PKo9bLW1_l>3Ph6ooooo`Oo
=SHf1olN7Qh7ohn?S`Oooooo1on][Jd7oh>3P`Oo=SHf1_n6QXH5ooooo`OonOWi1ol=3@d7ofUYJ@Oo
8B4Q1olU9BD7ogUiN@OoXJ6Q1_lG5aL=ooooo`002oooool7o`L71`Oo1@D51ol30`<7o`820POo=cLg
1ol];Bd7oo?cl`Ko;Bd]1Oooool7oo_kn`Oo1@D51olF5QH7oa@D50Oo8b<S1olP8207oa<C4`Ko1`L7
1_ooool6o`410@Oo4Q8B1ol];Bd7onCTi0OoMWIf1olZ:RX7ob4Q8@Ko=CDe1_ooool7oj2PX0Oo5QHF
1_lA4A47ojFUY@Oo6ATI1ol92@T7ono_k`Ko@T921_ooool7oaDE5@Oo5QHF1olJ6QX7oaDE5@Ko:BTY
1olA4A47o`X:2PKo<C4a1_ooool7ocLg=`Oo410@1ooinOT7o`H61POoI6AT1olV9RH6obLW9`Ko3Ph>
1_ooool7ocHf=POo7QhN1on?Shl7ooooo`Oo[Jf]1on3Ph<7ocHf=PKoQXJ61Oooool7ooWin@Oo3@d=
1omYJFT7ob4Q8@Oo9BDU1omiNGT7oj6QX@Ko5aLG3Oooool000_ooooo1ol71`L7o`D51@Oo0`<31ol2
0P87ocLg=`Oo;Bd]1ooclo<6obd];@Gooooo1ookno/7o`D51@Oo5QHF1olD51@7ob<S8`Oo820P1olC
4a<6o`L71`Kooooo1_l10@47oa8B4POo;Bd]1ooTi>@7ogIfMPOo:RXZ1olQ8B46ocDe=@Kooooo1onP
X:07oaHF5PKo4A4A1onUYJD7oaTI6@Oo2@T91oo_knl6od92@PKooooo1olE5AD7oaHF5POo6QXJ1olE
5AD6obTY:@Oo4A4A1ol:2PX6oc4a<@Kooooo1olg=cL7oa0@40OonOWi1ol61PH7ofATI0Oo9RHV1_lW
9bL6o`h>3PKooooo1olf=SH7oahN7POoShn?1oooool7ojf][@OoPh>31olf=SH6ohJ6QPGooooo1ooi
nOT7o`d=3@OoJFUY1olQ8B47obDU9@OoNGUi1onQXJ46oaLG5`gooooo000;ooooo`Oo1`L71ol51@D7
o`<30`Oo0P821olg=cL7obd];@Oolo?c1_l];Bd5ooooo`Oono_k1ol51@D7oaHF5POo51@D1olS8b<7
ob0P80Oo4a<C1_l71`L6ooooo`Ko0@411olB4Q87obd];@Ooi>CT1omfMWH7obXZ:POo8B4Q1_le=CD6
ooooo`OoX:2P1olF5QH6oa4A4@OoYJFU1olI6AT7o`T92@Ookno_1_m2@T86ooooo`Oo5ADE1olF5QH7
oaXJ6POo5ADE1_lY:BT7oa4A4@Oo2PX:1_la<C46ooooo`Oo=cLg1ol@4107ooWin@Oo1PH61omTI6@7
obHV9PKo9bLW1_l>3Ph6ooooo`Oo=SHf1olN7Qh7ohn?S`Oooooo1on][Jd7oh>3P`Oo=SHf1_n6QXH5
ooooo`OonOWi1ol=3@d7ofUYJ@Oo8B4Q1olU9BD7ogUiN@OoXJ6Q1_lG5aL=ooooo`002oooool7o`L7
1`Oo1@D51ol30`<7o`820POo=cLg1ol];Bd7oo?cl`Ko;Bd]1Oooool7oo_kn`Oo1@D51olF5QH7oa@D
50Oo8b<S1olP8207oa<C4`Ko1`L71_ooool6o`410@Oo4Q8B1ol];Bd7onCTi0OoMWIf1olZ:RX7ob4Q
8@Ko=CDe1_ooool7oj2PX0Oo5QHF1_lA4A47ojFUY@Oo6ATI1ol92@T7ono_k`Ko@T921_ooool7oaDE
5@Oo5QHF1olJ6QX7oaDE5@Ko:BTY1olA4A47o`X:2PKo<C4a1_ooool7ocLg=`Oo410@1ooinOT7o`H6
1POoI6AT1olV9RH6obLW9`Ko3Ph>1_ooool7ocHf=POo7QhN1on?Shl7ooooo`Oo[Jf]1on3Ph<7ocHf
=PKoQXJ61Oooool7ooWin@Oo3@d=1omYJFT7ob4Q8@Oo9BDU1omiNGT7oj6QX@Ko5aLG3Oooool000_o
oooo1ol>3Ph7o`0000Oo51@D1olN7Qh7od51@@Oo:b/[1ookno/6oaXJ6PGooooo1ooRh^87o`0000Oo
3Ph>3_lR8R87oaXJ6POo2@T91_l410@6ooooo`Ko00001ol61PH7od51@@Oooooo1on0P807obDU9@Oo
7alO1_lf=SH6ooooo`OoFEUI1olU9BD6oaTI6@OoMGEe1olN7Qh7o`L71`OoalO71_li>CT6ooooo`Oo
00001ol?3`l7oa0@40Oo5ADE1_lP8207oa@D50Oo1`L71_lj>SX6ooooo`Oo;Rh^1olH61P7ooooo`Oo
20P81omHF5P7oc4a<@Ko>SXj1_l71`L6ooooo`Oo;bl_1onGUiL7ojZZZPOoS8b<1on8R8P7obl_;`Oo
1@D51_n/[:`5ooooo`OoinOW1ol820P7ofATI0Oo92@T1oln?Sh7ogalO0OoP8201_lU9BD=ooooo`00
2oooool7o`h>3POo00001olD51@7oahN7POo@D511ol[:b/7oo_kn`Ko6QXJ1Oooool7on;RhPOo0000
1ol>3Ph>ob8R8POo6QXJ1ol92@T6o`@410Kooooo1_l00007o`H61POo@D511oooool7oh20P0Oo9BDU
1olO7al6ocHf=PKooooo1omIFET7obDU9@Ko6ATI1omeMGD7oahN7POo1`L71oo7alL6ocTi>@Kooooo
1ol00007o`l?3`Oo410@1olE5AD6ob0P80Oo51@D1ol71`L6ocXj>PKooooo1ol^;Rh7oaPH60Oooooo
1ol820P7oeQHF0Oo<C4a1_lj>SX6o`L71`Kooooo1ol_;bl7oiNGU`OoZZZZ1on<S8`7ohR8R0Oo;bl_
1ol51@D6ojb/[0Gooooo1ooWinL7o`P820OoI6AT1olT92@7ochn?POoO7al1on0P806obDU9@gooooo
000;ooooo`Oo3Ph>1ol00007oa@D50Oo7QhN1om1@D47ob/[:`Oono_k1_lJ6QX5ooooo`Ooh^;R1ol0
0007o`h>3Pko8R8R1olJ6QX7o`T92@Ko10@41_ooool6o`0000Oo1PH61om1@D47ooooo`OoP8201olU
9BD7oalO7`Ko=SHf1_ooool7oeUIF@Oo9BDU1_lI6AT7ogEeM@Oo7QhN1ol71`L7olO7a`Ko>CTi1_oo
ool7o`0000Oo3`l?1ol@4107oaDE5@Ko820P1olD51@7o`L71`Ko>SXj1_ooool7obh^;POo61PH1ooo
ool7o`P820OoF5QH1ola<C46ocXj>PKo1`L71_ooool7obl_;`OoUiNG1onZZZX7ohb<S0OoR8R81ol_
;bl7o`D51@Ko[:b/1Oooool7onOWi`Oo20P81omTI6@7ob@T90Oo?Shn1omlO7`7oh20P0Ko9BDU3Ooo
ool000_ooooo1ol>3Ph7o`0000Oo51@D1olN7Qh7od51@@Oo:b/[1ookno/6oaXJ6PGooooo1ooRh^87
o`0000Oo3Ph>3_lR8R87oaXJ6POo2@T91_l410@6ooooo`Ko00001ol61PH7od51@@Oooooo1on0P807
obDU9@Oo7alO1_lf=SH6ooooo`OoFEUI1olU9BD6oaTI6@OoMGEe1olN7Qh7o`L71`OoalO71_li>CT6
ooooo`Oo00001ol?3`l7oa0@40Oo5ADE1_lP8207oa@D50Oo1`L71_lj>SX6ooooo`Oo;Rh^1olH61P7
ooooo`Oo20P81omHF5P7oc4a<@Ko>SXj1_l71`L6ooooo`Oo;bl_1onGUiL7ojZZZPOoS8b<1on8R8P7
obl_;`Oo1@D51_n/[:`5ooooo`OoinOW1ol820P7ofATI0Oo92@T1oln?Sh7ogalO0OoP8201_lU9BD=
ooooo`002oooool7o`h>3POo00001olD51@7oahN7POo@D511ol[:b/7oo_kn`Ko6QXJ1Oooool7on;R
hPOo00001ol>3Ph>ob8R8POo6QXJ1ol92@T6o`@410Kooooo1_l00007o`H61POo@D511oooool7oh20
P0Oo9BDU1olO7al6ocHf=PKooooo1omIFET7obDU9@Ko6ATI1omeMGD7oahN7POo1`L71oo7alL6ocTi
>@Kooooo1ol00007o`l?3`Oo410@1olE5AD6ob0P80Oo51@D1ol71`L6ocXj>PKooooo1ol^;Rh7oaPH
60Oooooo1ol820P7oeQHF0Oo<C4a1_lj>SX6o`L71`Kooooo1ol_;bl7oiNGU`OoZZZZ1on<S8`7ohR8
R0Oo;bl_1ol51@D6ojb/[0Gooooo1ooWinL7o`P820OoI6AT1olT92@7ochn?POoO7al1on0P806obDU
9@gooooo000;ooooo`Oo3Ph>1ol00007oa@D50Oo7QhN1om1@D47ob/[:`Oono_k1_lJ6QX5ooooo`Oo
h^;R1ol00007o`h>3Pko8R8R1olJ6QX7o`T92@Ko10@41_ooool6o`0000Oo1PH61om1@D47ooooo`Oo
P8201olU9BD7oalO7`Ko=SHf1_ooool7oeUIF@Oo9BDU1_lI6AT7ogEeM@Oo7QhN1ol71`L7olO7a`Ko
>CTi1_ooool7o`0000Oo3`l?1ol@4107oaDE5@Ko820P1olD51@7o`L71`Ko>SXj1_ooool7obh^;POo
61PH1oooool7o`P820OoF5QH1ola<C46ocXj>PKo1`L71_ooool7obl_;`OoUiNG1onZZZX7ohb<S0Oo
R8R81ol_;bl7o`D51@Ko[:b/1Oooool7onOWi`Oo20P81omTI6@7ob@T90Oo?Shn1omlO7`7oh20P0Ko
9BDU3Oooool000_ooooo1ol>3Ph7o`0000Oo51@D1olN7Qh7od51@@Oo:b/[1ookno/6oaXJ6PGooooo
1ooRh^87o`0000Oo3Ph>3_lR8R87oaXJ6POo2@T91_l410@6ooooo`Ko00001ol61PH7od51@@Oooooo
1on0P807obDU9@Oo7alO1_lf=SH6ooooo`OoFEUI1olU9BD6oaTI6@OoMGEe1olN7Qh7o`L71`OoalO7
1_li>CT6ooooo`Oo00001ol?3`l7oa0@40Oo5ADE1_lP8207oa@D50Oo1`L71_lj>SX6ooooo`Oo;Rh^
1olH61P7ooooo`Oo20P81omHF5P7oc4a<@Ko>SXj1_l71`L6ooooo`Oo;bl_1onGUiL7ojZZZPOoS8b<
1on8R8P7obl_;`Oo1@D51_n/[:`5ooooo`OoinOW1ol820P7ofATI0Oo92@T1oln?Sh7ogalO0OoP820
1_lU9BD=ooooo`002oooool7oa0@40Oo2`/;1olF5QH7oaDE5@OoADE51ola<C47on[ZjPKo;Bd]1Ooo
ool7olW9b@Oo1PH61olB4Q87oa`L70Oo7AdM1olU9BD7oa8B4PKo410@1_ooool6o`h>3POo71`L1oll
?3`7oo?cl`OoRHV91ola<C47ob<S8`Ko>SXj1_ooool7ofQXJ0Oo6a/K1_lk>c/7oh^;R`Oo00001ol`
<307ooooo`KoHF5Q1_ooool7o`820POo4a<C1olI6AT7oaPH60Ko8R8R1olA4A47o`h>3PKo?Shn1_oo
ool7oc`l?0Oo7AdM1oolo?`7o`L71`OoE5AD1olk>c/6obh^;PKo5aLG1_ooool7od=3@`Oo=cLg1on]
[Jd7oogmo@OoWIfM1om:BTX7of1PH0KoQXJ61Oooool7olG5a@Oo0P821omQHF47obDU9@Oo>SXj1on3
Ph<7ohf=S@Ko;Bd]3Oooool000_ooooo1ol@4107o`/;2`Oo5QHF1olE5AD7odE5A@Oo<C4a1ooZj^X6
obd];@Gooooo1oo9bLT7o`H61POo4Q8B1olL71`7oadM7@Oo9BDU1olB4Q86oa0@40Kooooo1_l>3Ph7
oa`L70Oo?3`l1ooclo<7ohV9R@Oo<C4a1olS8b<6ocXj>PKooooo1omXJ6P7oa/K6`Ko>c/k1on;Rh/7
o`0000Oo<30`1oooool6of5QH@Kooooo1ol20P87oa<C4`Oo6ATI1olH61P6ob8R8POo4A4A1ol>3Ph6
ochn?PKooooo1oll?3`7oadM7@Ooo?cl1ol71`L7oeADE0Oo>c/k1_l^;Rh6oaLG5`Kooooo1om3@d<7
ocLg=`Oo[Jf]1oomoOd7oifMW@OoBTY:1omPH606ohJ6QPGooooo1oo5aLD7o`820POoHF5Q1olU9BD7
ocXj>POoPh>31on=SHd6obd];@gooooo000;ooooo`Oo410@1ol;2`/7oaHF5POo5ADE1om5ADD7oc4a
<@Ooj^[Z1_l];Bd5ooooo`OobLW91ol61PH7oa8B4POo71`L1olM7Ad7obDU9@Oo4Q8B1_l@4106oooo
o`Ko3Ph>1olL71`7oc`l?0Oolo?c1on9RHT7oc4a<@Oo8b<S1_lj>SX6ooooo`OoJ6QX1olK6a/6oc/k
>`OoRh^;1ol00007oc0`<0Oooooo1_mQHF46ooooo`Oo0P821olC4a<7oaTI6@Oo61PH1_lR8R87oa4A
4@Oo3Ph>1_ln?Sh6ooooo`Oo?3`l1olM7Ad7ooclo0Oo1`L71omDE5@7oc/k>`Ko;Rh^1_lG5aL6oooo
o`Oo@d=31olg=cL7ojf][@OooOgm1onMWId7odY:BPOoH61P1_n6QXH5ooooo`OoaLG51ol20P87of5Q
H@Oo9BDU1olj>SX7oh>3P`OoSHf=1_l];Bd=ooooo`002oooool7oa0@40Oo2`/;1olF5QH7oaDE5@Oo
ADE51ola<C47on[ZjPKo;Bd]1Oooool7olW9b@Oo1PH61olB4Q87oa`L70Oo7AdM1olU9BD7oa8B4PKo
410@1_ooool6o`h>3POo71`L1oll?3`7oo?cl`OoRHV91ola<C47ob<S8`Ko>SXj1_ooool7ofQXJ0Oo
6a/K1_lk>c/7oh^;R`Oo00001ol`<307ooooo`KoHF5Q1_ooool7o`820POo4a<C1olI6AT7oaPH60Ko
8R8R1olA4A47o`h>3PKo?Shn1_ooool7oc`l?0Oo7AdM1oolo?`7o`L71`OoE5AD1olk>c/6obh^;PKo
5aLG1_ooool7od=3@`Oo=cLg1on][Jd7oogmo@OoWIfM1om:BTX7of1PH0KoQXJ61Oooool7olG5a@Oo
0P821omQHF47obDU9@Oo>SXj1on3Ph<7ohf=S@Ko;Bd]3Oooool000_ooooo1ol@4107o`/;2`Oo5QHF
1olE5AD7odE5A@Oo<C4a1ooZj^X6obd];@Gooooo1oo9bLT7o`H61POo4Q8B1olL71`7oadM7@Oo9BDU
1olB4Q86oa0@40Kooooo1_l>3Ph7oa`L70Oo?3`l1ooclo<7ohV9R@Oo<C4a1olS8b<6ocXj>PKooooo
1omXJ6P7oa/K6`Ko>c/k1on;Rh/7o`0000Oo<30`1oooool6of5QH@Kooooo1ol20P87oa<C4`Oo6ATI
1olH61P6ob8R8POo4A4A1ol>3Ph6ochn?PKooooo1oll?3`7oadM7@Ooo?cl1ol71`L7oeADE0Oo>c/k
1_l^;Rh6oaLG5`Kooooo1om3@d<7ocLg=`Oo[Jf]1oomoOd7oifMW@OoBTY:1omPH606ohJ6QPGooooo
1oo5aLD7o`820POoHF5Q1olU9BD7ocXj>POoPh>31on=SHd6obd];@gooooo000;ooooo`Oo410@1ol;
2`/7oaHF5POo5ADE1om5ADD7oc4a<@Ooj^[Z1_l];Bd5ooooo`OobLW91ol61PH7oa8B4POo71`L1olM
7Ad7obDU9@Oo4Q8B1_l@4106ooooo`Ko3Ph>1olL71`7oc`l?0Oolo?c1on9RHT7oc4a<@Oo8b<S1_lj
>SX6ooooo`OoJ6QX1olK6a/6oc/k>`OoRh^;1ol00007oc0`<0Oooooo1_mQHF46ooooo`Oo0P821olC
4a<7oaTI6@Oo61PH1_lR8R87oa4A4@Oo3Ph>1_ln?Sh6ooooo`Oo?3`l1olM7Ad7ooclo0Oo1`L71omD
E5@7oc/k>`Ko;Rh^1_lG5aL6ooooo`Oo@d=31olg=cL7ojf][@OooOgm1onMWId7odY:BPOoH61P1_n6
QXH5ooooo`OoaLG51ol20P87of5QH@Oo9BDU1olj>SX7oh>3P`OoSHf=1_l];Bd=ooooo`002oooool7
oa0@40Oo2`/;1olF5QH7oaDE5@OoADE51ola<C47on[ZjPKo;Bd]1Oooool7olW9b@Oo1PH61olB4Q87
oa`L70Oo7AdM1olU9BD7oa8B4PKo410@1_ooool6o`h>3POo71`L1oll?3`7oo?cl`OoRHV91ola<C47
ob<S8`Ko>SXj1_ooool7ofQXJ0Oo6a/K1_lk>c/7oh^;R`Oo00001ol`<307ooooo`KoHF5Q1_ooool7
o`820POo4a<C1olI6AT7oaPH60Ko8R8R1olA4A47o`h>3PKo?Shn1_ooool7oc`l?0Oo7AdM1oolo?`7
o`L71`OoE5AD1olk>c/6obh^;PKo5aLG1_ooool7od=3@`Oo=cLg1on][Jd7oogmo@OoWIfM1om:BTX7
of1PH0KoQXJ61Oooool7olG5a@Oo0P821omQHF47obDU9@Oo>SXj1on3Ph<7ohf=S@Ko;Bd]3Oooool0
00_ooooo1ol?3`l7o`d=3@Oo51@D1olM7Ad7odA4A0Oo<C4a1ooPh>06oc0`<0Gooooo1onf][H7o`L7
1`Oo4a<C1olQ8B47ob<S8`Oo6QXJ1ol=3@d6oaDE5@Kooooo1_l=3@d7ob4Q8@OoBd];1ooQhN47ogUi
N@Oo;Bd]1olL71`6oc`l?0Kooooo1olh>3P7oaDE5@Ko:2PX1olo?cl>o`D51@OoY:BT1_lg=cL6oooo
o`Oo0@411ol:2PX7oa4A4@Oo7QhN1_lR8R87o`/;2`Oo0`<31_li>CT6ooooo`Oo;bl_1ol[:b/7om_K
f`Oo2PX:1om6ATH7ocTi>@Ko=SHf1_lC4a<6ooooo`Oo:BTY1ooTi>@7ok^k^`OoMGEe1omSHf<7oclo
?`Oo00001_n1PH45ooooo`OoZZZZ1ol00007oeIFEPOo8R8R1olk>c/7ogIfMPOoN7Qh1_lh>3P=oooo
o`002oooool7o`l?3`Oo3@d=1olD51@7oadM7@OoA4A41ola<C47on3Ph0Ko<30`1Oooool7okJf]POo
1`L71olC4a<7ob4Q8@Oo8b<S1olJ6QX7o`d=3@Ko5ADE1_ooool6o`d=3@Oo8B4Q1om;Bd/7on7Qh@Oo
NGUi1ol];Bd7oa`L70Ko?3`l1_ooool7ocPh>0Oo5ADE1_lX:2P7oclo?`ko1@D51onTY:@6ocLg=`Ko
oooo1ol10@47o`X:2POo4A4A1olN7Qh6ob8R8POo2`/;1ol30`<6ocTi>@Kooooo1ol_;bl7ob/[:`Oo
fm_K1ol:2PX7odI6APOo>CTi1_lf=SH6oa<C4`Kooooo1olY:BT7onCTi0Oo^k^k1omeMGD7of=SH`Oo
?clo1ol00006oh61P@Gooooo1onZZZX7o`0000OoEUIF1olR8R87oc/k>`OoMWIf1omhN7P6ocPh>0go
oooo000;ooooo`Oo3`l?1ol=3@d7oa@D50Oo7AdM1om4A4@7oc4a<@Ooh>3P1_l`<305ooooo`Oo][Jf
1ol71`L7oa<C4`Oo8B4Q1olS8b<7oaXJ6POo3@d=1_lE5AD6ooooo`Ko3@d=1olQ8B47od];B`OohN7Q
1omiNGT7obd];@Oo71`L1_ll?3`6ooooo`Oo>3Ph1olE5AD6obPX:0Oo?clo3_l51@D7ojBTY0Ko=cLg
1_ooool7o`410@Oo2PX:1olA4A47oahN7PKo8R8R1ol;2`/7o`<30`Ko>CTi1_ooool7obl_;`Oo:b/[
1ooKfm/7o`X:2POoATI61oli>CT6ocHf=PKo4a<C1_ooool7obTY:@Ooi>CT1onk^k/7ogEeM@OoHf=S
1olo?cl7o`0000KoPH611Oooool7ojZZZPOo00001omFEUH7ob8R8POo>c/k1omfMWH7ogQhN0Ko>3Ph
3Oooool000_ooooo1ol?3`l7o`d=3@Oo51@D1olM7Ad7odA4A0Oo<C4a1ooPh>06oc0`<0Gooooo1onf
][H7o`L71`Oo4a<C1olQ8B47ob<S8`Oo6QXJ1ol=3@d6oaDE5@Kooooo1_l=3@d7ob4Q8@OoBd];1ooQ
hN47ogUiN@Oo;Bd]1olL71`6oc`l?0Kooooo1olh>3P7oaDE5@Ko:2PX1olo?cl>o`D51@OoY:BT1_lg
=cL6ooooo`Oo0@411ol:2PX7oa4A4@Oo7QhN1_lR8R87o`/;2`Oo0`<31_li>CT6ooooo`Oo;bl_1ol[
:b/7om_Kf`Oo2PX:1om6ATH7ocTi>@Ko=SHf1_lC4a<6ooooo`Oo:BTY1ooTi>@7ok^k^`OoMGEe1omS
Hf<7oclo?`Oo00001_n1PH45ooooo`OoZZZZ1ol00007oeIFEPOo8R8R1olk>c/7ogIfMPOoN7Qh1_lh
>3P=ooooo`002oooool7o`l?3`Oo3@d=1olD51@7oadM7@OoA4A41ola<C47on3Ph0Ko<30`1Oooool7
okJf]POo1`L71olC4a<7ob4Q8@Oo8b<S1olJ6QX7o`d=3@Ko5ADE1_ooool6o`d=3@Oo8B4Q1om;Bd/7
on7Qh@OoNGUi1ol];Bd7oa`L70Ko?3`l1_ooool7ocPh>0Oo5ADE1_lX:2P7oclo?`ko1@D51onTY:@6
ocLg=`Kooooo1ol10@47o`X:2POo4A4A1olN7Qh6ob8R8POo2`/;1ol30`<6ocTi>@Kooooo1ol_;bl7
ob/[:`Oofm_K1ol:2PX7odI6APOo>CTi1_lf=SH6oa<C4`Kooooo1olY:BT7onCTi0Oo^k^k1omeMGD7
of=SH`Oo?clo1ol00006oh61P@Gooooo1onZZZX7o`0000OoEUIF1olR8R87oc/k>`OoMWIf1omhN7P6
ocPh>0gooooo000;ooooo`Oo3`l?1ol=3@d7oa@D50Oo7AdM1om4A4@7oc4a<@Ooh>3P1_l`<305oooo
o`Oo][Jf1ol71`L7oa<C4`Oo8B4Q1olS8b<7oaXJ6POo3@d=1_lE5AD6ooooo`Ko3@d=1olQ8B47od];
B`OohN7Q1omiNGT7obd];@Oo71`L1_ll?3`6ooooo`Oo>3Ph1olE5AD6obPX:0Oo?clo3_l51@D7ojBT
Y0Ko=cLg1_ooool7o`410@Oo2PX:1olA4A47oahN7PKo8R8R1ol;2`/7o`<30`Ko>CTi1_ooool7obl_
;`Oo:b/[1ooKfm/7o`X:2POoATI61oli>CT6ocHf=PKo4a<C1_ooool7obTY:@Ooi>CT1onk^k/7ogEe
M@OoHf=S1olo?cl7o`0000KoPH611Oooool7ojZZZPOo00001omFEUH7ob8R8POo>c/k1omfMWH7ogQh
N0Ko>3Ph3Oooool000_ooooo1ol?3`l7o`d=3@Oo51@D1olM7Ad7odA4A0Oo<C4a1ooPh>06oc0`<0Go
oooo1onf][H7o`L71`Oo4a<C1olQ8B47ob<S8`Oo6QXJ1ol=3@d6oaDE5@Kooooo1_l=3@d7ob4Q8@Oo
Bd];1ooQhN47ogUiN@Oo;Bd]1olL71`6oc`l?0Kooooo1olh>3P7oaDE5@Ko:2PX1olo?cl>o`D51@Oo
Y:BT1_lg=cL6ooooo`Oo0@411ol:2PX7oa4A4@Oo7QhN1_lR8R87o`/;2`Oo0`<31_li>CT6ooooo`Oo
;bl_1ol[:b/7om_Kf`Oo2PX:1om6ATH7ocTi>@Ko=SHf1_lC4a<6ooooo`Oo:BTY1ooTi>@7ok^k^`Oo
MGEe1omSHf<7oclo?`Oo00001_n1PH45ooooo`OoZZZZ1ol00007oeIFEPOo8R8R1olk>c/7ogIfMPOo
N7Qh1_lh>3P=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`002oooool7obHV9POoBTY:1omJFUX7ojf][@OoV9RH1ooC
dm<7oo3`l0Koc/k>1Oooool7obHV9POoe]KF1om/K6`7oaXJ6POo7alO1olJ6QX7oaPH60KoBTY:1_oo
ool6ochn?POo92@T1oo1`L47oe9BDPOo4Q8B1olW9bL7oaDE5@Ko<S8b1_ooool7obDU9@Oo4A4A1_l^
;Rh7o`/;2`Oo9BDU1ooNg]h7oc8b<PKo8R8R1_ooool7o`h>3POo51@D1ol;2`/7o`h>3PKo7QhN1olV
9RH7od51@@KoOgmo1_ooool7oe9BDPOoO7al1on3Ph<7oj6QX@Oo3@d=1olN7Qh6obh^;PKoSXj>1_oo
ool7oadM7@Oo:b/[1om8B4P7ob`/;0Ooe=CD1om4A4@7o`d=3@Ko8b<S1Oooool7obd];@Oo][Jf1omK
Fe/7ob4Q8@OoZJVY1oooool7ocHf=PKo<S8b3Oooool000_ooooo1olV9RH7odY:BPOoFUYJ1on][Jd7
oiRHV0Oodm?C1oo`l?06olk>cPGooooo1olV9RH7omKFePOoK6a/1olJ6QX7oalO7`Oo6QXJ1olH61P6
odY:BPKooooo1_ln?Sh7ob@T90Oo`L711omBDU87oa8B4POo9bLW1olE5AD6oc8b<PKooooo1olU9BD7
oa4A4@Ko;Rh^1ol;2`/7obDU9@Oog]kN1olb<S86ob8R8PKooooo1ol>3Ph7oa@D50Oo2`/;1ol>3Ph6
oahN7POo9RHV1om1@D46ogmoO`Kooooo1omBDU87ogalO0OoPh>31onQXJ47o`d=3@Oo7QhN1_l^;Rh6
ohj>SPKooooo1olM7Ad7ob/[:`OoB4Q81ol/;2`7omCDe0OoA4A41ol=3@d6ob<S8`Gooooo1ol];Bd7
okJf]POoFe]K1olQ8B47ojVYZ@Oooooo1olf=SH6oc8b<Pgooooo000;ooooo`Oo9RHV1om:BTX7oeYJ
FPOo[Jf]1onHV9P7om?Cd`Ool?3`1_o>c/h5ooooo`Oo9RHV1ooFe]H7ofa/K0Oo6QXJ1olO7al7oaXJ
6POo61PH1_m:BTX6ooooo`Ko?Shn1olT92@7ol71`@OoDU9B1olB4Q87obLW9`Oo5ADE1_lb<S86oooo
o`Oo9BDU1olA4A46obh^;POo2`/;1olU9BD7omkNgPOo<S8b1_lR8R86ooooo`Oo3Ph>1olD51@7o`/;
2`Oo3Ph>1_lN7Qh7obHV9POo@D511_moOgl6ooooo`OoDU9B1omlO7`7oh>3P`OoXJ6Q1ol=3@d7oahN
7PKo;Rh^1_n>SXh6ooooo`Oo7AdM1ol[:b/7odQ8B0Oo;2`/1ooDe=@7odA4A0Oo3@d=1_lS8b<5oooo
o`Oo;Bd]1onf][H7oe]KF`Oo8B4Q1onYZJT7ooooo`Oo=SHf1_lb<S8=ooooo`002oooool7obHV9POo
BTY:1omJFUX7ojf][@OoV9RH1ooCdm<7oo3`l0Koc/k>1Oooool7obHV9POoe]KF1om/K6`7oaXJ6POo
7alO1olJ6QX7oaPH60KoBTY:1_ooool6ochn?POo92@T1oo1`L47oe9BDPOo4Q8B1olW9bL7oaDE5@Ko
<S8b1_ooool7obDU9@Oo4A4A1_l^;Rh7o`/;2`Oo9BDU1ooNg]h7oc8b<PKo8R8R1_ooool7o`h>3POo
51@D1ol;2`/7o`h>3PKo7QhN1olV9RH7od51@@KoOgmo1_ooool7oe9BDPOoO7al1on3Ph<7oj6QX@Oo
3@d=1olN7Qh6obh^;PKoSXj>1_ooool7oadM7@Oo:b/[1om8B4P7ob`/;0Ooe=CD1om4A4@7o`d=3@Ko
8b<S1Oooool7obd];@Oo][Jf1omKFe/7ob4Q8@OoZJVY1oooool7ocHf=PKo<S8b3Oooool000_ooooo
1olV9RH7odY:BPOoFUYJ1on][Jd7oiRHV0Oodm?C1oo`l?06olk>cPGooooo1olV9RH7omKFePOoK6a/
1olJ6QX7oalO7`Oo6QXJ1olH61P6odY:BPKooooo1_ln?Sh7ob@T90Oo`L711omBDU87oa8B4POo9bLW
1olE5AD6oc8b<PKooooo1olU9BD7oa4A4@Ko;Rh^1ol;2`/7obDU9@Oog]kN1olb<S86ob8R8PKooooo
1ol>3Ph7oa@D50Oo2`/;1ol>3Ph6oahN7POo9RHV1om1@D46ogmoO`Kooooo1omBDU87ogalO0OoPh>3
1onQXJ47o`d=3@Oo7QhN1_l^;Rh6ohj>SPKooooo1olM7Ad7ob/[:`OoB4Q81ol/;2`7omCDe0OoA4A4
1ol=3@d6ob<S8`Gooooo1ol];Bd7okJf]POoFe]K1olQ8B47ojVYZ@Oooooo1olf=SH6oc8b<Pgooooo
000;ooooo`Oo9RHV1om:BTX7oeYJFPOo[Jf]1onHV9P7om?Cd`Ool?3`1_o>c/h5ooooo`Oo9RHV1ooF
e]H7ofa/K0Oo6QXJ1olO7al7oaXJ6POo61PH1_m:BTX6ooooo`Ko?Shn1olT92@7ol71`@OoDU9B1olB
4Q87obLW9`Oo5ADE1_lb<S86ooooo`Oo9BDU1olA4A46obh^;POo2`/;1olU9BD7omkNgPOo<S8b1_lR
8R86ooooo`Oo3Ph>1olD51@7o`/;2`Oo3Ph>1_lN7Qh7obHV9POo@D511_moOgl6ooooo`OoDU9B1oml
O7`7oh>3P`OoXJ6Q1ol=3@d7oahN7PKo;Rh^1_n>SXh6ooooo`Oo7AdM1ol[:b/7odQ8B0Oo;2`/1ooD
e=@7odA4A0Oo3@d=1_lS8b<5ooooo`Oo;Bd]1onf][H7oe]KF`Oo8B4Q1onYZJT7ooooo`Oo=SHf1_lb
<S8=ooooo`002oooool7obHV9POoBTY:1omJFUX7ojf][@OoV9RH1ooCdm<7oo3`l0Koc/k>1Oooool7
obHV9POoe]KF1om/K6`7oaXJ6POo7alO1olJ6QX7oaPH60KoBTY:1_ooool6ochn?POo92@T1oo1`L47
oe9BDPOo4Q8B1olW9bL7oaDE5@Ko<S8b1_ooool7obDU9@Oo4A4A1_l^;Rh7o`/;2`Oo9BDU1ooNg]h7
oc8b<PKo8R8R1_ooool7o`h>3POo51@D1ol;2`/7o`h>3PKo7QhN1olV9RH7od51@@KoOgmo1_ooool7
oe9BDPOoO7al1on3Ph<7oj6QX@Oo3@d=1olN7Qh6obh^;PKoSXj>1_ooool7oadM7@Oo:b/[1om8B4P7
ob`/;0Ooe=CD1om4A4@7o`d=3@Ko8b<S1Oooool7obd];@Oo][Jf1omKFe/7ob4Q8@OoZJVY1oooool7
ocHf=PKo<S8b3Oooool000_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKf
mPGooooo1old=3@7om?Cd`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@
d0OoADE51ol20P87oalO7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGe
m@go92@T1_ooool7o`0000Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`00
00OoBTY:1ooGemL7ohJ6QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV
9POoj>SX1omADE47o`410@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;
2`Ko6ATI3Oooool000_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKfmPGo
oooo1old=3@7om?Cd`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@d0Oo
ADE51ol20P87oalO7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGem@go
92@T1_ooool7o`0000Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`0000Oo
BTY:1ooGemL7ohJ6QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV9POo
j>SX1omADE47o`410@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;2`Ko
6ATI3Oooool000_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKfmPGooooo
1old=3@7om?Cd`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@d0OoADE5
1ol20P87oalO7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGem@go92@T
1_ooool7o`0000Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`0000OoBTY:
1ooGemL7ohJ6QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV9POoj>SX
1omADE47o`410@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;2`Ko6ATI
3Oooool000_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKfmPGooooo1old
=3@7om?Cd`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@d0OoADE51ol2
0P87oalO7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGem@go92@T1_oo
ool7o`0000Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`0000OoBTY:1ooG
emL7ohJ6QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV9POoj>SX1omA
DE47o`410@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;2`Ko6ATI3Ooo
ool000_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKfmPGooooo1old=3@7
om?Cd`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@d0OoADE51ol20P87
oalO7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGem@go92@T1_ooool7
o`0000Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`0000OoBTY:1ooGemL7
ohJ6QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV9POoj>SX1omADE47
o`410@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;2`Ko6ATI3Oooool0
00_ooooo1olB4Q87odU9B@OoEEEE1on;Rh/7ohf=S@Ooi^KV1oo;bl/6ooKfmPGooooo1old=3@7om?C
d`OoGUiN1ol30`<7o`h>3Pko7AdM1_m7AdL6ooooo`Ko9bLW1olN7Qh7om3@d0OoADE51ol20P87oalO
7`Oo1PH61_l/;2`6ooooo`Oo820P1ol51@D6ob/[:`Oo00001ol/;2`7ooGem@go92@T1_ooool7o`00
00Oo2`/;1ol51@D7o`H61PKo6QXJ1olS8b<7oc/k>`KoKVi^1_ooool7o`0000OoBTY:1ooGemL7ohJ6
QPOoSHf=1olM7Ad6oeUIF@Ko6ATI1_ooool7oa@D50Oo;Rh^1ol`<307obHV9POoj>SX1omADE47o`41
0@Ko5QHF1Oooool7obh^;POoQ8B41olS8b<7oc<c<`OoRh^;1ooNg]h7o`/;2`Ko6ATI3Oooool000_o
oooo1ol410@7ob`/;0OoF5QH1on;Rh/7ofQXJ0OobLW91oo=cLd6okjn_PGooooo1ol^;Rh7ooooo`Oo
HV9R1olA4A47oa`L70Oo6ATI1olS8b<6oe1@D0Kooooo1_lj>SX7obHV9POoemOG1ole=CD7o`L71`Oo
8R8R1ol71`L6obPX:0Kooooo1ol[:b/7o`L71`Ko;2`/1ol10@47ob`/;0Oon_[j1olM7Ad6ob@T90Ko
oooo1ol@4107o`d=3@Oo10@41ol@4106oa/K6`Oo71`L1old=3@6oi6AT@Kooooo1on9RHT7oifMW@Oo
K6a/1on:RXX7oa4A4@Oo3Ph>1_lh>3P6odE5A@Kooooo1olE5AD7oc0`<0Oo@D511olS8b<7ooclo0Oo
AdM71ol92@T6oaLG5`Gooooo1oln?Sh7olW9b@Oo;bl_1olY:BT7olo?c`Oon_[j1ol=3@d6oaLG5`go
oooo000;ooooo`Oo10@41ol/;2`7oeQHF0OoRh^;1omXJ6P7olW9b@OocLg=1_nn_[h5ooooo`Oo;Rh^
1oooool7of9RHPOo4A4A1olL71`7oaTI6@Oo8b<S1_m@D506ooooo`Ko>SXj1olV9RH7omOGe`Oo=CDe
1ol71`L7ob8R8POo1`L71_lX:2P6ooooo`Oo:b/[1ol71`L6ob`/;0Oo0@411ol/;2`7oo[jnPOo7AdM
1_lT92@6ooooo`Oo410@1ol=3@d7o`@410Oo410@1_lK6a/7oa`L70Oo=3@d1_nATI46ooooo`OoRHV9
1onMWId7ofa/K0OoRXZ:1olA4A47o`h>3PKo>3Ph1_m5ADD6ooooo`Oo5ADE1ol`<307od51@@Oo8b<S
1oolo?`7odM7A`Oo2@T91_lG5aL5ooooo`Oo?Shn1oo9bLT7obl_;`Oo:BTY1oo?cll7oo[jnPOo3@d=
1_lG5aL=ooooo`002oooool7o`@410Oo;2`/1omHF5P7oh^;R`OoJ6QX1oo9bLT7olg=c@Ko_[jn1Ooo
ool7obh^;POooooo1omRHV87oa4A4@Oo71`L1olI6AT7ob<S8`KoD51@1_ooool6ocXj>POo9RHV1ooG
emL7ocDe=@Oo1`L71olR8R87o`L71`Ko:2PX1_ooool7ob/[:`Oo1`L71_l/;2`7o`410@Oo;2`/1ooj
n_X7oadM7@Ko92@T1_ooool7oa0@40Oo3@d=1ol410@7oa0@40Ko6a/K1olL71`7oc@d=0KoTI6A1_oo
ool7ohV9R@OoWIfM1om/K6`7ohZ:RPOo4A4A1ol>3Ph6ocPh>0KoADE51_ooool7oaDE5@Oo<30`1om1
@D47ob<S8`Ooo?cl1om7AdL7o`T92@Ko5aLG1Oooool7ochn?POobLW91ol_;bl7obTY:@Ooclo?1ooj
n_X7o`d=3@Ko5aLG3Oooool000_ooooo1ol410@7ob`/;0OoF5QH1on;Rh/7ofQXJ0OobLW91oo=cLd6
okjn_PGooooo1ol^;Rh7ooooo`OoHV9R1olA4A47oa`L70Oo6ATI1olS8b<6oe1@D0Kooooo1_lj>SX7
obHV9POoemOG1ole=CD7o`L71`Oo8R8R1ol71`L6obPX:0Kooooo1ol[:b/7o`L71`Ko;2`/1ol10@47
ob`/;0Oon_[j1olM7Ad6ob@T90Kooooo1ol@4107o`d=3@Oo10@41ol@4106oa/K6`Oo71`L1old=3@6
oi6AT@Kooooo1on9RHT7oifMW@OoK6a/1on:RXX7oa4A4@Oo3Ph>1_lh>3P6odE5A@Kooooo1olE5AD7
oc0`<0Oo@D511olS8b<7ooclo0OoAdM71ol92@T6oaLG5`Gooooo1oln?Sh7olW9b@Oo;bl_1olY:BT7
olo?c`Oon_[j1ol=3@d6oaLG5`gooooo000;ooooo`Oo10@41ol/;2`7oeQHF0OoRh^;1omXJ6P7olW9
b@OocLg=1_nn_[h5ooooo`Oo;Rh^1oooool7of9RHPOo4A4A1olL71`7oaTI6@Oo8b<S1_m@D506oooo
o`Ko>SXj1olV9RH7omOGe`Oo=CDe1ol71`L7ob8R8POo1`L71_lX:2P6ooooo`Oo:b/[1ol71`L6ob`/
;0Oo0@411ol/;2`7oo[jnPOo7AdM1_lT92@6ooooo`Oo410@1ol=3@d7o`@410Oo410@1_lK6a/7oa`L
70Oo=3@d1_nATI46ooooo`OoRHV91onMWId7ofa/K0OoRXZ:1olA4A47o`h>3PKo>3Ph1_m5ADD6oooo
o`Oo5ADE1ol`<307od51@@Oo8b<S1oolo?`7odM7A`Oo2@T91_lG5aL5ooooo`Oo?Shn1oo9bLT7obl_
;`Oo:BTY1oo?cll7oo[jnPOo3@d=1_lG5aL=ooooo`002oooool7o`@410Oo;2`/1omHF5P7oh^;R`Oo
J6QX1oo9bLT7olg=c@Ko_[jn1Oooool7obh^;POooooo1omRHV87oa4A4@Oo71`L1olI6AT7ob<S8`Ko
D51@1_ooool6ocXj>POo9RHV1ooGemL7ocDe=@Oo1`L71olR8R87o`L71`Ko:2PX1_ooool7ob/[:`Oo
1`L71_l/;2`7o`410@Oo;2`/1oojn_X7oadM7@Ko92@T1_ooool7oa0@40Oo3@d=1ol410@7oa0@40Ko
6a/K1olL71`7oc@d=0KoTI6A1_ooool7ohV9R@OoWIfM1om/K6`7ohZ:RPOo4A4A1ol>3Ph6ocPh>0Ko
ADE51_ooool7oaDE5@Oo<30`1om1@D47ob<S8`Ooo?cl1om7AdL7o`T92@Ko5aLG1Oooool7ochn?POo
bLW91ol_;bl7obTY:@Ooclo?1oojn_X7o`d=3@Ko5aLG3Oooool000_ooooo1ol410@7ob`/;0OoF5QH
1on;Rh/7ofQXJ0OobLW91oo=cLd6okjn_PGooooo1ol^;Rh7ooooo`OoHV9R1olA4A47oa`L70Oo6ATI
1olS8b<6oe1@D0Kooooo1_lj>SX7obHV9POoemOG1ole=CD7o`L71`Oo8R8R1ol71`L6obPX:0Kooooo
1ol[:b/7o`L71`Ko;2`/1ol10@47ob`/;0Oon_[j1olM7Ad6ob@T90Kooooo1ol@4107o`d=3@Oo10@4
1ol@4106oa/K6`Oo71`L1old=3@6oi6AT@Kooooo1on9RHT7oifMW@OoK6a/1on:RXX7oa4A4@Oo3Ph>
1_lh>3P6odE5A@Kooooo1olE5AD7oc0`<0Oo@D511olS8b<7ooclo0OoAdM71ol92@T6oaLG5`Gooooo
1oln?Sh7olW9b@Oo;bl_1olY:BT7olo?c`Oon_[j1ol=3@d6oaLG5`gooooo000;ooooo`Oo51@D1om<
C4`7oeUIF@OoP8201omdM7@7okno_`Oob<S82oooool7ocLg=`Ooi^KV1omRHV87o`0000Oo3@d=1olM
7Ad7ob<S8`KoCDe=1_ooool6obTY:@Oo5aLG1ooAdM47oc`l?0Oo1PH61olN7Qh7o`820PKo:b/[1_oo
ool7oaPH60Oo0`<31_ld=3@7o`820POo:RXZ1oooool7oa@D50Ko8R8R1_ooool7oa4A4@Oo3Ph>1ol7
1`L7o``<30Ko5aLG1ol;2`/7ob<S8`KoPX:21_ooool7o`L71`OoH61P1oooool7ogAdM0OoCdm?1om3
@d<6oh61P@Ko7alO1_ooool7o`P820Oo>3Ph1olf=SH7oahN7POom_Kf1om5ADD7o`0000Ko30`<1Ooo
ool7oc/k>`OoTI6A1ol30`<7ocTi>@OoW9bL1oo0`<07o`@410Ko5aLG3Oooool000_ooooo1olD51@7
oda<C0OoFEUI1on0P807ogAdM0Oo_kno1oo8b<P;ooooo`Oo=cLg1ooVi^H7of9RHPOo00001ol=3@d7
oadM7@Oo8b<S1_m=CDd6ooooo`Ko:BTY1olG5aL7om7Ad@Oo?3`l1ol61PH7oahN7POo0P821_l[:b/6
ooooo`Oo61PH1ol30`<6oc@d=0Oo0P821olZ:RX7ooooo`Oo51@D1_lR8R86ooooo`Oo4A4A1ol>3Ph7
o`L71`Oo30`<1_lG5aL7o`/;2`Oo8b<S1_n2PX86ooooo`Oo1`L71omPH607ooooo`OoM7Ad1om?Cdl7
od=3@`KoPH611_lO7al6ooooo`Oo20P81olh>3P7ocHf=POo7QhN1oofm_H7odE5A@Oo00001_l<30`5
ooooo`Oo>c/k1onATI47o`<30`Oo>CTi1onLW9`7ol30`0Oo10@41_lG5aL=ooooo`002oooool7oa@D
50OoC4a<1omIFET7oh20P0OoM7Ad1ono_kl7olS8b0_ooooo1olg=cL7onKViPOoHV9R1ol00007o`d=
3@Oo7AdM1olS8b<6ode=C@Kooooo1_lY:BT7oaLG5`OodM7A1oll?3`7o`H61POo7QhN1ol20P86ob/[
:`Kooooo1olH61P7o`<30`Ko=3@d1ol20P87obXZ:POooooo1olD51@6ob8R8PKooooo1olA4A47o`h>
3POo1`L71ol<30`6oaLG5`Oo2`/;1olS8b<6oh:2PPKooooo1ol71`L7of1PH0Oooooo1omdM7@7odm?
C`Oo@d=31_n1PH46oalO7`Kooooo1ol820P7ocPh>0Oo=SHf1olN7Qh7ooKfmPOoADE51ol00006o``<
30Gooooo1olk>c/7oi6AT@Oo0`<31oli>CT7oibLW0Oo`<301ol410@6oaLG5`gooooo000;ooooo`Oo
51@D1om<C4`7oeUIF@OoP8201omdM7@7okno_`Oob<S82oooool7ocLg=`Ooi^KV1omRHV87o`0000Oo
3@d=1olM7Ad7ob<S8`KoCDe=1_ooool6obTY:@Oo5aLG1ooAdM47oc`l?0Oo1PH61olN7Qh7o`820PKo
:b/[1_ooool7oaPH60Oo0`<31_ld=3@7o`820POo:RXZ1oooool7oa@D50Ko8R8R1_ooool7oa4A4@Oo
3Ph>1ol71`L7o``<30Ko5aLG1ol;2`/7ob<S8`KoPX:21_ooool7o`L71`OoH61P1oooool7ogAdM0Oo
Cdm?1om3@d<6oh61P@Ko7alO1_ooool7o`P820Oo>3Ph1olf=SH7oahN7POom_Kf1om5ADD7o`0000Ko
30`<1Oooool7oc/k>`OoTI6A1ol30`<7ocTi>@OoW9bL1oo0`<07o`@410Ko5aLG3Oooool000_ooooo
1olD51@7oda<C0OoFEUI1on0P807ogAdM0Oo_kno1oo8b<P;ooooo`Oo=cLg1ooVi^H7of9RHPOo0000
1ol=3@d7oadM7@Oo8b<S1_m=CDd6ooooo`Ko:BTY1olG5aL7om7Ad@Oo?3`l1ol61PH7oahN7POo0P82
1_l[:b/6ooooo`Oo61PH1ol30`<6oc@d=0Oo0P821olZ:RX7ooooo`Oo51@D1_lR8R86ooooo`Oo4A4A
1ol>3Ph7o`L71`Oo30`<1_lG5aL7o`/;2`Oo8b<S1_n2PX86ooooo`Oo1`L71omPH607ooooo`OoM7Ad
1om?Cdl7od=3@`KoPH611_lO7al6ooooo`Oo20P81olh>3P7ocHf=POo7QhN1oofm_H7odE5A@Oo0000
1_l<30`5ooooo`Oo>c/k1onATI47o`<30`Oo>CTi1onLW9`7ol30`0Oo10@41_lG5aL=ooooo`002ooo
ool7oa@D50OoC4a<1omIFET7oh20P0OoM7Ad1ono_kl7olS8b0_ooooo1olg=cL7onKViPOoHV9R1ol0
0007o`d=3@Oo7AdM1olS8b<6ode=C@Kooooo1_lY:BT7oaLG5`OodM7A1oll?3`7o`H61POo7QhN1ol2
0P86ob/[:`Kooooo1olH61P7o`<30`Ko=3@d1ol20P87obXZ:POooooo1olD51@6ob8R8PKooooo1olA
4A47o`h>3POo1`L71ol<30`6oaLG5`Oo2`/;1olS8b<6oh:2PPKooooo1ol71`L7of1PH0Oooooo1omd
M7@7odm?C`Oo@d=31_n1PH46oalO7`Kooooo1ol820P7ocPh>0Oo=SHf1olN7Qh7ooKfmPOoADE51ol0
0006o``<30Gooooo1olk>c/7oi6AT@Oo0`<31oli>CT7oibLW0Oo`<301ol410@6oaLG5`gooooo000;
ooooo`Oo51@D1om<C4`7oeUIF@OoP8201omdM7@7okno_`Oob<S82oooool7ocLg=`Ooi^KV1omRHV87
o`0000Oo3@d=1olM7Ad7ob<S8`KoCDe=1_ooool6obTY:@Oo5aLG1ooAdM47oc`l?0Oo1PH61olN7Qh7
o`820PKo:b/[1_ooool7oaPH60Oo0`<31_ld=3@7o`820POo:RXZ1oooool7oa@D50Ko8R8R1_ooool7
oa4A4@Oo3Ph>1ol71`L7o``<30Ko5aLG1ol;2`/7ob<S8`KoPX:21_ooool7o`L71`OoH61P1oooool7
ogAdM0OoCdm?1om3@d<6oh61P@Ko7alO1_ooool7o`P820Oo>3Ph1olf=SH7oahN7POom_Kf1om5ADD7
o`0000Ko30`<1Oooool7oc/k>`OoTI6A1ol30`<7ocTi>@OoW9bL1oo0`<07o`@410Ko5aLG3Oooool0
00_ooooo1ol00007ob<S8`OoD51@1onKVi/7ofa/K0Oo_;bl1ooDe=@6oibLW0Gooooo1oli>CT7oo[j
nPOoFUYJ1ol:2PX7oa0@40Oo9bLW1olH61P6oe]KF`Kooooo1_m2@T87obDU9@Oog=cL1olm?Cd7o`<3
0`Oo51@D1ol410@6oc0`<0Kooooo1olG5aL7o`P820Ko;Bd]1ol20P87oc8b<POon_[j1ol;2`/6obLW
9`Kooooo1olQ8B47oa4A4@Oo3@d=3OlB4Q87o`T92@Oo5ADE1_oHf=P6ooooo`Oo_Kfm1onWYjL7oeEE
E@OoHF5Q1olK6a/7o`H61PKo@d=31_lM7Ad6ooooo`Oo5QHF1olX:2P7oc@d=0Oo9BDU1ooalO47oeIF
EPOo3`l?1_l@4105ooooo`OoEeMG1one]KD7o`T92@OoD51@1ooOgml7ok>c/`Oo0`<31_l;2`/=oooo
o`002oooool7o`0000Oo8b<S1om@D507oi^KV`OoK6a/1onl_;`7omCDe0KoW9bL1Oooool7ocTi>@Oo
n_[j1omJFUX7o`X:2POo410@1olW9bL7oaPH60KoFe]K1_ooool6od92@POo9BDU1ooLg=`7ocdm?@Oo
0`<31olD51@7o`@410Ko<30`1_ooool7oaLG5`Oo20P81_l];Bd7o`820POo<S8b1oojn_X7o`/;2`Ko
9bLW1_ooool7ob4Q8@Oo4A4A1ol=3@d=oa8B4POo2@T91olE5AD6omSHf0Kooooo1onm_Kd7ojNWY`Oo
EEEE1omQHF47oa/K6`Oo1PH61_m3@d<6oadM7@Kooooo1olF5QH7obPX:0Oo=3@d1olU9BD7oo7al@Oo
EUIF1ol?3`l6oa0@40Gooooo1omGEeL7okFe]@Oo2@T91om@D507omoOg`Oo/k>c1ol30`<6o`/;2`go
oooo000;ooooo`Oo00001olS8b<7oe1@D0OoVi^K1om/K6`7okbl_0Ooe=CD1_nLW9`5ooooo`Oo>CTi
1oojn_X7oeYJFPOo2PX:1ol@4107obLW9`Oo61PH1_mKFe/6ooooo`Ko@T921olU9BD7omcLg0Oo?Cdm
1ol30`<7oa@D50Oo10@41_l`<306ooooo`Oo5aLG1ol820P6obd];@Oo0P821olb<S87oo[jnPOo2`/;
1_lW9bL6ooooo`Oo8B4Q1olA4A47o`d=3@go4Q8B1ol92@T7oaDE5@Kof=SH1_ooool7okfm_@OoYjNW
1omEEED7of5QH@Oo6a/K1ol61PH6od=3@`Ko7AdM1_ooool7oaHF5POo:2PX1old=3@7obDU9@OolO7a
1omFEUH7o`l?3`Ko410@1Oooool7oeMGE`Oo]KFe1ol92@T7oe1@D0OogmoO1onc/k<7o`<30`Ko2`/;
3Oooool000_ooooo1ol00007ob<S8`OoD51@1onKVi/7ofa/K0Oo_;bl1ooDe=@6oibLW0Gooooo1oli
>CT7oo[jnPOoFUYJ1ol:2PX7oa0@40Oo9bLW1olH61P6oe]KF`Kooooo1_m2@T87obDU9@Oog=cL1olm
?Cd7o`<30`Oo51@D1ol410@6oc0`<0Kooooo1olG5aL7o`P820Ko;Bd]1ol20P87oc8b<POon_[j1ol;
2`/6obLW9`Kooooo1olQ8B47oa4A4@Oo3@d=3OlB4Q87o`T92@Oo5ADE1_oHf=P6ooooo`Oo_Kfm1onW
YjL7oeEEE@OoHF5Q1olK6a/7o`H61PKo@d=31_lM7Ad6ooooo`Oo5QHF1olX:2P7oc@d=0Oo9BDU1ooa
lO47oeIFEPOo3`l?1_l@4105ooooo`OoEeMG1one]KD7o`T92@OoD51@1ooOgml7ok>c/`Oo0`<31_l;
2`/=ooooo`002oooool7o`0000Oo8b<S1om@D507oi^KV`OoK6a/1onl_;`7omCDe0KoW9bL1Oooool7
ocTi>@Oon_[j1omJFUX7o`X:2POo410@1olW9bL7oaPH60KoFe]K1_ooool6od92@POo9BDU1ooLg=`7
ocdm?@Oo0`<31olD51@7o`@410Ko<30`1_ooool7oaLG5`Oo20P81_l];Bd7o`820POo<S8b1oojn_X7
o`/;2`Ko9bLW1_ooool7ob4Q8@Oo4A4A1ol=3@d=oa8B4POo2@T91olE5AD6omSHf0Kooooo1onm_Kd7
ojNWY`OoEEEE1omQHF47oa/K6`Oo1PH61_m3@d<6oadM7@Kooooo1olF5QH7obPX:0Oo=3@d1olU9BD7
oo7al@OoEUIF1ol?3`l6oa0@40Gooooo1omGEeL7okFe]@Oo2@T91om@D507omoOg`Oo/k>c1ol30`<6
o`/;2`gooooo000;ooooo`Oo00001olS8b<7oe1@D0OoVi^K1om/K6`7okbl_0Ooe=CD1_nLW9`5oooo
o`Oo>CTi1oojn_X7oeYJFPOo2PX:1ol@4107obLW9`Oo61PH1_mKFe/6ooooo`Ko@T921olU9BD7omcL
g0Oo?Cdm1ol30`<7oa@D50Oo10@41_l`<306ooooo`Oo5aLG1ol820P6obd];@Oo0P821olb<S87oo[j
nPOo2`/;1_lW9bL6ooooo`Oo8B4Q1olA4A47o`d=3@go4Q8B1ol92@T7oaDE5@Kof=SH1_ooool7okfm
_@OoYjNW1omEEED7of5QH@Oo6a/K1ol61PH6od=3@`Ko7AdM1_ooool7oaHF5POo:2PX1old=3@7obDU
9@OolO7a1omFEUH7o`l?3`Ko410@1Oooool7oeMGE`Oo]KFe1ol92@T7oe1@D0OogmoO1onc/k<7o`<3
0`Ko2`/;3Oooool000_ooooo1ol00007ob<S8`OoD51@1onKVi/7ofa/K0Oo_;bl1ooDe=@6oibLW0Go
oooo1oli>CT7oo[jnPOoFUYJ1ol:2PX7oa0@40Oo9bLW1olH61P6oe]KF`Kooooo1_m2@T87obDU9@Oo
g=cL1olm?Cd7o`<30`Oo51@D1ol410@6oc0`<0Kooooo1olG5aL7o`P820Ko;Bd]1ol20P87oc8b<POo
n_[j1ol;2`/6obLW9`Kooooo1olQ8B47oa4A4@Oo3@d=3OlB4Q87o`T92@Oo5ADE1_oHf=P6ooooo`Oo
_Kfm1onWYjL7oeEEE@OoHF5Q1olK6a/7o`H61PKo@d=31_lM7Ad6ooooo`Oo5QHF1olX:2P7oc@d=0Oo
9BDU1ooalO47oeIFEPOo3`l?1_l@4105ooooo`OoEeMG1one]KD7o`T92@OoD51@1ooOgml7ok>c/`Oo
0`<31_l;2`/=ooooo`002oooool7oaTI6@OoA4A41omWIfL7oiJFUPOoIfMW1onj^[X7ol71`@Kojn_[
1Oooool7oclo?`Ooh^;R1omHF5P7o`0000Oo410@1olN7Qh7oaXJ6PKoB4Q81_ooool6obd];@Oo8B4Q
1oooool7oe1@D0Oo3@d=1olU9BD7o`0000Ko@4101_ooool7oaDE5@Oo0@411_la<C47o``<30Oo9BDU
1ooinOT7o`T92@Ko820P1_ooool7oalO7`Oo8B4Q1ol820P7o`L71`Ko3Ph>1ol61PH7ob0P80KoXZ:R
1_ooool7ob/[:`OoQHF51oodm?@7oeaLG0Oo:b/[1omdM7@6oiZJVPKo9bLW1_ooool7o`T92@Oo;bl_
1olY:BT7oaXJ6POooooo1omDE5@7oa4A4@Ko2`/;1Oooool7od10@0OoLg=c1ol00007odM7A`Oo/;2`
1omlO7`7o`P820Ko30`<3Oooool000_ooooo1olI6AT7odA4A0OoIfMW1onFUYH7ofMWI`Oo^[Zj1oo1
`L46on_[j`Gooooo1olo?cl7on;RhPOoF5QH1ol00007oa0@40Oo7QhN1olJ6QX6odQ8B0Kooooo1_l]
;Bd7ob4Q8@Oooooo1om@D507o`d=3@Oo9BDU1ol00006od10@0Kooooo1olE5AD7o`410@Ko<C4a1ol<
30`7obDU9@OonOWi1ol92@T6ob0P80Kooooo1olO7al7ob4Q8@Oo20P81ol71`L6o`h>3POo1PH61olP
8206oj:RXPKooooo1ol[:b/7ohF5Q@Oom?Cd1omLG5`7ob/[:`OoM7Ad1_nJVYX6obLW9`Kooooo1ol9
2@T7obl_;`Oo:BTY1olJ6QX7ooooo`OoE5AD1olA4A46o`/;2`Gooooo1om0@407og=cL`Oo00001om7
AdL7ok2`/0OoO7al1ol820P6o``<30gooooo000;ooooo`Oo6ATI1om4A4@7ofMWI`OoUYJF1omWIfL7
okZj^POo`L711_o[jn/5ooooo`Oo?clo1ooRh^87oeQHF0Oo00001ol@4107oahN7POo6QXJ1_m8B4P6
ooooo`Ko;Bd]1olQ8B47ooooo`OoD51@1ol=3@d7obDU9@Oo00001_m0@406ooooo`Oo5ADE1ol10@46
oc4a<@Oo30`<1olU9BD7ooWin@Oo2@T91_lP8206ooooo`Oo7alO1olQ8B47o`P820Oo1`L71_l>3Ph7
o`H61POo820P1_nRXZ86ooooo`Oo:b/[1on5QHD7ooCdm0OoG5aL1ol[:b/7ogAdM0KoVYZJ1_lW9bL6
ooooo`Oo2@T91ol_;bl7obTY:@Oo6QXJ1oooool7oeADE0Oo4A4A1_l;2`/5ooooo`Oo@4101omcLg<7
o`0000OoAdM71on`/;07ogalO0Oo20P81_l<30`=ooooo`002oooool7oaTI6@OoA4A41omWIfL7oiJF
UPOoIfMW1onj^[X7ol71`@Kojn_[1Oooool7oclo?`Ooh^;R1omHF5P7o`0000Oo410@1olN7Qh7oaXJ
6PKoB4Q81_ooool6obd];@Oo8B4Q1oooool7oe1@D0Oo3@d=1olU9BD7o`0000Ko@4101_ooool7oaDE
5@Oo0@411_la<C47o``<30Oo9BDU1ooinOT7o`T92@Ko820P1_ooool7oalO7`Oo8B4Q1ol820P7o`L7
1`Ko3Ph>1ol61PH7ob0P80KoXZ:R1_ooool7ob/[:`OoQHF51oodm?@7oeaLG0Oo:b/[1omdM7@6oiZJ
VPKo9bLW1_ooool7o`T92@Oo;bl_1olY:BT7oaXJ6POooooo1omDE5@7oa4A4@Ko2`/;1Oooool7od10
@0OoLg=c1ol00007odM7A`Oo/;2`1omlO7`7o`P820Ko30`<3Oooool000_ooooo1olI6AT7odA4A0Oo
IfMW1onFUYH7ofMWI`Oo^[Zj1oo1`L46on_[j`Gooooo1olo?cl7on;RhPOoF5QH1ol00007oa0@40Oo
7QhN1olJ6QX6odQ8B0Kooooo1_l];Bd7ob4Q8@Oooooo1om@D507o`d=3@Oo9BDU1ol00006od10@0Ko
oooo1olE5AD7o`410@Ko<C4a1ol<30`7obDU9@OonOWi1ol92@T6ob0P80Kooooo1olO7al7ob4Q8@Oo
20P81ol71`L6o`h>3POo1PH61olP8206oj:RXPKooooo1ol[:b/7ohF5Q@Oom?Cd1omLG5`7ob/[:`Oo
M7Ad1_nJVYX6obLW9`Kooooo1ol92@T7obl_;`Oo:BTY1olJ6QX7ooooo`OoE5AD1olA4A46o`/;2`Go
oooo1om0@407og=cL`Oo00001om7AdL7ok2`/0OoO7al1ol820P6o``<30gooooo000;ooooo`Oo6ATI
1om4A4@7ofMWI`OoUYJF1omWIfL7okZj^POo`L711_o[jn/5ooooo`Oo?clo1ooRh^87oeQHF0Oo0000
1ol@4107oahN7POo6QXJ1_m8B4P6ooooo`Ko;Bd]1olQ8B47ooooo`OoD51@1ol=3@d7obDU9@Oo0000
1_m0@406ooooo`Oo5ADE1ol10@46oc4a<@Oo30`<1olU9BD7ooWin@Oo2@T91_lP8206ooooo`Oo7alO
1olQ8B47o`P820Oo1`L71_l>3Ph7o`H61POo820P1_nRXZ86ooooo`Oo:b/[1on5QHD7ooCdm0OoG5aL
1ol[:b/7ogAdM0KoVYZJ1_lW9bL6ooooo`Oo2@T91ol_;bl7obTY:@Oo6QXJ1oooool7oeADE0Oo4A4A
1_l;2`/5ooooo`Oo@4101omcLg<7o`0000OoAdM71on`/;07ogalO0Oo20P81_l<30`=ooooo`002ooo
ool7oa`L70Oo<30`1omDE5@7oifMW@OoMWIf1ona/K47olk>cPKoZZZZ1Oooool7oc/k>`OogmoO1omJ
FUX7o`H61POo6ATI1olU9BD7oaPH60KoJ6QX1_ooool6ocPh>0Oo:RXZ1ooShn<7oe9BDPOo5ADE1olP
8207o``<30KoBDU91_ooool7oa`L70Oo3`l?1_lc<c<7o`D51@Oo=CDe1ooShn<7oaLG5`Ko;Bd]1_oo
ool7obh^;POo4Q8B1ol:2PX7o`T92@Ko3Ph>1ol51@D7oaLG5`Kod=3@1_ooool7okVi^@OoZj^[1oll
?3`7ocdm?@Oo820P1olC4a<6of1PH0Ko<c<c1_ooool7oa@D50Oo;Bd]1olb<S87obPX:0Ooj>SX1omU
IFD=oaXJ6PGooooo1omVIVH7oh>3P`Oo0`<31om_Kfl7om3@d0OoJf][1olV9RH6obDU9@gooooo000;
ooooo`Oo71`L1ol`<307oeADE0OoWIfM1omfMWH7ok6a/@Ooc/k>1_nZZZX5ooooo`Oo>c/k1ooOgml7
oeYJFPOo1PH61olI6AT7obDU9@Oo61PH1_mXJ6P6ooooo`Ko>3Ph1olZ:RX7on?Sh`OoDU9B1olE5AD7
ob0P80Oo30`<1_m9BDT6ooooo`Oo71`L1ol?3`l6oc<c<`Oo1@D51ole=CD7on?Sh`Oo5aLG1_l];Bd6
ooooo`Oo;Rh^1olB4Q87o`X:2POo2@T91_l>3Ph7o`D51@Oo5aLG1_o@d=06ooooo`Oo^KVi1on[Zj/7
oc`l?0Oo?Cdm1olP8207oa<C4`KoH61P1_lc<c<6ooooo`Oo51@D1ol];Bd7oc8b<POo:2PX1ooXj>P7
ofEUI@go6QXJ1Oooool7ofIVIPOoPh>31ol30`<7ofm_K`Ood=3@1om[Jf/7obHV9PKo9BDU3Oooool0
00_ooooo1olL71`7oc0`<0OoE5AD1onMWId7ogIfMPOo/K6a1oo>c/h6ojZZZPGooooo1olk>c/7omoO
g`OoFUYJ1ol61PH7oaTI6@Oo9BDU1olH61P6ofQXJ0Kooooo1_lh>3P7obXZ:POohn?S1omBDU87oaDE
5@Oo820P1ol<30`6odU9B@Kooooo1olL71`7o`l?3`Ko<c<c1ol51@D7ocDe=@Oohn?S1olG5aL6obd]
;@Kooooo1ol^;Rh7oa8B4POo2PX:1ol92@T6o`h>3POo1@D51olG5aL6om3@d0Kooooo1oni^KT7oj^[
Z`Oo?3`l1olm?Cd7ob0P80Oo4a<C1_mPH606oc<c<`Kooooo1olD51@7obd];@Oo<S8b1olX:2P7onSX
j0OoIFEU3OlJ6QX5ooooo`OoIVIV1on3Ph<7o`<30`OoKfm_1oo@d=07of][J`Oo9RHV1_lU9BD=oooo
o`002oooool7oa`L70Oo<30`1omDE5@7oifMW@OoMWIf1ona/K47olk>cPKoZZZZ1Oooool7oc/k>`Oo
gmoO1omJFUX7o`H61POo6ATI1olU9BD7oaPH60KoJ6QX1_ooool6ocPh>0Oo:RXZ1ooShn<7oe9BDPOo
5ADE1olP8207o``<30KoBDU91_ooool7oa`L70Oo3`l?1_lc<c<7o`D51@Oo=CDe1ooShn<7oaLG5`Ko
;Bd]1_ooool7obh^;POo4Q8B1ol:2PX7o`T92@Ko3Ph>1ol51@D7oaLG5`Kod=3@1_ooool7okVi^@Oo
Zj^[1oll?3`7ocdm?@Oo820P1olC4a<6of1PH0Ko<c<c1_ooool7oa@D50Oo;Bd]1olb<S87obPX:0Oo
j>SX1omUIFD=oaXJ6PGooooo1omVIVH7oh>3P`Oo0`<31om_Kfl7om3@d0OoJf][1olV9RH6obDU9@go
oooo000;ooooo`Oo71`L1ol`<307oeADE0OoWIfM1omfMWH7ok6a/@Ooc/k>1_nZZZX5ooooo`Oo>c/k
1ooOgml7oeYJFPOo1PH61olI6AT7obDU9@Oo61PH1_mXJ6P6ooooo`Ko>3Ph1olZ:RX7on?Sh`OoDU9B
1olE5AD7ob0P80Oo30`<1_m9BDT6ooooo`Oo71`L1ol?3`l6oc<c<`Oo1@D51ole=CD7on?Sh`Oo5aLG
1_l];Bd6ooooo`Oo;Rh^1olB4Q87o`X:2POo2@T91_l>3Ph7o`D51@Oo5aLG1_o@d=06ooooo`Oo^KVi
1on[Zj/7oc`l?0Oo?Cdm1olP8207oa<C4`KoH61P1_lc<c<6ooooo`Oo51@D1ol];Bd7oc8b<POo:2PX
1ooXj>P7ofEUI@go6QXJ1Oooool7ofIVIPOoPh>31ol30`<7ofm_K`Ood=3@1om[Jf/7obHV9PKo9BDU
3Oooool000_ooooo1olL71`7oc0`<0OoE5AD1onMWId7ogIfMPOo/K6a1oo>c/h6ojZZZPGooooo1olk
>c/7omoOg`OoFUYJ1ol61PH7oaTI6@Oo9BDU1olH61P6ofQXJ0Kooooo1_lh>3P7obXZ:POohn?S1omB
DU87oaDE5@Oo820P1ol<30`6odU9B@Kooooo1olL71`7o`l?3`Ko<c<c1ol51@D7ocDe=@Oohn?S1olG
5aL6obd];@Kooooo1ol^;Rh7oa8B4POo2PX:1ol92@T6o`h>3POo1@D51olG5aL6om3@d0Kooooo1oni
^KT7oj^[Z`Oo?3`l1olm?Cd7ob0P80Oo4a<C1_mPH606oc<c<`Kooooo1olD51@7obd];@Oo<S8b1olX
:2P7onSXj0OoIFEU3OlJ6QX5ooooo`OoIVIV1on3Ph<7o`<30`OoKfm_1oo@d=07of][J`Oo9RHV1_lU
9BD=ooooo`002oooool7oa`L70Oo<30`1omDE5@7oifMW@OoMWIf1ona/K47olk>cPKoZZZZ1Oooool7
oc/k>`OogmoO1omJFUX7o`H61POo6ATI1olU9BD7oaPH60KoJ6QX1_ooool6ocPh>0Oo:RXZ1ooShn<7
oe9BDPOo5ADE1olP8207o``<30KoBDU91_ooool7oa`L70Oo3`l?1_lc<c<7o`D51@Oo=CDe1ooShn<7
oaLG5`Ko;Bd]1_ooool7obh^;POo4Q8B1ol:2PX7o`T92@Ko3Ph>1ol51@D7oaLG5`Kod=3@1_ooool7
okVi^@OoZj^[1oll?3`7ocdm?@Oo820P1olC4a<6of1PH0Ko<c<c1_ooool7oa@D50Oo;Bd]1olb<S87
obPX:0Ooj>SX1omUIFD=oaXJ6PGooooo1omVIVH7oh>3P`Oo0`<31om_Kfl7om3@d0OoJf][1olV9RH6
obDU9@gooooo000;ooooo`Oo@d=31omJFUX7ofi^KPOoUYJF1on8R8P7ojn_[`Ooa/K61_oalO45oooo
o`OoBTY:1onl_;`7odi>CPOo0@411ol@4107oalO7`Oo8R8R1_mNGUh6ooooo`Ko<C4a1olT92@7omOG
e`OoE5AD1ol=3@d7ob`/;0Oo5ADE1_m4A4@6ooooo`Oo51@D1ol92@T6obd];@Oo4Q8B1olh>3P7olk>
cPOo1PH61_lV9RH6ooooo`Oo>CTi1ol`<307oaLG5`Oo5QHF1_l92@T7o`/;2`Oo6QXJ3?ooool7obLW
9`OoNWYj1oo/k>`7odY:BPOo8b<S1onYZJT6ok6a/@Ko8b<S1_ooool7o`T92@Oo=SHf1olc<c<7obd]
;@OoeMGE1omHF5P7oadM7@Ko6a/K1Oooool7od92@POoAdM71ol@4107odi>CPOoWIfM1om8B4P7oa/K
6`Ko7AdM3Oooool000_ooooo1om3@d<7oeYJFPOoKVi^1onFUYH7ohR8R0Oo[jn_1oo6a/H6oo7al@Go
oooo1om:BTX7okbl_0OoCTi>1ol10@47oa0@40Oo7alO1olR8R86oeiNGPKooooo1_la<C47ob@T90Oo
emOG1omDE5@7o`d=3@Oo;2`/1olE5AD6odA4A0Kooooo1olD51@7o`T92@Ko;Bd]1olB4Q87ocPh>0Oo
c/k>1ol61PH6obHV9PKooooo1oli>CT7oc0`<0Oo5aLG1olF5QH6o`T92@Oo2`/;1olJ6QX<ooooo`Oo
9bLW1omjNWX7onc/k0OoBTY:1olS8b<7ojVYZ@Ko/K6a1_lS8b<6ooooo`Oo2@T91olf=SH7oc<c<`Oo
;Bd]1ooEeMD7oeQHF0Oo7AdM1_lK6a/5ooooo`Oo@T921om7AdL7oa0@40OoCTi>1onMWId7odQ8B0Oo
6a/K1_lM7Ad=ooooo`002oooool7od=3@`OoFUYJ1om^KVh7oiJFUPOoR8R81on_[jl7olK6aPKolO7a
1Oooool7odY:BPOo_;bl1om>CTh7o`410@Oo410@1olO7al7ob8R8PKoGUiN1_ooool6oc4a<@Oo92@T
1ooGemL7oeADE0Oo3@d=1ol/;2`7oaDE5@KoA4A41_ooool7oa@D50Oo2@T91_l];Bd7oa8B4POo>3Ph
1oo>c/h7o`H61PKo9RHV1_ooool7ocTi>@Oo<30`1olG5aL7oaHF5PKo2@T91ol;2`/7oaXJ6Pcooooo
1olW9bL7ogYjNPOok>c/1om:BTX7ob<S8`OoZJVY1_na/K46ob<S8`Kooooo1ol92@T7ocHf=POo<c<c
1ol];Bd7omGEe@OoF5QH1olM7Ad6oa/K6`Gooooo1om2@T87odM7A`Oo410@1om>CTh7oifMW@OoB4Q8
1olK6a/6oadM7@gooooo000;ooooo`Oo@d=31omJFUX7ofi^KPOoUYJF1on8R8P7ojn_[`Ooa/K61_oa
lO45ooooo`OoBTY:1onl_;`7odi>CPOo0@411ol@4107oalO7`Oo8R8R1_mNGUh6ooooo`Ko<C4a1olT
92@7omOGe`OoE5AD1ol=3@d7ob`/;0Oo5ADE1_m4A4@6ooooo`Oo51@D1ol92@T6obd];@Oo4Q8B1olh
>3P7olk>cPOo1PH61_lV9RH6ooooo`Oo>CTi1ol`<307oaLG5`Oo5QHF1_l92@T7o`/;2`Oo6QXJ3?oo
ool7obLW9`OoNWYj1oo/k>`7odY:BPOo8b<S1onYZJT6ok6a/@Ko8b<S1_ooool7o`T92@Oo=SHf1olc
<c<7obd];@OoeMGE1omHF5P7oadM7@Ko6a/K1Oooool7od92@POoAdM71ol@4107odi>CPOoWIfM1om8
B4P7oa/K6`Ko7AdM3Oooool000_ooooo1om3@d<7oeYJFPOoKVi^1onFUYH7ohR8R0Oo[jn_1oo6a/H6
oo7al@Gooooo1om:BTX7okbl_0OoCTi>1ol10@47oa0@40Oo7alO1olR8R86oeiNGPKooooo1_la<C47
ob@T90OoemOG1omDE5@7o`d=3@Oo;2`/1olE5AD6odA4A0Kooooo1olD51@7o`T92@Ko;Bd]1olB4Q87
ocPh>0Ooc/k>1ol61PH6obHV9PKooooo1oli>CT7oc0`<0Oo5aLG1olF5QH6o`T92@Oo2`/;1olJ6QX<
ooooo`Oo9bLW1omjNWX7onc/k0OoBTY:1olS8b<7ojVYZ@Ko/K6a1_lS8b<6ooooo`Oo2@T91olf=SH7
oc<c<`Oo;Bd]1ooEeMD7oeQHF0Oo7AdM1_lK6a/5ooooo`Oo@T921om7AdL7oa0@40OoCTi>1onMWId7
odQ8B0Oo6a/K1_lM7Ad=ooooo`002oooool7od=3@`OoFUYJ1om^KVh7oiJFUPOoR8R81on_[jl7olK6
aPKolO7a1Oooool7odY:BPOo_;bl1om>CTh7o`410@Oo410@1olO7al7ob8R8PKoGUiN1_ooool6oc4a
<@Oo92@T1ooGemL7oeADE0Oo3@d=1ol/;2`7oaDE5@KoA4A41_ooool7oa@D50Oo2@T91_l];Bd7oa8B
4POo>3Ph1oo>c/h7o`H61PKo9RHV1_ooool7ocTi>@Oo<30`1olG5aL7oaHF5PKo2@T91ol;2`/7oaXJ
6Pcooooo1olW9bL7ogYjNPOok>c/1om:BTX7ob<S8`OoZJVY1_na/K46ob<S8`Kooooo1ol92@T7ocHf
=POo<c<c1ol];Bd7omGEe@OoF5QH1olM7Ad6oa/K6`Gooooo1om2@T87odM7A`Oo410@1om>CTh7oifM
W@OoB4Q81olK6a/6oadM7@gooooo000;ooooo`Oo@d=31omJFUX7ofi^KPOoUYJF1on8R8P7ojn_[`Oo
a/K61_oalO45ooooo`OoBTY:1onl_;`7odi>CPOo0@411ol@4107oalO7`Oo8R8R1_mNGUh6ooooo`Ko
<C4a1olT92@7omOGe`OoE5AD1ol=3@d7ob`/;0Oo5ADE1_m4A4@6ooooo`Oo51@D1ol92@T6obd];@Oo
4Q8B1olh>3P7olk>cPOo1PH61_lV9RH6ooooo`Oo>CTi1ol`<307oaLG5`Oo5QHF1_l92@T7o`/;2`Oo
6QXJ3?ooool7obLW9`OoNWYj1oo/k>`7odY:BPOo8b<S1onYZJT6ok6a/@Ko8b<S1_ooool7o`T92@Oo
=SHf1olc<c<7obd];@OoeMGE1omHF5P7oadM7@Ko6a/K1Oooool7od92@POoAdM71ol@4107odi>CPOo
WIfM1om8B4P7oa/K6`Ko7AdM3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-1.73919, -1.74834, \
0.146455, 0.146455}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-10.5356, \
-1.74834, 0.146455, 0.146455}, {{132, 186.625}, {487.062, 432.438}} -> \
{-19.332, -1.74834, 0.146455, 0.146455}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-28.1376, -1.74834, 0.146455, 0.146455}, {{252.188, 306.812}, \
{487.062, 432.438}} -> {-36.934, -1.74834, 0.146455, 0.146455}, {{312.312, \
366.938}, {487.062, 432.438}} -> {-45.7396, -1.74834, 0.146455, 0.146455}, \
{{372.375, 427}, {487.062, 432.438}} -> {-54.5361, -1.74834, 0.146455, \
0.146455}, {{432.438, 487.062}, {487.062, 432.438}} -> {-63.3325, -1.74834, \
0.146455, 0.146455}, {{11.875, 66.5}, {427, 372.375}} -> {-1.73919, -10.5448, \
0.146455, 0.146455}, {{71.9375, 126.562}, {427, 372.375}} -> {-10.5356, \
-10.5448, 0.146455, 0.146455}, {{132, 186.625}, {427, 372.375}} -> {-19.332, \
-10.5448, 0.146455, 0.146455}, {{192.125, 246.75}, {427, 372.375}} -> \
{-28.1376, -10.5448, 0.146455, 0.146455}, {{252.188, 306.812}, {427, \
372.375}} -> {-36.934, -10.5448, 0.146455, 0.146455}, {{312.312, 366.938}, \
{427, 372.375}} -> {-45.7396, -10.5448, 0.146455, 0.146455}, {{372.375, 427}, \
{427, 372.375}} -> {-54.5361, -10.5448, 0.146455, 0.146455}, {{432.438, \
487.062}, {427, 372.375}} -> {-63.3325, -10.5448, 0.146455, 0.146455}, \
{{11.875, 66.5}, {366.938, 312.312}} -> {-1.73919, -19.3412, 0.146455, \
0.146455}, {{71.9375, 126.562}, {366.938, 312.312}} -> {-10.5356, -19.3412, \
0.146455, 0.146455}, {{132, 186.625}, {366.938, 312.312}} -> {-19.332, \
-19.3412, 0.146455, 0.146455}, {{192.125, 246.75}, {366.938, 312.312}} -> \
{-28.1376, -19.3412, 0.146455, 0.146455}, {{252.188, 306.812}, {366.938, \
312.312}} -> {-36.934, -19.3412, 0.146455, 0.146455}, {{312.312, 366.938}, \
{366.938, 312.312}} -> {-45.7396, -19.3412, 0.146455, 0.146455}, {{372.375, \
427}, {366.938, 312.312}} -> {-54.5361, -19.3412, 0.146455, 0.146455}, \
{{432.438, 487.062}, {366.938, 312.312}} -> {-63.3325, -19.3412, 0.146455, \
0.146455}, {{11.875, 66.5}, {306.812, 252.188}} -> {-1.73919, -28.1468, \
0.146455, 0.146455}, {{71.9375, 126.562}, {306.812, 252.188}} -> {-10.5356, \
-28.1468, 0.146455, 0.146455}, {{132, 186.625}, {306.812, 252.188}} -> \
{-19.332, -28.1468, 0.146455, 0.146455}, {{192.125, 246.75}, {306.812, \
252.188}} -> {-28.1376, -28.1468, 0.146455, 0.146455}, {{252.188, 306.812}, \
{306.812, 252.188}} -> {-36.934, -28.1468, 0.146455, 0.146455}, {{312.312, \
366.938}, {306.812, 252.188}} -> {-45.7396, -28.1468, 0.146455, 0.146455}, \
{{372.375, 427}, {306.812, 252.188}} -> {-54.5361, -28.1468, 0.146455, \
0.146455}, {{432.438, 487.062}, {306.812, 252.188}} -> {-63.3325, -28.1468, \
0.146455, 0.146455}, {{11.875, 66.5}, {246.75, 192.125}} -> {-1.73919, \
-36.9432, 0.146455, 0.146455}, {{71.9375, 126.562}, {246.75, 192.125}} -> \
{-10.5356, -36.9432, 0.146455, 0.146455}, {{132, 186.625}, {246.75, 192.125}} -> \
{-19.332, -36.9432, 0.146455, 0.146455}, {{192.125, 246.75}, {246.75, \
192.125}} -> {-28.1376, -36.9432, 0.146455, 0.146455}, {{252.188, 306.812}, \
{246.75, 192.125}} -> {-36.934, -36.9432, 0.146455, 0.146455}, {{312.312, \
366.938}, {246.75, 192.125}} -> {-45.7396, -36.9432, 0.146455, 0.146455}, \
{{372.375, 427}, {246.75, 192.125}} -> {-54.5361, -36.9432, 0.146455, \
0.146455}, {{432.438, 487.062}, {246.75, 192.125}} -> {-63.3325, -36.9432, \
0.146455, 0.146455}, {{11.875, 66.5}, {186.625, 132}} -> {-1.73919, -45.7488, \
0.146455, 0.146455}, {{71.9375, 126.562}, {186.625, 132}} -> {-10.5356, \
-45.7488, 0.146455, 0.146455}, {{132, 186.625}, {186.625, 132}} -> {-19.332, \
-45.7488, 0.146455, 0.146455}, {{192.125, 246.75}, {186.625, 132}} -> \
{-28.1376, -45.7488, 0.146455, 0.146455}, {{252.188, 306.812}, {186.625, 132}}
   -> {-36.934, -45.7488, 0.146455, 0.146455}, {{312.312, 366.938}, {186.625, \
132}} -> {-45.7396, -45.7488, 0.146455, 0.146455}, {{372.375, 427}, {186.625, \
132}} -> {-54.5361, -45.7488, 0.146455, 0.146455}, {{432.438, 487.062}, \
{186.625, 132}} -> {-63.3325, -45.7488, 0.146455, 0.146455}, {{11.875, 66.5}, \
{126.562, 71.9375}} -> {-1.73919, -54.5452, 0.146455, 0.146455}, {{71.9375, \
126.562}, {126.562, 71.9375}} -> {-10.5356, -54.5452, 0.146455, 0.146455}, \
{{132, 186.625}, {126.562, 71.9375}} -> {-19.332, -54.5452, 0.146455, \
0.146455}, {{192.125, 246.75}, {126.562, 71.9375}} -> {-28.1376, -54.5452, \
0.146455, 0.146455}, {{252.188, 306.812}, {126.562, 71.9375}} -> {-36.934, \
-54.5452, 0.146455, 0.146455}, {{312.312, 366.938}, {126.562, 71.9375}} -> \
{-45.7396, -54.5452, 0.146455, 0.146455}, {{372.375, 427}, {126.562, \
71.9375}} -> {-54.5361, -54.5452, 0.146455, 0.146455}, {{432.438, 487.062}, \
{126.562, 71.9375}} -> {-63.3325, -54.5452, 0.146455, 0.146455}, {{11.875, \
66.5}, {66.5, 11.875}} -> {-1.73919, -63.3416, 0.146455, 0.146455}, \
{{71.9375, 126.562}, {66.5, 11.875}} -> {-10.5356, -63.3416, 0.146455, \
0.146455}, {{132, 186.625}, {66.5, 11.875}} -> {-19.332, -63.3416, 0.146455, \
0.146455}, {{192.125, 246.75}, {66.5, 11.875}} -> {-28.1376, -63.3416, \
0.146455, 0.146455}, {{252.188, 306.812}, {66.5, 11.875}} -> {-36.934, \
-63.3416, 0.146455, 0.146455}, {{312.312, 366.938}, {66.5, 11.875}} -> \
{-45.7396, -63.3416, 0.146455, 0.146455}, {{372.375, 427}, {66.5, 11.875}} -> \
{-54.5361, -63.3416, 0.146455, 0.146455}, {{432.438, 487.062}, {66.5, \
11.875}} -> {-63.3325, -63.3416, 0.146455, 0.146455}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D28445222120021
002F3F5A2919172B
08143B1D2F26231C
1D13220406081644
2C2B2F0B1826293E
4C4F531A162D3278
52C1FF9A47181047
1C2D1C3D27223655
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5C09673B12440D51
991B7488124D0B50
76289B7D16721525
9F2855FF20532837
7F50799F0A6D2E00
774330E20140573F
524F19B6065E671F
48158F610969489A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
331316001E1E0733
233321150F28322C
191D2E2828134230
1A13162D321A4526
0F22141622193A30
4C3B240A2F3B2739
2829301416312525
73191B0E0D2B0DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A0460743004B124C
9B830C30099D0F78
85D8104017964D5D
91C303450A9171A2
59FF004232857387
46A2093C284FC971
1398093255527F42
31360228174C4D0F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
10151F37501F4123
0A12191663433352
000E382A46313E40
2C36275FFFD34F3E
2034312278DB4B49
1B1E1C15483D245C
051C151D4B151A39
2413204F4A57444C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E272C038D11144C
8717431A663A1965
73155110A36E1C13
FF234619A065124F
7F066B2267FC122A
A5012856947C0681
511D72282CE9004F
3400392B252219B8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
12411369352031FF
09350941731B35B8
0628305A4D0E44E3
113F252F8B1A45AF
06293B213C0E5E7B
17381B1858002955
02231E0D330E3D37
271D0B6428071F47
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B6F36052E0B3460
00654F0C512730AC
156A6A09272B3EAF
072D6E14336235FF
0337740E495128B6
131E7B11136938BD
11294F03303E1098
087C350348270330
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F1B0F46335D3D28
0F23303E2A795F22
271C1C463296623F
13041E331C425C31
1B30325A48A36B3E
1400173C24895006
170D253A5AFF7323
1B181D2F273B4626
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
12505E1A3B0D7146
1C4DA5173B057124
3A4EA00E34129039
3449FF174D197B2A
5B3A990C4D287260
401D99002437584C
3E1158103C272476
1E38160738342B37
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A101E1730111E1A
3C0E14051F213644
463F2B1B1625366F
FFCD47111E3235C8
524F413226283051
192529340D001527
271C360204102327
112439371C0F2C55
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5BC513623485A39B
6F9B044F1652FF8D
38DA10413E62AE7B
2F932A352B37BD3D
184B0D294124922A
1D601936271E7C35
104B025A2D004A5D
5B422B3E22907877
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
34761D181D091736
000B041812111929
001907081D16071D
11170A1314131029
13030C11191F192E
0B0114070114101A
0B0C240417282324
5FFF573349242B2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4921932979B31EB9
40157E1C43FB0EA9
4A18753A36970BFF
230A6F18199E0D9A
2C0D5423144400BD
2B1376101D471893
36124A2521370B5E
352C8439687D1759
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36265030476E14F0
1D0E51055A571EFF
5E173400881C01DB
6F12451B902F12C1
BF115130EE71082C
F31D6C2A7E893B38
B70583518BDD3031
6D4698406A6D2CBE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
074E082774173C18
02700E073E233B2F
02910B203F00274D
049D1A093714387B
16882F004C1435AD
04734C206C203BD4
06506E166F262DFF
1034401D56225F5A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F222C0D120E182D
0D13200E0C070010
121D25110B050A19
151712170D12111D
0C1A1F1C080E100D
09121F1508121B16
07172014110F0E18
1F39FF4B25292D48
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
762D4BFF094F3F2E
483F509C023C340B
50241DB9003A5C3C
3A1E1E5F103A4325
6216074901314E30
5E2F24381F4F1D3C
72342144003C2A30
5F35636A234A190F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C0B08171915232F
0200030C15160D30
0E00040910111A17
0C150F090B231339
0B0414090E151721
0C0E0C0D1A140A2D
1E1E130F181A1D29
2E1C3A1A324B2CFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D2D056A041D8D16
422108611C225036
741E0A4B001E1E3B
71701A3D0C402541
6F990A621133345A
6AFF154B254F295A
52E7024C55577F75
517626673C445C2B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3617000E2C68C24F
1A04030A2A376C48
1D0F050F19395A26
170D02122D455B3B
3015020519626129
200603142E546A3B
37270A0F2136493B
2D162C20206AFF68
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A0B130A0E11013A
3B061F1B231A0440
3D061C14243A0817
3E153D0113580021
4513241B32911B2A
2717331C1FFF271A
38172C391F5F0C38
0B111C24273A0701
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
193E1B58A51046FF
1837252AC4082D9D
073A1C137D234948
0D560E0D4E14313D
0076221A3010483B
11831C09250B4C5E
1E8A362C2A12647A
274E3B84841E58D8
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
141C014E15102C80
131D097C0D0020AD
1D3D137036112EFF
0A3A1A755B0B39F0
062E2C68751441E9
09343361711D52F6
0A2A2628671A66B4
0C2E10221B172A2E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
271312021B090C22
0E0E0C0905030514
221416090B0D0C18
1212140C0D12051C
1B160D1211110B1F
10120A0A17050018
120D1211130E0F1E
FF3A35252E332C3A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C102D181A0E143C
120C3F0D00120931
0B0A46171712131B
36176D291D1D0140
1D146179282C0F3C
1F126EFF7B340623
2B35496E2A592022
1B263745272E1A59
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26080A0D070C1042
241305090D09122E
120B10151C09102D
2A17111E1E0A183A
601E171D141417FF
26201213080F0D35
1911020D0A001127
2A1E22171B121030
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4C9719462F123434
50FF1E4645262F2B
37B517448A0E3C25
31971337A7352329
0F7C0828C3122D10
0C3D0025A01F3B13
102C092255245129
4E52103123145116
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0806203E1A110C16
090E08170817131D
04070E1D0E111115
060C091012091522
0C1315130A0E1708
0111000C0D090F22
0D07061311091219
262C28FF363F4224
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B193A2B31FF1A6C
440F4131429E3051
2D00871C083C0A51
2C1C7E3A172B1133
3B16A85E1248031A
4336A670272A1A27
4F1D76F81C72262D
6A1232432D71301B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
394CFF114A209D7A
584BC6035A1D737E
3516A70D6B28688A
19115D18252B3092
2A0E3906312A28B7
140E0C0C4A1900A0
3C2123135321216E
356294335F2A7B59
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
083D01170B1E1B20
0D280A1F14122226
14230014051E1B2C
20140827081D1522
1715042E182B244D
1107154501111756
260D2055140F1AFF
1F290D2B122D3148
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
269B4A7D6A303369
1A5F39605434435B
1FB73B6C55432D67
004A2B67402E242F
273E506B7F315337
46FFA49CC0476D52
3BDD77A0572F4F41
2155405142331B38
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
25068C37174F092B
2B219C621943121A
4C1A63E921470B1A
17309ED614270402
462F3FFF04493941
21222E4D0A393004
660B0E5F002B512E
2B310E2714122517
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28281E170F120F2E
263E281D12082611
2839322623181334
151F30171A0F0F2E
1C392D162F090B37
1D4014210708072C
1014130F13001B10
36512E1D231922FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
450D22280F390B29
441E31180A4D1936
7358311D00473E28
202720380F503933
0B430531212DB33A
00100D2C2E5AFF1C
012A0F121257BD19
342810382B311B2E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
153423366114133E
23171C65BE3B323D
0A191985FF78445A
00021F659A965F4C
19100B42562B4255
101A17405120523F
191A2328322B1F3A
2122205180393B48
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DA152C1F92550E36
FF104218A16A1731
DA0E40336EC1121E
990A2C4468C91A4D
721B3A4339A30A4D
3F0E26161C6A0B52
2200501005440856
6D11353239280F62
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1151303B431F40CE
0F3C4B4C3A1962FF
0B3D4123723443C9
131F451F471C5986
0E201D076A172D64
001D140F3C103247
0941190141052149
0A40242829191E8A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19493A1516074380
0E60340C13082490
1846341C1D263791
0F0B421726052FEC
09215516151C17FF
1A1F3002251E2FD3
1410330040300E53
154422020D2D1C3B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
211119243F897047
0C211515369F532F
130E131745613E32
0E21121240C3421C
00091912494A1C25
090B1A122041411B
0E0014233425474D
2F1C160C27FF402C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C2D1B0037131E47
1444090C2413113D
13412D0D2E152746
124C50052416422F
2F33AF1225185356
305AFF1C34225547
2D3FC719302C6D4F
202246154D1E294C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D1E1E1D2413162D
351B241D2817183F
792E262E1B0F0FFF
2816281B0506084A
131C141B0C020824
1F19120F0A00032F
1B1B080B100C0D32
3620180D0E0E1736
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5DCD36662A8A8B3D
2CB41E582B7BBA22
0B80145D384DFF15
1B4F0280342DFF21
1D400C6E171EA22A
28420E9C000E5664
586005820D253FD2
899A3C4B228A2C38
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
13151F150F11121D
14120F0B0D070C1C
1723120614080B1C
0A210A0A16070815
12180700140C0D1F
11170A0814020614
14171011110D071B
37FF302C533C2E37
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6501471B30B21814
7B0F293B65D5284C
482825283EFF1F5D
26001F0B1C520C51
15004406032E065D
11053635002E0F1D
1E0E5A2A1128032C
7115451063371450
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D08800C371760C8
0007450C1E1E35CE
1C1441153A1A1AC1
3415281160191C75
9D18441F79242E59
EA243C2AD53F415C
FF2C4F20EF6B1A49
6328862C4C297758
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0F4C0D2F381E5022
1C2F0F2922174313
14180D2812053D1A
20260B500C0F2D7E
2234005D140D30B5
1D241744181233FF
163D163D3D1C45B3
2453173338323C50
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A448B741463F4B83
9591CF7763004A5A
AA75E66F583F4331
E892FF807F035F62
E7E4F4633F2F3D74
573F78363107221A
A2479D363C1A485C
41467F332B433B33
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
130446772F271418
0A0E79FF64161337
2528384423301033
310900100E242735
2A0C0D180A181B13
241C150D00192053
2B1A0F150F231E2C
2402233D1E1C132A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17130A0803050B33
1F070A0C05031038
080A100305171244
0D00030B0A000E28
0A070C0F0A0D1225
0C040B0703060F26
0F0905080100091A
38221E32172029FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B1916111A091C26
090C11090010101E
21301B1005052318
274B120E31131415
33FF361924222B20
348953353D260D36
22401A2A40121838
2D29191B14062144
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D0704120C0D1F14
06050603020B130C
170E0E110E102E29
0F0E0A09000B0D13
0D000408090A1517
030A1215020B0B15
0604090B090E0F0D
281B2A302B4AFF2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36051E3A27521433
4A180C251F35353E
841E16272A310011
8B09191822503455
FF2B243324481A47
F46844291C461E4E
B083275815512446
3239204B1F643C2F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
63222718271117FF
2B11341B10171D8F
18181C19150C0927
092225141D000925
030D2023210C0727
1A200C150F1B1223
252E241B241A1E21
372627213D2A2869
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
154413290B1B4D2D
2C2F086B1114455F
162B006D311839D9
1928046A330E2C83
1D3E276762173CFF
16341D51AC1F496E
102D43597D0B3F9D
1A22184752146C33
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3378265E12453C9A
693A501A3D1F577F
346104681E497F9A
5144382C3D00618F
55800B503A6486B7
8C3546336140714C
596A4C42426D6A95
FF9FCFC2604EE248
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
34250F000D071B2A
4B4D5F0009122388
566F85283424474C
36E9FFDB652F502F
2445B5C575333845
12113B5153623653
15355A53993A1D53
2134282F4B323A6A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
260C0D150E131045
1C0A050D14170F71
191512170B141457
2A1810010A0E1F84
1E0C090B0C001249
5012221A18322FFF
251912111E112279
281B1C271618172A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B783E1F0C15112E
93FF50212C17184E
313D29270E181138
0414031A0C080926
090B03060B071520
230809110F170027
1B29072227190E25
312F2A0D1B151435
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0515141A2C0D0E12
07020A14270F1011
0D0A111D1E090B12
0403060F0D05060F
00050C1E140E0414
110606160F0E0A16
0C0C0D171B0E0E15
27192D58FF43252E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26162625A8E1365A
060C1E152B382B26
0400081B272A2B4F
00121F291115262B
010C152A1011261B
0C11260F34342A23
0302171A0F302B0C
423D1B53FFE45533
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C2CBE3F151B1632
170A49403B3A1728
092F453330371F17
02071C21294D312C
001C252532391620
18122414292C1218
230B2418203C1325
3138FF2E31292B34
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C1B080B0F100E26
130C100F0C171320
150C151507000D29
191711130F040F22
150F1A1A1E040038
2E1E111F2F0B1334
65221B323C3028FF
1B17171726182037
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R
1olB4Q87o`0000Ko8B4Q1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A
1_ooool6oc<c<`Oo4a<C1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L7
1om3@d<7o`0000OoBd];1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO
1om1@D46ob<S8`Kooooo1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo
1olB4Q87od51@@Oo4a<C1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D5
1ol^;Rh7o`/;2`Oo=3@d1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB
4Q87o`0000Ko8B4Q1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_oo
ool6oc<c<`Oo4a<C1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3
@d<7o`0000OoBd];1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1
@D46ob<S8`Kooooo1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB
4Q87od51@@Oo4a<C1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^
;Rh7o`/;2`Oo=3@d1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB4Q87
o`0000Ko8B4Q1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_ooool6
oc<c<`Oo4a<C1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3@d<7
o`0000OoBd];1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1@D46
ob<S8`Kooooo1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB4Q87
od51@@Oo4a<C1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^;Rh7
o`/;2`Oo=3@d1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB4Q87o`00
00Ko8B4Q1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_ooool6oc<c
<`Oo4a<C1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3@d<7o`00
00OoBd];1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1@D46ob<S
8`Kooooo1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB4Q87od51
@@Oo4a<C1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^;Rh7o`/;
2`Oo=3@d1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB4Q87o`0000Ko
8B4Q1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_ooool6oc<c<`Oo
4a<C1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3@d<7o`0000Oo
Bd];1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1@D46ob<S8`Ko
oooo1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB4Q87od51@@Oo
4a<C1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^;Rh7o`/;2`Oo
=3@d1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB4Q87o`0000Ko8B4Q
1Oooool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_ooool6oc<c<`Oo4a<C
1olF5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3@d<7o`0000OoBd];
1olB4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1@D46ob<S8`Kooooo
1oln?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB4Q87od51@@Oo4a<C
1omYJFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^;Rh7o`/;2`Oo=3@d
1_mPH60=ooooo`002oooool7o`d=3@Oo:2PX1om4A4@7oe9BDPOo8R8R1olB4Q87o`0000Ko8B4Q1Ooo
ool7oeaLG0Oo2@T91omWIfL7oc/k>`Oo4Q8B1om4A4@7o`d=3@KoDE5A1_ooool6oc<c<`Oo4a<C1olF
5QH7o`0000ko7QhN1ol71`L6oc<c<`Kooooo1onPX:07odI6APKo1`L71om3@d<7o`0000OoBd];1olB
4Q86oda<C0Kooooo1ol@4107oaDE5@Oo7alO1olg=cL6oe1@D0Oo7alO1om1@D46ob<S8`Kooooo1oln
?Sh7obLW9`Oo;2`/1ol30`<7ohf=S@Oo4A4A1_lD51@6oda<C0Kooooo1olB4Q87od51@@Oo4a<C1omY
JFT7ocDe=@Oo820P1ola<C4;ooooo`Oo2`/;1om_Kfl7ocHf=POo1@D51ol^;Rh7o`/;2`Oo=3@d1_mP
H60=ooooo`002oooool7o`0000Oo;bl_1olo?cl7oeYJFPOo:BTY1olI6AT7oaLG5`Ko:b/[1Oooool7
oiVIV@Oo6a/K1omdM7@7ohR8R0Oo4Q8B1om=CDd7o`/;2`KoD51@1_ooool6ob<S8`Oo<c<c1olQ8B47
oaDE5@Oo3`l?1olX:2P7oc8b<PKo;2`/1_ooool7oi^KV`OoPh>31_l<30`7oc0`<0Oo2@T91onMWId7
o`l?3`KoN7Qh1_ooool7o`X:2POo4Q8B1olI6AT7oaHF5PKoHf=S1om3@d<7oc<c<`KoDU9B1_ooool7
ohN7Q`Oo5aLG1om3@d<7oaXJ6POoIVIV1olj>SX6oaTI6@KoIFEU1_ooool7o`T92@Oo=CDe1ol92@T7
od51@@OoLg=c1olK6a/7ocDe=@Ko^;Rh1Oooool7o`0000OoIFEU1om?Cdl7o``<30OoDE5A1olW9bL7
oc0`<0Ko[:b/3Oooool000_ooooo1ol00007obl_;`Oo?clo1omJFUX7obTY:@Oo6ATI1olG5aL6ob/[
:`Gooooo1onIVIT7oa/K6`OoM7Ad1on8R8P7oa8B4POoCDe=1ol;2`/6oe1@D0Kooooo1_lS8b<7oc<c
<`Oo8B4Q1olE5AD7o`l?3`Oo:2PX1olb<S86ob`/;0Kooooo1onKVi/7oh>3P`Ko30`<1ol`<307o`T9
2@OoWIfM1ol?3`l6ogQhN0Kooooo1ol:2PX7oa8B4POo6ATI1olF5QH6of=SH`Oo@d=31olc<c<6oe9B
DPKooooo1on7QhL7oaLG5`Oo@d=31olJ6QX7ofIVIPOo>SXj1_lI6AT6ofEUI@Kooooo1ol92@T7ocDe
=@Oo2@T91om1@D47og=cL`Oo6a/K1ole=CD6okRh^0Gooooo1ol00007ofEUI@OoCdm?1ol<30`7oe5A
D@Oo9bLW1ol`<306ojb/[0gooooo000;ooooo`Oo00001ol_;bl7oclo?`OoFUYJ1olY:BT7oaTI6@Oo
5aLG1_l[:b/5ooooo`OoVIVI1olK6a/7ogAdM0OoR8R81olB4Q87ode=C@Oo2`/;1_m@D506ooooo`Ko
8b<S1olc<c<7ob4Q8@Oo5ADE1ol?3`l7obPX:0Oo<S8b1_l/;2`6ooooo`OoVi^K1on3Ph<6o``<30Oo
<30`1ol92@T7oifMW@Oo3`l?1_mhN7P6ooooo`Oo2PX:1olB4Q87oaTI6@Oo5QHF1_mSHf<7od=3@`Oo
<c<c1_mBDU86ooooo`OoQhN71olG5aL7od=3@`Oo6QXJ1omVIVH7ocXj>PKo6ATI1_mUIFD6ooooo`Oo
2@T91ole=CD7o`T92@Oo@D511omcLg<7oa/K6`Oo=CDe1_nh^;P5ooooo`Oo00001omUIFD7odm?C`Oo
30`<1omADE47obLW9`Oo<30`1_n/[:`=ooooo`002oooool7o`0000Oo;bl_1olo?cl7oeYJFPOo:BTY
1olI6AT7oaLG5`Ko:b/[1Oooool7oiVIV@Oo6a/K1omdM7@7ohR8R0Oo4Q8B1om=CDd7o`/;2`KoD51@
1_ooool6ob<S8`Oo<c<c1olQ8B47oaDE5@Oo3`l?1olX:2P7oc8b<PKo;2`/1_ooool7oi^KV`OoPh>3
1_l<30`7oc0`<0Oo2@T91onMWId7o`l?3`KoN7Qh1_ooool7o`X:2POo4Q8B1olI6AT7oaHF5PKoHf=S
1om3@d<7oc<c<`KoDU9B1_ooool7ohN7Q`Oo5aLG1om3@d<7oaXJ6POoIVIV1olj>SX6oaTI6@KoIFEU
1_ooool7o`T92@Oo=CDe1ol92@T7od51@@OoLg=c1olK6a/7ocDe=@Ko^;Rh1Oooool7o`0000OoIFEU
1om?Cdl7o``<30OoDE5A1olW9bL7oc0`<0Ko[:b/3Oooool000_ooooo1ol00007obl_;`Oo?clo1omJ
FUX7obTY:@Oo6ATI1olG5aL6ob/[:`Gooooo1onIVIT7oa/K6`OoM7Ad1on8R8P7oa8B4POoCDe=1ol;
2`/6oe1@D0Kooooo1_lS8b<7oc<c<`Oo8B4Q1olE5AD7o`l?3`Oo:2PX1olb<S86ob`/;0Kooooo1onK
Vi/7oh>3P`Ko30`<1ol`<307o`T92@OoWIfM1ol?3`l6ogQhN0Kooooo1ol:2PX7oa8B4POo6ATI1olF
5QH6of=SH`Oo@d=31olc<c<6oe9BDPKooooo1on7QhL7oaLG5`Oo@d=31olJ6QX7ofIVIPOo>SXj1_lI
6AT6ofEUI@Kooooo1ol92@T7ocDe=@Oo2@T91om1@D47og=cL`Oo6a/K1ole=CD6okRh^0Gooooo1ol0
0007ofEUI@OoCdm?1ol<30`7oe5AD@Oo9bLW1ol`<306ojb/[0gooooo000;ooooo`Oo00001ol_;bl7
oclo?`OoFUYJ1olY:BT7oaTI6@Oo5aLG1_l[:b/5ooooo`OoVIVI1olK6a/7ogAdM0OoR8R81olB4Q87
ode=C@Oo2`/;1_m@D506ooooo`Ko8b<S1olc<c<7ob4Q8@Oo5ADE1ol?3`l7obPX:0Oo<S8b1_l/;2`6
ooooo`OoVi^K1on3Ph<6o``<30Oo<30`1ol92@T7oifMW@Oo3`l?1_mhN7P6ooooo`Oo2PX:1olB4Q87
oaTI6@Oo5QHF1_mSHf<7od=3@`Oo<c<c1_mBDU86ooooo`OoQhN71olG5aL7od=3@`Oo6QXJ1omVIVH7
ocXj>PKo6ATI1_mUIFD6ooooo`Oo2@T91ole=CD7o`T92@Oo@D511omcLg<7oa/K6`Oo=CDe1_nh^;P5
ooooo`Oo00001omUIFD7odm?C`Oo30`<1omADE47obLW9`Oo<30`1_n/[:`=ooooo`002oooool7o`00
00Oo;bl_1olo?cl7oeYJFPOo:BTY1olI6AT7oaLG5`Ko:b/[1Oooool7oiVIV@Oo6a/K1omdM7@7ohR8
R0Oo4Q8B1om=CDd7o`/;2`KoD51@1_ooool6ob<S8`Oo<c<c1olQ8B47oaDE5@Oo3`l?1olX:2P7oc8b
<PKo;2`/1_ooool7oi^KV`OoPh>31_l<30`7oc0`<0Oo2@T91onMWId7o`l?3`KoN7Qh1_ooool7o`X:
2POo4Q8B1olI6AT7oaHF5PKoHf=S1om3@d<7oc<c<`KoDU9B1_ooool7ohN7Q`Oo5aLG1om3@d<7oaXJ
6POoIVIV1olj>SX6oaTI6@KoIFEU1_ooool7o`T92@Oo=CDe1ol92@T7od51@@OoLg=c1olK6a/7ocDe
=@Ko^;Rh1Oooool7o`0000OoIFEU1om?Cdl7o``<30OoDE5A1olW9bL7oc0`<0Ko[:b/3Oooool000_o
oooo1ol820P7oa@D50Oo>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0Oo
Vi^K1ommOGd7oaHF5POoLW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo
@T921_l`<306ooooo`OoQHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo
00001ol>3Ph7ocPh>0Oo:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo
410@1onSXj<7ofi^KPKo71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POo
A4A41_oShn<5ooooo`Oo5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo
1ol820P7oa@D50Oo>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K
1ommOGd7oaHF5POoLW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T92
1_l`<306ooooo`OoQHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo0000
1ol>3Ph7ocPh>0Oo:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@
1onSXj<7ofi^KPKo71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A4
1_oShn<5ooooo`Oo5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1ol8
20P7oa@D50Oo>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K1omm
OGd7oaHF5POoLW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T921_l`
<306ooooo`OoQHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo00001ol>
3Ph7ocPh>0Oo:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@1onS
Xj<7ofi^KPKo71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A41_oS
hn<5ooooo`Oo5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1ol820P7
oa@D50Oo>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K1ommOGd7
oaHF5POoLW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T921_l`<306
ooooo`OoQHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo00001ol>3Ph7
ocPh>0Oo:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@1onSXj<7
ofi^KPKo71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A41_oShn<5
ooooo`Oo5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1ol820P7oa@D
50Oo>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K1ommOGd7oaHF
5POoLW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T921_l`<306oooo
o`OoQHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo00001ol>3Ph7ocPh
>0Oo:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@1onSXj<7ofi^
KPKo71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A41_oShn<5oooo
o`Oo5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1ol820P7oa@D50Oo
>c/k1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K1ommOGd7oaHF5POo
LW9b1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T921_l`<306ooooo`Oo
QHF51ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo00001ol>3Ph7ocPh>0Oo
:RXZ1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@1onSXj<7ofi^KPKo
71`L1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A41_oShn<5ooooo`Oo
5ADE3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1ol820P7oa@D50Oo>c/k
1olM7Ad7obl_;`Oo9RHV1olS8b<6oa`L70Gooooo1omfMWH7obPX:0OoVi^K1ommOGd7oaHF5POoLW9b
1olE5AD6obDU9@Kooooo1_lI6AT7oadM7@Oo;Rh^3_lX:2P7oa<C4`Oo@T921_l`<306ooooo`OoQHF5
1ooHf=P6oa0@40Oo@4101olG5aL7oiJFUPOoCDe=1_mMGEd6ooooo`Oo00001ol>3Ph7ocPh>0Oo:RXZ
1_m6ATH7oc4a<@Oo?Shn1_m0@406ooooo`OoLg=c1olE5AD7oe5AD@Oo410@1onSXj<7ofi^KPKo71`L
1_lC4a<6ooooo`Oo1PH61olX:2P7oc0`<0OoFUYJ1om=CDd7o`h>3POoA4A41_oShn<5ooooo`Oo5ADE
3_mZJVX7o`T92@Oo9bLW1ol[:b/7ochn?PKo[jn_3Oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol4
10@7o`H61POo20P81olF5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX
:2P6ocLg=`Kooooo1_lJ6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onA
TI47ol?3``Ko0`<31om5ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omO
Gel6ooooo`Oodm?C1om?Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?
Cdl6ooooo`Oo4A4A1olo?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol]
;Bd7ofi^KPOo51@D1olc<c<7of9RHPOo=CDe4oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol410@7
o`H61POo20P81olF5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX:2P6
ocLg=`Kooooo1_lJ6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onATI47
ol?3``Ko0`<31om5ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omOGel6
ooooo`Oodm?C1om?Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?Cdl6
ooooo`Oo4A4A1olo?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol];Bd7
ofi^KPOo51@D1olc<c<7of9RHPOo=CDe4oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol410@7o`H6
1POo20P81olF5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX:2P6ocLg
=`Kooooo1_lJ6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onATI47ol?3
``Ko0`<31om5ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omOGel6oooo
o`Oodm?C1om?Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?Cdl6oooo
o`Oo4A4A1olo?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol];Bd7ofi^
KPOo51@D1olc<c<7of9RHPOo=CDe4oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol410@7o`H61POo
20P81olF5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX:2P6ocLg=`Ko
oooo1_lJ6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onATI47ol?3``Ko
0`<31om5ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omOGel6ooooo`Oo
dm?C1om?Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?Cdl6ooooo`Oo
4A4A1olo?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol];Bd7ofi^KPOo
51@D1olc<c<7of9RHPOo=CDe4oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol410@7o`H61POo20P8
1olF5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX:2P6ocLg=`Kooooo
1_lJ6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onATI47ol?3``Ko0`<3
1om5ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omOGel6ooooo`Oodm?C
1om?Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?Cdl6ooooo`Oo4A4A
1olo?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol];Bd7ofi^KPOo51@D
1olc<c<7of9RHPOo=CDe4oooool000_ooooo1olM7Ad7oa<C4`Oo8R8R1ol410@7o`H61POo20P81olF
5QH6odA4A0Gooooo1onOWil7obPX:0OoEEEE1oooool7ob0P80OoDe=C1olX:2P6ocLg=`Kooooo1_lJ
6QX7oa<C4`Oo5QHF1ol];Bd7oc8b<POo6QXJ1om5ADD6obHV9PKooooo1onATI47ol?3``Ko0`<31om5
ADD7o`X:2POoTI6A1omaLG46oj:RXPKooooo1ol/;2`7ocHf=POo9bLW1omOGel6ooooo`Oodm?C1om?
Cdl6ochn?Pgooooo1olS8b<7odI6APOo6ATI1onPX:07ofEUI@Ko4Q8B1_m?Cdl6ooooo`Oo4A4A1olo
?cl7obDU9@Oo;bl_1on;Rh/7oaXJ6POoADE51_n_[jl5ooooo`Oo1`L71ol];Bd7ofi^KPOo51@D1olc
<c<7of9RHPOo=CDe4oooool000_ooooo1ol/;2`7ob/[:`Oo;bl_1ol;2`/7oaPH60Oo9RHV1olY:BT6
ochn?PGooooo1omoOgl7oe1@D0OoNGUi1onOWil7o`X:2POoKFe]1ol^;Rh6o`0000Kooooo1_l?3`l7
ob8R8POo51@D1olF5QH7ob8R8POo6ATI1olj>SX6oc0`<0Kooooo1omIFET7ooooo`Ko00001om2@T87
oc8b<POoQHF51omcLg<6ohN7Q`Kooooo1olP8207oc@d=0Oo<C4a1olR8R86ogQhN0Oofm_K1om;Bd/6
odU9B@Kooooo1omoOgl7o`H61POoJf][1olR8R87ofMWI`Ooo?cl1_lB4Q86obXZ:PKooooo1ol61PH7
obTY:@Oo>c/k1olQ8B47oc`l?0Oo3Ph>1omNGUh6og]kN`Gooooo1ol30`<7ocLg=`OoM7Ad1ol>3Ph7
odU9B@OoDE5A1olX:2P6okJf]Pgooooo000;ooooo`Oo;2`/1ol[:b/7obl_;`Oo2`/;1olH61P7obHV
9POo:BTY1_ln?Sh5ooooo`OoOgmo1om@D507ogUiN@OoWinO1ol:2PX7ofe]K@Oo;Rh^1_l00006oooo
o`Ko3`l?1olR8R87oa@D50Oo5QHF1olR8R87oaTI6@Oo>SXj1_l`<306ooooo`OoFEUI1oooool6o`00
00Oo@T921olb<S87ohF5Q@OoLg=c1_n7QhL6ooooo`Oo820P1old=3@7oc4a<@Oo8R8R1_mhN7P7om_K
f`OoBd];1_m9BDT6ooooo`OoOgmo1ol61PH7of][J`Oo8R8R1omWIfL7ooclo0Ko4Q8B1_lZ:RX6oooo
o`Oo1PH61olY:BT7oc/k>`Oo8B4Q1oll?3`7o`h>3POoGUiN1_mkNg/5ooooo`Oo0`<31olg=cL7ogAd
M0Oo3Ph>1om9BDT7oe5AD@Oo:2PX1_nf][H=ooooo`002oooool7ob`/;0Oo:b/[1ol_;bl7o`/;2`Oo
61PH1olV9RH7obTY:@Ko?Shn1Oooool7ogmoO`OoD51@1omiNGT7oinOW`Oo2PX:1om]KFd7obh^;PKo
00001_ooool6o`l?3`Oo8R8R1olD51@7oaHF5POo8R8R1olI6AT7ocXj>PKo<30`1_ooool7oeUIF@Oo
oooo1_l00007od92@POo<S8b1on5QHD7og=cL`KoQhN71_ooool7ob0P80Oo=3@d1ola<C47ob8R8PKo
N7Qh1ooKfm/7od];B`KoBDU91_ooool7ogmoO`Oo1PH61om[Jf/7ob8R8POoIfMW1oolo?`6oa8B4PKo
:RXZ1_ooool7o`H61POo:BTY1olk>c/7ob4Q8@Oo?3`l1ol>3Ph7oeiNGPKoNg]k1Oooool7o`<30`Oo
=cLg1omdM7@7o`h>3POoBDU91omADE47obPX:0Ko][Jf3Oooool000_ooooo1ol/;2`7ob/[:`Oo;bl_
1ol;2`/7oaPH60Oo9RHV1olY:BT6ochn?PGooooo1omoOgl7oe1@D0OoNGUi1onOWil7o`X:2POoKFe]
1ol^;Rh6o`0000Kooooo1_l?3`l7ob8R8POo51@D1olF5QH7ob8R8POo6ATI1olj>SX6oc0`<0Kooooo
1omIFET7ooooo`Ko00001om2@T87oc8b<POoQHF51omcLg<6ohN7Q`Kooooo1olP8207oc@d=0Oo<C4a
1olR8R86ogQhN0Oofm_K1om;Bd/6odU9B@Kooooo1omoOgl7o`H61POoJf][1olR8R87ofMWI`Ooo?cl
1_lB4Q86obXZ:PKooooo1ol61PH7obTY:@Oo>c/k1olQ8B47oc`l?0Oo3Ph>1omNGUh6og]kN`Gooooo
1ol30`<7ocLg=`OoM7Ad1ol>3Ph7odU9B@OoDE5A1olX:2P6okJf]Pgooooo000;ooooo`Oo;2`/1ol[
:b/7obl_;`Oo2`/;1olH61P7obHV9POo:BTY1_ln?Sh5ooooo`OoOgmo1om@D507ogUiN@OoWinO1ol:
2PX7ofe]K@Oo;Rh^1_l00006ooooo`Ko3`l?1olR8R87oa@D50Oo5QHF1olR8R87oaTI6@Oo>SXj1_l`
<306ooooo`OoFEUI1oooool6o`0000Oo@T921olb<S87ohF5Q@OoLg=c1_n7QhL6ooooo`Oo820P1old
=3@7oc4a<@Oo8R8R1_mhN7P7om_Kf`OoBd];1_m9BDT6ooooo`OoOgmo1ol61PH7of][J`Oo8R8R1omW
IfL7ooclo0Ko4Q8B1_lZ:RX6ooooo`Oo1PH61olY:BT7oc/k>`Oo8B4Q1oll?3`7o`h>3POoGUiN1_mk
Ng/5ooooo`Oo0`<31olg=cL7ogAdM0Oo3Ph>1om9BDT7oe5AD@Oo:2PX1_nf][H=ooooo`002oooool7
ob`/;0Oo:b/[1ol_;bl7o`/;2`Oo61PH1olV9RH7obTY:@Ko?Shn1Oooool7ogmoO`OoD51@1omiNGT7
oinOW`Oo2PX:1om]KFd7obh^;PKo00001_ooool6o`l?3`Oo8R8R1olD51@7oaHF5POo8R8R1olI6AT7
ocXj>PKo<30`1_ooool7oeUIF@Oooooo1_l00007od92@POo<S8b1on5QHD7og=cL`KoQhN71_ooool7
ob0P80Oo=3@d1ola<C47ob8R8PKoN7Qh1ooKfm/7od];B`KoBDU91_ooool7ogmoO`Oo1PH61om[Jf/7
ob8R8POoIfMW1oolo?`6oa8B4PKo:RXZ1_ooool7o`H61POo:BTY1olk>c/7ob4Q8@Oo?3`l1ol>3Ph7
oeiNGPKoNg]k1Oooool7o`<30`Oo=cLg1omdM7@7o`h>3POoBDU91omADE47obPX:0Ko][Jf3Oooool0
00_ooooo1ol/;2`7ob/[:`Oo;bl_1ol;2`/7oaPH60Oo9RHV1olY:BT6ochn?PGooooo1omoOgl7oe1@
D0OoNGUi1onOWil7o`X:2POoKFe]1ol^;Rh6o`0000Kooooo1_l?3`l7ob8R8POo51@D1olF5QH7ob8R
8POo6ATI1olj>SX6oc0`<0Kooooo1omIFET7ooooo`Ko00001om2@T87oc8b<POoQHF51omcLg<6ohN7
Q`Kooooo1olP8207oc@d=0Oo<C4a1olR8R86ogQhN0Oofm_K1om;Bd/6odU9B@Kooooo1omoOgl7o`H6
1POoJf][1olR8R87ofMWI`Ooo?cl1_lB4Q86obXZ:PKooooo1ol61PH7obTY:@Oo>c/k1olQ8B47oc`l
?0Oo3Ph>1omNGUh6og]kN`Gooooo1ol30`<7ocLg=`OoM7Ad1ol>3Ph7odU9B@OoDE5A1olX:2P6okJf
]Pgooooo000;ooooo`OoC4a<1om?Cdl7oe=CD`Oo6QXJ1olF5QH7obd];@Oo<S8b1_mhN7P5ooooo`Oo
MgMg1om3@d<7oc0`<0Ooh^;R1ol10@47od10@0OoEeMG1_lo?cl6ooooo`KoC4a<1olk>c/7ob@T90Oo
2PX:1ol_;bl7oc/k>`Oo9bLW1_li>CT6ooooo`OoATI61onRXZ86o`T92@Oo?3`l1olX:2P7odm?C`Oo
bLW91_maLG46ooooo`Oo6a/K1olN7Qh7oa`L70Oo5ADE1_m8B4P7ocdm?@Oo92@T1_mLG5`6ooooo`Oo
YJFU1ol10@47obPX:0OoEUIF1onDU9@7ogalO0Ko1PH61_n1PH46ooooo`Oo5aLG1olh>3P7oa/K6`Oo
61PH1omHF5P7o`0000Oo:BTY1_mEEED5ooooo`Oo4a<C1olN7Qh7og]kN`Oo4A4A1olC4a<7ofUYJ@Oo
>3Ph1_nm_Kd=ooooo`002oooool7oda<C0OoCdm?1omCDe<7oaXJ6POo5QHF1ol];Bd7oc8b<PKoN7Qh
1Oooool7ogMgM`Oo@d=31ol`<307on;RhPOo0@411om0@407oeMGE`Ko?clo1_ooool6oda<C0Oo>c/k
1olT92@7o`X:2POo;bl_1olk>c/7obLW9`Ko>CTi1_ooool7odI6APOoXZ:R1_l92@T7oc`l?0Oo:2PX
1om?Cdl7olW9b@KoLG5a1_ooool7oa/K6`Oo7QhN1olL71`7oaDE5@KoB4Q81olm?Cd7ob@T90KoG5aL
1_ooool7ojFUY@Oo0@411olX:2P7oeIFEPOoU9BD1omlO7`6o`H61PKoPH611_ooool7oaLG5`Oo>3Ph
1olK6a/7oaPH60OoF5QH1ol00007obTY:@KoEEEE1Oooool7oa<C4`Oo7QhN1omkNg/7oa4A4@Oo4a<C
1omYJFT7ocPh>0Ko_Kfm3Oooool000_ooooo1om<C4`7odm?C`OoDe=C1olJ6QX7oaHF5POo;Bd]1olb
<S86ogQhN0Gooooo1omgMgL7od=3@`Oo<30`1ooRh^87o`410@Oo@4101omGEeL6oclo?`Kooooo1_m<
C4`7oc/k>`Oo92@T1ol:2PX7obl_;`Oo>c/k1olW9bL6ocTi>@Kooooo1om6ATH7oj:RXPKo2@T91oll
?3`7obPX:0OoCdm?1oo9bLT6og5aL@Kooooo1olK6a/7oahN7POo71`L1olE5AD6odQ8B0Oo?Cdm1olT
92@6oeaLG0Kooooo1onUYJD7o`410@Oo:2PX1omFEUH7oiBDU0OoO7al1_l61PH6oh61P@Kooooo1olG
5aL7ocPh>0Oo6a/K1olH61P7oeQHF0Oo00001olY:BT6oeEEE@Gooooo1olC4a<7oahN7POoNg]k1olA
4A47oa<C4`OoJFUY1olh>3P6okfm_@gooooo000;ooooo`OoC4a<1om?Cdl7oe=CD`Oo6QXJ1olF5QH7
obd];@Oo<S8b1_mhN7P5ooooo`OoMgMg1om3@d<7oc0`<0Ooh^;R1ol10@47od10@0OoEeMG1_lo?cl6
ooooo`KoC4a<1olk>c/7ob@T90Oo2PX:1ol_;bl7oc/k>`Oo9bLW1_li>CT6ooooo`OoATI61onRXZ86
o`T92@Oo?3`l1olX:2P7odm?C`OobLW91_maLG46ooooo`Oo6a/K1olN7Qh7oa`L70Oo5ADE1_m8B4P7
ocdm?@Oo92@T1_mLG5`6ooooo`OoYJFU1ol10@47obPX:0OoEUIF1onDU9@7ogalO0Ko1PH61_n1PH46
ooooo`Oo5aLG1olh>3P7oa/K6`Oo61PH1omHF5P7o`0000Oo:BTY1_mEEED5ooooo`Oo4a<C1olN7Qh7
og]kN`Oo4A4A1olC4a<7ofUYJ@Oo>3Ph1_nm_Kd=ooooo`002oooool7oda<C0OoCdm?1omCDe<7oaXJ
6POo5QHF1ol];Bd7oc8b<PKoN7Qh1Oooool7ogMgM`Oo@d=31ol`<307on;RhPOo0@411om0@407oeMG
E`Ko?clo1_ooool6oda<C0Oo>c/k1olT92@7o`X:2POo;bl_1olk>c/7obLW9`Ko>CTi1_ooool7odI6
APOoXZ:R1_l92@T7oc`l?0Oo:2PX1om?Cdl7olW9b@KoLG5a1_ooool7oa/K6`Oo7QhN1olL71`7oaDE
5@KoB4Q81olm?Cd7ob@T90KoG5aL1_ooool7ojFUY@Oo0@411olX:2P7oeIFEPOoU9BD1omlO7`6o`H6
1PKoPH611_ooool7oaLG5`Oo>3Ph1olK6a/7oaPH60OoF5QH1ol00007obTY:@KoEEEE1Oooool7oa<C
4`Oo7QhN1omkNg/7oa4A4@Oo4a<C1omYJFT7ocPh>0Ko_Kfm3Oooool000_ooooo1om<C4`7odm?C`Oo
De=C1olJ6QX7oaHF5POo;Bd]1olb<S86ogQhN0Gooooo1omgMgL7od=3@`Oo<30`1ooRh^87o`410@Oo
@4101omGEeL6oclo?`Kooooo1_m<C4`7oc/k>`Oo92@T1ol:2PX7obl_;`Oo>c/k1olW9bL6ocTi>@Ko
oooo1om6ATH7oj:RXPKo2@T91oll?3`7obPX:0OoCdm?1oo9bLT6og5aL@Kooooo1olK6a/7oahN7POo
71`L1olE5AD6odQ8B0Oo?Cdm1olT92@6oeaLG0Kooooo1onUYJD7o`410@Oo:2PX1omFEUH7oiBDU0Oo
O7al1_l61PH6oh61P@Kooooo1olG5aL7ocPh>0Oo6a/K1olH61P7oeQHF0Oo00001olY:BT6oeEEE@Go
oooo1olC4a<7oahN7POoNg]k1olA4A47oa<C4`OoJFUY1olh>3P6okfm_@gooooo000;ooooo`OoC4a<
1om?Cdl7oe=CD`Oo6QXJ1olF5QH7obd];@Oo<S8b1_mhN7P5ooooo`OoMgMg1om3@d<7oc0`<0Ooh^;R
1ol10@47od10@0OoEeMG1_lo?cl6ooooo`KoC4a<1olk>c/7ob@T90Oo2PX:1ol_;bl7oc/k>`Oo9bLW
1_li>CT6ooooo`OoATI61onRXZ86o`T92@Oo?3`l1olX:2P7odm?C`OobLW91_maLG46ooooo`Oo6a/K
1olN7Qh7oa`L70Oo5ADE1_m8B4P7ocdm?@Oo92@T1_mLG5`6ooooo`OoYJFU1ol10@47obPX:0OoEUIF
1onDU9@7ogalO0Ko1PH61_n1PH46ooooo`Oo5aLG1olh>3P7oa/K6`Oo61PH1omHF5P7o`0000Oo:BTY
1_mEEED5ooooo`Oo4a<C1olN7Qh7og]kN`Oo4A4A1olC4a<7ofUYJ@Oo>3Ph1_nm_Kd=ooooo`002ooo
ool7oe9BDPOo`L711oooool7oiZJVPOoAdM71olH61P7oa0@40KoAdM71Oooool7oe9BDPOoCdm?1olI
6AT7okJf]POo1PH61omNGUh7ofMWI`Ko7alO1_ooool6obPX:0Oo:BTY1ol`<307oa@D50Oo5QHF1ola
<C4=obDU9@Kooooo1olC4a<7oiRHV0Ko2@T91olb<S87oeEEE@OoDU9B1omoOgl6od92@PKooooo1ol5
1@D7oa`L70Oo5ADE1olM7Ad6od];B`Oo5ADE1olJ6QX6ocTi>@Kooooo1omADE47oadM7@OoLW9b1olX
:2P7ob`/;0OojNWY1_l00006odm?C`Kooooo1ol20P87ob<S8`Oo7QhN1ol=3@d7oc<c<`Oo3Ph>1olm
?Cd6ocLg=`Gooooo1olA4A47obTY:@OoCdm?1ol30`<7oc0`<0Oo?Shn1ol@4106oiRHV0gooooo000;
ooooo`OoDU9B1oo1`L47ooooo`OoVYZJ1om7AdL7oaPH60Oo410@1_m7AdL5ooooo`OoDU9B1om?Cdl7
oaTI6@Oo][Jf1ol61PH7oeiNGPOoIfMW1_lO7al6ooooo`Ko:2PX1olY:BT7oc0`<0Oo51@D1olF5QH7
oc4a<@go9BDU1_ooool7oa<C4`OoV9RH1_l92@T7oc8b<POoEEEE1omBDU87ogmoO`Ko@T921_ooool7
o`D51@Oo71`L1olE5AD7oadM7@KoBd];1olE5AD7oaXJ6PKo>CTi1_ooool7oe5AD@Oo7AdM1ombLW87
obPX:0Oo;2`/1ooYjNT6o`0000KoCdm?1_ooool7o`820POo8b<S1olN7Qh7o`d=3@Oo<c<c1ol>3Ph7
ocdm?@Ko=cLg1Oooool7oa4A4@Oo:BTY1om?Cdl7o`<30`Oo<30`1oln?Sh7oa0@40KoV9RH3Oooool0
00_ooooo1omBDU87ol71`@Oooooo1onJVYX7odM7A`Oo61PH1ol@4106odM7A`Gooooo1omBDU87odm?
C`Oo6ATI1onf][H7o`H61POoGUiN1omWIfL6oalO7`Kooooo1_lX:2P7obTY:@Oo<30`1olD51@7oaHF
5POo<C4a3OlU9BD6ooooo`Oo4a<C1onHV9P6o`T92@Oo<S8b1omEEED7oe9BDPOoOgmo1_m2@T86oooo
o`Oo1@D51olL71`7oaDE5@Oo7AdM1_m;Bd/7oaDE5@Oo6QXJ1_li>CT6ooooo`OoDE5A1olM7Ad7og9b
LPOo:2PX1ol/;2`7onWYj@Ko00001_m?Cdl6ooooo`Oo0P821olS8b<7oahN7POo3@d=1olc<c<7o`h>
3POo?Cdm1_lg=cL5ooooo`Oo4A4A1olY:BT7odm?C`Oo0`<31ol`<307ochn?POo410@1_nHV9P=oooo
o`002oooool7oe9BDPOo`L711oooool7oiZJVPOoAdM71olH61P7oa0@40KoAdM71Oooool7oe9BDPOo
Cdm?1olI6AT7okJf]POo1PH61omNGUh7ofMWI`Ko7alO1_ooool6obPX:0Oo:BTY1ol`<307oa@D50Oo
5QHF1ola<C4=obDU9@Kooooo1olC4a<7oiRHV0Ko2@T91olb<S87oeEEE@OoDU9B1omoOgl6od92@PKo
oooo1ol51@D7oa`L70Oo5ADE1olM7Ad6od];B`Oo5ADE1olJ6QX6ocTi>@Kooooo1omADE47oadM7@Oo
LW9b1olX:2P7ob`/;0OojNWY1_l00006odm?C`Kooooo1ol20P87ob<S8`Oo7QhN1ol=3@d7oc<c<`Oo
3Ph>1olm?Cd6ocLg=`Gooooo1olA4A47obTY:@OoCdm?1ol30`<7oc0`<0Oo?Shn1ol@4106oiRHV0go
oooo000;ooooo`OoDU9B1oo1`L47ooooo`OoVYZJ1om7AdL7oaPH60Oo410@1_m7AdL5ooooo`OoDU9B
1om?Cdl7oaTI6@Oo][Jf1ol61PH7oeiNGPOoIfMW1_lO7al6ooooo`Ko:2PX1olY:BT7oc0`<0Oo51@D
1olF5QH7oc4a<@go9BDU1_ooool7oa<C4`OoV9RH1_l92@T7oc8b<POoEEEE1omBDU87ogmoO`Ko@T92
1_ooool7o`D51@Oo71`L1olE5AD7oadM7@KoBd];1olE5AD7oaXJ6PKo>CTi1_ooool7oe5AD@Oo7AdM
1ombLW87obPX:0Oo;2`/1ooYjNT6o`0000KoCdm?1_ooool7o`820POo8b<S1olN7Qh7o`d=3@Oo<c<c
1ol>3Ph7ocdm?@Ko=cLg1Oooool7oa4A4@Oo:BTY1om?Cdl7o`<30`Oo<30`1oln?Sh7oa0@40KoV9RH
3Oooool000_ooooo1omBDU87ol71`@Oooooo1onJVYX7odM7A`Oo61PH1ol@4106odM7A`Gooooo1omB
DU87odm?C`Oo6ATI1onf][H7o`H61POoGUiN1omWIfL6oalO7`Kooooo1_lX:2P7obTY:@Oo<30`1olD
51@7oaHF5POo<C4a3OlU9BD6ooooo`Oo4a<C1onHV9P6o`T92@Oo<S8b1omEEED7oe9BDPOoOgmo1_m2
@T86ooooo`Oo1@D51olL71`7oaDE5@Oo7AdM1_m;Bd/7oaDE5@Oo6QXJ1_li>CT6ooooo`OoDE5A1olM
7Ad7og9bLPOo:2PX1ol/;2`7onWYj@Ko00001_m?Cdl6ooooo`Oo0P821olS8b<7oahN7POo3@d=1olc
<c<7o`h>3POo?Cdm1_lg=cL5ooooo`Oo4A4A1olY:BT7odm?C`Oo0`<31ol`<307ochn?POo410@1_nH
V9P=ooooo`002oooool7oa`L70Oo;Bd]1olL71`7ocdm?@Oo9bLW1olR8R87ocHf=PKoEEEE1Oooool7
odQ8B0Oo5ADE1on?Shl7of5QH@Oo2@T91omYJFT7odQ8B0KoVYZJ1_ooool6og=cL`Oo6ATI1olK6a/7
o`h>3POo3@d=1ol[:b/7o`d=3@cooooo1ola<C47ocHf=PKo0P821olX:2P7oaLG5`OoC4a<1om=CDd6
o`l?3`Kooooo1olT92@7oa<C4`Oo820P1om?Cdl6odY:BPOoEeMG1om4A4@6oda<C0Kooooo1old=3@7
o`0000Oo>CTi1ol[:b/7obDU9@Oo8R8R1_lI6AT6okRh^0Kooooo1olW9bL7oadM7@Oo2`/;1omTI6@7
obPX:0Oo1`L71olO7al6odM7A`Gooooo1ol820P7ogalO0Oo=CDe1ol30`<7odQ8B0Oo9bLW1ol30`<6
oc0`<0gooooo000;ooooo`Oo71`L1ol];Bd7oa`L70Oo?Cdm1olW9bL7ob8R8POo=SHf1_mEEED5oooo
o`OoB4Q81olE5AD7ohn?S`OoHF5Q1ol92@T7ofUYJ@OoB4Q81_nJVYX6ooooo`KoLg=c1olI6AT7oa/K
6`Oo3Ph>1ol=3@d7ob/[:`Oo3@d=3?ooool7oc4a<@Oo=SHf1_l20P87obPX:0Oo5aLG1om<C4`7ode=
C@Ko3`l?1_ooool7ob@T90Oo4a<C1olP8207odm?C`KoBTY:1omGEeL7odA4A0KoC4a<1_ooool7oc@d
=0Oo00001oli>CT7ob/[:`Oo9BDU1olR8R86oaTI6@Ko^;Rh1_ooool7obLW9`Oo7AdM1ol;2`/7ofAT
I0Oo:2PX1ol71`L7oalO7`KoAdM71Oooool7o`P820OoO7al1ole=CD7o`<30`OoB4Q81olW9bL7o`<3
0`Ko<30`3Oooool000_ooooo1olL71`7obd];@Oo71`L1olm?Cd7obLW9`Oo8R8R1olf=SH6oeEEE@Go
oooo1om8B4P7oaDE5@OoShn?1omQHF47o`T92@OoJFUY1om8B4P6oiZJVPKooooo1_mcLg<7oaTI6@Oo
6a/K1ol>3Ph7o`d=3@Oo:b/[1ol=3@d<ooooo`Oo<C4a1olf=SH6o`820POo:2PX1olG5aL7oda<C0Oo
CDe=1_l?3`l6ooooo`Oo92@T1olC4a<7ob0P80OoCdm?1_m:BTX7oeMGE`OoA4A41_m<C4`6ooooo`Oo
=3@d1ol00007ocTi>@Oo:b/[1olU9BD7ob8R8PKo6ATI1_nh^;P6ooooo`Oo9bLW1olM7Ad7o`/;2`Oo
I6AT1olX:2P7o`L71`Oo7alO1_m7AdL5ooooo`Oo20P81omlO7`7ocDe=@Oo0`<31om8B4P7obLW9`Oo
0`<31_l`<30=ooooo`002oooool7oa`L70Oo;Bd]1olL71`7ocdm?@Oo9bLW1olR8R87ocHf=PKoEEEE
1Oooool7odQ8B0Oo5ADE1on?Shl7of5QH@Oo2@T91omYJFT7odQ8B0KoVYZJ1_ooool6og=cL`Oo6ATI
1olK6a/7o`h>3POo3@d=1ol[:b/7o`d=3@cooooo1ola<C47ocHf=PKo0P821olX:2P7oaLG5`OoC4a<
1om=CDd6o`l?3`Kooooo1olT92@7oa<C4`Oo820P1om?Cdl6odY:BPOoEeMG1om4A4@6oda<C0Kooooo
1old=3@7o`0000Oo>CTi1ol[:b/7obDU9@Oo8R8R1_lI6AT6okRh^0Kooooo1olW9bL7oadM7@Oo2`/;
1omTI6@7obPX:0Oo1`L71olO7al6odM7A`Gooooo1ol820P7ogalO0Oo=CDe1ol30`<7odQ8B0Oo9bLW
1ol30`<6oc0`<0gooooo000;ooooo`Oo71`L1ol];Bd7oa`L70Oo?Cdm1olW9bL7ob8R8POo=SHf1_mE
EED5ooooo`OoB4Q81olE5AD7ohn?S`OoHF5Q1ol92@T7ofUYJ@OoB4Q81_nJVYX6ooooo`KoLg=c1olI
6AT7oa/K6`Oo3Ph>1ol=3@d7ob/[:`Oo3@d=3?ooool7oc4a<@Oo=SHf1_l20P87obPX:0Oo5aLG1om<
C4`7ode=C@Ko3`l?1_ooool7ob@T90Oo4a<C1olP8207odm?C`KoBTY:1omGEeL7odA4A0KoC4a<1_oo
ool7oc@d=0Oo00001oli>CT7ob/[:`Oo9BDU1olR8R86oaTI6@Ko^;Rh1_ooool7obLW9`Oo7AdM1ol;
2`/7ofATI0Oo:2PX1ol71`L7oalO7`KoAdM71Oooool7o`P820OoO7al1ole=CD7o`<30`OoB4Q81olW
9bL7o`<30`Ko<30`3Oooool000_ooooo1olL71`7obd];@Oo71`L1olm?Cd7obLW9`Oo8R8R1olf=SH6
oeEEE@Gooooo1om8B4P7oaDE5@OoShn?1omQHF47o`T92@OoJFUY1om8B4P6oiZJVPKooooo1_mcLg<7
oaTI6@Oo6a/K1ol>3Ph7o`d=3@Oo:b/[1ol=3@d<ooooo`Oo<C4a1olf=SH6o`820POo:2PX1olG5aL7
oda<C0OoCDe=1_l?3`l6ooooo`Oo92@T1olC4a<7ob0P80OoCdm?1_m:BTX7oeMGE`OoA4A41_m<C4`6
ooooo`Oo=3@d1ol00007ocTi>@Oo:b/[1olU9BD7ob8R8PKo6ATI1_nh^;P6ooooo`Oo9bLW1olM7Ad7
o`/;2`OoI6AT1olX:2P7o`L71`Oo7alO1_m7AdL5ooooo`Oo20P81omlO7`7ocDe=@Oo0`<31om8B4P7
obLW9`Oo0`<31_l`<30=ooooo`002oooool7oa`L70Oo;Bd]1olL71`7ocdm?@Oo9bLW1olR8R87ocHf
=PKoEEEE1Oooool7odQ8B0Oo5ADE1on?Shl7of5QH@Oo2@T91omYJFT7odQ8B0KoVYZJ1_ooool6og=c
L`Oo6ATI1olK6a/7o`h>3POo3@d=1ol[:b/7o`d=3@cooooo1ola<C47ocHf=PKo0P821olX:2P7oaLG
5`OoC4a<1om=CDd6o`l?3`Kooooo1olT92@7oa<C4`Oo820P1om?Cdl6odY:BPOoEeMG1om4A4@6oda<
C0Kooooo1old=3@7o`0000Oo>CTi1ol[:b/7obDU9@Oo8R8R1_lI6AT6okRh^0Kooooo1olW9bL7oadM
7@Oo2`/;1omTI6@7obPX:0Oo1`L71olO7al6odM7A`Gooooo1ol820P7ogalO0Oo=CDe1ol30`<7odQ8
B0Oo9bLW1ol30`<6oc0`<0gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003o
ooooooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`Oo3`l?1olK6a/7o`l?3`OoATI6
1olc<c<7oeeMG@Oo?Cdm1_lX:2P5ooooo`Oo4Q8B1om@D507oeiNGPOo6QXJ1olk>c/7o`d=3@OoLG5a
1_m6ATH6ooooo`Ko2PX:1ol@4107oahN7POo5aLG1ol`<307oa4A4@Oo7QhN1_lJ6QX6ooooo`OoFe]K
1oo5aLD6oa<C4`OoHV9R1old=3@7ohF5Q@OoXj>S1_nKVi/6ooooo`Oo=3@d1omfMWH7oadM7@Oo61PH
1_lM7Ad7o`T92@Oo5aLG1_lf=SH6ooooo`OoBDU91olQ8B47oi>CT`Oo:BTY1omiNGT7ok>c/`Ko7QhN
1_ni^KT6ooooo`Oo=SHf1olV9RH7oe1@D0Oo<30`1om7AdL7ofi^KPOo51@D1_o`l?05ooooo`Oo1`L7
1om>CTh7o`P820Oo9bLW1omdM7@7oaLG5`Oo?3`l1_lH61P=ooooo`002oooool7o`l?3`Oo6a/K1ol?
3`l7odI6APOo<c<c1omMGEd7ocdm?@Ko:2PX1Oooool7oa8B4POoD51@1omNGUh7oaXJ6POo>c/k1ol=
3@d7og5aL@KoATI61_ooool6o`X:2POo410@1olN7Qh7oaLG5`Oo<30`1olA4A47oahN7PKo6QXJ1_oo
ool7oe]KF`OoaLG51_lC4a<7of9RHPOo=3@d1on5QHD7oj>SX`KoVi^K1_ooool7oc@d=0OoMWIf1olM
7Ad7oaPH60Ko7AdM1ol92@T7oaLG5`Ko=SHf1_ooool7odU9B@Oo8B4Q1onCTi<7obTY:@OoNGUi1onc
/k<6oahN7PKo^KVi1_ooool7ocHf=POo9RHV1om@D507oc0`<0OoAdM71om^KVh7oa@D50Kol?3`1Ooo
ool7o`L71`OoCTi>1ol820P7obLW9`OoM7Ad1olG5aL7oc`l?0Ko61PH3Oooool000_ooooo1ol?3`l7
oa/K6`Oo3`l?1om6ATH7oc<c<`OoGEeM1olm?Cd6obPX:0Gooooo1olB4Q87oe1@D0OoGUiN1olJ6QX7
oc/k>`Oo3@d=1omaLG46odI6APKooooo1_l:2PX7oa0@40Oo7QhN1olG5aL7oc0`<0Oo4A4A1olN7Qh6
oaXJ6PKooooo1omKFe/7olG5a@Ko4a<C1omRHV87oc@d=0OoQHF51onSXj<6oi^KV`Kooooo1old=3@7
ogIfMPOo7AdM1olH61P6oadM7@Oo2@T91olG5aL6ocHf=PKooooo1om9BDT7ob4Q8@OoTi>C1olY:BT7
ogUiN@Oo/k>c1_lN7Qh6okVi^@Kooooo1olf=SH7obHV9POoD51@1ol`<307odM7A`OoKVi^1olD51@6
oo3`l0Gooooo1ol71`L7odi>CPOo20P81olW9bL7ogAdM0Oo5aLG1oll?3`6oaPH60gooooo000;oooo
o`Oo3`l?1olK6a/7o`l?3`OoATI61olc<c<7oeeMG@Oo?Cdm1_lX:2P5ooooo`Oo4Q8B1om@D507oeiN
GPOo6QXJ1olk>c/7o`d=3@OoLG5a1_m6ATH6ooooo`Ko2PX:1ol@4107oahN7POo5aLG1ol`<307oa4A
4@Oo7QhN1_lJ6QX6ooooo`OoFe]K1oo5aLD6oa<C4`OoHV9R1old=3@7ohF5Q@OoXj>S1_nKVi/6oooo
o`Oo=3@d1omfMWH7oadM7@Oo61PH1_lM7Ad7o`T92@Oo5aLG1_lf=SH6ooooo`OoBDU91olQ8B47oi>C
T`Oo:BTY1omiNGT7ok>c/`Ko7QhN1_ni^KT6ooooo`Oo=SHf1olV9RH7oe1@D0Oo<30`1om7AdL7ofi^
KPOo51@D1_o`l?05ooooo`Oo1`L71om>CTh7o`P820Oo9bLW1omdM7@7oaLG5`Oo?3`l1_lH61P=oooo
o`002oooool7o`l?3`Oo6a/K1ol?3`l7odI6APOo<c<c1omMGEd7ocdm?@Ko:2PX1Oooool7oa8B4POo
D51@1omNGUh7oaXJ6POo>c/k1ol=3@d7og5aL@KoATI61_ooool6o`X:2POo410@1olN7Qh7oaLG5`Oo
<30`1olA4A47oahN7PKo6QXJ1_ooool7oe]KF`OoaLG51_lC4a<7of9RHPOo=3@d1on5QHD7oj>SX`Ko
Vi^K1_ooool7oc@d=0OoMWIf1olM7Ad7oaPH60Ko7AdM1ol92@T7oaLG5`Ko=SHf1_ooool7odU9B@Oo
8B4Q1onCTi<7obTY:@OoNGUi1onc/k<6oahN7PKo^KVi1_ooool7ocHf=POo9RHV1om@D507oc0`<0Oo
AdM71om^KVh7oa@D50Kol?3`1Oooool7o`L71`OoCTi>1ol820P7obLW9`OoM7Ad1olG5aL7oc`l?0Ko
61PH3Oooool000_ooooo1ol?3`l7oa/K6`Oo3`l?1om6ATH7oc<c<`OoGEeM1olm?Cd6obPX:0Gooooo
1olB4Q87oe1@D0OoGUiN1olJ6QX7oc/k>`Oo3@d=1omaLG46odI6APKooooo1_l:2PX7oa0@40Oo7QhN
1olG5aL7oc0`<0Oo4A4A1olN7Qh6oaXJ6PKooooo1omKFe/7olG5a@Ko4a<C1omRHV87oc@d=0OoQHF5
1onSXj<6oi^KV`Kooooo1old=3@7ogIfMPOo7AdM1olH61P6oadM7@Oo2@T91olG5aL6ocHf=PKooooo
1om9BDT7ob4Q8@OoTi>C1olY:BT7ogUiN@Oo/k>c1_lN7Qh6okVi^@Kooooo1olf=SH7obHV9POoD51@
1ol`<307odM7A`OoKVi^1olD51@6oo3`l0Gooooo1ol71`L7odi>CPOo20P81olW9bL7ogAdM0Oo5aLG
1oll?3`6oaPH60gooooo000;ooooo`Oo3`l?1olK6a/7o`l?3`OoATI61olc<c<7oeeMG@Oo?Cdm1_lX
:2P5ooooo`Oo4Q8B1om@D507oeiNGPOo6QXJ1olk>c/7o`d=3@OoLG5a1_m6ATH6ooooo`Ko2PX:1ol@
4107oahN7POo5aLG1ol`<307oa4A4@Oo7QhN1_lJ6QX6ooooo`OoFe]K1oo5aLD6oa<C4`OoHV9R1old
=3@7ohF5Q@OoXj>S1_nKVi/6ooooo`Oo=3@d1omfMWH7oadM7@Oo61PH1_lM7Ad7o`T92@Oo5aLG1_lf
=SH6ooooo`OoBDU91olQ8B47oi>CT`Oo:BTY1omiNGT7ok>c/`Ko7QhN1_ni^KT6ooooo`Oo=SHf1olV
9RH7oe1@D0Oo<30`1om7AdL7ofi^KPOo51@D1_o`l?05ooooo`Oo1`L71om>CTh7o`P820Oo9bLW1omd
M7@7oaLG5`Oo?3`l1_lH61P=ooooo`002oooool7o`l?3`Oo8b<S1ol`<307ochn?POo:RXZ1omiNGT7
oemOG`Ko8R8R1Oooool7oa`L70OoCDe=1onUYJD7oaLG5`Oo>c/k1ol51@D7og5aL@Ko92@T1_ooool6
oc`l?0Oo3Ph>1olD51@7o`D51@Oo7alO1olQ8B47ocHf=PKoA4A41_ooool7ofm_K`OoVi^K1_l410@7
odm?C`Oo5QHF1omBDU87ooooo`KoSHf=1_ooool7o`0000Oo2`/;1ol410@7oaPH60Ko4Q8B1olA4A47
oaTI6@Ko:BTY1_ooool7od10@0Oo5ADE1omnOWh7oa`L70Oo@d=31ookno/6o`h>3PKoZJVY1_ooool7
oadM7@Oo3Ph>1omADE47o`D51@OoFUYJ1omGEeL7oahN7P_ooooo1ol20P87og1`L0Oo3Ph>1ol71`L7
ochn?POo8b<S1olk>c/6obl_;`gooooo000;ooooo`Oo3`l?1olS8b<7oc0`<0Oo?Shn1olZ:RX7ogUi
N@OoGemO1_lR8R85ooooo`Oo71`L1om=CDd7ojFUY@Oo5aLG1olk>c/7o`D51@OoLG5a1_lT92@6oooo
o`Ko?3`l1ol>3Ph7oa@D50Oo1@D51olO7al7ob4Q8@Oo=SHf1_m4A4@6ooooo`OoKfm_1onKVi/6o`@4
10OoCdm?1olF5QH7oe9BDPOooooo1_n=SHd6ooooo`Oo00001ol;2`/7o`@410Oo61PH1_lB4Q87oa4A
4@Oo6ATI1_lY:BT6ooooo`Oo@4101olE5AD7oginOPOo71`L1om3@d<7oo_kn`Ko3Ph>1_nYZJT6oooo
o`Oo7AdM1ol>3Ph7oe5AD@Oo1@D51omJFUX7oeMGE`Oo7QhN2oooool7o`820POoL71`1ol>3Ph7o`L7
1`Oo?Shn1olS8b<7oc/k>`Ko;bl_3Oooool000_ooooo1ol?3`l7ob<S8`Oo<30`1oln?Sh7obXZ:POo
NGUi1omOGel6ob8R8PGooooo1olL71`7ode=C@OoYJFU1olG5aL7oc/k>`Oo1@D51omaLG46ob@T90Ko
oooo1_ll?3`7o`h>3POo51@D1ol51@D7oalO7`Oo8B4Q1olf=SH6odA4A0Kooooo1om_Kfl7oi^KV`Ko
10@41om?Cdl7oaHF5POoDU9B1oooool6ohf=S@Kooooo1ol00007o`/;2`Oo10@41olH61P6oa8B4POo
4A4A1olI6AT6obTY:@Kooooo1om0@407oaDE5@OoOWin1olL71`7od=3@`Oono_k1_l>3Ph6ojVYZ@Ko
oooo1olM7Ad7o`h>3POoDE5A1ol51@D7oeYJFPOoEeMG1olN7Qh;ooooo`Oo0P821om`L707o`h>3POo
1`L71oln?Sh7ob<S8`Oo>c/k1_l_;bl=ooooo`002oooool7o`l?3`Oo8b<S1ol`<307ochn?POo:RXZ
1omiNGT7oemOG`Ko8R8R1Oooool7oa`L70OoCDe=1onUYJD7oaLG5`Oo>c/k1ol51@D7og5aL@Ko92@T
1_ooool6oc`l?0Oo3Ph>1olD51@7o`D51@Oo7alO1olQ8B47ocHf=PKoA4A41_ooool7ofm_K`OoVi^K
1_l410@7odm?C`Oo5QHF1omBDU87ooooo`KoSHf=1_ooool7o`0000Oo2`/;1ol410@7oaPH60Ko4Q8B
1olA4A47oaTI6@Ko:BTY1_ooool7od10@0Oo5ADE1omnOWh7oa`L70Oo@d=31ookno/6o`h>3PKoZJVY
1_ooool7oadM7@Oo3Ph>1omADE47o`D51@OoFUYJ1omGEeL7oahN7P_ooooo1ol20P87og1`L0Oo3Ph>
1ol71`L7ochn?POo8b<S1olk>c/6obl_;`gooooo000;ooooo`Oo3`l?1olS8b<7oc0`<0Oo?Shn1olZ
:RX7ogUiN@OoGemO1_lR8R85ooooo`Oo71`L1om=CDd7ojFUY@Oo5aLG1olk>c/7o`D51@OoLG5a1_lT
92@6ooooo`Ko?3`l1ol>3Ph7oa@D50Oo1@D51olO7al7ob4Q8@Oo=SHf1_m4A4@6ooooo`OoKfm_1onK
Vi/6o`@410OoCdm?1olF5QH7oe9BDPOooooo1_n=SHd6ooooo`Oo00001ol;2`/7o`@410Oo61PH1_lB
4Q87oa4A4@Oo6ATI1_lY:BT6ooooo`Oo@4101olE5AD7oginOPOo71`L1om3@d<7oo_kn`Ko3Ph>1_nY
ZJT6ooooo`Oo7AdM1ol>3Ph7oe5AD@Oo1@D51omJFUX7oeMGE`Oo7QhN2oooool7o`820POoL71`1ol>
3Ph7o`L71`Oo?Shn1olS8b<7oc/k>`Ko;bl_3Oooool000_ooooo1ol?3`l7ob<S8`Oo<30`1oln?Sh7
obXZ:POoNGUi1omOGel6ob8R8PGooooo1olL71`7ode=C@OoYJFU1olG5aL7oc/k>`Oo1@D51omaLG46
ob@T90Kooooo1_ll?3`7o`h>3POo51@D1ol51@D7oalO7`Oo8B4Q1olf=SH6odA4A0Kooooo1om_Kfl7
oi^KV`Ko10@41om?Cdl7oaHF5POoDU9B1oooool6ohf=S@Kooooo1ol00007o`/;2`Oo10@41olH61P6
oa8B4POo4A4A1olI6AT6obTY:@Kooooo1om0@407oaDE5@OoOWin1olL71`7od=3@`Oono_k1_l>3Ph6
ojVYZ@Kooooo1olM7Ad7o`h>3POoDE5A1ol51@D7oeYJFPOoEeMG1olN7Qh;ooooo`Oo0P821om`L707
o`h>3POo1`L71oln?Sh7ob<S8`Oo>c/k1_l_;bl=ooooo`002oooool7o`l?3`Oo8b<S1ol`<307ochn
?POo:RXZ1omiNGT7oemOG`Ko8R8R1Oooool7oa`L70OoCDe=1onUYJD7oaLG5`Oo>c/k1ol51@D7og5a
L@Ko92@T1_ooool6oc`l?0Oo3Ph>1olD51@7o`D51@Oo7alO1olQ8B47ocHf=PKoA4A41_ooool7ofm_
K`OoVi^K1_l410@7odm?C`Oo5QHF1omBDU87ooooo`KoSHf=1_ooool7o`0000Oo2`/;1ol410@7oaPH
60Ko4Q8B1olA4A47oaTI6@Ko:BTY1_ooool7od10@0Oo5ADE1omnOWh7oa`L70Oo@d=31ookno/6o`h>
3PKoZJVY1_ooool7oadM7@Oo3Ph>1omADE47o`D51@OoFUYJ1omGEeL7oahN7P_ooooo1ol20P87og1`
L0Oo3Ph>1ol71`L7ochn?POo8b<S1olk>c/6obl_;`gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo
<S8b1onFUYH7of9RHPKo?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko
>CTi1_ooool6odI6APOo?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oo
f][J1_l@4107od51@@Oo?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko
7AdM1olF5QH7o`L71`Ko7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`co
oooo1omNGUh7oaLG5`Oo=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo
2`/;1olP8207oclo?`Oo00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b
1onFUYH7of9RHPKo?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi
1_ooool6odI6APOo?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J
1_l@4107od51@@Oo?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM
1olF5QH7o`L71`Ko7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo
1omNGUh7oaLG5`Oo=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;
1olP8207oclo?`Oo00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b1onF
UYH7of9RHPKo?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi1_oo
ool6odI6APOo?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J1_l@
4107od51@@Oo?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM1olF
5QH7o`L71`Ko7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo1omN
GUh7oaLG5`Oo=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;1olP
8207oclo?`Oo00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b1onFUYH7
of9RHPKo?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi1_ooool6
odI6APOo?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J1_l@4107
od51@@Oo?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM1olF5QH7
o`L71`Ko7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo1omNGUh7
oaLG5`Oo=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;1olP8207
oclo?`Oo00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b1onFUYH7of9R
HPKo?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi1_ooool6odI6
APOo?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J1_l@4107od51
@@Oo?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM1olF5QH7o`L7
1`Ko7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo1omNGUh7oaLG
5`Oo=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;1olP8207oclo
?`Oo00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b1onFUYH7of9RHPKo
?clo1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi1_ooool6odI6APOo
?clo1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J1_l@4107od51@@Oo
?Shn1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM1olF5QH7o`L71`Ko
7AdM1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo1omNGUh7oaLG5`Oo
=3@d1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;1olP8207oclo?`Oo
00001olW9bL6ode=C@gooooo000;ooooo`Oo9bLW3_lL71`7odI6APOo<S8b1onFUYH7of9RHPKo?clo
1Oooool7ocXj>POoCTi>1onPX:07o`h>3POo=3@d1olB4Q87oi2@T0Ko>CTi1_ooool6odI6APOo?clo
1ol[:b/7oa/K6`Oo5QHF1olU9BD7ocHf=PKoKfm_1_ooool7ocPh>0Oof][J1_l@4107od51@@Oo?Shn
1omRHV87ojj^[PKoNg]k1_ooool7o`0000Oo6ATI1ol71`L7o`P820Ko7AdM1olF5QH7o`L71`Ko7AdM
1_ooool7odY:BPOo61PH1omeMGD7ocXj>POo=SHf1onGUiL6o`/;2`cooooo1omNGUh7oaLG5`Oo=3@d
1ol00007ohR8R0Oo71`L1ol10@46om_Kf`Gooooo1ol20P87oi6AT@Oo2`/;1olP8207oclo?`Oo0000
1olW9bL6ode=C@gooooo000;ooooo`Oo4a<C1ol410@7oahN7POo<c<c1olL71`7od92@POoG5aL1_la
<C45ooooo`Oo=3@d1om9BDT7ooooo`Oo5aLG1om=CDd7oaTI6@OoNg]k1_lZ:RX<ooooo`OocLg=1om7
AdL7oa4A4@Oo7QhN1olb<S87ocDe=@Kob<S81_ooool7obl_;`OoTi>C1_lZ:RX7ocDe=@Oo:b/[1olg
=cL7okfm_@Ko?Cdm1_ooool7oa4A4@Oo5aLG1ol:2PX7oa<C4`Ko51@D1olC4a<7oa0@40Ko:BTY1_oo
ool7ob<S8`Oo2PX:1om_Kfl7oaPH60Oo6ATI1onNWYh6o`d=3@KoVYZJ1_ooool7ofm_K`Oo4Q8B1om5
ADD7oa/K6`OoT92@1ol_;bl7oa8B4PKo`L711Oooool7o`@410OoWIfM1olJ6QX7o`T92@Oo=cLg1olD
51@7ocPh>0KoNg]k3Oooool000_ooooo1olC4a<7o`@410Oo7QhN1olc<c<7oa`L70Oo@T921omLG5`6
oc4a<@Gooooo1old=3@7odU9B@Oooooo1olG5aL7ode=C@Oo6ATI1omkNg/6obXZ:Pcooooo1oo=cLd7
odM7A`Oo4A4A1olN7Qh7oc8b<POo=CDe1_o8b<P6ooooo`Oo;bl_1onCTi<6obXZ:POo=CDe1ol[:b/7
ocLg=`Oo_Kfm1_lm?Cd6ooooo`Oo4A4A1olG5aL7o`X:2POo4a<C1_lD51@7oa<C4`Oo410@1_lY:BT6
ooooo`Oo8b<S1ol:2PX7ofm_K`Oo61PH1olI6AT7oijNWPKo3@d=1_nJVYX6ooooo`OoKfm_1olB4Q87
odE5A@Oo6a/K1on@T907obl_;`Oo4Q8B1_o1`L45ooooo`Oo10@41onMWId7oaXJ6POo2@T91olg=cL7
oa@D50Oo>3Ph1_mkNg/=ooooo`002oooool7oa<C4`Oo10@41olN7Qh7oc<c<`Oo71`L1om2@T87oeaL
G0Ko<C4a1Oooool7oc@d=0OoBDU91oooool7oaLG5`OoCDe=1olI6AT7og]kN`Ko:RXZ3?ooool7olg=
c@OoAdM71olA4A47oahN7POo<S8b1ole=CD6olS8b0Kooooo1ol_;bl7oi>CT`Ko:RXZ1ole=CD7ob/[
:`Oo=cLg1onm_Kd6ocdm?@Kooooo1olA4A47oaLG5`Oo2PX:1olC4a<6oa@D50Oo4a<C1ol@4106obTY
:@Kooooo1olS8b<7o`X:2POoKfm_1olH61P7oaTI6@OoWYjN1_l=3@d6oiZJVPKooooo1om_Kfl7oa8B
4POoADE51olK6a/7oi2@T0Oo;bl_1olB4Q86ol71`@Gooooo1ol410@7oifMW@Oo6QXJ1ol92@T7ocLg
=`Oo51@D1olh>3P6og]kN`gooooo000;ooooo`Oo4a<C1ol410@7oahN7POo<c<c1olL71`7od92@POo
G5aL1_la<C45ooooo`Oo=3@d1om9BDT7ooooo`Oo5aLG1om=CDd7oaTI6@OoNg]k1_lZ:RX<ooooo`Oo
cLg=1om7AdL7oa4A4@Oo7QhN1olb<S87ocDe=@Kob<S81_ooool7obl_;`OoTi>C1_lZ:RX7ocDe=@Oo
:b/[1olg=cL7okfm_@Ko?Cdm1_ooool7oa4A4@Oo5aLG1ol:2PX7oa<C4`Ko51@D1olC4a<7oa0@40Ko
:BTY1_ooool7ob<S8`Oo2PX:1om_Kfl7oaPH60Oo6ATI1onNWYh6o`d=3@KoVYZJ1_ooool7ofm_K`Oo
4Q8B1om5ADD7oa/K6`OoT92@1ol_;bl7oa8B4PKo`L711Oooool7o`@410OoWIfM1olJ6QX7o`T92@Oo
=cLg1olD51@7ocPh>0KoNg]k3Oooool000_ooooo1olC4a<7o`@410Oo7QhN1olc<c<7oa`L70Oo@T92
1omLG5`6oc4a<@Gooooo1old=3@7odU9B@Oooooo1olG5aL7ode=C@Oo6ATI1omkNg/6obXZ:Pcooooo
1oo=cLd7odM7A`Oo4A4A1olN7Qh7oc8b<POo=CDe1_o8b<P6ooooo`Oo;bl_1onCTi<6obXZ:POo=CDe
1ol[:b/7ocLg=`Oo_Kfm1_lm?Cd6ooooo`Oo4A4A1olG5aL7o`X:2POo4a<C1_lD51@7oa<C4`Oo410@
1_lY:BT6ooooo`Oo8b<S1ol:2PX7ofm_K`Oo61PH1olI6AT7oijNWPKo3@d=1_nJVYX6ooooo`OoKfm_
1olB4Q87odE5A@Oo6a/K1on@T907obl_;`Oo4Q8B1_o1`L45ooooo`Oo10@41onMWId7oaXJ6POo2@T9
1olg=cL7oa@D50Oo>3Ph1_mkNg/=ooooo`002oooool7oa<C4`Oo10@41olN7Qh7oc<c<`Oo71`L1om2
@T87oeaLG0Ko<C4a1Oooool7oc@d=0OoBDU91oooool7oaLG5`OoCDe=1olI6AT7og]kN`Ko:RXZ3?oo
ool7olg=c@OoAdM71olA4A47oahN7POo<S8b1ole=CD6olS8b0Kooooo1ol_;bl7oi>CT`Ko:RXZ1ole
=CD7ob/[:`Oo=cLg1onm_Kd6ocdm?@Kooooo1olA4A47oaLG5`Oo2PX:1olC4a<6oa@D50Oo4a<C1ol@
4106obTY:@Kooooo1olS8b<7o`X:2POoKfm_1olH61P7oaTI6@OoWYjN1_l=3@d6oiZJVPKooooo1om_
Kfl7oa8B4POoADE51olK6a/7oi2@T0Oo;bl_1olB4Q86ol71`@Gooooo1ol410@7oifMW@Oo6QXJ1ol9
2@T7ocLg=`Oo51@D1olh>3P6og]kN`gooooo000;ooooo`Oo6a/K1ol`<307oc8b<POoFUYJ1om8B4P7
oj>SX`OoJf][1_ln?Sh5ooooo`OoFe]K1olj>SX7oiVIV@Oo30`<1om=CDd7obPX:0OoLW9b1_mPH606
ooooo`KoDU9B1om?Cdl7od51@@Oo<S8b1olV9RH7obPX:0Oo<30`1_mADE46ooooo`Oo61PH1om;Bd/6
o`d=3@Oo:BTY1om1@D47ob@T90OoTY:B1_lZ:RX6ooooo`Oo4a<C1ol30`<7o``<30Oo4A4A1_lI6AT7
oalO7`Oo6ATI1_l^;Rh6ooooo`Oo;2`/1ol=3@d7oeADE0Oo8b<S1olD51@7odA4A0Ko00001_nm_Kd6
ooooo`Oo_kno1olA4A47oe5AD@Oo<30`1oo^k^h7og5aL@Oo20P81_l/;2`5ooooo`Oo5QHF1on8R8P7
obl_;`Oo00001om<C4`7oa@D50Oo=CDe1_n][Jd=ooooo`002oooool7oa/K6`Oo<30`1olb<S87oeYJ
FPOoB4Q81onSXj<7of][J`Ko?Shn1Oooool7oe]KF`Oo>SXj1onIVIT7o``<30OoCDe=1olX:2P7og9b
LPKoH61P1_ooool6oe9BDPOoCdm?1om1@D47oc8b<POo9RHV1olX:2P7oc0`<0KoDE5A1_ooool7oaPH
60OoBd];1_l=3@d7obTY:@Oo@D511olT92@7oi:BTPKo:RXZ1_ooool7oa<C4`Oo0`<31ol<30`7oa4A
4@Ko6ATI1olO7al7oaTI6@Ko;Rh^1_ooool7ob`/;0Oo3@d=1omDE5@7ob<S8`Oo51@D1om4A4@6o`00
00Ko_Kfm1_ooool7okno_`Oo4A4A1omADE47oc0`<0Ook^k^1omaLG47o`P820Ko;2`/1Oooool7oaHF
5POoR8R81ol_;bl7o`0000OoC4a<1olD51@7ocDe=@Ko[Jf]3Oooool000_ooooo1olK6a/7oc0`<0Oo
<S8b1omJFUX7odQ8B0OoXj>S1om[Jf/6ochn?PGooooo1omKFe/7ocXj>POoVIVI1ol<30`7ode=C@Oo
:2PX1ombLW86of1PH0Kooooo1_mBDU87odm?C`Oo@D511olb<S87obHV9POo:2PX1ol`<306oe5AD@Ko
oooo1olH61P7od];B`Ko3@d=1olY:BT7od51@@Oo92@T1onBTY86obXZ:PKooooo1olC4a<7o`<30`Oo
30`<1olA4A46oaTI6@Oo7alO1olI6AT6obh^;PKooooo1ol/;2`7o`d=3@OoE5AD1olS8b<7oa@D50Oo
A4A41_l00006okfm_@Kooooo1ono_kl7oa4A4@OoDE5A1ol`<307onk^kPOoLG5a1ol820P6ob`/;0Go
oooo1olF5QH7ohR8R0Oo;bl_1ol00007oda<C0Oo51@D1ole=CD6ojf][@gooooo000;ooooo`Oo6a/K
1ol`<307oc8b<POoFUYJ1om8B4P7oj>SX`OoJf][1_ln?Sh5ooooo`OoFe]K1olj>SX7oiVIV@Oo30`<
1om=CDd7obPX:0OoLW9b1_mPH606ooooo`KoDU9B1om?Cdl7od51@@Oo<S8b1olV9RH7obPX:0Oo<30`
1_mADE46ooooo`Oo61PH1om;Bd/6o`d=3@Oo:BTY1om1@D47ob@T90OoTY:B1_lZ:RX6ooooo`Oo4a<C
1ol30`<7o``<30Oo4A4A1_lI6AT7oalO7`Oo6ATI1_l^;Rh6ooooo`Oo;2`/1ol=3@d7oeADE0Oo8b<S
1olD51@7odA4A0Ko00001_nm_Kd6ooooo`Oo_kno1olA4A47oe5AD@Oo<30`1oo^k^h7og5aL@Oo20P8
1_l/;2`5ooooo`Oo5QHF1on8R8P7obl_;`Oo00001om<C4`7oa@D50Oo=CDe1_n][Jd=ooooo`002ooo
ool7oa/K6`Oo<30`1olb<S87oeYJFPOoB4Q81onSXj<7of][J`Ko?Shn1Oooool7oe]KF`Oo>SXj1onI
VIT7o``<30OoCDe=1olX:2P7og9bLPKoH61P1_ooool6oe9BDPOoCdm?1om1@D47oc8b<POo9RHV1olX
:2P7oc0`<0KoDE5A1_ooool7oaPH60OoBd];1_l=3@d7obTY:@Oo@D511olT92@7oi:BTPKo:RXZ1_oo
ool7oa<C4`Oo0`<31ol<30`7oa4A4@Ko6ATI1olO7al7oaTI6@Ko;Rh^1_ooool7ob`/;0Oo3@d=1omD
E5@7ob<S8`Oo51@D1om4A4@6o`0000Ko_Kfm1_ooool7okno_`Oo4A4A1omADE47oc0`<0Ook^k^1oma
LG47o`P820Ko;2`/1Oooool7oaHF5POoR8R81ol_;bl7o`0000OoC4a<1olD51@7ocDe=@Ko[Jf]3Ooo
ool000_ooooo1olK6a/7oc0`<0Oo<S8b1omJFUX7odQ8B0OoXj>S1om[Jf/6ochn?PGooooo1omKFe/7
ocXj>POoVIVI1ol<30`7ode=C@Oo:2PX1ombLW86of1PH0Kooooo1_mBDU87odm?C`Oo@D511olb<S87
obHV9POo:2PX1ol`<306oe5AD@Kooooo1olH61P7od];B`Ko3@d=1olY:BT7od51@@Oo92@T1onBTY86
obXZ:PKooooo1olC4a<7o`<30`Oo30`<1olA4A46oaTI6@Oo7alO1olI6AT6obh^;PKooooo1ol/;2`7
o`d=3@OoE5AD1olS8b<7oa@D50OoA4A41_l00006okfm_@Kooooo1ono_kl7oa4A4@OoDE5A1ol`<307
onk^kPOoLG5a1ol820P6ob`/;0Gooooo1olF5QH7ohR8R0Oo;bl_1ol00007oda<C0Oo51@D1ole=CD6
ojf][@gooooo000;ooooo`Oo6a/K1ol`<307oc8b<POoFUYJ1om8B4P7oj>SX`OoJf][1_ln?Sh5oooo
o`OoFe]K1olj>SX7oiVIV@Oo30`<1om=CDd7obPX:0OoLW9b1_mPH606ooooo`KoDU9B1om?Cdl7od51
@@Oo<S8b1olV9RH7obPX:0Oo<30`1_mADE46ooooo`Oo61PH1om;Bd/6o`d=3@Oo:BTY1om1@D47ob@T
90OoTY:B1_lZ:RX6ooooo`Oo4a<C1ol30`<7o``<30Oo4A4A1_lI6AT7oalO7`Oo6ATI1_l^;Rh6oooo
o`Oo;2`/1ol=3@d7oeADE0Oo8b<S1olD51@7odA4A0Ko00001_nm_Kd6ooooo`Oo_kno1olA4A47oe5A
D@Oo<30`1oo^k^h7og5aL@Oo20P81_l/;2`5ooooo`Oo5QHF1on8R8P7obl_;`Oo00001om<C4`7oa@D
50Oo=CDe1_n][Jd=ooooo`002oooool7oa@D50Oo00001olG5aL7oc`l?0Oo92@T1on9RHT7oe1@D0Ko
1PH61Oooool7od10@0Oo7AdM1onIVIT7o`0000Oo92@T1olg=cL7oeQHF0KoC4a<1_ooool6oaTI6@Oo
9BDU1olY:BT7oc@d=0Oo3@d=1ol00007oaDE5@Ko9bLW1_ooool7oadM7@OoH61P1_lI6AT7ocHf=POo
9bLW1olN7Qh7ogalO0Ko=CDe1_ooool7o`/;2`Oo0@411olD51@7o`L71`Ko0@411olD51@7oa0@40Ko
6QXJ1_ooool7ob/[:`Oo4a<C1omfMWH7oa0@40Oo7AdM1om7AdL6oaPH60KoTi>C1_ooool7oo?cl`Oo
7AdM1om/K6`7obXZ:POoOWin1on9RHT7oc/k>`Ko>3Ph1Oooool7o`@410OoLg=c1om<C4`7ob0P80Oo
K6a/1olP8207oc/k>`Koe=CD3Oooool000_ooooo1olD51@7o`0000Oo5aLG1oll?3`7ob@T90OoRHV9
1om@D506o`H61PGooooo1om0@407oadM7@OoVIVI1ol00007ob@T90Oo=cLg1omHF5P6oda<C0Kooooo
1_lI6AT7obDU9@Oo:BTY1old=3@7o`d=3@Oo00001olE5AD6obLW9`Kooooo1olM7Ad7of1PH0Ko6ATI
1olf=SH7obLW9`Oo7QhN1omlO7`6ocDe=@Kooooo1ol;2`/7o`410@Oo51@D1ol71`L6o`410@Oo51@D
1ol@4106oaXJ6PKooooo1ol[:b/7oa<C4`OoMWIf1ol@4107oadM7@OoAdM71_lH61P6oi>CT`Kooooo
1ooclo<7oadM7@OoK6a/1olZ:RX7oginOPOoRHV91olk>c/6ocPh>0Gooooo1ol410@7og=cL`OoC4a<
1olP8207ofa/K0Oo820P1olk>c/6omCDe0gooooo000;ooooo`Oo51@D1ol00007oaLG5`Oo?3`l1olT
92@7ohV9R@OoD51@1_l61PH5ooooo`Oo@4101olM7Ad7oiVIV@Oo00001olT92@7ocLg=`OoF5QH1_m<
C4`6ooooo`Ko6ATI1olU9BD7obTY:@Oo=3@d1ol=3@d7o`0000Oo5ADE1_lW9bL6ooooo`Oo7AdM1omP
H606oaTI6@Oo=SHf1olW9bL7oahN7POoO7al1_le=CD6ooooo`Oo2`/;1ol10@47oa@D50Oo1`L71_l1
0@47oa@D50Oo410@1_lJ6QX6ooooo`Oo:b/[1olC4a<7ogIfMPOo410@1olM7Ad7odM7A`Ko61PH1_nC
Ti<6ooooo`Oolo?c1olM7Ad7ofa/K0Oo:RXZ1omnOWh7ohV9R@Oo>c/k1_lh>3P5ooooo`Oo10@41omc
Lg<7oda<C0Oo820P1om/K6`7ob0P80Oo>c/k1_oDe=@=ooooo`002oooool7oa@D50Oo00001olG5aL7
oc`l?0Oo92@T1on9RHT7oe1@D0Ko1PH61Oooool7od10@0Oo7AdM1onIVIT7o`0000Oo92@T1olg=cL7
oeQHF0KoC4a<1_ooool6oaTI6@Oo9BDU1olY:BT7oc@d=0Oo3@d=1ol00007oaDE5@Ko9bLW1_ooool7
oadM7@OoH61P1_lI6AT7ocHf=POo9bLW1olN7Qh7ogalO0Ko=CDe1_ooool7o`/;2`Oo0@411olD51@7
o`L71`Ko0@411olD51@7oa0@40Ko6QXJ1_ooool7ob/[:`Oo4a<C1omfMWH7oa0@40Oo7AdM1om7AdL6
oaPH60KoTi>C1_ooool7oo?cl`Oo7AdM1om/K6`7obXZ:POoOWin1on9RHT7oc/k>`Ko>3Ph1Oooool7
o`@410OoLg=c1om<C4`7ob0P80OoK6a/1olP8207oc/k>`Koe=CD3Oooool000_ooooo1olD51@7o`00
00Oo5aLG1oll?3`7ob@T90OoRHV91om@D506o`H61PGooooo1om0@407oadM7@OoVIVI1ol00007ob@T
90Oo=cLg1omHF5P6oda<C0Kooooo1_lI6AT7obDU9@Oo:BTY1old=3@7o`d=3@Oo00001olE5AD6obLW
9`Kooooo1olM7Ad7of1PH0Ko6ATI1olf=SH7obLW9`Oo7QhN1omlO7`6ocDe=@Kooooo1ol;2`/7o`41
0@Oo51@D1ol71`L6o`410@Oo51@D1ol@4106oaXJ6PKooooo1ol[:b/7oa<C4`OoMWIf1ol@4107oadM
7@OoAdM71_lH61P6oi>CT`Kooooo1ooclo<7oadM7@OoK6a/1olZ:RX7oginOPOoRHV91olk>c/6ocPh
>0Gooooo1ol410@7og=cL`OoC4a<1olP8207ofa/K0Oo820P1olk>c/6omCDe0gooooo000;ooooo`Oo
51@D1ol00007oaLG5`Oo?3`l1olT92@7ohV9R@OoD51@1_l61PH5ooooo`Oo@4101olM7Ad7oiVIV@Oo
00001olT92@7ocLg=`OoF5QH1_m<C4`6ooooo`Ko6ATI1olU9BD7obTY:@Oo=3@d1ol=3@d7o`0000Oo
5ADE1_lW9bL6ooooo`Oo7AdM1omPH606oaTI6@Oo=SHf1olW9bL7oahN7POoO7al1_le=CD6ooooo`Oo
2`/;1ol10@47oa@D50Oo1`L71_l10@47oa@D50Oo410@1_lJ6QX6ooooo`Oo:b/[1olC4a<7ogIfMPOo
410@1olM7Ad7odM7A`Ko61PH1_nCTi<6ooooo`Oolo?c1olM7Ad7ofa/K0Oo:RXZ1omnOWh7ohV9R@Oo
>c/k1_lh>3P5ooooo`Oo10@41omcLg<7oda<C0Oo820P1om/K6`7ob0P80Oo>c/k1_oDe=@=ooooo`00
2oooool7oa@D50Oo00001olG5aL7oc`l?0Oo92@T1on9RHT7oe1@D0Ko1PH61Oooool7od10@0Oo7AdM
1onIVIT7o`0000Oo92@T1olg=cL7oeQHF0KoC4a<1_ooool6oaTI6@Oo9BDU1olY:BT7oc@d=0Oo3@d=
1ol00007oaDE5@Ko9bLW1_ooool7oadM7@OoH61P1_lI6AT7ocHf=POo9bLW1olN7Qh7ogalO0Ko=CDe
1_ooool7o`/;2`Oo0@411olD51@7o`L71`Ko0@411olD51@7oa0@40Ko6QXJ1_ooool7ob/[:`Oo4a<C
1omfMWH7oa0@40Oo7AdM1om7AdL6oaPH60KoTi>C1_ooool7oo?cl`Oo7AdM1om/K6`7obXZ:POoOWin
1on9RHT7oc/k>`Ko>3Ph1Oooool7o`@410OoLg=c1om<C4`7ob0P80OoK6a/1olP8207oc/k>`Koe=CD
3Oooool000_ooooo1olG5aL7o`d=3@Oo9BDU1olj>SX7oeYJFPOooooo1omcLg<6ob<S8`Gooooo1oln
?Sh7oa4A4@OoF5QH1ol@4107oc`l?0Oo9bLW1olT92@6ogIfMPKooooo1_lW9bL7oa`L70Oo=SHf1ol2
0P87o`@410Oo410@1olS8b<6obLW9`Kooooo1ol@4107od];B`Ko0P821omJFUX7obd];@Oo00001om:
BTX6oeeMG@Kooooo1ol;2`/7o``<30Oo92@T1ol410@6oaLG5`Oo:2PX1olS8b<6ob@T90Kooooo1olf
=SH7oa8B4POoBTY:1olU9BD7ob4Q8@Oo=cLg1_l;2`/6oeiNGPKooooo1ong]kL7o`D51@OoPh>31omA
DE47oh^;R`OogMgM1ol`<306oc4a<@Gooooo1ol61PH7oe1@D0OoKVi^1olF5QH7ofm_K`Oo9RHV1ol]
;BdCooooo`002oooool7oaLG5`Oo3@d=1olU9BD7ocXj>POoFUYJ1oooool7og=cL`Ko8b<S1Oooool7
ochn?POo4A4A1omHF5P7oa0@40Oo?3`l1olW9bL7ob@T90KoMWIf1_ooool6obLW9`Oo71`L1olf=SH7
o`820POo10@41ol@4107ob<S8`Ko9bLW1_ooool7oa0@40OoBd];1_l20P87oeYJFPOo;Bd]1ol00007
odY:BPKoGEeM1_ooool7o`/;2`Oo30`<1olT92@7o`@410Ko5aLG1olX:2P7ob<S8`Ko92@T1_ooool7
ocHf=POo4Q8B1om:BTX7obDU9@Oo8B4Q1olg=cL6o`/;2`KoGUiN1_ooool7okNg]`Oo1@D51on3Ph<7
oe5AD@OoRh^;1ooMgMd7oc0`<0Ko<C4a1Oooool7o`H61POoD51@1om^KVh7oaHF5POoKfm_1olV9RH7
obd];A?ooooo000;ooooo`Oo5aLG1ol=3@d7obDU9@Oo>SXj1omJFUX7ooooo`OoLg=c1_lS8b<5oooo
o`Oo?Shn1olA4A47oeQHF0Oo410@1oll?3`7obLW9`Oo92@T1_mfMWH6ooooo`Ko9bLW1olL71`7ocHf
=POo0P821ol410@7oa0@40Oo8b<S1_lW9bL6ooooo`Oo410@1om;Bd/6o`820POoFUYJ1ol];Bd7o`00
00OoBTY:1_mMGEd6ooooo`Oo2`/;1ol<30`7ob@T90Oo10@41_lG5aL7obPX:0Oo8b<S1_lT92@6oooo
o`Oo=SHf1olB4Q87odY:BPOo9BDU1olQ8B47ocLg=`Ko2`/;1_mNGUh6ooooo`Oo]kNg1ol51@D7oh>3
P`OoDE5A1on;Rh/7omgMg@Oo<30`1_la<C45ooooo`Oo1PH61om@D507ofi^KPOo5QHF1om_Kfl7obHV
9POo;Bd]4oooool000_ooooo1olG5aL7o`d=3@Oo9BDU1olj>SX7oeYJFPOooooo1omcLg<6ob<S8`Go
oooo1oln?Sh7oa4A4@OoF5QH1ol@4107oc`l?0Oo9bLW1olT92@6ogIfMPKooooo1_lW9bL7oa`L70Oo
=SHf1ol20P87o`@410Oo410@1olS8b<6obLW9`Kooooo1ol@4107od];B`Ko0P821omJFUX7obd];@Oo
00001om:BTX6oeeMG@Kooooo1ol;2`/7o``<30Oo92@T1ol410@6oaLG5`Oo:2PX1olS8b<6ob@T90Ko
oooo1olf=SH7oa8B4POoBTY:1olU9BD7ob4Q8@Oo=cLg1_l;2`/6oeiNGPKooooo1ong]kL7o`D51@Oo
Ph>31omADE47oh^;R`OogMgM1ol`<306oc4a<@Gooooo1ol61PH7oe1@D0OoKVi^1olF5QH7ofm_K`Oo
9RHV1ol];BdCooooo`002oooool7oaLG5`Oo3@d=1olU9BD7ocXj>POoFUYJ1oooool7og=cL`Ko8b<S
1Oooool7ochn?POo4A4A1omHF5P7oa0@40Oo?3`l1olW9bL7ob@T90KoMWIf1_ooool6obLW9`Oo71`L
1olf=SH7o`820POo10@41ol@4107ob<S8`Ko9bLW1_ooool7oa0@40OoBd];1_l20P87oeYJFPOo;Bd]
1ol00007odY:BPKoGEeM1_ooool7o`/;2`Oo30`<1olT92@7o`@410Ko5aLG1olX:2P7ob<S8`Ko92@T
1_ooool7ocHf=POo4Q8B1om:BTX7obDU9@Oo8B4Q1olg=cL6o`/;2`KoGUiN1_ooool7okNg]`Oo1@D5
1on3Ph<7oe5AD@OoRh^;1ooMgMd7oc0`<0Ko<C4a1Oooool7o`H61POoD51@1om^KVh7oaHF5POoKfm_
1olV9RH7obd];A?ooooo000;ooooo`Oo5aLG1ol=3@d7obDU9@Oo>SXj1omJFUX7ooooo`OoLg=c1_lS
8b<5ooooo`Oo?Shn1olA4A47oeQHF0Oo410@1oll?3`7obLW9`Oo92@T1_mfMWH6ooooo`Ko9bLW1olL
71`7ocHf=POo0P821ol410@7oa0@40Oo8b<S1_lW9bL6ooooo`Oo410@1om;Bd/6o`820POoFUYJ1ol]
;Bd7o`0000OoBTY:1_mMGEd6ooooo`Oo2`/;1ol<30`7ob@T90Oo10@41_lG5aL7obPX:0Oo8b<S1_lT
92@6ooooo`Oo=SHf1olB4Q87odY:BPOo9BDU1olQ8B47ocLg=`Ko2`/;1_mNGUh6ooooo`Oo]kNg1ol5
1@D7oh>3P`OoDE5A1on;Rh/7omgMg@Oo<30`1_la<C45ooooo`Oo1PH61om@D507ofi^KPOo5QHF1om_
Kfl7obHV9POo;Bd]4oooool000_ooooo1olK6a/7oaPH60Oo7AdM1ol_;bl7obLW9`Oo>c/k1om6ATH6
obHV9PGooooo1olN7Qh7ocPh>0Oo5QHF1ol71`L7ocPh>0Oo=3@d1ol[:b/6ocLg=`Kooooo1_lA4A47
ob@T90Oo>CTi1olg=cL7oa`L70Oo3`l?1ol/;2`6oeEEE@Kooooo1omKFe/7od92@PKo:b/[1oln?Sh7
ob8R8POoT92@1omhN7P6ogMgM`Kooooo1omOGel7ooooo`OoEeMG1olc<c<6odU9B@Oo92@T1ol[:b/6
obd];@Kooooo1ole=CD7ob`/;0OoQ8B41oli>CT7ofQXJ0OoOGem1_lG5aL6oeUIF@Kooooo1om]KFd7
odI6APOoV9RH1om0@407ofYZJPOoKFe]1ol/;2`6okjn_PGooooo1ol@4107oc@d=0Oo@4101olM7Ad7
oeIFEPOo8R8R1omOGel6oeYJFPgooooo000;ooooo`Oo6a/K1olH61P7oadM7@Oo;bl_1olW9bL7oc/k
>`OoATI61_lV9RH5ooooo`Oo7QhN1olh>3P7oaHF5POo1`L71olh>3P7oc@d=0Oo:b/[1_lg=cL6oooo
o`Ko4A4A1olT92@7ocTi>@Oo=cLg1olL71`7o`l?3`Oo;2`/1_mEEED6ooooo`OoFe]K1om2@T86ob/[
:`Oo?Shn1olR8R87oi2@T0OoN7Qh1_mgMgL6ooooo`OoGemO1oooool7oeMGE`Oo<c<c1_m9BDT7ob@T
90Oo:b/[1_l];Bd6ooooo`Oo=CDe1ol/;2`7ohB4Q0Oo>CTi1omXJ6P7ogemO@Ko5aLG1_mIFET6oooo
o`OoKFe]1om6ATH7oiRHV0Oo@4101omZJVX7ofe]K@Oo;2`/1_nn_[h5ooooo`Oo410@1old=3@7od10
@0Oo7AdM1omFEUH7ob8R8POoGemO1_mJFUX=ooooo`002oooool7oa/K6`Oo61PH1olM7Ad7obl_;`Oo
9bLW1olk>c/7odI6APKo9RHV1Oooool7oahN7POo>3Ph1olF5QH7o`L71`Oo>3Ph1old=3@7ob/[:`Ko
=cLg1_ooool6oa4A4@Oo92@T1oli>CT7ocLg=`Oo71`L1ol?3`l7ob`/;0KoEEEE1_ooool7oe]KF`Oo
@T921_l[:b/7ochn?POo8R8R1on@T907ogQhN0KoMgMg1_ooool7oemOG`Oooooo1omGEeL7oc<c<`Ko
BDU91olT92@7ob/[:`Ko;Bd]1_ooool7ocDe=@Oo;2`/1on4Q8@7ocTi>@OoJ6QX1ommOGd6oaLG5`Ko
FEUI1_ooool7ofe]K@OoATI61onHV9P7od10@0OoJVYZ1om]KFd7ob`/;0Ko_[jn1Oooool7oa0@40Oo
=3@d1om0@407oadM7@OoEUIF1olR8R87oemOG`KoFUYJ3Oooool000_ooooo1olK6a/7oaPH60Oo7AdM
1ol_;bl7obLW9`Oo>c/k1om6ATH6obHV9PGooooo1olN7Qh7ocPh>0Oo5QHF1ol71`L7ocPh>0Oo=3@d
1ol[:b/6ocLg=`Kooooo1_lA4A47ob@T90Oo>CTi1olg=cL7oa`L70Oo3`l?1ol/;2`6oeEEE@Kooooo
1omKFe/7od92@PKo:b/[1oln?Sh7ob8R8POoT92@1omhN7P6ogMgM`Kooooo1omOGel7ooooo`OoEeMG
1olc<c<6odU9B@Oo92@T1ol[:b/6obd];@Kooooo1ole=CD7ob`/;0OoQ8B41oli>CT7ofQXJ0OoOGem
1_lG5aL6oeUIF@Kooooo1om]KFd7odI6APOoV9RH1om0@407ofYZJPOoKFe]1ol/;2`6okjn_PGooooo
1ol@4107oc@d=0Oo@4101olM7Ad7oeIFEPOo8R8R1omOGel6oeYJFPgooooo000;ooooo`Oo6a/K1olH
61P7oadM7@Oo;bl_1olW9bL7oc/k>`OoATI61_lV9RH5ooooo`Oo7QhN1olh>3P7oaHF5POo1`L71olh
>3P7oc@d=0Oo:b/[1_lg=cL6ooooo`Ko4A4A1olT92@7ocTi>@Oo=cLg1olL71`7o`l?3`Oo;2`/1_mE
EED6ooooo`OoFe]K1om2@T86ob/[:`Oo?Shn1olR8R87oi2@T0OoN7Qh1_mgMgL6ooooo`OoGemO1ooo
ool7oeMGE`Oo<c<c1_m9BDT7ob@T90Oo:b/[1_l];Bd6ooooo`Oo=CDe1ol/;2`7ohB4Q0Oo>CTi1omX
J6P7ogemO@Ko5aLG1_mIFET6ooooo`OoKFe]1om6ATH7oiRHV0Oo@4101omZJVX7ofe]K@Oo;2`/1_nn
_[h5ooooo`Oo410@1old=3@7od10@0Oo7AdM1omFEUH7ob8R8POoGemO1_mJFUX=ooooo`002oooool7
oa/K6`Oo61PH1olM7Ad7obl_;`Oo9bLW1olk>c/7odI6APKo9RHV1Oooool7oahN7POo>3Ph1olF5QH7
o`L71`Oo>3Ph1old=3@7ob/[:`Ko=cLg1_ooool6oa4A4@Oo92@T1oli>CT7ocLg=`Oo71`L1ol?3`l7
ob`/;0KoEEEE1_ooool7oe]KF`Oo@T921_l[:b/7ochn?POo8R8R1on@T907ogQhN0KoMgMg1_ooool7
oemOG`Oooooo1omGEeL7oc<c<`KoBDU91olT92@7ob/[:`Ko;Bd]1_ooool7ocDe=@Oo;2`/1on4Q8@7
ocTi>@OoJ6QX1ommOGd6oaLG5`KoFEUI1_ooool7ofe]K@OoATI61onHV9P7od10@0OoJVYZ1om]KFd7
ob`/;0Ko_[jn1Oooool7oa0@40Oo=3@d1om0@407oadM7@OoEUIF1olR8R87oemOG`KoFUYJ3Oooool0
00_ooooo1olK6a/7oaPH60Oo7AdM1ol_;bl7obLW9`Oo>c/k1om6ATH6obHV9PGooooo1olN7Qh7ocPh
>0Oo5QHF1ol71`L7ocPh>0Oo=3@d1ol[:b/6ocLg=`Kooooo1_lA4A47ob@T90Oo>CTi1olg=cL7oa`L
70Oo3`l?1ol/;2`6oeEEE@Kooooo1omKFe/7od92@PKo:b/[1oln?Sh7ob8R8POoT92@1omhN7P6ogMg
M`Kooooo1omOGel7ooooo`OoEeMG1olc<c<6odU9B@Oo92@T1ol[:b/6obd];@Kooooo1ole=CD7ob`/
;0OoQ8B41oli>CT7ofQXJ0OoOGem1_lG5aL6oeUIF@Kooooo1om]KFd7odI6APOoV9RH1om0@407ofYZ
JPOoKFe]1ol/;2`6okjn_PGooooo1ol@4107oc@d=0Oo@4101olM7Ad7oeIFEPOo8R8R1omOGel6oeYJ
FPgooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB
4Q87o`h>3POo61PH1_l];Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^
;Rh6ooooo`Ko30`<1ol;2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l5
1@D7ofYZJPOo10@41olM7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omX
J6P7ol;2`PKoCdm?1_ooool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_oo
ool7oaTI6@Oo?Shn1olK6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>
CTh7oaDE5@Oo410@1ol/;2`6oh20P0gooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB4Q87
o`h>3POo61PH1_l];Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^;Rh6
ooooo`Ko30`<1ol;2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l51@D7
ofYZJPOo10@41olM7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omXJ6P7
ol;2`PKoCdm?1_ooool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_ooool7
oaTI6@Oo?Shn1olK6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>CTh7
oaDE5@Oo410@1ol/;2`6oh20P0gooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB4Q87o`h>
3POo61PH1_l];Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^;Rh6oooo
o`Ko30`<1ol;2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l51@D7ofYZ
JPOo10@41olM7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omXJ6P7ol;2
`PKoCdm?1_ooool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_ooool7oaTI
6@Oo?Shn1olK6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>CTh7oaDE
5@Oo410@1ol/;2`6oh20P0gooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB4Q87o`h>3POo
61PH1_l];Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^;Rh6ooooo`Ko
30`<1ol;2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l51@D7ofYZJPOo
10@41olM7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omXJ6P7ol;2`PKo
Cdm?1_ooool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_ooool7oaTI6@Oo
?Shn1olK6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>CTh7oaDE5@Oo
410@1ol/;2`6oh20P0gooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB4Q87o`h>3POo61PH
1_l];Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^;Rh6ooooo`Ko30`<
1ol;2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l51@D7ofYZJPOo10@4
1olM7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omXJ6P7ol;2`PKoCdm?
1_ooool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_ooool7oaTI6@Oo?Shn
1olK6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>CTh7oaDE5@Oo410@
1ol/;2`6oh20P0gooooo000;ooooo`Oo3`l?1olR8R87ob`/;0Oo3@d=1olB4Q87o`h>3POo61PH1_l]
;Bd5ooooo`OoMWIf1ol];Bd7od];B`Oooooo1ol92@T7odm?C`Oo?clo1_l^;Rh6ooooo`Ko30`<1ol;
2`/7o`P820Oo5aLG1olI6AT7oaDE5@Oo8b<S1_l_;bl6ooooo`ko;Bd]1_l51@D7ofYZJPOo10@41olM
7Ad7ohf=S@Ko5QHF1_ooool7ocHf=POo5aLG1ol00007o`h>3PKo;2`/1omXJ6P7ol;2`PKoCdm?1_oo
ool7obXZ:POo2`/;1olC4a<7o`X:2POo3Ph>1olA4A46o`410@Ko>SXj1_ooool7oaTI6@Oo?Shn1olK
6a/7oeQHF0OoYJFU1ol@4107odI6AP_ooooo1olD51@7oa`L70Oo0@411om>CTh7oaDE5@Oo410@1ol/
;2`6oh20P0gooooo000;ooooo`Oo3@d=1olC4a<7ob0P80Oo3Ph>1ol<30`7o`L71`Oo00001_l@4105
ooooo`OoB4Q81olo?cl7oe1@D0OoW9bL1ol20P87oc`l?0Oo=3@d1_l;2`/6ooooo`Ko0P821ol00007
o`<30`Oo30`<1olE5AD7oaHF5POo3@d=1_l`<306ooooo`Oo@T921olQ8B46o`P820OoHF5Q1olL71`7
ob8R8POoD51@1_lf=SH6ooooo`Oo6QXJ1ol410@7o`<30`Oo2PX:1_lZ:RX7ocLg=`OoK6a/1_m8B4P6
ooooo`Oo>c/k1ol61PH7oalO7`Oo6a/K1olS8b<7oaXJ6PKo10@41_m0@406ooooo`Oo61PH1olg=cL7
obDU9@Oo:RXZ1oo4a<@7o`P820Oo;Bd]1_nMWId5ooooo`Oo4a<C1olM7Ad7o`T92@OoO7al1ol=3@d7
o`0000Oo820P1_n][Jd=ooooo`002oooool7o`d=3@Oo4a<C1olP8207o`h>3POo30`<1ol71`L7o`00
00Ko410@1Oooool7odQ8B0Oo?clo1om@D507oibLW0Oo0P821oll?3`7oc@d=0Ko2`/;1_ooool6o`82
0POo00001ol30`<7o``<30Oo5ADE1olF5QH7o`d=3@Ko<30`1_ooool7od92@POo8B4Q1_l820P7of5Q
H@Oo71`L1olR8R87oe1@D0Ko=SHf1_ooool7oaXJ6POo10@41ol30`<7o`X:2PKo:RXZ1olg=cL7ofa/
K0KoB4Q81_ooool7oc/k>`Oo1PH61olO7al7oa/K6`Oo8b<S1olJ6QX6o`@410Ko@4101_ooool7oaPH
60Oo=cLg1olU9BD7obXZ:POoa<C41ol820P7obd];@KoWIfM1Oooool7oa<C4`Oo7AdM1ol92@T7ogal
O0Oo3@d=1ol00007ob0P80Ko[Jf]3Oooool000_ooooo1ol=3@d7oa<C4`Oo820P1ol>3Ph7o``<30Oo
1`L71ol00006oa0@40Gooooo1om8B4P7oclo?`OoD51@1onLW9`7o`820POo?3`l1old=3@6o`/;2`Ko
oooo1_l20P87o`0000Oo0`<31ol<30`7oaDE5@Oo5QHF1ol=3@d6oc0`<0Kooooo1om2@T87ob4Q8@Ko
20P81omQHF47oa`L70Oo8R8R1om@D506ocHf=PKooooo1olJ6QX7o`@410Oo0`<31ol:2PX6obXZ:POo
=cLg1om/K6`6odQ8B0Kooooo1olk>c/7o`H61POo7alO1olK6a/7ob<S8`Oo6QXJ1_l410@6od10@0Ko
oooo1olH61P7ocLg=`Oo9BDU1olZ:RX7olC4a0Oo20P81ol];Bd6oifMW@Gooooo1olC4a<7oadM7@Oo
2@T91omlO7`7o`d=3@Oo00001olP8206ojf][@gooooo000;ooooo`Oo3@d=1olC4a<7ob0P80Oo3Ph>
1ol<30`7o`L71`Oo00001_l@4105ooooo`OoB4Q81olo?cl7oe1@D0OoW9bL1ol20P87oc`l?0Oo=3@d
1_l;2`/6ooooo`Ko0P821ol00007o`<30`Oo30`<1olE5AD7oaHF5POo3@d=1_l`<306ooooo`Oo@T92
1olQ8B46o`P820OoHF5Q1olL71`7ob8R8POoD51@1_lf=SH6ooooo`Oo6QXJ1ol410@7o`<30`Oo2PX:
1_lZ:RX7ocLg=`OoK6a/1_m8B4P6ooooo`Oo>c/k1ol61PH7oalO7`Oo6a/K1olS8b<7oaXJ6PKo10@4
1_m0@406ooooo`Oo61PH1olg=cL7obDU9@Oo:RXZ1oo4a<@7o`P820Oo;Bd]1_nMWId5ooooo`Oo4a<C
1olM7Ad7o`T92@OoO7al1ol=3@d7o`0000Oo820P1_n][Jd=ooooo`002oooool7o`d=3@Oo4a<C1olP
8207o`h>3POo30`<1ol71`L7o`0000Ko410@1Oooool7odQ8B0Oo?clo1om@D507oibLW0Oo0P821oll
?3`7oc@d=0Ko2`/;1_ooool6o`820POo00001ol30`<7o``<30Oo5ADE1olF5QH7o`d=3@Ko<30`1_oo
ool7od92@POo8B4Q1_l820P7of5QH@Oo71`L1olR8R87oe1@D0Ko=SHf1_ooool7oaXJ6POo10@41ol3
0`<7o`X:2PKo:RXZ1olg=cL7ofa/K0KoB4Q81_ooool7oc/k>`Oo1PH61olO7al7oa/K6`Oo8b<S1olJ
6QX6o`@410Ko@4101_ooool7oaPH60Oo=cLg1olU9BD7obXZ:POoa<C41ol820P7obd];@KoWIfM1Ooo
ool7oa<C4`Oo7AdM1ol92@T7ogalO0Oo3@d=1ol00007ob0P80Ko[Jf]3Oooool000_ooooo1ol=3@d7
oa<C4`Oo820P1ol>3Ph7o``<30Oo1`L71ol00006oa0@40Gooooo1om8B4P7oclo?`OoD51@1onLW9`7
o`820POo?3`l1old=3@6o`/;2`Kooooo1_l20P87o`0000Oo0`<31ol<30`7oaDE5@Oo5QHF1ol=3@d6
oc0`<0Kooooo1om2@T87ob4Q8@Ko20P81omQHF47oa`L70Oo8R8R1om@D506ocHf=PKooooo1olJ6QX7
o`@410Oo0`<31ol:2PX6obXZ:POo=cLg1om/K6`6odQ8B0Kooooo1olk>c/7o`H61POo7alO1olK6a/7
ob<S8`Oo6QXJ1_l410@6od10@0Kooooo1olH61P7ocLg=`Oo9BDU1olZ:RX7olC4a0Oo20P81ol];Bd6
oifMW@Gooooo1olC4a<7oadM7@Oo2@T91omlO7`7o`d=3@Oo00001olP8206ojf][@gooooo000;oooo
o`Oo3@d=1olC4a<7ob0P80Oo3Ph>1ol<30`7o`L71`Oo00001_l@4105ooooo`OoB4Q81olo?cl7oe1@
D0OoW9bL1ol20P87oc`l?0Oo=3@d1_l;2`/6ooooo`Ko0P821ol00007o`<30`Oo30`<1olE5AD7oaHF
5POo3@d=1_l`<306ooooo`Oo@T921olQ8B46o`P820OoHF5Q1olL71`7ob8R8POoD51@1_lf=SH6oooo
o`Oo6QXJ1ol410@7o`<30`Oo2PX:1_lZ:RX7ocLg=`OoK6a/1_m8B4P6ooooo`Oo>c/k1ol61PH7oalO
7`Oo6a/K1olS8b<7oaXJ6PKo10@41_m0@406ooooo`Oo61PH1olg=cL7obDU9@Oo:RXZ1oo4a<@7o`P8
20Oo;Bd]1_nMWId5ooooo`Oo4a<C1olM7Ad7o`T92@OoO7al1ol=3@d7o`0000Oo820P1_n][Jd=oooo
o`002oooool7oa8B4POo7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo
92@T1olM7Ad7okVi^@Oo00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo
410@1olA4A47oaXJ6PKo5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Ko
oooo1olM7Ad7o`l?3`Oo1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo
71`L1olD51@7ob@T90Oo>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo
8b<S1om9BDT6odQ8B0Gooooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`00
2oooool7oa8B4POo7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T
1olM7Ad7okVi^@Oo00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@
1olA4A47oaXJ6PKo5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo
1olM7Ad7o`l?3`Oo1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L
1olD51@7ob@T90Oo>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S
1om9BDT6odQ8B0Gooooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002ooo
ool7oa8B4POo7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T1olM
7Ad7okVi^@Oo00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@1olA
4A47oaXJ6PKo5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo1olM
7Ad7o`l?3`Oo1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L1olD
51@7ob@T90Oo>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S1om9
BDT6odQ8B0Gooooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002oooool7
oa8B4POo7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T1olM7Ad7
okVi^@Oo00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@1olA4A47
oaXJ6PKo5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo1olM7Ad7
o`l?3`Oo1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L1olD51@7
ob@T90Oo>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S1om9BDT6
odQ8B0Gooooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002oooool7oa8B
4POo7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T1olM7Ad7okVi
^@Oo00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@1olA4A47oaXJ
6PKo5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo1olM7Ad7o`l?
3`Oo1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L1olD51@7ob@T
90Oo>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S1om9BDT6odQ8
B0Gooooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002oooool7oa8B4POo
7AdM1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T1olM7Ad7okVi^@Oo
00001olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@1olA4A47oaXJ6PKo
5aLG1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo1olM7Ad7o`l?3`Oo
1@D51ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L1olD51@7ob@T90Oo
>SXj1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S1om9BDT6odQ8B0Go
oooo1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002oooool7oa8B4POo7AdM
1olU9BD7oa4A4@Oo2`/;1ol51@D7o`X:2PKo6ATI1Oooool7oe1@D0Oo92@T1olM7Ad7okVi^@Oo0000
1olj>SX7oeaLG0Ko?3`l1_ooool6o`h>3POo00001ol410@7o`T92@Oo410@1olA4A47oaXJ6PKo5aLG
1_ooool7ogAdM0Oo7QhN1_l:2PX7od];B`Oo00003_lN7Qh6oc/k>`Kooooo1olM7Ad7o`l?3`Oo1@D5
1ol?3`l6oaTI6@Oo>CTi1omJFUX6obHV9PKooooo1olm?Cd7o`H61POo71`L1olD51@7ob@T90Oo>SXj
1_l820P6oaLG5`Kooooo1ol71`L7ocXj>POo71`L1olC4a<7ogemO@Oo8b<S1om9BDT6odQ8B0Gooooo
1olM7Ad7ocdm?@Oo4a<C1om`L707ocHf=POo4A4A1ol^;RhCooooo`002oooool7oaDE5@Oo5aLG1olB
4Q87oaLG5`Oo3@d=1olB4Q87oa4A4@Ko7AdM1Oooool7ocXj>Pko7QhN1omOGel7oa0@40Oo>SXj1om3
@d<6obDU9@Kooooo1_l<30`7oaDE5@Oo3`l?1ol92@T7o`/;2`Oo8b<S1olC4a<6ocTi>@Kooooo1oma
LG47og1`L0Ko6QXJ1olm?Cd7o``<30Oo@4101olU9BD6od51@@Kooooo1olG5aL7o`d=3@Oo0P821olB
4Q86obd];@OoADE51omKFe/6oc/k>`Kooooo1oln?Sh7oaDE5@Oo?Cdm1ol10@47oa<C4`OoF5QH1_l0
0006ob4Q8@Kooooo1ol=3@d7oeIFEPOo3Ph>1ol=3@d7odi>CPOo51@D1ola<C46ocdm?@Gooooo1ol:
2PX7ocXj>POo6QXJ1omeMGD7oe]KF`Oo2`/;1oli>CT6oo3`l0gooooo000;ooooo`Oo5ADE1olG5aL7
oa8B4POo5aLG1ol=3@d7oa8B4POo4A4A1_lM7Ad5ooooo`Oo>SXj3_lN7Qh7oemOG`Oo410@1olj>SX7
od=3@`Ko9BDU1_ooool6o``<30Oo5ADE1ol?3`l7o`T92@Oo2`/;1olS8b<7oa<C4`Ko>CTi1_ooool7
og5aL@OoL71`1_lJ6QX7ocdm?@Oo30`<1om0@407obDU9@Ko@D511_ooool7oaLG5`Oo3@d=1ol20P87
oa8B4PKo;Bd]1om5ADD7oe]KF`Ko>c/k1_ooool7ochn?POo5ADE1olm?Cd7o`410@Oo4a<C1omHF5P6
o`0000Ko8B4Q1_ooool7o`d=3@OoEUIF1ol>3Ph7o`d=3@OoCTi>1olD51@7oc4a<@Ko?Cdm1Oooool7
o`X:2POo>SXj1olJ6QX7ogEeM@OoFe]K1ol;2`/7ocTi>@Kol?3`3Oooool000_ooooo1olE5AD7oaLG
5`Oo4Q8B1olG5aL7o`d=3@Oo4Q8B1olA4A46oadM7@Gooooo1olj>SX>oahN7POoGemO1ol@4107ocXj
>POo@d=31_lU9BD6ooooo`Ko30`<1olE5AD7o`l?3`Oo2@T91ol;2`/7ob<S8`Oo4a<C1_li>CT6oooo
o`OoLG5a1om`L706oaXJ6POo?Cdm1ol<30`7od10@0Oo9BDU1_m1@D46ooooo`Oo5aLG1ol=3@d7o`82
0POo4Q8B1_l];Bd7odE5A@OoFe]K1_lk>c/6ooooo`Oo?Shn1olE5AD7ocdm?@Oo0@411olC4a<7oeQH
F0Ko00001_lQ8B46ooooo`Oo3@d=1omFEUH7o`h>3POo3@d=1om>CTh7oa@D50Oo<C4a1_lm?Cd5oooo
o`Oo2PX:1olj>SX7oaXJ6POoMGEe1omKFe/7o`/;2`Oo>CTi1_o`l?0=ooooo`002oooool7oaDE5@Oo
5aLG1olB4Q87oaLG5`Oo3@d=1olB4Q87oa4A4@Ko7AdM1Oooool7ocXj>Pko7QhN1omOGel7oa0@40Oo
>SXj1om3@d<6obDU9@Kooooo1_l<30`7oaDE5@Oo3`l?1ol92@T7o`/;2`Oo8b<S1olC4a<6ocTi>@Ko
oooo1omaLG47og1`L0Ko6QXJ1olm?Cd7o``<30Oo@4101olU9BD6od51@@Kooooo1olG5aL7o`d=3@Oo
0P821olB4Q86obd];@OoADE51omKFe/6oc/k>`Kooooo1oln?Sh7oaDE5@Oo?Cdm1ol10@47oa<C4`Oo
F5QH1_l00006ob4Q8@Kooooo1ol=3@d7oeIFEPOo3Ph>1ol=3@d7odi>CPOo51@D1ola<C46ocdm?@Go
oooo1ol:2PX7ocXj>POo6QXJ1omeMGD7oe]KF`Oo2`/;1oli>CT6oo3`l0gooooo000;ooooo`Oo5ADE
1olG5aL7oa8B4POo5aLG1ol=3@d7oa8B4POo4A4A1_lM7Ad5ooooo`Oo>SXj3_lN7Qh7oemOG`Oo410@
1olj>SX7od=3@`Ko9BDU1_ooool6o``<30Oo5ADE1ol?3`l7o`T92@Oo2`/;1olS8b<7oa<C4`Ko>CTi
1_ooool7og5aL@OoL71`1_lJ6QX7ocdm?@Oo30`<1om0@407obDU9@Ko@D511_ooool7oaLG5`Oo3@d=
1ol20P87oa8B4PKo;Bd]1om5ADD7oe]KF`Ko>c/k1_ooool7ochn?POo5ADE1olm?Cd7o`410@Oo4a<C
1omHF5P6o`0000Ko8B4Q1_ooool7o`d=3@OoEUIF1ol>3Ph7o`d=3@OoCTi>1olD51@7oc4a<@Ko?Cdm
1Oooool7o`X:2POo>SXj1olJ6QX7ogEeM@OoFe]K1ol;2`/7ocTi>@Kol?3`3Oooool000_ooooo1olE
5AD7oaLG5`Oo4Q8B1olG5aL7o`d=3@Oo4Q8B1olA4A46oadM7@Gooooo1olj>SX>oahN7POoGemO1ol@
4107ocXj>POo@d=31_lU9BD6ooooo`Ko30`<1olE5AD7o`l?3`Oo2@T91ol;2`/7ob<S8`Oo4a<C1_li
>CT6ooooo`OoLG5a1om`L706oaXJ6POo?Cdm1ol<30`7od10@0Oo9BDU1_m1@D46ooooo`Oo5aLG1ol=
3@d7o`820POo4Q8B1_l];Bd7odE5A@OoFe]K1_lk>c/6ooooo`Oo?Shn1olE5AD7ocdm?@Oo0@411olC
4a<7oeQHF0Ko00001_lQ8B46ooooo`Oo3@d=1omFEUH7o`h>3POo3@d=1om>CTh7oa@D50Oo<C4a1_lm
?Cd5ooooo`Oo2PX:1olj>SX7oaXJ6POoMGEe1omKFe/7o`/;2`Oo>CTi1_o`l?0=ooooo`002oooool7
o``<30Oo6QXJ1olO7al7oa`L70Oo20P81ol>3Ph7oa0@40Ko3@d=1Oooool7of9RHPOo5QHF1ol71`L7
odU9B@Oo0@411ola<C47odi>CPKo<30`1_ooool6o`/;2`Oo10@41olD51@7o`T92@Oo3Ph>1olE5AD7
oaLG5`Ko8B4Q1_ooool7ofm_K`OoVIVI1_l:2PX7of9RHPOo4A4A1olc<c<7oc@d=0KoFUYJ1_ooool7
oc0`<0Oo5ADE1ol20P87o`D51@Ko6ATI1omRHV87of5QH@Ko:BTY1_ooool7odE5A@Oo4a<C1olT92@7
oa/K6`Oo<S8b1onATI46oa/K6`Ko:RXZ1_ooool7o`0000OoMWIf1olR8R87oaXJ6POo<30`1ol@4107
odQ8B0Ko>c/k1Oooool7o`H61POo;Rh^1ol/;2`7ofQXJ0OoMGEe1olD51@7od51@@KojNWY3Oooool0
00_ooooo1ol<30`7oaXJ6POo7alO1olL71`7o`P820Oo3Ph>1ol@4106o`d=3@Gooooo1omRHV87oaHF
5POo1`L71om9BDT7o`410@Oo<C4a1om>CTh6oc0`<0Kooooo1_l;2`/7o`@410Oo51@D1ol92@T7o`h>
3POo5ADE1olG5aL6ob4Q8@Kooooo1om_Kfl7oiVIV@Ko2PX:1omRHV87oa4A4@Oo<c<c1old=3@6oeYJ
FPKooooo1ol`<307oaDE5@Oo0P821ol51@D6oaTI6@OoHV9R1omQHF46obTY:@Kooooo1om5ADD7oa<C
4`Oo92@T1olK6a/7oc8b<POoTI6A1_lK6a/6obXZ:PKooooo1ol00007ogIfMPOo8R8R1olJ6QX7oc0`
<0Oo410@1om8B4P6oc/k>`Gooooo1ol61PH7obh^;POo;2`/1omXJ6P7ogEeM@Oo51@D1om1@D46onWY
j@gooooo000;ooooo`Oo30`<1olJ6QX7oalO7`Oo71`L1ol820P7o`h>3POo410@1_l=3@d5ooooo`Oo
HV9R1olF5QH7o`L71`OoBDU91ol10@47oc4a<@OoCTi>1_l`<306ooooo`Ko2`/;1ol410@7oa@D50Oo
2@T91ol>3Ph7oaDE5@Oo5aLG1_lQ8B46ooooo`OoKfm_1onIVIT6o`X:2POoHV9R1olA4A47oc<c<`Oo
=3@d1_mJFUX6ooooo`Oo<30`1olE5AD7o`820POo1@D51_lI6AT7of9RHPOoHF5Q1_lY:BT6ooooo`Oo
ADE51olC4a<7ob@T90Oo6a/K1olb<S87oi6AT@Ko6a/K1_lZ:RX6ooooo`Oo00001omfMWH7ob8R8POo
6QXJ1ol`<307oa0@40OoB4Q81_lk>c/5ooooo`Oo1PH61ol^;Rh7ob`/;0OoJ6QX1omeMGD7oa@D50Oo
@D511_oYjNT=ooooo`002oooool7o``<30Oo6QXJ1olO7al7oa`L70Oo20P81ol>3Ph7oa0@40Ko3@d=
1Oooool7of9RHPOo5QHF1ol71`L7odU9B@Oo0@411ola<C47odi>CPKo<30`1_ooool6o`/;2`Oo10@4
1olD51@7o`T92@Oo3Ph>1olE5AD7oaLG5`Ko8B4Q1_ooool7ofm_K`OoVIVI1_l:2PX7of9RHPOo4A4A
1olc<c<7oc@d=0KoFUYJ1_ooool7oc0`<0Oo5ADE1ol20P87o`D51@Ko6ATI1omRHV87of5QH@Ko:BTY
1_ooool7odE5A@Oo4a<C1olT92@7oa/K6`Oo<S8b1onATI46oa/K6`Ko:RXZ1_ooool7o`0000OoMWIf
1olR8R87oaXJ6POo<30`1ol@4107odQ8B0Ko>c/k1Oooool7o`H61POo;Rh^1ol/;2`7ofQXJ0OoMGEe
1olD51@7od51@@KojNWY3Oooool000_ooooo1ol<30`7oaXJ6POo7alO1olL71`7o`P820Oo3Ph>1ol@
4106o`d=3@Gooooo1omRHV87oaHF5POo1`L71om9BDT7o`410@Oo<C4a1om>CTh6oc0`<0Kooooo1_l;
2`/7o`@410Oo51@D1ol92@T7o`h>3POo5ADE1olG5aL6ob4Q8@Kooooo1om_Kfl7oiVIV@Ko2PX:1omR
HV87oa4A4@Oo<c<c1old=3@6oeYJFPKooooo1ol`<307oaDE5@Oo0P821ol51@D6oaTI6@OoHV9R1omQ
HF46obTY:@Kooooo1om5ADD7oa<C4`Oo92@T1olK6a/7oc8b<POoTI6A1_lK6a/6obXZ:PKooooo1ol0
0007ogIfMPOo8R8R1olJ6QX7oc0`<0Oo410@1om8B4P6oc/k>`Gooooo1ol61PH7obh^;POo;2`/1omX
J6P7ogEeM@Oo51@D1om1@D46onWYj@gooooo000;ooooo`Oo30`<1olJ6QX7oalO7`Oo71`L1ol820P7
o`h>3POo410@1_l=3@d5ooooo`OoHV9R1olF5QH7o`L71`OoBDU91ol10@47oc4a<@OoCTi>1_l`<306
ooooo`Ko2`/;1ol410@7oa@D50Oo2@T91ol>3Ph7oaDE5@Oo5aLG1_lQ8B46ooooo`OoKfm_1onIVIT6
o`X:2POoHV9R1olA4A47oc<c<`Oo=3@d1_mJFUX6ooooo`Oo<30`1olE5AD7o`820POo1@D51_lI6AT7
of9RHPOoHF5Q1_lY:BT6ooooo`OoADE51olC4a<7ob@T90Oo6a/K1olb<S87oi6AT@Ko6a/K1_lZ:RX6
ooooo`Oo00001omfMWH7ob8R8POo6QXJ1ol`<307oa0@40OoB4Q81_lk>c/5ooooo`Oo1PH61ol^;Rh7
ob`/;0OoJ6QX1omeMGD7oa@D50Oo@D511_oYjNT=ooooo`002oooool7o``<30Oo6QXJ1olO7al7oa`L
70Oo20P81ol>3Ph7oa0@40Ko3@d=1Oooool7of9RHPOo5QHF1ol71`L7odU9B@Oo0@411ola<C47odi>
CPKo<30`1_ooool6o`/;2`Oo10@41olD51@7o`T92@Oo3Ph>1olE5AD7oaLG5`Ko8B4Q1_ooool7ofm_
K`OoVIVI1_l:2PX7of9RHPOo4A4A1olc<c<7oc@d=0KoFUYJ1_ooool7oc0`<0Oo5ADE1ol20P87o`D5
1@Ko6ATI1omRHV87of5QH@Ko:BTY1_ooool7odE5A@Oo4a<C1olT92@7oa/K6`Oo<S8b1onATI46oa/K
6`Ko:RXZ1_ooool7o`0000OoMWIf1olR8R87oaXJ6POo<30`1ol@4107odQ8B0Ko>c/k1Oooool7o`H6
1POo;Rh^1ol/;2`7ofQXJ0OoMGEe1olD51@7od51@@KojNWY3Oooool000_ooooo1ol92@T7oa8B4POo
7alO1olE5AD7o`P820Oo4Q8B1olK6a/6oaHF5PGooooo1omNGUh7obl_;`Oo92@T1olh>3P7oalO7`Oo
Cdm?1olM7Ad6oc`l?0Kooooo1_l<30`7o`h>3POo30`<1ol=3@d7oaXJ6POo51@D1ol:2PX6obd];@Ko
oooo1omZJVX7ooooo`Ko5ADE1om;Bd/7obDU9@OoCdm?1olY:BT6oeYJFPKooooo1olP8207o`H61POo
0`<31olD51@6obh^;POoE5AD1omZJVX6oc/k>`Kooooo1olW9bL7oaLG5`Oo<c<c1olL71`7oalO7`Oo
oooo1_lW9bL6oaXJ6PKooooo1olA4A47oh>3P`Oo71`L1ol92@T7obDU9@Oo2`/;1om<C4`6oeiNGPGo
oooo1ol92@T7oc@d=0Oo<c<c1omQHF47og5aL@Oo7AdM1omBDU86ooKfmPgooooo000;ooooo`Oo2@T9
1olB4Q87oalO7`Oo5ADE1ol820P7oa8B4POo6a/K1_lF5QH5ooooo`OoGUiN1ol_;bl7ob@T90Oo>3Ph
1olO7al7odm?C`Oo7AdM1_ll?3`6ooooo`Ko30`<1ol>3Ph7o``<30Oo3@d=1olJ6QX7oa@D50Oo2PX:
1_l];Bd6ooooo`OoJVYZ1oooool6oaDE5@OoBd];1olU9BD7odm?C`Oo:BTY1_mJFUX6ooooo`Oo820P
1ol61PH7o`<30`Oo51@D1_l^;Rh7oeADE0OoJVYZ1_lk>c/6ooooo`Oo9bLW1olG5aL7oc<c<`Oo71`L
1olO7al7ooooo`Ko9bLW1_lJ6QX6ooooo`Oo4A4A1on3Ph<7oa`L70Oo2@T91olU9BD7o`/;2`OoC4a<
1_mNGUh5ooooo`Oo2@T91old=3@7oc<c<`OoHF5Q1omaLG47oadM7@OoDU9B1_ofm_H=ooooo`002ooo
ool7o`T92@Oo4Q8B1olO7al7oaDE5@Oo20P81olB4Q87oa/K6`Ko5QHF1Oooool7oeiNGPOo;bl_1olT
92@7ocPh>0Oo7alO1om?Cdl7oadM7@Ko?3`l1_ooool6o``<30Oo3Ph>1ol<30`7o`d=3@Oo6QXJ1olD
51@7o`X:2PKo;Bd]1_ooool7ofYZJPOooooo1_lE5AD7od];B`Oo9BDU1om?Cdl7obTY:@KoFUYJ1_oo
ool7ob0P80Oo1PH61ol30`<7oa@D50Ko;Rh^1omDE5@7ofYZJPKo>c/k1_ooool7obLW9`Oo5aLG1olc
<c<7oa`L70Oo7alO1oooool6obLW9`Ko6QXJ1_ooool7oa4A4@OoPh>31olL71`7o`T92@Oo9BDU1ol;
2`/7oda<C0KoGUiN1Oooool7o`T92@Oo=3@d1olc<c<7of5QH@OoLG5a1olM7Ad7oe9BDPKom_Kf3Ooo
ool000_ooooo1ol92@T7oa8B4POo7alO1olE5AD7o`P820Oo4Q8B1olK6a/6oaHF5PGooooo1omNGUh7
obl_;`Oo92@T1olh>3P7oalO7`OoCdm?1olM7Ad6oc`l?0Kooooo1_l<30`7o`h>3POo30`<1ol=3@d7
oaXJ6POo51@D1ol:2PX6obd];@Kooooo1omZJVX7ooooo`Ko5ADE1om;Bd/7obDU9@OoCdm?1olY:BT6
oeYJFPKooooo1olP8207o`H61POo0`<31olD51@6obh^;POoE5AD1omZJVX6oc/k>`Kooooo1olW9bL7
oaLG5`Oo<c<c1olL71`7oalO7`Oooooo1_lW9bL6oaXJ6PKooooo1olA4A47oh>3P`Oo71`L1ol92@T7
obDU9@Oo2`/;1om<C4`6oeiNGPGooooo1ol92@T7oc@d=0Oo<c<c1omQHF47og5aL@Oo7AdM1omBDU86
ooKfmPgooooo000;ooooo`Oo2@T91olB4Q87oalO7`Oo5ADE1ol820P7oa8B4POo6a/K1_lF5QH5oooo
o`OoGUiN1ol_;bl7ob@T90Oo>3Ph1olO7al7odm?C`Oo7AdM1_ll?3`6ooooo`Ko30`<1ol>3Ph7o``<
30Oo3@d=1olJ6QX7oa@D50Oo2PX:1_l];Bd6ooooo`OoJVYZ1oooool6oaDE5@OoBd];1olU9BD7odm?
C`Oo:BTY1_mJFUX6ooooo`Oo820P1ol61PH7o`<30`Oo51@D1_l^;Rh7oeADE0OoJVYZ1_lk>c/6oooo
o`Oo9bLW1olG5aL7oc<c<`Oo71`L1olO7al7ooooo`Ko9bLW1_lJ6QX6ooooo`Oo4A4A1on3Ph<7oa`L
70Oo2@T91olU9BD7o`/;2`OoC4a<1_mNGUh5ooooo`Oo2@T91old=3@7oc<c<`OoHF5Q1omaLG47oadM
7@OoDU9B1_ofm_H=ooooo`002oooool7o`T92@Oo4Q8B1olO7al7oaDE5@Oo20P81olB4Q87oa/K6`Ko
5QHF1Oooool7oeiNGPOo;bl_1olT92@7ocPh>0Oo7alO1om?Cdl7oadM7@Ko?3`l1_ooool6o``<30Oo
3Ph>1ol<30`7o`d=3@Oo6QXJ1olD51@7o`X:2PKo;Bd]1_ooool7ofYZJPOooooo1_lE5AD7od];B`Oo
9BDU1om?Cdl7obTY:@KoFUYJ1_ooool7ob0P80Oo1PH61ol30`<7oa@D50Ko;Rh^1omDE5@7ofYZJPKo
>c/k1_ooool7obLW9`Oo5aLG1olc<c<7oa`L70Oo7alO1oooool6obLW9`Ko6QXJ1_ooool7oa4A4@Oo
Ph>31olL71`7o`T92@Oo9BDU1ol;2`/7oda<C0KoGUiN1Oooool7o`T92@Oo=3@d1olc<c<7of5QH@Oo
LG5a1olM7Ad7oe9BDPKom_Kf3Oooool000_ooooo1ol92@T7oa8B4POo7alO1olE5AD7o`P820Oo4Q8B
1olK6a/6oaHF5PGooooo1omNGUh7obl_;`Oo92@T1olh>3P7oalO7`OoCdm?1olM7Ad6oc`l?0Kooooo
1_l<30`7o`h>3POo30`<1ol=3@d7oaXJ6POo51@D1ol:2PX6obd];@Kooooo1omZJVX7ooooo`Ko5ADE
1om;Bd/7obDU9@OoCdm?1olY:BT6oeYJFPKooooo1olP8207o`H61POo0`<31olD51@6obh^;POoE5AD
1omZJVX6oc/k>`Kooooo1olW9bL7oaLG5`Oo<c<c1olL71`7oalO7`Oooooo1_lW9bL6oaXJ6PKooooo
1olA4A47oh>3P`Oo71`L1ol92@T7obDU9@Oo2`/;1om<C4`6oeiNGPGooooo1ol92@T7oc@d=0Oo<c<c
1omQHF47og5aL@Oo7AdM1omBDU86ooKfmPgooooo000;ooooo`Oo1`L71olG5aL7ob0P80Oo51@D1olA
4A47o`l?3`Oo3Ph>1_lH61P5ooooo`OoLW9b1old=3@7ob4Q8@OoA4A41ol00007oc`l?0Oo:RXZ1_l`
<306ooooo`go7QhN1olC4a<7o`l?3`Oo61PH1olJ6QX7oadM7@Ko:BTY1_ooool7oe9BDPOoinOW1_l2
0P87oda<C0OoEEEE1omGEeL7ogmoO`KoMGEe1_ooool7ocLg=`Oo9bLW1ol:2PX7o`l?3`Ko8B4Q1olf
=SH7odU9B@Ko>c/k1_ooool7ocPh>0Oo5aLG1ol/;2`7ocTi>@Oo7alO1omOGel6o``<30Ko>3Ph1_oo
ool7oahN7POoRXZ:1olf=SH7ob`/;0Oo:RXZ1olB4Q87ofATI0KoNWYj1Oooool7o`X:2POo:RXZ1olV
9RH7obPX:0OoIfMW1olJ6QX7ofIVIPKo];Bd3Oooool000_ooooo1ol71`L7oaLG5`Oo820P1olD51@7
oa4A4@Oo3`l?1ol>3Ph6oaPH60Gooooo1ombLW87oc@d=0Oo8B4Q1om4A4@7o`0000Oo?3`l1olZ:RX6
oc0`<0Kooooo3OlN7Qh7oa<C4`Oo3`l?1olH61P7oaXJ6POo7AdM1_lY:BT6ooooo`OoDU9B1ooWinL6
o`820POoC4a<1omEEED7oeMGE`OoOgmo1_meMGD6ooooo`Oo=cLg1olW9bL7o`X:2POo3`l?1_lQ8B47
ocHf=POoBDU91_lk>c/6ooooo`Oo>3Ph1olG5aL7ob`/;0Oo>CTi1olO7al7oemOG`Ko30`<1_lh>3P6
ooooo`Oo7QhN1on:RXX7ocHf=POo;2`/1olZ:RX7oa8B4POoI6AT1_mjNWX5ooooo`Oo2PX:1olZ:RX7
obHV9POo:2PX1omWIfL7oaXJ6POoIVIV1_nd];@=ooooo`002oooool7o`L71`Oo5aLG1olP8207oa@D
50Oo4A4A1ol?3`l7o`h>3PKo61PH1Oooool7og9bLPOo=3@d1olQ8B47odA4A0Oo00001oll?3`7obXZ
:PKo<30`1_ooool=oahN7POo4a<C1ol?3`l7oaPH60Oo6QXJ1olM7Ad6obTY:@Kooooo1omBDU87onOW
i`Ko0P821om<C4`7oeEEE@OoEeMG1omoOgl6ogEeM@Kooooo1olg=cL7obLW9`Oo2PX:1ol?3`l6ob4Q
8@Oo=SHf1om9BDT6oc/k>`Kooooo1olh>3P7oaLG5`Oo;2`/1oli>CT7oalO7`OoGemO1_l<30`6ocPh
>0Kooooo1olN7Qh7ohZ:RPOo=SHf1ol/;2`7obXZ:POo4Q8B1omTI6@6ogYjNPGooooo1ol:2PX7obXZ
:POo9RHV1olX:2P7ofMWI`Oo6QXJ1omVIVH6okBd]0gooooo000;ooooo`Oo1`L71olG5aL7ob0P80Oo
51@D1olA4A47o`l?3`Oo3Ph>1_lH61P5ooooo`OoLW9b1old=3@7ob4Q8@OoA4A41ol00007oc`l?0Oo
:RXZ1_l`<306ooooo`go7QhN1olC4a<7o`l?3`Oo61PH1olJ6QX7oadM7@Ko:BTY1_ooool7oe9BDPOo
inOW1_l20P87oda<C0OoEEEE1omGEeL7ogmoO`KoMGEe1_ooool7ocLg=`Oo9bLW1ol:2PX7o`l?3`Ko
8B4Q1olf=SH7odU9B@Ko>c/k1_ooool7ocPh>0Oo5aLG1ol/;2`7ocTi>@Oo7alO1omOGel6o``<30Ko
>3Ph1_ooool7oahN7POoRXZ:1olf=SH7ob`/;0Oo:RXZ1olB4Q87ofATI0KoNWYj1Oooool7o`X:2POo
:RXZ1olV9RH7obPX:0OoIfMW1olJ6QX7ofIVIPKo];Bd3Oooool000_ooooo1ol71`L7oaLG5`Oo820P
1olD51@7oa4A4@Oo3`l?1ol>3Ph6oaPH60Gooooo1ombLW87oc@d=0Oo8B4Q1om4A4@7o`0000Oo?3`l
1olZ:RX6oc0`<0Kooooo3OlN7Qh7oa<C4`Oo3`l?1olH61P7oaXJ6POo7AdM1_lY:BT6ooooo`OoDU9B
1ooWinL6o`820POoC4a<1omEEED7oeMGE`OoOgmo1_meMGD6ooooo`Oo=cLg1olW9bL7o`X:2POo3`l?
1_lQ8B47ocHf=POoBDU91_lk>c/6ooooo`Oo>3Ph1olG5aL7ob`/;0Oo>CTi1olO7al7oemOG`Ko30`<
1_lh>3P6ooooo`Oo7QhN1on:RXX7ocHf=POo;2`/1olZ:RX7oa8B4POoI6AT1_mjNWX5ooooo`Oo2PX:
1olZ:RX7obHV9POo:2PX1omWIfL7oaXJ6POoIVIV1_nd];@=ooooo`002oooool7o`L71`Oo5aLG1olP
8207oa@D50Oo4A4A1ol?3`l7o`h>3PKo61PH1Oooool7og9bLPOo=3@d1olQ8B47odA4A0Oo00001oll
?3`7obXZ:PKo<30`1_ooool=oahN7POo4a<C1ol?3`l7oaPH60Oo6QXJ1olM7Ad6obTY:@Kooooo1omB
DU87onOWi`Ko0P821om<C4`7oeEEE@OoEeMG1omoOgl6ogEeM@Kooooo1olg=cL7obLW9`Oo2PX:1ol?
3`l6ob4Q8@Oo=SHf1om9BDT6oc/k>`Kooooo1olh>3P7oaLG5`Oo;2`/1oli>CT7oalO7`OoGemO1_l<
30`6ocPh>0Kooooo1olN7Qh7ohZ:RPOo=SHf1ol/;2`7obXZ:POo4Q8B1omTI6@6ogYjNPGooooo1ol:
2PX7obXZ:POo9RHV1olX:2P7ofMWI`Oo6QXJ1omVIVH6okBd]0gooooo000;ooooo`Oo7alO1oli>CT7
ooooo`OoBd];1olU9BD7obTY:@Oo;Bd]1_m8B4P5ooooo`OoGemO1ole=CD7of=SH`OoJVYZ1olS8b<7
odY:BPOo6ATI1_l?3`l6ooooo`Ko;Rh^1olL71`7ocXj>POo6QXJ1olb<S87od];B`Oo;2`/3?ooool7
oe5AD@OoMWIf1_lV9RH7ofMWI`Oo?3`l1om4A4@7oeaLG0Ko:b/[1_ooool7obd];@Oo5QHF1ol/;2`=
ob0P80OoJVYZ1oooool6ofQXJ0Kooooo1ol;2`/7oa4A4@Oo71`L1olT92@7obLW9`Oo>SXj1_l71`L6
o`410@Kooooo1olW9bL7odi>CPOo>c/k3_n4Q8@7oahN7POoF5QH1_oHf=P5ooooo`Oo30`<1ol^;Rh7
oa0@40Oo8R8R1olK6a/7oaLG5`Oo:RXZ1_l^;Rh=ooooo`002oooool7oalO7`Oo>CTi1oooool7od];
B`Oo9BDU1olY:BT7obd];@KoB4Q81Oooool7oemOG`Oo=CDe1omSHf<7ofYZJPOo8b<S1om:BTX7oaTI
6@Ko3`l?1_ooool6obh^;POo71`L1olj>SX7oaXJ6POo<S8b1om;Bd/7ob`/;0cooooo1omADE47ogIf
MPKo9RHV1omWIfL7oc`l?0OoA4A41omLG5`6ob/[:`Kooooo1ol];Bd7oaHF5POo;2`/3OlP8207ofYZ
JPOooooo1_mXJ6P6ooooo`Oo2`/;1olA4A47oa`L70Oo92@T1olW9bL7ocXj>PKo1`L71_l10@46oooo
o`Oo9bLW1om>CTh7oc/k>`koQ8B41olN7Qh7oeQHF0Kof=SH1Oooool7o``<30Oo;Rh^1ol@4107ob8R
8POo6a/K1olG5aL7obXZ:PKo;Rh^3Oooool000_ooooo1olO7al7ocTi>@Oooooo1om;Bd/7obDU9@Oo
:BTY1ol];Bd6odQ8B0Gooooo1omOGel7ocDe=@OoHf=S1omZJVX7ob<S8`OoBTY:1olI6AT6o`l?3`Ko
oooo1_l^;Rh7oa`L70Oo>SXj1olJ6QX7oc8b<POoBd];1ol/;2`<ooooo`OoDE5A1omfMWH6obHV9POo
IfMW1oll?3`7odA4A0OoG5aL1_l[:b/6ooooo`Oo;Bd]1olF5QH7ob`/;0go820P1omZJVX7ooooo`Ko
J6QX1_ooool7o`/;2`Oo4A4A1olL71`7ob@T90Oo9bLW1olj>SX6o`L71`Ko0@411_ooool7obLW9`Oo
CTi>1olk>c/>ohB4Q0Oo7QhN1omHF5P6omSHf0Gooooo1ol<30`7obh^;POo410@1olR8R87oa/K6`Oo
5aLG1olZ:RX6obh^;Pgooooo000;ooooo`Oo7alO1oli>CT7ooooo`OoBd];1olU9BD7obTY:@Oo;Bd]
1_m8B4P5ooooo`OoGemO1ole=CD7of=SH`OoJVYZ1olS8b<7odY:BPOo6ATI1_l?3`l6ooooo`Ko;Rh^
1olL71`7ocXj>POo6QXJ1olb<S87od];B`Oo;2`/3?ooool7oe5AD@OoMWIf1_lV9RH7ofMWI`Oo?3`l
1om4A4@7oeaLG0Ko:b/[1_ooool7obd];@Oo5QHF1ol/;2`=ob0P80OoJVYZ1oooool6ofQXJ0Kooooo
1ol;2`/7oa4A4@Oo71`L1olT92@7obLW9`Oo>SXj1_l71`L6o`410@Kooooo1olW9bL7odi>CPOo>c/k
3_n4Q8@7oahN7POoF5QH1_oHf=P5ooooo`Oo30`<1ol^;Rh7oa0@40Oo8R8R1olK6a/7oaLG5`Oo:RXZ
1_l^;Rh=ooooo`002oooool7oalO7`Oo>CTi1oooool7od];B`Oo9BDU1olY:BT7obd];@KoB4Q81Ooo
ool7oemOG`Oo=CDe1omSHf<7ofYZJPOo8b<S1om:BTX7oaTI6@Ko3`l?1_ooool6obh^;POo71`L1olj
>SX7oaXJ6POo<S8b1om;Bd/7ob`/;0cooooo1omADE47ogIfMPKo9RHV1omWIfL7oc`l?0OoA4A41omL
G5`6ob/[:`Kooooo1ol];Bd7oaHF5POo;2`/3OlP8207ofYZJPOooooo1_mXJ6P6ooooo`Oo2`/;1olA
4A47oa`L70Oo92@T1olW9bL7ocXj>PKo1`L71_l10@46ooooo`Oo9bLW1om>CTh7oc/k>`koQ8B41olN
7Qh7oeQHF0Kof=SH1Oooool7o``<30Oo;Rh^1ol@4107ob8R8POo6a/K1olG5aL7obXZ:PKo;Rh^3Ooo
ool000_ooooo1olO7al7ocTi>@Oooooo1om;Bd/7obDU9@Oo:BTY1ol];Bd6odQ8B0Gooooo1omOGel7
ocDe=@OoHf=S1omZJVX7ob<S8`OoBTY:1olI6AT6o`l?3`Kooooo1_l^;Rh7oa`L70Oo>SXj1olJ6QX7
oc8b<POoBd];1ol/;2`<ooooo`OoDE5A1omfMWH6obHV9POoIfMW1oll?3`7odA4A0OoG5aL1_l[:b/6
ooooo`Oo;Bd]1olF5QH7ob`/;0go820P1omZJVX7ooooo`KoJ6QX1_ooool7o`/;2`Oo4A4A1olL71`7
ob@T90Oo9bLW1olj>SX6o`L71`Ko0@411_ooool7obLW9`OoCTi>1olk>c/>ohB4Q0Oo7QhN1omHF5P6
omSHf0Gooooo1ol<30`7obh^;POo410@1olR8R87oa/K6`Oo5aLG1olZ:RX6obh^;Pgooooo000;oooo
o`Oo7alO1oli>CT7ooooo`OoBd];1olU9BD7obTY:@Oo;Bd]1_m8B4P5ooooo`OoGemO1ole=CD7of=S
H`OoJVYZ1olS8b<7odY:BPOo6ATI1_l?3`l6ooooo`Ko;Rh^1olL71`7ocXj>POo6QXJ1olb<S87od];
B`Oo;2`/3?ooool7oe5AD@OoMWIf1_lV9RH7ofMWI`Oo?3`l1om4A4@7oeaLG0Ko:b/[1_ooool7obd]
;@Oo5QHF1ol/;2`=ob0P80OoJVYZ1oooool6ofQXJ0Kooooo1ol;2`/7oa4A4@Oo71`L1olT92@7obLW
9`Oo>SXj1_l71`L6o`410@Kooooo1olW9bL7odi>CPOo>c/k3_n4Q8@7oahN7POoF5QH1_oHf=P5oooo
o`Oo30`<1ol^;Rh7oa0@40Oo8R8R1olK6a/7oaLG5`Oo:RXZ1_l^;Rh=ooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`002oooool7obLW9`Oo4a<C1olB4Q87o`820POo6a/K1ol92@T7o``<30Ko8R8R1Ooo
ool7oa`L70Oo410@1ol];Bd7oaPH60Oo6QXJ1ol>3Ph7oa@D50Ko?3`l1_ooool6obHV9POo20P81ol:
2PX7o`d=3@Oo1`L71ol<30`7oa0@40Ko@T921_ooool7oda<C0OoUiNG1_lI6AT7odI6APOo;bl_1olB
4Q8=oc@d=0Kooooo1ol820P7o`H61POo820P1oln?Sh6oaXJ6POo4A4A1ol<30`6oaHF5PKooooo1omK
Fe/7oaTI6@Oo>SXj1ol[:b/7oc4a<@Oooooo1_lJ6QX6ofa/K0Kooooo1oli>CT7oda<C0Oooooo1olA
4A47odY:BPOo820P1onMWId6ogYjNPGooooo1ol820P7ocdm?@Oo0@411olG5aL7o`/;2`Oo7QhN1olK
6a/6ob0P80gooooo000;ooooo`Oo9bLW1olC4a<7oa8B4POo0P821olK6a/7o`T92@Oo30`<1_lR8R85
ooooo`Oo71`L1ol@4107obd];@Oo61PH1olJ6QX7o`h>3POo51@D1_ll?3`6ooooo`Ko9RHV1ol820P7
o`X:2POo3@d=1ol71`L7o``<30Oo410@1_m2@T86ooooo`OoC4a<1onGUiL6oaTI6@OoATI61ol_;bl7
oa8B4Pgo=3@d1_ooool7o`P820Oo1PH61olP8207ochn?PKo6QXJ1olA4A47o``<30Ko5QHF1_ooool7
oe]KF`Oo6ATI1olj>SX7ob/[:`Oo<C4a1oooool6oaXJ6PKoK6a/1_ooool7ocTi>@OoC4a<1oooool7
oa4A4@OoBTY:1olP8207oifMW@KoNWYj1Oooool7o`P820Oo?Cdm1ol10@47oaLG5`Oo2`/;1olN7Qh7
oa/K6`Ko820P3Oooool000_ooooo1olW9bL7oa<C4`Oo4Q8B1ol20P87oa/K6`Oo2@T91ol<30`6ob8R
8PGooooo1olL71`7oa0@40Oo;Bd]1olH61P7oaXJ6POo3Ph>1olD51@6oc`l?0Kooooo1_lV9RH7o`P8
20Oo2PX:1ol=3@d7o`L71`Oo30`<1ol@4106od92@PKooooo1om<C4`7oiNGU`Ko6ATI1om6ATH7obl_
;`Oo4Q8B3Old=3@6ooooo`Oo20P81ol61PH7ob0P80Oo?Shn1_lJ6QX7oa4A4@Oo30`<1_lF5QH6oooo
o`OoFe]K1olI6AT7ocXj>POo:b/[1ola<C47ooooo`Ko6QXJ1_m/K6`6ooooo`Oo>CTi1om<C4`7oooo
o`Oo4A4A1om:BTX7ob0P80OoWIfM1_mjNWX5ooooo`Oo20P81olm?Cd7o`410@Oo5aLG1ol;2`/7oahN
7POo6a/K1_lP820=ooooo`002oooool7obLW9`Oo4a<C1olB4Q87o`820POo6a/K1ol92@T7o``<30Ko
8R8R1Oooool7oa`L70Oo410@1ol];Bd7oaPH60Oo6QXJ1ol>3Ph7oa@D50Ko?3`l1_ooool6obHV9POo
20P81ol:2PX7o`d=3@Oo1`L71ol<30`7oa0@40Ko@T921_ooool7oda<C0OoUiNG1_lI6AT7odI6APOo
;bl_1olB4Q8=oc@d=0Kooooo1ol820P7o`H61POo820P1oln?Sh6oaXJ6POo4A4A1ol<30`6oaHF5PKo
oooo1omKFe/7oaTI6@Oo>SXj1ol[:b/7oc4a<@Oooooo1_lJ6QX6ofa/K0Kooooo1oli>CT7oda<C0Oo
oooo1olA4A47odY:BPOo820P1onMWId6ogYjNPGooooo1ol820P7ocdm?@Oo0@411olG5aL7o`/;2`Oo
7QhN1olK6a/6ob0P80gooooo000;ooooo`Oo9bLW1olC4a<7oa8B4POo0P821olK6a/7o`T92@Oo30`<
1_lR8R85ooooo`Oo71`L1ol@4107obd];@Oo61PH1olJ6QX7o`h>3POo51@D1_ll?3`6ooooo`Ko9RHV
1ol820P7o`X:2POo3@d=1ol71`L7o``<30Oo410@1_m2@T86ooooo`OoC4a<1onGUiL6oaTI6@OoATI6
1ol_;bl7oa8B4Pgo=3@d1_ooool7o`P820Oo1PH61olP8207ochn?PKo6QXJ1olA4A47o``<30Ko5QHF
1_ooool7oe]KF`Oo6ATI1olj>SX7ob/[:`Oo<C4a1oooool6oaXJ6PKoK6a/1_ooool7ocTi>@OoC4a<
1oooool7oa4A4@OoBTY:1olP8207oifMW@KoNWYj1Oooool7o`P820Oo?Cdm1ol10@47oaLG5`Oo2`/;
1olN7Qh7oa/K6`Ko820P3Oooool000_ooooo1olW9bL7oa<C4`Oo4Q8B1ol20P87oa/K6`Oo2@T91ol<
30`6ob8R8PGooooo1olL71`7oa0@40Oo;Bd]1olH61P7oaXJ6POo3Ph>1olD51@6oc`l?0Kooooo1_lV
9RH7o`P820Oo2PX:1ol=3@d7o`L71`Oo30`<1ol@4106od92@PKooooo1om<C4`7oiNGU`Ko6ATI1om6
ATH7obl_;`Oo4Q8B3Old=3@6ooooo`Oo20P81ol61PH7ob0P80Oo?Shn1_lJ6QX7oa4A4@Oo30`<1_lF
5QH6ooooo`OoFe]K1olI6AT7ocXj>POo:b/[1ola<C47ooooo`Ko6QXJ1_m/K6`6ooooo`Oo>CTi1om<
C4`7ooooo`Oo4A4A1om:BTX7ob0P80OoWIfM1_mjNWX5ooooo`Oo20P81olm?Cd7o`410@Oo5aLG1ol;
2`/7oahN7POo6a/K1_lP820=ooooo`002oooool>o`h>3POo30`<1ol92@T7o`D51@Oo0`<31ol51@D6
oa@D50Gooooo1olB4Q87o``<30Oo?clo1ol=3@d7o`0000Oo4Q8B1ol92@T6oc4a<@Kooooo1_lT92@7
oa<C4`Oo1@D51ol92@T7o`d=3@Oo2@T91olB4Q86obh^;PKooooo1om@D507ooooo`Ko7QhN1om6ATH7
odE5A@Oo9RHV1ol_;bl6ob/[:`Kooooo1ol92@T7o`h>3POo20P81olG5aL6o`P820Oo5aLG1olC4a<6
oadM7@Kooooo1om4A4@7o`l?3`Oo@D511ola<C47od92@POoWYjN1_l`<306oe5AD@Kooooo1omHF5P7
od];B`Ooa/K61ol30`<7oeYJFPOo7AdM1omcLg<6oginOPGooooo1ol=3@d7obPX:0Oo2PX:1olO7al7
oa@D50Oo4Q8B1olR8R86obHV9Pgooooo000;ooooo`ko3Ph>1ol<30`7o`T92@Oo1@D51ol30`<7o`D5
1@Ko51@D1Oooool7oa8B4POo30`<1olo?cl7o`d=3@Oo00001olB4Q87o`T92@Ko<C4a1_ooool6ob@T
90Oo4a<C1ol51@D7o`T92@Oo3@d=1ol92@T7oa8B4PKo;Rh^1_ooool7oe1@D0Oooooo1_lN7Qh7odI6
APOoADE51olV9RH7obl_;`Ko:b/[1_ooool7o`T92@Oo3Ph>1ol820P7oaLG5`Ko20P81olG5aL7oa<C
4`Ko7AdM1_ooool7odA4A0Oo3`l?1om1@D47oc4a<@Oo@T921onNWYh6oc0`<0KoDE5A1_ooool7oeQH
F0OoBd];1oo6a/H7o`<30`OoFUYJ1olM7Ad7og=cL`KoOWin1Oooool7o`d=3@Oo:2PX1ol:2PX7oalO
7`Oo51@D1olB4Q87ob8R8PKo9RHV3Oooool000_ooooo3_l>3Ph7o``<30Oo2@T91ol51@D7o`<30`Oo
1@D51_lD51@5ooooo`Oo4Q8B1ol<30`7oclo?`Oo3@d=1ol00007oa8B4POo2@T91_la<C46ooooo`Ko
92@T1olC4a<7o`D51@Oo2@T91ol=3@d7o`T92@Oo4Q8B1_l^;Rh6ooooo`OoD51@1oooool6oahN7POo
ATI61om5ADD7obHV9POo;bl_1_l[:b/6ooooo`Oo2@T91ol>3Ph7o`P820Oo5aLG1_l820P7oaLG5`Oo
4a<C1_lM7Ad6ooooo`OoA4A41ol?3`l7od51@@Oo<C4a1om2@T87oijNWPKo<30`1_mADE46ooooo`Oo
F5QH1om;Bd/7olK6aPOo0`<31omJFUX7oadM7@OoLg=c1_mnOWh5ooooo`Oo3@d=1olX:2P7o`X:2POo
7alO1olD51@7oa8B4POo8R8R1_lV9RH=ooooo`002oooool>o`h>3POo30`<1ol92@T7o`D51@Oo0`<3
1ol51@D6oa@D50Gooooo1olB4Q87o``<30Oo?clo1ol=3@d7o`0000Oo4Q8B1ol92@T6oc4a<@Kooooo
1_lT92@7oa<C4`Oo1@D51ol92@T7o`d=3@Oo2@T91olB4Q86obh^;PKooooo1om@D507ooooo`Ko7QhN
1om6ATH7odE5A@Oo9RHV1ol_;bl6ob/[:`Kooooo1ol92@T7o`h>3POo20P81olG5aL6o`P820Oo5aLG
1olC4a<6oadM7@Kooooo1om4A4@7o`l?3`Oo@D511ola<C47od92@POoWYjN1_l`<306oe5AD@Kooooo
1omHF5P7od];B`Ooa/K61ol30`<7oeYJFPOo7AdM1omcLg<6oginOPGooooo1ol=3@d7obPX:0Oo2PX:
1olO7al7oa@D50Oo4Q8B1olR8R86obHV9Pgooooo000;ooooo`ko3Ph>1ol<30`7o`T92@Oo1@D51ol3
0`<7o`D51@Ko51@D1Oooool7oa8B4POo30`<1olo?cl7o`d=3@Oo00001olB4Q87o`T92@Ko<C4a1_oo
ool6ob@T90Oo4a<C1ol51@D7o`T92@Oo3@d=1ol92@T7oa8B4PKo;Rh^1_ooool7oe1@D0Oooooo1_lN
7Qh7odI6APOoADE51olV9RH7obl_;`Ko:b/[1_ooool7o`T92@Oo3Ph>1ol820P7oaLG5`Ko20P81olG
5aL7oa<C4`Ko7AdM1_ooool7odA4A0Oo3`l?1om1@D47oc4a<@Oo@T921onNWYh6oc0`<0KoDE5A1_oo
ool7oeQHF0OoBd];1oo6a/H7o`<30`OoFUYJ1olM7Ad7og=cL`KoOWin1Oooool7o`d=3@Oo:2PX1ol:
2PX7oalO7`Oo51@D1olB4Q87ob8R8PKo9RHV3Oooool000_ooooo3_l>3Ph7o``<30Oo2@T91ol51@D7
o`<30`Oo1@D51_lD51@5ooooo`Oo4Q8B1ol<30`7oclo?`Oo3@d=1ol00007oa8B4POo2@T91_la<C46
ooooo`Ko92@T1olC4a<7o`D51@Oo2@T91ol=3@d7o`T92@Oo4Q8B1_l^;Rh6ooooo`OoD51@1oooool6
oahN7POoATI61om5ADD7obHV9POo;bl_1_l[:b/6ooooo`Oo2@T91ol>3Ph7o`P820Oo5aLG1_l820P7
oaLG5`Oo4a<C1_lM7Ad6ooooo`OoA4A41ol?3`l7od51@@Oo<C4a1om2@T87oijNWPKo<30`1_mADE46
ooooo`OoF5QH1om;Bd/7olK6aPOo0`<31omJFUX7oadM7@OoLg=c1_mnOWh5ooooo`Oo3@d=1olX:2P7
o`X:2POo7alO1olD51@7oa8B4POo8R8R1_lV9RH=ooooo`002oooool>o`h>3POo30`<1ol92@T7o`D5
1@Oo0`<31ol51@D6oa@D50Gooooo1olB4Q87o``<30Oo?clo1ol=3@d7o`0000Oo4Q8B1ol92@T6oc4a
<@Kooooo1_lT92@7oa<C4`Oo1@D51ol92@T7o`d=3@Oo2@T91olB4Q86obh^;PKooooo1om@D507oooo
o`Ko7QhN1om6ATH7odE5A@Oo9RHV1ol_;bl6ob/[:`Kooooo1ol92@T7o`h>3POo20P81olG5aL6o`P8
20Oo5aLG1olC4a<6oadM7@Kooooo1om4A4@7o`l?3`Oo@D511ola<C47od92@POoWYjN1_l`<306oe5A
D@Kooooo1omHF5P7od];B`Ooa/K61ol30`<7oeYJFPOo7AdM1omcLg<6oginOPGooooo1ol=3@d7obPX
:0Oo2PX:1olO7al7oa@D50Oo4Q8B1olR8R86obHV9Pgooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo
2@T91ol;2`/7o`d=3@Oo30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko
6a/K1_ooool6oa8B4POo2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo
]KFe1_lG5aL7odA4A0OoRXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko
3Ph>3_lA4A46oaDE5@Kooooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Ko
oooo1ole=CD7oaHF5POoYjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo
00001olD51@7o`D51@Oo7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T9
1ol;2`/7o`d=3@Oo30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K
1_ooool6oa8B4POo2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe
1_lG5aL7odA4A0OoRXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>
3_lA4A46oaDE5@Kooooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo
1ole=CD7oaHF5POoYjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo0000
1olD51@7o`D51@Oo7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T91ol;
2`/7o`d=3@Oo30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K1_oo
ool6oa8B4POo2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe1_lG
5aL7odA4A0OoRXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>3_lA
4A46oaDE5@Kooooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo1ole
=CD7oaHF5POoYjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo00001olD
51@7o`D51@Oo7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T91ol;2`/7
o`d=3@Oo30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K1_ooool6
oa8B4POo2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe1_lG5aL7
odA4A0OoRXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>3_lA4A46
oaDE5@Kooooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo1ole=CD7
oaHF5POoYjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo00001olD51@7
o`D51@Oo7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T91ol;2`/7o`d=
3@Oo30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K1_ooool6oa8B
4POo2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe1_lG5aL7odA4
A0OoRXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>3_lA4A46oaDE
5@Kooooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo1ole=CD7oaHF
5POoYjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo00001olD51@7o`D5
1@Oo7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T91ol;2`/7o`d=3@Oo
30`<1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K1_ooool6oa8B4POo
2`/;1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe1_lG5aL7odA4A0Oo
RXZ:1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>3_lA4A46oaDE5@Ko
oooo1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo1ole=CD7oaHF5POo
YjNW1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo00001olD51@7o`D51@Oo
7QhN1olK6a/6ob`/;0gooooo000;ooooo`Oo8R8R1olD51@7oaHF5POo2@T91ol;2`/7o`d=3@Oo30`<
1_lH61P5ooooo`Oo2`/;1ol:2PX7odI6APko5aLG1olB4Q87oa<C4`Ko6a/K1_ooool6oa8B4POo2`/;
1ol@4107oaDE5@Oo71`L1ol92@T7oa0@40Ko;Bd]1_ooool7ocLg=`Oo]KFe1_lG5aL7odA4A0OoRXZ:
1ol>3Ph7oc`l?0Ko9BDU1_ooool7o`@410Oo1`L71ol>3Ph7oadM7@Ko3Ph>3_lA4A46oaDE5@Kooooo
1ol];Bd7o`0000OoQhN71olL71`7o`P820Oo?3`l1_l:2PX6oe5AD@Kooooo1ole=CD7oaHF5POoYjNW
1ol=3@d7of][J`Oo:2PX1omXJ6P6ohZ:RPGooooo1olD51@7ob<S8`Oo00001olD51@7o`D51@Oo7QhN
1olK6a/6ob`/;0gooooo000;ooooo`ko4Q8B1olD51@7o``<30Oo3@d=1olB4Q87o`D51@Ko71`L1Ooo
ool7ocHf=POo5aLG1om]KFd7obTY:@ko7AdM1ol10@46od10@0Kooooo1_lZ:RX7oaLG5`Oo4A4A3_lN
7Qh7o`X:2POo61PH1_lj>SX6ooooo`Oo<C4a1onGUiL6oa<C4`Oo=cLg1onWYjL7ocDe=@Oo8b<S1_lY
:BT6ooooo`Oo1PH61ol<30`7o`T92@Oo410@1_lB4Q87o`T92@Oo5ADE1_lR8R86ooooo`Oo;2`/1olL
71`7oginOPOo>SXj1olG5aL7ob/[:`Ko4A4A1_lc<c<6ooooo`Oo6ATI1olA4A47oeeMG@Oo61PH1olU
9BD7ob/[:`Oo<30`1_nBTY85ooooo`Oo820P1olD51@7o`P820Oo9bLW1ol820P7oadM7@Oo5ADE1_lR
8R8=ooooo`002oooool>oa8B4POo51@D1ol<30`7o`d=3@Oo4Q8B1ol51@D6oa`L70Gooooo1olf=SH7
oaLG5`OoKFe]1olY:BT>oadM7@Oo0@411_m0@406ooooo`Ko:RXZ1olG5aL7oa4A4@ko7QhN1ol:2PX7
oaPH60Ko>SXj1_ooool7oc4a<@OoUiNG1_lC4a<7ocLg=`OoYjNW1ole=CD7ob<S8`Ko:BTY1_ooool7
o`H61POo30`<1ol92@T7oa0@40Ko4Q8B1ol92@T7oaDE5@Ko8R8R1_ooool7ob`/;0Oo71`L1omnOWh7
ocXj>POo5aLG1ol[:b/6oa4A4@Ko<c<c1_ooool7oaTI6@Oo4A4A1omMGEd7oaPH60Oo9BDU1ol[:b/7
oc0`<0KoTY:B1Oooool7ob0P80Oo51@D1ol820P7obLW9`Oo20P81olM7Ad7oaDE5@Ko8R8R3Oooool0
00_ooooo3_lB4Q87oa@D50Oo30`<1ol=3@d7oa8B4POo1@D51_lL71`5ooooo`Oo=SHf1olG5aL7ofe]
K@Oo:BTY3_lM7Ad7o`410@Ko@4101_ooool6obXZ:POo5aLG1olA4A4>oahN7POo2PX:1olH61P6ocXj
>PKooooo1ola<C47oiNGU`Ko4a<C1olg=cL7ojNWY`Oo=CDe1olS8b<6obTY:@Kooooo1ol61PH7o``<
30Oo2@T91ol@4106oa8B4POo2@T91olE5AD6ob8R8PKooooo1ol/;2`7oa`L70OoOWin1olj>SX7oaLG
5`Oo:b/[1_lA4A46oc<c<`Kooooo1olI6AT7oa4A4@OoGEeM1olH61P7obDU9@Oo:b/[1ol`<306oi:B
TPGooooo1olP8207oa@D50Oo20P81olW9bL7o`P820Oo7AdM1olE5AD6ob8R8Pgooooo000;ooooo`ko
4Q8B1olD51@7o``<30Oo3@d=1olB4Q87o`D51@Ko71`L1Oooool7ocHf=POo5aLG1om]KFd7obTY:@ko
7AdM1ol10@46od10@0Kooooo1_lZ:RX7oaLG5`Oo4A4A3_lN7Qh7o`X:2POo61PH1_lj>SX6ooooo`Oo
<C4a1onGUiL6oa<C4`Oo=cLg1onWYjL7ocDe=@Oo8b<S1_lY:BT6ooooo`Oo1PH61ol<30`7o`T92@Oo
410@1_lB4Q87o`T92@Oo5ADE1_lR8R86ooooo`Oo;2`/1olL71`7oginOPOo>SXj1olG5aL7ob/[:`Ko
4A4A1_lc<c<6ooooo`Oo6ATI1olA4A47oeeMG@Oo61PH1olU9BD7ob/[:`Oo<30`1_nBTY85ooooo`Oo
820P1olD51@7o`P820Oo9bLW1ol820P7oadM7@Oo5ADE1_lR8R8=ooooo`002oooool>oa8B4POo51@D
1ol<30`7o`d=3@Oo4Q8B1ol51@D6oa`L70Gooooo1olf=SH7oaLG5`OoKFe]1olY:BT>oadM7@Oo0@41
1_m0@406ooooo`Ko:RXZ1olG5aL7oa4A4@ko7QhN1ol:2PX7oaPH60Ko>SXj1_ooool7oc4a<@OoUiNG
1_lC4a<7ocLg=`OoYjNW1ole=CD7ob<S8`Ko:BTY1_ooool7o`H61POo30`<1ol92@T7oa0@40Ko4Q8B
1ol92@T7oaDE5@Ko8R8R1_ooool7ob`/;0Oo71`L1omnOWh7ocXj>POo5aLG1ol[:b/6oa4A4@Ko<c<c
1_ooool7oaTI6@Oo4A4A1omMGEd7oaPH60Oo9BDU1ol[:b/7oc0`<0KoTY:B1Oooool7ob0P80Oo51@D
1ol820P7obLW9`Oo20P81olM7Ad7oaDE5@Ko8R8R3Oooool000_ooooo3_lB4Q87oa@D50Oo30`<1ol=
3@d7oa8B4POo1@D51_lL71`5ooooo`Oo=SHf1olG5aL7ofe]K@Oo:BTY3_lM7Ad7o`410@Ko@4101_oo
ool6obXZ:POo5aLG1olA4A4>oahN7POo2PX:1olH61P6ocXj>PKooooo1ola<C47oiNGU`Ko4a<C1olg
=cL7ojNWY`Oo=CDe1olS8b<6obTY:@Kooooo1ol61PH7o``<30Oo2@T91ol@4106oa8B4POo2@T91olE
5AD6ob8R8PKooooo1ol/;2`7oa`L70OoOWin1olj>SX7oaLG5`Oo:b/[1_lA4A46oc<c<`Kooooo1olI
6AT7oa4A4@OoGEeM1olH61P7obDU9@Oo:b/[1ol`<306oi:BTPGooooo1olP8207oa@D50Oo20P81olW
9bL7o`P820Oo7AdM1olE5AD6ob8R8Pgooooo000;ooooo`Oo6a/K1olF5QH7o`d=3@Oo4Q8B3_lA4A47
o`/;2`Ko7alO1Oooool7oadM7@Oo51@D1omQHF47ogUiN@Oo:2PX1ol/;2`7o`l?3`Ko?3`l1_ooool6
of1PH0Oo7QhN1olG5aL7oadM7@ko51@D1olG5aL<ooooo`Oo3`l?1omlO7`6o`P820Oo:2PX1oo3`l<7
oa8B4POo;Bd]1_l@4106ooooo`Oo30`<1olC4a<7oaDE5@Oo4a<C1_l:2PX7o`h>3POo5aLG1_l820P6
ooooo`Oo>c/k1olF5QH7ojRXZ0OoGUiN1olB4Q87odQ8B0Ko0`<31_lJ6QX6ooooo`Oo:RXZ1ol>3Ph7
ocTi>@Oo1PH61ola<C47obXZ:POo:2PX1_ng]kL5ooooo`Oo5aLG1olE5AD7o`@410Oo;Rh^1olH61P7
ob/[:`Oo92@T1_m=CDd=ooooo`002oooool7oa/K6`Oo5QHF1ol=3@d7oa8B4Pko4A4A1ol;2`/6oalO
7`Gooooo1olM7Ad7oa@D50OoHF5Q1omiNGT7obPX:0Oo;2`/1ol?3`l6oc`l?0Kooooo1_mPH607oahN
7POo5aLG1olM7Ad>oa@D50Oo5aLG3?ooool7o`l?3`OoO7al1_l820P7obPX:0Oo`l?31olB4Q87obd]
;@Ko410@1_ooool7o``<30Oo4a<C1olE5AD7oa<C4`Ko2PX:1ol>3Ph7oaLG5`Ko20P81_ooool7oc/k
>`Oo5QHF1onXZ:P7oeiNGPOo4Q8B1om8B4P6o`<30`Ko6QXJ1_ooool7obXZ:POo3Ph>1oli>CT7o`H6
1POo<C4a1olZ:RX7obPX:0Ko]kNg1Oooool7oaLG5`Oo5ADE1ol410@7obh^;POo61PH1ol[:b/7ob@T
90KoCDe=3Oooool000_ooooo1olK6a/7oaHF5POo3@d=1olB4Q8>oa4A4@Oo2`/;1_lO7al5ooooo`Oo
7AdM1olD51@7of5QH@OoNGUi1olX:2P7ob`/;0Oo3`l?1_ll?3`6ooooo`KoH61P1olN7Qh7oaLG5`Oo
7AdM3_lD51@7oaLG5`cooooo1ol?3`l7ogalO0Ko20P81olX:2P7ol?3``Oo4Q8B1ol];Bd6oa0@40Ko
oooo1ol<30`7oa<C4`Oo5ADE1olC4a<6o`X:2POo3Ph>1olG5aL6o`P820Kooooo1olk>c/7oaHF5POo
Z:RX1omNGUh7oa8B4POoB4Q81_l30`<6oaXJ6PKooooo1olZ:RX7o`h>3POo>CTi1ol61PH7oc4a<@Oo
:RXZ1olX:2P6okNg]`Gooooo1olG5aL7oaDE5@Oo10@41ol^;Rh7oaPH60Oo:b/[1olT92@6ode=C@go
oooo000;ooooo`Oo6a/K1olF5QH7o`d=3@Oo4Q8B3_lA4A47o`/;2`Ko7alO1Oooool7oadM7@Oo51@D
1omQHF47ogUiN@Oo:2PX1ol/;2`7o`l?3`Ko?3`l1_ooool6of1PH0Oo7QhN1olG5aL7oadM7@ko51@D
1olG5aL<ooooo`Oo3`l?1omlO7`6o`P820Oo:2PX1oo3`l<7oa8B4POo;Bd]1_l@4106ooooo`Oo30`<
1olC4a<7oaDE5@Oo4a<C1_l:2PX7o`h>3POo5aLG1_l820P6ooooo`Oo>c/k1olF5QH7ojRXZ0OoGUiN
1olB4Q87odQ8B0Ko0`<31_lJ6QX6ooooo`Oo:RXZ1ol>3Ph7ocTi>@Oo1PH61ola<C47obXZ:POo:2PX
1_ng]kL5ooooo`Oo5aLG1olE5AD7o`@410Oo;Rh^1olH61P7ob/[:`Oo92@T1_m=CDd=ooooo`002ooo
ool7oa/K6`Oo5QHF1ol=3@d7oa8B4Pko4A4A1ol;2`/6oalO7`Gooooo1olM7Ad7oa@D50OoHF5Q1omi
NGT7obPX:0Oo;2`/1ol?3`l6oc`l?0Kooooo1_mPH607oahN7POo5aLG1olM7Ad>oa@D50Oo5aLG3?oo
ool7o`l?3`OoO7al1_l820P7obPX:0Oo`l?31olB4Q87obd];@Ko410@1_ooool7o``<30Oo4a<C1olE
5AD7oa<C4`Ko2PX:1ol>3Ph7oaLG5`Ko20P81_ooool7oc/k>`Oo5QHF1onXZ:P7oeiNGPOo4Q8B1om8
B4P6o`<30`Ko6QXJ1_ooool7obXZ:POo3Ph>1oli>CT7o`H61POo<C4a1olZ:RX7obPX:0Ko]kNg1Ooo
ool7oaLG5`Oo5ADE1ol410@7obh^;POo61PH1ol[:b/7ob@T90KoCDe=3Oooool000_ooooo1olK6a/7
oaHF5POo3@d=1olB4Q8>oa4A4@Oo2`/;1_lO7al5ooooo`Oo7AdM1olD51@7of5QH@OoNGUi1olX:2P7
ob`/;0Oo3`l?1_ll?3`6ooooo`KoH61P1olN7Qh7oaLG5`Oo7AdM3_lD51@7oaLG5`cooooo1ol?3`l7
ogalO0Ko20P81olX:2P7ol?3``Oo4Q8B1ol];Bd6oa0@40Kooooo1ol<30`7oa<C4`Oo5ADE1olC4a<6
o`X:2POo3Ph>1olG5aL6o`P820Kooooo1olk>c/7oaHF5POoZ:RX1omNGUh7oa8B4POoB4Q81_l30`<6
oaXJ6PKooooo1olZ:RX7o`h>3POo>CTi1ol61PH7oc4a<@Oo:RXZ1olX:2P6okNg]`Gooooo1olG5aL7
oaDE5@Oo10@41ol^;Rh7oaPH60Oo:b/[1olT92@6ode=C@gooooo000;ooooo`Oo6a/K1olF5QH7o`d=
3@Oo4Q8B3_lA4A47o`/;2`Ko7alO1Oooool7oadM7@Oo51@D1omQHF47ogUiN@Oo:2PX1ol/;2`7o`l?
3`Ko?3`l1_ooool6of1PH0Oo7QhN1olG5aL7oadM7@ko51@D1olG5aL<ooooo`Oo3`l?1omlO7`6o`P8
20Oo:2PX1oo3`l<7oa8B4POo;Bd]1_l@4106ooooo`Oo30`<1olC4a<7oaDE5@Oo4a<C1_l:2PX7o`h>
3POo5aLG1_l820P6ooooo`Oo>c/k1olF5QH7ojRXZ0OoGUiN1olB4Q87odQ8B0Ko0`<31_lJ6QX6oooo
o`Oo:RXZ1ol>3Ph7ocTi>@Oo1PH61ola<C47obXZ:POo:2PX1_ng]kL5ooooo`Oo5aLG1olE5AD7o`@4
10Oo;Rh^1olH61P7ob/[:`Oo92@T1_m=CDd=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo
1@D51ol00006oaPH60Gooooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Ko
oooo1_lV9RH7ob0P80Oo4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko
00001olU9BD7oj2PX0Oo7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo
2@T91ol?3`l6ob8R8PKooooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Ko
oooo1olD51@7o`h>3Pko30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@Oo
ADE51ol10@47oa4A4@Oo5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D5
1ol00006oaPH60Gooooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo
1_lV9RH7ob0P80Oo4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko0000
1olU9BD7oj2PX0Oo7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T9
1ol?3`l6ob8R8PKooooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo
1olD51@7o`h>3Pko30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE5
1ol10@47oa4A4@Oo5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D51ol0
0006oaPH60Gooooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo1_lV
9RH7ob0P80Oo4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko00001olU
9BD7oj2PX0Oo7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T91ol?
3`l6ob8R8PKooooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo1olD
51@7o`h>3Pko30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE51ol1
0@47oa4A4@Oo5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D51ol00006
oaPH60Gooooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo1_lV9RH7
ob0P80Oo4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko00001olU9BD7
oj2PX0Oo7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T91ol?3`l6
ob8R8PKooooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo1olD51@7
o`h>3Pko30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE51ol10@47
oa4A4@Oo5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D51ol00006oaPH
60Gooooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo1_lV9RH7ob0P
80Oo4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko00001olU9BD7oj2P
X0Oo7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T91ol?3`l6ob8R
8PKooooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo1olD51@7o`h>
3Pko30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE51ol10@47oa4A
4@Oo5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D51ol00006oaPH60Go
oooo1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo1_lV9RH7ob0P80Oo
4Q8B1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko00001olU9BD7oj2PX0Oo
7alO1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T91ol?3`l6ob8R8PKo
oooo1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo1olD51@7o`h>3Pko
30`<1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE51ol10@47oa4A4@Oo
5aLG1_mFEUH=ooooo`002oooool7oa0@40Oo4Q8B3_l:2PX7oaLG5`Oo1@D51ol00006oaPH60Gooooo
1olO7al7oa8B4POoKVi^1oooool7og]kN`Oo=3@d1ol61PH6ob<S8`Kooooo1_lV9RH7ob0P80Oo4Q8B
1olC4a<7o`P820Oo3`l?1ol=3@d6ocDe=@Kooooo1ol<30`7ocdm?@Ko00001olU9BD7oj2PX0Oo7alO
1olk>c/6oa<C4`Kooooo1ol10@47oa4A4@Oo00001ol<30`6o`d=3@Oo2@T91ol?3`l6ob8R8PKooooo
1om3@d<7ocHf=POoYZJV1om`L707obLW9`Oo:RXZ1_lJ6QX6obLW9`Kooooo1olD51@7o`h>3Pko30`<
1om:BTX7oaTI6@Oo00001_nPX:05ooooo`Oo4A4A1ol71`L7oaDE5@OoADE51ol10@47oa4A4@Oo5aLG
1_mFEUH=ooooo`002oooool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Ooo
ool7ob/[:`Oo=CDe1om9BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol2
0P87o`d=3@Oo2PX:1ol00007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT
92@7oe5AD@Ko:BTY1_ooool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_oo
ool7odm?C`Oo7AdM1omfMWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS
8b<7oa<C4`OoDe=C3_lQ8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ
6QXCooooo`002oooool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7
ob/[:`Oo=CDe1om9BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87
o`d=3@Oo2PX:1ol00007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7
oe5AD@Ko:BTY1_ooool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7
odm?C`Oo7AdM1omfMWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7
oa<C4`OoDe=C3_lQ8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXC
ooooo`002oooool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7ob/[
:`Oo=CDe1om9BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87o`d=
3@Oo2PX:1ol00007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7oe5A
D@Ko:BTY1_ooool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7odm?
C`Oo7AdM1omfMWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7oa<C
4`OoDe=C3_lQ8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXCoooo
o`002oooool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7ob/[:`Oo
=CDe1om9BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87o`d=3@Oo
2PX:1ol00007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7oe5AD@Ko
:BTY1_ooool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7odm?C`Oo
7AdM1omfMWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7oa<C4`Oo
De=C3_lQ8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXCooooo`00
2oooool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7ob/[:`Oo=CDe
1om9BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87o`d=3@Oo2PX:
1ol00007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7oe5AD@Ko:BTY
1_ooool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7odm?C`Oo7AdM
1omfMWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7oa<C4`OoDe=C
3_lQ8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXCooooo`002ooo
ool7oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7ob/[:`Oo=CDe1om9
BDT7ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87o`d=3@Oo2PX:1ol0
0007oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7oe5AD@Ko:BTY1_oo
ool7o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7odm?C`Oo7AdM1omf
MWH7ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7oa<C4`OoDe=C3_lQ
8B46ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXCooooo`002oooool7
oa8B4POo3@d=1olB4Q87oa4A4@Oo4a<C1ol>3Ph7o`l?3`Ko7QhN1Oooool7ob/[:`Oo=CDe1om9BDT7
ofi^KPOo:RXZ1omIFET7ob0P80Ko8R8R1_ooool6oaTI6@Oo4A4A1ol20P87o`d=3@Oo2PX:1ol00007
oa4A4@Ko9bLW1_ooool7oa0@40Oo;2`/1_l92@T7ob8R8POoEEEE1olT92@7oe5AD@Ko:BTY1_ooool7
o`d=3@Oo1`L71ol61PH7oa<C4`Ko4A4A1ol92@T7oa8B4PKo6ATI1_ooool7odm?C`Oo7AdM1omfMWH7
ooShn0Oo71`L1ombLW86obHV9PKo;Bd]1_ooool7oc`l?0Oo8B4Q1olS8b<7oa<C4`OoDe=C3_lQ8B46
ofi^KPGooooo1olV9RH7o`d=3@Oo820P1omEEED7oa@D50Oo3`l?1olJ6QXCooooo`004_ooool7ocXj
>POo=CDe1olU9BD7obh^;POo<c<c1ol/;2`6ocXj>PGooooo1olK6a/7obHV9POo=cLg1om5ADD7obLW
9`Oo;Rh^1olJ6QX6oeUIF@Kooooo1_lZ:RX7oahN7POo8R8R1olG5aL7oa/K6`Oo4Q8B1ol@4106oc0`
<0Kooooo1om>CTh7oe9BDPKo410@1ola<C47ob<S8`Oo51@D1omADE46oaHF5PKooooo1olV9RH7ob`/
;0Oo:2PX1oooool6ocHf=POo?clo1om2@T86ob@T90Kooooo1omZJVX7oa8B4POo<S8b1om3@d<7obd]
;@OoLG5a1_l`<306oa/K6`Kooooo1ole=CD7of9RHPOoU9BD1olc<c<7oemOG`Oo:RXZ1omkNg/6oeUI
F@Gooooo1olO7al7obTY:@Oo3@d=1ol[:b/7oa8B4POo;Bd]1ola<C46odQ8B0gooooo000Booooo`Oo
>SXj1ole=CD7obDU9@Oo;Rh^1olc<c<7ob`/;0Ko>SXj1Oooool7oa/K6`Oo9RHV1olg=cL7odE5A@Oo
9bLW1ol^;Rh7oaXJ6PKoFEUI1_ooool6obXZ:POo7QhN1olR8R87oaLG5`Oo6a/K1olB4Q87oa0@40Ko
<30`1_ooool7odi>CPOoDU9B1_l@4107oc4a<@Oo8b<S1olD51@7oe5AD@Ko5QHF1_ooool7obHV9POo
;2`/1olX:2P7ooooo`Ko=SHf1olo?cl7od92@PKo92@T1_ooool7ofYZJPOo4Q8B1olb<S87od=3@`Oo
;Bd]1omaLG46oc0`<0Ko6a/K1_ooool7ocDe=@OoHV9R1onDU9@7oc<c<`OoGemO1olZ:RX7og]kN`Ko
FEUI1Oooool7oalO7`Oo:BTY1ol=3@d7ob/[:`Oo4Q8B1ol];Bd7oc4a<@KoB4Q83Oooool001;ooooo
1olj>SX7ocDe=@Oo9BDU1ol^;Rh7oc<c<`Oo;2`/1_lj>SX5ooooo`Oo6a/K1olV9RH7ocLg=`OoADE5
1olW9bL7obh^;POo6QXJ1_mIFET6ooooo`Ko:RXZ1olN7Qh7ob8R8POo5aLG1olK6a/7oa8B4POo410@
1_l`<306ooooo`OoCTi>1omBDU86oa0@40Oo<C4a1olS8b<7oa@D50OoDE5A1_lF5QH6ooooo`Oo9RHV
1ol/;2`7obPX:0Oooooo1_lf=SH7oclo?`Oo@T921_lT92@6ooooo`OoJVYZ1olB4Q87oc8b<POo@d=3
1ol];Bd7og5aL@Ko<30`1_lK6a/6ooooo`Oo=CDe1omRHV87oiBDU0Oo<c<c1omOGel7obXZ:POoNg]k
1_mIFET5ooooo`Oo7alO1olY:BT7o`d=3@Oo:b/[1olB4Q87obd];@Oo<C4a1_m8B4P=ooooo`004_oo
ool7ocXj>POo=CDe1olU9BD7obh^;POo<c<c1ol/;2`6ocXj>PGooooo1olK6a/7obHV9POo=cLg1om5
ADD7obLW9`Oo;Rh^1olJ6QX6oeUIF@Kooooo1_lZ:RX7oahN7POo8R8R1olG5aL7oa/K6`Oo4Q8B1ol@
4106oc0`<0Kooooo1om>CTh7oe9BDPKo410@1ola<C47ob<S8`Oo51@D1omADE46oaHF5PKooooo1olV
9RH7ob`/;0Oo:2PX1oooool6ocHf=POo?clo1om2@T86ob@T90Kooooo1omZJVX7oa8B4POo<S8b1om3
@d<7obd];@OoLG5a1_l`<306oa/K6`Kooooo1ole=CD7of9RHPOoU9BD1olc<c<7oemOG`Oo:RXZ1omk
Ng/6oeUIF@Gooooo1olO7al7obTY:@Oo3@d=1ol[:b/7oa8B4POo;Bd]1ola<C46odQ8B0gooooo000B
ooooo`Oo>SXj1ole=CD7obDU9@Oo;Rh^1olc<c<7ob`/;0Ko>SXj1Oooool7oa/K6`Oo9RHV1olg=cL7
odE5A@Oo9bLW1ol^;Rh7oaXJ6PKoFEUI1_ooool6obXZ:POo7QhN1olR8R87oaLG5`Oo6a/K1olB4Q87
oa0@40Ko<30`1_ooool7odi>CPOoDU9B1_l@4107oc4a<@Oo8b<S1olD51@7oe5AD@Ko5QHF1_ooool7
obHV9POo;2`/1olX:2P7ooooo`Ko=SHf1olo?cl7od92@PKo92@T1_ooool7ofYZJPOo4Q8B1olb<S87
od=3@`Oo;Bd]1omaLG46oc0`<0Ko6a/K1_ooool7ocDe=@OoHV9R1onDU9@7oc<c<`OoGemO1olZ:RX7
og]kN`KoFEUI1Oooool7oalO7`Oo:BTY1ol=3@d7ob/[:`Oo4Q8B1ol];Bd7oc4a<@KoB4Q83Oooool0
01;ooooo1olj>SX7ocDe=@Oo9BDU1ol^;Rh7oc<c<`Oo;2`/1_lj>SX5ooooo`Oo6a/K1olV9RH7ocLg
=`OoADE51olW9bL7obh^;POo6QXJ1_mIFET6ooooo`Ko:RXZ1olN7Qh7ob8R8POo5aLG1olK6a/7oa8B
4POo410@1_l`<306ooooo`OoCTi>1omBDU86oa0@40Oo<C4a1olS8b<7oa@D50OoDE5A1_lF5QH6oooo
o`Oo9RHV1ol/;2`7obPX:0Oooooo1_lf=SH7oclo?`Oo@T921_lT92@6ooooo`OoJVYZ1olB4Q87oc8b
<POo@d=31ol];Bd7og5aL@Ko<30`1_lK6a/6ooooo`Oo=CDe1omRHV87oiBDU0Oo<c<c1omOGel7obXZ
:POoNg]k1_mIFET5ooooo`Oo7alO1olY:BT7o`d=3@Oo:b/[1olB4Q87obd];@Oo<C4a1_m8B4P=oooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`002oooool7obHV9POoVi^K1om:BTX7ogemO@OoJVYZ1ol`
<307oc<c<`KoJFUY1Oooool7obDU9@Oo1PH61on<S8`7ocLg=`Oo5aLG1om?Cdl7o`T92@Ko:b/[1_oo
ool=obPX:0Oo7QhN1olG5aL7o`l?3`Oo4Q8B1ol?3`l6obh^;PKooooo1om5ADD7o`d=3@Ko8R8R1olX
:2P7o`l?3`Oo>CTi1ol;2`/6obTY:@Kooooo1olE5AD7oc@d=0Oo8b<S1olf=SH6of5QH@Oo51@D1olC
4a<6ochn?PKooooo1ooJf]X7oaDE5@Oo;2`/1olO7al7oi:BTPOoEEEE1_l>3Ph6ocHf=PKooooo1olA
4A47oe5AD@Oo<30`1olk>c/7od=3@`Oo7alO1om0@406olk>cPGooooo1olI6AT7odU9B@Oo>SXj1olE
5AD7oaHF5POo1`L71om3@d<6oh20P0gooooo000;ooooo`Oo9RHV1onKVi/7odY:BPOoOGem1omZJVX7
oc0`<0Oo<c<c1_mYJFT5ooooo`Oo9BDU1ol61PH7ohb<S0Oo=cLg1olG5aL7odm?C`Oo2@T91_l[:b/6
ooooo`go:2PX1olN7Qh7oaLG5`Oo3`l?1olB4Q87o`l?3`Ko;Rh^1_ooool7odE5A@Oo3@d=1_lR8R87
obPX:0Oo3`l?1oli>CT7o`/;2`Ko:BTY1_ooool7oaDE5@Oo=3@d1olS8b<7ocHf=PKoHF5Q1olD51@7
oa<C4`Ko?Shn1_ooool7om[JfPOo5ADE1ol/;2`7oalO7`OoTY:B1omEEED6o`h>3PKo=SHf1_ooool7
oa4A4@OoDE5A1ol`<307oc/k>`Oo@d=31olO7al7od10@0Koc/k>1Oooool7oaTI6@OoBDU91olj>SX7
oaDE5@Oo5QHF1ol71`L7od=3@`KoP8203Oooool000_ooooo1olV9RH7oi^KV`OoBTY:1ommOGd7ofYZ
JPOo<30`1olc<c<6ofUYJ@Gooooo1olU9BD7o`H61POoS8b<1olg=cL7oaLG5`OoCdm?1ol92@T6ob/[
:`Kooooo3OlX:2P7oahN7POo5aLG1ol?3`l7oa8B4POo3`l?1_l^;Rh6ooooo`OoADE51ol=3@d6ob8R
8POo:2PX1ol?3`l7ocTi>@Oo2`/;1_lY:BT6ooooo`Oo5ADE1old=3@7ob<S8`Oo=SHf1_mQHF47oa@D
50Oo4a<C1_ln?Sh6ooooo`Oof][J1olE5AD7ob`/;0Oo7alO1onBTY87oeEEE@Ko3Ph>1_lf=SH6oooo
o`Oo4A4A1omADE47oc0`<0Oo>c/k1om3@d<7oalO7`Oo@4101_o>c/h5ooooo`Oo6ATI1om9BDT7ocXj
>POo5ADE1olF5QH7o`L71`Oo@d=31_n0P80=ooooo`002oooool7obHV9POoVi^K1om:BTX7ogemO@Oo
JVYZ1ol`<307oc<c<`KoJFUY1Oooool7obDU9@Oo1PH61on<S8`7ocLg=`Oo5aLG1om?Cdl7o`T92@Ko
:b/[1_ooool=obPX:0Oo7QhN1olG5aL7o`l?3`Oo4Q8B1ol?3`l6obh^;PKooooo1om5ADD7o`d=3@Ko
8R8R1olX:2P7o`l?3`Oo>CTi1ol;2`/6obTY:@Kooooo1olE5AD7oc@d=0Oo8b<S1olf=SH6of5QH@Oo
51@D1olC4a<6ochn?PKooooo1ooJf]X7oaDE5@Oo;2`/1olO7al7oi:BTPOoEEEE1_l>3Ph6ocHf=PKo
oooo1olA4A47oe5AD@Oo<30`1olk>c/7od=3@`Oo7alO1om0@406olk>cPGooooo1olI6AT7odU9B@Oo
>SXj1olE5AD7oaHF5POo1`L71om3@d<6oh20P0gooooo000;ooooo`Oo9RHV1onKVi/7odY:BPOoOGem
1omZJVX7oc0`<0Oo<c<c1_mYJFT5ooooo`Oo9BDU1ol61PH7ohb<S0Oo=cLg1olG5aL7odm?C`Oo2@T9
1_l[:b/6ooooo`go:2PX1olN7Qh7oaLG5`Oo3`l?1olB4Q87o`l?3`Ko;Rh^1_ooool7odE5A@Oo3@d=
1_lR8R87obPX:0Oo3`l?1oli>CT7o`/;2`Ko:BTY1_ooool7oaDE5@Oo=3@d1olS8b<7ocHf=PKoHF5Q
1olD51@7oa<C4`Ko?Shn1_ooool7om[JfPOo5ADE1ol/;2`7oalO7`OoTY:B1omEEED6o`h>3PKo=SHf
1_ooool7oa4A4@OoDE5A1ol`<307oc/k>`Oo@d=31olO7al7od10@0Koc/k>1Oooool7oaTI6@OoBDU9
1olj>SX7oaDE5@Oo5QHF1ol71`L7od=3@`KoP8203Oooool000_ooooo1olV9RH7oi^KV`OoBTY:1omm
OGd7ofYZJPOo<30`1olc<c<6ofUYJ@Gooooo1olU9BD7o`H61POoS8b<1olg=cL7oaLG5`OoCdm?1ol9
2@T6ob/[:`Kooooo3OlX:2P7oahN7POo5aLG1ol?3`l7oa8B4POo3`l?1_l^;Rh6ooooo`OoADE51ol=
3@d6ob8R8POo:2PX1ol?3`l7ocTi>@Oo2`/;1_lY:BT6ooooo`Oo5ADE1old=3@7ob<S8`Oo=SHf1_mQ
HF47oa@D50Oo4a<C1_ln?Sh6ooooo`Oof][J1olE5AD7ob`/;0Oo7alO1onBTY87oeEEE@Ko3Ph>1_lf
=SH6ooooo`Oo4A4A1omADE47oc0`<0Oo>c/k1om3@d<7oalO7`Oo@4101_o>c/h5ooooo`Oo6ATI1om9
BDT7ocXj>POo5ADE1olF5QH7o`L71`Oo@d=31_n0P80=ooooo`002oooool7oaXJ6POoGemO1oli>CT7
of1PH0OoE5AD1old=3@7od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7
oa8B4PKo6QXJ1_ooool6obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7
odA4A0Oo7QhN1_la<C47oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7
ofEUI@Ko_[jn1olk>c/7oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6
oc4a<@Kooooo1ol?3`l7oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607
oc@d=0Oo30`<1olC4a<7o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1P
H0OoE5AD1old=3@7od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B
4PKo6QXJ1_ooool6obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4
A0Oo7QhN1_la<C47oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEU
I@Ko_[jn1olk>c/7oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a
<@Kooooo1ol?3`l7oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d
=0Oo30`<1olC4a<7o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1PH0Oo
E5AD1old=3@7od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B4PKo
6QXJ1_ooool6obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4A0Oo
7QhN1_la<C47oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEUI@Ko
_[jn1olk>c/7oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a<@Ko
oooo1ol?3`l7oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d=0Oo
30`<1olC4a<7o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1PH0OoE5AD
1old=3@7od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B4PKo6QXJ
1_ooool6obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4A0Oo7QhN
1_la<C47oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEUI@Ko_[jn
1olk>c/7oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a<@Kooooo
1ol?3`l7oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d=0Oo30`<
1olC4a<7o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1PH0OoE5AD1old
=3@7od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B4PKo6QXJ1_oo
ool6obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4A0Oo7QhN1_la
<C47oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEUI@Ko_[jn1olk
>c/7oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a<@Kooooo1ol?
3`l7oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d=0Oo30`<1olC
4a<7o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1PH0OoE5AD1old=3@7
od=3@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B4PKo6QXJ1_ooool6
obHV9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4A0Oo7QhN1_la<C47
oaPH60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEUI@Ko_[jn1olk>c/7
oc8b<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a<@Kooooo1ol?3`l7
oc`l?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d=0Oo30`<1olC4a<7
o`P820Oo92@T1_n@T90=ooooo`002oooool7oaXJ6POoGemO1oli>CT7of1PH0OoE5AD1old=3@7od=3
@`KoFe]K1Oooool7ob/[:`Oo8B4Q1onLW9`7of9RHPOo6ATI1om3@d<7oa8B4PKo6QXJ1_ooool6obHV
9POo?Shn1olX:2P7oadM7@Oo4Q8B1ol820P7obHV9PKo4A4A1_ooool7odA4A0Oo7QhN1_la<C47oaPH
60Oo2PX:1om=CDd7oaTI6@Ko=SHf1_ooool7ob<S8`Oo5aLG1olL71`7ofEUI@Ko_[jn1olk>c/7oc8b
<PKo?Cdm3Oooool7oa0@40Oo@T921olH61P7oj6QX@OoJVYZ1_lG5aL6oc4a<@Kooooo1ol?3`l7oc`l
?0OoBd];1om<C4`7ocXj>POo6ATI1omRHV8;ooooo`Oo3Ph>1omPH607oc@d=0Oo30`<1olC4a<7o`P8
20Oo92@T1_n@T90=ooooo`002oooool7oalO7`Oo]kNg1olk>c/7ofa/K0OoEEEE1om3@d<7obd];@Ko
IfMW1Oooool7oda<C0Oo6QXJ1omSHf<7onWYj@Oo8B4Q1om7AdL7o`/;2`Ko6QXJ1_ooool6obPX:0Oo
>CTi1olb<S87obHV9POo8b<S1olH61P7oa<C4`Ko=3@d1_ooool7og=cL`OoF5QH1_la<C47oadM7@Oo
00001om7AdL7ochn?PKo:2PX1_ooool7o`X:2Pko6ATI1on5QHD6ooooo`OoN7Qh1om4A4@6oeYJFPKo
oooo1ooJf]X7o`h>3POo@4101olc<c<7ofi^KPOo`L711_lB4Q86oahN7PKooooo1ol;2`/7ocdm?@Oo
@D511olS8b<7og9bLPOo=3@d1om3@d<6olW9b@Gooooo1olH61P7odI6APOo=3@d1olL71`7oadM7@Oo
9RHV1olg=cL6oi6AT@gooooo000;ooooo`Oo7alO1ong]kL7oc/k>`OoK6a/1omEEED7od=3@`Oo;Bd]
1_mWIfL5ooooo`OoC4a<1olJ6QX7of=SH`OojNWY1olQ8B47odM7A`Oo2`/;1_lJ6QX6ooooo`Ko:2PX
1oli>CT7oc8b<POo9RHV1olS8b<7oaPH60Oo4a<C1_ld=3@6ooooo`OoLg=c1omHF5P6oc4a<@Oo7AdM
1ol00007odM7A`Oo?Shn1_lX:2P6ooooo`Oo2PX:3_lI6AT7ohF5Q@Kooooo1omhN7P7odA4A0KoFUYJ
1_ooool7om[JfPOo3Ph>1om0@407oc<c<`OoKVi^1oo1`L46oa8B4PKo7QhN1_ooool7o`/;2`Oo?Cdm
1om1@D47ob<S8`OoLW9b1old=3@7od=3@`KobLW91Oooool7oaPH60OoATI61old=3@7oa`L70Oo7AdM
1olV9RH7ocLg=`KoTI6A3Oooool000_ooooo1olO7al7okNg]`Oo>c/k1om/K6`7oeEEE@Oo@d=31ol]
;Bd6ofMWI`Gooooo1om<C4`7oaXJ6POoHf=S1ooYjNT7ob4Q8@OoAdM71ol;2`/6oaXJ6PKooooo1_lX
:2P7ocTi>@Oo<S8b1olV9RH7ob<S8`Oo61PH1olC4a<6oc@d=0Kooooo1omcLg<7oeQHF0Ko<C4a1olM
7Ad7o`0000OoAdM71oln?Sh6obPX:0Kooooo1ol:2PX>oaTI6@OoQHF51_ooool7ogQhN0OoA4A41_mJ
FUX6ooooo`Oof][J1ol>3Ph7od10@0Oo<c<c1om^KVh7ol71`@Ko4Q8B1_lN7Qh6ooooo`Oo2`/;1olm
?Cd7od51@@Oo8b<S1ombLW87oc@d=0Oo@d=31_o9bLT5ooooo`Oo61PH1om6ATH7oc@d=0Oo71`L1olM
7Ad7obHV9POo=cLg1_nATI4=ooooo`002oooool7oalO7`Oo]kNg1olk>c/7ofa/K0OoEEEE1om3@d<7
obd];@KoIfMW1Oooool7oda<C0Oo6QXJ1omSHf<7onWYj@Oo8B4Q1om7AdL7o`/;2`Ko6QXJ1_ooool6
obPX:0Oo>CTi1olb<S87obHV9POo8b<S1olH61P7oa<C4`Ko=3@d1_ooool7og=cL`OoF5QH1_la<C47
oadM7@Oo00001om7AdL7ochn?PKo:2PX1_ooool7o`X:2Pko6ATI1on5QHD6ooooo`OoN7Qh1om4A4@6
oeYJFPKooooo1ooJf]X7o`h>3POo@4101olc<c<7ofi^KPOo`L711_lB4Q86oahN7PKooooo1ol;2`/7
ocdm?@Oo@D511olS8b<7og9bLPOo=3@d1om3@d<6olW9b@Gooooo1olH61P7odI6APOo=3@d1olL71`7
oadM7@Oo9RHV1olg=cL6oi6AT@gooooo000;ooooo`Oo7alO1ong]kL7oc/k>`OoK6a/1omEEED7od=3
@`Oo;Bd]1_mWIfL5ooooo`OoC4a<1olJ6QX7of=SH`OojNWY1olQ8B47odM7A`Oo2`/;1_lJ6QX6oooo
o`Ko:2PX1oli>CT7oc8b<POo9RHV1olS8b<7oaPH60Oo4a<C1_ld=3@6ooooo`OoLg=c1omHF5P6oc4a
<@Oo7AdM1ol00007odM7A`Oo?Shn1_lX:2P6ooooo`Oo2PX:3_lI6AT7ohF5Q@Kooooo1omhN7P7odA4
A0KoFUYJ1_ooool7om[JfPOo3Ph>1om0@407oc<c<`OoKVi^1oo1`L46oa8B4PKo7QhN1_ooool7o`/;
2`Oo?Cdm1om1@D47ob<S8`OoLW9b1old=3@7od=3@`KobLW91Oooool7oaPH60OoATI61old=3@7oa`L
70Oo7AdM1olV9RH7ocLg=`KoTI6A3Oooool000_ooooo1olO7al7okNg]`Oo>c/k1om/K6`7oeEEE@Oo
@d=31ol];Bd6ofMWI`Gooooo1om<C4`7oaXJ6POoHf=S1ooYjNT7ob4Q8@OoAdM71ol;2`/6oaXJ6PKo
oooo1_lX:2P7ocTi>@Oo<S8b1olV9RH7ob<S8`Oo61PH1olC4a<6oc@d=0Kooooo1omcLg<7oeQHF0Ko
<C4a1olM7Ad7o`0000OoAdM71oln?Sh6obPX:0Kooooo1ol:2PX>oaTI6@OoQHF51_ooool7ogQhN0Oo
A4A41_mJFUX6ooooo`Oof][J1ol>3Ph7od10@0Oo<c<c1om^KVh7ol71`@Ko4Q8B1_lN7Qh6ooooo`Oo
2`/;1olm?Cd7od51@@Oo8b<S1ombLW87oc@d=0Oo@d=31_o9bLT5ooooo`Oo61PH1om6ATH7oc@d=0Oo
71`L1olM7Ad7obHV9POo=cLg1_nATI4=ooooo`002oooool7oalO7`Oo]kNg1olk>c/7ofa/K0OoEEEE
1om3@d<7obd];@KoIfMW1Oooool7oda<C0Oo6QXJ1omSHf<7onWYj@Oo8B4Q1om7AdL7o`/;2`Ko6QXJ
1_ooool6obPX:0Oo>CTi1olb<S87obHV9POo8b<S1olH61P7oa<C4`Ko=3@d1_ooool7og=cL`OoF5QH
1_la<C47oadM7@Oo00001om7AdL7ochn?PKo:2PX1_ooool7o`X:2Pko6ATI1on5QHD6ooooo`OoN7Qh
1om4A4@6oeYJFPKooooo1ooJf]X7o`h>3POo@4101olc<c<7ofi^KPOo`L711_lB4Q86oahN7PKooooo
1ol;2`/7ocdm?@Oo@D511olS8b<7og9bLPOo=3@d1om3@d<6olW9b@Gooooo1olH61P7odI6APOo=3@d
1olL71`7oadM7@Oo9RHV1olg=cL6oi6AT@gooooo000;ooooo`Oo00001om:BTX7ob/[:`OoIfMW1om0
@407obh^;POo92@T1_l_;bl5ooooo`Oo5aLG1ol`<307oijNWPOoe]KF1olD51@7obLW9`Oo10@41_l2
0P86ooooo`Ko5ADE1olO7al7oc0`<0Oo5aLG1olJ6QX>o`l?3`Ko;Rh^1_ooool7ob0P80Oo9bLW1_lP
8207ocPh>0Oo3`l?1om@D507ocTi>@Ko<c<c1_ooool7o`0000Oo0P821olO7al7ofEUI@KoVYZJ1onF
UYH7oemOG`KoC4a<1_ooool7oiVIV@Oo2PX:1ol/;2`7odA4A0OoJ6QX1oo9bLT6oaXJ6PKoCDe=1_oo
ool7oa<C4`Oo7alO1om5ADD7oalO7`OoAdM71olL71`7oeUIF@KoQXJ61Oooool7o`l?3`Oo2`/;1om2
@T87oaLG5`Oo9RHV1ol51@D7obl_;`Kok>c/3Oooool000_ooooo1ol00007odY:BPOo:b/[1omWIfL7
od10@0Oo;Rh^1olT92@6obl_;`Gooooo1olG5aL7oc0`<0OoWYjN1ooFe]H7oa@D50Oo9bLW1ol410@6
o`820PKooooo1_lE5AD7oalO7`Oo<30`1olG5aL7oaXJ6Pko3`l?1_l^;Rh6ooooo`Oo820P1olW9bL6
ob0P80Oo>3Ph1ol?3`l7oe1@D0Oo>CTi1_lc<c<6ooooo`Oo00001ol20P87oalO7`OoIFEU1_nJVYX7
oiJFUPOoGemO1_m<C4`6ooooo`OoVIVI1ol:2PX7ob`/;0OoA4A41omXJ6P7olW9b@Ko6QXJ1_m=CDd6
ooooo`Oo4a<C1olO7al7odE5A@Oo7alO1om7AdL7oa`L70OoFEUI1_n6QXH5ooooo`Oo3`l?1ol;2`/7
od92@POo5aLG1olV9RH7o`D51@Oo;bl_1_o/k>`=ooooo`002oooool7o`0000OoBTY:1ol[:b/7ofMW
I`Oo@4101ol^;Rh7ob@T90Ko;bl_1Oooool7oaLG5`Oo<30`1onNWYh7omKFePOo51@D1olW9bL7o`@4
10Ko0P821_ooool6oaDE5@Oo7alO1ol`<307oaLG5`Oo6QXJ3_l?3`l6obh^;PKooooo1olP8207obLW
9`Ko820P1olh>3P7o`l?3`OoD51@1oli>CT6oc<c<`Kooooo1ol00007o`820POo7alO1omUIFD6oiZJ
VPOoUYJF1omOGel6oda<C0Kooooo1onIVIT7o`X:2POo;2`/1om4A4@7ofQXJ0OobLW91_lJ6QX6ode=
C@Kooooo1olC4a<7oalO7`OoADE51olO7al7odM7A`Oo71`L1omIFET6ohJ6QPGooooo1ol?3`l7o`/;
2`Oo@T921olG5aL7obHV9POo1@D51ol_;bl6onc/k0gooooo000;ooooo`Oo00001om:BTX7ob/[:`Oo
IfMW1om0@407obh^;POo92@T1_l_;bl5ooooo`Oo5aLG1ol`<307oijNWPOoe]KF1olD51@7obLW9`Oo
10@41_l20P86ooooo`Ko5ADE1olO7al7oc0`<0Oo5aLG1olJ6QX>o`l?3`Ko;Rh^1_ooool7ob0P80Oo
9bLW1_lP8207ocPh>0Oo3`l?1om@D507ocTi>@Ko<c<c1_ooool7o`0000Oo0P821olO7al7ofEUI@Ko
VYZJ1onFUYH7oemOG`KoC4a<1_ooool7oiVIV@Oo2PX:1ol/;2`7odA4A0OoJ6QX1oo9bLT6oaXJ6PKo
CDe=1_ooool7oa<C4`Oo7alO1om5ADD7oalO7`OoAdM71olL71`7oeUIF@KoQXJ61Oooool7o`l?3`Oo
2`/;1om2@T87oaLG5`Oo9RHV1ol51@D7obl_;`Kok>c/3Oooool000_ooooo1ol00007odY:BPOo:b/[
1omWIfL7od10@0Oo;Rh^1olT92@6obl_;`Gooooo1olG5aL7oc0`<0OoWYjN1ooFe]H7oa@D50Oo9bLW
1ol410@6o`820PKooooo1_lE5AD7oalO7`Oo<30`1olG5aL7oaXJ6Pko3`l?1_l^;Rh6ooooo`Oo820P
1olW9bL6ob0P80Oo>3Ph1ol?3`l7oe1@D0Oo>CTi1_lc<c<6ooooo`Oo00001ol20P87oalO7`OoIFEU
1_nJVYX7oiJFUPOoGemO1_m<C4`6ooooo`OoVIVI1ol:2PX7ob`/;0OoA4A41omXJ6P7olW9b@Ko6QXJ
1_m=CDd6ooooo`Oo4a<C1olO7al7odE5A@Oo7alO1om7AdL7oa`L70OoFEUI1_n6QXH5ooooo`Oo3`l?
1ol;2`/7od92@POo5aLG1olV9RH7o`D51@Oo;bl_1_o/k>`=ooooo`002oooool7o`0000OoBTY:1ol[
:b/7ofMWI`Oo@4101ol^;Rh7ob@T90Ko;bl_1Oooool7oaLG5`Oo<30`1onNWYh7omKFePOo51@D1olW
9bL7o`@410Ko0P821_ooool6oaDE5@Oo7alO1ol`<307oaLG5`Oo6QXJ3_l?3`l6obh^;PKooooo1olP
8207obLW9`Ko820P1olh>3P7o`l?3`OoD51@1oli>CT6oc<c<`Kooooo1ol00007o`820POo7alO1omU
IFD6oiZJVPOoUYJF1omOGel6oda<C0Kooooo1onIVIT7o`X:2POo;2`/1om4A4@7ofQXJ0OobLW91_lJ
6QX6ode=C@Kooooo1olC4a<7oalO7`OoADE51olO7al7odM7A`Oo71`L1omIFET6ohJ6QPGooooo1ol?
3`l7o`/;2`Oo@T921olG5aL7obHV9POo1@D51ol_;bl6onc/k0gooooo000;ooooo`Oo00001om:BTX7
ob/[:`OoIfMW1om0@407obh^;POo92@T1_l_;bl5ooooo`Oo5aLG1ol`<307oijNWPOoe]KF1olD51@7
obLW9`Oo10@41_l20P86ooooo`Ko5ADE1olO7al7oc0`<0Oo5aLG1olJ6QX>o`l?3`Ko;Rh^1_ooool7
ob0P80Oo9bLW1_lP8207ocPh>0Oo3`l?1om@D507ocTi>@Ko<c<c1_ooool7o`0000Oo0P821olO7al7
ofEUI@KoVYZJ1onFUYH7oemOG`KoC4a<1_ooool7oiVIV@Oo2PX:1ol/;2`7odA4A0OoJ6QX1oo9bLT6
oaXJ6PKoCDe=1_ooool7oa<C4`Oo7alO1om5ADD7oalO7`OoAdM71olL71`7oeUIF@KoQXJ61Oooool7
o`l?3`Oo2`/;1om2@T87oaLG5`Oo9RHV1ol51@D7obl_;`Kok>c/3Oooool000_ooooo1olW9bL7ochn
?POoD51@1om[Jf/7ogmoO`Oo<C4a1omCDe<6ocLg=`Gooooo1om6ATH7obl_;`Oo?clo1oooool7o`@4
10OoBDU91oli>CT6od51@@Kooooo1_lL71`7ocTi>@Oo;Bd]1olF5QH7obl_;`Oo2@T91ol;2`/6ocLg
=`Kooooo1ol;2`/7od=3@`Ko1@D51ola<C47ob4Q8@Oo;Bd]1onc/k<6ocXj>PKooooo1olI6AT7oa0@
40Oo2`/;1om2@T86oeIFEPOo:b/[1om2@T86oeEEE@Kooooo1ombLW87oa/K6`Oo>SXj1om3@d<7ocTi
>@OoXj>S1_l:2PX6ode=C@Kooooo1ol>3Ph7ob0P80Oo7AdM1ol71`L7ofYZJPOo5aLG1ol];Bd6ofAT
I0Gooooo1ol92@T7ob4Q8@OoEEEE1olF5QH7oaDE5@Oo71`L1olG5aLCooooo`002oooool7obLW9`Oo
?Shn1om@D507of][J`OoOgmo1ola<C47oe=CD`Ko=cLg1Oooool7odI6APOo;bl_1olo?cl7ooooo`Oo
10@41om9BDT7ocTi>@Ko@D511_ooool6oa`L70Oo>CTi1ol];Bd7oaHF5POo;bl_1ol92@T7o`/;2`Ko
=cLg1_ooool7o`/;2`Oo@d=31_l51@D7oc4a<@Oo8B4Q1ol];Bd7ok>c/`Ko>SXj1_ooool7oaTI6@Oo
410@1ol;2`/7od92@PKoEUIF1ol[:b/7od92@PKoEEEE1_ooool7og9bLPOo6a/K1olj>SX7od=3@`Oo
>CTi1onSXj<6o`X:2PKoCDe=1_ooool7o`h>3POo820P1olM7Ad7o`L71`OoJVYZ1olG5aL7obd];@Ko
I6AT1Oooool7o`T92@Oo8B4Q1omEEED7oaHF5POo5ADE1olL71`7oaLG5a?ooooo000;ooooo`Oo9bLW
1oln?Sh7oe1@D0OoJf][1omoOgl7oc4a<@OoDe=C1_lg=cL5ooooo`OoATI61ol_;bl7oclo?`Oooooo
1ol410@7odU9B@Oo>CTi1_m1@D46ooooo`Ko71`L1oli>CT7obd];@Oo5QHF1ol_;bl7o`T92@Oo2`/;
1_lg=cL6ooooo`Oo2`/;1om3@d<6o`D51@Oo<C4a1olQ8B47obd];@Oo/k>c1_lj>SX6ooooo`Oo6ATI
1ol@4107o`/;2`Oo@T921_mFEUH7ob/[:`Oo@T921_mEEED6ooooo`OoLW9b1olK6a/7ocXj>POo@d=3
1oli>CT7oj>SX`Ko2PX:1_m=CDd6ooooo`Oo3Ph>1olP8207oadM7@Oo1`L71omZJVX7oaLG5`Oo;Bd]
1_mTI6@5ooooo`Oo2@T91olQ8B47oeEEE@Oo5QHF1olE5AD7oa`L70Oo5aLG4oooool000_ooooo1olW
9bL7ochn?POoD51@1om[Jf/7ogmoO`Oo<C4a1omCDe<6ocLg=`Gooooo1om6ATH7obl_;`Oo?clo1ooo
ool7o`@410OoBDU91oli>CT6od51@@Kooooo1_lL71`7ocTi>@Oo;Bd]1olF5QH7obl_;`Oo2@T91ol;
2`/6ocLg=`Kooooo1ol;2`/7od=3@`Ko1@D51ola<C47ob4Q8@Oo;Bd]1onc/k<6ocXj>PKooooo1olI
6AT7oa0@40Oo2`/;1om2@T86oeIFEPOo:b/[1om2@T86oeEEE@Kooooo1ombLW87oa/K6`Oo>SXj1om3
@d<7ocTi>@OoXj>S1_l:2PX6ode=C@Kooooo1ol>3Ph7ob0P80Oo7AdM1ol71`L7ofYZJPOo5aLG1ol]
;Bd6ofATI0Gooooo1ol92@T7ob4Q8@OoEEEE1olF5QH7oaDE5@Oo71`L1olG5aLCooooo`002oooool7
obLW9`Oo?Shn1om@D507of][J`OoOgmo1ola<C47oe=CD`Ko=cLg1Oooool7odI6APOo;bl_1olo?cl7
ooooo`Oo10@41om9BDT7ocTi>@Ko@D511_ooool6oa`L70Oo>CTi1ol];Bd7oaHF5POo;bl_1ol92@T7
o`/;2`Ko=cLg1_ooool7o`/;2`Oo@d=31_l51@D7oc4a<@Oo8B4Q1ol];Bd7ok>c/`Ko>SXj1_ooool7
oaTI6@Oo410@1ol;2`/7od92@PKoEUIF1ol[:b/7od92@PKoEEEE1_ooool7og9bLPOo6a/K1olj>SX7
od=3@`Oo>CTi1onSXj<6o`X:2PKoCDe=1_ooool7o`h>3POo820P1olM7Ad7o`L71`OoJVYZ1olG5aL7
obd];@KoI6AT1Oooool7o`T92@Oo8B4Q1omEEED7oaHF5POo5ADE1olL71`7oaLG5a?ooooo000;oooo
o`Oo9bLW1oln?Sh7oe1@D0OoJf][1omoOgl7oc4a<@OoDe=C1_lg=cL5ooooo`OoATI61ol_;bl7oclo
?`Oooooo1ol410@7odU9B@Oo>CTi1_m1@D46ooooo`Ko71`L1oli>CT7obd];@Oo5QHF1ol_;bl7o`T9
2@Oo2`/;1_lg=cL6ooooo`Oo2`/;1om3@d<6o`D51@Oo<C4a1olQ8B47obd];@Oo/k>c1_lj>SX6oooo
o`Oo6ATI1ol@4107o`/;2`Oo@T921_mFEUH7ob/[:`Oo@T921_mEEED6ooooo`OoLW9b1olK6a/7ocXj
>POo@d=31oli>CT7oj>SX`Ko2PX:1_m=CDd6ooooo`Oo3Ph>1olP8207oadM7@Oo1`L71omZJVX7oaLG
5`Oo;Bd]1_mTI6@5ooooo`Oo2@T91olQ8B47oeEEE@Oo5QHF1olE5AD7oa`L70Oo5aLG4oooool000_o
oooo1om6ATH7ooooo`OoY:BT1onLW9`7ol30`0OoAdM71om]KFd6oe9BDPGooooo1olQ8B47ob8R8POo
;Rh^1om=CDd7o`X:2POo>CTi1ol`<306o`@410Kooooo1_lM7Ad7od10@0Oo51@D1olQ8B47o`L71`Oo
20P81ol71`L6ob`/;0Kooooo1ol00007oa0@40Ko3@d=1ol/;2`7obh^;POoFUYJ1oooool6oa`L70Ko
oooo1ol@4107oaXJ6POo5aLG1om0@406oe5AD@Oo820P1omBDU86oclo?`Kooooo1olo?cl7o`h>3POo
9RHV1olF5QH7oa`L70OoJVYZ1_l;2`/6oe9BDPKooooo1ol00007oadM7@Oo51@D1ol?3`l7oc`l?0Oo
410@1olb<S86odM7A`Gooooo1olJ6QX7oalO7`Oo<30`1ol20P87obDU9@Oo7QhN1ol_;bl6om?Cd`go
oooo000;ooooo`OoATI61oooool7ojBTY0OoW9bL1oo0`<07odM7A`OoKFe]1_mBDU85ooooo`Oo8B4Q
1olR8R87obh^;POoCDe=1ol:2PX7ocTi>@Oo<30`1_l410@6ooooo`Ko7AdM1om0@407oa@D50Oo8B4Q
1ol71`L7o`P820Oo1`L71_l/;2`6ooooo`Oo00001ol@4106o`d=3@Oo;2`/1ol^;Rh7oeYJFPOooooo
1_lL71`6ooooo`Oo410@1olJ6QX7oaLG5`Oo@4101_mADE47ob0P80OoDU9B1_lo?cl6ooooo`Oo?clo
1ol>3Ph7obHV9POo5QHF1olL71`7ofYZJPKo2`/;1_mBDU86ooooo`Oo00001olM7Ad7oa@D50Oo3`l?
1oll?3`7oa0@40Oo<S8b1_m7AdL5ooooo`Oo6QXJ1olO7al7oc0`<0Oo0P821olU9BD7oahN7POo;bl_
1_oCdm<=ooooo`002oooool7odI6APOooooo1onTY:@7oibLW0Oo`<301om7AdL7ofe]K@KoDU9B1Ooo
ool7ob4Q8@Oo8R8R1ol^;Rh7ode=C@Oo2PX:1oli>CT7oc0`<0Ko10@41_ooool6oadM7@Oo@4101olD
51@7ob4Q8@Oo1`L71ol820P7o`L71`Ko;2`/1_ooool7o`0000Oo410@1_l=3@d7ob`/;0Oo;Rh^1omJ
FUX7ooooo`Ko71`L1_ooool7oa0@40Oo6QXJ1olG5aL7od10@0KoDE5A1olP8207oe9BDPKo?clo1_oo
ool7oclo?`Oo3Ph>1olV9RH7oaHF5POo71`L1omZJVX6o`/;2`KoDU9B1_ooool7o`0000Oo7AdM1olD
51@7o`l?3`Oo?3`l1ol@4107oc8b<PKoAdM71Oooool7oaXJ6POo7alO1ol`<307o`820POo9BDU1olN
7Qh7obl_;`Kodm?C3Oooool000_ooooo1om6ATH7ooooo`OoY:BT1onLW9`7ol30`0OoAdM71om]KFd6
oe9BDPGooooo1olQ8B47ob8R8POo;Rh^1om=CDd7o`X:2POo>CTi1ol`<306o`@410Kooooo1_lM7Ad7
od10@0Oo51@D1olQ8B47o`L71`Oo20P81ol71`L6ob`/;0Kooooo1ol00007oa0@40Ko3@d=1ol/;2`7
obh^;POoFUYJ1oooool6oa`L70Kooooo1ol@4107oaXJ6POo5aLG1om0@406oe5AD@Oo820P1omBDU86
oclo?`Kooooo1olo?cl7o`h>3POo9RHV1olF5QH7oa`L70OoJVYZ1_l;2`/6oe9BDPKooooo1ol00007
oadM7@Oo51@D1ol?3`l7oc`l?0Oo410@1olb<S86odM7A`Gooooo1olJ6QX7oalO7`Oo<30`1ol20P87
obDU9@Oo7QhN1ol_;bl6om?Cd`gooooo000;ooooo`OoATI61oooool7ojBTY0OoW9bL1oo0`<07odM7
A`OoKFe]1_mBDU85ooooo`Oo8B4Q1olR8R87obh^;POoCDe=1ol:2PX7ocTi>@Oo<30`1_l410@6oooo
o`Ko7AdM1om0@407oa@D50Oo8B4Q1ol71`L7o`P820Oo1`L71_l/;2`6ooooo`Oo00001ol@4106o`d=
3@Oo;2`/1ol^;Rh7oeYJFPOooooo1_lL71`6ooooo`Oo410@1olJ6QX7oaLG5`Oo@4101_mADE47ob0P
80OoDU9B1_lo?cl6ooooo`Oo?clo1ol>3Ph7obHV9POo5QHF1olL71`7ofYZJPKo2`/;1_mBDU86oooo
o`Oo00001olM7Ad7oa@D50Oo3`l?1oll?3`7oa0@40Oo<S8b1_m7AdL5ooooo`Oo6QXJ1olO7al7oc0`
<0Oo0P821olU9BD7oahN7POo;bl_1_oCdm<=ooooo`002oooool7odI6APOooooo1onTY:@7oibLW0Oo
`<301om7AdL7ofe]K@KoDU9B1Oooool7ob4Q8@Oo8R8R1ol^;Rh7ode=C@Oo2PX:1oli>CT7oc0`<0Ko
10@41_ooool6oadM7@Oo@4101olD51@7ob4Q8@Oo1`L71ol820P7o`L71`Ko;2`/1_ooool7o`0000Oo
410@1_l=3@d7ob`/;0Oo;Rh^1omJFUX7ooooo`Ko71`L1_ooool7oa0@40Oo6QXJ1olG5aL7od10@0Ko
DE5A1olP8207oe9BDPKo?clo1_ooool7oclo?`Oo3Ph>1olV9RH7oaHF5POo71`L1omZJVX6o`/;2`Ko
DU9B1_ooool7o`0000Oo7AdM1olD51@7o`l?3`Oo?3`l1ol@4107oc8b<PKoAdM71Oooool7oaXJ6POo
7alO1ol`<307o`820POo9BDU1olN7Qh7obl_;`Kodm?C3Oooool000_ooooo1om6ATH7ooooo`OoY:BT
1onLW9`7ol30`0OoAdM71om]KFd6oe9BDPGooooo1olQ8B47ob8R8POo;Rh^1om=CDd7o`X:2POo>CTi
1ol`<306o`@410Kooooo1_lM7Ad7od10@0Oo51@D1olQ8B47o`L71`Oo20P81ol71`L6ob`/;0Kooooo
1ol00007oa0@40Ko3@d=1ol/;2`7obh^;POoFUYJ1oooool6oa`L70Kooooo1ol@4107oaXJ6POo5aLG
1om0@406oe5AD@Oo820P1omBDU86oclo?`Kooooo1olo?cl7o`h>3POo9RHV1olF5QH7oa`L70OoJVYZ
1_l;2`/6oe9BDPKooooo1ol00007oadM7@Oo51@D1ol?3`l7oc`l?0Oo410@1olb<S86odM7A`Gooooo
1olJ6QX7oalO7`Oo<30`1ol20P87obDU9@Oo7QhN1ol_;bl6om?Cd`gooooo000;ooooo`Oo>c/k1ooM
gMd7ogMgM`OoX:2P1omGEeL7obl_;`OoCdm?1_m1@D45ooooo`OoIVIV1ol;2`/7o`h>3POoGemO1ol0
0007ob/[:`OoDE5A1_l^;Rh6ooooo`Ko410@1olD51@7oa<C4`Oo3`l?1olC4a<7o`0000Oo6a/K1_l@
4106ooooo`Oo0@411olZ:RX6o`l?3`ko4Q8B1omGEeL7okfm_@Ko6ATI1_ooool7oaTI6@Oo6QXJ1olS
8b<7obPX:0Ko<S8b1ol[:b/7oalO7`Ko>SXj1_ooool7ob8R8POo00001om@D507oa0@40Oo1@D51om4
A4@6o`P820KoEUIF1_ooool7o`T92@Oo@D511olI6AT7o`410@Oo@D511ol51@D7ob4Q8@KoBDU91Ooo
ool7oa@D50Oo410@1olc<c<7o`0000Oo@4101ol`<307o`h>3PKoDe=C3Oooool000_ooooo1olk>c/7
omgMg@OoMgMg1onPX:07oeMGE`Oo;bl_1om?Cdl6od51@@Gooooo1omVIVH7o`/;2`Oo3Ph>1omOGel7
o`0000Oo:b/[1omADE46obh^;PKooooo1_l@4107oa@D50Oo4a<C1ol?3`l7oa<C4`Oo00001olK6a/6
oa0@40Kooooo1ol10@47obXZ:PKo3`l?3_lB4Q87oeMGE`Oo_Kfm1_lI6AT6ooooo`Oo6ATI1olJ6QX7
ob<S8`Oo:2PX1_lb<S87ob/[:`Oo7alO1_lj>SX6ooooo`Oo8R8R1ol00007oe1@D0Oo410@1ol51@D7
odA4A0Ko20P81_mFEUH6ooooo`Oo2@T91om1@D47oaTI6@Oo0@411om1@D47o`D51@Oo8B4Q1_m9BDT5
ooooo`Oo51@D1ol@4107oc<c<`Oo00001om0@407oc0`<0Oo3Ph>1_mCDe<=ooooo`002oooool7oc/k
>`OogMgM1omgMgL7oj2PX0OoEeMG1ol_;bl7odm?C`Ko@D511Oooool7ofIVIPOo2`/;1ol>3Ph7oemO
G`Oo00001ol[:b/7oe5AD@Ko;Rh^1_ooool6oa0@40Oo51@D1olC4a<7o`l?3`Oo4a<C1ol00007oa/K
6`Ko410@1_ooool7o`410@Oo:RXZ1_l?3`l>oa8B4POoEeMG1onm_Kd6oaTI6@Kooooo1olI6AT7oaXJ
6POo8b<S1olX:2P6oc8b<POo:b/[1olO7al6ocXj>PKooooo1olR8R87o`0000OoD51@1ol@4107o`D5
1@OoA4A41_l820P6oeIFEPKooooo1ol92@T7od51@@Oo6ATI1ol10@47od51@@Oo1@D51olQ8B46odU9
B@Gooooo1olD51@7oa0@40Oo<c<c1ol00007od10@0Oo<30`1ol>3Ph6oe=CD`gooooo000;ooooo`Oo
>c/k1ooMgMd7ogMgM`OoX:2P1omGEeL7obl_;`OoCdm?1_m1@D45ooooo`OoIVIV1ol;2`/7o`h>3POo
GemO1ol00007ob/[:`OoDE5A1_l^;Rh6ooooo`Ko410@1olD51@7oa<C4`Oo3`l?1olC4a<7o`0000Oo
6a/K1_l@4106ooooo`Oo0@411olZ:RX6o`l?3`ko4Q8B1omGEeL7okfm_@Ko6ATI1_ooool7oaTI6@Oo
6QXJ1olS8b<7obPX:0Ko<S8b1ol[:b/7oalO7`Ko>SXj1_ooool7ob8R8POo00001om@D507oa0@40Oo
1@D51om4A4@6o`P820KoEUIF1_ooool7o`T92@Oo@D511olI6AT7o`410@Oo@D511ol51@D7ob4Q8@Ko
BDU91Oooool7oa@D50Oo410@1olc<c<7o`0000Oo@4101ol`<307o`h>3PKoDe=C3Oooool000_ooooo
1olk>c/7omgMg@OoMgMg1onPX:07oeMGE`Oo;bl_1om?Cdl6od51@@Gooooo1omVIVH7o`/;2`Oo3Ph>
1omOGel7o`0000Oo:b/[1omADE46obh^;PKooooo1_l@4107oa@D50Oo4a<C1ol?3`l7oa<C4`Oo0000
1olK6a/6oa0@40Kooooo1ol10@47obXZ:PKo3`l?3_lB4Q87oeMGE`Oo_Kfm1_lI6AT6ooooo`Oo6ATI
1olJ6QX7ob<S8`Oo:2PX1_lb<S87ob/[:`Oo7alO1_lj>SX6ooooo`Oo8R8R1ol00007oe1@D0Oo410@
1ol51@D7odA4A0Ko20P81_mFEUH6ooooo`Oo2@T91om1@D47oaTI6@Oo0@411om1@D47o`D51@Oo8B4Q
1_m9BDT5ooooo`Oo51@D1ol@4107oc<c<`Oo00001om0@407oc0`<0Oo3Ph>1_mCDe<=ooooo`002ooo
ool7oc/k>`OogMgM1omgMgL7oj2PX0OoEeMG1ol_;bl7odm?C`Ko@D511Oooool7ofIVIPOo2`/;1ol>
3Ph7oemOG`Oo00001ol[:b/7oe5AD@Ko;Rh^1_ooool6oa0@40Oo51@D1olC4a<7o`l?3`Oo4a<C1ol0
0007oa/K6`Ko410@1_ooool7o`410@Oo:RXZ1_l?3`l>oa8B4POoEeMG1onm_Kd6oaTI6@Kooooo1olI
6AT7oaXJ6POo8b<S1olX:2P6oc8b<POo:b/[1olO7al6ocXj>PKooooo1olR8R87o`0000OoD51@1ol@
4107o`D51@OoA4A41_l820P6oeIFEPKooooo1ol92@T7od51@@Oo6ATI1ol10@47od51@@Oo1@D51olQ
8B46odU9B@Gooooo1olD51@7oa0@40Oo<c<c1ol00007od10@0Oo<30`1ol>3Ph6oe=CD`gooooo000;
ooooo`Oo>c/k1ooMgMd7ogMgM`OoX:2P1omGEeL7obl_;`OoCdm?1_m1@D45ooooo`OoIVIV1ol;2`/7
o`h>3POoGemO1ol00007ob/[:`OoDE5A1_l^;Rh6ooooo`Ko410@1olD51@7oa<C4`Oo3`l?1olC4a<7
o`0000Oo6a/K1_l@4106ooooo`Oo0@411olZ:RX6o`l?3`ko4Q8B1omGEeL7okfm_@Ko6ATI1_ooool7
oaTI6@Oo6QXJ1olS8b<7obPX:0Ko<S8b1ol[:b/7oalO7`Ko>SXj1_ooool7ob8R8POo00001om@D507
oa0@40Oo1@D51om4A4@6o`P820KoEUIF1_ooool7o`T92@Oo@D511olI6AT7o`410@Oo@D511ol51@D7
ob4Q8@KoBDU91Oooool7oa@D50Oo410@1olc<c<7o`0000Oo@4101ol`<307o`h>3PKoDe=C3Oooool0
00_ooooo1olQ8B47oeEEE@Oo@4101omADE47od92@POo<c<c1olK6a/6ocPh>0Gooooo1ol[:b/7oc4a
<@Oo3Ph>1olW9bL7oa@D50Oo4Q8B1olU9BD6oaLG5`Kooooo1_lf=SH7oe5AD@Oo;Rh^1olM7Ad7ob<S
8`Oo6ATI1olR8R8<ooooo`Oo=3@d1olX:2P6oa0@40Oo>3Ph1ol[:b/7oc4a<@Oo6a/K1_l^;Rh6oooo
o`Oo8B4Q1olR8R87ob0P80OoDE5A1_n0P807ocTi>@Oo>c/k1_m8B4P6ooooo`OoKFe]1olA4A47ocDe
=@Oo<S8b1oli>CT7obPX:0Ko3`l?1_mRHV86ooooo`Oo2PX:1om0@407ob@T90Oo:2PX1olY:BT7oaTI
6@Oo7QhN1_n:RXX5ooooo`Oo5ADE1om4A4@7ob8R8POo0P821ol=3@d7obd];@Oo71`L1_lk>c/=oooo
o`002oooool7ob4Q8@OoEEEE1om0@407oe5AD@Oo@T921olc<c<7oa/K6`Ko>3Ph1Oooool7ob/[:`Oo
<C4a1ol>3Ph7obLW9`Oo51@D1olB4Q87obDU9@Ko5aLG1_ooool6ocHf=POoDE5A1ol^;Rh7oadM7@Oo
8b<S1olI6AT7ob8R8Pcooooo1old=3@7obPX:0Ko410@1olh>3P7ob/[:`Oo<C4a1olK6a/6obh^;PKo
oooo1olQ8B47ob8R8POo820P1omADE46oh20P0Oo>CTi1olk>c/6odQ8B0Kooooo1om]KFd7oa4A4@Oo
=CDe1olb<S87ocTi>@Oo:2PX1_l?3`l6of9RHPKooooo1ol:2PX7od10@0Oo92@T1olX:2P7obTY:@Oo
6ATI1olN7Qh6ohZ:RPGooooo1olE5AD7odA4A0Oo8R8R1ol20P87o`d=3@Oo;Bd]1olL71`6oc/k>`go
oooo000;ooooo`Oo8B4Q1omEEED7od10@0OoDE5A1om2@T87oc<c<`Oo6a/K1_lh>3P5ooooo`Oo:b/[
1ola<C47o`h>3POo9bLW1olD51@7oa8B4POo9BDU1_lG5aL6ooooo`Ko=SHf1omADE47obh^;POo7AdM
1olS8b<7oaTI6@Oo8R8R3?ooool7oc@d=0Oo:2PX1_l@4107ocPh>0Oo:b/[1ola<C47oa/K6`Ko;Rh^
1_ooool7ob4Q8@Oo8R8R1olP8207oe5AD@KoP8201oli>CT7oc/k>`KoB4Q81_ooool7ofe]K@Oo4A4A
1ole=CD7oc8b<POo>CTi1olX:2P6o`l?3`KoHV9R1_ooool7o`X:2POo@4101olT92@7obPX:0Oo:BTY
1olI6AT7oahN7PKoRXZ:1Oooool7oaDE5@OoA4A41olR8R87o`820POo3@d=1ol];Bd7oa`L70Ko>c/k
3Oooool000_ooooo1olQ8B47oeEEE@Oo@4101omADE47od92@POo<c<c1olK6a/6ocPh>0Gooooo1ol[
:b/7oc4a<@Oo3Ph>1olW9bL7oa@D50Oo4Q8B1olU9BD6oaLG5`Kooooo1_lf=SH7oe5AD@Oo;Rh^1olM
7Ad7ob<S8`Oo6ATI1olR8R8<ooooo`Oo=3@d1olX:2P6oa0@40Oo>3Ph1ol[:b/7oc4a<@Oo6a/K1_l^
;Rh6ooooo`Oo8B4Q1olR8R87ob0P80OoDE5A1_n0P807ocTi>@Oo>c/k1_m8B4P6ooooo`OoKFe]1olA
4A47ocDe=@Oo<S8b1oli>CT7obPX:0Ko3`l?1_mRHV86ooooo`Oo2PX:1om0@407ob@T90Oo:2PX1olY
:BT7oaTI6@Oo7QhN1_n:RXX5ooooo`Oo5ADE1om4A4@7ob8R8POo0P821ol=3@d7obd];@Oo71`L1_lk
>c/=ooooo`002oooool7ob4Q8@OoEEEE1om0@407oe5AD@Oo@T921olc<c<7oa/K6`Ko>3Ph1Oooool7
ob/[:`Oo<C4a1ol>3Ph7obLW9`Oo51@D1olB4Q87obDU9@Ko5aLG1_ooool6ocHf=POoDE5A1ol^;Rh7
oadM7@Oo8b<S1olI6AT7ob8R8Pcooooo1old=3@7obPX:0Ko410@1olh>3P7ob/[:`Oo<C4a1olK6a/6
obh^;PKooooo1olQ8B47ob8R8POo820P1omADE46oh20P0Oo>CTi1olk>c/6odQ8B0Kooooo1om]KFd7
oa4A4@Oo=CDe1olb<S87ocTi>@Oo:2PX1_l?3`l6of9RHPKooooo1ol:2PX7od10@0Oo92@T1olX:2P7
obTY:@Oo6ATI1olN7Qh6ohZ:RPGooooo1olE5AD7odA4A0Oo8R8R1ol20P87o`d=3@Oo;Bd]1olL71`6
oc/k>`gooooo000;ooooo`Oo8B4Q1omEEED7od10@0OoDE5A1om2@T87oc<c<`Oo6a/K1_lh>3P5oooo
o`Oo:b/[1ola<C47o`h>3POo9bLW1olD51@7oa8B4POo9BDU1_lG5aL6ooooo`Ko=SHf1omADE47obh^
;POo7AdM1olS8b<7oaTI6@Oo8R8R3?ooool7oc@d=0Oo:2PX1_l@4107ocPh>0Oo:b/[1ola<C47oa/K
6`Ko;Rh^1_ooool7ob4Q8@Oo8R8R1olP8207oe5AD@KoP8201oli>CT7oc/k>`KoB4Q81_ooool7ofe]
K@Oo4A4A1ole=CD7oc8b<POo>CTi1olX:2P6o`l?3`KoHV9R1_ooool7o`X:2POo@4101olT92@7obPX
:0Oo:BTY1olI6AT7oahN7PKoRXZ:1Oooool7oaDE5@OoA4A41olR8R87o`820POo3@d=1ol];Bd7oa`L
70Ko>c/k3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo1olQ8B47oa4A4@Oo6ATI1olT
92@7oclo?`OoRHV91om`L706odM7A`Gooooo1ol<30`7obd];@Oo6a/K1ol00007ocLg=`Oo4a<C1olN
7Qh6odM7A`Kooooo1_lM7Ad>oahN7POo7AdM1olT92@7oa<C4`Oo5QHF1_l];Bd6ooooo`OoGEeM1oo=
cLd6ocHf=POoIVIV1olZ:RX7ohZ:RPOoRh^;1_lm?Cd6ooooo`Oo4a<C1olE5AD7oalO7`Oo5ADE1_l?
3`l7oa4A4@Oo4Q8B1_lM7Ad6ooooo`OoIFEU1ol10@47odM7A`Oo6a/K1ol`<307ok:b/PKo61PH1_lD
51@6ooooo`Oo;Bd]1ol820P7oh20P0Oo30`<1olg=cL7oaLG5`OoH61P1_o8b<P5ooooo`Oo3`l?1om<
C4`7o`d=3@Oo;bl_1olh>3P7oahN7POoD51@1_lR8R8=ooooo`002oooool7ob4Q8@Oo4A4A1olI6AT7
ob@T90Oo?clo1on9RHT7og1`L0KoAdM71Oooool7o``<30Oo;Bd]1olK6a/7o`0000Oo=cLg1olC4a<7
oahN7PKoAdM71_ooool6oadM7@ko7QhN1olM7Ad7ob@T90Oo4a<C1olF5QH6obd];@Kooooo1omMGEd7
olg=c@Ko=SHf1omVIVH7obXZ:POoRXZ:1on;Rh/6ocdm?@Kooooo1olC4a<7oaDE5@Oo7alO1olE5AD6
o`l?3`Oo4A4A1olB4Q86oadM7@Kooooo1omUIFD7o`410@OoAdM71olK6a/7oc0`<0Oo/[:b1_lH61P6
oa@D50Kooooo1ol];Bd7o`P820OoP8201ol<30`7ocLg=`Oo5aLG1omPH606olS8b0Gooooo1ol?3`l7
oda<C0Oo3@d=1ol_;bl7ocPh>0Oo7QhN1om@D506ob8R8Pgooooo000;ooooo`Oo8B4Q1olA4A47oaTI
6@Oo92@T1olo?cl7ohV9R@OoL71`1_m7AdL5ooooo`Oo30`<1ol];Bd7oa/K6`Oo00001olg=cL7oa<C
4`Oo7QhN1_m7AdL6ooooo`Ko7AdM3_lN7Qh7oadM7@Oo92@T1olC4a<7oaHF5PKo;Bd]1_ooool7oeeM
G@OocLg=1_lf=SH7ofIVIPOo:RXZ1on:RXX7oh^;R`Ko?Cdm1_ooool7oa<C4`Oo5ADE1olO7al7oaDE
5@Ko3`l?1olA4A47oa8B4PKo7AdM1_ooool7ofEUI@Oo0@411om7AdL7oa/K6`Oo<30`1onb/[86oaPH
60Ko51@D1_ooool7obd];@Oo20P81on0P807o``<30Oo=cLg1olG5aL7of1PH0Kob<S81Oooool7o`l?
3`OoC4a<1ol=3@d7obl_;`Oo>3Ph1olN7Qh7oe1@D0Ko8R8R3Oooool000_ooooo1olQ8B47oa4A4@Oo
6ATI1olT92@7oclo?`OoRHV91om`L706odM7A`Gooooo1ol<30`7obd];@Oo6a/K1ol00007ocLg=`Oo
4a<C1olN7Qh6odM7A`Kooooo1_lM7Ad>oahN7POo7AdM1olT92@7oa<C4`Oo5QHF1_l];Bd6ooooo`Oo
GEeM1oo=cLd6ocHf=POoIVIV1olZ:RX7ohZ:RPOoRh^;1_lm?Cd6ooooo`Oo4a<C1olE5AD7oalO7`Oo
5ADE1_l?3`l7oa4A4@Oo4Q8B1_lM7Ad6ooooo`OoIFEU1ol10@47odM7A`Oo6a/K1ol`<307ok:b/PKo
61PH1_lD51@6ooooo`Oo;Bd]1ol820P7oh20P0Oo30`<1olg=cL7oaLG5`OoH61P1_o8b<P5ooooo`Oo
3`l?1om<C4`7o`d=3@Oo;bl_1olh>3P7oahN7POoD51@1_lR8R8=ooooo`002oooool7ob4Q8@Oo4A4A
1olI6AT7ob@T90Oo?clo1on9RHT7og1`L0KoAdM71Oooool7o``<30Oo;Bd]1olK6a/7o`0000Oo=cLg
1olC4a<7oahN7PKoAdM71_ooool6oadM7@ko7QhN1olM7Ad7ob@T90Oo4a<C1olF5QH6obd];@Kooooo
1omMGEd7olg=c@Ko=SHf1omVIVH7obXZ:POoRXZ:1on;Rh/6ocdm?@Kooooo1olC4a<7oaDE5@Oo7alO
1olE5AD6o`l?3`Oo4A4A1olB4Q86oadM7@Kooooo1omUIFD7o`410@OoAdM71olK6a/7oc0`<0Oo/[:b
1_lH61P6oa@D50Kooooo1ol];Bd7o`P820OoP8201ol<30`7ocLg=`Oo5aLG1omPH606olS8b0Gooooo
1ol?3`l7oda<C0Oo3@d=1ol_;bl7ocPh>0Oo7QhN1om@D506ob8R8Pgooooo000;ooooo`Oo8B4Q1olA
4A47oaTI6@Oo92@T1olo?cl7ohV9R@OoL71`1_m7AdL5ooooo`Oo30`<1ol];Bd7oa/K6`Oo00001olg
=cL7oa<C4`Oo7QhN1_m7AdL6ooooo`Ko7AdM3_lN7Qh7oadM7@Oo92@T1olC4a<7oaHF5PKo;Bd]1_oo
ool7oeeMG@OocLg=1_lf=SH7ofIVIPOo:RXZ1on:RXX7oh^;R`Ko?Cdm1_ooool7oa<C4`Oo5ADE1olO
7al7oaDE5@Ko3`l?1olA4A47oa8B4PKo7AdM1_ooool7ofEUI@Oo0@411om7AdL7oa/K6`Oo<30`1onb
/[86oaPH60Ko51@D1_ooool7obd];@Oo20P81on0P807o``<30Oo=cLg1olG5aL7of1PH0Kob<S81Ooo
ool7o`l?3`OoC4a<1ol=3@d7obl_;`Oo>3Ph1olN7Qh7oe1@D0Ko8R8R3Oooool000_ooooo1olQ8B47
oa4A4@Oo6ATI1olT92@7oclo?`OoRHV91om`L706odM7A`Gooooo1ol<30`7obd];@Oo6a/K1ol00007
ocLg=`Oo4a<C1olN7Qh6odM7A`Kooooo1_lM7Ad>oahN7POo7AdM1olT92@7oa<C4`Oo5QHF1_l];Bd6
ooooo`OoGEeM1oo=cLd6ocHf=POoIVIV1olZ:RX7ohZ:RPOoRh^;1_lm?Cd6ooooo`Oo4a<C1olE5AD7
oalO7`Oo5ADE1_l?3`l7oa4A4@Oo4Q8B1_lM7Ad6ooooo`OoIFEU1ol10@47odM7A`Oo6a/K1ol`<307
ok:b/PKo61PH1_lD51@6ooooo`Oo;Bd]1ol820P7oh20P0Oo30`<1olg=cL7oaLG5`OoH61P1_o8b<P5
ooooo`Oo3`l?1om<C4`7o`d=3@Oo;bl_1olh>3P7oahN7POoD51@1_lR8R8=ooooo`002oooool7o``<
30Oo8B4Q3_lE5AD7ocHf=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T
90Oo4a<C1olA4A46ocdm?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo
?`Kooooo1ol/;2`7okBd]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B
4POo3`l?1ol;2`/6o`d=3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEU
I@OoeMGE1_lX:2P6oda<C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5oooo
o`Oo71`L1ol_;bl7o`l?3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7o``<30Oo
8B4Q3_lE5AD7ocHf=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T90Oo
4a<C1olA4A46ocdm?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo?`Ko
oooo1ol/;2`7okBd]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B4POo
3`l?1ol;2`/6o`d=3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEUI@Oo
eMGE1_lX:2P6oda<C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5ooooo`Oo
71`L1ol_;bl7o`l?3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7o``<30Oo8B4Q
3_lE5AD7ocHf=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T90Oo4a<C
1olA4A46ocdm?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo?`Kooooo
1ol/;2`7okBd]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B4POo3`l?
1ol;2`/6o`d=3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEUI@OoeMGE
1_lX:2P6oda<C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5ooooo`Oo71`L
1ol_;bl7o`l?3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7o``<30Oo8B4Q3_lE
5AD7ocHf=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T90Oo4a<C1olA
4A46ocdm?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo?`Kooooo1ol/
;2`7okBd]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B4POo3`l?1ol;
2`/6o`d=3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEUI@OoeMGE1_lX
:2P6oda<C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5ooooo`Oo71`L1ol_
;bl7o`l?3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7o``<30Oo8B4Q3_lE5AD7
ocHf=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T90Oo4a<C1olA4A46
ocdm?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo?`Kooooo1ol/;2`7
okBd]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B4POo3`l?1ol;2`/6
o`d=3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEUI@OoeMGE1_lX:2P6
oda<C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5ooooo`Oo71`L1ol_;bl7
o`l?3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7o``<30Oo8B4Q3_lE5AD7ocHf
=POoWinO1omCDe<6obl_;`Gooooo1olD51@7odA4A0Oo2@T91ol<30`7ob@T90Oo4a<C1olA4A46ocdm
?@Kooooo1_le=CD7oa/K6`Oo92@T1olM7Ad7obPX:0Oo5aLG1olH61P6oclo?`Kooooo1ol/;2`7okBd
]0Ko7QhN1omHF5P7ob/[:`OoNg]k1onj^[X6ob8R8PKooooo1olD51@7oa8B4POo3`l?1ol;2`/6o`d=
3@Oo1`L71ol<30`6oa`L70Kooooo1omkNg/7o`l?3`Oo:BTY1olk>c/7ofEUI@OoeMGE1_lX:2P6oda<
C0Kooooo1ol00007o`L71`OoADE51ol<30`>oahN7POo=CDe1_o>c/h5ooooo`Oo71`L1ol_;bl7o`l?
3`Oo:BTY1olR8R87oaLG5`Oo@d=31_lC4a<=ooooo`002oooool7oa<C4`Oo3Ph>1olC4a<7oaLG5`Oo
ADE51omQHF47ochn?PKo<S8b1Oooool7oa<C4`Oo@D511ol];Bd7o`d=3@Oo;Rh^1olE5AD7obLW9`Ko
ATI61_ooool6ogUiN@Oo;Rh^1olV9RH7obh^;POo6a/K3_l?3`l<ooooo`Oo2`/;1on0P806oa@D50Oo
GEeM1olh>3P7ode=C@Oooooo1_lE5AD6ooooo`Oo5aLG1olS8b<7oa8B4POo1PH61_lD51@7o`P820Oo
2`/;1_lL71`6ooooo`OoB4Q81olX:2P7obDU9@Oo:2PX1oln?Sh7ooooo`Ko7alO1_mMGEd6ooooo`Oo
71`L1olD51@7od51@@Oo5ADE1olj>SX>oaXJ6PKo`L711Oooool7oa@D50Oo61PH1ol=3@d7obPX:0Oo
4Q8B1ol51@D7ocdm?@Ko6QXJ3Oooool000_ooooo1olC4a<7o`h>3POo4a<C1olG5aL7odE5A@OoHF5Q
1oln?Sh6oc8b<PGooooo1olC4a<7od51@@Oo;Bd]1ol=3@d7obh^;POo5ADE1olW9bL6odI6APKooooo
1_miNGT7obh^;POo9RHV1ol^;Rh7oa/K6`ko3`l?3?ooool7o`/;2`OoP8201_lD51@7oeeMG@Oo>3Ph
1om=CDd7ooooo`Ko5ADE1_ooool7oaLG5`Oo8b<S1olB4Q87o`H61PKo51@D1ol820P7o`/;2`Ko71`L
1_ooool7odQ8B0Oo:2PX1olU9BD7obPX:0Oo?Shn1oooool6oalO7`KoGEeM1_ooool7oa`L70Oo51@D
1om1@D47oaDE5@Oo>SXj3_lJ6QX6ol71`@Gooooo1olD51@7oaPH60Oo3@d=1olX:2P7oa8B4POo1@D5
1olm?Cd6oaXJ6Pgooooo000;ooooo`Oo4a<C1ol>3Ph7oa<C4`Oo5aLG1om5ADD7of5QH@Oo?Shn1_lb
<S85ooooo`Oo4a<C1om1@D47obd];@Oo3@d=1ol^;Rh7oaDE5@Oo9bLW1_m6ATH6ooooo`KoNGUi1ol^
;Rh7obHV9POo;Rh^1olK6a/>o`l?3`cooooo1ol;2`/7oh20P0Ko51@D1omMGEd7ocPh>0OoCDe=1ooo
ool6oaDE5@Kooooo1olG5aL7ob<S8`Oo4Q8B1ol61PH6oa@D50Oo20P81ol;2`/6oa`L70Kooooo1om8
B4P7obPX:0Oo9BDU1olX:2P7ochn?POooooo1_lO7al6oeeMG@Kooooo1olL71`7oa@D50Oo@D511olE
5AD7ocXj>Pko6QXJ1_o1`L45ooooo`Oo51@D1olH61P7o`d=3@Oo:2PX1olB4Q87o`D51@Oo?Cdm1_lJ
6QX=ooooo`002oooool7oa<C4`Oo3Ph>1olC4a<7oaLG5`OoADE51omQHF47ochn?PKo<S8b1Oooool7
oa<C4`Oo@D511ol];Bd7o`d=3@Oo;Rh^1olE5AD7obLW9`KoATI61_ooool6ogUiN@Oo;Rh^1olV9RH7
obh^;POo6a/K3_l?3`l<ooooo`Oo2`/;1on0P806oa@D50OoGEeM1olh>3P7ode=C@Oooooo1_lE5AD6
ooooo`Oo5aLG1olS8b<7oa8B4POo1PH61_lD51@7o`P820Oo2`/;1_lL71`6ooooo`OoB4Q81olX:2P7
obDU9@Oo:2PX1oln?Sh7ooooo`Ko7alO1_mMGEd6ooooo`Oo71`L1olD51@7od51@@Oo5ADE1olj>SX>
oaXJ6PKo`L711Oooool7oa@D50Oo61PH1ol=3@d7obPX:0Oo4Q8B1ol51@D7ocdm?@Ko6QXJ3Oooool0
00_ooooo1olC4a<7o`h>3POo4a<C1olG5aL7odE5A@OoHF5Q1oln?Sh6oc8b<PGooooo1olC4a<7od51
@@Oo;Bd]1ol=3@d7obh^;POo5ADE1olW9bL6odI6APKooooo1_miNGT7obh^;POo9RHV1ol^;Rh7oa/K
6`ko3`l?3?ooool7o`/;2`OoP8201_lD51@7oeeMG@Oo>3Ph1om=CDd7ooooo`Ko5ADE1_ooool7oaLG
5`Oo8b<S1olB4Q87o`H61PKo51@D1ol820P7o`/;2`Ko71`L1_ooool7odQ8B0Oo:2PX1olU9BD7obPX
:0Oo?Shn1oooool6oalO7`KoGEeM1_ooool7oa`L70Oo51@D1om1@D47oaDE5@Oo>SXj3_lJ6QX6ol71
`@Gooooo1olD51@7oaPH60Oo3@d=1olX:2P7oa8B4POo1@D51olm?Cd6oaXJ6Pgooooo000;ooooo`Oo
4a<C1ol>3Ph7oa<C4`Oo5aLG1om5ADD7of5QH@Oo?Shn1_lb<S85ooooo`Oo4a<C1om1@D47obd];@Oo
3@d=1ol^;Rh7oaDE5@Oo9bLW1_m6ATH6ooooo`KoNGUi1ol^;Rh7obHV9POo;Rh^1olK6a/>o`l?3`co
oooo1ol;2`/7oh20P0Ko51@D1omMGEd7ocPh>0OoCDe=1oooool6oaDE5@Kooooo1olG5aL7ob<S8`Oo
4Q8B1ol61PH6oa@D50Oo20P81ol;2`/6oa`L70Kooooo1om8B4P7obPX:0Oo9BDU1olX:2P7ochn?POo
oooo1_lO7al6oeeMG@Kooooo1olL71`7oa@D50Oo@D511olE5AD7ocXj>Pko6QXJ1_o1`L45ooooo`Oo
51@D1olH61P7o`d=3@Oo:2PX1olB4Q87o`D51@Oo?Cdm1_lJ6QX=ooooo`002oooool7oa<C4`Oo3Ph>
1olC4a<7oaLG5`OoADE51omQHF47ochn?PKo<S8b1Oooool7oa<C4`Oo@D511ol];Bd7o`d=3@Oo;Rh^
1olE5AD7obLW9`KoATI61_ooool6ogUiN@Oo;Rh^1olV9RH7obh^;POo6a/K3_l?3`l<ooooo`Oo2`/;
1on0P806oa@D50OoGEeM1olh>3P7ode=C@Oooooo1_lE5AD6ooooo`Oo5aLG1olS8b<7oa8B4POo1PH6
1_lD51@7o`P820Oo2`/;1_lL71`6ooooo`OoB4Q81olX:2P7obDU9@Oo:2PX1oln?Sh7ooooo`Ko7alO
1_mMGEd6ooooo`Oo71`L1olD51@7od51@@Oo5ADE1olj>SX>oaXJ6PKo`L711Oooool7oa@D50Oo61PH
1ol=3@d7obPX:0Oo4Q8B1ol51@D7ocdm?@Ko6QXJ3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0
@407ol?3``Oo@T921_lL71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_
;bl6ooooo`Ko:2PX1olF5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?
Cdl6o`820POoP8201old=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol7
1`L7o`P820Ko5ADE1_ooool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_oo
ool7oc@d=0Oo5ADE1olX:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;
2`/7oe1@D0Oo30`<1ol?3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407
ol?3``Oo@T921_lL71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6
ooooo`Ko:2PX1olF5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6
o`820POoP8201old=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7
o`P820Ko5ADE1_ooool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7
oc@d=0Oo5ADE1olX:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7
oe1@D0Oo30`<1ol?3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407ol?3
``Oo@T921_lL71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6oooo
o`Ko:2PX1olF5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6o`82
0POoP8201old=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7o`P8
20Ko5ADE1_ooool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7oc@d
=0Oo5ADE1olX:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7oe1@
D0Oo30`<1ol?3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407ol?3``Oo
@T921_lL71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6ooooo`Ko
:2PX1olF5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6o`820POo
P8201old=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7o`P820Ko
5ADE1_ooool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7oc@d=0Oo
5ADE1olX:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7oe1@D0Oo
30`<1ol?3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407ol?3``Oo@T92
1_lL71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6ooooo`Ko:2PX
1olF5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6o`820POoP820
1old=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7o`P820Ko5ADE
1_ooool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7oc@d=0Oo5ADE
1olX:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7oe1@D0Oo30`<
1ol?3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407ol?3``Oo@T921_lL
71`5ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6ooooo`Ko:2PX1olF
5QH7obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6o`820POoP8201old
=3@7obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7o`P820Ko5ADE1_oo
ool7obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7oc@d=0Oo5ADE1olX
:2P7oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7oe1@D0Oo30`<1ol?
3`l7obd];@KoOWin3Oooool000_ooooo1ol>3Ph7ob4Q8@ko4Q8B1om0@407ol?3``Oo@T921_lL71`5
ooooo`Oo4Q8B1om<C4`7oe1@D0Oo1@D51olT92@7oaHF5POo@T921_l_;bl6ooooo`Ko:2PX1olF5QH7
obPX:0Oo6a/K1ol51@D7o`H61POo20P81_m:BTX6ooooo`Oo6a/K1om?Cdl6o`820POoP8201old=3@7
obd];@Oooooo1_lQ8B46ooooo`Oo2PX:1olQ8B4>o`X:2PKo5QHF1ol71`L7o`P820Ko5ADE1_ooool7
obHV9POo00001olO7al7o`/;2`Oo71`L1omBDU86o``<30KoDE5A1_ooool7oc@d=0Oo5ADE1olX:2P7
oa4A4@OoH61P1olI6AT7oa`L70KoMGEe1Oooool7ob0P80Oo9RHV1ol;2`/7oe1@D0Oo30`<1ol?3`l7
obd];@KoOWin3Oooool000_ooooo1ol00007o`T92@Oo6ATI1olB4Q87odU9B@OoBTY:1olL71`6obDU
9@Gooooo1ol_;bl7oc<c<`Oo[jn_1olB4Q87obDU9@Oo61PH1omCDe<6oeIFEPKooooo1_lC4a<7oa`L
70Oo51@D1olK6a/7o``<30Oo0P821ol820P6ob@T90Kooooo1olM7Ad7od10@0Ko30`<1om^KVh7oaLG
5`Oo7QhN1onRXZ86obXZ:PKooooo1olB4Q87oaPH60Oo1`L71ol00006oa@D50Oo30`<1ol=3@d6oalO
7`Kooooo1olE5AD7o`0000OoA4A41ol61PH7o`<30`Oo;Rh^1_l61PH6oeeMG@Kooooo1onMWId7oaPH
60OoA4A41olO7al7ogUiN@Oo92@T1ol^;Rh6oeUIF@Gooooo1olR8R87oc@d=0Oo00001omMGEd7oa@D
50Oo3@d=1ol`<306okFe]@gooooo000;ooooo`Oo00001ol92@T7oaTI6@Oo4Q8B1om9BDT7odY:BPOo
71`L1_lU9BD5ooooo`Oo;bl_1olc<c<7ojn_[`Oo4Q8B1olU9BD7oaPH60OoDe=C1_mFEUH6ooooo`Ko
4a<C1olL71`7oa@D50Oo6a/K1ol<30`7o`820POo20P81_lT92@6ooooo`Oo7AdM1om0@406o``<30Oo
KVi^1olG5aL7oahN7POoXZ:R1_lZ:RX6ooooo`Oo4Q8B1olH61P7o`L71`Oo00001_lD51@7o``<30Oo
3@d=1_lO7al6ooooo`Oo5ADE1ol00007odA4A0Oo1PH61ol30`<7obh^;PKo1PH61_mMGEd6ooooo`Oo
WIfM1olH61P7odA4A0Oo7alO1omiNGT7ob@T90Oo;Rh^1_mIFET5ooooo`Oo8R8R1old=3@7o`0000Oo
GEeM1olD51@7o`d=3@Oo<30`1_ne]KD=ooooo`002oooool7o`0000Oo2@T91olI6AT7oa8B4POoBDU9
1om:BTX7oa`L70Ko9BDU1Oooool7obl_;`Oo<c<c1on_[jl7oa8B4POo9BDU1olH61P7oe=CD`KoEUIF
1_ooool6oa<C4`Oo71`L1olD51@7oa/K6`Oo30`<1ol20P87o`P820Ko92@T1_ooool7oadM7@Oo@410
1_l<30`7ofi^KPOo5aLG1olN7Qh7oj:RXPKo:RXZ1_ooool7oa8B4POo61PH1ol71`L7o`0000Ko51@D
1ol<30`7o`d=3@Ko7alO1_ooool7oaDE5@Oo00001om4A4@7o`H61POo0`<31ol^;Rh6o`H61PKoGEeM
1_ooool7oifMW@Oo61PH1om4A4@7oalO7`OoNGUi1olT92@7obh^;PKoFEUI1Oooool7ob8R8POo=3@d
1ol00007oeeMG@Oo51@D1ol=3@d7oc0`<0Ko]KFe3Oooool000_ooooo1ol00007o`T92@Oo6ATI1olB
4Q87odU9B@OoBTY:1olL71`6obDU9@Gooooo1ol_;bl7oc<c<`Oo[jn_1olB4Q87obDU9@Oo61PH1omC
De<6oeIFEPKooooo1_lC4a<7oa`L70Oo51@D1olK6a/7o``<30Oo0P821ol820P6ob@T90Kooooo1olM
7Ad7od10@0Ko30`<1om^KVh7oaLG5`Oo7QhN1onRXZ86obXZ:PKooooo1olB4Q87oaPH60Oo1`L71ol0
0006oa@D50Oo30`<1ol=3@d6oalO7`Kooooo1olE5AD7o`0000OoA4A41ol61PH7o`<30`Oo;Rh^1_l6
1PH6oeeMG@Kooooo1onMWId7oaPH60OoA4A41olO7al7ogUiN@Oo92@T1ol^;Rh6oeUIF@Gooooo1olR
8R87oc@d=0Oo00001omMGEd7oa@D50Oo3@d=1ol`<306okFe]@gooooo000;ooooo`Oo00001ol92@T7
oaTI6@Oo4Q8B1om9BDT7odY:BPOo71`L1_lU9BD5ooooo`Oo;bl_1olc<c<7ojn_[`Oo4Q8B1olU9BD7
oaPH60OoDe=C1_mFEUH6ooooo`Ko4a<C1olL71`7oa@D50Oo6a/K1ol<30`7o`820POo20P81_lT92@6
ooooo`Oo7AdM1om0@406o``<30OoKVi^1olG5aL7oahN7POoXZ:R1_lZ:RX6ooooo`Oo4Q8B1olH61P7
o`L71`Oo00001_lD51@7o``<30Oo3@d=1_lO7al6ooooo`Oo5ADE1ol00007odA4A0Oo1PH61ol30`<7
obh^;PKo1PH61_mMGEd6ooooo`OoWIfM1olH61P7odA4A0Oo7alO1omiNGT7ob@T90Oo;Rh^1_mIFET5
ooooo`Oo8R8R1old=3@7o`0000OoGEeM1olD51@7o`d=3@Oo<30`1_ne]KD=ooooo`002oooool7o`00
00Oo2@T91olI6AT7oa8B4POoBDU91om:BTX7oa`L70Ko9BDU1Oooool7obl_;`Oo<c<c1on_[jl7oa8B
4POo9BDU1olH61P7oe=CD`KoEUIF1_ooool6oa<C4`Oo71`L1olD51@7oa/K6`Oo30`<1ol20P87o`P8
20Ko92@T1_ooool7oadM7@Oo@4101_l<30`7ofi^KPOo5aLG1olN7Qh7oj:RXPKo:RXZ1_ooool7oa8B
4POo61PH1ol71`L7o`0000Ko51@D1ol<30`7o`d=3@Ko7alO1_ooool7oaDE5@Oo00001om4A4@7o`H6
1POo0`<31ol^;Rh6o`H61PKoGEeM1_ooool7oifMW@Oo61PH1om4A4@7oalO7`OoNGUi1olT92@7obh^
;PKoFEUI1Oooool7ob8R8POo=3@d1ol00007oeeMG@Oo51@D1ol=3@d7oc0`<0Ko]KFe3Oooool000_o
oooo1ol92@T7o`/;2`Oo6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo
71`L1old=3@7ob8R8POoEEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo
0`<31_l_;bl6ooooo`Oo:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo
4A4A1olG5aL7o`X:2POo20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo
=CDe1ol00007obh^;PKo3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo
@D511_mLG5`5ooooo`Oo7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo
1ol92@T7o`/;2`Oo6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L
1old=3@7ob8R8POoEEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<3
1_l_;bl6ooooo`Oo:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A
1olG5aL7o`X:2POo20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe
1ol00007obh^;PKo3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D51
1_mLG5`5ooooo`Oo7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol9
2@T7o`/;2`Oo6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L1old
=3@7ob8R8POoEEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<31_l_
;bl6ooooo`Oo:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A1olG
5aL7o`X:2POo20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe1ol0
0007obh^;PKo3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D511_mL
G5`5ooooo`Oo7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol92@T7
o`/;2`Oo6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L1old=3@7
ob8R8POoEEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<31_l_;bl6
ooooo`Oo:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A1olG5aL7
o`X:2POo20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe1ol00007
obh^;PKo3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D511_mLG5`5
ooooo`Oo7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol92@T7o`/;
2`Oo6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L1old=3@7ob8R
8POoEEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<31_l_;bl6oooo
o`Oo:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A1olG5aL7o`X:
2POo20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe1ol00007obh^
;PKo3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D511_mLG5`5oooo
o`Oo7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol92@T7o`/;2`Oo
6QXJ1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L1old=3@7ob8R8POo
EEEE1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<31_l_;bl6ooooo`Oo
:2PX1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A1olG5aL7o`X:2POo
20P81_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe1ol00007obh^;PKo
3`l?1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D511_mLG5`5ooooo`Oo
7AdM1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol92@T7o`/;2`Oo6QXJ
1olB4Q87ob0P80ko@D511_lK6a/5ooooo`Oo<30`1omJFUX7ooooo`Oo71`L1old=3@7ob8R8POoEEEE
1_m7AdL6ooooo`Ko7alO1olI6AT7oa8B4POo3`l?1ol:2PX7o`0000Oo0`<31_l_;bl6ooooo`Oo:2PX
1om2@T86o`h>3POoW9bL1ol00007o`h>3POoEUIF1_mTI6@6ooooo`Oo4A4A1olG5aL7o`X:2POo20P8
1_lD51@7o`820POo1PH61_lD51@6ooooo`Oo4A4A1ol51@D7ocHf=POo=CDe1ol00007obh^;PKo3`l?
1_lM7Ad6ooooo`Ooj^[Z1olT92@7oc`l?0Oo:RXZ1ooEeMD7oclo?`Oo@D511_mLG5`5ooooo`Oo7AdM
1olT92@7oaLG5`OoA4A41olH61P7oa8B4POo<c<c4oooool000_ooooo1ol>3Ph7o`0000Oo51@D1olS
8b<7oc@d=0Oo9BDU1om7AdL6ode=C@Gooooo1ol];Bd7oclo?`OoalO71olI6AT7oc0`<0Oo;2`/1om]
KFd6odm?C`Kooooo3OlK6a/7o`P820Oo2`/;1ol@4107o``<30Oo3@d=1_lb<S86ooooo`OoF5QH1omP
H606o`D51@OoPX:21ol=3@d7obDU9@Oo?clo1_oBd]86ooooo`Oo51@D1olG5aL7oa0@40go4A4A1ol=
3@d7o`L71`Ko6a/K1_ooool7oahN7POo3Ph>1omJFUX7obXZ:POo4A4A1olX:2P6o`<30`Ko;2`/3Ooo
ool7ob`/;0OoCdm?1olP8207ono_k`OoJf][1olJ6QX6odU9B@Gooooo1olF5QH7ocdm?@Oo5QHF3_lm
?Cd7oa`L70OoADE51_nc/k<=ooooo`002oooool7o`h>3POo00001olD51@7ob<S8`Oo=3@d1olU9BD7
odM7A`KoCDe=1Oooool7obd];@Oo?clo1oo7alL7oaTI6@Oo<30`1ol/;2`7ofe]K@KoCdm?1_ooool=
oa/K6`Oo20P81ol;2`/7oa0@40Oo30`<1ol=3@d6oc8b<PKooooo1omHF5P7of1PH0Ko1@D51on2PX87
o`d=3@Oo9BDU1olo?cl6om;BdPKooooo1olD51@7oaLG5`Oo410@3OlA4A47o`d=3@Oo1`L71_lK6a/6
ooooo`Oo7QhN1ol>3Ph7oeYJFPOo:RXZ1olA4A47obPX:0Ko0`<31_l/;2`=ooooo`Oo;2`/1om?Cdl7
ob0P80Ookno_1om[Jf/7oaXJ6PKoBDU91Oooool7oaHF5POo?Cdm1olF5QH>ocdm?@Oo71`L1om5ADD6
ok>c/`gooooo000;ooooo`Oo3Ph>1ol00007oa@D50Oo8b<S1old=3@7obDU9@OoAdM71_m=CDd5oooo
o`Oo;Bd]1olo?cl7olO7a`Oo6ATI1ol`<307ob`/;0OoKFe]1_m?Cdl6ooooo`go6a/K1ol820P7o`/;
2`Oo410@1ol<30`7o`d=3@Ko<S8b1_ooool7oeQHF0OoH61P1_l51@D7oh:2PPOo3@d=1olU9BD7oclo
?`Kod];B1_ooool7oa@D50Oo5aLG1ol@410=oa4A4@Oo3@d=1ol71`L6oa/K6`Kooooo1olN7Qh7o`h>
3POoFUYJ1olZ:RX7oa4A4@Oo:2PX1_l30`<6ob`/;0gooooo1ol/;2`7odm?C`Oo820P1oo_knl7of][
J`Oo6QXJ1_m9BDT5ooooo`Oo5QHF1olm?Cd7oaHF5Pko?Cdm1olL71`7odE5A@Ko/k>c3Oooool000_o
oooo1ol>3Ph7o`0000Oo51@D1olS8b<7oc@d=0Oo9BDU1om7AdL6ode=C@Gooooo1ol];Bd7oclo?`Oo
alO71olI6AT7oc0`<0Oo;2`/1om]KFd6odm?C`Kooooo3OlK6a/7o`P820Oo2`/;1ol@4107o``<30Oo
3@d=1_lb<S86ooooo`OoF5QH1omPH606o`D51@OoPX:21ol=3@d7obDU9@Oo?clo1_oBd]86ooooo`Oo
51@D1olG5aL7oa0@40go4A4A1ol=3@d7o`L71`Ko6a/K1_ooool7oahN7POo3Ph>1omJFUX7obXZ:POo
4A4A1olX:2P6o`<30`Ko;2`/3Oooool7ob`/;0OoCdm?1olP8207ono_k`OoJf][1olJ6QX6odU9B@Go
oooo1olF5QH7ocdm?@Oo5QHF3_lm?Cd7oa`L70OoADE51_nc/k<=ooooo`002oooool7o`h>3POo0000
1olD51@7ob<S8`Oo=3@d1olU9BD7odM7A`KoCDe=1Oooool7obd];@Oo?clo1oo7alL7oaTI6@Oo<30`
1ol/;2`7ofe]K@KoCdm?1_ooool=oa/K6`Oo20P81ol;2`/7oa0@40Oo30`<1ol=3@d6oc8b<PKooooo
1omHF5P7of1PH0Ko1@D51on2PX87o`d=3@Oo9BDU1olo?cl6om;BdPKooooo1olD51@7oaLG5`Oo410@
3OlA4A47o`d=3@Oo1`L71_lK6a/6ooooo`Oo7QhN1ol>3Ph7oeYJFPOo:RXZ1olA4A47obPX:0Ko0`<3
1_l/;2`=ooooo`Oo;2`/1om?Cdl7ob0P80Ookno_1om[Jf/7oaXJ6PKoBDU91Oooool7oaHF5POo?Cdm
1olF5QH>ocdm?@Oo71`L1om5ADD6ok>c/`gooooo000;ooooo`Oo3Ph>1ol00007oa@D50Oo8b<S1old
=3@7obDU9@OoAdM71_m=CDd5ooooo`Oo;Bd]1olo?cl7olO7a`Oo6ATI1ol`<307ob`/;0OoKFe]1_m?
Cdl6ooooo`go6a/K1ol820P7o`/;2`Oo410@1ol<30`7o`d=3@Ko<S8b1_ooool7oeQHF0OoH61P1_l5
1@D7oh:2PPOo3@d=1olU9BD7oclo?`Kod];B1_ooool7oa@D50Oo5aLG1ol@410=oa4A4@Oo3@d=1ol7
1`L6oa/K6`Kooooo1olN7Qh7o`h>3POoFUYJ1olZ:RX7oa4A4@Oo:2PX1_l30`<6ob`/;0gooooo1ol/
;2`7odm?C`Oo820P1oo_knl7of][J`Oo6QXJ1_m9BDT5ooooo`Oo5QHF1olm?Cd7oaHF5Pko?Cdm1olL
71`7odE5A@Ko/k>c3Oooool000_ooooo1ol>3Ph7o`0000Oo51@D1olS8b<7oc@d=0Oo9BDU1om7AdL6
ode=C@Gooooo1ol];Bd7oclo?`OoalO71olI6AT7oc0`<0Oo;2`/1om]KFd6odm?C`Kooooo3OlK6a/7
o`P820Oo2`/;1ol@4107o``<30Oo3@d=1_lb<S86ooooo`OoF5QH1omPH606o`D51@OoPX:21ol=3@d7
obDU9@Oo?clo1_oBd]86ooooo`Oo51@D1olG5aL7oa0@40go4A4A1ol=3@d7o`L71`Ko6a/K1_ooool7
oahN7POo3Ph>1omJFUX7obXZ:POo4A4A1olX:2P6o`<30`Ko;2`/3Oooool7ob`/;0OoCdm?1olP8207
ono_k`OoJf][1olJ6QX6odU9B@Gooooo1olF5QH7ocdm?@Oo5QHF3_lm?Cd7oa`L70OoADE51_nc/k<=
ooooo`002oooool7obl_;`Oo71`L1olF5QH7o``<30Oo9bLW1oooool7od10@0Ko;2`/1Oooool7ob0P
80Oo8R8R1om6ATH7oaDE5@OoCDe=1olN7Qh7obTY:@KoC4a<1_ooool6ocHf=POo820P1olH61P7o`d=
3@ko3Ph>1olG5aL6ocHf=PKooooo1on9RHT7oiZJVPKo?3`l1om;Bd/7ob8R8POoRXZ:1ol/;2`6ocPh
>0Kooooo1olg=cL7ooooo`Oo<30`1ol/;2`6oe=CD`Oo?3`l1ol^;Rh6ocLg=`Kooooo1omaLG47oaDE
5@OoADE51ol@4107of=SH`Oo=cLg1_lD51@6oe1@D0Kooooo1omSHf<7obPX:0OoQXJ61ol/;2`7oda<
C0Oo:BTY1omgMgL6oeQHF0Gooooo1olT92@7oe=CD`Oo5aLG1olc<c<7ocPh>0Oo<S8b1oll?3`6oe1@
D0gooooo000;ooooo`Oo;bl_1olL71`7oaHF5POo30`<1olW9bL7ooooo`Oo@4101_l/;2`5ooooo`Oo
820P1olR8R87odI6APOo5ADE1om=CDd7oahN7POo:BTY1_m<C4`6ooooo`Ko=SHf1olP8207oaPH60Oo
3@d=3_l>3Ph7oaLG5`Ko=SHf1_ooool7ohV9R@OoVYZJ1_ll?3`7od];B`Oo8R8R1on:RXX7ob`/;0Ko
>3Ph1_ooool7ocLg=`Oooooo1ol`<307ob`/;0KoDe=C1oll?3`7obh^;PKo=cLg1_ooool7og5aL@Oo
5ADE1om5ADD7oa0@40OoHf=S1olg=cL6oa@D50KoD51@1_ooool7of=SH`Oo:2PX1on6QXH7ob`/;0Oo
C4a<1olY:BT7ogMgM`KoF5QH1Oooool7ob@T90OoDe=C1olG5aL7oc<c<`Oo>3Ph1olb<S87oc`l?0Ko
D51@3Oooool000_ooooo1ol_;bl7oa`L70Oo5QHF1ol<30`7obLW9`Oooooo1om0@406ob`/;0Gooooo
1olP8207ob8R8POoATI61olE5AD7ode=C@Oo7QhN1olY:BT6oda<C0Kooooo1_lf=SH7ob0P80Oo61PH
1ol=3@d>o`h>3POo5aLG1_lf=SH6ooooo`OoRHV91onJVYX6oc`l?0OoBd];1olR8R87ohZ:RPOo;2`/
1_lh>3P6ooooo`Oo=cLg1oooool7oc0`<0Oo;2`/1_mCDe<7oc`l?0Oo;Rh^1_lg=cL6ooooo`OoLG5a
1olE5AD7odE5A@Oo410@1omSHf<7ocLg=`Ko51@D1_m@D506ooooo`OoHf=S1olX:2P7ohJ6QPOo;2`/
1om<C4`7obTY:@OoMgMg1_mHF5P5ooooo`Oo92@T1omCDe<7oaLG5`Oo<c<c1olh>3P7oc8b<POo?3`l
1_m@D50=ooooo`002oooool7obl_;`Oo71`L1olF5QH7o``<30Oo9bLW1oooool7od10@0Ko;2`/1Ooo
ool7ob0P80Oo8R8R1om6ATH7oaDE5@OoCDe=1olN7Qh7obTY:@KoC4a<1_ooool6ocHf=POo820P1olH
61P7o`d=3@ko3Ph>1olG5aL6ocHf=PKooooo1on9RHT7oiZJVPKo?3`l1om;Bd/7ob8R8POoRXZ:1ol/
;2`6ocPh>0Kooooo1olg=cL7ooooo`Oo<30`1ol/;2`6oe=CD`Oo?3`l1ol^;Rh6ocLg=`Kooooo1oma
LG47oaDE5@OoADE51ol@4107of=SH`Oo=cLg1_lD51@6oe1@D0Kooooo1omSHf<7obPX:0OoQXJ61ol/
;2`7oda<C0Oo:BTY1omgMgL6oeQHF0Gooooo1olT92@7oe=CD`Oo5aLG1olc<c<7ocPh>0Oo<S8b1oll
?3`6oe1@D0gooooo000;ooooo`Oo;bl_1olL71`7oaHF5POo30`<1olW9bL7ooooo`Oo@4101_l/;2`5
ooooo`Oo820P1olR8R87odI6APOo5ADE1om=CDd7oahN7POo:BTY1_m<C4`6ooooo`Ko=SHf1olP8207
oaPH60Oo3@d=3_l>3Ph7oaLG5`Ko=SHf1_ooool7ohV9R@OoVYZJ1_ll?3`7od];B`Oo8R8R1on:RXX7
ob`/;0Ko>3Ph1_ooool7ocLg=`Oooooo1ol`<307ob`/;0KoDe=C1oll?3`7obh^;PKo=cLg1_ooool7
og5aL@Oo5ADE1om5ADD7oa0@40OoHf=S1olg=cL6oa@D50KoD51@1_ooool7of=SH`Oo:2PX1on6QXH7
ob`/;0OoC4a<1olY:BT7ogMgM`KoF5QH1Oooool7ob@T90OoDe=C1olG5aL7oc<c<`Oo>3Ph1olb<S87
oc`l?0KoD51@3Oooool000_ooooo1ol_;bl7oa`L70Oo5QHF1ol<30`7obLW9`Oooooo1om0@406ob`/
;0Gooooo1olP8207ob8R8POoATI61olE5AD7ode=C@Oo7QhN1olY:BT6oda<C0Kooooo1_lf=SH7ob0P
80Oo61PH1ol=3@d>o`h>3POo5aLG1_lf=SH6ooooo`OoRHV91onJVYX6oc`l?0OoBd];1olR8R87ohZ:
RPOo;2`/1_lh>3P6ooooo`Oo=cLg1oooool7oc0`<0Oo;2`/1_mCDe<7oc`l?0Oo;Rh^1_lg=cL6oooo
o`OoLG5a1olE5AD7odE5A@Oo410@1omSHf<7ocLg=`Ko51@D1_m@D506ooooo`OoHf=S1olX:2P7ohJ6
QPOo;2`/1om<C4`7obTY:@OoMgMg1_mHF5P5ooooo`Oo92@T1omCDe<7oaLG5`Oo<c<c1olh>3P7oc8b
<POo?3`l1_m@D50=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002oooool7ojBTY0OoB4Q81ong
]kL7od51@@OoATI61olo?cl7od];B`KoPh>31Oooool7oa<C4`Oo10@41om6ATH7ogMgM`Oo;bl_1olW
9bL7oa@D50Ko61PH1_ooool6oaLG5`Oo4a<C1ol:2PX7o`P820Oo0`<31ol51@D7o`/;2`Ko<c<c1_oo
ool7oa/K6`Oo6ATI1_lF5QH7oa4A4@Oo6QXJ1ol92@T7oa`L70Ko9RHV1_ooool7o`d=3@Oo1`L71ol4
10@7oa8B4PKo30`<1ol=3@d7oalO7`Ko51@D1_ooool7ocHf=POo1@D51olN7Qh7ocXj>POo9bLW1omB
DU86oa@D50Ko<c<c1_ooool7of=SH`Oo8R8R1olW9bL7oaPH60Oo9bLW1olA4A47oaLG5`_ooooo1olE
5AD7odA4A0Oo4a<C1olY:BT7o`/;2`Oo6a/K1om=CDd6obd];@gooooo000;ooooo`OoY:BT1om8B4P7
okNg]`Oo@D511om6ATH7oclo?`OoBd];1_n3Ph<5ooooo`Oo4a<C1ol410@7odI6APOoMgMg1ol_;bl7
obLW9`Oo51@D1_lH61P6ooooo`Ko5aLG1olC4a<7o`X:2POo20P81ol30`<7o`D51@Oo2`/;1_lc<c<6
ooooo`Oo6a/K1olI6AT6oaHF5POo4A4A1olJ6QX7o`T92@Oo71`L1_lV9RH6ooooo`Oo3@d=1ol71`L7
o`@410Oo4Q8B1_l<30`7o`d=3@Oo7alO1_lD51@6ooooo`Oo=SHf1ol51@D7oahN7POo>SXj1olW9bL7
oe9BDPKo51@D1_lc<c<6ooooo`OoHf=S1olR8R87obLW9`Oo61PH1olW9bL7oa4A4@Oo5aLG2oooool7
oaDE5@OoA4A41olC4a<7obTY:@Oo2`/;1olK6a/7ode=C@Ko;Bd]3Oooool000_ooooo1onTY:@7odQ8
B0Oo]kNg1om1@D47odI6APOo?clo1om;Bd/6oh>3P`Gooooo1olC4a<7o`@410OoATI61omgMgL7obl_
;`Oo9bLW1olD51@6oaPH60Kooooo1_lG5aL7oa<C4`Oo2PX:1ol820P7o`<30`Oo1@D51ol;2`/6oc<c
<`Kooooo1olK6a/7oaTI6@Ko5QHF1olA4A47oaXJ6POo2@T91olL71`6obHV9PKooooo1ol=3@d7o`L7
1`Oo10@41olB4Q86o``<30Oo3@d=1olO7al6oa@D50Kooooo1olf=SH7o`D51@Oo7QhN1olj>SX7obLW
9`OoDU9B1_lD51@6oc<c<`Kooooo1omSHf<7ob8R8POo9bLW1olH61P7obLW9`Oo4A4A1olG5aL;oooo
o`Oo5ADE1om4A4@7oa<C4`Oo:BTY1ol;2`/7oa/K6`OoCDe=1_l];Bd=ooooo`002oooool7ojBTY0Oo
B4Q81ong]kL7od51@@OoATI61olo?cl7od];B`KoPh>31Oooool7oa<C4`Oo10@41om6ATH7ogMgM`Oo
;bl_1olW9bL7oa@D50Ko61PH1_ooool6oaLG5`Oo4a<C1ol:2PX7o`P820Oo0`<31ol51@D7o`/;2`Ko
<c<c1_ooool7oa/K6`Oo6ATI1_lF5QH7oa4A4@Oo6QXJ1ol92@T7oa`L70Ko9RHV1_ooool7o`d=3@Oo
1`L71ol410@7oa8B4PKo30`<1ol=3@d7oalO7`Ko51@D1_ooool7ocHf=POo1@D51olN7Qh7ocXj>POo
9bLW1omBDU86oa@D50Ko<c<c1_ooool7of=SH`Oo8R8R1olW9bL7oaPH60Oo9bLW1olA4A47oaLG5`_o
oooo1olE5AD7odA4A0Oo4a<C1olY:BT7o`/;2`Oo6a/K1om=CDd6obd];@gooooo000;ooooo`OoY:BT
1om8B4P7okNg]`Oo@D511om6ATH7oclo?`OoBd];1_n3Ph<5ooooo`Oo4a<C1ol410@7odI6APOoMgMg
1ol_;bl7obLW9`Oo51@D1_lH61P6ooooo`Ko5aLG1olC4a<7o`X:2POo20P81ol30`<7o`D51@Oo2`/;
1_lc<c<6ooooo`Oo6a/K1olI6AT6oaHF5POo4A4A1olJ6QX7o`T92@Oo71`L1_lV9RH6ooooo`Oo3@d=
1ol71`L7o`@410Oo4Q8B1_l<30`7o`d=3@Oo7alO1_lD51@6ooooo`Oo=SHf1ol51@D7oahN7POo>SXj
1olW9bL7oe9BDPKo51@D1_lc<c<6ooooo`OoHf=S1olR8R87obLW9`Oo61PH1olW9bL7oa4A4@Oo5aLG
2oooool7oaDE5@OoA4A41olC4a<7obTY:@Oo2`/;1olK6a/7ode=C@Ko;Bd]3Oooool000_ooooo1onT
Y:@7odQ8B0Oo]kNg1om1@D47odI6APOo?clo1om;Bd/6oh>3P`Gooooo1olC4a<7o`@410OoATI61omg
MgL7obl_;`Oo9bLW1olD51@6oaPH60Kooooo1_lG5aL7oa<C4`Oo2PX:1ol820P7o`<30`Oo1@D51ol;
2`/6oc<c<`Kooooo1olK6a/7oaTI6@Ko5QHF1olA4A47oaXJ6POo2@T91olL71`6obHV9PKooooo1ol=
3@d7o`L71`Oo10@41olB4Q86o``<30Oo3@d=1olO7al6oa@D50Kooooo1olf=SH7o`D51@Oo7QhN1olj
>SX7obLW9`OoDU9B1_lD51@6oc<c<`Kooooo1omSHf<7ob8R8POo9bLW1olH61P7obLW9`Oo4A4A1olG
5aL;ooooo`Oo5ADE1om4A4@7oa<C4`Oo:BTY1ol;2`/7oa/K6`OoCDe=1_l];Bd=ooooo`002oooool7
ojBTY0OoB4Q81ong]kL7od51@@OoATI61olo?cl7od];B`KoPh>31Oooool7oa<C4`Oo10@41om6ATH7
ogMgM`Oo;bl_1olW9bL7oa@D50Ko61PH1_ooool6oaLG5`Oo4a<C1ol:2PX7o`P820Oo0`<31ol51@D7
o`/;2`Ko<c<c1_ooool7oa/K6`Oo6ATI1_lF5QH7oa4A4@Oo6QXJ1ol92@T7oa`L70Ko9RHV1_ooool7
o`d=3@Oo1`L71ol410@7oa8B4PKo30`<1ol=3@d7oalO7`Ko51@D1_ooool7ocHf=POo1@D51olN7Qh7
ocXj>POo9bLW1omBDU86oa@D50Ko<c<c1_ooool7of=SH`Oo8R8R1olW9bL7oaPH60Oo9bLW1olA4A47
oaLG5`_ooooo1olE5AD7odA4A0Oo4a<C1olY:BT7o`/;2`Oo6a/K1om=CDd6obd];@gooooo000;oooo
o`OoUIFE1onATI47olo?c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUi
N@Oooooo1omTI6@7oaHF5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<3
0`Oo410@1_lh>3P6ooooo`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H6
1POo1@D51ol61PH7o`<30`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU
9@Oo7alO3Ole=CD6ochn?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?
S`Gooooo1ol/;2`7obl_;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`Oo
UIFE1onATI47olo?c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUiN@Oo
oooo1omTI6@7oaHF5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<30`Oo
410@1_lh>3P6ooooo`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H61POo
1@D51ol61PH7o`<30`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU9@Oo
7alO3Ole=CD6ochn?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?S`Go
oooo1ol/;2`7obl_;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`OoUIFE
1onATI47olo?c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUiN@Oooooo
1omTI6@7oaHF5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<30`Oo410@
1_lh>3P6ooooo`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H61POo1@D5
1ol61PH7o`<30`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU9@Oo7alO
3Ole=CD6ochn?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?S`Gooooo
1ol/;2`7obl_;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`OoUIFE1onA
TI47olo?c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUiN@Oooooo1omT
I6@7oaHF5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<30`Oo410@1_lh
>3P6ooooo`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H61POo1@D51ol6
1PH7o`<30`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU9@Oo7alO3Ole
=CD6ochn?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?S`Gooooo1ol/
;2`7obl_;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`OoUIFE1onATI47
olo?c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUiN@Oooooo1omTI6@7
oaHF5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<30`Oo410@1_lh>3P6
ooooo`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H61POo1@D51ol61PH7
o`<30`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU9@Oo7alO3Ole=CD6
ochn?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?S`Gooooo1ol/;2`7
obl_;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`OoUIFE1onATI47olo?
c`OoMgMg1omSHf<7o`0000OoBTY:1_mJFUX5ooooo`Oo2PX:1ol>3Ph7ogUiN@Oooooo1omTI6@7oaHF
5POo4a<C1_lg=cL6ooooo`Ko7alO1ol71`L7o`X:2POo30`<1ol51@D7o`<30`Oo410@1_lh>3P6oooo
o`Oo2@T91ol<30`6oa4A4@Oo2@T91ol0000>oa0@40Ko7QhN1_ooool7o`H61POo1@D51ol61PH7o`<3
0`Ko0P821ol;2`/7oa<C4`Ko30`<1_ooool7odY:BPOo61PH1ol<30`7obDU9@Oo7alO3Ole=CD6ochn
?PKooooo1ol[:b/7oa4A4@Oo=3@d1olK6a/7oa0@40Oo5aLG1olM7Ad6ohn?S`Gooooo1ol/;2`7obl_
;`Oo20P81om[Jf/7oa4A4@Oo51@D1om5ADD6oemOG`gooooo000;ooooo`OoZZZZ1omeMGD7onKViPOo
Kfm_1omHF5P7oclo?`Oo@d=31_la<C45ooooo`Oo9BDU1olX:2P7ocPh>0OoA4A41olS8b<7oc0`<0Oo
410@1_lc<c<6ooooo`Ko20P81ol:2PX7oa0@40Oo0`<31ol51@D7oaLG5`Oo4Q8B1_m4A4@6ooooo`Oo
8B4Q1ol`<306oa/K6`Oo410@3_l51@D7ob<S8`Ko61PH1_ooool7oaLG5`ko3Ph>1olA4A46o`h>3POo
410@1ol^;Rh6obTY:@Kooooo1on4Q8@7oahN7POo5QHF1olW9bL7obXZ:POo<C4a1_l00006oa4A4@Ko
oooo3_lH61P7oa`L70Oo6ATI1olE5AD7o``<30Oo2@T91_lW9bL5ooooo`Oo5QHF1ol[:b/7o`0000Oo
KFe]1ola<C47oaPH60Oo>CTi1_oIfMT=ooooo`002oooool7ojZZZPOoMGEe1ooVi^H7ofm_K`OoF5QH
1olo?cl7od=3@`Ko<C4a1Oooool7obDU9@Oo:2PX1olh>3P7odA4A0Oo8b<S1ol`<307oa0@40Ko<c<c
1_ooool6o`P820Oo2PX:1ol@4107o`<30`Oo1@D51olG5aL7oa8B4PKoA4A41_ooool7ob4Q8@Oo<30`
1_lK6a/7oa0@40ko1@D51olS8b<6oaPH60Kooooo1olG5aL>o`h>3POo4A4A1_l>3Ph7oa0@40Oo;Rh^
1_lY:BT6ooooo`OoQ8B41olN7Qh7oaHF5POo9bLW1olZ:RX7oc4a<@Ko00001_lA4A46ooooo`ko61PH
1olL71`7oaTI6@Oo5ADE1ol<30`7o`T92@Ko9bLW1Oooool7oaHF5POo:b/[1ol00007ofe]K@Oo<C4a
1olH61P7ocTi>@KofMWI3Oooool000_ooooo1onZZZX7ogEeM@Ooi^KV1om_Kfl7oeQHF0Oo?clo1om3
@d<6oc4a<@Gooooo1olU9BD7obPX:0Oo>3Ph1om4A4@7ob<S8`Oo<30`1ol@4106oc<c<`Kooooo1_l8
20P7o`X:2POo410@1ol30`<7o`D51@Oo5aLG1olB4Q86odA4A0Kooooo1olQ8B47oc0`<0Ko6a/K1ol@
410>o`D51@Oo8b<S1_lH61P6ooooo`Oo5aLG3_l>3Ph7oa4A4@Ko3Ph>1ol@4107obh^;PKo:BTY1_oo
ool7ohB4Q0Oo7QhN1olF5QH7obLW9`Oo:RXZ1ola<C46o`0000Ko4A4A1_ooool>oaPH60Oo71`L1olI
6AT7oaDE5@Oo30`<1ol92@T6obLW9`Gooooo1olF5QH7ob/[:`Oo00001om]KFd7oc4a<@Oo61PH1oli
>CT6omWIf@gooooo000;ooooo`OoZZZZ1omeMGD7onKViPOoKfm_1omHF5P7oclo?`Oo@d=31_la<C45
ooooo`Oo9BDU1olX:2P7ocPh>0OoA4A41olS8b<7oc0`<0Oo410@1_lc<c<6ooooo`Ko20P81ol:2PX7
oa0@40Oo0`<31ol51@D7oaLG5`Oo4Q8B1_m4A4@6ooooo`Oo8B4Q1ol`<306oa/K6`Oo410@3_l51@D7
ob<S8`Ko61PH1_ooool7oaLG5`ko3Ph>1olA4A46o`h>3POo410@1ol^;Rh6obTY:@Kooooo1on4Q8@7
oahN7POo5QHF1olW9bL7obXZ:POo<C4a1_l00006oa4A4@Kooooo3_lH61P7oa`L70Oo6ATI1olE5AD7
o``<30Oo2@T91_lW9bL5ooooo`Oo5QHF1ol[:b/7o`0000OoKFe]1ola<C47oaPH60Oo>CTi1_oIfMT=
ooooo`002oooool7ojZZZPOoMGEe1ooVi^H7ofm_K`OoF5QH1olo?cl7od=3@`Ko<C4a1Oooool7obDU
9@Oo:2PX1olh>3P7odA4A0Oo8b<S1ol`<307oa0@40Ko<c<c1_ooool6o`P820Oo2PX:1ol@4107o`<3
0`Oo1@D51olG5aL7oa8B4PKoA4A41_ooool7ob4Q8@Oo<30`1_lK6a/7oa0@40ko1@D51olS8b<6oaPH
60Kooooo1olG5aL>o`h>3POo4A4A1_l>3Ph7oa0@40Oo;Rh^1_lY:BT6ooooo`OoQ8B41olN7Qh7oaHF
5POo9bLW1olZ:RX7oc4a<@Ko00001_lA4A46ooooo`ko61PH1olL71`7oaTI6@Oo5ADE1ol<30`7o`T9
2@Ko9bLW1Oooool7oaHF5POo:b/[1ol00007ofe]K@Oo<C4a1olH61P7ocTi>@KofMWI3Oooool000_o
oooo1onZZZX7ogEeM@Ooi^KV1om_Kfl7oeQHF0Oo?clo1om3@d<6oc4a<@Gooooo1olU9BD7obPX:0Oo
>3Ph1om4A4@7ob<S8`Oo<30`1ol@4106oc<c<`Kooooo1_l820P7o`X:2POo410@1ol30`<7o`D51@Oo
5aLG1olB4Q86odA4A0Kooooo1olQ8B47oc0`<0Ko6a/K1ol@410>o`D51@Oo8b<S1_lH61P6ooooo`Oo
5aLG3_l>3Ph7oa4A4@Ko3Ph>1ol@4107obh^;PKo:BTY1_ooool7ohB4Q0Oo7QhN1olF5QH7obLW9`Oo
:RXZ1ola<C46o`0000Ko4A4A1_ooool>oaPH60Oo71`L1olI6AT7oaDE5@Oo30`<1ol92@T6obLW9`Go
oooo1olF5QH7ob/[:`Oo00001om]KFd7oc4a<@Oo61PH1oli>CT6omWIf@gooooo000;ooooo`OoZZZZ
1omeMGD7onKViPOoKfm_1omHF5P7oclo?`Oo@d=31_la<C45ooooo`Oo9BDU1olX:2P7ocPh>0OoA4A4
1olS8b<7oc0`<0Oo410@1_lc<c<6ooooo`Ko20P81ol:2PX7oa0@40Oo0`<31ol51@D7oaLG5`Oo4Q8B
1_m4A4@6ooooo`Oo8B4Q1ol`<306oa/K6`Oo410@3_l51@D7ob<S8`Ko61PH1_ooool7oaLG5`ko3Ph>
1olA4A46o`h>3POo410@1ol^;Rh6obTY:@Kooooo1on4Q8@7oahN7POo5QHF1olW9bL7obXZ:POo<C4a
1_l00006oa4A4@Kooooo3_lH61P7oa`L70Oo6ATI1olE5AD7o``<30Oo2@T91_lW9bL5ooooo`Oo5QHF
1ol[:b/7o`0000OoKFe]1ola<C47oaPH60Oo>CTi1_oIfMT=ooooo`002oooool7onSXj0OoTY:B1ooo
ool7oh20P0OoOgmo1ol30`<7oemOG`KoHV9R1Oooool7oc4a<@Oo2@T91ol00007oa0@40Oo3Ph>1olT
92@7obLW9`Ko=CDe1_ooool6o`d=3@Oo00001ol30`<7o`/;2`Oo2PX:1ol00007o`h>3PKo:2PX1_oo
ool7obLW9`OoBd];1_lB4Q87o`h>3POo<C4a1olC4a<7oa@D50Ko5ADE1_ooool7o`l?3`Oo3Ph>1ol:
2PX7o`T92@Ko00001ol;2`/7o`d=3@Ko4a<C1_ooool7oh^;R`Oo2@T91olI6AT7oaPH60Oo8R8R1om@
D506oc@d=0KoEEEE1_ooool7o`T92@Oo8R8R1olU9BD7oa@D50Oo7AdM1ol00007o`T92@Ko9BDU1Ooo
ool7oaTI6@Oo:2PX1ol410@7ofYZJPOo<c<c1ol>3Ph7ob`/;0KoPh>33Oooool000_ooooo1ooXj>P7
oi:BTPOooooo1on0P807ogmoO`Oo0`<31omOGel6of9RHPGooooo1ola<C47o`T92@Oo00001ol@4107
o`h>3POo92@T1olW9bL6ocDe=@Kooooo1_l=3@d7o`0000Oo0`<31ol;2`/7o`X:2POo00001ol>3Ph6
obPX:0Kooooo1olW9bL7od];B`Ko4Q8B1ol>3Ph7oc4a<@Oo4a<C1olD51@6oaDE5@Kooooo1ol?3`l7
o`h>3POo2PX:1ol92@T6o`0000Oo2`/;1ol=3@d6oa<C4`Kooooo1on;Rh/7o`T92@Oo6ATI1olH61P7
ob8R8POoD51@1_ld=3@6oeEEE@Kooooo1ol92@T7ob8R8POo9BDU1olD51@7oadM7@Oo00001ol92@T6
obDU9@Gooooo1olI6AT7obPX:0Oo10@41omZJVX7oc<c<`Oo3Ph>1ol/;2`6oh>3P`gooooo000;oooo
o`Ooj>SX1onBTY87ooooo`OoP8201omoOgl7o`<30`OoGemO1_mRHV85ooooo`Oo<C4a1ol92@T7o`00
00Oo410@1ol>3Ph7ob@T90Oo9bLW1_le=CD6ooooo`Ko3@d=1ol00007o`<30`Oo2`/;1ol:2PX7o`00
00Oo3Ph>1_lX:2P6ooooo`Oo9bLW1om;Bd/6oa8B4POo3Ph>1ola<C47oa<C4`Oo51@D1_lE5AD6oooo
o`Oo3`l?1ol>3Ph7o`X:2POo2@T91_l00007o`/;2`Oo3@d=1_lC4a<6ooooo`OoRh^;1ol92@T7oaTI
6@Oo61PH1olR8R87oe1@D0Ko=3@d1_mEEED6ooooo`Oo2@T91olR8R87obDU9@Oo51@D1olM7Ad7o`00
00Oo2@T91_lU9BD5ooooo`Oo6ATI1olX:2P7o`@410OoJVYZ1olc<c<7o`h>3POo;2`/1_n3Ph<=oooo
o`002oooool7onSXj0OoTY:B1oooool7oh20P0OoOgmo1ol30`<7oemOG`KoHV9R1Oooool7oc4a<@Oo
2@T91ol00007oa0@40Oo3Ph>1olT92@7obLW9`Ko=CDe1_ooool6o`d=3@Oo00001ol30`<7o`/;2`Oo
2PX:1ol00007o`h>3PKo:2PX1_ooool7obLW9`OoBd];1_lB4Q87o`h>3POo<C4a1olC4a<7oa@D50Ko
5ADE1_ooool7o`l?3`Oo3Ph>1ol:2PX7o`T92@Ko00001ol;2`/7o`d=3@Ko4a<C1_ooool7oh^;R`Oo
2@T91olI6AT7oaPH60Oo8R8R1om@D506oc@d=0KoEEEE1_ooool7o`T92@Oo8R8R1olU9BD7oa@D50Oo
7AdM1ol00007o`T92@Ko9BDU1Oooool7oaTI6@Oo:2PX1ol410@7ofYZJPOo<c<c1ol>3Ph7ob`/;0Ko
Ph>33Oooool000_ooooo1ooXj>P7oi:BTPOooooo1on0P807ogmoO`Oo0`<31omOGel6of9RHPGooooo
1ola<C47o`T92@Oo00001ol@4107o`h>3POo92@T1olW9bL6ocDe=@Kooooo1_l=3@d7o`0000Oo0`<3
1ol;2`/7o`X:2POo00001ol>3Ph6obPX:0Kooooo1olW9bL7od];B`Ko4Q8B1ol>3Ph7oc4a<@Oo4a<C
1olD51@6oaDE5@Kooooo1ol?3`l7o`h>3POo2PX:1ol92@T6o`0000Oo2`/;1ol=3@d6oa<C4`Kooooo
1on;Rh/7o`T92@Oo6ATI1olH61P7ob8R8POoD51@1_ld=3@6oeEEE@Kooooo1ol92@T7ob8R8POo9BDU
1olD51@7oadM7@Oo00001ol92@T6obDU9@Gooooo1olI6AT7obPX:0Oo10@41omZJVX7oc<c<`Oo3Ph>
1ol/;2`6oh>3P`gooooo000;ooooo`Ooj>SX1onBTY87ooooo`OoP8201omoOgl7o`<30`OoGemO1_mR
HV85ooooo`Oo<C4a1ol92@T7o`0000Oo410@1ol>3Ph7ob@T90Oo9bLW1_le=CD6ooooo`Ko3@d=1ol0
0007o`<30`Oo2`/;1ol:2PX7o`0000Oo3Ph>1_lX:2P6ooooo`Oo9bLW1om;Bd/6oa8B4POo3Ph>1ola
<C47oa<C4`Oo51@D1_lE5AD6ooooo`Oo3`l?1ol>3Ph7o`X:2POo2@T91_l00007o`/;2`Oo3@d=1_lC
4a<6ooooo`OoRh^;1ol92@T7oaTI6@Oo61PH1olR8R87oe1@D0Ko=3@d1_mEEED6ooooo`Oo2@T91olR
8R87obDU9@Oo51@D1olM7Ad7o`0000Oo2@T91_lU9BD5ooooo`Oo6ATI1olX:2P7o`@410OoJVYZ1olc
<c<7o`h>3POo;2`/1_n3Ph<=ooooo`002oooool7onSXj0OoTY:B1oooool7oh20P0OoOgmo1ol30`<7
oemOG`KoHV9R1Oooool7oc4a<@Oo2@T91ol00007oa0@40Oo3Ph>1olT92@7obLW9`Ko=CDe1_ooool6
o`d=3@Oo00001ol30`<7o`/;2`Oo2PX:1ol00007o`h>3PKo:2PX1_ooool7obLW9`OoBd];1_lB4Q87
o`h>3POo<C4a1olC4a<7oa@D50Ko5ADE1_ooool7o`l?3`Oo3Ph>1ol:2PX7o`T92@Ko00001ol;2`/7
o`d=3@Ko4a<C1_ooool7oh^;R`Oo2@T91olI6AT7oaPH60Oo8R8R1om@D506oc@d=0KoEEEE1_ooool7
o`T92@Oo8R8R1olU9BD7oa@D50Oo7AdM1ol00007o`T92@Ko9BDU1Oooool7oaTI6@Oo:2PX1ol410@7
ofYZJPOo<c<c1ol>3Ph7ob`/;0KoPh>33Oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo
?`Oo;bl_1olm?Cd6ogAdM0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C
4`Kooooo1_l:2PX7o`L71`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7oooo
o`Ko=SHf1olI6AT7ob@T90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T9
2@Oo2PX:1olE5AD6oaLG5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6oooo
o`Oo0`<31ol=3@d7ob0P80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW
9`OoIfMW1omRHV87oaLG5`Oo?3`l4oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo?`Oo
;bl_1olm?Cd6ogAdM0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C4`Ko
oooo1_l:2PX7o`L71`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7ooooo`Ko
=SHf1olI6AT7ob@T90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T92@Oo
2PX:1olE5AD6oaLG5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6ooooo`Oo
0`<31ol=3@d7ob0P80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW9`Oo
IfMW1omRHV87oaLG5`Oo?3`l4oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo?`Oo;bl_
1olm?Cd6ogAdM0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C4`Kooooo
1_l:2PX7o`L71`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7ooooo`Ko=SHf
1olI6AT7ob@T90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T92@Oo2PX:
1olE5AD6oaLG5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6ooooo`Oo0`<3
1ol=3@d7ob0P80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW9`OoIfMW
1omRHV87oaLG5`Oo?3`l4oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo?`Oo;bl_1olm
?Cd6ogAdM0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C4`Kooooo1_l:
2PX7o`L71`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7ooooo`Ko=SHf1olI
6AT7ob@T90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T92@Oo2PX:1olE
5AD6oaLG5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6ooooo`Oo0`<31ol=
3@d7ob0P80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW9`OoIfMW1omR
HV87oaLG5`Oo?3`l4oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo?`Oo;bl_1olm?Cd6
ogAdM0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C4`Kooooo1_l:2PX7
o`L71`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7ooooo`Ko=SHf1olI6AT7
ob@T90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T92@Oo2PX:1olE5AD6
oaLG5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6ooooo`Oo0`<31ol=3@d7
ob0P80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW9`OoIfMW1omRHV87
oaLG5`Oo?3`l4oooool000_ooooo1ooWinL7onCTi0Oom?Cd1omSHf<7oclo?`Oo;bl_1olm?Cd6ogAd
M0Gooooo1olZ:RX7o``<30Oo3@d=1olH61P7o`X:2POo61PH1olK6a/6oa<C4`Kooooo1_l:2PX7o`L7
1`Oo30`<1ol?3`l7o`X:2POo3@d=1olB4Q86obDU9@Kooooo1olc<c<7ooooo`Ko=SHf1olI6AT7ob@T
90Oo8R8R1ol[:b/6ob0P80Kooooo1ol=3@d7o`0000Oo10@41ol820P6o`T92@Oo2PX:1olE5AD6oaLG
5`gooooo1ol[:b/7ob@T90Oo<c<c1olT92@7odQ8B0Ko6QXJ1_m7AdL6ooooo`Oo0`<31ol=3@d7ob0P
80Oo8b<S1olQ8B47o``<30Oo1`L71_lW9bL5ooooo`Oo7AdM1oln?Sh7obLW9`OoIfMW1omRHV87oaLG
5`Oo?3`l4oooool000_ooooo1omGEeL7oclo?`OoN7Qh1olf=SH7oc4a<@Oo1`L71olR8R86oaXJ6PGo
oooo1olT92@7oa`L70Oo5ADE1ol=3@d7o`0000Oo6ATI1olP8206oe=CD`Kooooo1_l<30`7o`@410Oo
2`/;1ol71`L7o`<30`Oo1PH61ol?3`l6obHV9PKooooo1old=3@7ohV9R@KoDe=C1ole=CD7ocdm?@Oo
9RHV1ol=3@d6ocHf=PKooooo1ol30`<7o`X:2POo4Q8B1olE5AD6o`820Pko2`/;1_lE5AD6ooooo`Oo
m?Cd1omXJ6P7odA4A0Oo:BTY1olL71`7odI6APKo7QhN1_m>CTh6ooooo`Oo6QXJ1olP8207o``<30Oo
5ADE1ol?3`l7oa/K6`Oo4Q8B1_lS8b<5ooooo`Oo5QHF1old=3@7oadM7@OoDE5A1on/[:`7oalO7`Oo
BDU91_m^KVh=ooooo`002oooool7oeMGE`Oo?clo1omhN7P7ocHf=POo<C4a1ol71`L7ob8R8PKo6QXJ
1Oooool7ob@T90Oo71`L1olE5AD7o`d=3@Oo00001olI6AT7ob0P80KoDe=C1_ooool6o``<30Oo10@4
1ol;2`/7o`L71`Oo0`<31ol61PH7o`l?3`Ko9RHV1_ooool7oc@d=0OoRHV91_mCDe<7ocDe=@Oo?Cdm
1olV9RH7o`d=3@Ko=SHf1_ooool7o`<30`Oo2PX:1olB4Q87oaDE5@Ko0P823_l;2`/6oaDE5@Kooooo
1oodm?@7ofQXJ0OoA4A41olY:BT7oa`L70OoATI61_lN7Qh6odi>CPKooooo1olJ6QX7ob0P80Oo30`<
1olE5AD7o`l?3`Oo6a/K1olB4Q86ob<S8`Gooooo1olF5QH7oc@d=0Oo7AdM1omADE47ojb/[0Oo7alO
1om9BDT6ofi^KPgooooo000;ooooo`OoEeMG1olo?cl7ogQhN0Oo=SHf1ola<C47o`L71`Oo8R8R1_lJ
6QX5ooooo`Oo92@T1olL71`7oaDE5@Oo3@d=1ol00007oaTI6@Oo820P1_mCDe<6ooooo`Ko30`<1ol4
10@7o`/;2`Oo1`L71ol30`<7o`H61POo3`l?1_lV9RH6ooooo`Oo=3@d1on9RHT6oe=CD`Oo=CDe1olm
?Cd7obHV9POo3@d=1_lf=SH6ooooo`Oo0`<31ol:2PX7oa8B4POo5ADE1_l20P8>o`/;2`Ko5ADE1_oo
ool7ooCdm0OoJ6QX1om4A4@7obTY:@Oo71`L1om6ATH6oahN7PKoCTi>1_ooool7oaXJ6POo820P1ol<
30`7oaDE5@Oo3`l?1olK6a/7oa8B4PKo8b<S1Oooool7oaHF5POo=3@d1olM7Ad7oe5AD@Oo[:b/1olO
7al7odU9B@KoKVi^3Oooool000_ooooo1omGEeL7oclo?`OoN7Qh1olf=SH7oc4a<@Oo1`L71olR8R86
oaXJ6PGooooo1olT92@7oa`L70Oo5ADE1ol=3@d7o`0000Oo6ATI1olP8206oe=CD`Kooooo1_l<30`7
o`@410Oo2`/;1ol71`L7o`<30`Oo1PH61ol?3`l6obHV9PKooooo1old=3@7ohV9R@KoDe=C1ole=CD7
ocdm?@Oo9RHV1ol=3@d6ocHf=PKooooo1ol30`<7o`X:2POo4Q8B1olE5AD6o`820Pko2`/;1_lE5AD6
ooooo`Oom?Cd1omXJ6P7odA4A0Oo:BTY1olL71`7odI6APKo7QhN1_m>CTh6ooooo`Oo6QXJ1olP8207
o``<30Oo5ADE1ol?3`l7oa/K6`Oo4Q8B1_lS8b<5ooooo`Oo5QHF1old=3@7oadM7@OoDE5A1on/[:`7
oalO7`OoBDU91_m^KVh=ooooo`002oooool7oeMGE`Oo?clo1omhN7P7ocHf=POo<C4a1ol71`L7ob8R
8PKo6QXJ1Oooool7ob@T90Oo71`L1olE5AD7o`d=3@Oo00001olI6AT7ob0P80KoDe=C1_ooool6o``<
30Oo10@41ol;2`/7o`L71`Oo0`<31ol61PH7o`l?3`Ko9RHV1_ooool7oc@d=0OoRHV91_mCDe<7ocDe
=@Oo?Cdm1olV9RH7o`d=3@Ko=SHf1_ooool7o`<30`Oo2PX:1olB4Q87oaDE5@Ko0P823_l;2`/6oaDE
5@Kooooo1oodm?@7ofQXJ0OoA4A41olY:BT7oa`L70OoATI61_lN7Qh6odi>CPKooooo1olJ6QX7ob0P
80Oo30`<1olE5AD7o`l?3`Oo6a/K1olB4Q86ob<S8`Gooooo1olF5QH7oc@d=0Oo7AdM1omADE47ojb/
[0Oo7alO1om9BDT6ofi^KPgooooo000;ooooo`OoEeMG1olo?cl7ogQhN0Oo=SHf1ola<C47o`L71`Oo
8R8R1_lJ6QX5ooooo`Oo92@T1olL71`7oaDE5@Oo3@d=1ol00007oaTI6@Oo820P1_mCDe<6ooooo`Ko
30`<1ol410@7o`/;2`Oo1`L71ol30`<7o`H61POo3`l?1_lV9RH6ooooo`Oo=3@d1on9RHT6oe=CD`Oo
=CDe1olm?Cd7obHV9POo3@d=1_lf=SH6ooooo`Oo0`<31ol:2PX7oa8B4POo5ADE1_l20P8>o`/;2`Ko
5ADE1_ooool7ooCdm0OoJ6QX1om4A4@7obTY:@Oo71`L1om6ATH6oahN7PKoCTi>1_ooool7oaXJ6POo
820P1ol<30`7oaDE5@Oo3`l?1olK6a/7oa8B4PKo8b<S1Oooool7oaHF5POo=3@d1olM7Ad7oe5AD@Oo
[:b/1olO7al7odU9B@KoKVi^3Oooool000_ooooo1omGEeL7oclo?`OoN7Qh1olf=SH7oc4a<@Oo1`L7
1olR8R86oaXJ6PGooooo1olT92@7oa`L70Oo5ADE1ol=3@d7o`0000Oo6ATI1olP8206oe=CD`Kooooo
1_l<30`7o`@410Oo2`/;1ol71`L7o`<30`Oo1PH61ol?3`l6obHV9PKooooo1old=3@7ohV9R@KoDe=C
1ole=CD7ocdm?@Oo9RHV1ol=3@d6ocHf=PKooooo1ol30`<7o`X:2POo4Q8B1olE5AD6o`820Pko2`/;
1_lE5AD6ooooo`Oom?Cd1omXJ6P7odA4A0Oo:BTY1olL71`7odI6APKo7QhN1_m>CTh6ooooo`Oo6QXJ
1olP8207o``<30Oo5ADE1ol?3`l7oa/K6`Oo4Q8B1_lS8b<5ooooo`Oo5QHF1old=3@7oadM7@OoDE5A
1on/[:`7oalO7`OoBDU91_m^KVh=ooooo`002oooool7oj:RXPOoAdM71onMWId7ocHf=POo?3`l1olJ
6QX7odQ8B0KoG5aL1Oooool7ob/[:`Oo6QXJ1ol?3`l7oaDE5@Oo3`l?1olS8b<7oahN7PKo;2`/1_oo
ool6o`l?3`Oo2@T91ol51@D7o`P820Oo0@411ol00007o`T92@Ko6QXJ1_ooool7ob8R8POo@4101_lJ
6QX7obXZ:POo@4101olB4Q87oaPH60Ko>3Ph1_ooool7o`H61POo10@41ol92@T7o`/;2`Ko2@T91ol>
3Ph7o`l?3`Ko3@d=1_ooool7ok2`/0OoPh>31olW9bL7oeQHF0Oo5ADE1omADE46ob@T90KoATI61_oo
ool7obDU9@Oo;Rh^1olT92@7oa/K6`Oo92@T1olJ6QX7oahN7PKo8B4Q1Oooool7oa0@40Oo;Bd]1om3
@d<7oeUIF@OoOGem1ol;2`/7oclo?`KoWIfM3Oooool000_ooooo1onRXZ87odM7A`OoWIfM1olf=SH7
oc`l?0Oo6QXJ1om8B4P6oeaLG0Gooooo1ol[:b/7oaXJ6POo3`l?1olE5AD7o`l?3`Oo8b<S1olN7Qh6
ob`/;0Kooooo1_l?3`l7o`T92@Oo1@D51ol820P7o`410@Oo00001ol92@T6oaXJ6PKooooo1olR8R87
od10@0Ko6QXJ1olZ:RX7od10@0Oo4Q8B1olH61P6ocPh>0Kooooo1ol61PH7o`@410Oo2@T91ol;2`/6
o`T92@Oo3Ph>1ol?3`l6o`d=3@Kooooo1on`/;07oh>3P`Oo9bLW1omHF5P7oaDE5@OoDE5A1_lT92@6
odI6APKooooo1olU9BD7obh^;POo92@T1olK6a/7ob@T90Oo6QXJ1olN7Qh6ob4Q8@Gooooo1ol@4107
obd];@Oo@d=31omIFET7ogemO@Oo2`/;1olo?cl6oifMW@gooooo000;ooooo`OoXZ:R1om7AdL7oifM
W@Oo=SHf1oll?3`7oaXJ6POoB4Q81_mLG5`5ooooo`Oo:b/[1olJ6QX7o`l?3`Oo5ADE1ol?3`l7ob<S
8`Oo7QhN1_l/;2`6ooooo`Ko3`l?1ol92@T7o`D51@Oo20P81ol10@47o`0000Oo2@T91_lJ6QX6oooo
o`Oo8R8R1om0@406oaXJ6POo:RXZ1om0@407oa8B4POo61PH1_lh>3P6ooooo`Oo1PH61ol410@7o`T9
2@Oo2`/;1_l92@T7o`h>3POo3`l?1_l=3@d6ooooo`Oo/;2`1on3Ph<7obLW9`OoF5QH1olE5AD7oe5A
D@Ko92@T1_m6ATH6ooooo`Oo9BDU1ol^;Rh7ob@T90Oo6a/K1olT92@7oaXJ6POo7QhN1_lQ8B45oooo
o`Oo410@1ol];Bd7od=3@`OoFEUI1ommOGd7o`/;2`Oo?clo1_nMWId=ooooo`002oooool7oj:RXPOo
AdM71onMWId7ocHf=POo?3`l1olJ6QX7odQ8B0KoG5aL1Oooool7ob/[:`Oo6QXJ1ol?3`l7oaDE5@Oo
3`l?1olS8b<7oahN7PKo;2`/1_ooool6o`l?3`Oo2@T91ol51@D7o`P820Oo0@411ol00007o`T92@Ko
6QXJ1_ooool7ob8R8POo@4101_lJ6QX7obXZ:POo@4101olB4Q87oaPH60Ko>3Ph1_ooool7o`H61POo
10@41ol92@T7o`/;2`Ko2@T91ol>3Ph7o`l?3`Ko3@d=1_ooool7ok2`/0OoPh>31olW9bL7oeQHF0Oo
5ADE1omADE46ob@T90KoATI61_ooool7obDU9@Oo;Rh^1olT92@7oa/K6`Oo92@T1olJ6QX7oahN7PKo
8B4Q1Oooool7oa0@40Oo;Bd]1om3@d<7oeUIF@OoOGem1ol;2`/7oclo?`KoWIfM3Oooool000_ooooo
1onRXZ87odM7A`OoWIfM1olf=SH7oc`l?0Oo6QXJ1om8B4P6oeaLG0Gooooo1ol[:b/7oaXJ6POo3`l?
1olE5AD7o`l?3`Oo8b<S1olN7Qh6ob`/;0Kooooo1_l?3`l7o`T92@Oo1@D51ol820P7o`410@Oo0000
1ol92@T6oaXJ6PKooooo1olR8R87od10@0Ko6QXJ1olZ:RX7od10@0Oo4Q8B1olH61P6ocPh>0Kooooo
1ol61PH7o`@410Oo2@T91ol;2`/6o`T92@Oo3Ph>1ol?3`l6o`d=3@Kooooo1on`/;07oh>3P`Oo9bLW
1omHF5P7oaDE5@OoDE5A1_lT92@6odI6APKooooo1olU9BD7obh^;POo92@T1olK6a/7ob@T90Oo6QXJ
1olN7Qh6ob4Q8@Gooooo1ol@4107obd];@Oo@d=31omIFET7ogemO@Oo2`/;1olo?cl6oifMW@gooooo
000;ooooo`OoXZ:R1om7AdL7oifMW@Oo=SHf1oll?3`7oaXJ6POoB4Q81_mLG5`5ooooo`Oo:b/[1olJ
6QX7o`l?3`Oo5ADE1ol?3`l7ob<S8`Oo7QhN1_l/;2`6ooooo`Ko3`l?1ol92@T7o`D51@Oo20P81ol1
0@47o`0000Oo2@T91_lJ6QX6ooooo`Oo8R8R1om0@406oaXJ6POo:RXZ1om0@407oa8B4POo61PH1_lh
>3P6ooooo`Oo1PH61ol410@7o`T92@Oo2`/;1_l92@T7o`h>3POo3`l?1_l=3@d6ooooo`Oo/;2`1on3
Ph<7obLW9`OoF5QH1olE5AD7oe5AD@Ko92@T1_m6ATH6ooooo`Oo9BDU1ol^;Rh7ob@T90Oo6a/K1olT
92@7oaXJ6POo7QhN1_lQ8B45ooooo`Oo410@1ol];Bd7od=3@`OoFEUI1ommOGd7o`/;2`Oo?clo1_nM
WId=ooooo`002oooool7oj:RXPOoAdM71onMWId7ocHf=POo?3`l1olJ6QX7odQ8B0KoG5aL1Oooool7
ob/[:`Oo6QXJ1ol?3`l7oaDE5@Oo3`l?1olS8b<7oahN7PKo;2`/1_ooool6o`l?3`Oo2@T91ol51@D7
o`P820Oo0@411ol00007o`T92@Ko6QXJ1_ooool7ob8R8POo@4101_lJ6QX7obXZ:POo@4101olB4Q87
oaPH60Ko>3Ph1_ooool7o`H61POo10@41ol92@T7o`/;2`Ko2@T91ol>3Ph7o`l?3`Ko3@d=1_ooool7
ok2`/0OoPh>31olW9bL7oeQHF0Oo5ADE1omADE46ob@T90KoATI61_ooool7obDU9@Oo;Rh^1olT92@7
oa/K6`Oo92@T1olJ6QX7oahN7PKo8B4Q1Oooool7oa0@40Oo;Bd]1om3@d<7oeUIF@OoOGem1ol;2`/7
oclo?`KoWIfM3Oooool000_ooooo1om1@D47odI6APOoOgmo1olc<c<7ob/[:`Oo@d=31olk>c/6oc<c
<`Gooooo1olT92@7o`820POo8b<S1olm?Cd7oahN7POo71`L1olC4a<6obXZ:PKooooo1_lh>3P7ob8R
8POo7QhN1olb<S87oaLG5`Oo820P1olY:BT<ooooo`Oo;Bd]1olY:BT6oaTI6@Oo6a/K1olD51@7o`H6
1POo8B4Q1_m4A4@6ooooo`Oo:2PX1olK6a/7obXZ:POo<30`1_l[:b/7odY:BPOooooo1_l];Bd6oooo
o`Oo<S8b1oli>CT7ob0P80OoBd];1olO7al7ofATI0Ko?3`l1_l_;bl6ooooo`Oo=cLg1olV9RH7obLW
9`Oo8B4Q1olm?Cd7obXZ:POo:2PX1_mYJFT5ooooo`Oo6QXJ1olR8R87oaPH60OoAdM71omBDU87oa@D
50OoK6a/1_lc<c<=ooooo`002oooool7od51@@OoATI61omoOgl7oc<c<`Oo:b/[1om3@d<7oc/k>`Ko
<c<c1Oooool7ob@T90Oo0P821olS8b<7ocdm?@Oo7QhN1olL71`7oa<C4`Ko:RXZ1_ooool6ocPh>0Oo
8R8R1olN7Qh7oc8b<POo5aLG1olP8207obTY:@cooooo1ol];Bd7obTY:@Ko6ATI1olK6a/7oa@D50Oo
1PH61olQ8B46odA4A0Kooooo1olX:2P7oa/K6`Oo:RXZ1ol`<306ob/[:`OoBTY:1oooool6obd];@Ko
oooo1olb<S87ocTi>@Oo820P1om;Bd/7oalO7`OoI6AT1_ll?3`6obl_;`Kooooo1olg=cL7obHV9POo
9bLW1olQ8B47ocdm?@Oo:RXZ1olX:2P6ofUYJ@Gooooo1olJ6QX7ob8R8POo61PH1om7AdL7oe9BDPOo
51@D1om/K6`6oc<c<`gooooo000;ooooo`Oo@D511om6ATH7ogmoO`Oo<c<c1ol[:b/7od=3@`Oo>c/k
1_lc<c<5ooooo`Oo92@T1ol20P87ob<S8`Oo?Cdm1olN7Qh7oa`L70Oo4a<C1_lZ:RX6ooooo`Ko>3Ph
1olR8R87oahN7POo<S8b1olG5aL7ob0P80Oo:BTY3?ooool7obd];@Oo:BTY1_lI6AT7oa/K6`Oo51@D
1ol61PH7ob4Q8@KoA4A41_ooool7obPX:0Oo6a/K1olZ:RX7oc0`<0Ko:b/[1om:BTX7ooooo`Ko;Bd]
1_ooool7oc8b<POo>CTi1olP8207od];B`Oo7alO1omTI6@6oc`l?0Ko;bl_1_ooool7ocLg=`Oo9RHV
1olW9bL7ob4Q8@Oo?Cdm1olZ:RX7obPX:0KoJFUY1Oooool7oaXJ6POo8R8R1olH61P7odM7A`OoDU9B
1olD51@7ofa/K0Ko<c<c3Oooool000_ooooo1om1@D47odI6APOoOgmo1olc<c<7ob/[:`Oo@d=31olk
>c/6oc<c<`Gooooo1olT92@7o`820POo8b<S1olm?Cd7oahN7POo71`L1olC4a<6obXZ:PKooooo1_lh
>3P7ob8R8POo7QhN1olb<S87oaLG5`Oo820P1olY:BT<ooooo`Oo;Bd]1olY:BT6oaTI6@Oo6a/K1olD
51@7o`H61POo8B4Q1_m4A4@6ooooo`Oo:2PX1olK6a/7obXZ:POo<30`1_l[:b/7odY:BPOooooo1_l]
;Bd6ooooo`Oo<S8b1oli>CT7ob0P80OoBd];1olO7al7ofATI0Ko?3`l1_l_;bl6ooooo`Oo=cLg1olV
9RH7obLW9`Oo8B4Q1olm?Cd7obXZ:POo:2PX1_mYJFT5ooooo`Oo6QXJ1olR8R87oaPH60OoAdM71omB
DU87oa@D50OoK6a/1_lc<c<=ooooo`002oooool7od51@@OoATI61omoOgl7oc<c<`Oo:b/[1om3@d<7
oc/k>`Ko<c<c1Oooool7ob@T90Oo0P821olS8b<7ocdm?@Oo7QhN1olL71`7oa<C4`Ko:RXZ1_ooool6
ocPh>0Oo8R8R1olN7Qh7oc8b<POo5aLG1olP8207obTY:@cooooo1ol];Bd7obTY:@Ko6ATI1olK6a/7
oa@D50Oo1PH61olQ8B46odA4A0Kooooo1olX:2P7oa/K6`Oo:RXZ1ol`<306ob/[:`OoBTY:1oooool6
obd];@Kooooo1olb<S87ocTi>@Oo820P1om;Bd/7oalO7`OoI6AT1_ll?3`6obl_;`Kooooo1olg=cL7
obHV9POo9bLW1olQ8B47ocdm?@Oo:RXZ1olX:2P6ofUYJ@Gooooo1olJ6QX7ob8R8POo61PH1om7AdL7
oe9BDPOo51@D1om/K6`6oc<c<`gooooo000;ooooo`Oo@D511om6ATH7ogmoO`Oo<c<c1ol[:b/7od=3
@`Oo>c/k1_lc<c<5ooooo`Oo92@T1ol20P87ob<S8`Oo?Cdm1olN7Qh7oa`L70Oo4a<C1_lZ:RX6oooo
o`Ko>3Ph1olR8R87oahN7POo<S8b1olG5aL7ob0P80Oo:BTY3?ooool7obd];@Oo:BTY1_lI6AT7oa/K
6`Oo51@D1ol61PH7ob4Q8@KoA4A41_ooool7obPX:0Oo6a/K1olZ:RX7oc0`<0Ko:b/[1om:BTX7oooo
o`Ko;Bd]1_ooool7oc8b<POo>CTi1olP8207od];B`Oo7alO1omTI6@6oc`l?0Ko;bl_1_ooool7ocLg
=`Oo9RHV1olW9bL7ob4Q8@Oo?Cdm1olZ:RX7obPX:0KoJFUY1Oooool7oaXJ6POo8R8R1olH61P7odM7
A`OoDU9B1olD51@7ofa/K0Ko<c<c3Oooool000_ooooo1om1@D47odI6APOoOgmo1olc<c<7ob/[:`Oo
@d=31olk>c/6oc<c<`Gooooo1olT92@7o`820POo8b<S1olm?Cd7oahN7POo71`L1olC4a<6obXZ:PKo
oooo1_lh>3P7ob8R8POo7QhN1olb<S87oaLG5`Oo820P1olY:BT<ooooo`Oo;Bd]1olY:BT6oaTI6@Oo
6a/K1olD51@7o`H61POo8B4Q1_m4A4@6ooooo`Oo:2PX1olK6a/7obXZ:POo<30`1_l[:b/7odY:BPOo
oooo1_l];Bd6ooooo`Oo<S8b1oli>CT7ob0P80OoBd];1olO7al7ofATI0Ko?3`l1_l_;bl6ooooo`Oo
=cLg1olV9RH7obLW9`Oo8B4Q1olm?Cd7obXZ:POo:2PX1_mYJFT5ooooo`Oo6QXJ1olR8R87oaPH60Oo
AdM71omBDU87oa@D50OoK6a/1_lc<c<=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002oooool7oc<c<`OoN7Qh1olV
9RH7oeiNGPOo4Q8B1om5ADD7oc`l?0KoVYZJ1Oooool7oc@d=0Oo9BDU1ol?3`l7o`0000Oo3@d=1ol7
1`L7oa/K6`Ko:RXZ1_ooool6obHV9POo30`<1ol=3@d7oaDE5@Oo3Ph>1olC4a<7oa0@40KoADE51_oo
ool7ob/[:`OoN7Qh1_ln?Sh7oalO7`Oo30`<1olE5AD7oa4A4@Ko;Rh^1_ooool7o`D51@Oo5ADE1olD
51@7oaXJ6PKo;2`/1ol=3@d7o`h>3PKo4Q8B1_ooool7obHV9POo5QHF1olV9RH7obDU9@OoZ:RX1ooQ
hN46ocHf=PKoFUYJ1_ooool7oa`L70Oo;2`/1onn_[h7oclo?`Oo5ADE1olK6a/7oaHF5PKo<S8b1Ooo
ool7o``<30Oo6a/K1ol820P7o`/;2`Oo3`l?1ol@4107o`h>3PKo9RHV3Oooool000_ooooo1olc<c<7
ogQhN0Oo9RHV1omNGUh7oa8B4POoADE51oll?3`6oiZJVPGooooo1old=3@7obDU9@Oo3`l?1ol00007
o`d=3@Oo1`L71olK6a/6obXZ:PKooooo1_lV9RH7o``<30Oo3@d=1olE5AD7o`h>3POo4a<C1ol@4106
odE5A@Kooooo1ol[:b/7ogQhN0Ko?Shn1olO7al7o``<30Oo5ADE1olA4A46obh^;PKooooo1ol51@D7
oaDE5@Oo51@D1olJ6QX6ob`/;0Oo3@d=1ol>3Ph6oa8B4PKooooo1olV9RH7oaHF5POo9RHV1olU9BD7
ojRXZ0OohN7Q1_lf=SH6oeYJFPKooooo1olL71`7ob`/;0Oo_[jn1olo?cl7oaDE5@Oo6a/K1olF5QH6
oc8b<PGooooo1ol<30`7oa/K6`Oo20P81ol;2`/7o`l?3`Oo410@1ol>3Ph6obHV9Pgooooo000;oooo
o`Oo<c<c1omhN7P7obHV9POoGUiN1olB4Q87odE5A@Oo?3`l1_nJVYX5ooooo`Oo=3@d1olU9BD7o`l?
3`Oo00001ol=3@d7o`L71`Oo6a/K1_lZ:RX6ooooo`Ko9RHV1ol<30`7o`d=3@Oo5ADE1ol>3Ph7oa<C
4`Oo410@1_m5ADD6ooooo`Oo:b/[1omhN7P6ochn?POo7alO1ol<30`7oaDE5@Oo4A4A1_l^;Rh6oooo
o`Oo1@D51olE5AD7oa@D50Oo6QXJ1_l/;2`7o`d=3@Oo3Ph>1_lB4Q86ooooo`Oo9RHV1olF5QH7obHV
9POo9BDU1onXZ:P7on7Qh@Ko=SHf1_mJFUX6ooooo`Oo71`L1ol/;2`7okjn_POo?clo1olE5AD7oa/K
6`Oo5QHF1_lb<S85ooooo`Oo30`<1olK6a/7o`P820Oo2`/;1ol?3`l7oa0@40Oo3Ph>1_lV9RH=oooo
o`002oooool7oc<c<`OoN7Qh1olV9RH7oeiNGPOo4Q8B1om5ADD7oc`l?0KoVYZJ1Oooool7oc@d=0Oo
9BDU1ol?3`l7o`0000Oo3@d=1ol71`L7oa/K6`Ko:RXZ1_ooool6obHV9POo30`<1ol=3@d7oaDE5@Oo
3Ph>1olC4a<7oa0@40KoADE51_ooool7ob/[:`OoN7Qh1_ln?Sh7oalO7`Oo30`<1olE5AD7oa4A4@Ko
;Rh^1_ooool7o`D51@Oo5ADE1olD51@7oaXJ6PKo;2`/1ol=3@d7o`h>3PKo4Q8B1_ooool7obHV9POo
5QHF1olV9RH7obDU9@OoZ:RX1ooQhN46ocHf=PKoFUYJ1_ooool7oa`L70Oo;2`/1onn_[h7oclo?`Oo
5ADE1olK6a/7oaHF5PKo<S8b1Oooool7o``<30Oo6a/K1ol820P7o`/;2`Oo3`l?1ol@4107o`h>3PKo
9RHV3Oooool000_ooooo1olc<c<7ogQhN0Oo9RHV1omNGUh7oa8B4POoADE51oll?3`6oiZJVPGooooo
1old=3@7obDU9@Oo3`l?1ol00007o`d=3@Oo1`L71olK6a/6obXZ:PKooooo1_lV9RH7o``<30Oo3@d=
1olE5AD7o`h>3POo4a<C1ol@4106odE5A@Kooooo1ol[:b/7ogQhN0Ko?Shn1olO7al7o``<30Oo5ADE
1olA4A46obh^;PKooooo1ol51@D7oaDE5@Oo51@D1olJ6QX6ob`/;0Oo3@d=1ol>3Ph6oa8B4PKooooo
1olV9RH7oaHF5POo9RHV1olU9BD7ojRXZ0OohN7Q1_lf=SH6oeYJFPKooooo1olL71`7ob`/;0Oo_[jn
1olo?cl7oaDE5@Oo6a/K1olF5QH6oc8b<PGooooo1ol<30`7oa/K6`Oo20P81ol;2`/7o`l?3`Oo410@
1ol>3Ph6obHV9Pgooooo000;ooooo`Oo<c<c1omhN7P7obHV9POoGUiN1olB4Q87odE5A@Oo?3`l1_nJ
VYX5ooooo`Oo=3@d1olU9BD7o`l?3`Oo00001ol=3@d7o`L71`Oo6a/K1_lZ:RX6ooooo`Ko9RHV1ol<
30`7o`d=3@Oo5ADE1ol>3Ph7oa<C4`Oo410@1_m5ADD6ooooo`Oo:b/[1omhN7P6ochn?POo7alO1ol<
30`7oaDE5@Oo4A4A1_l^;Rh6ooooo`Oo1@D51olE5AD7oa@D50Oo6QXJ1_l/;2`7o`d=3@Oo3Ph>1_lB
4Q86ooooo`Oo9RHV1olF5QH7obHV9POo9BDU1onXZ:P7on7Qh@Ko=SHf1_mJFUX6ooooo`Oo71`L1ol/
;2`7okjn_POo?clo1olE5AD7oa/K6`Oo5QHF1_lb<S85ooooo`Oo30`<1olK6a/7o`P820Oo2`/;1ol?
3`l7oa0@40Oo3Ph>1_lV9RH=ooooo`002oooool7oc<c<`OoN7Qh1olV9RH7oeiNGPOo4Q8B1om5ADD7
oc`l?0KoVYZJ1Oooool7oc@d=0Oo9BDU1ol?3`l7o`0000Oo3@d=1ol71`L7oa/K6`Ko:RXZ1_ooool6
obHV9POo30`<1ol=3@d7oaDE5@Oo3Ph>1olC4a<7oa0@40KoADE51_ooool7ob/[:`OoN7Qh1_ln?Sh7
oalO7`Oo30`<1olE5AD7oa4A4@Ko;Rh^1_ooool7o`D51@Oo5ADE1olD51@7oaXJ6PKo;2`/1ol=3@d7
o`h>3PKo4Q8B1_ooool7obHV9POo5QHF1olV9RH7obDU9@OoZ:RX1ooQhN46ocHf=PKoFUYJ1_ooool7
oa`L70Oo;2`/1onn_[h7oclo?`Oo5ADE1olK6a/7oaHF5PKo<S8b1Oooool7o``<30Oo6a/K1ol820P7
o`/;2`Oo3`l?1ol@4107o`h>3PKo9RHV3Oooool000_ooooo1omYJFT7ocXj>POoD51@1olJ6QX7ocdm
?@Oo7alO1omGEeL6ogmoO`Gooooo1om;Bd/7ode=C@OoGemO1ol00007o`T92@Oo4Q8B1olS8b<6ohR8
R0Kooooo1_lL71`7o`X:2POo1@D51ol=3@d7oa@D50Oo5aLG1ol?3`l6og5aL@Kooooo1onCTi<7oooo
o`KoD51@1olQ8B47ob`/;0Oo5aLG1olH61P6odi>CPKooooo1ol71`L7o`820POo2PX:1olD51@6obLW
9`Oo3`l?1ol@4106oa4A4@Kooooo1ol61PH7o``<30Oo7QhN1olE5AD7ob/[:`Oo>3Ph1_l[:b/6obHV
9PKooooo1olG5aL7o`X:2POoBDU91om0@407oc/k>`Oo>SXj1olG5aL6obPX:0Gooooo1olC4a<7o``<
30Oo410@1ol?3`l7o``<30Oo5aLG1olC4a<6ob0P80gooooo000;ooooo`OoJFUY1olj>SX7oe1@D0Oo
6QXJ1olm?Cd7oalO7`OoEeMG1_moOgl5ooooo`OoBd];1om=CDd7oemOG`Oo00001ol92@T7oa8B4POo
8b<S1_n8R8P6ooooo`Ko71`L1ol:2PX7o`D51@Oo3@d=1olD51@7oaLG5`Oo3`l?1_maLG46ooooo`Oo
Ti>C1oooool6oe1@D0Oo8B4Q1ol/;2`7oaLG5`Oo61PH1_m>CTh6ooooo`Oo1`L71ol20P87o`X:2POo
51@D1_lW9bL7o`l?3`Oo410@1_lA4A46ooooo`Oo1PH61ol<30`7oahN7POo5ADE1ol[:b/7ocPh>0Ko
:b/[1_lV9RH6ooooo`Oo5aLG1ol:2PX7odU9B@Oo@4101olk>c/7ocXj>POo5aLG1_lX:2P5ooooo`Oo
4a<C1ol<30`7oa0@40Oo3`l?1ol<30`7oaLG5`Oo4a<C1_lP820=ooooo`002oooool7ofUYJ@Oo>SXj
1om@D507oaXJ6POo?Cdm1olO7al7oeMGE`KoOgmo1Oooool7od];B`OoCDe=1omOGel7o`0000Oo2@T9
1olB4Q87ob<S8`KoR8R81_ooool6oa`L70Oo2PX:1ol51@D7o`d=3@Oo51@D1olG5aL7o`l?3`KoLG5a
1_ooool7oi>CT`Oooooo1_m@D507ob4Q8@Oo;2`/1olG5aL7oaPH60KoCTi>1_ooool7o`L71`Oo0P82
1ol:2PX7oa@D50Ko9bLW1ol?3`l7oa0@40Ko4A4A1_ooool7o`H61POo30`<1olN7Qh7oaDE5@Oo:b/[
1olh>3P6ob/[:`Ko9RHV1_ooool7oaLG5`Oo2PX:1om9BDT7od10@0Oo>c/k1olj>SX7oaLG5`Ko:2PX
1Oooool7oa<C4`Oo30`<1ol@4107o`l?3`Oo30`<1olG5aL7oa<C4`Ko820P3Oooool000_ooooo1omY
JFT7ocXj>POoD51@1olJ6QX7ocdm?@Oo7alO1omGEeL6ogmoO`Gooooo1om;Bd/7ode=C@OoGemO1ol0
0007o`T92@Oo4Q8B1olS8b<6ohR8R0Kooooo1_lL71`7o`X:2POo1@D51ol=3@d7oa@D50Oo5aLG1ol?
3`l6og5aL@Kooooo1onCTi<7ooooo`KoD51@1olQ8B47ob`/;0Oo5aLG1olH61P6odi>CPKooooo1ol7
1`L7o`820POo2PX:1olD51@6obLW9`Oo3`l?1ol@4106oa4A4@Kooooo1ol61PH7o``<30Oo7QhN1olE
5AD7ob/[:`Oo>3Ph1_l[:b/6obHV9PKooooo1olG5aL7o`X:2POoBDU91om0@407oc/k>`Oo>SXj1olG
5aL6obPX:0Gooooo1olC4a<7o``<30Oo410@1ol?3`l7o``<30Oo5aLG1olC4a<6ob0P80gooooo000;
ooooo`OoJFUY1olj>SX7oe1@D0Oo6QXJ1olm?Cd7oalO7`OoEeMG1_moOgl5ooooo`OoBd];1om=CDd7
oemOG`Oo00001ol92@T7oa8B4POo8b<S1_n8R8P6ooooo`Ko71`L1ol:2PX7o`D51@Oo3@d=1olD51@7
oaLG5`Oo3`l?1_maLG46ooooo`OoTi>C1oooool6oe1@D0Oo8B4Q1ol/;2`7oaLG5`Oo61PH1_m>CTh6
ooooo`Oo1`L71ol20P87o`X:2POo51@D1_lW9bL7o`l?3`Oo410@1_lA4A46ooooo`Oo1PH61ol<30`7
oahN7POo5ADE1ol[:b/7ocPh>0Ko:b/[1_lV9RH6ooooo`Oo5aLG1ol:2PX7odU9B@Oo@4101olk>c/7
ocXj>POo5aLG1_lX:2P5ooooo`Oo4a<C1ol<30`7oa0@40Oo3`l?1ol<30`7oaLG5`Oo4a<C1_lP820=
ooooo`002oooool7ofUYJ@Oo>SXj1om@D507oaXJ6POo?Cdm1olO7al7oeMGE`KoOgmo1Oooool7od];
B`OoCDe=1omOGel7o`0000Oo2@T91olB4Q87ob<S8`KoR8R81_ooool6oa`L70Oo2PX:1ol51@D7o`d=
3@Oo51@D1olG5aL7o`l?3`KoLG5a1_ooool7oi>CT`Oooooo1_m@D507ob4Q8@Oo;2`/1olG5aL7oaPH
60KoCTi>1_ooool7o`L71`Oo0P821ol:2PX7oa@D50Ko9bLW1ol?3`l7oa0@40Ko4A4A1_ooool7o`H6
1POo30`<1olN7Qh7oaDE5@Oo:b/[1olh>3P6ob/[:`Ko9RHV1_ooool7oaLG5`Oo2PX:1om9BDT7od10
@0Oo>c/k1olj>SX7oaLG5`Ko:2PX1Oooool7oa<C4`Oo30`<1ol@4107o`l?3`Oo30`<1olG5aL7oa<C
4`Ko820P3Oooool000_ooooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGo
oooo1omFEUH7ofm_K`OoQHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo
4Q8B1olG5aL7o`/;2`ko51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo
4A4A1_lh>3P6ooooo`Oo3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo
10@41ol00007o`P820Oo6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo
<c<c1ol`<307ocLg=`Oo7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko
:BTY3Oooool000_ooooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo
1omFEUH7ofm_K`OoQHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B
1olG5aL7o`/;2`ko51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A
1_lh>3P6ooooo`Oo3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@4
1ol00007o`P820Oo6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c
1ol`<307ocLg=`Oo7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY
3Oooool000_ooooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo1omF
EUH7ofm_K`OoQHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B1olG
5aL7o`/;2`ko51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A1_lh
>3P6ooooo`Oo3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@41ol0
0007o`P820Oo6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c1ol`
<307ocLg=`Oo7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY3Ooo
ool000_ooooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo1omFEUH7
ofm_K`OoQHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B1olG5aL7
o`/;2`ko51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A1_lh>3P6
ooooo`Oo3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@41ol00007
o`P820Oo6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c1ol`<307
ocLg=`Oo7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY3Oooool0
00_ooooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo1omFEUH7ofm_
K`OoQHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B1olG5aL7o`/;
2`ko51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A1_lh>3P6oooo
o`Oo3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@41ol00007o`P8
20Oo6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c1ol`<307ocLg
=`Oo7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY3Oooool000_o
oooo1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo1omFEUH7ofm_K`Oo
QHF51olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B1olG5aL7o`/;2`ko
51@D1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A1_lh>3P6ooooo`Oo
3@d=1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@41ol00007o`P820Oo
6a/K1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c1ol`<307ocLg=`Oo
7alO1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY3Oooool000_ooooo
1old=3@7of5QH@Oo10@41omXJ6P7oahN7POoBDU91omoOgl6oiZJVPGooooo1omFEUH7ofm_K`OoQHF5
1olX:2P7oc@d=0Oo92@T1om7AdL6oda<C0Kooooo1_lI6AT7oaDE5@Oo4Q8B1olG5aL7o`/;2`ko51@D
1_mGEeL6ooooo`Oo<C4a1olm?Cd6obTY:@Oo9bLW1ol>3Ph7oaPH60Oo4A4A1_lh>3P6ooooo`Oo3@d=
1ol:2PX7oa4A4@Oo7AdM1_lN7Qh7o`T92@Oo2`/;1_lB4Q86ooooo`Oo10@41ol00007o`P820Oo6a/K
1olW9bL7obXZ:PKo:b/[1_m?Cdl6ooooo`Oo2@T91ol_;bl7odE5A@Oo<c<c1ol`<307ocLg=`Oo7alO
1_lG5aL5ooooo`Oo5ADE1ol<30`>oaDE5@Oo1`L71ol00007o`d=3@Ko:BTY3Oooool000_ooooo1omA
DE47odA4A0Oo>3Ph1ol/;2`7ocdm?@Oo00001omQHF46ohn?S`Gooooo1olf=SH7onWYj@Oooooo1ooK
fm/7ofEUI@Oo;bl_1om@D506obl_;`Kooooo1_lZ:RX7oaPH60Oo410@1ol10@47o`X:2POo3Ph>1olO
7al6ohB4Q0Kooooo1ol410@7oa@D50Ko0`<31olJ6QX7o``<30Oo20P81ol92@T6obHV9PKooooo1ol4
10@7o`<30`Oo1PH61ol?3`l6o`d=3@Oo1@D51ol61PH6o`l?3`Kooooo1ol00007oa8B4POo7alO1olY
:BT7oa4A4@Oo5ADE1_lV9RH6ob/[:`Kooooo1ol20P87o`L71`Oo71`L1olQ8B47obTY:@OoCDe=1ola
<C46ob`/;0Gooooo1olI6AT7oaLG5`Oo4A4A1olC4a<7o`l?3`Oo10@41ol?3`l6ob8R8Pgooooo000;
ooooo`OoDE5A1om4A4@7ocPh>0Oo;2`/1olm?Cd7o`0000OoHF5Q1_n?Shl5ooooo`Oo=SHf1ooYjNT7
ooooo`Oofm_K1omUIFD7obl_;`OoD51@1_l_;bl6ooooo`Ko:RXZ1olH61P7oa0@40Oo0@411ol:2PX7
o`h>3POo7alO1_n4Q8@6ooooo`Oo10@41olD51@6o`<30`Oo6QXJ1ol<30`7o`P820Oo2@T91_lV9RH6
ooooo`Oo10@41ol30`<7o`H61POo3`l?1_l=3@d7o`D51@Oo1PH61_l?3`l6ooooo`Oo00001olB4Q87
oalO7`Oo:BTY1olA4A47oaDE5@Ko9RHV1_l[:b/6ooooo`Oo0P821ol71`L7oa`L70Oo8B4Q1olY:BT7
ode=C@Oo<C4a1_l/;2`5ooooo`Oo6ATI1olG5aL7oa4A4@Oo4a<C1ol?3`l7o`@410Oo3`l?1_lR8R8=
ooooo`002oooool7oe5AD@OoA4A41olh>3P7ob`/;0Oo?Cdm1ol00007of5QH@KoShn?1Oooool7ocHf
=POojNWY1oooool7om_Kf`OoIFEU1ol_;bl7oe1@D0Ko;bl_1_ooool6obXZ:POo61PH1ol@4107o`41
0@Oo2PX:1ol>3Ph7oalO7`KoQ8B41_ooool7o`@410Oo51@D1_l30`<7oaXJ6POo30`<1ol820P7o`T9
2@Ko9RHV1_ooool7o`@410Oo0`<31ol61PH7o`l?3`Ko3@d=1ol51@D7o`H61PKo3`l?1_ooool7o`00
00Oo4Q8B1olO7al7obTY:@Oo4A4A1olE5AD6obHV9PKo:b/[1_ooool7o`820POo1`L71olL71`7ob4Q
8@Oo:BTY1om=CDd7oc4a<@Ko;2`/1Oooool7oaTI6@Oo5aLG1olA4A47oa<C4`Oo3`l?1ol410@7o`l?
3`Ko8R8R3Oooool000_ooooo1omADE47odA4A0Oo>3Ph1ol/;2`7ocdm?@Oo00001omQHF46ohn?S`Go
oooo1olf=SH7onWYj@Oooooo1ooKfm/7ofEUI@Oo;bl_1om@D506obl_;`Kooooo1_lZ:RX7oaPH60Oo
410@1ol10@47o`X:2POo3Ph>1olO7al6ohB4Q0Kooooo1ol410@7oa@D50Ko0`<31olJ6QX7o``<30Oo
20P81ol92@T6obHV9PKooooo1ol410@7o`<30`Oo1PH61ol?3`l6o`d=3@Oo1@D51ol61PH6o`l?3`Ko
oooo1ol00007oa8B4POo7alO1olY:BT7oa4A4@Oo5ADE1_lV9RH6ob/[:`Kooooo1ol20P87o`L71`Oo
71`L1olQ8B47obTY:@OoCDe=1ola<C46ob`/;0Gooooo1olI6AT7oaLG5`Oo4A4A1olC4a<7o`l?3`Oo
10@41ol?3`l6ob8R8Pgooooo000;ooooo`OoDE5A1om4A4@7ocPh>0Oo;2`/1olm?Cd7o`0000OoHF5Q
1_n?Shl5ooooo`Oo=SHf1ooYjNT7ooooo`Oofm_K1omUIFD7obl_;`OoD51@1_l_;bl6ooooo`Ko:RXZ
1olH61P7oa0@40Oo0@411ol:2PX7o`h>3POo7alO1_n4Q8@6ooooo`Oo10@41olD51@6o`<30`Oo6QXJ
1ol<30`7o`P820Oo2@T91_lV9RH6ooooo`Oo10@41ol30`<7o`H61POo3`l?1_l=3@d7o`D51@Oo1PH6
1_l?3`l6ooooo`Oo00001olB4Q87oalO7`Oo:BTY1olA4A47oaDE5@Ko9RHV1_l[:b/6ooooo`Oo0P82
1ol71`L7oa`L70Oo8B4Q1olY:BT7ode=C@Oo<C4a1_l/;2`5ooooo`Oo6ATI1olG5aL7oa4A4@Oo4a<C
1ol?3`l7o`@410Oo3`l?1_lR8R8=ooooo`002oooool7oe5AD@OoA4A41olh>3P7ob`/;0Oo?Cdm1ol0
0007of5QH@KoShn?1Oooool7ocHf=POojNWY1oooool7om_Kf`OoIFEU1ol_;bl7oe1@D0Ko;bl_1_oo
ool6obXZ:POo61PH1ol@4107o`410@Oo2PX:1ol>3Ph7oalO7`KoQ8B41_ooool7o`@410Oo51@D1_l3
0`<7oaXJ6POo30`<1ol820P7o`T92@Ko9RHV1_ooool7o`@410Oo0`<31ol61PH7o`l?3`Ko3@d=1ol5
1@D7o`H61PKo3`l?1_ooool7o`0000Oo4Q8B1olO7al7obTY:@Oo4A4A1olE5AD6obHV9PKo:b/[1_oo
ool7o`820POo1`L71olL71`7ob4Q8@Oo:BTY1om=CDd7oc4a<@Ko;2`/1Oooool7oaTI6@Oo5aLG1olA
4A47oa<C4`Oo3`l?1ol410@7o`l?3`Ko8R8R3Oooool000_ooooo1omADE47odA4A0Oo>3Ph1ol/;2`7
ocdm?@Oo00001omQHF46ohn?S`Gooooo1olf=SH7onWYj@Oooooo1ooKfm/7ofEUI@Oo;bl_1om@D506
obl_;`Kooooo1_lZ:RX7oaPH60Oo410@1ol10@47o`X:2POo3Ph>1olO7al6ohB4Q0Kooooo1ol410@7
oa@D50Ko0`<31olJ6QX7o``<30Oo20P81ol92@T6obHV9PKooooo1ol410@7o`<30`Oo1PH61ol?3`l6
o`d=3@Oo1@D51ol61PH6o`l?3`Kooooo1ol00007oa8B4POo7alO1olY:BT7oa4A4@Oo5ADE1_lV9RH6
ob/[:`Kooooo1ol20P87o`L71`Oo71`L1olQ8B47obTY:@OoCDe=1ola<C46ob`/;0Gooooo1olI6AT7
oaLG5`Oo4A4A1olC4a<7o`l?3`Oo10@41ol?3`l6ob8R8Pgooooo000;ooooo`OoEEEE1on0P807o`/;
2`OoD51@1olj>SX7ofATI0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c
<`Oo>3Ph1_m5ADD6ooooo`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6oooo
o`Oo2@T91ol;2`/6o`<30`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<
30Oo7QhN1_lD51@7o`h>3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A
4@Ko9RHV1_lK6a/6ooooo`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE
5@Oo3`l?3_lJ6QX7oahN7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`Oo
D51@1olj>SX7ofATI0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo
>3Ph1_m5ADD6ooooo`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo
2@T91ol;2`/6o`<30`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo
7QhN1_lD51@7o`h>3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko
9RHV1_lK6a/6ooooo`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo
3`l?3_lJ6QX7oahN7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`OoD51@
1olj>SX7ofATI0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo>3Ph
1_m5ADD6ooooo`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo2@T9
1ol;2`/6o`<30`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo7QhN
1_lD51@7o`h>3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko9RHV
1_lK6a/6ooooo`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo3`l?
3_lJ6QX7oahN7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`OoD51@1olj
>SX7ofATI0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo>3Ph1_m5
ADD6ooooo`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo2@T91ol;
2`/6o`<30`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo7QhN1_lD
51@7o`h>3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko9RHV1_lK
6a/6ooooo`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo3`l?3_lJ
6QX7oahN7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`OoD51@1olj>SX7
ofATI0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo>3Ph1_m5ADD6
ooooo`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo2@T91ol;2`/6
o`<30`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo7QhN1_lD51@7
o`h>3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko9RHV1_lK6a/6
ooooo`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo3`l?3_lJ6QX7
oahN7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`OoD51@1olj>SX7ofAT
I0OoQXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo>3Ph1_m5ADD6oooo
o`Ko7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo2@T91ol;2`/6o`<3
0`Oo1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo7QhN1_lD51@7o`h>
3POo10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko9RHV1_lK6a/6oooo
o`Oo00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo3`l?3_lJ6QX7oahN
7POo10@41ol00006ocPh>0gooooo000;ooooo`OoEEEE1on0P807o`/;2`OoD51@1olj>SX7ofATI0Oo
QXJ61_ng]kL5ooooo`Oo92@T1om5ADD7okFe]@OoaLG51omeMGD7oc<c<`Oo>3Ph1_m5ADD6ooooo`Ko
7QhN1ol<30`7o`T92@Oo2`/;1ol<30`7o`0000Oo4Q8B1_m9BDT6ooooo`Oo2@T91ol;2`/6o`<30`Oo
1PH61ol;2`/7o`L71`Oo5ADE1_lP8206ooooo`Oo00001ol51@D7o``<30Oo7QhN1_lD51@7o`h>3POo
10@41_lD51@6ooooo`Oo0@411ol<30`7oaDE5@Oo:RXZ1ol@4107oa4A4@Ko9RHV1_lK6a/6ooooo`Oo
00001olL71`>obDU9@Oo<S8b1oli>CT7oaHF5PKo820P1Oooool7oaDE5@Oo3`l?3_lJ6QX7oahN7POo
10@41ol00006ocPh>0gooooo000;ooooo`OoS8b<1ole=CD7odI6APOo<c<c1omQHF47od10@0OoLG5a
1_m<C4`5ooooo`Oo4Q8B1olA4A47oc/k>`OoDE5A1omCDe<7of9RHPOo=SHf1_mCDe<6ooooo`KoD51@
1olB4Q87ob8R8POo6QXJ1olH61P7oc8b<POo;bl_3?ooool7ob<S8`Oo20P81_l92@T7oa4A4@Oo3`l?
1olG5aL7o`0000Ko9bLW1_ooool7oa4A4@ko1PH61olF5QH6o`l?3`Oo3Ph>1ol:2PX6oaHF5PKooooo
1ol<30`7oa4A4@Oo9RHV1ol?3`l>oc@d=0Ko:RXZ1_lS8b<6ooooo`Oo61PH1olB4Q87ob@T90Oo51@D
1olY:BT7ob`/;0Oo4Q8B1_lH61P5ooooo`Oo;Rh^1olN7Qh7oa4A4@Oo7alO1ol_;bl7o`/;2`Oo4a<C
1_ld=3@=ooooo`002oooool7ohb<S0Oo=CDe1om6ATH7oc<c<`OoHF5Q1om0@407og5aL@KoC4a<1Ooo
ool7oa8B4POo4A4A1olk>c/7oe5AD@OoDe=C1omRHV87ocHf=PKoDe=C1_ooool6oe1@D0Oo4Q8B1olR
8R87oaXJ6POo61PH1olb<S87obl_;`cooooo1olS8b<7o`P820Ko2@T91olA4A47o`l?3`Oo5aLG1ol0
0006obLW9`Kooooo1olA4A4>o`H61POo5QHF1_l?3`l7o`h>3POo2PX:1_lF5QH6ooooo`Oo30`<1olA
4A47obHV9POo3`l?3_ld=3@6obXZ:PKo8b<S1_ooool7oaPH60Oo4Q8B1olT92@7oa@D50Oo:BTY1ol/
;2`7oa8B4PKo61PH1Oooool7obh^;POo7QhN1olA4A47oalO7`Oo;bl_1ol;2`/7oa<C4`Ko=3@d3Ooo
ool000_ooooo1on<S8`7ocDe=@OoATI61olc<c<7of5QH@Oo@4101omaLG46oda<C0Gooooo1olB4Q87
oa4A4@Oo>c/k1omADE47oe=CD`OoHV9R1olf=SH6oe=CD`Kooooo1_m@D507oa8B4POo8R8R1olJ6QX7
oaPH60Oo<S8b1ol_;bl<ooooo`Oo8b<S1ol820P6o`T92@Oo4A4A1ol?3`l7oaLG5`Oo00001_lW9bL6
ooooo`Oo4A4A3_l61PH7oaHF5PKo3`l?1ol>3Ph7o`X:2PKo5QHF1_ooool7o``<30Oo4A4A1olV9RH7
o`l?3`ko=3@d1_lZ:RX6ob<S8`Kooooo1olH61P7oa8B4POo92@T1olD51@7obTY:@Oo;2`/1olB4Q86
oaPH60Gooooo1ol^;Rh7oahN7POo4A4A1olO7al7obl_;`Oo2`/;1olC4a<6oc@d=0gooooo000;oooo
o`OoS8b<1ole=CD7odI6APOo<c<c1omQHF47od10@0OoLG5a1_m<C4`5ooooo`Oo4Q8B1olA4A47oc/k
>`OoDE5A1omCDe<7of9RHPOo=SHf1_mCDe<6ooooo`KoD51@1olB4Q87ob8R8POo6QXJ1olH61P7oc8b
<POo;bl_3?ooool7ob<S8`Oo20P81_l92@T7oa4A4@Oo3`l?1olG5aL7o`0000Ko9bLW1_ooool7oa4A
4@ko1PH61olF5QH6o`l?3`Oo3Ph>1ol:2PX6oaHF5PKooooo1ol<30`7oa4A4@Oo9RHV1ol?3`l>oc@d
=0Ko:RXZ1_lS8b<6ooooo`Oo61PH1olB4Q87ob@T90Oo51@D1olY:BT7ob`/;0Oo4Q8B1_lH61P5oooo
o`Oo;Rh^1olN7Qh7oa4A4@Oo7alO1ol_;bl7o`/;2`Oo4a<C1_ld=3@=ooooo`002oooool7ohb<S0Oo
=CDe1om6ATH7oc<c<`OoHF5Q1om0@407og5aL@KoC4a<1Oooool7oa8B4POo4A4A1olk>c/7oe5AD@Oo
De=C1omRHV87ocHf=PKoDe=C1_ooool6oe1@D0Oo4Q8B1olR8R87oaXJ6POo61PH1olb<S87obl_;`co
oooo1olS8b<7o`P820Ko2@T91olA4A47o`l?3`Oo5aLG1ol00006obLW9`Kooooo1olA4A4>o`H61POo
5QHF1_l?3`l7o`h>3POo2PX:1_lF5QH6ooooo`Oo30`<1olA4A47obHV9POo3`l?3_ld=3@6obXZ:PKo
8b<S1_ooool7oaPH60Oo4Q8B1olT92@7oa@D50Oo:BTY1ol/;2`7oa8B4PKo61PH1Oooool7obh^;POo
7QhN1olA4A47oalO7`Oo;bl_1ol;2`/7oa<C4`Ko=3@d3Oooool000_ooooo1on<S8`7ocDe=@OoATI6
1olc<c<7of5QH@Oo@4101omaLG46oda<C0Gooooo1olB4Q87oa4A4@Oo>c/k1omADE47oe=CD`OoHV9R
1olf=SH6oe=CD`Kooooo1_m@D507oa8B4POo8R8R1olJ6QX7oaPH60Oo<S8b1ol_;bl<ooooo`Oo8b<S
1ol820P6o`T92@Oo4A4A1ol?3`l7oaLG5`Oo00001_lW9bL6ooooo`Oo4A4A3_l61PH7oaHF5PKo3`l?
1ol>3Ph7o`X:2PKo5QHF1_ooool7o``<30Oo4A4A1olV9RH7o`l?3`ko=3@d1_lZ:RX6ob<S8`Kooooo
1olH61P7oa8B4POo92@T1olD51@7obTY:@Oo;2`/1olB4Q86oaPH60Gooooo1ol^;Rh7oahN7POo4A4A
1olO7al7obl_;`Oo2`/;1olC4a<6oc@d=0gooooo000;ooooo`OoFEUI1omZJVX7oda<C0ko@T921om]
KFd7ofYZJPKoUIFE1Oooool7oaDE5@Oo=CDe1omJFUX7oe=CD`OoVIVI1olj>SX7oadM7@KoDe=C1_oo
ool6obDU9@Oo6ATI1olB4Q87oa4A4@Oo7QhN1olA4A47ob8R8PKoNGUi1_ooool7oa/K6`Oo:BTY1_l7
1`L7ob8R8POo9bLW1olI6AT7o`h>3PKo9BDU1_ooool>o``<30Oo3@d=1olG5aL6oa/K6`ko3Ph>1_lE
5AD6ooooo`Oo0`<31ol20P87oaLG5`Oo6QXJ1ol?3`l7oc0`<0Ko:b/[1_l<30`6ooooo`Oo8b<S1ol;
2`/7ob@T90Oo61PH1olP8207oc`l?0Oo4a<C1_lU9BD5ooooo`OoIFEU1olR8R87oa/K6`Oo<S8b1oll
?3`7oc0`<0Oo:2PX4oooool000_ooooo1omIFET7ofYZJPOoC4a<3_m2@T87ofe]K@OoJVYZ1_nEUID5
ooooo`Oo5ADE1ole=CD7oeYJFPOoDe=C1onIVIT7ocXj>POo7AdM1_mCDe<6ooooo`Ko9BDU1olI6AT7
oa8B4POo4A4A1olN7Qh7oa4A4@Oo8R8R1_miNGT6ooooo`Oo6a/K1olY:BT6o`L71`Oo8R8R1olW9bL7
oaTI6@Oo3Ph>1_lU9BD6ooooo`ko30`<1ol=3@d7oaLG5`Ko6a/K3_l>3Ph6oaDE5@Kooooo1ol30`<7
o`820POo5aLG1olJ6QX7o`l?3`Oo<30`1_l[:b/6o``<30Kooooo1olS8b<7o`/;2`Oo92@T1olH61P7
ob0P80Oo?3`l1olC4a<6obDU9@Gooooo1omUIFD7ob8R8POo6a/K1olb<S87oc`l?0Oo<30`1olX:2PC
ooooo`002oooool7oeUIF@OoJVYZ1om<C4`>od92@POoKFe]1omZJVX6oiFEU@Gooooo1olE5AD7ocDe
=@OoFUYJ1omCDe<7oiVIV@Oo>SXj1olM7Ad6oe=CD`Kooooo1_lU9BD7oaTI6@Oo4Q8B1olA4A47oahN
7POo4A4A1olR8R86ogUiN@Kooooo1olK6a/7obTY:@Ko1`L71olR8R87obLW9`Oo6ATI1ol>3Ph6obDU
9@Kooooo3_l<30`7o`d=3@Oo5aLG1_lK6a/>o`h>3PKo5ADE1_ooool7o`<30`Oo0P821olG5aL7oaXJ
6POo3`l?1ol`<306ob/[:`Ko30`<1_ooool7ob<S8`Oo2`/;1olT92@7oaPH60Oo820P1oll?3`7oa<C
4`Ko9BDU1Oooool7ofEUI@Oo8R8R1olK6a/7oc8b<POo?3`l1ol`<307obPX:1?ooooo000;ooooo`Oo
FEUI1omZJVX7oda<C0ko@T921om]KFd7ofYZJPKoUIFE1Oooool7oaDE5@Oo=CDe1omJFUX7oe=CD`Oo
VIVI1olj>SX7oadM7@KoDe=C1_ooool6obDU9@Oo6ATI1olB4Q87oa4A4@Oo7QhN1olA4A47ob8R8PKo
NGUi1_ooool7oa/K6`Oo:BTY1_l71`L7ob8R8POo9bLW1olI6AT7o`h>3PKo9BDU1_ooool>o``<30Oo
3@d=1olG5aL6oa/K6`ko3Ph>1_lE5AD6ooooo`Oo0`<31ol20P87oaLG5`Oo6QXJ1ol?3`l7oc0`<0Ko
:b/[1_l<30`6ooooo`Oo8b<S1ol;2`/7ob@T90Oo61PH1olP8207oc`l?0Oo4a<C1_lU9BD5ooooo`Oo
IFEU1olR8R87oa/K6`Oo<S8b1oll?3`7oc0`<0Oo:2PX4oooool000_ooooo1omIFET7ofYZJPOoC4a<
3_m2@T87ofe]K@OoJVYZ1_nEUID5ooooo`Oo5ADE1ole=CD7oeYJFPOoDe=C1onIVIT7ocXj>POo7AdM
1_mCDe<6ooooo`Ko9BDU1olI6AT7oa8B4POo4A4A1olN7Qh7oa4A4@Oo8R8R1_miNGT6ooooo`Oo6a/K
1olY:BT6o`L71`Oo8R8R1olW9bL7oaTI6@Oo3Ph>1_lU9BD6ooooo`ko30`<1ol=3@d7oaLG5`Ko6a/K
3_l>3Ph6oaDE5@Kooooo1ol30`<7o`820POo5aLG1olJ6QX7o`l?3`Oo<30`1_l[:b/6o``<30Kooooo
1olS8b<7o`/;2`Oo92@T1olH61P7ob0P80Oo?3`l1olC4a<6obDU9@Gooooo1omUIFD7ob8R8POo6a/K
1olb<S87oc`l?0Oo<30`1olX:2PCooooo`002oooool7oeUIF@OoJVYZ1om<C4`>od92@POoKFe]1omZ
JVX6oiFEU@Gooooo1olE5AD7ocDe=@OoFUYJ1omCDe<7oiVIV@Oo>SXj1olM7Ad6oe=CD`Kooooo1_lU
9BD7oaTI6@Oo4Q8B1olA4A47oahN7POo4A4A1olR8R86ogUiN@Kooooo1olK6a/7obTY:@Ko1`L71olR
8R87obLW9`Oo6ATI1ol>3Ph6obDU9@Kooooo3_l<30`7o`d=3@Oo5aLG1_lK6a/>o`h>3PKo5ADE1_oo
ool7o`<30`Oo0P821olG5aL7oaXJ6POo3`l?1ol`<306ob/[:`Ko30`<1_ooool7ob<S8`Oo2`/;1olT
92@7oaPH60Oo820P1oll?3`7oa<C4`Ko9BDU1Oooool7ofEUI@Oo8R8R1olK6a/7oc8b<POo?3`l1ol`
<307obPX:1?ooooo000;ooooo`OoFEUI1omZJVX7oda<C0ko@T921om]KFd7ofYZJPKoUIFE1Oooool7
oaDE5@Oo=CDe1omJFUX7oe=CD`OoVIVI1olj>SX7oadM7@KoDe=C1_ooool6obDU9@Oo6ATI1olB4Q87
oa4A4@Oo7QhN1olA4A47ob8R8PKoNGUi1_ooool7oa/K6`Oo:BTY1_l71`L7ob8R8POo9bLW1olI6AT7
o`h>3PKo9BDU1_ooool>o``<30Oo3@d=1olG5aL6oa/K6`ko3Ph>1_lE5AD6ooooo`Oo0`<31ol20P87
oaLG5`Oo6QXJ1ol?3`l7oc0`<0Ko:b/[1_l<30`6ooooo`Oo8b<S1ol;2`/7ob@T90Oo61PH1olP8207
oc`l?0Oo4a<C1_lU9BD5ooooo`OoIFEU1olR8R87oa/K6`Oo<S8b1oll?3`7oc0`<0Oo:2PX4oooool0
01;ooooo1onOWil7olo?c`Oo`/;21omPH607odi>CPOoh^;R1_m8B4P5ooooo`Oo8B4Q1old=3@7obPX
:0Oo;bl_1om;Bd/7oc8b<POo>SXj1_mZJVX6ooooo`Ko:2PX1olK6a/7oa`L70Oo9bLW1olF5QH7oaPH
60Oo5aLG1_lZ:RX6ooooo`Oo<C4a1ol_;bl6obXZ:POo3@d=1olK6a/7oaDE5@Oo51@D1_le=CD6oooo
o`Oo9bLW1olI6AT7obd];@OoF5QH1_ooool7od=3@`Oo9BDU1_l^;Rh6ooooo`Oo@T921olm?Cd7oa/K
6`OoDe=C1oooool7onCTi0KoEEEE1_lc<c<6ooooo`Oo<C4a1olh>3P7ooooo`Oo;Rh^1ola<C47obTY
:@Oo:b/[1_ld=3@5ooooo`Oo6a/K5OlG5aL7obHV9POo61PH1olP8206ocLg=`gooooo000Booooo`Oo
WinO1oo?cll7ol;2`POoH61P1om>CTh7on;RhPKoB4Q81Oooool7ob4Q8@Oo=3@d1olX:2P7obl_;`Oo
Bd];1olb<S87ocXj>PKoJVYZ1_ooool6obPX:0Oo6a/K1olL71`7obLW9`Oo5QHF1olH61P7oaLG5`Ko
:RXZ1_ooool7oc4a<@Oo;bl_1_lZ:RX7o`d=3@Oo6a/K1olE5AD7oa@D50Ko=CDe1_ooool7obLW9`Oo
6ATI1ol];Bd7oeQHF0Kooooo1om3@d<7obDU9@Ko;Rh^1_ooool7od92@POo?Cdm1olK6a/7oe=CD`Oo
oooo1ooTi>@6oeEEE@Ko<c<c1_ooool7oc4a<@Oo>3Ph1oooool7obh^;POo<C4a1olY:BT7ob/[:`Ko
=3@d1Oooool7oa/K6aGo5aLG1olV9RH7oaPH60Oo820P1_lg=cL=ooooo`004_ooool7oinOW`Ooclo?
1oo2`/87of1PH0OoCTi>1ooRh^86odQ8B0Gooooo1olQ8B47oc@d=0Oo:2PX1ol_;bl7od];B`Oo<S8b
1olj>SX6ofYZJPKooooo1_lX:2P7oa/K6`Oo71`L1olW9bL7oaHF5POo61PH1olG5aL6obXZ:PKooooo
1ola<C47obl_;`Ko:RXZ1ol=3@d7oa/K6`Oo5ADE1olD51@6ocDe=@Kooooo1olW9bL7oaTI6@Oo;Bd]
1omHF5P6ooooo`Oo@d=31olU9BD6obh^;PKooooo1om2@T87ocdm?@Oo6a/K1omCDe<7ooooo`Ooi>CT
1_mEEED6oc<c<`Kooooo1ola<C47ocPh>0Oooooo1ol^;Rh7oc4a<@Oo:BTY1ol[:b/6oc@d=0Gooooo
1olK6a/EoaLG5`Oo9RHV1olH61P7ob0P80Ko=cLg3Oooool001;ooooo1onOWil7olo?c`Oo`/;21omP
H607odi>CPOoh^;R1_m8B4P5ooooo`Oo8B4Q1old=3@7obPX:0Oo;bl_1om;Bd/7oc8b<POo>SXj1_mZ
JVX6ooooo`Ko:2PX1olK6a/7oa`L70Oo9bLW1olF5QH7oaPH60Oo5aLG1_lZ:RX6ooooo`Oo<C4a1ol_
;bl6obXZ:POo3@d=1olK6a/7oaDE5@Oo51@D1_le=CD6ooooo`Oo9bLW1olI6AT7obd];@OoF5QH1_oo
ool7od=3@`Oo9BDU1_l^;Rh6ooooo`Oo@T921olm?Cd7oa/K6`OoDe=C1oooool7onCTi0KoEEEE1_lc
<c<6ooooo`Oo<C4a1olh>3P7ooooo`Oo;Rh^1ola<C47obTY:@Oo:b/[1_ld=3@5ooooo`Oo6a/K5OlG
5aL7obHV9POo61PH1olP8206ocLg=`gooooo000Booooo`OoWinO1oo?cll7ol;2`POoH61P1om>CTh7
on;RhPKoB4Q81Oooool7ob4Q8@Oo=3@d1olX:2P7obl_;`OoBd];1olb<S87ocXj>PKoJVYZ1_ooool6
obPX:0Oo6a/K1olL71`7obLW9`Oo5QHF1olH61P7oaLG5`Ko:RXZ1_ooool7oc4a<@Oo;bl_1_lZ:RX7
o`d=3@Oo6a/K1olE5AD7oa@D50Ko=CDe1_ooool7obLW9`Oo6ATI1ol];Bd7oeQHF0Kooooo1om3@d<7
obDU9@Ko;Rh^1_ooool7od92@POo?Cdm1olK6a/7oe=CD`Oooooo1ooTi>@6oeEEE@Ko<c<c1_ooool7
oc4a<@Oo>3Ph1oooool7obh^;POo<C4a1olY:BT7ob/[:`Ko=3@d1Oooool7oa/K6aGo5aLG1olV9RH7
oaPH60Oo820P1_lg=cL=ooooo`004_ooool7oinOW`Ooclo?1oo2`/87of1PH0OoCTi>1ooRh^86odQ8
B0Gooooo1olQ8B47oc@d=0Oo:2PX1ol_;bl7od];B`Oo<S8b1olj>SX6ofYZJPKooooo1_lX:2P7oa/K
6`Oo71`L1olW9bL7oaHF5POo61PH1olG5aL6obXZ:PKooooo1ola<C47obl_;`Ko:RXZ1ol=3@d7oa/K
6`Oo5ADE1olD51@6ocDe=@Kooooo1olW9bL7oaTI6@Oo;Bd]1omHF5P6ooooo`Oo@d=31olU9BD6obh^
;PKooooo1om2@T87ocdm?@Oo6a/K1omCDe<7ooooo`Ooi>CT1_mEEED6oc<c<`Kooooo1ola<C47ocPh
>0Oooooo1ol^;Rh7oc4a<@Oo:BTY1ol[:b/6oc@d=0Gooooo1olK6a/EoaLG5`Oo9RHV1olH61P7ob0P
80Ko=cLg3Oooool001;ooooo1onOWil7olo?c`Oo`/;21omPH607odi>CPOoh^;R1_m8B4P5ooooo`Oo
8B4Q1old=3@7obPX:0Oo;bl_1om;Bd/7oc8b<POo>SXj1_mZJVX6ooooo`Ko:2PX1olK6a/7oa`L70Oo
9bLW1olF5QH7oaPH60Oo5aLG1_lZ:RX6ooooo`Oo<C4a1ol_;bl6obXZ:POo3@d=1olK6a/7oaDE5@Oo
51@D1_le=CD6ooooo`Oo9bLW1olI6AT7obd];@OoF5QH1_ooool7od=3@`Oo9BDU1_l^;Rh6ooooo`Oo
@T921olm?Cd7oa/K6`OoDe=C1oooool7onCTi0KoEEEE1_lc<c<6ooooo`Oo<C4a1olh>3P7ooooo`Oo
;Rh^1ola<C47obTY:@Oo:b/[1_ld=3@5ooooo`Oo6a/K5OlG5aL7obHV9POo61PH1olP8206ocLg=`go
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-1.73919, -1.74834, \
0.146455, 0.146455}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-10.5356, \
-1.74834, 0.146455, 0.146455}, {{132, 186.625}, {487.062, 432.438}} -> \
{-19.332, -1.74834, 0.146455, 0.146455}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-28.1376, -1.74834, 0.146455, 0.146455}, {{252.188, 306.812}, \
{487.062, 432.438}} -> {-36.934, -1.74834, 0.146455, 0.146455}, {{312.312, \
366.938}, {487.062, 432.438}} -> {-45.7396, -1.74834, 0.146455, 0.146455}, \
{{372.375, 427}, {487.062, 432.438}} -> {-54.5361, -1.74834, 0.146455, \
0.146455}, {{432.438, 487.062}, {487.062, 432.438}} -> {-63.3325, -1.74834, \
0.146455, 0.146455}, {{11.875, 66.5}, {427, 372.375}} -> {-1.73919, -10.5448, \
0.146455, 0.146455}, {{71.9375, 126.562}, {427, 372.375}} -> {-10.5356, \
-10.5448, 0.146455, 0.146455}, {{132, 186.625}, {427, 372.375}} -> {-19.332, \
-10.5448, 0.146455, 0.146455}, {{192.125, 246.75}, {427, 372.375}} -> \
{-28.1376, -10.5448, 0.146455, 0.146455}, {{252.188, 306.812}, {427, \
372.375}} -> {-36.934, -10.5448, 0.146455, 0.146455}, {{312.312, 366.938}, \
{427, 372.375}} -> {-45.7396, -10.5448, 0.146455, 0.146455}, {{372.375, 427}, \
{427, 372.375}} -> {-54.5361, -10.5448, 0.146455, 0.146455}, {{432.438, \
487.062}, {427, 372.375}} -> {-63.3325, -10.5448, 0.146455, 0.146455}, \
{{11.875, 66.5}, {366.938, 312.312}} -> {-1.73919, -19.3412, 0.146455, \
0.146455}, {{71.9375, 126.562}, {366.938, 312.312}} -> {-10.5356, -19.3412, \
0.146455, 0.146455}, {{132, 186.625}, {366.938, 312.312}} -> {-19.332, \
-19.3412, 0.146455, 0.146455}, {{192.125, 246.75}, {366.938, 312.312}} -> \
{-28.1376, -19.3412, 0.146455, 0.146455}, {{252.188, 306.812}, {366.938, \
312.312}} -> {-36.934, -19.3412, 0.146455, 0.146455}, {{312.312, 366.938}, \
{366.938, 312.312}} -> {-45.7396, -19.3412, 0.146455, 0.146455}, {{372.375, \
427}, {366.938, 312.312}} -> {-54.5361, -19.3412, 0.146455, 0.146455}, \
{{432.438, 487.062}, {366.938, 312.312}} -> {-63.3325, -19.3412, 0.146455, \
0.146455}, {{11.875, 66.5}, {306.812, 252.188}} -> {-1.73919, -28.1468, \
0.146455, 0.146455}, {{71.9375, 126.562}, {306.812, 252.188}} -> {-10.5356, \
-28.1468, 0.146455, 0.146455}, {{132, 186.625}, {306.812, 252.188}} -> \
{-19.332, -28.1468, 0.146455, 0.146455}, {{192.125, 246.75}, {306.812, \
252.188}} -> {-28.1376, -28.1468, 0.146455, 0.146455}, {{252.188, 306.812}, \
{306.812, 252.188}} -> {-36.934, -28.1468, 0.146455, 0.146455}, {{312.312, \
366.938}, {306.812, 252.188}} -> {-45.7396, -28.1468, 0.146455, 0.146455}, \
{{372.375, 427}, {306.812, 252.188}} -> {-54.5361, -28.1468, 0.146455, \
0.146455}, {{432.438, 487.062}, {306.812, 252.188}} -> {-63.3325, -28.1468, \
0.146455, 0.146455}, {{11.875, 66.5}, {246.75, 192.125}} -> {-1.73919, \
-36.9432, 0.146455, 0.146455}, {{71.9375, 126.562}, {246.75, 192.125}} -> \
{-10.5356, -36.9432, 0.146455, 0.146455}, {{132, 186.625}, {246.75, 192.125}} -> \
{-19.332, -36.9432, 0.146455, 0.146455}, {{192.125, 246.75}, {246.75, \
192.125}} -> {-28.1376, -36.9432, 0.146455, 0.146455}, {{252.188, 306.812}, \
{246.75, 192.125}} -> {-36.934, -36.9432, 0.146455, 0.146455}, {{312.312, \
366.938}, {246.75, 192.125}} -> {-45.7396, -36.9432, 0.146455, 0.146455}, \
{{372.375, 427}, {246.75, 192.125}} -> {-54.5361, -36.9432, 0.146455, \
0.146455}, {{432.438, 487.062}, {246.75, 192.125}} -> {-63.3325, -36.9432, \
0.146455, 0.146455}, {{11.875, 66.5}, {186.625, 132}} -> {-1.73919, -45.7488, \
0.146455, 0.146455}, {{71.9375, 126.562}, {186.625, 132}} -> {-10.5356, \
-45.7488, 0.146455, 0.146455}, {{132, 186.625}, {186.625, 132}} -> {-19.332, \
-45.7488, 0.146455, 0.146455}, {{192.125, 246.75}, {186.625, 132}} -> \
{-28.1376, -45.7488, 0.146455, 0.146455}, {{252.188, 306.812}, {186.625, 132}}
   -> {-36.934, -45.7488, 0.146455, 0.146455}, {{312.312, 366.938}, {186.625, \
132}} -> {-45.7396, -45.7488, 0.146455, 0.146455}, {{372.375, 427}, {186.625, \
132}} -> {-54.5361, -45.7488, 0.146455, 0.146455}, {{432.438, 487.062}, \
{186.625, 132}} -> {-63.3325, -45.7488, 0.146455, 0.146455}, {{11.875, 66.5}, \
{126.562, 71.9375}} -> {-1.73919, -54.5452, 0.146455, 0.146455}, {{71.9375, \
126.562}, {126.562, 71.9375}} -> {-10.5356, -54.5452, 0.146455, 0.146455}, \
{{132, 186.625}, {126.562, 71.9375}} -> {-19.332, -54.5452, 0.146455, \
0.146455}, {{192.125, 246.75}, {126.562, 71.9375}} -> {-28.1376, -54.5452, \
0.146455, 0.146455}, {{252.188, 306.812}, {126.562, 71.9375}} -> {-36.934, \
-54.5452, 0.146455, 0.146455}, {{312.312, 366.938}, {126.562, 71.9375}} -> \
{-45.7396, -54.5452, 0.146455, 0.146455}, {{372.375, 427}, {126.562, \
71.9375}} -> {-54.5361, -54.5452, 0.146455, 0.146455}, {{432.438, 487.062}, \
{126.562, 71.9375}} -> {-63.3325, -54.5452, 0.146455, 0.146455}, {{11.875, \
66.5}, {66.5, 11.875}} -> {-1.73919, -63.3416, 0.146455, 0.146455}, \
{{71.9375, 126.562}, {66.5, 11.875}} -> {-10.5356, -63.3416, 0.146455, \
0.146455}, {{132, 186.625}, {66.5, 11.875}} -> {-19.332, -63.3416, 0.146455, \
0.146455}, {{192.125, 246.75}, {66.5, 11.875}} -> {-28.1376, -63.3416, \
0.146455, 0.146455}, {{252.188, 306.812}, {66.5, 11.875}} -> {-36.934, \
-63.3416, 0.146455, 0.146455}, {{312.312, 366.938}, {66.5, 11.875}} -> \
{-45.7396, -63.3416, 0.146455, 0.146455}, {{372.375, 427}, {66.5, 11.875}} -> \
{-54.5361, -63.3416, 0.146455, 0.146455}, {{432.438, 487.062}, {66.5, \
11.875}} -> {-63.3325, -63.3416, 0.146455, 0.146455}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C420C32
0318112D
001B0A12
4CFF0D68
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
300E0823
432B1A00
83FFF94C
57311F23
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4091513E
00FF0357
005A2213
3A4C3329
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A247035
0054945F
26535543
9B70FF8F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E561D31
269179C7
0978B8FF
2C100005
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2DC9FF59
30675F25
41624700
0F7C4E0F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
032F400D
1D0D561E
0D04AA3E
00E82BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
650B040A
6F36250F
1A13000F
FF17435E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00023124
07022A14
0E072107
182AFF39
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17131900
A2FF9A25
39360A08
41383125
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
004891FF
0000307A
33080F24
086B8AE0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
271C6BE7
813E438E
53004991
313DFF5A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
502B0D16
548A092C
68FF329C
1C002028
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
001B410A
2507FFBD
283A4228
2C440E40
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFEF4300
2582282C
24307D3A
70450D49
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6A541214
7437130B
3B250027
49FF1E35
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8E140804
221A110B
1A0B001D
FF131308
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
01021B40
004C1D3D
B7FF100A
2F5F2321
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
22613FFF
00284082
1C332020
291C2742
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
54283100
3E481817
7D04251B
008AFF23
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B120A21
0702135E
002F3EFF
1E0B031A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D11FFB6
00102719
29162500
2039301D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19301156
4A390605
3B5E0500
531A99FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D08091A
1731130D
1E5B8A7E
FF472000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3E8EFF1E
1028470C
06001C0A
0A021909
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
912D5628
FF0B4421
63402921
56004F2D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
10002E5C
26071F15
30251428
10254BFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
23540030
2126281A
23AB3517
AD0EFF0F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
480F0001
FF291410
3B150E0D
1A0D101F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4156312F
00ADFF28
481E762F
27232331
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF3A1E00
483B3A41
204330C9
3E521D6A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F733215
2E4D6D27
003D491E
2AFF570C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A3A0502
11120800
14080B03
12FF2608
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
16000106
16484E10
67D4FFA1
0C3B4729
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0BFF1A03
06550006
090D1413
38331F58
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2012AA0E
0D10A013
04004114
9721FF2B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
140F020E
0E032800
2331FF28
100A1E18
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26FFC91A
26103A05
2D000D40
434A3C17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D140A0F
28002012
3014FF11
38222964
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
504C476F
1C0D1735
33170030
FF1F5F3E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1818191E
0C121611
1300132B
1108FF1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A4C2924
E9FF1300
344A2E15
2F1C0964
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A2E24FF
1A021342
1907031E
0C0F002D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
002A3718
1C2228D8
3727384F
1D25FF11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
382D1A0D
15351700
3AFF1E34
1529271A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
09003237
315F95FF
191E1459
68050214
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFB91C32
25031122
0D282A00
4E314B2B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6640263E
15321329
16232E00
D7FF2A7B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
170F1600
0C110E06
2E160A02
FF1A0407
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D1E0D00
311E0D15
FF231219
48412030
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
106D70D9
03378FFF
000978D4
304B2A74
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
13243C1E
1804130C
1A0F0002
40A4FF39
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1506000A
25EF71FF
10121C3B
28221A11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5837FF27
13002800
18271830
13471E17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
11002A2F
05272F1C
092A0E1D
0B354DFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
15050A01
000D2916
0510341C
FF201A49
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
99987A6E
FFB3C1A7
DFBAC6C5
37540070
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
220F0D25
FF19093B
4B2F0B17
0C420004
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
16001711
0F121312
100A0B10
191313FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
12083616
2F310C00
1F143515
2123FF1C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A130019
3A060305
FF20080D
0B141532
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17002E1F
6B33FF16
251B2623
1745192B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF002722
3E2A0F32
1E120707
6F523800
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
012A0912
26000718
13010C3A
62FF3806
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo
3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T
3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI
1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002ooo
ool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nA
TI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola
<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mU
IFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>
o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=
ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>
o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<
30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5A
D@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46oooo
o`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;
2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko
20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Ko
oooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko
;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T92
3_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn
1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]
3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@4
3Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS
8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln
?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0
@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=
oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>
ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>
ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=
ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6oooo
o`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIF
EPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=
3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGo
oooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo
92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`co
FEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`00
2oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@410
3_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM
3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo
3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`
<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`
L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_oo
ool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>
o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>3Pko20P83OlS8b<6ooooo`go@4103_nATI4>
oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46
ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<30`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>
o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o``<30ko@T923_l<30`=oc8b<PGooooo3_l`<30>o`h>
3Pko20P83OlS8b<6ooooo`go@4103_nATI4>oe5AD@go?Shn1_ooool>ocXj>Pgo92@T3_m`L70=ocDe
=@Kooooo3_ln?Sh>oeIFEPgo7AdM3Ola<C46ooooo`ko;Bd]3_o9bLT>ooooo`coFEUI1_ooool>o`<3
0`ko;bl_3_m0@40=o`d=3@Gooooo3_mUIFD>o`/;2`ko10@43Ol:2PX=ooooo`002oooool>o`<30`ko
61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`go
EeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko
<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko
9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ
3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo
3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=
3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA
4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_oo
ool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mW
IfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?
3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006
ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>
oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=
oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd]
;@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`00
00goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemO
G`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=oooo
o`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go
00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@go
NGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGo
oooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo
3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD
3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU
1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002ooo
ool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_oo
ool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7
alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_
Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>
ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=
oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>
oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<3
0`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<3
0`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6oooo
o`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf
=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko
6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Ko
oooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko
3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`<30`ko61PH
3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol00006ooooo`go00003_ooool>o`<30`goEeMG
1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`
3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mFEUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU
3Ol?3`l=ooooo`002oooool>o`<30`ko61PH3_lA4A4=obd];@Gooooo3_m3@d<>ob/[:`ko6QXJ3Ol0
0006ooooo`go00003_ooool>o`<30`goEeMG1_ooool>o`0000goE5AD3_nDU9@=oemOG`Kooooo3_lV
9RH>oi6AT@goNGUi3Oo7alL6ooooo`ko<30`3_mWIfL>oemOG`co9BDU1_ooool>oadM7@ko3@d=3_mF
EUH=oahN7PGooooo3_m_Kfl>ocHf=Pko9BDU3Ol?3`l=ooooo`002oooool>o`0000ko6a/K3_l:2PX=
oa8B4PGooooo3_n3Ph<>ooooo`konOWi3Om<C4`6ooooo`go00003_mJFUX>ob8R8Pgo4a<C1_ooool>
obHV9PgoDe=C3_mEEED=od=3@`Kooooo3_l92@T>ogQhN0go^;Rh4oooool>od51@@koHV9R3_m7AdL<
o`0000Kooooo3_l=3@d>o`@410koZZZZ3Oln?Sh5ooooo`ko6QXJ3_lC4a<>o`0000go3`l?3Oooool0
00_ooooo3_l0000>oa/K6`ko2PX:3OlB4Q85ooooo`koPh>33_ooool>ooWin@goC4a<1_ooool=o`00
00koFUYJ3_lR8R8=oa<C4`Kooooo3_lV9RH=oe=CD`koEEEE3Om3@d<6ooooo`ko2@T93_mhN7P=okRh
^1?ooooo3_m1@D4>of9RHPkoAdM73?l00006ooooo`ko3@d=3_l410@>ojZZZPgo?Shn1Oooool>oaXJ
6Pko4a<C3_l0000=o`l?3`gooooo000;ooooo`ko00003_lK6a/>o`X:2Pgo4Q8B1Oooool>oh>3P`ko
oooo3_oinOT=oda<C0Kooooo3Ol0000>oeYJFPko8R8R3OlC4a<6ooooo`ko9RHV3OmCDe<>oeEEE@go
@d=31_ooool>o`T92@koN7Qh3Onh^;PCooooo`ko@D513_mRHV8>odM7A`co00001_ooool>o`d=3@ko
10@43_nZZZX=ochn?PGooooo3_lJ6QX>oa<C4`ko00003Ol?3`l=ooooo`002oooool>o`0000ko6a/K
3_l:2PX=oa8B4PGooooo3_n3Ph<>ooooo`konOWi3Om<C4`6ooooo`go00003_mJFUX>ob8R8Pgo4a<C
1_ooool>obHV9PgoDe=C3_mEEED=od=3@`Kooooo3_l92@T>ogQhN0go^;Rh4oooool>od51@@koHV9R
3_m7AdL<o`0000Kooooo3_l=3@d>o`@410koZZZZ3Oln?Sh5ooooo`ko6QXJ3_lC4a<>o`0000go3`l?
3Oooool000_ooooo3_l0000>oa/K6`ko2PX:3OlB4Q85ooooo`koPh>33_ooool>ooWin@goC4a<1_oo
ool=o`0000koFUYJ3_lR8R8=oa<C4`Kooooo3_lV9RH=oe=CD`koEEEE3Om3@d<6ooooo`ko2@T93_mh
N7P=okRh^1?ooooo3_m1@D4>of9RHPkoAdM73?l00006ooooo`ko3@d=3_l410@>ojZZZPgo?Shn1Ooo
ool>oaXJ6Pko4a<C3_l0000=o`l?3`gooooo000;ooooo`ko00003_lK6a/>o`X:2Pgo4Q8B1Oooool>
oh>3P`kooooo3_oinOT=oda<C0Kooooo3Ol0000>oeYJFPko8R8R3OlC4a<6ooooo`ko9RHV3OmCDe<>
oeEEE@go@d=31_ooool>o`T92@koN7Qh3Onh^;PCooooo`ko@D513_mRHV8>odM7A`co00001_ooool>
o`d=3@ko10@43_nZZZX=ochn?PGooooo3_lJ6QX>oa<C4`ko00003Ol?3`l=ooooo`002oooool>o`00
00ko6a/K3_l:2PX=oa8B4PGooooo3_n3Ph<>ooooo`konOWi3Om<C4`6ooooo`go00003_mJFUX>ob8R
8Pgo4a<C1_ooool>obHV9PgoDe=C3_mEEED=od=3@`Kooooo3_l92@T>ogQhN0go^;Rh4oooool>od51
@@koHV9R3_m7AdL<o`0000Kooooo3_l=3@d>o`@410koZZZZ3Oln?Sh5ooooo`ko6QXJ3_lC4a<>o`00
00go3`l?3Oooool000_ooooo3_l0000>oa/K6`ko2PX:3OlB4Q85ooooo`koPh>33_ooool>ooWin@go
C4a<1_ooool=o`0000koFUYJ3_lR8R8=oa<C4`Kooooo3_lV9RH=oe=CD`koEEEE3Om3@d<6ooooo`ko
2@T93_mhN7P=okRh^1?ooooo3_m1@D4>of9RHPkoAdM73?l00006ooooo`ko3@d=3_l410@>ojZZZPgo
?Shn1Oooool>oaXJ6Pko4a<C3_l0000=o`l?3`gooooo000;ooooo`ko00003_lK6a/>o`X:2Pgo4Q8B
1Oooool>oh>3P`kooooo3_oinOT=oda<C0Kooooo3Ol0000>oeYJFPko8R8R3OlC4a<6ooooo`ko9RHV
3OmCDe<>oeEEE@go@d=31_ooool>o`T92@koN7Qh3Onh^;PCooooo`ko@D513_mRHV8>odM7A`co0000
1_ooool>o`d=3@ko10@43_nZZZX=ochn?PGooooo3_lJ6QX>oa<C4`ko00003Ol?3`l=ooooo`002ooo
ool>o`0000ko6a/K3_l:2PX=oa8B4PGooooo3_n3Ph<>ooooo`konOWi3Om<C4`6ooooo`go00003_mJ
FUX>ob8R8Pgo4a<C1_ooool>obHV9PgoDe=C3_mEEED=od=3@`Kooooo3_l92@T>ogQhN0go^;Rh4ooo
ool>od51@@koHV9R3_m7AdL<o`0000Kooooo3_l=3@d>o`@410koZZZZ3Oln?Sh5ooooo`ko6QXJ3_lC
4a<>o`0000go3`l?3Oooool000_ooooo3_l0000>oa/K6`ko2PX:3OlB4Q85ooooo`koPh>33_ooool>
ooWin@goC4a<1_ooool=o`0000koFUYJ3_lR8R8=oa<C4`Kooooo3_lV9RH=oe=CD`koEEEE3Om3@d<6
ooooo`ko2@T93_mhN7P=okRh^1?ooooo3_m1@D4>of9RHPkoAdM73?l00006ooooo`ko3@d=3_l410@>
ojZZZPgo?Shn1Oooool>oaXJ6Pko4a<C3_l0000=o`l?3`gooooo000;ooooo`ko00003_lK6a/>o`X:
2Pgo4Q8B1Oooool>oh>3P`kooooo3_oinOT=oda<C0Kooooo3Ol0000>oeYJFPko8R8R3OlC4a<6oooo
o`ko9RHV3OmCDe<>oeEEE@go@d=31_ooool>o`T92@koN7Qh3Onh^;PCooooo`ko@D513_mRHV8>odM7
A`co00001_ooool>o`d=3@ko10@43_nZZZX=ochn?PGooooo3_lJ6QX>oa<C4`ko00003Ol?3`l=oooo
o`002oooool>o`0000ko6a/K3_l:2PX=oa8B4PGooooo3_n3Ph<>ooooo`konOWi3Om<C4`6ooooo`go
00003_mJFUX>ob8R8Pgo4a<C1_ooool>obHV9PgoDe=C3_mEEED=od=3@`Kooooo3_l92@T>ogQhN0go
^;Rh4oooool>od51@@koHV9R3_m7AdL<o`0000Kooooo3_l=3@d>o`@410koZZZZ3Oln?Sh5ooooo`ko
6QXJ3_lC4a<>o`0000go3`l?3Oooool000_ooooo3_l0000>oa/K6`ko2PX:3OlB4Q85ooooo`koPh>3
3_ooool>ooWin@goC4a<1_ooool=o`0000koFUYJ3_lR8R8=oa<C4`Kooooo3_lV9RH=oe=CD`koEEEE
3Om3@d<6ooooo`ko2@T93_mhN7P=okRh^1?ooooo3_m1@D4>of9RHPkoAdM73?l00006ooooo`ko3@d=
3_l410@>ojZZZPgo?Shn1Oooool>oaXJ6Pko4a<C3_l0000=o`l?3`gooooo000;ooooo`koC4a<3_oo
ool>o`d=3@goJ6QX1Oooool>oeMGE`ko<C4a3_lO7al=ob<S8`Kooooo3Olj>SX>oda<C0ko<c<c3OlY
:BT6ooooo`koVi^K3Om`L70>ooooo`goShn?1_ooool>ob`/;0ko410@3Ol0000=o`D51@Kooooo3_l?
3`l>ogalO0koCTi>3?l?3`l6ooooo`ko00003_oXj>P>ob/[:b3ooooo3_lG5aL>od=3@`goGUiN3Ooo
ool000_ooooo3_m<C4`>ooooo`ko3@d=3OmXJ6P5ooooo`koEeMG3_la<C4>oalO7`go8b<S1_ooool=
ocXj>PkoC4a<3_lc<c<=obTY:@Kooooo3_nKVi/=og1`L0kooooo3On?Shl6ooooo`ko;2`/3_l@410=
o`0000go1@D51_ooool>o`l?3`koO7al3_m>CTh<o`l?3`Kooooo3_l0000>onSXj0ko:b/[8?ooool>
oaLG5`ko@d=33OmNGUh=ooooo`002oooool>oda<C0kooooo3_l=3@d=ofQXJ0Gooooo3_mGEeL>oc4a
<@ko7alO3OlS8b<6ooooo`go>SXj3_m<C4`>oc<c<`go:BTY1_ooool>oi^KV`goL71`3_ooool=ohn?
S`Kooooo3_l/;2`>oa0@40go00003Ol51@D6ooooo`ko3`l?3_mlO7`>odi>CPco3`l?1_ooool>o`00
00koj>SX3_l[:b/Pooooo`ko5aLG3_m3@d<=oeiNGPgooooo000;ooooo`koC4a<3_ooool>o`d=3@go
J6QX1Oooool>oeMGE`ko<C4a3_lO7al=ob<S8`Kooooo3Olj>SX>oda<C0ko<c<c3OlY:BT6ooooo`ko
Vi^K3Om`L70>ooooo`goShn?1_ooool>ob`/;0ko410@3Ol0000=o`D51@Kooooo3_l?3`l>ogalO0ko
CTi>3?l?3`l6ooooo`ko00003_oXj>P>ob/[:b3ooooo3_lG5aL>od=3@`goGUiN3Oooool000_ooooo
3_m<C4`>ooooo`ko3@d=3OmXJ6P5ooooo`koEeMG3_la<C4>oalO7`go8b<S1_ooool=ocXj>PkoC4a<
3_lc<c<=obTY:@Kooooo3_nKVi/=og1`L0kooooo3On?Shl6ooooo`ko;2`/3_l@410=o`0000go1@D5
1_ooool>o`l?3`koO7al3_m>CTh<o`l?3`Kooooo3_l0000>onSXj0ko:b/[8?ooool>oaLG5`ko@d=3
3OmNGUh=ooooo`002oooool>oda<C0kooooo3_l=3@d=ofQXJ0Gooooo3_mGEeL>oc4a<@ko7alO3OlS
8b<6ooooo`go>SXj3_m<C4`>oc<c<`go:BTY1_ooool>oi^KV`goL71`3_ooool=ohn?S`Kooooo3_l/
;2`>oa0@40go00003Ol51@D6ooooo`ko3`l?3_mlO7`>odi>CPco3`l?1_ooool>o`0000koj>SX3_l[
:b/Pooooo`ko5aLG3_m3@d<=oeiNGPgooooo000;ooooo`koC4a<3_ooool>o`d=3@goJ6QX1Oooool>
oeMGE`ko<C4a3_lO7al=ob<S8`Kooooo3Olj>SX>oda<C0ko<c<c3OlY:BT6ooooo`koVi^K3Om`L70>
ooooo`goShn?1_ooool>ob`/;0ko410@3Ol0000=o`D51@Kooooo3_l?3`l>ogalO0koCTi>3?l?3`l6
ooooo`ko00003_oXj>P>ob/[:b3ooooo3_lG5aL>od=3@`goGUiN3Oooool000_ooooo3_m<C4`>oooo
o`ko3@d=3OmXJ6P5ooooo`koEeMG3_la<C4>oalO7`go8b<S1_ooool=ocXj>PkoC4a<3_lc<c<=obTY
:@Kooooo3_nKVi/=og1`L0kooooo3On?Shl6ooooo`ko;2`/3_l@410=o`0000go1@D51_ooool>o`l?
3`koO7al3_m>CTh<o`l?3`Kooooo3_l0000>onSXj0ko:b/[8?ooool>oaLG5`ko@d=33OmNGUh=oooo
o`002oooool>oda<C0kooooo3_l=3@d=ofQXJ0Gooooo3_mGEeL>oc4a<@ko7alO3OlS8b<6ooooo`go
>SXj3_m<C4`>oc<c<`go:BTY1_ooool>oi^KV`goL71`3_ooool=ohn?S`Kooooo3_l/;2`>oa0@40go
00003Ol51@D6ooooo`ko3`l?3_mlO7`>odi>CPco3`l?1_ooool>o`0000koj>SX3_l[:b/Pooooo`ko
5aLG3_m3@d<=oeiNGPgooooo000;ooooo`koC4a<3_ooool>o`d=3@goJ6QX1Oooool>oeMGE`ko<C4a
3_lO7al=ob<S8`Kooooo3Olj>SX>oda<C0ko<c<c3OlY:BT6ooooo`koVi^K3Om`L70>ooooo`goShn?
1_ooool>ob`/;0ko410@3Ol0000=o`D51@Kooooo3_l?3`l>ogalO0koCTi>3?l?3`l6ooooo`ko0000
3_oXj>P>ob/[:b3ooooo3_lG5aL>od=3@`goGUiN3Oooool000_ooooo3_m<C4`>ooooo`ko3@d=3OmX
J6P5ooooo`koEeMG3_la<C4>oalO7`go8b<S1_ooool=ocXj>PkoC4a<3_lc<c<=obTY:@Kooooo3_nK
Vi/=og1`L0kooooo3On?Shl6ooooo`ko;2`/3_l@410=o`0000go1@D51_ooool>o`l?3`koO7al3_m>
CTh<o`l?3`Kooooo3_l0000>onSXj0ko:b/[8?ooool>oaLG5`ko@d=33OmNGUh=ooooo`002oooool>
oda<C0kooooo3_l=3@d=ofQXJ0Gooooo3_mGEeL>oc4a<@ko7alO3OlS8b<6ooooo`go>SXj3_m<C4`>
oc<c<`go:BTY1_ooool>oi^KV`goL71`3_ooool=ohn?S`Kooooo3_l/;2`>oa0@40go00003Ol51@D6
ooooo`ko3`l?3_mlO7`>odi>CPco3`l?1_ooool>o`0000koj>SX3_l[:b/Pooooo`ko5aLG3_m3@d<=
oeiNGPgooooo000;ooooo`koC4a<3_ooool>o`d=3@goJ6QX1Oooool>oeMGE`ko<C4a3_lO7al=ob<S
8`Kooooo3Olj>SX>oda<C0ko<c<c3OlY:BT6ooooo`koVi^K3Om`L70>ooooo`goShn?1_ooool>ob`/
;0ko410@3Ol0000=o`D51@Kooooo3_l?3`l>ogalO0koCTi>3?l?3`l6ooooo`ko00003_oXj>P>ob/[
:b3ooooo3_lG5aL>od=3@`goGUiN3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo3_l0000>o`820Pko<C4a
3OlT92@5ooooo`ko5aLG3_lC4a<>oaTI6@go00001_ooool=o`0000koB4Q83_nATI4Cooooo`ko9bLW
3OlL71`>of][J`goinOW1_ooool>oe1@D0ko:b/[3Ol=3@d=oaHF5PKooooo3_l0000>oa/K6`ko@D51
3?l:2PXDooooo`kokno_3_m3@d<=o`0000Gooooo3_mZJVX>oeADE0ko4Q8B3OlD51@=ooooo`002ooo
ool>o`0000ko0P823_la<C4=ob@T90Gooooo3_lG5aL>oa<C4`ko6ATI3Ol00006ooooo`go00003_m8
B4P>oi6ATA?ooooo3_lW9bL=oa`L70koJf][3OoWinL6ooooo`koD51@3_l[:b/=o`d=3@go5QHF1_oo
ool>o`0000ko6a/K3_m1@D4<o`X:2QCooooo3_o_knl>od=3@`go00001Oooool>ofYZJPkoE5AD3_lB
4Q8=oa@D50gooooo000;ooooo`ko00003_l20P8>oc4a<@go92@T1Oooool>oaLG5`ko4a<C3_lI6AT=
o`0000Kooooo3Ol0000>odQ8B0koTI6A4oooool>obLW9`go71`L3_m[Jf/=onOWi`Kooooo3_m@D50>
ob/[:`go3@d=3OlF5QH6ooooo`ko00003_lK6a/>od51@@co2PX:5?ooool>ono_k`ko@d=33Ol00005
ooooo`koJVYZ3_mDE5@>oa8B4Pgo51@D3Oooool000_ooooo3_l0000>o`820Pko<C4a3OlT92@5oooo
o`ko5aLG3_lC4a<>oaTI6@go00001_ooool=o`0000koB4Q83_nATI4Cooooo`ko9bLW3OlL71`>of][
J`goinOW1_ooool>oe1@D0ko:b/[3Ol=3@d=oaHF5PKooooo3_l0000>oa/K6`ko@D513?l:2PXDoooo
o`kokno_3_m3@d<=o`0000Gooooo3_mZJVX>oeADE0ko4Q8B3OlD51@=ooooo`002oooool>o`0000ko
0P823_la<C4=ob@T90Gooooo3_lG5aL>oa<C4`ko6ATI3Ol00006ooooo`go00003_m8B4P>oi6ATA?o
oooo3_lW9bL=oa`L70koJf][3OoWinL6ooooo`koD51@3_l[:b/=o`d=3@go5QHF1_ooool>o`0000ko
6a/K3_m1@D4<o`X:2QCooooo3_o_knl>od=3@`go00001Oooool>ofYZJPkoE5AD3_lB4Q8=oa@D50go
oooo000;ooooo`ko00003_l20P8>oc4a<@go92@T1Oooool>oaLG5`ko4a<C3_lI6AT=o`0000Kooooo
3Ol0000>odQ8B0koTI6A4oooool>obLW9`go71`L3_m[Jf/=onOWi`Kooooo3_m@D50>ob/[:`go3@d=
3OlF5QH6ooooo`ko00003_lK6a/>od51@@co2PX:5?ooool>ono_k`ko@d=33Ol00005ooooo`koJVYZ
3_mDE5@>oa8B4Pgo51@D3Oooool000_ooooo3_l0000>o`820Pko<C4a3OlT92@5ooooo`ko5aLG3_lC
4a<>oaTI6@go00001_ooool=o`0000koB4Q83_nATI4Cooooo`ko9bLW3OlL71`>of][J`goinOW1_oo
ool>oe1@D0ko:b/[3Ol=3@d=oaHF5PKooooo3_l0000>oa/K6`ko@D513?l:2PXDooooo`kokno_3_m3
@d<=o`0000Gooooo3_mZJVX>oeADE0ko4Q8B3OlD51@=ooooo`002oooool>o`0000ko0P823_la<C4=
ob@T90Gooooo3_lG5aL>oa<C4`ko6ATI3Ol00006ooooo`go00003_m8B4P>oi6ATA?ooooo3_lW9bL=
oa`L70koJf][3OoWinL6ooooo`koD51@3_l[:b/=o`d=3@go5QHF1_ooool>o`0000ko6a/K3_m1@D4<
o`X:2QCooooo3_o_knl>od=3@`go00001Oooool>ofYZJPkoE5AD3_lB4Q8=oa@D50gooooo000;oooo
o`ko00003_l20P8>oc4a<@go92@T1Oooool>oaLG5`ko4a<C3_lI6AT=o`0000Kooooo3Ol0000>odQ8
B0koTI6A4oooool>obLW9`go71`L3_m[Jf/=onOWi`Kooooo3_m@D50>ob/[:`go3@d=3OlF5QH6oooo
o`ko00003_lK6a/>od51@@co2PX:5?ooool>ono_k`ko@d=33Ol00005ooooo`koJVYZ3_mDE5@>oa8B
4Pgo51@D3Oooool000_ooooo3_l0000>o`820Pko<C4a3OlT92@5ooooo`ko5aLG3_lC4a<>oaTI6@go
00001_ooool=o`0000koB4Q83_nATI4Cooooo`ko9bLW3OlL71`>of][J`goinOW1_ooool>oe1@D0ko
:b/[3Ol=3@d=oaHF5PKooooo3_l0000>oa/K6`ko@D513?l:2PXDooooo`kokno_3_m3@d<=o`0000Go
oooo3_mZJVX>oeADE0ko4Q8B3OlD51@=ooooo`002oooool>o`0000ko0P823_la<C4=ob@T90Gooooo
3_lG5aL>oa<C4`ko6ATI3Ol00006ooooo`go00003_m8B4P>oi6ATA?ooooo3_lW9bL=oa`L70koJf][
3OoWinL6ooooo`koD51@3_l[:b/=o`d=3@go5QHF1_ooool>o`0000ko6a/K3_m1@D4<o`X:2QCooooo
3_o_knl>od=3@`go00001Oooool>ofYZJPkoE5AD3_lB4Q8=oa@D50gooooo000;ooooo`ko00003_l2
0P8>oc4a<@go92@T1Oooool>oaLG5`ko4a<C3_lI6AT=o`0000Kooooo3Ol0000>odQ8B0koTI6A4ooo
ool>obLW9`go71`L3_m[Jf/=onOWi`Kooooo3_m@D50>ob/[:`go3@d=3OlF5QH6ooooo`ko00003_lK
6a/>od51@@co2PX:5?ooool>ono_k`ko@d=33Ol00005ooooo`koJVYZ3_mDE5@>oa8B4Pgo51@D3Ooo
ool000_ooooo3_l0000>o`820Pko<C4a3OlT92@5ooooo`ko5aLG3_lC4a<>oaTI6@go00001_ooool=
o`0000koB4Q83_nATI4Cooooo`ko9bLW3OlL71`>of][J`goinOW1_ooool>oe1@D0ko:b/[3Ol=3@d=
oaHF5PKooooo3_l0000>oa/K6`ko@D513?l:2PXDooooo`kokno_3_m3@d<=o`0000Gooooo3_mZJVX>
oeADE0ko4Q8B3OlD51@=ooooo`002oooool>o`0000ko0P823_la<C4=ob@T90Gooooo3_lG5aL>oa<C
4`ko6ATI3Ol00006ooooo`go00003_m8B4P>oi6ATA?ooooo3_lW9bL=oa`L70koJf][3OoWinL6oooo
o`koD51@3_l[:b/=o`d=3@go5QHF1_ooool>o`0000ko6a/K3_m1@D4<o`X:2QCooooo3_o_knl>od=3
@`go00001Oooool>ofYZJPkoE5AD3_lB4Q8=oa@D50gooooo000;ooooo`ko1`L73_l20P8>obXZ:Pgo
51@D1Oooool>oj:RXPkooooo3_nJVYX=obDU9@Kooooo6ol0000>oc0`<0goNWYj1_ooool>oh61P@go
?Shn3_m3@d<=ohj>SPKooooo3_mDE5@>ohZ:RPgo2@T93Ol/;2`6ooooo`ko9BDU3_l71`L>ooooo`co
_Kfm1_ooool>obDU9@koPX:23_lX:2P=ob`/;0Gooooo3_mdM7@>ocLg=`ko4a<C3Ol;2`/=ooooo`00
2oooool>o`L71`ko0P823_lZ:RX=oa@D50Gooooo3_nRXZ8>ooooo`koVYZJ3OlU9BD6oooooa_o0000
3_l`<30=ogYjNPKooooo3_n1PH4=ochn?Pko@d=33On>SXh6ooooo`koE5AD3_n:RXX=o`T92@go;2`/
1_ooool>obDU9@ko1`L73_ooool<okfm_@Kooooo3_lU9BD>oh:2PPko:2PX3Ol/;2`5ooooo`koM7Ad
3_lg=cL>oa<C4`go2`/;3Oooool000_ooooo3_l71`L>o`820Pko:RXZ3OlD51@5ooooo`koXZ:R3_oo
ool>oiZJVPgo9BDU1_oooolKo`0000ko<30`3OmjNWX6ooooo`koPH613Oln?Sh>od=3@`goSXj>1_oo
ool>oeADE0koRXZ:3Ol92@T=ob`/;0Kooooo3_lU9BD>o`L71`kooooo3?nm_Kd6ooooo`ko9BDU3_n2
PX8>obPX:0go;2`/1Oooool>ogAdM0ko=cLg3_lC4a<=o`/;2`gooooo000;ooooo`ko1`L73_l20P8>
obXZ:Pgo51@D1Oooool>oj:RXPkooooo3_nJVYX=obDU9@Kooooo6ol0000>oc0`<0goNWYj1_ooool>
oh61P@go?Shn3_m3@d<=ohj>SPKooooo3_mDE5@>ohZ:RPgo2@T93Ol/;2`6ooooo`ko9BDU3_l71`L>
ooooo`co_Kfm1_ooool>obDU9@koPX:23_lX:2P=ob`/;0Gooooo3_mdM7@>ocLg=`ko4a<C3Ol;2`/=
ooooo`002oooool>o`L71`ko0P823_lZ:RX=oa@D50Gooooo3_nRXZ8>ooooo`koVYZJ3OlU9BD6oooo
oa_o00003_l`<30=ogYjNPKooooo3_n1PH4=ochn?Pko@d=33On>SXh6ooooo`koE5AD3_n:RXX=o`T9
2@go;2`/1_ooool>obDU9@ko1`L73_ooool<okfm_@Kooooo3_lU9BD>oh:2PPko:2PX3Ol/;2`5oooo
o`koM7Ad3_lg=cL>oa<C4`go2`/;3Oooool000_ooooo3_l71`L>o`820Pko:RXZ3OlD51@5ooooo`ko
XZ:R3_ooool>oiZJVPgo9BDU1_oooolKo`0000ko<30`3OmjNWX6ooooo`koPH613Oln?Sh>od=3@`go
SXj>1_ooool>oeADE0koRXZ:3Ol92@T=ob`/;0Kooooo3_lU9BD>o`L71`kooooo3?nm_Kd6ooooo`ko
9BDU3_n2PX8>obPX:0go;2`/1Oooool>ogAdM0ko=cLg3_lC4a<=o`/;2`gooooo000;ooooo`ko1`L7
3_l20P8>obXZ:Pgo51@D1Oooool>oj:RXPkooooo3_nJVYX=obDU9@Kooooo6ol0000>oc0`<0goNWYj
1_ooool>oh61P@go?Shn3_m3@d<=ohj>SPKooooo3_mDE5@>ohZ:RPgo2@T93Ol/;2`6ooooo`ko9BDU
3_l71`L>ooooo`co_Kfm1_ooool>obDU9@koPX:23_lX:2P=ob`/;0Gooooo3_mdM7@>ocLg=`ko4a<C
3Ol;2`/=ooooo`002oooool>o`L71`ko0P823_lZ:RX=oa@D50Gooooo3_nRXZ8>ooooo`koVYZJ3OlU
9BD6oooooa_o00003_l`<30=ogYjNPKooooo3_n1PH4=ochn?Pko@d=33On>SXh6ooooo`koE5AD3_n:
RXX=o`T92@go;2`/1_ooool>obDU9@ko1`L73_ooool<okfm_@Kooooo3_lU9BD>oh:2PPko:2PX3Ol/
;2`5ooooo`koM7Ad3_lg=cL>oa<C4`go2`/;3Oooool000_ooooo3_l71`L>o`820Pko:RXZ3OlD51@5
ooooo`koXZ:R3_ooool>oiZJVPgo9BDU1_oooolKo`0000ko<30`3OmjNWX6ooooo`koPH613Oln?Sh>
od=3@`goSXj>1_ooool>oeADE0koRXZ:3Ol92@T=ob`/;0Kooooo3_lU9BD>o`L71`kooooo3?nm_Kd6
ooooo`ko9BDU3_n2PX8>obPX:0go;2`/1Oooool>ogAdM0ko=cLg3_lC4a<=o`/;2`gooooo000;oooo
o`ko1`L73_l20P8>obXZ:Pgo51@D1Oooool>oj:RXPkooooo3_nJVYX=obDU9@Kooooo6ol0000>oc0`
<0goNWYj1_ooool>oh61P@go?Shn3_m3@d<=ohj>SPKooooo3_mDE5@>ohZ:RPgo2@T93Ol/;2`6oooo
o`ko9BDU3_l71`L>ooooo`co_Kfm1_ooool>obDU9@koPX:23_lX:2P=ob`/;0Gooooo3_mdM7@>ocLg
=`ko4a<C3Ol;2`/=ooooo`002oooool>o`L71`ko0P823_lZ:RX=oa@D50Gooooo3_nRXZ8>ooooo`ko
VYZJ3OlU9BD6oooooa_o00003_l`<30=ogYjNPKooooo3_n1PH4=ochn?Pko@d=33On>SXh6ooooo`ko
E5AD3_n:RXX=o`T92@go;2`/1_ooool>obDU9@ko1`L73_ooool<okfm_@Kooooo3_lU9BD>oh:2PPko
:2PX3Ol/;2`5ooooo`koM7Ad3_lg=cL>oa<C4`go2`/;3Oooool000_ooooo3_l71`L>o`820Pko:RXZ
3OlD51@5ooooo`koXZ:R3_ooool>oiZJVPgo9BDU1_oooolKo`0000ko<30`3OmjNWX6ooooo`koPH61
3Oln?Sh>od=3@`goSXj>1_ooool>oeADE0koRXZ:3Ol92@T=ob`/;0Kooooo3_lU9BD>o`L71`kooooo
3?nm_Kd6ooooo`ko9BDU3_n2PX8>obPX:0go;2`/1Oooool>ogAdM0ko=cLg3_lC4a<=o`/;2`gooooo
000;ooooo`ko1`L73_l20P8>obXZ:Pgo51@D1Oooool>oj:RXPkooooo3_nJVYX=obDU9@Kooooo6ol0
000>oc0`<0goNWYj1_ooool>oh61P@go?Shn3_m3@d<=ohj>SPKooooo3_mDE5@>ohZ:RPgo2@T93Ol/
;2`6ooooo`ko9BDU3_l71`L>ooooo`co_Kfm1_ooool>obDU9@koPX:23_lX:2P=ob`/;0Gooooo3_md
M7@>ocLg=`ko4a<C3Ol;2`/=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>
ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=
oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>
ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>
3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?
3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6oooo
o`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU
9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko
2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Ko
oooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko
<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L7
3_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T
1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX
3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko0000
3OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol8
20P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mX
J6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mm
OGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=
o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>
oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>
od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=
ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6oooo
o`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>oooo
o`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj
>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Go
oooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go
00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco
:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`00
2oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c
3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b
3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo
3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li
>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9
BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_oo
ool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>
o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>
o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6
ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>
obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf
=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6A
T@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T
90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>o`h>3Pko
1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go
92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko
:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko
00003OlW9bL=ooooo`002oooool>o`h>3Pko1`L73_lQ8B4=o`L71`Gooooo3_li>CT>ocHf=Pko2PX:
3Ol820P6ooooo`go<c<c3_l820P>o`l?3`go92@T1_ooool>oe=CD`go00003_m9BDT=oi6AT@Kooooo
3_mXJ6P>ooooo`go<S8b3OnLW9`6ooooo`ko:2PX3_lj>SX>od92@Pco:2PX1_ooool>ob@T90ko<30`
3_mmOGd=ocXj>PGooooo3_lk>c/>obDU9@ko00003OlW9bL=ooooo`002oooool>oaPH60ko:RXZ3_oo
ool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_oo
ool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4
A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole
=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6
ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>
o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=
odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi
>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a
<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>
3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=oooo
o`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go
20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go
820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Go
oooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo
3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm
3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@410
1_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002ooo
ool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[
Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX
:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9
BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>
ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=
oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>
og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH
60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:
RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6oooo
o`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>oooo
o`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko
<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKo
oooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0ko
ADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ
3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P
1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/
3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN
3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU
9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL
71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=
3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`002oooool>oaPH60ko:RXZ3_ooool=
ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6ooooo`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>
oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`0000go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>
o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=
ooooo`002oooool>oaPH60ko:RXZ3_ooool=ocTi>@Gooooo3_m1@D4>ocPh>0ko<C4a3OlU9BD6oooo
o`go20P83_m[Jf/>ohZ:RPgoh>3P1_ooool>oc4a<@go?Cdm3_ooool=oeYJFPKooooo3_lL71`>o`00
00go820P3OlX:2P6ooooo`ko;2`/3_m4A4@>o`h>3Pco@4101_ooool>og1`L0koADE53_l=3@d=odU9
B@Gooooo3_m9BDT>ooooo`ko7QhN3Ole=CD=ooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002ooo
ool>ohj>SPko51@D3_l820P=o`@410Gooooo3_l10@4>o`820Pko6a/K3Om0@406ooooo`go8R8R3_mQ
HF4>oclo?a?ooooo3_mDE5@=obPX:0ko<C4a3Ol00006ooooo`ko6a/K3_lB4Q8=o`X:2Pgo8B4Q1_oo
ool>oadM7@ko4A4A3_ooool<okJf]PKooooo3_lI6AT>oc0`<0ko4A4A3OmFEUH5ooooo`ko7AdM3_l8
20P>o`T92@go6QXJ3Oooool000_ooooo3_n>SXh>oa@D50ko20P83Ol410@5ooooo`ko0@413_l20P8>
oa/K6`go@4101_ooool=ob8R8PkoHF5Q3_lo?clCooooo`koE5AD3OlX:2P>oc4a<@go00001_ooool>
oa/K6`ko4Q8B3Ol:2PX=ob4Q8@Kooooo3_lM7Ad>oa4A4@kooooo3?nf][H6ooooo`ko6ATI3_l`<30>
oa4A4@goEUIF1Oooool>oadM7@ko20P83_l92@T=oaXJ6Pgooooo000;ooooo`koSXj>3_lD51@>o`P8
20go10@41Oooool>o`410@ko0P823_lK6a/=od10@0Kooooo3OlR8R8>of5QH@ko?clo4oooool>oeAD
E0go:2PX3_la<C4=o`0000Kooooo3_lK6a/>oa8B4Pgo2PX:3OlQ8B46ooooo`ko7AdM3_lA4A4>oooo
o`co][Jf1_ooool>oaTI6@ko<30`3_lA4A4=oeIFEPGooooo3_lM7Ad>o`P820ko2@T93OlJ6QX=oooo
o`002oooool>ohj>SPko51@D3_l820P=o`@410Gooooo3_l10@4>o`820Pko6a/K3Om0@406ooooo`go
8R8R3_mQHF4>oclo?a?ooooo3_mDE5@=obPX:0ko<C4a3Ol00006ooooo`ko6a/K3_lB4Q8=o`X:2Pgo
8B4Q1_ooool>oadM7@ko4A4A3_ooool<okJf]PKooooo3_lI6AT>oc0`<0ko4A4A3OmFEUH5ooooo`ko
7AdM3_l820P>o`T92@go6QXJ3Oooool000_ooooo3_n>SXh>oa@D50ko20P83Ol410@5ooooo`ko0@41
3_l20P8>oa/K6`go@4101_ooool=ob8R8PkoHF5Q3_lo?clCooooo`koE5AD3OlX:2P>oc4a<@go0000
1_ooool>oa/K6`ko4Q8B3Ol:2PX=ob4Q8@Kooooo3_lM7Ad>oa4A4@kooooo3?nf][H6ooooo`ko6ATI
3_l`<30>oa4A4@goEUIF1Oooool>oadM7@ko20P83_l92@T=oaXJ6Pgooooo000;ooooo`koSXj>3_lD
51@>o`P820go10@41Oooool>o`410@ko0P823_lK6a/=od10@0Kooooo3OlR8R8>of5QH@ko?clo4ooo
ool>oeADE0go:2PX3_la<C4=o`0000Kooooo3_lK6a/>oa8B4Pgo2PX:3OlQ8B46ooooo`ko7AdM3_lA
4A4>ooooo`co][Jf1_ooool>oaTI6@ko<30`3_lA4A4=oeIFEPGooooo3_lM7Ad>o`P820ko2@T93OlJ
6QX=ooooo`002oooool>ohj>SPko51@D3_l820P=o`@410Gooooo3_l10@4>o`820Pko6a/K3Om0@406
ooooo`go8R8R3_mQHF4>oclo?a?ooooo3_mDE5@=obPX:0ko<C4a3Ol00006ooooo`ko6a/K3_lB4Q8=
o`X:2Pgo8B4Q1_ooool>oadM7@ko4A4A3_ooool<okJf]PKooooo3_lI6AT>oc0`<0ko4A4A3OmFEUH5
ooooo`ko7AdM3_l820P>o`T92@go6QXJ3Oooool000_ooooo3_n>SXh>oa@D50ko20P83Ol410@5oooo
o`ko0@413_l20P8>oa/K6`go@4101_ooool=ob8R8PkoHF5Q3_lo?clCooooo`koE5AD3OlX:2P>oc4a
<@go00001_ooool>oa/K6`ko4Q8B3Ol:2PX=ob4Q8@Kooooo3_lM7Ad>oa4A4@kooooo3?nf][H6oooo
o`ko6ATI3_l`<30>oa4A4@goEUIF1Oooool>oadM7@ko20P83_l92@T=oaXJ6Pgooooo000;ooooo`ko
SXj>3_lD51@>o`P820go10@41Oooool>o`410@ko0P823_lK6a/=od10@0Kooooo3OlR8R8>of5QH@ko
?clo4oooool>oeADE0go:2PX3_la<C4=o`0000Kooooo3_lK6a/>oa8B4Pgo2PX:3OlQ8B46ooooo`ko
7AdM3_lA4A4>ooooo`co][Jf1_ooool>oaTI6@ko<30`3_lA4A4=oeIFEPGooooo3_lM7Ad>o`P820ko
2@T93OlJ6QX=ooooo`002oooool>ohj>SPko51@D3_l820P=o`@410Gooooo3_l10@4>o`820Pko6a/K
3Om0@406ooooo`go8R8R3_mQHF4>oclo?a?ooooo3_mDE5@=obPX:0ko<C4a3Ol00006ooooo`ko6a/K
3_lB4Q8=o`X:2Pgo8B4Q1_ooool>oadM7@ko4A4A3_ooool<okJf]PKooooo3_lI6AT>oc0`<0ko4A4A
3OmFEUH5ooooo`ko7AdM3_l820P>o`T92@go6QXJ3Oooool000_ooooo3_n>SXh>oa@D50ko20P83Ol4
10@5ooooo`ko0@413_l20P8>oa/K6`go@4101_ooool=ob8R8PkoHF5Q3_lo?clCooooo`koE5AD3OlX
:2P>oc4a<@go00001_ooool>oa/K6`ko4Q8B3Ol:2PX=ob4Q8@Kooooo3_lM7Ad>oa4A4@kooooo3?nf
][H6ooooo`ko6ATI3_l`<30>oa4A4@goEUIF1Oooool>oadM7@ko20P83_l92@T=oaXJ6Pgooooo000;
ooooo`koSXj>3_lD51@>o`P820go10@41Oooool>o`410@ko0P823_lK6a/=od10@0Kooooo3OlR8R8>
of5QH@ko?clo4oooool>oeADE0go:2PX3_la<C4=o`0000Kooooo3_lK6a/>oa8B4Pgo2PX:3OlQ8B46
ooooo`ko7AdM3_lA4A4>ooooo`co][Jf1_ooool>oaTI6@ko<30`3_lA4A4=oeIFEPGooooo3_lM7Ad>
o`P820ko2@T93OlJ6QX=ooooo`002oooool>ohj>SPko51@D3_l820P=o`@410Gooooo3_l10@4>o`82
0Pko6a/K3Om0@406ooooo`go8R8R3_mQHF4>oclo?a?ooooo3_mDE5@=obPX:0ko<C4a3Ol00006oooo
o`ko6a/K3_lB4Q8=o`X:2Pgo8B4Q1_ooool>oadM7@ko4A4A3_ooool<okJf]PKooooo3_lI6AT>oc0`
<0ko4A4A3OmFEUH5ooooo`ko7AdM3_l820P>o`T92@go6QXJ3Oooool000_ooooo3_lR8R8>oaXJ6Pko
4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKo
oooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko
410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go
3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm
1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L7
3_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH6
3Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;
2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln
?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW
9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Ooo
ool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=
o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=
oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5
ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5oooo
o`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8
B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI
6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_o
oooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko
:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`go
GUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko
5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko0000
3_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH
3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo
3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR
8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0
@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_oo
ool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la
<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>
oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6
ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>
ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ
6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2
PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`00
00ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C
4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go
?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko
1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko
1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A
3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_ooool=o`0000ko:2PX3_m0@40=oh:2PPKooooo
3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l20P8=oa<C4`goGUiN1_ooool>o`0000ko410@
3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol51@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=
3Oooool000_ooooo3_lR8R8>oaXJ6Pko4A4A3Ol;2`/5ooooo`ko00003_m<C4`>oadM7@go?Cdm1_oo
ool=o`0000ko:2PX3_m0@40=oh:2PPKooooo3_ln?Sh=odQ8B0ko61PH3OlG5aL6ooooo`ko1`L73_l2
0P8=oa<C4`goGUiN1_ooool>o`0000ko410@3_lW9bL<oaTI6@Kooooo3_m:BTX>ocTi>@ko1PH63Ol5
1@D5ooooo`ko5aLG3_la<C4>oa<C4`go3@d=3Oooool000_ooooo3_lJ6QX>o`/;2`ko00003OlM7Ad5
ooooo`ko]kNg3_ooool>oa0@40go2PX:1_ooool=oa`L70ko<c<c6olP8206ooooo`koOGem3Ol410@>
obDU9@go6a/K1_ooool>o`0000ko;bl_3Oln?ShCooooo`ko:BTY3_lF5QH>obDU9@co00001_ooool>
oc/k>`koGUiN3_l51@D=o`0000Gooooo3_lN7Qh>oe]KF`koRXZ:3OmnOWh=ooooo`002oooool>oaXJ
6Pko2`/;3_l0000=oadM7@Gooooo3_ng]kL>ooooo`ko410@3Ol:2PX6ooooo`go71`L3_lc<c<Kob0P
80Kooooo3_mmOGd=o`@410ko9BDU3OlK6a/6ooooo`ko00003_l_;bl=ochn?Q?ooooo3_lY:BT>oaHF
5Pko9BDU3?l00006ooooo`ko>c/k3_mNGUh>o`D51@go00001Oooool>oahN7PkoFe]K3_n:RXX=ogin
OPgooooo000;ooooo`ko6QXJ3_l;2`/>o`0000go7AdM1Oooool>okNg]`kooooo3_l@410=o`X:2PKo
oooo3OlL71`>oc<c<a_o820P1_ooool>ogemO@go10@43_lU9BD=oa/K6`Kooooo3_l0000>obl_;`go
?Shn4oooool>obTY:@ko5QHF3_lU9BD<o`0000Kooooo3_lk>c/>oeiNGPko1@D53Ol00005ooooo`ko
7QhN3_mKFe/>ohZ:RPgoOWin3Oooool000_ooooo3_lJ6QX>o`/;2`ko00003OlM7Ad5ooooo`ko]kNg
3_ooool>oa0@40go2PX:1_ooool=oa`L70ko<c<c6olP8206ooooo`koOGem3Ol410@>obDU9@go6a/K
1_ooool>o`0000ko;bl_3Oln?ShCooooo`ko:BTY3_lF5QH>obDU9@co00001_ooool>oc/k>`koGUiN
3_l51@D=o`0000Gooooo3_lN7Qh>oe]KF`koRXZ:3OmnOWh=ooooo`002oooool>oaXJ6Pko2`/;3_l0
000=oadM7@Gooooo3_ng]kL>ooooo`ko410@3Ol:2PX6ooooo`go71`L3_lc<c<Kob0P80Kooooo3_mm
OGd=o`@410ko9BDU3OlK6a/6ooooo`ko00003_l_;bl=ochn?Q?ooooo3_lY:BT>oaHF5Pko9BDU3?l0
0006ooooo`ko>c/k3_mNGUh>o`D51@go00001Oooool>oahN7PkoFe]K3_n:RXX=oginOPgooooo000;
ooooo`ko6QXJ3_l;2`/>o`0000go7AdM1Oooool>okNg]`kooooo3_l@410=o`X:2PKooooo3OlL71`>
oc<c<a_o820P1_ooool>ogemO@go10@43_lU9BD=oa/K6`Kooooo3_l0000>obl_;`go?Shn4oooool>
obTY:@ko5QHF3_lU9BD<o`0000Kooooo3_lk>c/>oeiNGPko1@D53Ol00005ooooo`ko7QhN3_mKFe/>
ohZ:RPgoOWin3Oooool000_ooooo3_lJ6QX>o`/;2`ko00003OlM7Ad5ooooo`ko]kNg3_ooool>oa0@
40go2PX:1_ooool=oa`L70ko<c<c6olP8206ooooo`koOGem3Ol410@>obDU9@go6a/K1_ooool>o`00
00ko;bl_3Oln?ShCooooo`ko:BTY3_lF5QH>obDU9@co00001_ooool>oc/k>`koGUiN3_l51@D=o`00
00Gooooo3_lN7Qh>oe]KF`koRXZ:3OmnOWh=ooooo`002oooool>oaXJ6Pko2`/;3_l0000=oadM7@Go
oooo3_ng]kL>ooooo`ko410@3Ol:2PX6ooooo`go71`L3_lc<c<Kob0P80Kooooo3_mmOGd=o`@410ko
9BDU3OlK6a/6ooooo`ko00003_l_;bl=ochn?Q?ooooo3_lY:BT>oaHF5Pko9BDU3?l00006ooooo`ko
>c/k3_mNGUh>o`D51@go00001Oooool>oahN7PkoFe]K3_n:RXX=oginOPgooooo000;ooooo`ko6QXJ
3_l;2`/>o`0000go7AdM1Oooool>okNg]`kooooo3_l@410=o`X:2PKooooo3OlL71`>oc<c<a_o820P
1_ooool>ogemO@go10@43_lU9BD=oa/K6`Kooooo3_l0000>obl_;`go?Shn4oooool>obTY:@ko5QHF
3_lU9BD<o`0000Kooooo3_lk>c/>oeiNGPko1@D53Ol00005ooooo`ko7QhN3_mKFe/>ohZ:RPgoOWin
3Oooool000_ooooo3_lJ6QX>o`/;2`ko00003OlM7Ad5ooooo`ko]kNg3_ooool>oa0@40go2PX:1_oo
ool=oa`L70ko<c<c6olP8206ooooo`koOGem3Ol410@>obDU9@go6a/K1_ooool>o`0000ko;bl_3Oln
?ShCooooo`ko:BTY3_lF5QH>obDU9@co00001_ooool>oc/k>`koGUiN3_l51@D=o`0000Gooooo3_lN
7Qh>oe]KF`koRXZ:3OmnOWh=ooooo`002oooool>oaXJ6Pko2`/;3_l0000=oadM7@Gooooo3_ng]kL>
ooooo`ko410@3Ol:2PX6ooooo`go71`L3_lc<c<Kob0P80Kooooo3_mmOGd=o`@410ko9BDU3OlK6a/6
ooooo`ko00003_l_;bl=ochn?Q?ooooo3_lY:BT>oaHF5Pko9BDU3?l00006ooooo`ko>c/k3_mNGUh>
o`D51@go00001Oooool>oahN7PkoFe]K3_n:RXX=oginOPgooooo000;ooooo`ko6QXJ3_l;2`/>o`00
00go7AdM1Oooool>okNg]`kooooo3_l@410=o`X:2PKooooo3OlL71`>oc<c<a_o820P1_ooool>ogem
O@go10@43_lU9BD=oa/K6`Kooooo3_l0000>obl_;`go?Shn4oooool>obTY:@ko5QHF3_lU9BD<o`00
00Kooooo3_lk>c/>oeiNGPko1@D53Ol00005ooooo`ko7QhN3_mKFe/>ohZ:RPgoOWin3Oooool000_o
oooo3_lJ6QX>o`/;2`ko00003OlM7Ad5ooooo`ko]kNg3_ooool>oa0@40go2PX:1_ooool=oa`L70ko
<c<c6olP8206ooooo`koOGem3Ol410@>obDU9@go6a/K1_ooool>o`0000ko;bl_3Oln?ShCooooo`ko
:BTY3_lF5QH>obDU9@co00001_ooool>oc/k>`koGUiN3_l51@D=o`0000Gooooo3_lN7Qh>oe]KF`ko
RXZ:3OmnOWh=ooooo`002oooool>oaXJ6Pko2`/;3_l0000=oadM7@Gooooo3_ng]kL>ooooo`ko410@
3Ol:2PX6ooooo`go71`L3_lc<c<Kob0P80Kooooo3_mmOGd=o`@410ko9BDU3OlK6a/6ooooo`ko0000
3_l_;bl=ochn?Q?ooooo3_lY:BT>oaHF5Pko9BDU3?l00006ooooo`ko>c/k3_mNGUh>o`D51@go0000
1Oooool>oahN7PkoFe]K3_n:RXX=oginOPgooooo000Ioooooaco4a<C3Ol820P5ooooo`ko;bl_3_mO
Gel>ob<S8`go8B4Q1_ooool=obTY:@ko71`L3_lW9bL=od92@PKooooo3_l0000=ohZ:RPkooooo3OlS
8b<6ooooo`ko7QhN3_l;2`/=o`<30`go6QXJ1_ooool>ob0P80ko>CTi3_l`<30<oadM7@Kooooo3_mC
De<>oaXJ6PkoVIVI8?ooool>odM7A`ko820P3Ol0000=ooooo`006OoooolLoa<C4`go20P81Oooool>
obl_;`koGemO3_lS8b<=ob4Q8@Kooooo3OlY:BT>oa`L70ko9bLW3Om2@T86ooooo`ko00003On:RXX>
ooooo`go8b<S1_ooool>oahN7Pko2`/;3Ol30`<=oaXJ6PKooooo3_lP820>ocTi>@ko<30`3?lM7Ad6
ooooo`koDe=C3_lJ6QX>oiVIVB3ooooo3_m7AdL>ob0P80go00003Oooool001Wooooo7?lC4a<=o`P8
20Gooooo3_l_;bl>oemOG`ko8b<S3OlQ8B46ooooo`go:BTY3_lL71`>obLW9`go@T921_ooool>o`00
00goRXZ:3_ooool=ob<S8`Kooooo3_lN7Qh>o`/;2`go0`<33OlJ6QX6ooooo`ko820P3_li>CT>oc0`
<0co7AdM1_ooool>oe=CD`ko6QXJ3_nIVITPooooo`koAdM73_lP820=o`0000gooooo000Ioooooaco
4a<C3Ol820P5ooooo`ko;bl_3_mOGel>ob<S8`go8B4Q1_ooool=obTY:@ko71`L3_lW9bL=od92@PKo
oooo3_l0000=ohZ:RPkooooo3OlS8b<6ooooo`ko7QhN3_l;2`/=o`<30`go6QXJ1_ooool>ob0P80ko
>CTi3_l`<30<oadM7@Kooooo3_mCDe<>oaXJ6PkoVIVI8?ooool>odM7A`ko820P3Ol0000=ooooo`00
6OoooolLoa<C4`go20P81Oooool>obl_;`koGemO3_lS8b<=ob4Q8@Kooooo3OlY:BT>oa`L70ko9bLW
3Om2@T86ooooo`ko00003On:RXX>ooooo`go8b<S1_ooool>oahN7Pko2`/;3Ol30`<=oaXJ6PKooooo
3_lP820>ocTi>@ko<30`3?lM7Ad6ooooo`koDe=C3_lJ6QX>oiVIVB3ooooo3_m7AdL>ob0P80go0000
3Oooool001Wooooo7?lC4a<=o`P820Gooooo3_l_;bl>oemOG`ko8b<S3OlQ8B46ooooo`go:BTY3_lL
71`>obLW9`go@T921_ooool>o`0000goRXZ:3_ooool=ob<S8`Kooooo3_lN7Qh>o`/;2`go0`<33OlJ
6QX6ooooo`ko820P3_li>CT>oc0`<0co7AdM1_ooool>oe=CD`ko6QXJ3_nIVITPooooo`koAdM73_lP
820=o`0000gooooo000Ioooooaco4a<C3Ol820P5ooooo`ko;bl_3_mOGel>ob<S8`go8B4Q1_ooool=
obTY:@ko71`L3_lW9bL=od92@PKooooo3_l0000=ohZ:RPkooooo3OlS8b<6ooooo`ko7QhN3_l;2`/=
o`<30`go6QXJ1_ooool>ob0P80ko>CTi3_l`<30<oadM7@Kooooo3_mCDe<>oaXJ6PkoVIVI8?ooool>
odM7A`ko820P3Ol0000=ooooo`006OoooolLoa<C4`go20P81Oooool>obl_;`koGemO3_lS8b<=ob4Q
8@Kooooo3OlY:BT>oa`L70ko9bLW3Om2@T86ooooo`ko00003On:RXX>ooooo`go8b<S1_ooool>oahN
7Pko2`/;3Ol30`<=oaXJ6PKooooo3_lP820>ocTi>@ko<30`3?lM7Ad6ooooo`koDe=C3_lJ6QX>oiVI
VB3ooooo3_m7AdL>ob0P80go00003Oooool001Wooooo7?lC4a<=o`P820Gooooo3_l_;bl>oemOG`ko
8b<S3OlQ8B46ooooo`go:BTY3_lL71`>obLW9`go@T921_ooool>o`0000goRXZ:3_ooool=ob<S8`Ko
oooo3_lN7Qh>o`/;2`go0`<33OlJ6QX6ooooo`ko820P3_li>CT>oc0`<0co7AdM1_ooool>oe=CD`ko
6QXJ3_nIVITPooooo`koAdM73_lP820=o`0000gooooo000Ioooooaco4a<C3Ol820P5ooooo`ko;bl_
3_mOGel>ob<S8`go8B4Q1_ooool=obTY:@ko71`L3_lW9bL=od92@PKooooo3_l0000=ohZ:RPkooooo
3OlS8b<6ooooo`ko7QhN3_l;2`/=o`<30`go6QXJ1_ooool>ob0P80ko>CTi3_l`<30<oadM7@Kooooo
3_mCDe<>oaXJ6PkoVIVI8?ooool>odM7A`ko820P3Ol0000=ooooo`006OoooolLoa<C4`go20P81Ooo
ool>obl_;`koGemO3_lS8b<=ob4Q8@Kooooo3OlY:BT>oa`L70ko9bLW3Om2@T86ooooo`ko00003On:
RXX>ooooo`go8b<S1_ooool>oahN7Pko2`/;3Ol30`<=oaXJ6PKooooo3_lP820>ocTi>@ko<30`3?lM
7Ad6ooooo`koDe=C3_lJ6QX>oiVIVB3ooooo3_m7AdL>ob0P80go00003Oooool001Wooooo7?lC4a<=
o`P820Gooooo3_l_;bl>oemOG`ko8b<S3OlQ8B46ooooo`go:BTY3_lL71`>obLW9`go@T921_ooool>
o`0000goRXZ:3_ooool=ob<S8`Kooooo3_lN7Qh>o`/;2`go0`<33OlJ6QX6ooooo`ko820P3_li>CT>
oc0`<0co7AdM1_ooool>oe=CD`ko6QXJ3_nIVITPooooo`koAdM73_lP820=o`0000gooooo000Ioooo
oaco4a<C3Ol820P5ooooo`ko;bl_3_mOGel>ob<S8`go8B4Q1_ooool=obTY:@ko71`L3_lW9bL=od92
@PKooooo3_l0000=ohZ:RPkooooo3OlS8b<6ooooo`ko7QhN3_l;2`/=o`<30`go6QXJ1_ooool>ob0P
80ko>CTi3_l`<30<oadM7@Kooooo3_mCDe<>oaXJ6PkoVIVI8?ooool>odM7A`ko820P3Ol0000=oooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`002oooool>ochn?PkoSXj>3_ooool=oahN7PGooooo3_nA
TI4>obd];@koEUIF3OlX:2P6ooooo`go410@3_l0000>obh^;PgoG5aL1_ooool>ob<S8`goE5AD3_l0
000=oc0`<0Kooooo3_m8B4P>o`l?3`go00003Ol10@46ooooo`ko@D513_mFEUH>oc4a<@co;bl_5?oo
ool>ocXj>Pko7QhN3Ol00005ooooo`ko7alO3_mcLg<>oc8b<Pgo5ADE3Oooool000_ooooo3_ln?Sh>
ohj>SPkooooo3OlN7Qh5ooooo`koTI6A3_l];Bd>oeIFEPgo:2PX1_ooool=oa0@40ko00003_l^;Rh=
oeaLG0Kooooo3_lS8b<=oeADE0ko00003Ol`<306ooooo`koB4Q83_l?3`l=o`0000go0@411_ooool>
od51@@koEUIF3_la<C4<obl_;aCooooo3_lj>SX>oahN7Pgo00001Oooool>oalO7`koLg=c3_lb<S8=
oaDE5@gooooo000;ooooo`ko?Shn3_n>SXh>ooooo`go7QhN1Oooool>oi6AT@ko;Bd]3_mFEUH=obPX
:0Kooooo3Ol@410>o`0000ko;Rh^3OmLG5`6ooooo`ko8b<S3OmDE5@>o`0000go<30`1_ooool>odQ8
B0ko3`l?3Ol0000=o`410@Kooooo3_m1@D4>oeIFEPko<C4a3?l_;blDooooo`ko>SXj3_lN7Qh=o`00
00Gooooo3_lO7al>og=cL`ko<S8b3OlE5AD=ooooo`002oooool>ochn?PkoSXj>3_ooool=oahN7PGo
oooo3_nATI4>obd];@koEUIF3OlX:2P6ooooo`go410@3_l0000>obh^;PgoG5aL1_ooool>ob<S8`go
E5AD3_l0000=oc0`<0Kooooo3_m8B4P>o`l?3`go00003Ol10@46ooooo`ko@D513_mFEUH>oc4a<@co
;bl_5?ooool>ocXj>Pko7QhN3Ol00005ooooo`ko7alO3_mcLg<>oc8b<Pgo5ADE3Oooool000_ooooo
3_ln?Sh>ohj>SPkooooo3OlN7Qh5ooooo`koTI6A3_l];Bd>oeIFEPgo:2PX1_ooool=oa0@40ko0000
3_l^;Rh=oeaLG0Kooooo3_lS8b<=oeADE0ko00003Ol`<306ooooo`koB4Q83_l?3`l=o`0000go0@41
1_ooool>od51@@koEUIF3_la<C4<obl_;aCooooo3_lj>SX>oahN7Pgo00001Oooool>oalO7`koLg=c
3_lb<S8=oaDE5@gooooo000;ooooo`ko?Shn3_n>SXh>ooooo`go7QhN1Oooool>oi6AT@ko;Bd]3_mF
EUH=obPX:0Kooooo3Ol@410>o`0000ko;Rh^3OmLG5`6ooooo`ko8b<S3OmDE5@>o`0000go<30`1_oo
ool>odQ8B0ko3`l?3Ol0000=o`410@Kooooo3_m1@D4>oeIFEPko<C4a3?l_;blDooooo`ko>SXj3_lN
7Qh=o`0000Gooooo3_lO7al>og=cL`ko<S8b3OlE5AD=ooooo`002oooool>ochn?PkoSXj>3_ooool=
oahN7PGooooo3_nATI4>obd];@koEUIF3OlX:2P6ooooo`go410@3_l0000>obh^;PgoG5aL1_ooool>
ob<S8`goE5AD3_l0000=oc0`<0Kooooo3_m8B4P>o`l?3`go00003Ol10@46ooooo`ko@D513_mFEUH>
oc4a<@co;bl_5?ooool>ocXj>Pko7QhN3Ol00005ooooo`ko7alO3_mcLg<>oc8b<Pgo5ADE3Oooool0
00_ooooo3_ln?Sh>ohj>SPkooooo3OlN7Qh5ooooo`koTI6A3_l];Bd>oeIFEPgo:2PX1_ooool=oa0@
40ko00003_l^;Rh=oeaLG0Kooooo3_lS8b<=oeADE0ko00003Ol`<306ooooo`koB4Q83_l?3`l=o`00
00go0@411_ooool>od51@@koEUIF3_la<C4<obl_;aCooooo3_lj>SX>oahN7Pgo00001Oooool>oalO
7`koLg=c3_lb<S8=oaDE5@gooooo000;ooooo`ko?Shn3_n>SXh>ooooo`go7QhN1Oooool>oi6AT@ko
;Bd]3_mFEUH=obPX:0Kooooo3Ol@410>o`0000ko;Rh^3OmLG5`6ooooo`ko8b<S3OmDE5@>o`0000go
<30`1_ooool>odQ8B0ko3`l?3Ol0000=o`410@Kooooo3_m1@D4>oeIFEPko<C4a3?l_;blDooooo`ko
>SXj3_lN7Qh=o`0000Gooooo3_lO7al>og=cL`ko<S8b3OlE5AD=ooooo`002oooool>ochn?PkoSXj>
3_ooool=oahN7PGooooo3_nATI4>obd];@koEUIF3OlX:2P6ooooo`go410@3_l0000>obh^;PgoG5aL
1_ooool>ob<S8`goE5AD3_l0000=oc0`<0Kooooo3_m8B4P>o`l?3`go00003Ol10@46ooooo`ko@D51
3_mFEUH>oc4a<@co;bl_5?ooool>ocXj>Pko7QhN3Ol00005ooooo`ko7alO3_mcLg<>oc8b<Pgo5ADE
3Oooool000_ooooo3_ln?Sh>ohj>SPkooooo3OlN7Qh5ooooo`koTI6A3_l];Bd>oeIFEPgo:2PX1_oo
ool=oa0@40ko00003_l^;Rh=oeaLG0Kooooo3_lS8b<=oeADE0ko00003Ol`<306ooooo`koB4Q83_l?
3`l=o`0000go0@411_ooool>od51@@koEUIF3_la<C4<obl_;aCooooo3_lj>SX>oahN7Pgo00001Ooo
ool>oalO7`koLg=c3_lb<S8=oaDE5@gooooo000;ooooo`ko?Shn3_n>SXh>ooooo`go7QhN1Oooool>
oi6AT@ko;Bd]3_mFEUH=obPX:0Kooooo3Ol@410>o`0000ko;Rh^3OmLG5`6ooooo`ko8b<S3OmDE5@>
o`0000go<30`1_ooool>odQ8B0ko3`l?3Ol0000=o`410@Kooooo3_m1@D4>oeIFEPko<C4a3?l_;blD
ooooo`ko>SXj3_lN7Qh=o`0000Gooooo3_lO7al>og=cL`ko<S8b3OlE5AD=ooooo`002oooool>ochn
?PkoSXj>3_ooool=oahN7PGooooo3_nATI4>obd];@koEUIF3OlX:2P6ooooo`go410@3_l0000>obh^
;PgoG5aL1_ooool>ob<S8`goE5AD3_l0000=oc0`<0Kooooo3_m8B4P>o`l?3`go00003Ol10@46oooo
o`ko@D513_mFEUH>oc4a<@co;bl_5?ooool>ocXj>Pko7QhN3Ol00005ooooo`ko7alO3_mcLg<>oc8b
<Pgo5ADE3Oooool000_ooooo3_l@410>obPX:0koAdM73Ol<30`Cooooo`ko2`/;3_m4A4@=ob4Q8@Ko
oooo3OlV9RH>o`L71`ko7alO3OlE5AD6ooooo`ko8B4Q3OlV9RH>obPX:0go6QXJ5?ooool>obTY:@go
51@D3Ol@4106ooooo`ko00003_n][Jd>ooooo`co:2PX1_ooool>odQ8B0ko>c/k3_lj>SX=od51@@Go
oooo3_l^;Rh>ode=C@koKFe]3OlW9bL=ooooo`002oooool>oa0@40ko:2PX3_m7AdL=o``<31?ooooo
3_l;2`/>odA4A0go8B4Q1_ooool=obHV9Pko1`L73_lO7al=oaDE5@Kooooo3_lQ8B4=obHV9Pko:2PX
3OlJ6QXDooooo`ko:BTY3OlD51@=oa0@40Kooooo3_l0000>ojf][@kooooo3?lX:2P6ooooo`koB4Q8
3_lk>c/>ocXj>Pgo@D511Oooool>obh^;PkoCDe=3_m]KFd=obLW9`gooooo000;ooooo`ko410@3_lX
:2P>odM7A`go30`<4oooool>o`/;2`koA4A43OlQ8B46ooooo`go9RHV3_l71`L>oalO7`go5ADE1_oo
ool>ob4Q8@go9RHV3_lX:2P=oaXJ6QCooooo3_lY:BT=oa@D50go410@1_ooool>o`0000ko[Jf]3_oo
ool<obPX:0Kooooo3_m8B4P>oc/k>`ko>SXj3Om1@D45ooooo`ko;Rh^3_m=CDd>ofe]K@go9bLW3Ooo
ool000_ooooo3_l@410>obPX:0koAdM73Ol<30`Cooooo`ko2`/;3_m4A4@=ob4Q8@Kooooo3OlV9RH>
o`L71`ko7alO3OlE5AD6ooooo`ko8B4Q3OlV9RH>obPX:0go6QXJ5?ooool>obTY:@go51@D3Ol@4106
ooooo`ko00003_n][Jd>ooooo`co:2PX1_ooool>odQ8B0ko>c/k3_lj>SX=od51@@Gooooo3_l^;Rh>
ode=C@koKFe]3OlW9bL=ooooo`002oooool>oa0@40ko:2PX3_m7AdL=o``<31?ooooo3_l;2`/>odA4
A0go8B4Q1_ooool=obHV9Pko1`L73_lO7al=oaDE5@Kooooo3_lQ8B4=obHV9Pko:2PX3OlJ6QXDoooo
o`ko:BTY3OlD51@=oa0@40Kooooo3_l0000>ojf][@kooooo3?lX:2P6ooooo`koB4Q83_lk>c/>ocXj
>Pgo@D511Oooool>obh^;PkoCDe=3_m]KFd=obLW9`gooooo000;ooooo`ko410@3_lX:2P>odM7A`go
30`<4oooool>o`/;2`koA4A43OlQ8B46ooooo`go9RHV3_l71`L>oalO7`go5ADE1_ooool>ob4Q8@go
9RHV3_lX:2P=oaXJ6QCooooo3_lY:BT=oa@D50go410@1_ooool>o`0000ko[Jf]3_ooool<obPX:0Ko
oooo3_m8B4P>oc/k>`ko>SXj3Om1@D45ooooo`ko;Rh^3_m=CDd>ofe]K@go9bLW3Oooool000_ooooo
3_l@410>obPX:0koAdM73Ol<30`Cooooo`ko2`/;3_m4A4@=ob4Q8@Kooooo3OlV9RH>o`L71`ko7alO
3OlE5AD6ooooo`ko8B4Q3OlV9RH>obPX:0go6QXJ5?ooool>obTY:@go51@D3Ol@4106ooooo`ko0000
3_n][Jd>ooooo`co:2PX1_ooool>odQ8B0ko>c/k3_lj>SX=od51@@Gooooo3_l^;Rh>ode=C@koKFe]
3OlW9bL=ooooo`002oooool>oa0@40ko:2PX3_m7AdL=o``<31?ooooo3_l;2`/>odA4A0go8B4Q1_oo
ool=obHV9Pko1`L73_lO7al=oaDE5@Kooooo3_lQ8B4=obHV9Pko:2PX3OlJ6QXDooooo`ko:BTY3OlD
51@=oa0@40Kooooo3_l0000>ojf][@kooooo3?lX:2P6ooooo`koB4Q83_lk>c/>ocXj>Pgo@D511Ooo
ool>obh^;PkoCDe=3_m]KFd=obLW9`gooooo000;ooooo`ko410@3_lX:2P>odM7A`go30`<4oooool>
o`/;2`koA4A43OlQ8B46ooooo`go9RHV3_l71`L>oalO7`go5ADE1_ooool>ob4Q8@go9RHV3_lX:2P=
oaXJ6QCooooo3_lY:BT=oa@D50go410@1_ooool>o`0000ko[Jf]3_ooool<obPX:0Kooooo3_m8B4P>
oc/k>`ko>SXj3Om1@D45ooooo`ko;Rh^3_m=CDd>ofe]K@go9bLW3Oooool000_ooooo3_l@410>obPX
:0koAdM73Ol<30`Cooooo`ko2`/;3_m4A4@=ob4Q8@Kooooo3OlV9RH>o`L71`ko7alO3OlE5AD6oooo
o`ko8B4Q3OlV9RH>obPX:0go6QXJ5?ooool>obTY:@go51@D3Ol@4106ooooo`ko00003_n][Jd>oooo
o`co:2PX1_ooool>odQ8B0ko>c/k3_lj>SX=od51@@Gooooo3_l^;Rh>ode=C@koKFe]3OlW9bL=oooo
o`002oooool>oa0@40ko:2PX3_m7AdL=o``<31?ooooo3_l;2`/>odA4A0go8B4Q1_ooool=obHV9Pko
1`L73_lO7al=oaDE5@Kooooo3_lQ8B4=obHV9Pko:2PX3OlJ6QXDooooo`ko:BTY3OlD51@=oa0@40Ko
oooo3_l0000>ojf][@kooooo3?lX:2P6ooooo`koB4Q83_lk>c/>ocXj>Pgo@D511Oooool>obh^;Pko
CDe=3_m]KFd=obLW9`gooooo000;ooooo`ko410@3_lX:2P>odM7A`go30`<4oooool>o`/;2`koA4A4
3OlQ8B46ooooo`go9RHV3_l71`L>oalO7`go5ADE1_ooool>ob4Q8@go9RHV3_lX:2P=oaXJ6QCooooo
3_lY:BT=oa@D50go410@1_ooool>o`0000ko[Jf]3_ooool<obPX:0Kooooo3_m8B4P>oc/k>`ko>SXj
3Om1@D45ooooo`ko;Rh^3_m=CDd>ofe]K@go9bLW3Oooool000_ooooo3_l@410>obPX:0koAdM73Ol<
30`Cooooo`ko2`/;3_m4A4@=ob4Q8@Kooooo3OlV9RH>o`L71`ko7alO3OlE5AD6ooooo`ko8B4Q3OlV
9RH>obPX:0go6QXJ5?ooool>obTY:@go51@D3Ol@4106ooooo`ko00003_n][Jd>ooooo`co:2PX1_oo
ool>odQ8B0ko>c/k3_lj>SX=od51@@Gooooo3_l^;Rh>ode=C@koKFe]3OlW9bL=ooooo`002oooool>
o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>
oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6
ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>
ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10
@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG
5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P
80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko
00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go
:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`ko
B4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@ko
BDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY
3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo
3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=3
3_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL
71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_oo
ool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN
7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN
7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46
ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>
oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=
olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:
2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S
8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIf
MPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=oooo
o`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go
<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go
3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Go
oooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo
3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[
3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_
1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002ooo
ool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU
9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=
3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0
000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>
od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=
oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>
ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H6
1Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D
50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6oooo
o`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm
?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko00003_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko
:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Ko
oooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q83_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko
@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU93OlN7Qh=ooooo`002oooool>o`H61Pko0000
3_lL71`=o`X:2PGooooo3_mSHf<>od10@0ko:BTY3OlQ8B46ooooo`go<30`3_lU9BD>oa@D50go:2PX
1_ooool>ob<S8`goZj^[3_le=CD=oaLG5`Kooooo3_lk>c/>oaDE5@go3Ph>3Ol=3@d6ooooo`koB4Q8
3_lN7Qh>ogIfMPco;bl_1_ooool>ob0P80ko@d=33_l`<30=olW9b@Gooooo3_l0000>ocdm?@koBDU9
3OlN7Qh=ooooo`002oooool>o`X:2Pko0P823_lI6AT=o`T92@Gooooo3_mFEUH>o`0000koCdm?3Ol]
;Bd6ooooo`go410@3_lU9BD>od];Ba?ooooo3_n][Jd=o`h>3Pkooooo3Ol?3`l6ooooo`ko6QXJ3_l=
3@d=oa0@40go7alO1_ooool>obLW9aco8b<S3?la<C46ooooo`ko?Shn3_mBDU8>oadM7@goJVYZ1Ooo
ool>obXZ:Pkooooo3_mGEeL=o``<30gooooo000;ooooo`ko2PX:3_l20P8>oaTI6@go2@T91Oooool>
oeIFEPko00003_m?Cdl=obd];@Kooooo3Ol@410>obDU9@koBd];4oooool>ojf][@go3Ph>3_ooool=
o`l?3`Kooooo3_lJ6QX>o`d=3@go410@3OlO7al6ooooo`ko9bLW7?lS8b<<oc4a<@Kooooo3_ln?Sh>
oe9BDPko7AdM3OmZJVX5ooooo`ko:RXZ3_ooool>oeMGE`go30`<3Oooool000_ooooo3_l:2PX>o`82
0Pko6ATI3Ol92@T5ooooo`koEUIF3_l0000>odm?C`go;Bd]1_ooool=oa0@40ko9BDU3_m;Bd/Coooo
o`ko[Jf]3Ol>3Ph>ooooo`go3`l?1_ooool>oaXJ6Pko3@d=3Ol@410=oalO7`Kooooo3_lW9bLLob<S
8`co<C4a1_ooool>ochn?PkoDU9B3_lM7Ad=ofYZJPGooooo3_lZ:RX>ooooo`koEeMG3Ol<30`=oooo
o`002oooool>o`X:2Pko0P823_lI6AT=o`T92@Gooooo3_mFEUH>o`0000koCdm?3Ol];Bd6ooooo`go
410@3_lU9BD>od];Ba?ooooo3_n][Jd=o`h>3Pkooooo3Ol?3`l6ooooo`ko6QXJ3_l=3@d=oa0@40go
7alO1_ooool>obLW9aco8b<S3?la<C46ooooo`ko?Shn3_mBDU8>oadM7@goJVYZ1Oooool>obXZ:Pko
oooo3_mGEeL=o``<30gooooo000;ooooo`ko2PX:3_l20P8>oaTI6@go2@T91Oooool>oeIFEPko0000
3_m?Cdl=obd];@Kooooo3Ol@410>obDU9@koBd];4oooool>ojf][@go3Ph>3_ooool=o`l?3`Kooooo
3_lJ6QX>o`d=3@go410@3OlO7al6ooooo`ko9bLW7?lS8b<<oc4a<@Kooooo3_ln?Sh>oe9BDPko7AdM
3OmZJVX5ooooo`ko:RXZ3_ooool>oeMGE`go30`<3Oooool000_ooooo3_l:2PX>o`820Pko6ATI3Ol9
2@T5ooooo`koEUIF3_l0000>odm?C`go;Bd]1_ooool=oa0@40ko9BDU3_m;Bd/Cooooo`ko[Jf]3Ol>
3Ph>ooooo`go3`l?1_ooool>oaXJ6Pko3@d=3Ol@410=oalO7`Kooooo3_lW9bLLob<S8`co<C4a1_oo
ool>ochn?PkoDU9B3_lM7Ad=ofYZJPGooooo3_lZ:RX>ooooo`koEeMG3Ol<30`=ooooo`002oooool>
o`X:2Pko0P823_lI6AT=o`T92@Gooooo3_mFEUH>o`0000koCdm?3Ol];Bd6ooooo`go410@3_lU9BD>
od];Ba?ooooo3_n][Jd=o`h>3Pkooooo3Ol?3`l6ooooo`ko6QXJ3_l=3@d=oa0@40go7alO1_ooool>
obLW9aco8b<S3?la<C46ooooo`ko?Shn3_mBDU8>oadM7@goJVYZ1Oooool>obXZ:Pkooooo3_mGEeL=
o``<30gooooo000;ooooo`ko2PX:3_l20P8>oaTI6@go2@T91Oooool>oeIFEPko00003_m?Cdl=obd]
;@Kooooo3Ol@410>obDU9@koBd];4oooool>ojf][@go3Ph>3_ooool=o`l?3`Kooooo3_lJ6QX>o`d=
3@go410@3OlO7al6ooooo`ko9bLW7?lS8b<<oc4a<@Kooooo3_ln?Sh>oe9BDPko7AdM3OmZJVX5oooo
o`ko:RXZ3_ooool>oeMGE`go30`<3Oooool000_ooooo3_l:2PX>o`820Pko6ATI3Ol92@T5ooooo`ko
EUIF3_l0000>odm?C`go;Bd]1_ooool=oa0@40ko9BDU3_m;Bd/Cooooo`ko[Jf]3Ol>3Ph>ooooo`go
3`l?1_ooool>oaXJ6Pko3@d=3Ol@410=oalO7`Kooooo3_lW9bLLob<S8`co<C4a1_ooool>ochn?Pko
DU9B3_lM7Ad=ofYZJPGooooo3_lZ:RX>ooooo`koEeMG3Ol<30`=ooooo`002oooool>o`X:2Pko0P82
3_lI6AT=o`T92@Gooooo3_mFEUH>o`0000koCdm?3Ol];Bd6ooooo`go410@3_lU9BD>od];Ba?ooooo
3_n][Jd=o`h>3Pkooooo3Ol?3`l6ooooo`ko6QXJ3_l=3@d=oa0@40go7alO1_ooool>obLW9aco8b<S
3?la<C46ooooo`ko?Shn3_mBDU8>oadM7@goJVYZ1Oooool>obXZ:Pkooooo3_mGEeL=o``<30gooooo
000;ooooo`ko2PX:3_l20P8>oaTI6@go2@T91Oooool>oeIFEPko00003_m?Cdl=obd];@Kooooo3Ol@
410>obDU9@koBd];4oooool>ojf][@go3Ph>3_ooool=o`l?3`Kooooo3_lJ6QX>o`d=3@go410@3OlO
7al6ooooo`ko9bLW7?lS8b<<oc4a<@Kooooo3_ln?Sh>oe9BDPko7AdM3OmZJVX5ooooo`ko:RXZ3_oo
ool>oeMGE`go30`<3Oooool000_ooooo3_l:2PX>o`820Pko6ATI3Ol92@T5ooooo`koEUIF3_l0000>
odm?C`go;Bd]1_ooool=oa0@40ko9BDU3_m;Bd/Cooooo`ko[Jf]3Ol>3Ph>ooooo`go3`l?1_ooool>
oaXJ6Pko3@d=3Ol@410=oalO7`Kooooo3_lW9bLLob<S8`co<C4a1_ooool>ochn?PkoDU9B3_lM7Ad=
ofYZJPGooooo3_lZ:RX>ooooo`koEeMG3Ol<30`=ooooo`002oooool>o`X:2Pko0P823_lI6AT=o`T9
2@Gooooo3_mFEUH>o`0000koCdm?3Ol];Bd6ooooo`go410@3_lU9BD>od];Ba?ooooo3_n][Jd=o`h>
3Pkooooo3Ol?3`l6ooooo`ko6QXJ3_l=3@d=oa0@40go7alO1_ooool>obLW9aco8b<S3?la<C46oooo
o`ko?Shn3_mBDU8>oadM7@goJVYZ1Oooool>obXZ:Pkooooo3_mGEeL=o``<30gooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l1
0@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_oo
ool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD
51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>
o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6
ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>
ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=
ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H6
1PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D
50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:
2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go
0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko
820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`ko
bLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`go
oooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo
3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?
3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?
1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Ooo
ool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB
4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ
6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;
ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>
ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=
o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>
oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF
5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZ
ZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6oooo
o`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko
6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko
6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKo
oooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0ko
C4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko0000
3_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>
1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM
3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj
>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol3
0`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV
9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7
AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D51@go0P821Oooool>oaHF5Pko00003_l10@4=
o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6ooooo`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>
oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>ooooo`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>
o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_K`gooooo000;ooooo`ko6QXJ3_lj>SX>o`D5
1@go0P821Oooool>oaHF5Pko00003_l10@4=o`H61PKooooo3Ol;2`/>ooooo`ko6QXJ3Ol30`<6oooo
o`ko820P3OlB4Q8>ojZZZPgo3Ph>1_ooool>oa@D50ko3`l?3Ol20P8=o`h>3PKooooo3_lV9RH>oooo
o`kobLW93?lJ6QX6ooooo`ko7AdM3_lD51@>o`X:2Pgo3`l?1Oooool>oe1@D0koC4a<3_m7AdL=ofm_
K`gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Ko
oooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko
0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go
4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go0000
1Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=
3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj
3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo
000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol6
1PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX
:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Ooo
ool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>
oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>
oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6
ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;oooo
o`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEE
E@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`00
00Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L
70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5Pko
B4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go
4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko
:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A
3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko0000
3Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo
3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=
3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>
CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_oo
ool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0
000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>
o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6
ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>
oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=
ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@
40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>
3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P
80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go
00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko
3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko
>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@go
oooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo
3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<3
3OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B
1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko4A4A3_lB4Q8>o`P820go00001Ooo
ool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@
410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l5
1@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;
ooooo`ko4A4A3_lB4Q8>o`P820go00001Oooool>oaHF5PkoB4Q83_m>CTh=oa0@40Kooooo3Ol61PH>
oeEEE@ko00003Ol61PH6ooooo`ko3@d=3Ol@410>oj2PX0go4a<C1_ooool>o`h>3Pko0`<33OlX:2P=
o`0000Kooooo3_lV9RH>oa0@40ko>SXj3?l51@D6ooooo`ko:2PX3_l0000>ob0P80go4Q8B1Oooool>
oa`L70ko3@d=3_lG5aL=ocDe=@gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMW
I`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51
@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406oooo
o`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko
51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko
51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Ko
oooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko
5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD
3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D
1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`
3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l8
20P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC
4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l]
;Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0
000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=
oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>
ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>
ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;
2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6oooo
o`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`00
00ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`
<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Ko
oooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko
<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go
4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<3
1Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@4
3Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=
3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo
000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol9
2@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Ooo
ool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Ooo
ool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>
ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>
od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406
ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;oooo
o`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=
3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX
:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c
<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D3_l820P>o`/;2`go0`<31Oooool>ofMWI`ko
e=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D3OlC4a<6ooooo`ko10@43Ol0000>od51@@go
51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko
<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG3_l0000=oc0`<0gooooo000;ooooo`ko51@D
3_l820P>o`/;2`go0`<31Oooool>ofMWI`koe=CD3_ooool=oj6QX@Kooooo3Ol92@T>o`d=3@ko51@D
3OlC4a<6ooooo`ko10@43Ol0000>od51@@go51@D1_ooool>ob<S8`ko<C4a3Oooool=obPX:0Kooooo
3_l];Bd>o`0000ko3@d=3?m0@406ooooo`ko<30`3_lD51@>ooooo`go4A4A1Oooool>oc<c<`ko5aLG
3_l0000=oc0`<0gooooo000;ooooo`ko4Q8B3_ooool>obHV9Pgo20P81Oooool>o``<30ko>c/k3_m7
AdL=obTY:@Kooooo3Olh>3P>oc<c<`ko7alO3OmHF5P6ooooo`koUiNG3OlQ8B4>ooooo`go:b/[1_oo
ool>oa0@40ko2PX:3OlN7Qh=oaPH60Kooooo3_m3@d<>odY:BPko?3`l3?lG5aL6ooooo`ko>3Ph3_lR
8R8>obTY:@goI6AT4oooool>oalO7`koGemO3Oln?Sh=ooooo`002oooool>oa8B4Pkooooo3_lV9RH=
o`P820Gooooo3_l<30`>oc/k>`koAdM73OlY:BT6ooooo`go>3Ph3_lc<c<>oalO7`goF5QH1_ooool>
oiNGU`go8B4Q3_ooool=ob/[:`Kooooo3_l@410>o`X:2Pgo7QhN3OlH61P6ooooo`ko@d=33_m:BTX>
oc`l?0co5aLG1_ooool>ocPh>0ko8R8R3_lY:BT=ofATI1?ooooo3_lO7al>oemOG`go?Shn3Oooool0
00_ooooo3_lB4Q8>ooooo`ko9RHV3Ol820P5ooooo`ko30`<3_lk>c/>odM7A`go:BTY1_ooool=ocPh
>0ko<c<c3_lO7al=oeQHF0Kooooo3_nGUiL=ob4Q8@kooooo3Ol[:b/6ooooo`ko410@3_l:2PX=oahN
7Pgo61PH1_ooool>od=3@`koBTY:3_ll?3`<oaLG5`Kooooo3_lh>3P>ob8R8Pko:BTY3OmTI6@Coooo
o`ko7alO3_mOGel=ochn?Pgooooo000;ooooo`ko4Q8B3_ooool>obHV9Pgo20P81Oooool>o``<30ko
>c/k3_m7AdL=obTY:@Kooooo3Olh>3P>oc<c<`ko7alO3OmHF5P6ooooo`koUiNG3OlQ8B4>ooooo`go
:b/[1_ooool>oa0@40ko2PX:3OlN7Qh=oaPH60Kooooo3_m3@d<>odY:BPko?3`l3?lG5aL6ooooo`ko
>3Ph3_lR8R8>obTY:@goI6AT4oooool>oalO7`koGemO3Oln?Sh=ooooo`002oooool>oa8B4Pkooooo
3_lV9RH=o`P820Gooooo3_l<30`>oc/k>`koAdM73OlY:BT6ooooo`go>3Ph3_lc<c<>oalO7`goF5QH
1_ooool>oiNGU`go8B4Q3_ooool=ob/[:`Kooooo3_l@410>o`X:2Pgo7QhN3OlH61P6ooooo`ko@d=3
3_m:BTX>oc`l?0co5aLG1_ooool>ocPh>0ko8R8R3_lY:BT=ofATI1?ooooo3_lO7al>oemOG`go?Shn
3Oooool000_ooooo3_lB4Q8>ooooo`ko9RHV3Ol820P5ooooo`ko30`<3_lk>c/>odM7A`go:BTY1_oo
ool=ocPh>0ko<c<c3_lO7al=oeQHF0Kooooo3_nGUiL=ob4Q8@kooooo3Ol[:b/6ooooo`ko410@3_l:
2PX=oahN7Pgo61PH1_ooool>od=3@`koBTY:3_ll?3`<oaLG5`Kooooo3_lh>3P>ob8R8Pko:BTY3OmT
I6@Cooooo`ko7alO3_mOGel=ochn?Pgooooo000;ooooo`ko4Q8B3_ooool>obHV9Pgo20P81Oooool>
o``<30ko>c/k3_m7AdL=obTY:@Kooooo3Olh>3P>oc<c<`ko7alO3OmHF5P6ooooo`koUiNG3OlQ8B4>
ooooo`go:b/[1_ooool>oa0@40ko2PX:3OlN7Qh=oaPH60Kooooo3_m3@d<>odY:BPko?3`l3?lG5aL6
ooooo`ko>3Ph3_lR8R8>obTY:@goI6AT4oooool>oalO7`koGemO3Oln?Sh=ooooo`002oooool>oa8B
4Pkooooo3_lV9RH=o`P820Gooooo3_l<30`>oc/k>`koAdM73OlY:BT6ooooo`go>3Ph3_lc<c<>oalO
7`goF5QH1_ooool>oiNGU`go8B4Q3_ooool=ob/[:`Kooooo3_l@410>o`X:2Pgo7QhN3OlH61P6oooo
o`ko@d=33_m:BTX>oc`l?0co5aLG1_ooool>ocPh>0ko8R8R3_lY:BT=ofATI1?ooooo3_lO7al>oemO
G`go?Shn3Oooool000_ooooo3_lB4Q8>ooooo`ko9RHV3Ol820P5ooooo`ko30`<3_lk>c/>odM7A`go
:BTY1_ooool=ocPh>0ko<c<c3_lO7al=oeQHF0Kooooo3_nGUiL=ob4Q8@kooooo3Ol[:b/6ooooo`ko
410@3_l:2PX=oahN7Pgo61PH1_ooool>od=3@`koBTY:3_ll?3`<oaLG5`Kooooo3_lh>3P>ob8R8Pko
:BTY3OmTI6@Cooooo`ko7alO3_mOGel=ochn?Pgooooo000;ooooo`ko4Q8B3_ooool>obHV9Pgo20P8
1Oooool>o``<30ko>c/k3_m7AdL=obTY:@Kooooo3Olh>3P>oc<c<`ko7alO3OmHF5P6ooooo`koUiNG
3OlQ8B4>ooooo`go:b/[1_ooool>oa0@40ko2PX:3OlN7Qh=oaPH60Kooooo3_m3@d<>odY:BPko?3`l
3?lG5aL6ooooo`ko>3Ph3_lR8R8>obTY:@goI6AT4oooool>oalO7`koGemO3Oln?Sh=ooooo`002ooo
ool>oa8B4Pkooooo3_lV9RH=o`P820Gooooo3_l<30`>oc/k>`koAdM73OlY:BT6ooooo`go>3Ph3_lc
<c<>oalO7`goF5QH1_ooool>oiNGU`go8B4Q3_ooool=ob/[:`Kooooo3_l@410>o`X:2Pgo7QhN3OlH
61P6ooooo`ko@d=33_m:BTX>oc`l?0co5aLG1_ooool>ocPh>0ko8R8R3_lY:BT=ofATI1?ooooo3_lO
7al>oemOG`go?Shn3Oooool000_ooooo3_lB4Q8>ooooo`ko9RHV3Ol820P5ooooo`ko30`<3_lk>c/>
odM7A`go:BTY1_ooool=ocPh>0ko<c<c3_lO7al=oeQHF0Kooooo3_nGUiL=ob4Q8@kooooo3Ol[:b/6
ooooo`ko410@3_l:2PX=oahN7Pgo61PH1_ooool>od=3@`koBTY:3_ll?3`<oaLG5`Kooooo3_lh>3P>
ob8R8Pko:BTY3OmTI6@Cooooo`ko7alO3_mOGel=ochn?Pgooooo000;ooooo`ko4Q8B3_ooool>obHV
9Pgo20P81Oooool>o``<30ko>c/k3_m7AdL=obTY:@Kooooo3Olh>3P>oc<c<`ko7alO3OmHF5P6oooo
o`koUiNG3OlQ8B4>ooooo`go:b/[1_ooool>oa0@40ko2PX:3OlN7Qh=oaPH60Kooooo3_m3@d<>odY:
BPko?3`l3?lG5aL6ooooo`ko>3Ph3_lR8R8>obTY:@goI6AT4oooool>oalO7`koGemO3Oln?Sh=oooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<
C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_oo
ool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL
71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5
ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>
ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLD
ooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH
60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Coooo
o`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`00
00ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=oooo
o`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko
;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Ko
oooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko
9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T
1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]
3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo
3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<
C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_oo
ool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL
71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5
ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>
ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLD
ooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH
60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Coooo
o`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`00
00ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=oooo
o`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko
;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Ko
oooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko
9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T
1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]
3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo
3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<
C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>ocLg=`go61PH1_oo
ool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLDooooo`ko^KVi3_lL
71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH60ko6ATI3OlN7Qh5
ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Cooooo`ko00003OlZ:RX>
ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`0000ko<S8b3?lg=cLD
ooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=ooooo`002ooooolLoaPH
60ko6ATI3OlN7Qh5ooooo`ko:RXZ3_m<C4`>obTY:@go92@T1_ooool=oaXJ6Pko;Rh^3_lT92@Coooo
o`ko00003OlZ:RX>ocLg=`go61PH1_ooool>ocPh>0ko;Bd]3OlJ6QX=o`d=3@Kooooo3_l92@T>o`00
00ko<S8b3?lg=cLDooooo`ko^KVi3_lL71`=oc8b<PGooooo3_mVIVH>od10@0ko9RHV3Oln?Sh=oooo
o`002oooool>o``<30ko4Q8B3_lF5QH=oa4A4@Gooooo3_oYjNT>ooooo`ko4a<C3Ol00006ooooo`go
6QXJ3_l20P8>oa<C4`go@T921_ooool>oa`L70go8R8R3_lX:2P=omSHf0Kooooo3_lE5AD>ocDe=@go
5aLG3Ol00006ooooo`ko<C4a3_mOGel>oiFEUA;ooooo3_lU9BD>o`<30`ko4A4A3OlR8R85ooooo`ko
5ADE3_lb<S8>oa<C4`go:BTY3Oooool000_ooooo3_l<30`>oa8B4Pko5QHF3OlA4A45ooooo`kojNWY
3_ooool>oa<C4`go00001_ooool=oaXJ6Pko0P823_lC4a<=od92@PKooooo3_lL71`=ob8R8Pko:2PX
3OoHf=P6ooooo`ko5ADE3_le=CD=oaLG5`go00001_ooool>oc4a<@koGemO3_nEUIDBooooo`ko9BDU
3_l30`<>oa4A4@go8R8R1Oooool>oaDE5@ko<S8b3_lC4a<=obTY:@gooooo000;ooooo`ko30`<3_lB
4Q8>oaHF5Pgo4A4A1Oooool>onWYj@kooooo3_lC4a<=o`0000Kooooo3OlJ6QX>o`820Pko4a<C3Om2
@T86ooooo`ko71`L3OlR8R8>obPX:0gof=SH1_ooool>oaDE5@ko=CDe3OlG5aL=o`0000Kooooo3_la
<C4>oemOG`koUIFE4_ooool>obDU9@ko0`<33_lA4A4=ob8R8PGooooo3_lE5AD>oc8b<Pko4a<C3OlY
:BT=ooooo`002oooool>o``<30ko4Q8B3_lF5QH=oa4A4@Gooooo3_oYjNT>ooooo`ko4a<C3Ol00006
ooooo`go6QXJ3_l20P8>oa<C4`go@T921_ooool>oa`L70go8R8R3_lX:2P=omSHf0Kooooo3_lE5AD>
ocDe=@go5aLG3Ol00006ooooo`ko<C4a3_mOGel>oiFEUA;ooooo3_lU9BD>o`<30`ko4A4A3OlR8R85
ooooo`ko5ADE3_lb<S8>oa<C4`go:BTY3Oooool000_ooooo3_l<30`>oa8B4Pko5QHF3OlA4A45oooo
o`kojNWY3_ooool>oa<C4`go00001_ooool=oaXJ6Pko0P823_lC4a<=od92@PKooooo3_lL71`=ob8R
8Pko:2PX3OoHf=P6ooooo`ko5ADE3_le=CD=oaLG5`go00001_ooool>oc4a<@koGemO3_nEUIDBoooo
o`ko9BDU3_l30`<>oa4A4@go8R8R1Oooool>oaDE5@ko<S8b3_lC4a<=obTY:@gooooo000;ooooo`ko
30`<3_lB4Q8>oaHF5Pgo4A4A1Oooool>onWYj@kooooo3_lC4a<=o`0000Kooooo3OlJ6QX>o`820Pko
4a<C3Om2@T86ooooo`ko71`L3OlR8R8>obPX:0gof=SH1_ooool>oaDE5@ko=CDe3OlG5aL=o`0000Ko
oooo3_la<C4>oemOG`koUIFE4_ooool>obDU9@ko0`<33_lA4A4=ob8R8PGooooo3_lE5AD>oc8b<Pko
4a<C3OlY:BT=ooooo`002oooool>o``<30ko4Q8B3_lF5QH=oa4A4@Gooooo3_oYjNT>ooooo`ko4a<C
3Ol00006ooooo`go6QXJ3_l20P8>oa<C4`go@T921_ooool>oa`L70go8R8R3_lX:2P=omSHf0Kooooo
3_lE5AD>ocDe=@go5aLG3Ol00006ooooo`ko<C4a3_mOGel>oiFEUA;ooooo3_lU9BD>o`<30`ko4A4A
3OlR8R85ooooo`ko5ADE3_lb<S8>oa<C4`go:BTY3Oooool000_ooooo3_l<30`>oa8B4Pko5QHF3OlA
4A45ooooo`kojNWY3_ooool>oa<C4`go00001_ooool=oaXJ6Pko0P823_lC4a<=od92@PKooooo3_lL
71`=ob8R8Pko:2PX3OoHf=P6ooooo`ko5ADE3_le=CD=oaLG5`go00001_ooool>oc4a<@koGemO3_nE
UIDBooooo`ko9BDU3_l30`<>oa4A4@go8R8R1Oooool>oaDE5@ko<S8b3_lC4a<=obTY:@gooooo000;
ooooo`ko30`<3_lB4Q8>oaHF5Pgo4A4A1Oooool>onWYj@kooooo3_lC4a<=o`0000Kooooo3OlJ6QX>
o`820Pko4a<C3Om2@T86ooooo`ko71`L3OlR8R8>obPX:0gof=SH1_ooool>oaDE5@ko=CDe3OlG5aL=
o`0000Kooooo3_la<C4>oemOG`koUIFE4_ooool>obDU9@ko0`<33_lA4A4=ob8R8PGooooo3_lE5AD>
oc8b<Pko4a<C3OlY:BT=ooooo`002oooool>o``<30ko4Q8B3_lF5QH=oa4A4@Gooooo3_oYjNT>oooo
o`ko4a<C3Ol00006ooooo`go6QXJ3_l20P8>oa<C4`go@T921_ooool>oa`L70go8R8R3_lX:2P=omSH
f0Kooooo3_lE5AD>ocDe=@go5aLG3Ol00006ooooo`ko<C4a3_mOGel>oiFEUA;ooooo3_lU9BD>o`<3
0`ko4A4A3OlR8R85ooooo`ko5ADE3_lb<S8>oa<C4`go:BTY3Oooool000_ooooo3_l<30`>oa8B4Pko
5QHF3OlA4A45ooooo`kojNWY3_ooool>oa<C4`go00001_ooool=oaXJ6Pko0P823_lC4a<=od92@PKo
oooo3_lL71`=ob8R8Pko:2PX3OoHf=P6ooooo`ko5ADE3_le=CD=oaLG5`go00001_ooool>oc4a<@ko
GemO3_nEUIDBooooo`ko9BDU3_l30`<>oa4A4@go8R8R1Oooool>oaDE5@ko<S8b3_lC4a<=obTY:@go
oooo000;ooooo`ko30`<3_lB4Q8>oaHF5Pgo4A4A1Oooool>onWYj@kooooo3_lC4a<=o`0000Kooooo
3OlJ6QX>o`820Pko4a<C3Om2@T86ooooo`ko71`L3OlR8R8>obPX:0gof=SH1_ooool>oaDE5@ko=CDe
3OlG5aL=o`0000Kooooo3_la<C4>oemOG`koUIFE4_ooool>obDU9@ko0`<33_lA4A4=ob8R8PGooooo
3_lE5AD>oc8b<Pko4a<C3OlY:BT=ooooo`002oooool>o``<30ko4Q8B3_lF5QH=oa4A4@Gooooo3_oY
jNT>ooooo`ko4a<C3Ol00006ooooo`go6QXJ3_l20P8>oa<C4`go@T921_ooool>oa`L70go8R8R3_lX
:2P=omSHf0Kooooo3_lE5AD>ocDe=@go5aLG3Ol00006ooooo`ko<C4a3_mOGel>oiFEUA;ooooo3_lU
9BD>o`<30`ko4A4A3OlR8R85ooooo`ko5ADE3_lb<S8>oa<C4`go:BTY3Oooool000_ooooo3_l<30`>
oa8B4Pko5QHF3OlA4A45ooooo`kojNWY3_ooool>oa<C4`go00001_ooool=oaXJ6Pko0P823_lC4a<=
od92@PKooooo3_lL71`=ob8R8Pko:2PX3OoHf=P6ooooo`ko5ADE3_le=CD=oaLG5`go00001_ooool>
oc4a<@koGemO3_nEUIDBooooo`ko9BDU3_l30`<>oa4A4@go8R8R1Oooool>oaDE5@ko<S8b3_lC4a<=
obTY:@gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE
5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj
>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ
:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go
:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko
=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko
51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000go
oooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo
3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo
3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo0000
1Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Ooo
ool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW
9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mI
FET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;
ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>
o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=
oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>
oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d
=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh
>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6oooo
o`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko
4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko
0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Ko
oooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko
8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:
3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?
1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=
3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0
000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN
7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI
6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^
;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=
oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>
ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>
obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C
4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6oooo
o`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN
7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`00
00gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Ko
oooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pko
oooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo
00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo000;ooooo`ko4a<C3_l0000>oa<C4`go:b/[
1Oooool>oc@d=0koBTY:3_l^;Rh=oaDE5@Kooooo3OlI6AT>o`L71`ko0`<33OlN7Qh6ooooo`ko=cLg
3OlW9bL>ocPh>0goCdm?1_ooool>ocXj>Pkooooo3OlN7Qh=oc@d=0Kooooo3_lI6AT>oahN7Pko51@D
3?mIFET6ooooo`ko3@d=3_lX:2P>obXZ:Pgo00001Oooool>oaHF5Pko8b<S3_l^;Rh=o`0000gooooo
000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<
30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW
9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Ooo
ool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>
obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>
ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6
ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;oooo
o`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?
3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ
6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOG
e`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko
71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go
4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`ko
CTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A
3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko0000
3Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo
3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo
3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l9
2@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_oo
ool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la
<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>
ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6
ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>
o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=
og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofAT
I0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE
5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];
B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go
71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko
7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko
0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`go
oooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo
3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY
3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[
1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Ooo
ool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU
9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD
51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo000;
ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>
o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>ooooo`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=
oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6ooooo`koCTi>3_la<C4>od];B`go:b/[1Oooool>
omOGe`kooooo3_lZ:RX=og]kN`gooooo000;ooooo`ko4A4A3_l820P>ooooo`go71`L1Oooool>obl_
;`ko71`L3_l92@T=ofATI0Kooooo3Ol<30`>o`l?3`ko00003Ol];Bd6ooooo`ko7AdM3OlU9BD>oooo
o`go4A4A1_ooool>oaDE5@ko:BTY3OlW9bL=oaXJ6PKooooo3_mXJ6P>o`D51@ko0P823?lD51@6oooo
o`koCTi>3_la<C4>od];B`go:b/[1Oooool>omOGe`kooooo3_lZ:RX=og]kN`gooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=
3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_oo
ool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0
000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>
oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6
ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>
ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=
o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`00
00Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE
5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ
:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo
00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko
4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`ko
oooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@go
oooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo
3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH6
3Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_
1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Ooo
ool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT
92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW
9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;
ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>
ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=
o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>
oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=
3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l
?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6oooo
o`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko
5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@ko
L71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKo
oooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko
1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN
3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN
1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A
3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?
3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoI
fMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mH
F5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:
2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=
o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6ooooo`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>
oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>
obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`410@gooooo000;ooooo`ko5aLG3_l?3`l>oaHF
5Pgo00001Oooool>o`d=3@ko7QhN3_l=3@d=o`0000Kooooo3Ol@410>ofe]K@koL71`3OoIfMT6oooo
o`ko4a<C3OlT92@>oc`l?0go7QhN1_ooool>oaDE5@ko1PH63Ol0000=o`X:2PKooooo3_mHF5P>ocLg
=`kooooo3?lW9bL6ooooo`ko4A4A3_l0000>obXZ:Pgo;bl_1Oooool>oaDE5@ko1@D53_l:2PX=o`41
0@gooooo000;ooooo`ko30`<3_lA4A4>o`h>3Pgo1PH61Oooool>oc4a<@ko7QhN3_l=3@d=oaDE5@Ko
oooo3Ol30`<>ocLg=`koShn?4oooool>oaPH60go10@43_lC4a<=o``<30Kooooo3_lU9BD>ono_k`go
LG5a4oooool>oa<C4`ko00003_lX:2P<o`0000Kooooo3_l51@D>obLW9`ko;bl_3OlL71`5ooooo`ko
00003_l=3@d>obTY:@go5QHF3Oooool000_ooooo3_l<30`>oa4A4@ko3Ph>3Ol61PH5ooooo`ko<C4a
3_lN7Qh>o`d=3@go5ADE1_ooool=o`<30`ko=cLg3_n?ShlCooooo`ko61PH3Ol410@>oa<C4`go30`<
1_ooool>obDU9@kokno_3OmaLG4Cooooo`ko4a<C3_l0000>obPX:0co00001_ooool>o`D51@ko9bLW
3_l_;bl=oa`L70Gooooo3_l0000>o`d=3@ko:BTY3OlF5QH=ooooo`002oooool>o``<30ko4A4A3_l>
3Ph=o`H61PGooooo3_la<C4>oahN7Pko3@d=3OlE5AD6ooooo`go0`<33_lg=cL>ohn?Sa?ooooo3_lH
61P=o`@410ko4a<C3Ol<30`6ooooo`ko9BDU3_o_knl=og5aLA?ooooo3_lC4a<>o`0000ko:2PX3?l0
0006ooooo`ko1@D53_lW9bL>obl_;`go71`L1Oooool>o`0000ko3@d=3_lY:BT=oaHF5Pgooooo000;
ooooo`ko30`<3_lA4A4>o`h>3Pgo1PH61Oooool>oc4a<@ko7QhN3_l=3@d=oaDE5@Kooooo3Ol30`<>
ocLg=`koShn?4oooool>oaPH60go10@43_lC4a<=o``<30Kooooo3_lU9BD>ono_k`goLG5a4oooool>
oa<C4`ko00003_lX:2P<o`0000Kooooo3_l51@D>obLW9`ko;bl_3OlL71`5ooooo`ko00003_l=3@d>
obTY:@go5QHF3Oooool000_ooooo3_l<30`>oa4A4@ko3Ph>3Ol61PH5ooooo`ko<C4a3_lN7Qh>o`d=
3@go5ADE1_ooool=o`<30`ko=cLg3_n?ShlCooooo`ko61PH3Ol410@>oa<C4`go30`<1_ooool>obDU
9@kokno_3OmaLG4Cooooo`ko4a<C3_l0000>obPX:0co00001_ooool>o`D51@ko9bLW3_l_;bl=oa`L
70Gooooo3_l0000>o`d=3@ko:BTY3OlF5QH=ooooo`002oooool>o``<30ko4A4A3_l>3Ph=o`H61PGo
oooo3_la<C4>oahN7Pko3@d=3OlE5AD6ooooo`go0`<33_lg=cL>ohn?Sa?ooooo3_lH61P=o`@410ko
4a<C3Ol<30`6ooooo`ko9BDU3_o_knl=og5aLA?ooooo3_lC4a<>o`0000ko:2PX3?l00006ooooo`ko
1@D53_lW9bL>obl_;`go71`L1Oooool>o`0000ko3@d=3_lY:BT=oaHF5Pgooooo000;ooooo`ko30`<
3_lA4A4>o`h>3Pgo1PH61Oooool>oc4a<@ko7QhN3_l=3@d=oaDE5@Kooooo3Ol30`<>ocLg=`koShn?
4oooool>oaPH60go10@43_lC4a<=o``<30Kooooo3_lU9BD>ono_k`goLG5a4oooool>oa<C4`ko0000
3_lX:2P<o`0000Kooooo3_l51@D>obLW9`ko;bl_3OlL71`5ooooo`ko00003_l=3@d>obTY:@go5QHF
3Oooool000_ooooo3_l<30`>oa4A4@ko3Ph>3Ol61PH5ooooo`ko<C4a3_lN7Qh>o`d=3@go5ADE1_oo
ool=o`<30`ko=cLg3_n?ShlCooooo`ko61PH3Ol410@>oa<C4`go30`<1_ooool>obDU9@kokno_3Oma
LG4Cooooo`ko4a<C3_l0000>obPX:0co00001_ooool>o`D51@ko9bLW3_l_;bl=oa`L70Gooooo3_l0
000>o`d=3@ko:BTY3OlF5QH=ooooo`002oooool>o``<30ko4A4A3_l>3Ph=o`H61PGooooo3_la<C4>
oahN7Pko3@d=3OlE5AD6ooooo`go0`<33_lg=cL>ohn?Sa?ooooo3_lH61P=o`@410ko4a<C3Ol<30`6
ooooo`ko9BDU3_o_knl=og5aLA?ooooo3_lC4a<>o`0000ko:2PX3?l00006ooooo`ko1@D53_lW9bL>
obl_;`go71`L1Oooool>o`0000ko3@d=3_lY:BT=oaHF5Pgooooo000;ooooo`ko30`<3_lA4A4>o`h>
3Pgo1PH61Oooool>oc4a<@ko7QhN3_l=3@d=oaDE5@Kooooo3Ol30`<>ocLg=`koShn?4oooool>oaPH
60go10@43_lC4a<=o``<30Kooooo3_lU9BD>ono_k`goLG5a4oooool>oa<C4`ko00003_lX:2P<o`00
00Kooooo3_l51@D>obLW9`ko;bl_3OlL71`5ooooo`ko00003_l=3@d>obTY:@go5QHF3Oooool000_o
oooo3_l<30`>oa4A4@ko3Ph>3Ol61PH5ooooo`ko<C4a3_lN7Qh>o`d=3@go5ADE1_ooool=o`<30`ko
=cLg3_n?ShlCooooo`ko61PH3Ol410@>oa<C4`go30`<1_ooool>obDU9@kokno_3OmaLG4Cooooo`ko
4a<C3_l0000>obPX:0co00001_ooool>o`D51@ko9bLW3_l_;bl=oa`L70Gooooo3_l0000>o`d=3@ko
:BTY3OlF5QH=ooooo`002oooool>o``<30ko4A4A3_l>3Ph=o`H61PGooooo3_la<C4>oahN7Pko3@d=
3OlE5AD6ooooo`go0`<33_lg=cL>ohn?Sa?ooooo3_lH61P=o`@410ko4a<C3Ol<30`6ooooo`ko9BDU
3_o_knl=og5aLA?ooooo3_lC4a<>o`0000ko:2PX3?l00006ooooo`ko1@D53_lW9bL>obl_;`go71`L
1Oooool>o`0000ko3@d=3_lY:BT=oaHF5Pgooooo000;ooooo`ko30`<3_lA4A4>o`h>3Pgo1PH61Ooo
ool>oc4a<@ko7QhN3_l=3@d=oaDE5@Kooooo3Ol30`<>ocLg=`koShn?4oooool>oaPH60go10@43_lC
4a<=o``<30Kooooo3_lU9BD>ono_k`goLG5a4oooool>oa<C4`ko00003_lX:2P<o`0000Kooooo3_l5
1@D>obLW9`ko;bl_3OlL71`5ooooo`ko00003_l=3@d>obTY:@go5QHF3Oooool000_ooooo3_l<30`>
oa4A4@ko3Ph>3Ol61PH5ooooo`ko<C4a3_lN7Qh>o`d=3@go5ADE1_ooool=o`<30`ko=cLg3_n?ShlC
ooooo`ko61PH3Ol410@>oa<C4`go30`<1_ooool>obDU9@kokno_3OmaLG4Cooooo`ko4a<C3_l0000>
obPX:0co00001_ooool>o`D51@ko9bLW3_l_;bl=oa`L70Gooooo3_l0000>o`d=3@ko:BTY3OlF5QH=
ooooo`002oooool>obh^;Pko5QHF3_l:2PX=o`820Q?ooooo3_lS8b<>oa8B4Pgo6ATI1_ooool=o`00
00ko2@T93_mhN7P=omCDe0Kooooo3_lJ6QX=o`l?3`ko00003Ol20P86ooooo`ko410@3_lB4Q8=oa`L
70go>c/k1_ooool>oaPH60ko9bLW3_lH61P<oc0`<0Kooooo3_l92@T>obXZ:Pko3Ph>3OlM7Ad5oooo
o`ko1@D53_l@410>oc@d=0go71`L3Oooool000_ooooo3_l^;Rh>oaHF5Pko2PX:3Ol20P8Cooooo`ko
8b<S3_lB4Q8=oaTI6@Kooooo3Ol0000>o`T92@koN7Qh3OoDe=@6ooooo`ko6QXJ3Ol?3`l>o`0000go
0P821_ooool>oa0@40ko4Q8B3OlL71`=oc/k>`Kooooo3_lH61P>obLW9`ko61PH3?l`<306ooooo`ko
2@T93_lZ:RX>o`h>3Pgo7AdM1Oooool>o`D51@ko410@3_ld=3@=oa`L70gooooo000;ooooo`ko;Rh^
3_lF5QH>o`X:2Pgo0P824oooool>ob<S8`ko4Q8B3OlI6AT6ooooo`go00003_l92@T>ogQhN0goe=CD
1_ooool>oaXJ6Pgo3`l?3_l0000=o`820PKooooo3_l@410>oa8B4Pgo71`L3Olk>c/6ooooo`ko61PH
3_lW9bL>oaPH60co<30`1_ooool>o`T92@ko:RXZ3_l>3Ph=oadM7@Gooooo3_l51@D>oa0@40ko=3@d
3OlL71`=ooooo`002oooool>obh^;Pko5QHF3_l:2PX=o`820Q?ooooo3_lS8b<>oa8B4Pgo6ATI1_oo
ool=o`0000ko2@T93_mhN7P=omCDe0Kooooo3_lJ6QX=o`l?3`ko00003Ol20P86ooooo`ko410@3_lB
4Q8=oa`L70go>c/k1_ooool>oaPH60ko9bLW3_lH61P<oc0`<0Kooooo3_l92@T>obXZ:Pko3Ph>3OlM
7Ad5ooooo`ko1@D53_l@410>oc@d=0go71`L3Oooool000_ooooo3_l^;Rh>oaHF5Pko2PX:3Ol20P8C
ooooo`ko8b<S3_lB4Q8=oaTI6@Kooooo3Ol0000>o`T92@koN7Qh3OoDe=@6ooooo`ko6QXJ3Ol?3`l>
o`0000go0P821_ooool>oa0@40ko4Q8B3OlL71`=oc/k>`Kooooo3_lH61P>obLW9`ko61PH3?l`<306
ooooo`ko2@T93_lZ:RX>o`h>3Pgo7AdM1Oooool>o`D51@ko410@3_ld=3@=oa`L70gooooo000;oooo
o`ko;Rh^3_lF5QH>o`X:2Pgo0P824oooool>ob<S8`ko4Q8B3OlI6AT6ooooo`go00003_l92@T>ogQh
N0goe=CD1_ooool>oaXJ6Pgo3`l?3_l0000=o`820PKooooo3_l@410>oa8B4Pgo71`L3Olk>c/6oooo
o`ko61PH3_lW9bL>oaPH60co<30`1_ooool>o`T92@ko:RXZ3_l>3Ph=oadM7@Gooooo3_l51@D>oa0@
40ko=3@d3OlL71`=ooooo`002oooool>obh^;Pko5QHF3_l:2PX=o`820Q?ooooo3_lS8b<>oa8B4Pgo
6ATI1_ooool=o`0000ko2@T93_mhN7P=omCDe0Kooooo3_lJ6QX=o`l?3`ko00003Ol20P86ooooo`ko
410@3_lB4Q8=oa`L70go>c/k1_ooool>oaPH60ko9bLW3_lH61P<oc0`<0Kooooo3_l92@T>obXZ:Pko
3Ph>3OlM7Ad5ooooo`ko1@D53_l@410>oc@d=0go71`L3Oooool000_ooooo3_l^;Rh>oaHF5Pko2PX:
3Ol20P8Cooooo`ko8b<S3_lB4Q8=oaTI6@Kooooo3Ol0000>o`T92@koN7Qh3OoDe=@6ooooo`ko6QXJ
3Ol?3`l>o`0000go0P821_ooool>oa0@40ko4Q8B3OlL71`=oc/k>`Kooooo3_lH61P>obLW9`ko61PH
3?l`<306ooooo`ko2@T93_lZ:RX>o`h>3Pgo7AdM1Oooool>o`D51@ko410@3_ld=3@=oa`L70gooooo
000;ooooo`ko;Rh^3_lF5QH>o`X:2Pgo0P824oooool>ob<S8`ko4Q8B3OlI6AT6ooooo`go00003_l9
2@T>ogQhN0goe=CD1_ooool>oaXJ6Pgo3`l?3_l0000=o`820PKooooo3_l@410>oa8B4Pgo71`L3Olk
>c/6ooooo`ko61PH3_lW9bL>oaPH60co<30`1_ooool>o`T92@ko:RXZ3_l>3Ph=oadM7@Gooooo3_l5
1@D>oa0@40ko=3@d3OlL71`=ooooo`002oooool>obh^;Pko5QHF3_l:2PX=o`820Q?ooooo3_lS8b<>
oa8B4Pgo6ATI1_ooool=o`0000ko2@T93_mhN7P=omCDe0Kooooo3_lJ6QX=o`l?3`ko00003Ol20P86
ooooo`ko410@3_lB4Q8=oa`L70go>c/k1_ooool>oaPH60ko9bLW3_lH61P<oc0`<0Kooooo3_l92@T>
obXZ:Pko3Ph>3OlM7Ad5ooooo`ko1@D53_l@410>oc@d=0go71`L3Oooool000_ooooo3_l^;Rh>oaHF
5Pko2PX:3Ol20P8Cooooo`ko8b<S3_lB4Q8=oaTI6@Kooooo3Ol0000>o`T92@koN7Qh3OoDe=@6oooo
o`ko6QXJ3Ol?3`l>o`0000go0P821_ooool>oa0@40ko4Q8B3OlL71`=oc/k>`Kooooo3_lH61P>obLW
9`ko61PH3?l`<306ooooo`ko2@T93_lZ:RX>o`h>3Pgo7AdM1Oooool>o`D51@ko410@3_ld=3@=oa`L
70gooooo000;ooooo`ko;Rh^3_lF5QH>o`X:2Pgo0P824oooool>ob<S8`ko4Q8B3OlI6AT6ooooo`go
00003_l92@T>ogQhN0goe=CD1_ooool>oaXJ6Pgo3`l?3_l0000=o`820PKooooo3_l@410>oa8B4Pgo
71`L3Olk>c/6ooooo`ko61PH3_lW9bL>oaPH60co<30`1_ooool>o`T92@ko:RXZ3_l>3Ph=oadM7@Go
oooo3_l51@D>oa0@40ko=3@d3OlL71`=ooooo`002oooool>obh^;Pko5QHF3_l:2PX=o`820Q?ooooo
3_lS8b<>oa8B4Pgo6ATI1_ooool=o`0000ko2@T93_mhN7P=omCDe0Kooooo3_lJ6QX=o`l?3`ko0000
3Ol20P86ooooo`ko410@3_lB4Q8=oa`L70go>c/k1_ooool>oaPH60ko9bLW3_lH61P<oc0`<0Kooooo
3_l92@T>obXZ:Pko3Ph>3OlM7Ad5ooooo`ko1@D53_l@410>oc@d=0go71`L3Oooool001Wooooo3_lJ
6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3Omd
M7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC
4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Ooo
ool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>
od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=
oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>
oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`
<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX
:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=
CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko
@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go
>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko
2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L7
1Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@410
3OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN
3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ
6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3Omd
M7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC
4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Ooo
ool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>
od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=
oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>
oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`
<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX
:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=
CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko
@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go
>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko
2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L7
1Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@410
3OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN
3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ
6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3Omd
M7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC
4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Ooo
ool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`<0Kooooo3Ol`<30>
od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=
oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=CB3ooooo3_lP820>
oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko@D513_lP820=oc0`
<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go>CTi1_ooool>obPX
:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko2`/;3_le=CD>ode=
CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool001Wooooo3_lJ6QX>o`@410go1`L71Oooool>odQ8B0ko
@D513_lP820=oc0`<0Kooooo3Ol`<30>od];B`ko:RXZ3OmdM7@6ooooo`ko@4103OnTY:@>ooooo`go
>CTi1_ooool>obPX:0ko8R8R3OlJ6QX=oa4A4@Kooooo3_lC4a<>odM7A`ko7QhN3?lG5aL6ooooo`ko
2`/;3_le=CD>ode=CB3ooooo3_lP820>oaXJ6PgoBDU93Oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo3_nI
VIT>oiRHV0koNWYj3Om^KVh5ooooo`ko8R8R3_l?3`l>o`d=3@go9BDU1_ooool=oaHF5Pko00003_lG
5aL=oa4A4@Kooooo3_lB4Q8=o`P820ko=SHf3OlF5QH6ooooo`ko:RXZ3_lC4a<=o`0000go6ATI1_oo
ool>oaLG5`ko00003_l^;Rh<oalO7aCooooo3_l0000>obLW9`go8R8R1Oooool>o`410@ko:RXZ3_l9
2@T=oa8B4Pgooooo000;ooooo`koVIVI3_nHV9P>ogYjNPgoKVi^1Oooool>ob8R8Pko3`l?3_l=3@d=
obDU9@Kooooo3OlF5QH>o`0000ko5aLG3OlA4A46ooooo`ko4Q8B3Ol820P>ocHf=Pgo5QHF1_ooool>
obXZ:Pko4a<C3Ol0000=oaTI6@Kooooo3_lG5aL>o`0000ko;Rh^3?lO7alDooooo`ko00003_lW9bL=
ob8R8PGooooo3_l10@4>obXZ:Pko2@T93OlB4Q8=ooooo`002oooool>oiVIV@koV9RH3_mjNWX=ofi^
KPGooooo3_lR8R8>o`l?3`ko3@d=3OlU9BD6ooooo`go5QHF3_l0000>oaLG5`go4A4A1_ooool>oa8B
4Pgo20P83_lf=SH=oaHF5PKooooo3_lZ:RX>oa<C4`go00003OlI6AT6ooooo`ko5aLG3_l0000>obh^
;Pco7alO5?ooool>o`0000ko9bLW3OlR8R85ooooo`ko0@413_lZ:RX>o`T92@go4Q8B3Oooool000_o
oooo3_nIVIT>oiRHV0koNWYj3Om^KVh5ooooo`ko8R8R3_l?3`l>o`d=3@go9BDU1_ooool=oaHF5Pko
00003_lG5aL=oa4A4@Kooooo3_lB4Q8=o`P820ko=SHf3OlF5QH6ooooo`ko:RXZ3_lC4a<=o`0000go
6ATI1_ooool>oaLG5`ko00003_l^;Rh<oalO7aCooooo3_l0000>obLW9`go8R8R1Oooool>o`410@ko
:RXZ3_l92@T=oa8B4Pgooooo000;ooooo`koVIVI3_nHV9P>ogYjNPgoKVi^1Oooool>ob8R8Pko3`l?
3_l=3@d=obDU9@Kooooo3OlF5QH>o`0000ko5aLG3OlA4A46ooooo`ko4Q8B3Ol820P>ocHf=Pgo5QHF
1_ooool>obXZ:Pko4a<C3Ol0000=oaTI6@Kooooo3_lG5aL>o`0000ko;Rh^3?lO7alDooooo`ko0000
3_lW9bL=ob8R8PGooooo3_l10@4>obXZ:Pko2@T93OlB4Q8=ooooo`002oooool>oiVIV@koV9RH3_mj
NWX=ofi^KPGooooo3_lR8R8>o`l?3`ko3@d=3OlU9BD6ooooo`go5QHF3_l0000>oaLG5`go4A4A1_oo
ool>oa8B4Pgo20P83_lf=SH=oaHF5PKooooo3_lZ:RX>oa<C4`go00003OlI6AT6ooooo`ko5aLG3_l0
000>obh^;Pco7alO5?ooool>o`0000ko9bLW3OlR8R85ooooo`ko0@413_lZ:RX>o`T92@go4Q8B3Ooo
ool000_ooooo3_nIVIT>oiRHV0koNWYj3Om^KVh5ooooo`ko8R8R3_l?3`l>o`d=3@go9BDU1_ooool=
oaHF5Pko00003_lG5aL=oa4A4@Kooooo3_lB4Q8=o`P820ko=SHf3OlF5QH6ooooo`ko:RXZ3_lC4a<=
o`0000go6ATI1_ooool>oaLG5`ko00003_l^;Rh<oalO7aCooooo3_l0000>obLW9`go8R8R1Oooool>
o`410@ko:RXZ3_l92@T=oa8B4Pgooooo000;ooooo`koVIVI3_nHV9P>ogYjNPgoKVi^1Oooool>ob8R
8Pko3`l?3_l=3@d=obDU9@Kooooo3OlF5QH>o`0000ko5aLG3OlA4A46ooooo`ko4Q8B3Ol820P>ocHf
=Pgo5QHF1_ooool>obXZ:Pko4a<C3Ol0000=oaTI6@Kooooo3_lG5aL>o`0000ko;Rh^3?lO7alDoooo
o`ko00003_lW9bL=ob8R8PGooooo3_l10@4>obXZ:Pko2@T93OlB4Q8=ooooo`002oooool>oiVIV@ko
V9RH3_mjNWX=ofi^KPGooooo3_lR8R8>o`l?3`ko3@d=3OlU9BD6ooooo`go5QHF3_l0000>oaLG5`go
4A4A1_ooool>oa8B4Pgo20P83_lf=SH=oaHF5PKooooo3_lZ:RX>oa<C4`go00003OlI6AT6ooooo`ko
5aLG3_l0000>obh^;Pco7alO5?ooool>o`0000ko9bLW3OlR8R85ooooo`ko0@413_lZ:RX>o`T92@go
4Q8B3Oooool000_ooooo3_nIVIT>oiRHV0koNWYj3Om^KVh5ooooo`ko8R8R3_l?3`l>o`d=3@go9BDU
1_ooool=oaHF5Pko00003_lG5aL=oa4A4@Kooooo3_lB4Q8=o`P820ko=SHf3OlF5QH6ooooo`ko:RXZ
3_lC4a<=o`0000go6ATI1_ooool>oaLG5`ko00003_l^;Rh<oalO7aCooooo3_l0000>obLW9`go8R8R
1Oooool>o`410@ko:RXZ3_l92@T=oa8B4Pgooooo000;ooooo`koVIVI3_nHV9P>ogYjNPgoKVi^1Ooo
ool>ob8R8Pko3`l?3_l=3@d=obDU9@Kooooo3OlF5QH>o`0000ko5aLG3OlA4A46ooooo`ko4Q8B3Ol8
20P>ocHf=Pgo5QHF1_ooool>obXZ:Pko4a<C3Ol0000=oaTI6@Kooooo3_lG5aL>o`0000ko;Rh^3?lO
7alDooooo`ko00003_lW9bL=ob8R8PGooooo3_l10@4>obXZ:Pko2@T93OlB4Q8=ooooo`002oooool>
oiVIV@koV9RH3_mjNWX=ofi^KPGooooo3_lR8R8>o`l?3`ko3@d=3OlU9BD6ooooo`go5QHF3_l0000>
oaLG5`go4A4A1_ooool>oa8B4Pgo20P83_lf=SH=oaHF5PKooooo3_lZ:RX>oa<C4`go00003OlI6AT6
ooooo`ko5aLG3_l0000>obh^;Pco7alO5?ooool>o`0000ko9bLW3OlR8R85ooooo`ko0@413_lZ:RX>
o`T92@go4Q8B3Oooool000_ooooo3_nIVIT>oiRHV0koNWYj3Om^KVh5ooooo`ko8R8R3_l?3`l>o`d=
3@go9BDU1_ooool=oaHF5Pko00003_lG5aL=oa4A4@Kooooo3_lB4Q8=o`P820ko=SHf3OlF5QH6oooo
o`ko:RXZ3_lC4a<=o`0000go6ATI1_ooool>oaLG5`ko00003_l^;Rh<oalO7aCooooo3_l0000>obLW
9`go8R8R1Oooool>o`410@ko:RXZ3_l92@T=oa8B4Pgooooo000Iooooo`ko/k>c3_o1`L4=ojNWYa?o
oooo3_lI6AT>o`T92@go>c/k1_ooool=o`l?3`ko4Q8B3_lC4a<=oa8B4PKooooo3_l_;bl=oc4a<@ko
30`<3Ol00006ooooo`ko>SXj3_l61PH=o`<30`go1@D51_ooool>of][J`ko<c<c3_ooool<oaHF5PKo
oooo3_ln?Sh>obXZ:Pko3`l?3Olb<S85ooooo`ko9RHV3_l0000>o`L71`go61PH3Oooool001Wooooo
3_nc/k<>ol71`@goYjNW4oooool>oaTI6@ko2@T93Olk>c/6ooooo`go3`l?3_lB4Q8>oa<C4`go4Q8B
1_ooool>obl_;`go<C4a3_l<30`=o`0000Kooooo3_lj>SX>o`H61Pgo0`<33Ol51@D6ooooo`koJf][
3_lc<c<>ooooo`co5QHF1_ooool>ochn?Pko:RXZ3_l?3`l=oc8b<PGooooo3_lV9RH>o`0000ko1`L7
3OlH61P=ooooo`006Oooool>ok>c/`ko`L713OnWYjLCooooo`ko6ATI3_l92@T=oc/k>`Kooooo3Ol?
3`l>oa8B4Pko4a<C3OlB4Q86ooooo`ko;bl_3Ola<C4>o``<30go00001_ooool>ocXj>Pko1PH63Ol3
0`<=o`D51@Kooooo3_m[Jf/>oc<c<`kooooo3?lF5QH6ooooo`ko?Shn3_lZ:RX>o`l?3`go<S8b1Ooo
ool>obHV9Pko00003_l71`L=oaPH60gooooo000Iooooo`ko/k>c3_o1`L4=ojNWYa?ooooo3_lI6AT>
o`T92@go>c/k1_ooool=o`l?3`ko4Q8B3_lC4a<=oa8B4PKooooo3_l_;bl=oc4a<@ko30`<3Ol00006
ooooo`ko>SXj3_l61PH=o`<30`go1@D51_ooool>of][J`ko<c<c3_ooool<oaHF5PKooooo3_ln?Sh>
obXZ:Pko3`l?3Olb<S85ooooo`ko9RHV3_l0000>o`L71`go61PH3Oooool001Wooooo3_nc/k<>ol71
`@goYjNW4oooool>oaTI6@ko2@T93Olk>c/6ooooo`go3`l?3_lB4Q8>oa<C4`go4Q8B1_ooool>obl_
;`go<C4a3_l<30`=o`0000Kooooo3_lj>SX>o`H61Pgo0`<33Ol51@D6ooooo`koJf][3_lc<c<>oooo
o`co5QHF1_ooool>ochn?Pko:RXZ3_l?3`l=oc8b<PGooooo3_lV9RH>o`0000ko1`L73OlH61P=oooo
o`006Oooool>ok>c/`ko`L713OnWYjLCooooo`ko6ATI3_l92@T=oc/k>`Kooooo3Ol?3`l>oa8B4Pko
4a<C3OlB4Q86ooooo`ko;bl_3Ola<C4>o``<30go00001_ooool>ocXj>Pko1PH63Ol30`<=o`D51@Ko
oooo3_m[Jf/>oc<c<`kooooo3?lF5QH6ooooo`ko?Shn3_lZ:RX>o`l?3`go<S8b1Oooool>obHV9Pko
00003_l71`L=oaPH60gooooo000Iooooo`ko/k>c3_o1`L4=ojNWYa?ooooo3_lI6AT>o`T92@go>c/k
1_ooool=o`l?3`ko4Q8B3_lC4a<=oa8B4PKooooo3_l_;bl=oc4a<@ko30`<3Ol00006ooooo`ko>SXj
3_l61PH=o`<30`go1@D51_ooool>of][J`ko<c<c3_ooool<oaHF5PKooooo3_ln?Sh>obXZ:Pko3`l?
3Olb<S85ooooo`ko9RHV3_l0000>o`L71`go61PH3Oooool001Wooooo3_nc/k<>ol71`@goYjNW4ooo
ool>oaTI6@ko2@T93Olk>c/6ooooo`go3`l?3_lB4Q8>oa<C4`go4Q8B1_ooool>obl_;`go<C4a3_l<
30`=o`0000Kooooo3_lj>SX>o`H61Pgo0`<33Ol51@D6ooooo`koJf][3_lc<c<>ooooo`co5QHF1_oo
ool>ochn?Pko:RXZ3_l?3`l=oc8b<PGooooo3_lV9RH>o`0000ko1`L73OlH61P=ooooo`006Oooool>
ok>c/`ko`L713OnWYjLCooooo`ko6ATI3_l92@T=oc/k>`Kooooo3Ol?3`l>oa8B4Pko4a<C3OlB4Q86
ooooo`ko;bl_3Ola<C4>o``<30go00001_ooool>ocXj>Pko1PH63Ol30`<=o`D51@Kooooo3_m[Jf/>
oc<c<`kooooo3?lF5QH6ooooo`ko?Shn3_lZ:RX>o`l?3`go<S8b1Oooool>obHV9Pko00003_l71`L=
oaPH60gooooo000Iooooo`ko/k>c3_o1`L4=ojNWYa?ooooo3_lI6AT>o`T92@go>c/k1_ooool=o`l?
3`ko4Q8B3_lC4a<=oa8B4PKooooo3_l_;bl=oc4a<@ko30`<3Ol00006ooooo`ko>SXj3_l61PH=o`<3
0`go1@D51_ooool>of][J`ko<c<c3_ooool<oaHF5PKooooo3_ln?Sh>obXZ:Pko3`l?3Olb<S85oooo
o`ko9RHV3_l0000>o`L71`go61PH3Oooool001Wooooo3_nc/k<>ol71`@goYjNW4oooool>oaTI6@ko
2@T93Olk>c/6ooooo`go3`l?3_lB4Q8>oa<C4`go4Q8B1_ooool>obl_;`go<C4a3_l<30`=o`0000Ko
oooo3_lj>SX>o`H61Pgo0`<33Ol51@D6ooooo`koJf][3_lc<c<>ooooo`co5QHF1_ooool>ochn?Pko
:RXZ3_l?3`l=oc8b<PGooooo3_lV9RH>o`0000ko1`L73OlH61P=ooooo`006Oooool>ok>c/`ko`L71
3OnWYjLCooooo`ko6ATI3_l92@T=oc/k>`Kooooo3Ol?3`l>oa8B4Pko4a<C3OlB4Q86ooooo`ko;bl_
3Ola<C4>o``<30go00001_ooool>ocXj>Pko1PH63Ol30`<=o`D51@Kooooo3_m[Jf/>oc<c<`kooooo
3?lF5QH6ooooo`ko?Shn3_lZ:RX>o`l?3`go<S8b1Oooool>obHV9Pko00003_l71`L=oaPH60gooooo
000Iooooo`ko/k>c3_o1`L4=ojNWYa?ooooo3_lI6AT>o`T92@go>c/k1_ooool=o`l?3`ko4Q8B3_lC
4a<=oa8B4PKooooo3_l_;bl=oc4a<@ko30`<3Ol00006ooooo`ko>SXj3_l61PH=o`<30`go1@D51_oo
ool>of][J`ko<c<c3_ooool<oaHF5PKooooo3_ln?Sh>obXZ:Pko3`l?3Olb<S85ooooo`ko9RHV3_l0
000>o`L71`go61PH3Oooool001Wooooo3_nc/k<>ol71`@goYjNW4oooool>oaTI6@ko2@T93Olk>c/6
ooooo`go3`l?3_lB4Q8>oa<C4`go4Q8B1_ooool>obl_;`go<C4a3_l<30`=o`0000Kooooo3_lj>SX>
o`H61Pgo0`<33Ol51@D6ooooo`koJf][3_lc<c<>ooooo`co5QHF1_ooool>ochn?Pko:RXZ3_l?3`l=
oc8b<PGooooo3_lV9RH>o`0000ko1`L73OlH61P=ooooo`002oooool>omoOg`ko^[Zj3_o6a/H=olG5
a@Gooooo3_m;Bd/>obl_;`ko2`/;3OlG5aL6ooooo`go410@3_l:2PX>o`/;2`go410@1_ooool>oalO
7`go51@D3_le=CD=oaDE5ACooooo3_lP820=o`P820go3@d=1_ooool>obDU9@ko6a/K3_lV9RH<ob<S
8`Kooooo3_lN7Qh>oa8B4Q_o1`L71Oooool>oa<C4`ko0@413_l<30`=ocXj>Pgooooo000;ooooo`ko
gmoO3_nj^[X>olK6aPgoaLG51Oooool>od];B`ko;bl_3_l;2`/=oaLG5`Kooooo3Ol@410>o`X:2Pko
2`/;3Ol@4106ooooo`ko7alO3OlD51@>ocDe=@go5ADE5?ooool>ob0P80go20P83Ol=3@d6ooooo`ko
9BDU3_lK6a/>obHV9Pco8b<S1_ooool>oahN7Pko4Q8B6ol71`L5ooooo`ko4a<C3_l10@4>o``<30go
>SXj3Oooool000_ooooo3_oOgml>okZj^Pkoa/K63Oo5aLD5ooooo`koBd];3_l_;bl>o`/;2`go5aLG
1_ooool=oa0@40ko2PX:3_l;2`/=oa0@40Kooooo3_lO7al=oa@D50ko=CDe3OlE5ADDooooo`ko820P
3Ol820P=o`d=3@Kooooo3_lU9BD>oa/K6`ko9RHV3?lS8b<6ooooo`ko7QhN3_lB4Q8Ko`L71`Gooooo
3_lC4a<>o`410@ko30`<3Olj>SX=ooooo`002oooool>omoOg`ko^[Zj3_o6a/H=olG5a@Gooooo3_m;
Bd/>obl_;`ko2`/;3OlG5aL6ooooo`go410@3_l:2PX>o`/;2`go410@1_ooool>oalO7`go51@D3_le
=CD=oaDE5ACooooo3_lP820=o`P820go3@d=1_ooool>obDU9@ko6a/K3_lV9RH<ob<S8`Kooooo3_lN
7Qh>oa8B4Q_o1`L71Oooool>oa<C4`ko0@413_l<30`=ocXj>Pgooooo000;ooooo`kogmoO3_nj^[X>
olK6aPgoaLG51Oooool>od];B`ko;bl_3_l;2`/=oaLG5`Kooooo3Ol@410>o`X:2Pko2`/;3Ol@4106
ooooo`ko7alO3OlD51@>ocDe=@go5ADE5?ooool>ob0P80go20P83Ol=3@d6ooooo`ko9BDU3_lK6a/>
obHV9Pco8b<S1_ooool>oahN7Pko4Q8B6ol71`L5ooooo`ko4a<C3_l10@4>o``<30go>SXj3Oooool0
00_ooooo3_oOgml>okZj^Pkoa/K63Oo5aLD5ooooo`koBd];3_l_;bl>o`/;2`go5aLG1_ooool=oa0@
40ko2PX:3_l;2`/=oa0@40Kooooo3_lO7al=oa@D50ko=CDe3OlE5ADDooooo`ko820P3Ol820P=o`d=
3@Kooooo3_lU9BD>oa/K6`ko9RHV3?lS8b<6ooooo`ko7QhN3_lB4Q8Ko`L71`Gooooo3_lC4a<>o`41
0@ko30`<3Olj>SX=ooooo`002oooool>omoOg`ko^[Zj3_o6a/H=olG5a@Gooooo3_m;Bd/>obl_;`ko
2`/;3OlG5aL6ooooo`go410@3_l:2PX>o`/;2`go410@1_ooool>oalO7`go51@D3_le=CD=oaDE5ACo
oooo3_lP820=o`P820go3@d=1_ooool>obDU9@ko6a/K3_lV9RH<ob<S8`Kooooo3_lN7Qh>oa8B4Q_o
1`L71Oooool>oa<C4`ko0@413_l<30`=ocXj>Pgooooo000;ooooo`kogmoO3_nj^[X>olK6aPgoaLG5
1Oooool>od];B`ko;bl_3_l;2`/=oaLG5`Kooooo3Ol@410>o`X:2Pko2`/;3Ol@4106ooooo`ko7alO
3OlD51@>ocDe=@go5ADE5?ooool>ob0P80go20P83Ol=3@d6ooooo`ko9BDU3_lK6a/>obHV9Pco8b<S
1_ooool>oahN7Pko4Q8B6ol71`L5ooooo`ko4a<C3_l10@4>o``<30go>SXj3Oooool000_ooooo3_oO
gml>okZj^Pkoa/K63Oo5aLD5ooooo`koBd];3_l_;bl>o`/;2`go5aLG1_ooool=oa0@40ko2PX:3_l;
2`/=oa0@40Kooooo3_lO7al=oa@D50ko=CDe3OlE5ADDooooo`ko820P3Ol820P=o`d=3@Kooooo3_lU
9BD>oa/K6`ko9RHV3?lS8b<6ooooo`ko7QhN3_lB4Q8Ko`L71`Gooooo3_lC4a<>o`410@ko30`<3Olj
>SX=ooooo`002oooool>omoOg`ko^[Zj3_o6a/H=olG5a@Gooooo3_m;Bd/>obl_;`ko2`/;3OlG5aL6
ooooo`go410@3_l:2PX>o`/;2`go410@1_ooool>oalO7`go51@D3_le=CD=oaDE5ACooooo3_lP820=
o`P820go3@d=1_ooool>obDU9@ko6a/K3_lV9RH<ob<S8`Kooooo3_lN7Qh>oa8B4Q_o1`L71Oooool>
oa<C4`ko0@413_l<30`=ocXj>Pgooooo000;ooooo`kogmoO3_nj^[X>olK6aPgoaLG51Oooool>od];
B`ko;bl_3_l;2`/=oaLG5`Kooooo3Ol@410>o`X:2Pko2`/;3Ol@4106ooooo`ko7alO3OlD51@>ocDe
=@go5ADE5?ooool>ob0P80go20P83Ol=3@d6ooooo`ko9BDU3_lK6a/>obHV9Pco8b<S1_ooool>oahN
7Pko4Q8B6ol71`L5ooooo`ko4a<C3_l10@4>o``<30go>SXj3Oooool000_ooooo3_oOgml>okZj^Pko
a/K63Oo5aLD5ooooo`koBd];3_l_;bl>o`/;2`go5aLG1_ooool=oa0@40ko2PX:3_l;2`/=oa0@40Ko
oooo3_lO7al=oa@D50ko=CDe3OlE5ADDooooo`ko820P3Ol820P=o`d=3@Kooooo3_lU9BD>oa/K6`ko
9RHV3?lS8b<6ooooo`ko7QhN3_lB4Q8Ko`L71`Gooooo3_lC4a<>o`410@ko30`<3Olj>SX=ooooo`00
2oooool>omoOg`ko^[Zj3_o6a/H=olG5a@Gooooo3_m;Bd/>obl_;`ko2`/;3OlG5aL6ooooo`go410@
3_l:2PX>o`/;2`go410@1_ooool>oalO7`go51@D3_le=CD=oaDE5ACooooo3_lP820=o`P820go3@d=
1_ooool>obDU9@ko6a/K3_lV9RH<ob<S8`Kooooo3_lN7Qh>oa8B4Q_o1`L71Oooool>oa<C4`ko0@41
3_l<30`=ocXj>Pgooooo000;ooooo`ko=cLg3_mDE5@>o`0000goL71`1Oooool>o``<30ko@T923_l0
000=o`@410Kooooo3OlI6ATLoa<C4a?ooooo3_lQ8B4=ob<S8`kooooo3OlL71`6ooooo`ko2`/;3_lD
51@=oaDE5@go<S8b1_ooool>oaLG5`koADE53_lI6AT<ob/[:`Kooooo3_m_Kfl>oe9BDPko>3Ph3Ol0
0005ooooo`koHV9R3_ooool>ocPh>0go1PH63Oooool000_ooooo3_lg=cL>oeADE0ko00003Om`L705
ooooo`ko30`<3_m2@T8>o`0000go10@41_ooool=oaTI6Aco4a<C4oooool>ob4Q8@go8b<S3_ooool=
oa`L70Kooooo3_l;2`/>oa@D50go5ADE3Olb<S86ooooo`ko5aLG3_m5ADD>oaTI6@co:b/[1_ooool>
ofm_K`koDU9B3_lh>3P=o`0000Gooooo3_mRHV8>ooooo`ko>3Ph3Ol61PH=ooooo`002oooool>ocLg
=`koE5AD3_l0000=og1`L0Gooooo3_l<30`>od92@Pko00003Ol410@6ooooo`go6ATI7?lC4a<Coooo
o`ko8B4Q3OlS8b<>ooooo`go71`L1_ooool>o`/;2`ko51@D3OlE5AD=oc8b<PKooooo3_lG5aL>odE5
A@ko6ATI3?l[:b/6ooooo`koKfm_3_mBDU8>ocPh>0go00001Oooool>of9RHPkooooo3_lh>3P=o`H6
1Pgooooo000;ooooo`ko=cLg3_mDE5@>o`0000goL71`1Oooool>o``<30ko@T923_l0000=o`@410Ko
oooo3OlI6ATLoa<C4a?ooooo3_lQ8B4=ob<S8`kooooo3OlL71`6ooooo`ko2`/;3_lD51@=oaDE5@go
<S8b1_ooool>oaLG5`koADE53_lI6AT<ob/[:`Kooooo3_m_Kfl>oe9BDPko>3Ph3Ol00005ooooo`ko
HV9R3_ooool>ocPh>0go1PH63Oooool000_ooooo3_lg=cL>oeADE0ko00003Om`L705ooooo`ko30`<
3_m2@T8>o`0000go10@41_ooool=oaTI6Aco4a<C4oooool>ob4Q8@go8b<S3_ooool=oa`L70Kooooo
3_l;2`/>oa@D50go5ADE3Olb<S86ooooo`ko5aLG3_m5ADD>oaTI6@co:b/[1_ooool>ofm_K`koDU9B
3_lh>3P=o`0000Gooooo3_mRHV8>ooooo`ko>3Ph3Ol61PH=ooooo`002oooool>ocLg=`koE5AD3_l0
000=og1`L0Gooooo3_l<30`>od92@Pko00003Ol410@6ooooo`go6ATI7?lC4a<Cooooo`ko8B4Q3OlS
8b<>ooooo`go71`L1_ooool>o`/;2`ko51@D3OlE5AD=oc8b<PKooooo3_lG5aL>odE5A@ko6ATI3?l[
:b/6ooooo`koKfm_3_mBDU8>ocPh>0go00001Oooool>of9RHPkooooo3_lh>3P=o`H61Pgooooo000;
ooooo`ko=cLg3_mDE5@>o`0000goL71`1Oooool>o``<30ko@T923_l0000=o`@410Kooooo3OlI6ATL
oa<C4a?ooooo3_lQ8B4=ob<S8`kooooo3OlL71`6ooooo`ko2`/;3_lD51@=oaDE5@go<S8b1_ooool>
oaLG5`koADE53_lI6AT<ob/[:`Kooooo3_m_Kfl>oe9BDPko>3Ph3Ol00005ooooo`koHV9R3_ooool>
ocPh>0go1PH63Oooool000_ooooo3_lg=cL>oeADE0ko00003Om`L705ooooo`ko30`<3_m2@T8>o`00
00go10@41_ooool=oaTI6Aco4a<C4oooool>ob4Q8@go8b<S3_ooool=oa`L70Kooooo3_l;2`/>oa@D
50go5ADE3Olb<S86ooooo`ko5aLG3_m5ADD>oaTI6@co:b/[1_ooool>ofm_K`koDU9B3_lh>3P=o`00
00Gooooo3_mRHV8>ooooo`ko>3Ph3Ol61PH=ooooo`002oooool>ocLg=`koE5AD3_l0000=og1`L0Go
oooo3_l<30`>od92@Pko00003Ol410@6ooooo`go6ATI7?lC4a<Cooooo`ko8B4Q3OlS8b<>ooooo`go
71`L1_ooool>o`/;2`ko51@D3OlE5AD=oc8b<PKooooo3_lG5aL>odE5A@ko6ATI3?l[:b/6ooooo`ko
Kfm_3_mBDU8>ocPh>0go00001Oooool>of9RHPkooooo3_lh>3P=o`H61Pgooooo000;ooooo`ko=cLg
3_mDE5@>o`0000goL71`1Oooool>o``<30ko@T923_l0000=o`@410Kooooo3OlI6ATLoa<C4a?ooooo
3_lQ8B4=ob<S8`kooooo3OlL71`6ooooo`ko2`/;3_lD51@=oaDE5@go<S8b1_ooool>oaLG5`koADE5
3_lI6AT<ob/[:`Kooooo3_m_Kfl>oe9BDPko>3Ph3Ol00005ooooo`koHV9R3_ooool>ocPh>0go1PH6
3Oooool000_ooooo3_lg=cL>oeADE0ko00003Om`L705ooooo`ko30`<3_m2@T8>o`0000go10@41_oo
ool=oaTI6Aco4a<C4oooool>ob4Q8@go8b<S3_ooool=oa`L70Kooooo3_l;2`/>oa@D50go5ADE3Olb
<S86ooooo`ko5aLG3_m5ADD>oaTI6@co:b/[1_ooool>ofm_K`koDU9B3_lh>3P=o`0000Gooooo3_mR
HV8>ooooo`ko>3Ph3Ol61PH=ooooo`002oooool>ocLg=`koE5AD3_l0000=og1`L0Gooooo3_l<30`>
od92@Pko00003Ol410@6ooooo`go6ATI7?lC4a<Cooooo`ko8B4Q3OlS8b<>ooooo`go71`L1_ooool>
o`/;2`ko51@D3OlE5AD=oc8b<PKooooo3_lG5aL>odE5A@ko6ATI3?l[:b/6ooooo`koKfm_3_mBDU8>
ocPh>0go00001Oooool>of9RHPkooooo3_lh>3P=o`H61Pgooooo000;ooooo`ko=cLg3_mDE5@>o`00
00goL71`1Oooool>o``<30ko@T923_l0000=o`@410Kooooo3OlI6ATLoa<C4a?ooooo3_lQ8B4=ob<S
8`kooooo3OlL71`6ooooo`ko2`/;3_lD51@=oaDE5@go<S8b1_ooool>oaLG5`koADE53_lI6AT<ob/[
:`Kooooo3_m_Kfl>oe9BDPko>3Ph3Ol00005ooooo`koHV9R3_ooool>ocPh>0go1PH63Oooool000_o
oooo3_lg=cL>oeADE0ko00003Om`L705ooooo`ko30`<3_m2@T8>o`0000go10@41_ooool=oaTI6Aco
4a<C4oooool>ob4Q8@go8b<S3_ooool=oa`L70Kooooo3_l;2`/>oa@D50go5ADE3Olb<S86ooooo`ko
5aLG3_m5ADD>oaTI6@co:b/[1_ooool>ofm_K`koDU9B3_lh>3P=o`0000Gooooo3_mRHV8>ooooo`ko
>3Ph3Ol61PH=ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-0.869594, -0.874171, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-5.26781, \
-0.874171, 0.0732273, 0.0732273}, {{132, 186.625}, {487.062, 432.438}} -> \
{-9.66602, -0.874171, 0.0732273, 0.0732273}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-14.0688, -0.874171, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {487.062, 432.438}} -> {-18.467, -0.874171, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {487.062, 432.438}} -> {-22.8698, -0.874171, 0.0732273, \
0.0732273}, {{372.375, 427}, {487.062, 432.438}} -> {-27.268, -0.874171, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {487.062, 432.438}} -> {-31.6662, \
-0.874171, 0.0732273, 0.0732273}, {{11.875, 66.5}, {427, 372.375}} -> \
{-0.869594, -5.27238, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {427, \
372.375}} -> {-5.26781, -5.27238, 0.0732273, 0.0732273}, {{132, 186.625}, \
{427, 372.375}} -> {-9.66602, -5.27238, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {427, 372.375}} -> {-14.0688, -5.27238, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {427, 372.375}} -> {-18.467, -5.27238, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {427, 372.375}} -> {-22.8698, -5.27238, \
0.0732273, 0.0732273}, {{372.375, 427}, {427, 372.375}} -> {-27.268, \
-5.27238, 0.0732273, 0.0732273}, {{432.438, 487.062}, {427, 372.375}} -> \
{-31.6662, -5.27238, 0.0732273, 0.0732273}, {{11.875, 66.5}, {366.938, \
312.312}} -> {-0.869594, -9.6706, 0.0732273, 0.0732273}, {{71.9375, 126.562}, \
{366.938, 312.312}} -> {-5.26781, -9.6706, 0.0732273, 0.0732273}, {{132, \
186.625}, {366.938, 312.312}} -> {-9.66602, -9.6706, 0.0732273, 0.0732273}, \
{{192.125, 246.75}, {366.938, 312.312}} -> {-14.0688, -9.6706, 0.0732273, \
0.0732273}, {{252.188, 306.812}, {366.938, 312.312}} -> {-18.467, -9.6706, \
0.0732273, 0.0732273}, {{312.312, 366.938}, {366.938, 312.312}} -> {-22.8698, \
-9.6706, 0.0732273, 0.0732273}, {{372.375, 427}, {366.938, 312.312}} -> \
{-27.268, -9.6706, 0.0732273, 0.0732273}, {{432.438, 487.062}, {366.938, \
312.312}} -> {-31.6662, -9.6706, 0.0732273, 0.0732273}, {{11.875, 66.5}, \
{306.812, 252.188}} -> {-0.869594, -14.0734, 0.0732273, 0.0732273}, \
{{71.9375, 126.562}, {306.812, 252.188}} -> {-5.26781, -14.0734, 0.0732273, \
0.0732273}, {{132, 186.625}, {306.812, 252.188}} -> {-9.66602, -14.0734, \
0.0732273, 0.0732273}, {{192.125, 246.75}, {306.812, 252.188}} -> {-14.0688, \
-14.0734, 0.0732273, 0.0732273}, {{252.188, 306.812}, {306.812, 252.188}} -> \
{-18.467, -14.0734, 0.0732273, 0.0732273}, {{312.312, 366.938}, {306.812, \
252.188}} -> {-22.8698, -14.0734, 0.0732273, 0.0732273}, {{372.375, 427}, \
{306.812, 252.188}} -> {-27.268, -14.0734, 0.0732273, 0.0732273}, {{432.438, \
487.062}, {306.812, 252.188}} -> {-31.6662, -14.0734, 0.0732273, 0.0732273}, \
{{11.875, 66.5}, {246.75, 192.125}} -> {-0.869594, -18.4716, 0.0732273, \
0.0732273}, {{71.9375, 126.562}, {246.75, 192.125}} -> {-5.26781, -18.4716, \
0.0732273, 0.0732273}, {{132, 186.625}, {246.75, 192.125}} -> {-9.66602, \
-18.4716, 0.0732273, 0.0732273}, {{192.125, 246.75}, {246.75, 192.125}} -> \
{-14.0688, -18.4716, 0.0732273, 0.0732273}, {{252.188, 306.812}, {246.75, \
192.125}} -> {-18.467, -18.4716, 0.0732273, 0.0732273}, {{312.312, 366.938}, \
{246.75, 192.125}} -> {-22.8698, -18.4716, 0.0732273, 0.0732273}, {{372.375, \
427}, {246.75, 192.125}} -> {-27.268, -18.4716, 0.0732273, 0.0732273}, \
{{432.438, 487.062}, {246.75, 192.125}} -> {-31.6662, -18.4716, 0.0732273, \
0.0732273}, {{11.875, 66.5}, {186.625, 132}} -> {-0.869594, -22.8744, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {186.625, 132}} -> {-5.26781, \
-22.8744, 0.0732273, 0.0732273}, {{132, 186.625}, {186.625, 132}} -> \
{-9.66602, -22.8744, 0.0732273, 0.0732273}, {{192.125, 246.75}, {186.625, \
132}} -> {-14.0688, -22.8744, 0.0732273, 0.0732273}, {{252.188, 306.812}, \
{186.625, 132}} -> {-18.467, -22.8744, 0.0732273, 0.0732273}, {{312.312, \
366.938}, {186.625, 132}} -> {-22.8698, -22.8744, 0.0732273, 0.0732273}, \
{{372.375, 427}, {186.625, 132}} -> {-27.268, -22.8744, 0.0732273, \
0.0732273}, {{432.438, 487.062}, {186.625, 132}} -> {-31.6662, -22.8744, \
0.0732273, 0.0732273}, {{11.875, 66.5}, {126.562, 71.9375}} -> {-0.869594, \
-27.2726, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {126.562, 71.9375}} -> \
{-5.26781, -27.2726, 0.0732273, 0.0732273}, {{132, 186.625}, {126.562, \
71.9375}} -> {-9.66602, -27.2726, 0.0732273, 0.0732273}, {{192.125, 246.75}, \
{126.562, 71.9375}} -> {-14.0688, -27.2726, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {126.562, 71.9375}} -> {-18.467, -27.2726, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {126.562, 71.9375}} -> {-22.8698, -27.2726, 0.0732273, \
0.0732273}, {{372.375, 427}, {126.562, 71.9375}} -> {-27.268, -27.2726, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {126.562, 71.9375}} -> {-31.6662, \
-27.2726, 0.0732273, 0.0732273}, {{11.875, 66.5}, {66.5, 11.875}} -> \
{-0.869594, -31.6708, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {66.5, \
11.875}} -> {-5.26781, -31.6708, 0.0732273, 0.0732273}, {{132, 186.625}, \
{66.5, 11.875}} -> {-9.66602, -31.6708, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {66.5, 11.875}} -> {-14.0688, -31.6708, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {66.5, 11.875}} -> {-18.467, -31.6708, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {66.5, 11.875}} -> {-22.8698, -31.6708, \
0.0732273, 0.0732273}, {{372.375, 427}, {66.5, 11.875}} -> {-27.268, \
-31.6708, 0.0732273, 0.0732273}, {{432.438, 487.062}, {66.5, 11.875}} -> \
{-31.6662, -31.6708, 0.0732273, 0.0732273}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0FFF1DA7
0FAD2ABA
00922DC9
138928B7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5B2605FF
071D0900
172F1342
0E080833
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF4F008A
A2410DA1
32131563
1117227E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
69CBE713
8AF4E200
B6FFD704
86EAC505
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A3D0034
05964C3A
8FFF6DAC
263A59AB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A7AE4279
DDA54BFF
D87692FC
DE006398
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D05707D0
F34A00D4
F25600FF
BC4F02EA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
006ADB50
177BEC9D
0277FFB6
3F53B8CD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D77F2C23
FF3A312A
B300226F
2E1711CD
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
092B082D
681D03FF
3D33001A
2C0B0A12
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05907E37
00A89A2E
029BD71B
3677FF15
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
68F51007
70FF1113
66FF050C
57CE001B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
87FF4403
B8E03A00
D5D50C13
8CC1161C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C182400
22520F28
242202FF
0C130D3A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9C0FC114
C400FF24
F308F92F
A809E02E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
40FF6B24
26071D52
1E0C1F20
0D00174F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17100BE3
0A0C0AF8
060518FF
0B0017F9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3B1E26FF
73391A1C
2526001D
231C3B17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D1D3A83
041A76A8
0017F2C5
0C21FF6B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F003CA7
342C6491
41A1AE35
94FF5B0D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
114A9FDF
047A73CD
00B265B0
0EFF3160
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
261A00E3
0A1004FF
000C0FF0
03120FD1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
32440743
82600F24
FF4C0E3D
F7290052
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5000AC1A
5A0BE407
4806FF10
2B07E809
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D942140
00C70A2F
1AFF2B36
16F93C3B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
620B5599
4D093BF0
480027FF
3A0D35DA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1612C23F
0517EE34
002EFF2F
1237F10E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
39C0521E
45FF5317
12192915
0D00040A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00AE2C2F
02E8200B
13F60D00
1AFF0C09
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B0F2551
1C092042
2F333200
3B1613FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8F1C1829
FF250073
8919075C
2E121F36
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
102FA977
1724FF7E
0637476D
0022322B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
01FA33A3
00FF10AB
30A50C9D
2E4C1CA3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
15001EFF
0808309E
0E184126
16130D0B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF332D30
371F222F
002B3726
2435062E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D4845100
FF9C5706
D6AE5E10
A17E400E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05002125
10161211
1CFF5403
1903071B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D839FE8F
D304DE9A
FF009D8F
CF1C6D68
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F13B122E
FF320020
F7351023
CF272825
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0CD9DA27
03E2FF1F
00E8F025
09C6D11B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BB13052A
CC050018
FF0A0019
E41D0003
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
17171717
170B22FF
23111D17
000D1A3D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0652FF2C
0B83BF18
05B85A01
1D7A3600
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0CA54E26
00D52F18
00FF291B
0FE9191D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3FBE3633
67A21E0E
AF5F1600
FF242309
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B081266
2600270D
460C15FF
301B1C16
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD096602
E9008D0C
A80FD62F
641CFF1A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C0AFF3B
1223131B
00001F2D
13061628
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D132EBD
0D0D1BF4
000829FF
100318C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
292137FF
15004A79
180E3516
1B133300
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5C1B5849
41106A81
3211B6CB
4200FFA4
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E300C00
25281E30
15281B0E
13FF6635
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
66020C12
251C0047
0673126D
18FF0D99
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0919156D
1C0013FF
230441EA
0A1B1409
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
23005C50
34003457
AB232B47
FF540F50
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A1ACA2E
001BE51D
0716FF25
0817C12C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF36A7E1
FD1E96CE
9A179DA8
98009DFC
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8F1004F9
8D000DFF
9E0E10C7
6F151493
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2052EF0F
1F2CFF00
2A0FE401
3006C42A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0E001435
13FF7035
4217197A
0D160C17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
57FF0A20
61D80208
57BF1200
33862601
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
27170B23
2C101323
320700D8
220417FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E432000E
F1140E15
F00C2023
FF0C2612
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
210EC277
080FFF72
0A2AB983
00454BD0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool>o`l?3`kooooo3_lM7Ad=ojNWY`Gooooo
3_mKFe/>obHV9Pko1@D58?ooool>odm?C`ko00003On:RXX6ooooo`koJFUY3Oo;bl/>onOWi`go4a<C
1_ooool>obXZ:Pko?Cdm3Ol0000=oc@d=0Kooooo3_nWYjL>ojj^[Pko@T923?miNGT6ooooo`kod=3@
3_mGEeL>o`L71`god=3@1Oooool>o`0000koJVYZ3_oKfm/=oe1@D0gooooo000;ooooo`ko3`l?3_oo
ool>oadM7@goYjNW1Oooool>oe]KF`ko9RHV3_l51@DPooooo`koCdm?3_l0000=ohZ:RPKooooo3_mY
JFT=ol_;b`koinOW3OlC4a<6ooooo`ko:RXZ3_lm?Cd=o`0000go=3@d1_ooool>ojNWY`ko[Zj^3_m2
@T8<ogUiN@Kooooo3_o@d=0>oeMGE`ko1`L73Oo@d=05ooooo`ko00003_mZJVX>om_Kf`goD51@3Ooo
ool000_ooooo3_l?3`l>ooooo`ko7AdM3OnWYjL5ooooo`koFe]K3_lV9RH>o`D51B3ooooo3_m?Cdl>
o`0000goRXZ:1_ooool>ofUYJ@gobl_;3_oWinL=oa<C4`Kooooo3_lZ:RX>ocdm?@go00003Old=3@6
ooooo`koYjNW3_n^[Zh>od92@PcoNGUi1_ooool>om3@d0koEeMG3_l71`L=om3@d0Gooooo3_l0000>
ofYZJPkofm_K3Om@D50=ooooo`002oooool>o`l?3`kooooo3_lM7Ad=ojNWY`Gooooo3_mKFe/>obHV
9Pko1@D58?ooool>odm?C`ko00003On:RXX6ooooo`koJFUY3Oo;bl/>onOWi`go4a<C1_ooool>obXZ
:Pko?Cdm3Ol0000=oc@d=0Kooooo3_nWYjL>ojj^[Pko@T923?miNGT6ooooo`kod=3@3_mGEeL>o`L7
1`god=3@1Oooool>o`0000koJVYZ3_oKfm/=oe1@D0gooooo000;ooooo`ko3`l?3_ooool>oadM7@go
YjNW1Oooool>oe]KF`ko9RHV3_l51@DPooooo`koCdm?3_l0000=ohZ:RPKooooo3_mYJFT=ol_;b`ko
inOW3OlC4a<6ooooo`ko:RXZ3_lm?Cd=o`0000go=3@d1_ooool>ojNWY`ko[Zj^3_m2@T8<ogUiN@Ko
oooo3_o@d=0>oeMGE`ko1`L73Oo@d=05ooooo`ko00003_mZJVX>om_Kf`goD51@3Oooool000_ooooo
3_l?3`l>ooooo`ko7AdM3OnWYjL5ooooo`koFe]K3_lV9RH>o`D51B3ooooo3_m?Cdl>o`0000goRXZ:
1_ooool>ofUYJ@gobl_;3_oWinL=oa<C4`Kooooo3_lZ:RX>ocdm?@go00003Old=3@6ooooo`koYjNW
3_n^[Zh>od92@PcoNGUi1_ooool>om3@d0koEeMG3_l71`L=om3@d0Gooooo3_l0000>ofYZJPkofm_K
3Om@D50=ooooo`002oooool>o`l?3`kooooo3_lM7Ad=ojNWY`Gooooo3_mKFe/>obHV9Pko1@D58?oo
ool>odm?C`ko00003On:RXX6ooooo`koJFUY3Oo;bl/>onOWi`go4a<C1_ooool>obXZ:Pko?Cdm3Ol0
000=oc@d=0Kooooo3_nWYjL>ojj^[Pko@T923?miNGT6ooooo`kod=3@3_mGEeL>o`L71`god=3@1Ooo
ool>o`0000koJVYZ3_oKfm/=oe1@D0gooooo000;ooooo`ko3`l?3_ooool>oadM7@goYjNW1Oooool>
oe]KF`ko9RHV3_l51@DPooooo`koCdm?3_l0000=ohZ:RPKooooo3_mYJFT=ol_;b`koinOW3OlC4a<6
ooooo`ko:RXZ3_lm?Cd=o`0000go=3@d1_ooool>ojNWY`ko[Zj^3_m2@T8<ogUiN@Kooooo3_o@d=0>
oeMGE`ko1`L73Oo@d=05ooooo`ko00003_mZJVX>om_Kf`goD51@3Oooool000_ooooo3_l?3`l>oooo
o`ko7AdM3OnWYjL5ooooo`koFe]K3_lV9RH>o`D51B3ooooo3_m?Cdl>o`0000goRXZ:1_ooool>ofUY
J@gobl_;3_oWinL=oa<C4`Kooooo3_lZ:RX>ocdm?@go00003Old=3@6ooooo`koYjNW3_n^[Zh>od92
@PcoNGUi1_ooool>om3@d0koEeMG3_l71`L=om3@d0Gooooo3_l0000>ofYZJPkofm_K3Om@D50=oooo
o`002oooool>o`l?3`kooooo3_lM7Ad=ojNWY`Gooooo3_mKFe/>obHV9Pko1@D58?ooool>odm?C`ko
00003On:RXX6ooooo`koJFUY3Oo;bl/>onOWi`go4a<C1_ooool>obXZ:Pko?Cdm3Ol0000=oc@d=0Ko
oooo3_nWYjL>ojj^[Pko@T923?miNGT6ooooo`kod=3@3_mGEeL>o`L71`god=3@1Oooool>o`0000ko
JVYZ3_oKfm/=oe1@D0gooooo000;ooooo`ko3`l?3_ooool>oadM7@goYjNW1Oooool>oe]KF`ko9RHV
3_l51@DPooooo`koCdm?3_l0000=ohZ:RPKooooo3_mYJFT=ol_;b`koinOW3OlC4a<6ooooo`ko:RXZ
3_lm?Cd=o`0000go=3@d1_ooool>ojNWY`ko[Zj^3_m2@T8<ogUiN@Kooooo3_o@d=0>oeMGE`ko1`L7
3Oo@d=05ooooo`ko00003_mZJVX>om_Kf`goD51@3Oooool000_ooooo3_l?3`l>ooooo`ko7AdM3OnW
YjL5ooooo`koFe]K3_lV9RH>o`D51B3ooooo3_m?Cdl>o`0000goRXZ:1_ooool>ofUYJ@gobl_;3_oW
inL=oa<C4`Kooooo3_lZ:RX>ocdm?@go00003Old=3@6ooooo`koYjNW3_n^[Zh>od92@PcoNGUi1_oo
ool>om3@d0koEeMG3_l71`L=om3@d0Gooooo3_l0000>ofYZJPkofm_K3Om@D50=ooooo`002oooool>
o`l?3`kooooo3_lM7Ad=ojNWY`Gooooo3_mKFe/>obHV9Pko1@D58?ooool>odm?C`ko00003On:RXX6
ooooo`koJFUY3Oo;bl/>onOWi`go4a<C1_ooool>obXZ:Pko?Cdm3Ol0000=oc@d=0Kooooo3_nWYjL>
ojj^[Pko@T923?miNGT6ooooo`kod=3@3_mGEeL>o`L71`god=3@1Oooool>o`0000koJVYZ3_oKfm/=
oe1@D0gooooo000;ooooo`ko3`l?3_ooool>oadM7@goYjNW1Oooool>oe]KF`ko9RHV3_l51@DPoooo
o`koCdm?3_l0000=ohZ:RPKooooo3_mYJFT=ol_;b`koinOW3OlC4a<6ooooo`ko:RXZ3_lm?Cd=o`00
00go=3@d1_ooool>ojNWY`ko[Zj^3_m2@T8<ogUiN@Kooooo3_o@d=0>oeMGE`ko1`L73Oo@d=05oooo
o`ko00003_mZJVX>om_Kf`goD51@3Oooool000_ooooo3_l?3`l>ojf][@ko:RXZ3Onj^[X5ooooo`ko
1`L73_lM7Ad>o`T92@go00001_ooool=oj:RXPko@D513_l=3@d=oj6QX@Kooooo3_n:RXX=ooCdm0ko
h^;R3Ol00006ooooo`ko1@D53_nFUYH=oda<C0go>SXj1_ooool>omgMg@koYJFU3_m;Bd/Booooo`ko
lo?c3_m:BTX>o`0000goe=CD1Oooool>oaLG5`koNg]k3_o/k>`=oifMW@gooooo000;ooooo`ko3`l?
3_n][Jd>obXZ:Pgo^[Zj1Oooool>o`L71`ko7AdM3_l92@T=o`0000Kooooo3OnRXZ8>od51@@ko3@d=
3OnQXJ46ooooo`koRXZ:3Oodm?@>on;RhPgo00001_ooool>o`D51@koUYJF3Om<C4`=ocXj>PKooooo
3_oMgMd>ojFUY@koBd];4_ooool>oo?cl`koBTY:3_l0000=omCDe0Gooooo3_lG5aL>og]kN`kok>c/
3OnMWId=ooooo`002oooool>o`l?3`ko[Jf]3_lZ:RX=okZj^PGooooo3_l71`L>oadM7@ko2@T93Ol0
0006ooooo`goXZ:R3_m1@D4>o`d=3@goXJ6Q1_ooool>ohZ:RPgom?Cd3_oRh^8=o`0000Kooooo3_l5
1@D>oiJFUPgoC4a<3Olj>SX6ooooo`kogMgM3_nUYJD>od];Ba;ooooo3_oclo<>odY:BPko00003OoD
e=@5ooooo`ko5aLG3_mkNg/>onc/k0goWIfM3Oooool000_ooooo3_l?3`l>ojf][@ko:RXZ3Onj^[X5
ooooo`ko1`L73_lM7Ad>o`T92@go00001_ooool=oj:RXPko@D513_l=3@d=oj6QX@Kooooo3_n:RXX=
ooCdm0koh^;R3Ol00006ooooo`ko1@D53_nFUYH=oda<C0go>SXj1_ooool>omgMg@koYJFU3_m;Bd/B
ooooo`kolo?c3_m:BTX>o`0000goe=CD1Oooool>oaLG5`koNg]k3_o/k>`=oifMW@gooooo000;oooo
o`ko3`l?3_n][Jd>obXZ:Pgo^[Zj1Oooool>o`L71`ko7AdM3_l92@T=o`0000Kooooo3OnRXZ8>od51
@@ko3@d=3OnQXJ46ooooo`koRXZ:3Oodm?@>on;RhPgo00001_ooool>o`D51@koUYJF3Om<C4`=ocXj
>PKooooo3_oMgMd>ojFUY@koBd];4_ooool>oo?cl`koBTY:3_l0000=omCDe0Gooooo3_lG5aL>og]k
N`kok>c/3OnMWId=ooooo`002oooool>o`l?3`ko[Jf]3_lZ:RX=okZj^PGooooo3_l71`L>oadM7@ko
2@T93Ol00006ooooo`goXZ:R3_m1@D4>o`d=3@goXJ6Q1_ooool>ohZ:RPgom?Cd3_oRh^8=o`0000Ko
oooo3_l51@D>oiJFUPgoC4a<3Olj>SX6ooooo`kogMgM3_nUYJD>od];Ba;ooooo3_oclo<>odY:BPko
00003OoDe=@5ooooo`ko5aLG3_mkNg/>onc/k0goWIfM3Oooool000_ooooo3_l?3`l>ojf][@ko:RXZ
3Onj^[X5ooooo`ko1`L73_lM7Ad>o`T92@go00001_ooool=oj:RXPko@D513_l=3@d=oj6QX@Kooooo
3_n:RXX=ooCdm0koh^;R3Ol00006ooooo`ko1@D53_nFUYH=oda<C0go>SXj1_ooool>omgMg@koYJFU
3_m;Bd/Booooo`kolo?c3_m:BTX>o`0000goe=CD1Oooool>oaLG5`koNg]k3_o/k>`=oifMW@gooooo
000;ooooo`ko3`l?3_n][Jd>obXZ:Pgo^[Zj1Oooool>o`L71`ko7AdM3_l92@T=o`0000Kooooo3OnR
XZ8>od51@@ko3@d=3OnQXJ46ooooo`koRXZ:3Oodm?@>on;RhPgo00001_ooool>o`D51@koUYJF3Om<
C4`=ocXj>PKooooo3_oMgMd>ojFUY@koBd];4_ooool>oo?cl`koBTY:3_l0000=omCDe0Gooooo3_lG
5aL>og]kN`kok>c/3OnMWId=ooooo`002oooool>o`l?3`ko[Jf]3_lZ:RX=okZj^PGooooo3_l71`L>
oadM7@ko2@T93Ol00006ooooo`goXZ:R3_m1@D4>o`d=3@goXJ6Q1_ooool>ohZ:RPgom?Cd3_oRh^8=
o`0000Kooooo3_l51@D>oiJFUPgoC4a<3Olj>SX6ooooo`kogMgM3_nUYJD>od];Ba;ooooo3_oclo<>
odY:BPko00003OoDe=@5ooooo`ko5aLG3_mkNg/>onc/k0goWIfM3Oooool000_ooooo3_l?3`l>ojf]
[@ko:RXZ3Onj^[X5ooooo`ko1`L73_lM7Ad>o`T92@go00001_ooool=oj:RXPko@D513_l=3@d=oj6Q
X@Kooooo3_n:RXX=ooCdm0koh^;R3Ol00006ooooo`ko1@D53_nFUYH=oda<C0go>SXj1_ooool>omgM
g@koYJFU3_m;Bd/Booooo`kolo?c3_m:BTX>o`0000goe=CD1Oooool>oaLG5`koNg]k3_o/k>`=oifM
W@gooooo000;ooooo`ko3`l?3_n][Jd>obXZ:Pgo^[Zj1Oooool>o`L71`ko7AdM3_l92@T=o`0000Ko
oooo3OnRXZ8>od51@@ko3@d=3OnQXJ46ooooo`koRXZ:3Oodm?@>on;RhPgo00001_ooool>o`D51@ko
UYJF3Om<C4`=ocXj>PKooooo3_oMgMd>ojFUY@koBd];4_ooool>oo?cl`koBTY:3_l0000=omCDe0Go
oooo3_lG5aL>og]kN`kok>c/3OnMWId=ooooo`002oooool>o`l?3`ko[Jf]3_lZ:RX=okZj^PGooooo
3_l71`L>oadM7@ko2@T93Ol00006ooooo`goXZ:R3_m1@D4>o`d=3@goXJ6Q1_ooool>ohZ:RPgom?Cd
3_oRh^8=o`0000Kooooo3_l51@D>oiJFUPgoC4a<3Olj>SX6ooooo`kogMgM3_nUYJD>od];Ba;ooooo
3_oclo<>odY:BPko00003OoDe=@5ooooo`ko5aLG3_mkNg/>onc/k0goWIfM3Oooool000_ooooo3_l?
3`l>ojf][@ko:RXZ3Onj^[X5ooooo`ko1`L73_lM7Ad>o`T92@go00001_ooool=oj:RXPko@D513_l=
3@d=oj6QX@Kooooo3_n:RXX=ooCdm0koh^;R3Ol00006ooooo`ko1@D53_nFUYH=oda<C0go>SXj1_oo
ool>omgMg@koYJFU3_m;Bd/Booooo`kolo?c3_m:BTX>o`0000goe=CD1Oooool>oaLG5`koNg]k3_o/
k>`=oifMW@gooooo000;ooooo`ko00003_nBTY8>obd];@gobLW91Oooool>oaLG5`ko;bl_3_lC4a<=
od92@PKooooo3Olb<S8>oa<C4`ko5ADE3OmSHf<6ooooo`ko][Jf3Oooool>omOGe`go10@41_ooool>
ohn?S`kooooo3Om]KFd=ojb/[0Kooooo3_oHf=P>ogIfMPkoTY:B3?olo?`6ooooo`kol_;b3_mFEUH>
o`0001;ooooo3_l20P8>ogMgM`kooooo3Onf][H=ooooo`002oooool>o`0000koTY:B3_l];Bd=olW9
b@Gooooo3_lG5aL>obl_;`ko4a<C3Om2@T86ooooo`go<S8b3_lC4a<>oaDE5@goHf=S1_ooool>okJf
]Pgooooo3_oGemL=o`@410Kooooo3_n?Shl>ooooo`goKFe]3On/[:`6ooooo`kof=SH3_mfMWH>oi:B
TPcoo?cl1_ooool>oo;blPkoEUIF3_l0000Booooo`ko0P823_mgMgL>ooooo`go][Jf3Oooool000_o
oooo3_l0000>oi:BTPko;Bd]3Oo9bLT5ooooo`ko5aLG3_l_;bl>oa<C4`go@T921_ooool=oc8b<Pko
4a<C3_lE5AD=of=SH`Kooooo3_nf][H=ooooo`koemOG3Ol410@6ooooo`koShn?3_ooool=ofe]K@go
[:b/1_ooool>omSHf0koMWIf3_nBTY8<ooclo0Kooooo3_obl_8>oeIFEPko00004_ooool>o`820Pko
MgMg3_ooool=okJf]Pgooooo000;ooooo`ko00003_nBTY8>obd];@gobLW91Oooool>oaLG5`ko;bl_
3_lC4a<=od92@PKooooo3Olb<S8>oa<C4`ko5ADE3OmSHf<6ooooo`ko][Jf3Oooool>omOGe`go10@4
1_ooool>ohn?S`kooooo3Om]KFd=ojb/[0Kooooo3_oHf=P>ogIfMPkoTY:B3?olo?`6ooooo`kol_;b
3_mFEUH>o`0001;ooooo3_l20P8>ogMgM`kooooo3Onf][H=ooooo`002oooool>o`0000koTY:B3_l]
;Bd=olW9b@Gooooo3_lG5aL>obl_;`ko4a<C3Om2@T86ooooo`go<S8b3_lC4a<>oaDE5@goHf=S1_oo
ool>okJf]Pgooooo3_oGemL=o`@410Kooooo3_n?Shl>ooooo`goKFe]3On/[:`6ooooo`kof=SH3_mf
MWH>oi:BTPcoo?cl1_ooool>oo;blPkoEUIF3_l0000Booooo`ko0P823_mgMgL>ooooo`go][Jf3Ooo
ool000_ooooo3_l0000>oi:BTPko;Bd]3Oo9bLT5ooooo`ko5aLG3_l_;bl>oa<C4`go@T921_ooool=
oc8b<Pko4a<C3_lE5AD=of=SH`Kooooo3_nf][H=ooooo`koemOG3Ol410@6ooooo`koShn?3_ooool=
ofe]K@go[:b/1_ooool>omSHf0koMWIf3_nBTY8<ooclo0Kooooo3_obl_8>oeIFEPko00004_ooool>
o`820PkoMgMg3_ooool=okJf]Pgooooo000;ooooo`ko00003_nBTY8>obd];@gobLW91Oooool>oaLG
5`ko;bl_3_lC4a<=od92@PKooooo3Olb<S8>oa<C4`ko5ADE3OmSHf<6ooooo`ko][Jf3Oooool>omOG
e`go10@41_ooool>ohn?S`kooooo3Om]KFd=ojb/[0Kooooo3_oHf=P>ogIfMPkoTY:B3?olo?`6oooo
o`kol_;b3_mFEUH>o`0001;ooooo3_l20P8>ogMgM`kooooo3Onf][H=ooooo`002oooool>o`0000ko
TY:B3_l];Bd=olW9b@Gooooo3_lG5aL>obl_;`ko4a<C3Om2@T86ooooo`go<S8b3_lC4a<>oaDE5@go
Hf=S1_ooool>okJf]Pgooooo3_oGemL=o`@410Kooooo3_n?Shl>ooooo`goKFe]3On/[:`6ooooo`ko
f=SH3_mfMWH>oi:BTPcoo?cl1_ooool>oo;blPkoEUIF3_l0000Booooo`ko0P823_mgMgL>ooooo`go
][Jf3Oooool000_ooooo3_l0000>oi:BTPko;Bd]3Oo9bLT5ooooo`ko5aLG3_l_;bl>oa<C4`go@T92
1_ooool=oc8b<Pko4a<C3_lE5AD=of=SH`Kooooo3_nf][H=ooooo`koemOG3Ol410@6ooooo`koShn?
3_ooool=ofe]K@go[:b/1_ooool>omSHf0koMWIf3_nBTY8<ooclo0Kooooo3_obl_8>oeIFEPko0000
4_ooool>o`820PkoMgMg3_ooool=okJf]Pgooooo000;ooooo`ko00003_nBTY8>obd];@gobLW91Ooo
ool>oaLG5`ko;bl_3_lC4a<=od92@PKooooo3Olb<S8>oa<C4`ko5ADE3OmSHf<6ooooo`ko][Jf3Ooo
ool>omOGe`go10@41_ooool>ohn?S`kooooo3Om]KFd=ojb/[0Kooooo3_oHf=P>ogIfMPkoTY:B3?ol
o?`6ooooo`kol_;b3_mFEUH>o`0001;ooooo3_l20P8>ogMgM`kooooo3Onf][H=ooooo`002oooool>
o`0000koTY:B3_l];Bd=olW9b@Gooooo3_lG5aL>obl_;`ko4a<C3Om2@T86ooooo`go<S8b3_lC4a<>
oaDE5@goHf=S1_ooool>okJf]Pgooooo3_oGemL=o`@410Kooooo3_n?Shl>ooooo`goKFe]3On/[:`6
ooooo`kof=SH3_mfMWH>oi:BTPcoo?cl1_ooool>oo;blPkoEUIF3_l0000Booooo`ko0P823_mgMgL>
ooooo`go][Jf3Oooool000_ooooo3_l0000>oi:BTPko;Bd]3Oo9bLT5ooooo`ko5aLG3_l_;bl>oa<C
4`go@T921_ooool=oc8b<Pko4a<C3_lE5AD=of=SH`Kooooo3_nf][H=ooooo`koemOG3Ol410@6oooo
o`koShn?3_ooool=ofe]K@go[:b/1_ooool>omSHf0koMWIf3_nBTY8<ooclo0Kooooo3_obl_8>oeIF
EPko00004_ooool>o`820PkoMgMg3_ooool=okJf]Pgooooo000;ooooo`ko00003_nBTY8>obd];@go
bLW91Oooool>oaLG5`ko;bl_3_lC4a<=od92@PKooooo3Olb<S8>oa<C4`ko5ADE3OmSHf<6ooooo`ko
][Jf3Oooool>omOGe`go10@41_ooool>ohn?S`kooooo3Om]KFd=ojb/[0Kooooo3_oHf=P>ogIfMPko
TY:B3?olo?`6ooooo`kol_;b3_mFEUH>o`0001;ooooo3_l20P8>ogMgM`kooooo3Onf][H=ooooo`00
2oooool>o`0000koTY:B3_l];Bd=olW9b@Gooooo3_lG5aL>obl_;`ko4a<C3Om2@T86ooooo`go<S8b
3_lC4a<>oaDE5@goHf=S1_ooool>okJf]Pgooooo3_oGemL=o`@410Kooooo3_n?Shl>ooooo`goKFe]
3On/[:`6ooooo`kof=SH3_mfMWH>oi:BTPcoo?cl1_ooool>oo;blPkoEUIF3_l0000Booooo`ko0P82
3_mgMgL>ooooo`go][Jf3Oooool000_ooooo3_lC4a<>ohV9R@ko:2PX3Ong]kL5ooooo`ko3Ph>7?l8
20P=oc<c<`Kooooo3OlA4A4>oaLG5`ko8R8R3OmnOWh6ooooo`koQXJ63OoZj^X>olG5a@go1@D51_oo
ool>obHV9Pko>SXj3OmIFET=oj^[Z`Kooooo3_oNg]h>o`0000koHf=S3?nHV9P6ooooo`ko_;bl3_m?
Cdl>o`820Pgoj^[Z1Oooool>oclo?`koDe=C3_nh^;P=olg=c@gooooo000;ooooo`ko4a<C3_n9RHT>
obPX:0go]kNg1Oooool>o`h>3Qco20P83Olc<c<6ooooo`go4A4A3_lG5aL>ob8R8PgoOWin1_ooool>
ohJ6QPgoj^[Z3_o5aLD=o`D51@Kooooo3_lV9RH>ocXj>PgoFEUI3On[Zj/6ooooo`kog]kN3_l0000>
of=SH`coV9RH1_ooool>okbl_0koCdm?3_l20P8=on[ZjPGooooo3_lo?cl>oe=CD`ko^;Rh3Oo=cLd=
ooooo`002oooool>oa<C4`koRHV93_lX:2P=okNg]`Gooooo3_l>3PhLo`P820go<c<c1_ooool=oa4A
4@ko5aLG3_lR8R8=oginOPKooooo3_n6QXH=on[ZjPkoaLG53Ol51@D6ooooo`ko9RHV3_lj>SX=oeUI
F@goZj^[1_ooool>omkNgPko00003_mSHf<<oiRHV0Kooooo3_nl_;`>odm?C`ko0P823OoZj^X5oooo
o`ko?clo3_mCDe<>okRh^0gocLg=3Oooool000_ooooo3_lC4a<>ohV9R@ko:2PX3Ong]kL5ooooo`ko
3Ph>7?l820P=oc<c<`Kooooo3OlA4A4>oaLG5`ko8R8R3OmnOWh6ooooo`koQXJ63OoZj^X>olG5a@go
1@D51_ooool>obHV9Pko>SXj3OmIFET=oj^[Z`Kooooo3_oNg]h>o`0000koHf=S3?nHV9P6ooooo`ko
_;bl3_m?Cdl>o`820Pgoj^[Z1Oooool>oclo?`koDe=C3_nh^;P=olg=c@gooooo000;ooooo`ko4a<C
3_n9RHT>obPX:0go]kNg1Oooool>o`h>3Qco20P83Olc<c<6ooooo`go4A4A3_lG5aL>ob8R8PgoOWin
1_ooool>ohJ6QPgoj^[Z3_o5aLD=o`D51@Kooooo3_lV9RH>ocXj>PgoFEUI3On[Zj/6ooooo`kog]kN
3_l0000>of=SH`coV9RH1_ooool>okbl_0koCdm?3_l20P8=on[ZjPGooooo3_lo?cl>oe=CD`ko^;Rh
3Oo=cLd=ooooo`002oooool>oa<C4`koRHV93_lX:2P=okNg]`Gooooo3_l>3PhLo`P820go<c<c1_oo
ool=oa4A4@ko5aLG3_lR8R8=oginOPKooooo3_n6QXH=on[ZjPkoaLG53Ol51@D6ooooo`ko9RHV3_lj
>SX=oeUIF@goZj^[1_ooool>omkNgPko00003_mSHf<<oiRHV0Kooooo3_nl_;`>odm?C`ko0P823OoZ
j^X5ooooo`ko?clo3_mCDe<>okRh^0gocLg=3Oooool000_ooooo3_lC4a<>ohV9R@ko:2PX3Ong]kL5
ooooo`ko3Ph>7?l820P=oc<c<`Kooooo3OlA4A4>oaLG5`ko8R8R3OmnOWh6ooooo`koQXJ63OoZj^X>
olG5a@go1@D51_ooool>obHV9Pko>SXj3OmIFET=oj^[Z`Kooooo3_oNg]h>o`0000koHf=S3?nHV9P6
ooooo`ko_;bl3_m?Cdl>o`820Pgoj^[Z1Oooool>oclo?`koDe=C3_nh^;P=olg=c@gooooo000;oooo
o`ko4a<C3_n9RHT>obPX:0go]kNg1Oooool>o`h>3Qco20P83Olc<c<6ooooo`go4A4A3_lG5aL>ob8R
8PgoOWin1_ooool>ohJ6QPgoj^[Z3_o5aLD=o`D51@Kooooo3_lV9RH>ocXj>PgoFEUI3On[Zj/6oooo
o`kog]kN3_l0000>of=SH`coV9RH1_ooool>okbl_0koCdm?3_l20P8=on[ZjPGooooo3_lo?cl>oe=C
D`ko^;Rh3Oo=cLd=ooooo`002oooool>oa<C4`koRHV93_lX:2P=okNg]`Gooooo3_l>3PhLo`P820go
<c<c1_ooool=oa4A4@ko5aLG3_lR8R8=oginOPKooooo3_n6QXH=on[ZjPkoaLG53Ol51@D6ooooo`ko
9RHV3_lj>SX=oeUIF@goZj^[1_ooool>omkNgPko00003_mSHf<<oiRHV0Kooooo3_nl_;`>odm?C`ko
0P823OoZj^X5ooooo`ko?clo3_mCDe<>okRh^0gocLg=3Oooool000_ooooo3_lC4a<>ohV9R@ko:2PX
3Ong]kL5ooooo`ko3Ph>7?l820P=oc<c<`Kooooo3OlA4A4>oaLG5`ko8R8R3OmnOWh6ooooo`koQXJ6
3OoZj^X>olG5a@go1@D51_ooool>obHV9Pko>SXj3OmIFET=oj^[Z`Kooooo3_oNg]h>o`0000koHf=S
3?nHV9P6ooooo`ko_;bl3_m?Cdl>o`820Pgoj^[Z1Oooool>oclo?`koDe=C3_nh^;P=olg=c@gooooo
000;ooooo`ko4a<C3_n9RHT>obPX:0go]kNg1Oooool>o`h>3Qco20P83Olc<c<6ooooo`go4A4A3_lG
5aL>ob8R8PgoOWin1_ooool>ohJ6QPgoj^[Z3_o5aLD=o`D51@Kooooo3_lV9RH>ocXj>PgoFEUI3On[
Zj/6ooooo`kog]kN3_l0000>of=SH`coV9RH1_ooool>okbl_0koCdm?3_l20P8=on[ZjPGooooo3_lo
?cl>oe=CD`ko^;Rh3Oo=cLd=ooooo`002oooool>oa<C4`koRHV93_lX:2P=okNg]`Gooooo3_l>3PhL
o`P820go<c<c1_ooool=oa4A4@ko5aLG3_lR8R8=oginOPKooooo3_n6QXH=on[ZjPkoaLG53Ol51@D6
ooooo`ko9RHV3_lj>SX=oeUIF@goZj^[1_ooool>omkNgPko00003_mSHf<<oiRHV0Kooooo3_nl_;`>
odm?C`ko0P823OoZj^X5ooooo`ko?clo3_mCDe<>okRh^0gocLg=3Oooool000_ooooo3_lC4a<>ohV9
R@ko:2PX3Ong]kL5ooooo`ko3Ph>7?l820P=oc<c<`Kooooo3OlA4A4>oaLG5`ko8R8R3OmnOWh6oooo
o`koQXJ63OoZj^X>olG5a@go1@D51_ooool>obHV9Pko>SXj3OmIFET=oj^[Z`Kooooo3_oNg]h>o`00
00koHf=S3?nHV9P6ooooo`ko_;bl3_m?Cdl>o`820Pgoj^[Z1Oooool>oclo?`koDe=C3_nh^;P=olg=
c@gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[
3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L7
1_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL
3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_mo
Ogl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg
=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<
30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[
Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=
obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>
ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>
ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/
;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6oooo
o`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH
60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T
90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Ko
oooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`ko
oooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go
51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S
1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX
3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T
3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo
000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol5
1@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4
A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Ooo
ool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>
o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>
oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006
ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;oooo
o`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@
T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<3
0`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10
@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko
:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go
1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`ko
W9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG
3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin
3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo
3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo
3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l8
20P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_oo
ool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?
3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000;ooooo`koemOG3_moOgl>
ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd];@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6
ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>
oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71`@go51@D1Oooool>od10@0kooooo3_m[Jf/=
ob@T90gooooo000;ooooo`koemOG3_moOgl>ob`/;0go8b<S1Oooool>o`T92@ko:b/[3_l820P=obd]
;@Kooooo3Ol51@D>oi2@T0koOWin3Olg=cL6ooooo`koJ6QX3OoemOD>oa0@40go1`L71_ooool>ohN7
Q`kooooo3Om4A4@=o`<30`Kooooo3_l<30`>oaPH60ko92@T3?l00006ooooo`koW9bL3_l?3`l>ol71
`@go51@D1Oooool>od10@0kooooo3_m[Jf/=ob@T90gooooo000Iooooo`ko>SXj3_la<C4=obXZ:PGo
oooo3_mXJ6P>oadM7@ko0`<34oooool=o`0000koZ:RX3_nJVYX=obh^;PKooooo3_m`L70=ooooo`ko
4A4A3OlC4a<6ooooo`ko^;Rh3_oPh>0=ocXj>Pgo00001_ooool>ob8R8PkoDU9B3_l?3`l<obPX:0Ko
oooo3_o4a<@>o`0000kooooo3OlT92@5ooooo`ko9RHV3_l71`L>oadM7@goDU9B3Oooool001Wooooo
3_lj>SX>oc4a<@go:RXZ1Oooool>ofQXJ0ko7AdM3_l30`<Cooooo`go00003_nXZ:P>oiZJVPgo;Rh^
1_ooool>og1`L0gooooo3_lA4A4=oa<C4`Kooooo3_nh^;P>on3Ph0go>SXj3Ol00006ooooo`ko8R8R
3_mBDU8>o`l?3`co:2PX1_ooool>olC4a0ko00003_ooool=ob@T90Gooooo3_lV9RH>o`L71`ko7AdM
3OmBDU8=ooooo`006Oooool>ocXj>Pko<C4a3OlZ:RX5ooooo`koJ6QX3_lM7Ad>o`<30a?ooooo3Ol0
000>ojRXZ0koVYZJ3Ol^;Rh6ooooo`koL71`3Oooool>oa4A4@go4a<C1_ooool>okRh^0koh>3P3Olj
>SX=o`0000Kooooo3_lR8R8>oe9BDPko3`l?3?lX:2P6ooooo`koa<C43_l0000>ooooo`go92@T1Ooo
ool>obHV9Pko1`L73_lM7Ad=oe9BDPgooooo000Iooooo`ko>SXj3_la<C4=obXZ:PGooooo3_mXJ6P>
oadM7@ko0`<34oooool=o`0000koZ:RX3_nJVYX=obh^;PKooooo3_m`L70=ooooo`ko4A4A3OlC4a<6
ooooo`ko^;Rh3_oPh>0=ocXj>Pgo00001_ooool>ob8R8PkoDU9B3_l?3`l<obPX:0Kooooo3_o4a<@>
o`0000kooooo3OlT92@5ooooo`ko9RHV3_l71`L>oadM7@goDU9B3Oooool001Wooooo3_lj>SX>oc4a
<@go:RXZ1Oooool>ofQXJ0ko7AdM3_l30`<Cooooo`go00003_nXZ:P>oiZJVPgo;Rh^1_ooool>og1`
L0gooooo3_lA4A4=oa<C4`Kooooo3_nh^;P>on3Ph0go>SXj3Ol00006ooooo`ko8R8R3_mBDU8>o`l?
3`co:2PX1_ooool>olC4a0ko00003_ooool=ob@T90Gooooo3_lV9RH>o`L71`ko7AdM3OmBDU8=oooo
o`006Oooool>ocXj>Pko<C4a3OlZ:RX5ooooo`koJ6QX3_lM7Ad>o`<30a?ooooo3Ol0000>ojRXZ0ko
VYZJ3Ol^;Rh6ooooo`koL71`3Oooool>oa4A4@go4a<C1_ooool>okRh^0koh>3P3Olj>SX=o`0000Ko
oooo3_lR8R8>oe9BDPko3`l?3?lX:2P6ooooo`koa<C43_l0000>ooooo`go92@T1Oooool>obHV9Pko
1`L73_lM7Ad=oe9BDPgooooo000Iooooo`ko>SXj3_la<C4=obXZ:PGooooo3_mXJ6P>oadM7@ko0`<3
4oooool=o`0000koZ:RX3_nJVYX=obh^;PKooooo3_m`L70=ooooo`ko4A4A3OlC4a<6ooooo`ko^;Rh
3_oPh>0=ocXj>Pgo00001_ooool>ob8R8PkoDU9B3_l?3`l<obPX:0Kooooo3_o4a<@>o`0000kooooo
3OlT92@5ooooo`ko9RHV3_l71`L>oadM7@goDU9B3Oooool001Wooooo3_lj>SX>oc4a<@go:RXZ1Ooo
ool>ofQXJ0ko7AdM3_l30`<Cooooo`go00003_nXZ:P>oiZJVPgo;Rh^1_ooool>og1`L0gooooo3_lA
4A4=oa<C4`Kooooo3_nh^;P>on3Ph0go>SXj3Ol00006ooooo`ko8R8R3_mBDU8>o`l?3`co:2PX1_oo
ool>olC4a0ko00003_ooool=ob@T90Gooooo3_lV9RH>o`L71`ko7AdM3OmBDU8=ooooo`006Oooool>
ocXj>Pko<C4a3OlZ:RX5ooooo`koJ6QX3_lM7Ad>o`<30a?ooooo3Ol0000>ojRXZ0koVYZJ3Ol^;Rh6
ooooo`koL71`3Oooool>oa4A4@go4a<C1_ooool>okRh^0koh>3P3Olj>SX=o`0000Kooooo3_lR8R8>
oe9BDPko3`l?3?lX:2P6ooooo`koa<C43_l0000>ooooo`go92@T1Oooool>obHV9Pko1`L73_lM7Ad=
oe9BDPgooooo000Iooooo`ko>SXj3_la<C4=obXZ:PGooooo3_mXJ6P>oadM7@ko0`<34oooool=o`00
00koZ:RX3_nJVYX=obh^;PKooooo3_m`L70=ooooo`ko4A4A3OlC4a<6ooooo`ko^;Rh3_oPh>0=ocXj
>Pgo00001_ooool>ob8R8PkoDU9B3_l?3`l<obPX:0Kooooo3_o4a<@>o`0000kooooo3OlT92@5oooo
o`ko9RHV3_l71`L>oadM7@goDU9B3Oooool001Wooooo3_lj>SX>oc4a<@go:RXZ1Oooool>ofQXJ0ko
7AdM3_l30`<Cooooo`go00003_nXZ:P>oiZJVPgo;Rh^1_ooool>og1`L0gooooo3_lA4A4=oa<C4`Ko
oooo3_nh^;P>on3Ph0go>SXj3Ol00006ooooo`ko8R8R3_mBDU8>o`l?3`co:2PX1_ooool>olC4a0ko
00003_ooool=ob@T90Gooooo3_lV9RH>o`L71`ko7AdM3OmBDU8=ooooo`006Oooool>ocXj>Pko<C4a
3OlZ:RX5ooooo`koJ6QX3_lM7Ad>o`<30a?ooooo3Ol0000>ojRXZ0koVYZJ3Ol^;Rh6ooooo`koL71`
3Oooool>oa4A4@go4a<C1_ooool>okRh^0koh>3P3Olj>SX=o`0000Kooooo3_lR8R8>oe9BDPko3`l?
3?lX:2P6ooooo`koa<C43_l0000>ooooo`go92@T1Oooool>obHV9Pko1`L73_lM7Ad=oe9BDPgooooo
000Iooooo`ko>SXj3_la<C4=obXZ:PGooooo3_mXJ6P>oadM7@ko0`<34oooool=o`0000koZ:RX3_nJ
VYX=obh^;PKooooo3_m`L70=ooooo`ko4A4A3OlC4a<6ooooo`ko^;Rh3_oPh>0=ocXj>Pgo00001_oo
ool>ob8R8PkoDU9B3_l?3`l<obPX:0Kooooo3_o4a<@>o`0000kooooo3OlT92@5ooooo`ko9RHV3_l7
1`L>oadM7@goDU9B3Oooool000_ooooo3_nc/k<>o`0000ko8R8R3Om_Kfl5ooooo`ko?Cdm3_lc<c<>
o`0000go6QXJ1_ooool=o`820PkoVi^K3_oGemL=oa/K6`Kooooo3_mVIVH=ooooo`ko1@D53Ol<30`6
oooooacoeMGE3Ol<30`=oa<C4`Kooooo3_lT92@>ob8R8Pko0P824_ooool>oo?cl`ko20P83_oinOT=
obl_;`Gooooo3_lN7Qh>o``<30ko7alO3OlP820=ooooo`002oooool>ok>c/`ko00003_lR8R8=ofm_
K`Gooooo3_lm?Cd>oc<c<`ko00003OlJ6QX6ooooo`go0P823_nKVi/>omOGe`go6a/K1_ooool>ofIV
IPgooooo3_l51@D=o``<30Kooooo7?oEeMD=o``<30go4a<C1_ooool>ob@T90ko8R8R3_l20P8Boooo
o`kolo?c3_l820P>ooWin@go;bl_1Oooool>oahN7Pko30`<3_lO7al=ob0P80gooooo000;ooooo`ko
/k>c3_l0000>ob8R8PgoKfm_1Oooool>ocdm?@ko<c<c3_l0000=oaXJ6PKooooo3Ol20P8>oi^KV`ko
emOG3OlK6a/6ooooo`koIVIV3Oooool>o`D51@go30`<1_oooolLomGEe@go30`<3OlC4a<6ooooo`ko
92@T3_lR8R8>o`820Q;ooooo3_oclo<>o`P820konOWi3Ol_;bl5ooooo`ko7QhN3_l<30`>oalO7`go
820P3Oooool000_ooooo3_nc/k<>o`0000ko8R8R3Om_Kfl5ooooo`ko?Cdm3_lc<c<>o`0000go6QXJ
1_ooool=o`820PkoVi^K3_oGemL=oa/K6`Kooooo3_mVIVH=ooooo`ko1@D53Ol<30`6oooooacoeMGE
3Ol<30`=oa<C4`Kooooo3_lT92@>ob8R8Pko0P824_ooool>oo?cl`ko20P83_oinOT=obl_;`Gooooo
3_lN7Qh>o``<30ko7alO3OlP820=ooooo`002oooool>ok>c/`ko00003_lR8R8=ofm_K`Gooooo3_lm
?Cd>oc<c<`ko00003OlJ6QX6ooooo`go0P823_nKVi/>omOGe`go6a/K1_ooool>ofIVIPgooooo3_l5
1@D=o``<30Kooooo7?oEeMD=o``<30go4a<C1_ooool>ob@T90ko8R8R3_l20P8Booooo`kolo?c3_l8
20P>ooWin@go;bl_1Oooool>oahN7Pko30`<3_lO7al=ob0P80gooooo000;ooooo`ko/k>c3_l0000>
ob8R8PgoKfm_1Oooool>ocdm?@ko<c<c3_l0000=oaXJ6PKooooo3Ol20P8>oi^KV`koemOG3OlK6a/6
ooooo`koIVIV3Oooool>o`D51@go30`<1_oooolLomGEe@go30`<3OlC4a<6ooooo`ko92@T3_lR8R8>
o`820Q;ooooo3_oclo<>o`P820konOWi3Ol_;bl5ooooo`ko7QhN3_l<30`>oalO7`go820P3Oooool0
00_ooooo3_nc/k<>o`0000ko8R8R3Om_Kfl5ooooo`ko?Cdm3_lc<c<>o`0000go6QXJ1_ooool=o`82
0PkoVi^K3_oGemL=oa/K6`Kooooo3_mVIVH=ooooo`ko1@D53Ol<30`6oooooacoeMGE3Ol<30`=oa<C
4`Kooooo3_lT92@>ob8R8Pko0P824_ooool>oo?cl`ko20P83_oinOT=obl_;`Gooooo3_lN7Qh>o``<
30ko7alO3OlP820=ooooo`002oooool>ok>c/`ko00003_lR8R8=ofm_K`Gooooo3_lm?Cd>oc<c<`ko
00003OlJ6QX6ooooo`go0P823_nKVi/>omOGe`go6a/K1_ooool>ofIVIPgooooo3_l51@D=o``<30Ko
oooo7?oEeMD=o``<30go4a<C1_ooool>ob@T90ko8R8R3_l20P8Booooo`kolo?c3_l820P>ooWin@go
;bl_1Oooool>oahN7Pko30`<3_lO7al=ob0P80gooooo000;ooooo`ko/k>c3_l0000>ob8R8PgoKfm_
1Oooool>ocdm?@ko<c<c3_l0000=oaXJ6PKooooo3Ol20P8>oi^KV`koemOG3OlK6a/6ooooo`koIVIV
3Oooool>o`D51@go30`<1_oooolLomGEe@go30`<3OlC4a<6ooooo`ko92@T3_lR8R8>o`820Q;ooooo
3_oclo<>o`P820konOWi3Ol_;bl5ooooo`ko7QhN3_l<30`>oalO7`go820P3Oooool000_ooooo3_nc
/k<>o`0000ko8R8R3Om_Kfl5ooooo`ko?Cdm3_lc<c<>o`0000go6QXJ1_ooool=o`820PkoVi^K3_oG
emL=oa/K6`Kooooo3_mVIVH=ooooo`ko1@D53Ol<30`6oooooacoeMGE3Ol<30`=oa<C4`Kooooo3_lT
92@>ob8R8Pko0P824_ooool>oo?cl`ko20P83_oinOT=obl_;`Gooooo3_lN7Qh>o``<30ko7alO3OlP
820=ooooo`002oooool>ok>c/`ko00003_lR8R8=ofm_K`Gooooo3_lm?Cd>oc<c<`ko00003OlJ6QX6
ooooo`go0P823_nKVi/>omOGe`go6a/K1_ooool>ofIVIPgooooo3_l51@D=o``<30Kooooo7?oEeMD=
o``<30go4a<C1_ooool>ob@T90ko8R8R3_l20P8Booooo`kolo?c3_l820P>ooWin@go;bl_1Oooool>
oahN7Pko30`<3_lO7al=ob0P80gooooo000;ooooo`ko/k>c3_l0000>ob8R8PgoKfm_1Oooool>ocdm
?@ko<c<c3_l0000=oaXJ6PKooooo3Ol20P8>oi^KV`koemOG3OlK6a/6ooooo`koIVIV3Oooool>o`D5
1@go30`<1_oooolLomGEe@go30`<3OlC4a<6ooooo`ko92@T3_lR8R8>o`820Q;ooooo3_oclo<>o`P8
20konOWi3Ol_;bl5ooooo`ko7QhN3_l<30`>oalO7`go820P3Oooool000_ooooo3_nc/k<>o`0000ko
8R8R3Om_Kfl5ooooo`ko?Cdm3_lc<c<>o`0000go6QXJ1_ooool=o`820PkoVi^K3_oGemL=oa/K6`Ko
oooo3_mVIVH=ooooo`ko1@D53Ol<30`6oooooacoeMGE3Ol<30`=oa<C4`Kooooo3_lT92@>ob8R8Pko
0P824_ooool>oo?cl`ko20P83_oinOT=obl_;`Gooooo3_lN7Qh>o``<30ko7alO3OlP820=ooooo`00
2oooool>ok>c/`ko00003_lR8R8=ofm_K`Gooooo3_lm?Cd>oc<c<`ko00003OlJ6QX6ooooo`go0P82
3_nKVi/>omOGe`go6a/K1_ooool>ofIVIPgooooo3_l51@D=o``<30Kooooo7?oEeMD=o``<30go4a<C
1_ooool>ob@T90ko8R8R3_l20P8Booooo`kolo?c3_l820P>ooWin@go;bl_1Oooool>oahN7Pko30`<
3_lO7al=ob0P80gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:
2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_oo
ool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l9
2@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>
oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6
ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>
oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=
odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B
4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<
S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3P
h0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@go
cLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`ko
EeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko
3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`go
oooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo
3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L71
3OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^
1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Ooo
ool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>
c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj
>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;
ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>
ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=
oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>
o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/
;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`00
00go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6oooo
o`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko
;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`ko
oooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Ko
oooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko
00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;
3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K
1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX
3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG
5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE
5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<
30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG
5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=
oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6ooooo`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>
ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>
on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?C`gooooo000;ooooo`ko;Rh^3_lG5aL>oa4A
4@gocLg=1Oooool>ob`/;0ko2`/;3_l:2PX=oa8B4PKooooo3Olf=SH>ogMgM`kooooo3OlE5AD6oooo
o`koEeMG3Oo>c/h>o`0000go6a/K1_ooool>ohb<S0ko`L713OlF5QH=oa`L70Kooooo3_l<30`>oa<C
4`ko3@d=3?lj>SX6ooooo`koZ:RX3_l92@T>on3Ph0go;Rh^1Oooool>o`d=3@ko00003_lG5aL=odm?
C`gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`ko5aLG3_l@410>o`/;2`gohn?S1Ooo
ool>oc/k>`ko7QhN3_lV9RHCoooooa_o7AdM3_lj>SX=oh>3P`Kooooo3_m?Cdl=o`0000ko?3`l3OnW
YjL6ooooo`ko4A4A3_m:BTX=oinOW`gogmoO1_ooool>obHV9Pko6QXJ3_l0000<on?Sh`Kooooo3_lb
<S8>odA4A0ko1`L73Om3@d<5ooooo`koD51@3_l0000>ojb/[0go6QXJ3Oooool000_ooooo3_lG5aL>
oa0@40ko2`/;3OoShn<5ooooo`ko>c/k3_lN7Qh>obHV9Q?ooooo6olM7Ad>ocXj>PgoPh>31_ooool>
odm?C`go00003_ll?3`=ojNWY`Kooooo3_lA4A4>odY:BPgoWinO3OoOgml6ooooo`ko9RHV3_lJ6QX>
o`0000cohn?S1_ooool>oc8b<PkoA4A43_l71`L=od=3@`Gooooo3_m@D50>o`0000ko[:b/3OlJ6QX=
ooooo`002oooool>oaLG5`ko410@3_l;2`/=on?Sh`Gooooo3_lk>c/>oahN7Pko9RHV4ooooolKoadM
7@ko>SXj3On3Ph<6ooooo`koCdm?3Ol0000>oc`l?0goYjNW1_ooool>oa4A4@koBTY:3OnOWil=omoO
g`Kooooo3_lV9RH>oaXJ6Pko00003?oShn<6ooooo`ko<S8b3_m4A4@>o`L71`go@d=31Oooool>oe1@
D0ko00003_n/[:`=oaXJ6Pgooooo000;ooooo`ko5aLG3_l@410>o`/;2`gohn?S1Oooool>oc/k>`ko
7QhN3_lV9RHCoooooa_o7AdM3_lj>SX=oh>3P`Kooooo3_m?Cdl=o`0000ko?3`l3OnWYjL6ooooo`ko
4A4A3_m:BTX=oinOW`gogmoO1_ooool>obHV9Pko6QXJ3_l0000<on?Sh`Kooooo3_lb<S8>odA4A0ko
1`L73Om3@d<5ooooo`koD51@3_l0000>ojb/[0go6QXJ3Oooool000_ooooo3_lG5aL>oa0@40ko2`/;
3OoShn<5ooooo`ko>c/k3_lN7Qh>obHV9Q?ooooo6olM7Ad>ocXj>PgoPh>31_ooool>odm?C`go0000
3_ll?3`=ojNWY`Kooooo3_lA4A4>odY:BPgoWinO3OoOgml6ooooo`ko9RHV3_lJ6QX>o`0000cohn?S
1_ooool>oc8b<PkoA4A43_l71`L=od=3@`Gooooo3_m@D50>o`0000ko[:b/3OlJ6QX=ooooo`002ooo
ool>oaLG5`ko410@3_l;2`/=on?Sh`Gooooo3_lk>c/>oahN7Pko9RHV4ooooolKoadM7@ko>SXj3On3
Ph<6ooooo`koCdm?3Ol0000>oc`l?0goYjNW1_ooool>oa4A4@koBTY:3OnOWil=omoOg`Kooooo3_lV
9RH>oaXJ6Pko00003?oShn<6ooooo`ko<S8b3_m4A4@>o`L71`go@d=31Oooool>oe1@D0ko00003_n/
[:`=oaXJ6Pgooooo000;ooooo`ko5aLG3_l@410>o`/;2`gohn?S1Oooool>oc/k>`ko7QhN3_lV9RHC
oooooa_o7AdM3_lj>SX=oh>3P`Kooooo3_m?Cdl=o`0000ko?3`l3OnWYjL6ooooo`ko4A4A3_m:BTX=
oinOW`gogmoO1_ooool>obHV9Pko6QXJ3_l0000<on?Sh`Kooooo3_lb<S8>odA4A0ko1`L73Om3@d<5
ooooo`koD51@3_l0000>ojb/[0go6QXJ3Oooool000_ooooo3_lG5aL>oa0@40ko2`/;3OoShn<5oooo
o`ko>c/k3_lN7Qh>obHV9Q?ooooo6olM7Ad>ocXj>PgoPh>31_ooool>odm?C`go00003_ll?3`=ojNW
Y`Kooooo3_lA4A4>odY:BPgoWinO3OoOgml6ooooo`ko9RHV3_lJ6QX>o`0000cohn?S1_ooool>oc8b
<PkoA4A43_l71`L=od=3@`Gooooo3_m@D50>o`0000ko[:b/3OlJ6QX=ooooo`002oooool>oaLG5`ko
410@3_l;2`/=on?Sh`Gooooo3_lk>c/>oahN7Pko9RHV4ooooolKoadM7@ko>SXj3On3Ph<6ooooo`ko
Cdm?3Ol0000>oc`l?0goYjNW1_ooool>oa4A4@koBTY:3OnOWil=omoOg`Kooooo3_lV9RH>oaXJ6Pko
00003?oShn<6ooooo`ko<S8b3_m4A4@>o`L71`go@d=31Oooool>oe1@D0ko00003_n/[:`=oaXJ6Pgo
oooo000;ooooo`ko5aLG3_l@410>o`/;2`gohn?S1Oooool>oc/k>`ko7QhN3_lV9RHCoooooa_o7AdM
3_lj>SX=oh>3P`Kooooo3_m?Cdl=o`0000ko?3`l3OnWYjL6ooooo`ko4A4A3_m:BTX=oinOW`gogmoO
1_ooool>obHV9Pko6QXJ3_l0000<on?Sh`Kooooo3_lb<S8>odA4A0ko1`L73Om3@d<5ooooo`koD51@
3_l0000>ojb/[0go6QXJ3Oooool000_ooooo3_lG5aL>oa0@40ko2`/;3OoShn<5ooooo`ko>c/k3_lN
7Qh>obHV9Q?ooooo6olM7Ad>ocXj>PgoPh>31_ooool>odm?C`go00003_ll?3`=ojNWY`Kooooo3_lA
4A4>odY:BPgoWinO3OoOgml6ooooo`ko9RHV3_lJ6QX>o`0000cohn?S1_ooool>oc8b<PkoA4A43_l7
1`L=od=3@`Gooooo3_m@D50>o`0000ko[:b/3OlJ6QX=ooooo`002oooool>oaLG5`ko410@3_l;2`/=
on?Sh`Gooooo3_lk>c/>oahN7Pko9RHV4ooooolKoadM7@ko>SXj3On3Ph<6ooooo`koCdm?3Ol0000>
oc`l?0goYjNW1_ooool>oa4A4@koBTY:3OnOWil=omoOg`Kooooo3_lV9RH>oaXJ6Pko00003?oShn<6
ooooo`ko<S8b3_m4A4@>o`L71`go@d=31Oooool>oe1@D0ko00003_n/[:`=oaXJ6Pgooooo000;oooo
o`ko5aLG3_l@410>o`/;2`gohn?S1Oooool>oc/k>`ko7QhN3_lV9RHCoooooa_o7AdM3_lj>SX=oh>3
P`Kooooo3_m?Cdl=o`0000ko?3`l3OnWYjL6ooooo`ko4A4A3_m:BTX=oinOW`gogmoO1_ooool>obHV
9Pko6QXJ3_l0000<on?Sh`Kooooo3_lb<S8>odA4A0ko1`L73Om3@d<5ooooo`koD51@3_l0000>ojb/
[0go6QXJ3Oooool000_ooooo3_l:2PX>o``<30ko2PX:3Oohn?P5ooooo`koLg=c3_li>CT>oaXJ6Pgo
71`L1_ooool=o`@410ko6QXJ3_mfMWH=ojRXZ0Kooooo3_ld=3@=ob`/;0koI6AT3OnATI46ooooo`ko
10@43_mjNWX=og=cL`gocLg=1_ooool>o`X:2Pko410@3_l410@Booooo`koPX:23_mPH60>o`l?3`go
92@T1Oooool>oeYJFPko2`/;3_oTi>@=o`L71`gooooo000;ooooo`ko2PX:3_l<30`>o`X:2Pgon?Sh
1Oooool>og=cL`ko>CTi3_lJ6QX=oa`L70Kooooo3Ol410@>oaXJ6PkoMWIf3OnXZ:P6ooooo`ko=3@d
3Ol/;2`>ofATI0goTI6A1_ooool>o`@410koNWYj3OmcLg<=olg=c@Kooooo3_l:2PX>oa0@40ko10@4
4_ooool>oh:2PPkoH61P3_l?3`l=ob@T90Gooooo3_mJFUX>o`/;2`koi>CT3Ol71`L=ooooo`002ooo
ool>o`X:2Pko30`<3_l:2PX=ooShn0Gooooo3_mcLg<>ocTi>@ko6QXJ3OlL71`6ooooo`go10@43_lJ
6QX>ogIfMPgoZ:RX1_ooool>oc@d=0go;2`/3_mTI6@=oi6AT@Kooooo3_l410@>ogYjNPgoLg=c3Oo=
cLd6ooooo`ko2PX:3_l@410>o`@411;ooooo3_n2PX8>of1PH0ko3`l?3OlT92@5ooooo`koFUYJ3_l;
2`/>onCTi0go1`L73Oooool000_ooooo3_l:2PX>o``<30ko2PX:3Oohn?P5ooooo`koLg=c3_li>CT>
oaXJ6Pgo71`L1_ooool=o`@410ko6QXJ3_mfMWH=ojRXZ0Kooooo3_ld=3@=ob`/;0koI6AT3OnATI46
ooooo`ko10@43_mjNWX=og=cL`gocLg=1_ooool>o`X:2Pko410@3_l410@Booooo`koPX:23_mPH60>
o`l?3`go92@T1Oooool>oeYJFPko2`/;3_oTi>@=o`L71`gooooo000;ooooo`ko2PX:3_l<30`>o`X:
2Pgon?Sh1Oooool>og=cL`ko>CTi3_lJ6QX=oa`L70Kooooo3Ol410@>oaXJ6PkoMWIf3OnXZ:P6oooo
o`ko=3@d3Ol/;2`>ofATI0goTI6A1_ooool>o`@410koNWYj3OmcLg<=olg=c@Kooooo3_l:2PX>oa0@
40ko10@44_ooool>oh:2PPkoH61P3_l?3`l=ob@T90Gooooo3_mJFUX>o`/;2`koi>CT3Ol71`L=oooo
o`002oooool>o`X:2Pko30`<3_l:2PX=ooShn0Gooooo3_mcLg<>ocTi>@ko6QXJ3OlL71`6ooooo`go
10@43_lJ6QX>ogIfMPgoZ:RX1_ooool>oc@d=0go;2`/3_mTI6@=oi6AT@Kooooo3_l410@>ogYjNPgo
Lg=c3Oo=cLd6ooooo`ko2PX:3_l@410>o`@411;ooooo3_n2PX8>of1PH0ko3`l?3OlT92@5ooooo`ko
FUYJ3_l;2`/>onCTi0go1`L73Oooool000_ooooo3_l:2PX>o``<30ko2PX:3Oohn?P5ooooo`koLg=c
3_li>CT>oaXJ6Pgo71`L1_ooool=o`@410ko6QXJ3_mfMWH=ojRXZ0Kooooo3_ld=3@=ob`/;0koI6AT
3OnATI46ooooo`ko10@43_mjNWX=og=cL`gocLg=1_ooool>o`X:2Pko410@3_l410@Booooo`koPX:2
3_mPH60>o`l?3`go92@T1Oooool>oeYJFPko2`/;3_oTi>@=o`L71`gooooo000;ooooo`ko2PX:3_l<
30`>o`X:2Pgon?Sh1Oooool>og=cL`ko>CTi3_lJ6QX=oa`L70Kooooo3Ol410@>oaXJ6PkoMWIf3OnX
Z:P6ooooo`ko=3@d3Ol/;2`>ofATI0goTI6A1_ooool>o`@410koNWYj3OmcLg<=olg=c@Kooooo3_l:
2PX>oa0@40ko10@44_ooool>oh:2PPkoH61P3_l?3`l=ob@T90Gooooo3_mJFUX>o`/;2`koi>CT3Ol7
1`L=ooooo`002oooool>o`X:2Pko30`<3_l:2PX=ooShn0Gooooo3_mcLg<>ocTi>@ko6QXJ3OlL71`6
ooooo`go10@43_lJ6QX>ogIfMPgoZ:RX1_ooool>oc@d=0go;2`/3_mTI6@=oi6AT@Kooooo3_l410@>
ogYjNPgoLg=c3Oo=cLd6ooooo`ko2PX:3_l@410>o`@411;ooooo3_n2PX8>of1PH0ko3`l?3OlT92@5
ooooo`koFUYJ3_l;2`/>onCTi0go1`L73Oooool000_ooooo3_l:2PX>o``<30ko2PX:3Oohn?P5oooo
o`koLg=c3_li>CT>oaXJ6Pgo71`L1_ooool=o`@410ko6QXJ3_mfMWH=ojRXZ0Kooooo3_ld=3@=ob`/
;0koI6AT3OnATI46ooooo`ko10@43_mjNWX=og=cL`gocLg=1_ooool>o`X:2Pko410@3_l410@Boooo
o`koPX:23_mPH60>o`l?3`go92@T1Oooool>oeYJFPko2`/;3_oTi>@=o`L71`gooooo000;ooooo`ko
2PX:3_l<30`>o`X:2Pgon?Sh1Oooool>og=cL`ko>CTi3_lJ6QX=oa`L70Kooooo3Ol410@>oaXJ6Pko
MWIf3OnXZ:P6ooooo`ko=3@d3Ol/;2`>ofATI0goTI6A1_ooool>o`@410koNWYj3OmcLg<=olg=c@Ko
oooo3_l:2PX>oa0@40ko10@44_ooool>oh:2PPkoH61P3_l?3`l=ob@T90Gooooo3_mJFUX>o`/;2`ko
i>CT3Ol71`L=ooooo`002oooool>o`X:2Pko30`<3_l:2PX=ooShn0Gooooo3_mcLg<>ocTi>@ko6QXJ
3OlL71`6ooooo`go10@43_lJ6QX>ogIfMPgoZ:RX1_ooool>oc@d=0go;2`/3_mTI6@=oi6AT@Kooooo
3_l410@>ogYjNPgoLg=c3Oo=cLd6ooooo`ko2PX:3_l@410>o`@411;ooooo3_n2PX8>of1PH0ko3`l?
3OlT92@5ooooo`koFUYJ3_l;2`/>onCTi0go1`L73Oooool000_ooooo3_l:2PX>o``<30ko2PX:3Ooh
n?P5ooooo`koLg=c3_li>CT>oaXJ6Pgo71`L1_ooool=o`@410ko6QXJ3_mfMWH=ojRXZ0Kooooo3_ld
=3@=ob`/;0koI6AT3OnATI46ooooo`ko10@43_mjNWX=og=cL`gocLg=1_ooool>o`X:2Pko410@3_l4
10@Booooo`koPX:23_mPH60>o`l?3`go92@T1Oooool>oeYJFPko2`/;3_oTi>@=o`L71`gooooo000;
ooooo`ko1PH63_l51@D>oaPH61;ooooo3_lU9BD>obHV9Pko00003OlM7Ad6ooooo`go00003_lG5aL>
oo;blPgoaLG51_ooool>od51@@goXJ6Q3_n^[Zh=ocDe=@Kooooo3_l0000>ok:b/PgoIFEU3On`/;06
ooooo`ko00003_l<30`>o`l?3`col?3`5?ooool>oda<C0ko3Ph>3Olm?Cd5ooooo`koB4Q83_l61PH>
ooooo`go410@3Oooool000_ooooo3_l61PH>o`D51@ko61PH4_ooool>obDU9@ko9RHV3_l0000=oadM
7@Kooooo3Ol0000>oaLG5`kol_;b3Oo5aLD6ooooo`ko@D513OnQXJ4>ojj^[Pgo=CDe1_ooool>o`00
00ko/[:b3OmUIFD=ok2`/0Kooooo3_l0000>o``<30ko3`l?3?o`l?0Dooooo`koC4a<3_l>3Ph=ocdm
?@Gooooo3_m8B4P>o`H61Pkooooo3Ol@410=ooooo`002oooool>o`H61Pko1@D53_lH61PBooooo`ko
9BDU3_lV9RH>o`0000go7AdM1_ooool=o`0000ko5aLG3_obl_8=olG5a@Kooooo3_m1@D4=oj6QX@ko
[Zj^3Ole=CD6ooooo`ko00003_nb/[8=ofEUI@go/;2`1_ooool>o`0000ko30`<3_l?3`l<oo3`l1Co
oooo3_m<C4`>o`h>3Pgo?Cdm1Oooool>odQ8B0ko1PH63_ooool=oa0@40gooooo000;ooooo`ko1PH6
3_l51@D>oaPH61;ooooo3_lU9BD>obHV9Pko00003OlM7Ad6ooooo`go00003_lG5aL>oo;blPgoaLG5
1_ooool>od51@@goXJ6Q3_n^[Zh=ocDe=@Kooooo3_l0000>ok:b/PgoIFEU3On`/;06ooooo`ko0000
3_l<30`>o`l?3`col?3`5?ooool>oda<C0ko3Ph>3Olm?Cd5ooooo`koB4Q83_l61PH>ooooo`go410@
3Oooool000_ooooo3_l61PH>o`D51@ko61PH4_ooool>obDU9@ko9RHV3_l0000=oadM7@Kooooo3Ol0
000>oaLG5`kol_;b3Oo5aLD6ooooo`ko@D513OnQXJ4>ojj^[Pgo=CDe1_ooool>o`0000ko/[:b3OmU
IFD=ok2`/0Kooooo3_l0000>o``<30ko3`l?3?o`l?0Dooooo`koC4a<3_l>3Ph=ocdm?@Gooooo3_m8
B4P>o`H61Pkooooo3Ol@410=ooooo`002oooool>o`H61Pko1@D53_lH61PBooooo`ko9BDU3_lV9RH>
o`0000go7AdM1_ooool=o`0000ko5aLG3_obl_8=olG5a@Kooooo3_m1@D4=oj6QX@ko[Zj^3Ole=CD6
ooooo`ko00003_nb/[8=ofEUI@go/;2`1_ooool>o`0000ko30`<3_l?3`l<oo3`l1Cooooo3_m<C4`>
o`h>3Pgo?Cdm1Oooool>odQ8B0ko1PH63_ooool=oa0@40gooooo000;ooooo`ko1PH63_l51@D>oaPH
61;ooooo3_lU9BD>obHV9Pko00003OlM7Ad6ooooo`go00003_lG5aL>oo;blPgoaLG51_ooool>od51
@@goXJ6Q3_n^[Zh=ocDe=@Kooooo3_l0000>ok:b/PgoIFEU3On`/;06ooooo`ko00003_l<30`>o`l?
3`col?3`5?ooool>oda<C0ko3Ph>3Olm?Cd5ooooo`koB4Q83_l61PH>ooooo`go410@3Oooool000_o
oooo3_l61PH>o`D51@ko61PH4_ooool>obDU9@ko9RHV3_l0000=oadM7@Kooooo3Ol0000>oaLG5`ko
l_;b3Oo5aLD6ooooo`ko@D513OnQXJ4>ojj^[Pgo=CDe1_ooool>o`0000ko/[:b3OmUIFD=ok2`/0Ko
oooo3_l0000>o``<30ko3`l?3?o`l?0Dooooo`koC4a<3_l>3Ph=ocdm?@Gooooo3_m8B4P>o`H61Pko
oooo3Ol@410=ooooo`002oooool>o`H61Pko1@D53_lH61PBooooo`ko9BDU3_lV9RH>o`0000go7AdM
1_ooool=o`0000ko5aLG3_obl_8=olG5a@Kooooo3_m1@D4=oj6QX@ko[Zj^3Ole=CD6ooooo`ko0000
3_nb/[8=ofEUI@go/;2`1_ooool>o`0000ko30`<3_l?3`l<oo3`l1Cooooo3_m<C4`>o`h>3Pgo?Cdm
1Oooool>odQ8B0ko1PH63_ooool=oa0@40gooooo000;ooooo`ko1PH63_l51@D>oaPH61;ooooo3_lU
9BD>obHV9Pko00003OlM7Ad6ooooo`go00003_lG5aL>oo;blPgoaLG51_ooool>od51@@goXJ6Q3_n^
[Zh=ocDe=@Kooooo3_l0000>ok:b/PgoIFEU3On`/;06ooooo`ko00003_l<30`>o`l?3`col?3`5?oo
ool>oda<C0ko3Ph>3Olm?Cd5ooooo`koB4Q83_l61PH>ooooo`go410@3Oooool000_ooooo3_l61PH>
o`D51@ko61PH4_ooool>obDU9@ko9RHV3_l0000=oadM7@Kooooo3Ol0000>oaLG5`kol_;b3Oo5aLD6
ooooo`ko@D513OnQXJ4>ojj^[Pgo=CDe1_ooool>o`0000ko/[:b3OmUIFD=ok2`/0Kooooo3_l0000>
o``<30ko3`l?3?o`l?0Dooooo`koC4a<3_l>3Ph=ocdm?@Gooooo3_m8B4P>o`H61Pkooooo3Ol@410=
ooooo`002oooool>o`H61Pko1@D53_lH61PBooooo`ko9BDU3_lV9RH>o`0000go7AdM1_ooool=o`00
00ko5aLG3_obl_8=olG5a@Kooooo3_m1@D4=oj6QX@ko[Zj^3Ole=CD6ooooo`ko00003_nb/[8=ofEU
I@go/;2`1_ooool>o`0000ko30`<3_l?3`l<oo3`l1Cooooo3_m<C4`>o`h>3Pgo?Cdm1Oooool>odQ8
B0ko1PH63_ooool=oa0@40gooooo000;ooooo`ko1PH63_l51@D>oaPH61;ooooo3_lU9BD>obHV9Pko
00003OlM7Ad6ooooo`go00003_lG5aL>oo;blPgoaLG51_ooool>od51@@goXJ6Q3_n^[Zh=ocDe=@Ko
oooo3_l0000>ok:b/PgoIFEU3On`/;06ooooo`ko00003_l<30`>o`l?3`col?3`5?ooool>oda<C0ko
3Ph>3Olm?Cd5ooooo`koB4Q83_l61PH>ooooo`go410@3Oooool000_ooooo3_l61PH>o`D51@ko61PH
4_ooool>obDU9@ko9RHV3_l0000=oadM7@Kooooo3Ol0000>oaLG5`kol_;b3Oo5aLD6ooooo`ko@D51
3OnQXJ4>ojj^[Pgo=CDe1_ooool>o`0000ko/[:b3OmUIFD=ok2`/0Kooooo3_l0000>o``<30ko3`l?
3?o`l?0Dooooo`koC4a<3_l>3Ph=ocdm?@Gooooo3_m8B4P>o`H61Pkooooo3Ol@410=ooooo`002ooo
ool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ
8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmP
H606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[
:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>
oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=
o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>
ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;
2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>oooo
o`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606oooo
o`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L7
1`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko
>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Ko
oooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko
:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko0000
3_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][
1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<3
3_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX
3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG
5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>
3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0
000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=
ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>
oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>
o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=
ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6oooo
o`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>oooo
o`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9B
DPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Go
oooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0go
oooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`co
dM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`00
2oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<
3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a
3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo
3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS
8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mK
Fe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_oo
ool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`002oooool>
o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>
ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606
ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOgm`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>
o`L71`koj>SX3Ol92@T=ooooo`002oooool>o`/;2`ko00003_lG5aL=ooWin@Gooooo3_lS8b<>oa`L
70ko>c/k3OlG5aL6ooooo`go30`<3_lQ8B4>ooooo`goJf][1_ooool>oiBDU0gooooo3_mKFe/=o`d=
3@Kooooo3_l>3Ph>ooooo`go<C4a3OmPH606ooooo`ko0`<33_lB4Q8>o`l?3`codM7A1_ooool>ooOg
m`ko:BTY3_l0000=oe9BDPGooooo3_l[:b/>o`L71`koj>SX3Ol92@T=ooooo`00oooooooeooooo`00
oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00
oooooooeooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnI
VIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0
000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH
61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=
od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>
ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>
obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=
ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6oooo
o`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^
[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY
:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Go
oooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go
`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@co
DE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`00
2oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF
3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/
3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo
3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mR
HV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mB
DU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_oo
ool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>
o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>
ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6
ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>
obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;
2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN
7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?
S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@ko
U9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo
?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko
2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`ko
ZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE
3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo
3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L
3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ
8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_oo
ool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?
3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3Omg
MgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6
ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi>@go`<303_mBDU8=oahN7PKooooo3_l0000>
ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=
obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=ooooo`002oooool>o`d=3@koU9BD3_lQ8B4=od10
@0Gooooo3_mRHV8>o`/;2`koEEEE3OnIVIT6ooooo`go5QHF3_lB4Q8>ol;2`Pgo?clo1_ooool>ocTi
>@go`<303_mBDU8=oahN7PKooooo3_l0000>ojj^[Pgo;2`/3Ol_;bl6ooooo`ko2`/;3_l?3`l>obDU
9@coDE5A1_ooool>ohn?S`ko71`L3_lH61P=obTY:@Gooooo3_l@410>obl_;`koZJVY3OmgMgL=oooo
o`002oooool>o`0000koalO73_l:2PX=obl_;`Gooooo3_m=CDd>o`T92@ko>c/k3Oo`l?06ooooo`go
1@D53_lG5aL>onk^kPgo=3@d1_ooool>odE5A@gooooo3_mCDe<=oaLG5`Kooooo3_l20P8>onSXj0go
820P3Ol;2`/6ooooo`ko71`L3_l92@T>ob0P80co@T925?ooool>obDU9@ko00003OmcLg<5ooooo`ko
5aLG3_lT92@>ooooo`goOWin3Oooool000_ooooo3_l0000>olO7a`ko2PX:3Ol_;bl5ooooo`koCDe=
3_l92@T>oc/k>`gol?3`1_ooool=o`D51@ko5aLG3_o^k^h=oc@d=0Kooooo3_m5ADD=ooooo`koDe=C
3OlG5aL6ooooo`ko0P823_oXj>P=ob0P80go2`/;1_ooool>oa`L70ko2@T93_lP820<od92@QCooooo
3_lU9BD>o`0000goLg=c1Oooool>oaLG5`ko92@T3_ooool=oginOPgooooo000;ooooo`ko00003_o7
alL>o`X:2Pgo;bl_1Oooool>ode=C@ko2@T93_lk>c/=oo3`l0Kooooo3Ol51@D>oaLG5`kok^k^3Old
=3@6ooooo`koADE53Oooool>oe=CD`go5aLG1_ooool>o`820Pkoj>SX3OlP820=o`/;2`Kooooo3_lL
71`>o`T92@ko820P3?m2@T8Dooooo`ko9BDU3_l0000=og=cL`Gooooo3_lG5aL>ob@T90kooooo3Omn
OWh=ooooo`002oooool>o`0000koalO73_l:2PX=obl_;`Gooooo3_m=CDd>o`T92@ko>c/k3Oo`l?06
ooooo`go1@D53_lG5aL>onk^kPgo=3@d1_ooool>odE5A@gooooo3_mCDe<=oaLG5`Kooooo3_l20P8>
onSXj0go820P3Ol;2`/6ooooo`ko71`L3_l92@T>ob0P80co@T925?ooool>obDU9@ko00003OmcLg<5
ooooo`ko5aLG3_lT92@>ooooo`goOWin3Oooool000_ooooo3_l0000>olO7a`ko2PX:3Ol_;bl5oooo
o`koCDe=3_l92@T>oc/k>`gol?3`1_ooool=o`D51@ko5aLG3_o^k^h=oc@d=0Kooooo3_m5ADD=oooo
o`koDe=C3OlG5aL6ooooo`ko0P823_oXj>P=ob0P80go2`/;1_ooool>oa`L70ko2@T93_lP820<od92
@QCooooo3_lU9BD>o`0000goLg=c1Oooool>oaLG5`ko92@T3_ooool=oginOPgooooo000;ooooo`ko
00003_o7alL>o`X:2Pgo;bl_1Oooool>ode=C@ko2@T93_lk>c/=oo3`l0Kooooo3Ol51@D>oaLG5`ko
k^k^3Old=3@6ooooo`koADE53Oooool>oe=CD`go5aLG1_ooool>o`820Pkoj>SX3OlP820=o`/;2`Ko
oooo3_lL71`>o`T92@ko820P3?m2@T8Dooooo`ko9BDU3_l0000=og=cL`Gooooo3_lG5aL>ob@T90ko
oooo3OmnOWh=ooooo`002oooool>o`0000koalO73_l:2PX=obl_;`Gooooo3_m=CDd>o`T92@ko>c/k
3Oo`l?06ooooo`go1@D53_lG5aL>onk^kPgo=3@d1_ooool>odE5A@gooooo3_mCDe<=oaLG5`Kooooo
3_l20P8>onSXj0go820P3Ol;2`/6ooooo`ko71`L3_l92@T>ob0P80co@T925?ooool>obDU9@ko0000
3OmcLg<5ooooo`ko5aLG3_lT92@>ooooo`goOWin3Oooool000_ooooo3_l0000>olO7a`ko2PX:3Ol_
;bl5ooooo`koCDe=3_l92@T>oc/k>`gol?3`1_ooool=o`D51@ko5aLG3_o^k^h=oc@d=0Kooooo3_m5
ADD=ooooo`koDe=C3OlG5aL6ooooo`ko0P823_oXj>P=ob0P80go2`/;1_ooool>oa`L70ko2@T93_lP
820<od92@QCooooo3_lU9BD>o`0000goLg=c1Oooool>oaLG5`ko92@T3_ooool=oginOPgooooo000;
ooooo`ko00003_o7alL>o`X:2Pgo;bl_1Oooool>ode=C@ko2@T93_lk>c/=oo3`l0Kooooo3Ol51@D>
oaLG5`kok^k^3Old=3@6ooooo`koADE53Oooool>oe=CD`go5aLG1_ooool>o`820Pkoj>SX3OlP820=
o`/;2`Kooooo3_lL71`>o`T92@ko820P3?m2@T8Dooooo`ko9BDU3_l0000=og=cL`Gooooo3_lG5aL>
ob@T90kooooo3OmnOWh=ooooo`002oooool>o`0000koalO73_l:2PX=obl_;`Gooooo3_m=CDd>o`T9
2@ko>c/k3Oo`l?06ooooo`go1@D53_lG5aL>onk^kPgo=3@d1_ooool>odE5A@gooooo3_mCDe<=oaLG
5`Kooooo3_l20P8>onSXj0go820P3Ol;2`/6ooooo`ko71`L3_l92@T>ob0P80co@T925?ooool>obDU
9@ko00003OmcLg<5ooooo`ko5aLG3_lT92@>ooooo`goOWin3Oooool000_ooooo3_l0000>olO7a`ko
2PX:3Ol_;bl5ooooo`koCDe=3_l92@T>oc/k>`gol?3`1_ooool=o`D51@ko5aLG3_o^k^h=oc@d=0Ko
oooo3_m5ADD=ooooo`koDe=C3OlG5aL6ooooo`ko0P823_oXj>P=ob0P80go2`/;1_ooool>oa`L70ko
2@T93_lP820<od92@QCooooo3_lU9BD>o`0000goLg=c1Oooool>oaLG5`ko92@T3_ooool=oginOPgo
oooo000;ooooo`ko00003_o7alL>o`X:2Pgo;bl_1Oooool>ode=C@ko2@T93_lk>c/=oo3`l0Kooooo
3Ol51@D>oaLG5`kok^k^3Old=3@6ooooo`koADE53Oooool>oe=CD`go5aLG1_ooool>o`820Pkoj>SX
3OlP820=o`/;2`Kooooo3_lL71`>o`T92@ko820P3?m2@T8Dooooo`ko9BDU3_l0000=og=cL`Gooooo
3_lG5aL>ob@T90kooooo3OmnOWh=ooooo`002oooool>o`0000koalO73_l:2PX=obl_;`Gooooo3_m=
CDd>o`T92@ko>c/k3Oo`l?06ooooo`go1@D53_lG5aL>onk^kPgo=3@d1_ooool>odE5A@gooooo3_mC
De<=oaLG5`Kooooo3_l20P8>onSXj0go820P3Ol;2`/6ooooo`ko71`L3_l92@T>ob0P80co@T925?oo
ool>obDU9@ko00003OmcLg<5ooooo`ko5aLG3_lT92@>ooooo`goOWin3Oooool000_ooooo3_lJ6QX>
ooooo`ko:b/[3Olf=SH5ooooo`koB4Q83_l0000>obLW9a?ooooo3Ol0000>obh^;Pkooooo3Ol_;bl6
ooooo`ko4Q8B3OlI6AT>obTY:@go5ADE1_ooool>oa<C4`kom_Kf3Ol=3@d=o`0000Kooooo3_l_;bl>
oc<c<`ko<S8b3?l00006ooooo`koRHV93_lI6AT>o`L71`goG5aL1Oooool>o`H61Pko=cLg3_m7AdL=
ofe]K@gooooo000;ooooo`ko6QXJ3_ooool>ob/[:`go=SHf1Oooool>odQ8B0ko00003_lW9bLCoooo
o`go00003_l^;Rh>ooooo`go;bl_1_ooool>oa8B4Pgo6ATI3_lY:BT=oaDE5@Kooooo3_lC4a<>ooKf
mPgo3@d=3Ol00006ooooo`ko;bl_3_lc<c<>oc8b<Pco00001_ooool>ohV9R@ko6ATI3_l71`L=oeaL
G0Gooooo3_l61PH>ocLg=`koAdM73Om]KFd=ooooo`002oooool>oaXJ6Pkooooo3_l[:b/=ocHf=PGo
oooo3_m8B4P>o`0000ko9bLW4oooool=o`0000ko;Rh^3_ooool=obl_;`Kooooo3_lB4Q8=oaTI6@ko
:BTY3OlE5AD6ooooo`ko4a<C3_ofm_H=o`d=3@go00001_ooool>obl_;`ko<c<c3_lb<S8<o`0000Ko
oooo3_n9RHT>oaTI6@ko1`L73OmLG5`5ooooo`ko1PH63_lg=cL>odM7A`goKFe]3Oooool000_ooooo
3_lJ6QX>ooooo`ko:b/[3Olf=SH5ooooo`koB4Q83_l0000>obLW9a?ooooo3Ol0000>obh^;Pkooooo
3Ol_;bl6ooooo`ko4Q8B3OlI6AT>obTY:@go5ADE1_ooool>oa<C4`kom_Kf3Ol=3@d=o`0000Kooooo
3_l_;bl>oc<c<`ko<S8b3?l00006ooooo`koRHV93_lI6AT>o`L71`goG5aL1Oooool>o`H61Pko=cLg
3_m7AdL=ofe]K@gooooo000;ooooo`ko6QXJ3_ooool>ob/[:`go=SHf1Oooool>odQ8B0ko00003_lW
9bLCooooo`go00003_l^;Rh>ooooo`go;bl_1_ooool>oa8B4Pgo6ATI3_lY:BT=oaDE5@Kooooo3_lC
4a<>ooKfmPgo3@d=3Ol00006ooooo`ko;bl_3_lc<c<>oc8b<Pco00001_ooool>ohV9R@ko6ATI3_l7
1`L=oeaLG0Gooooo3_l61PH>ocLg=`koAdM73Om]KFd=ooooo`002oooool>oaXJ6Pkooooo3_l[:b/=
ocHf=PGooooo3_m8B4P>o`0000ko9bLW4oooool=o`0000ko;Rh^3_ooool=obl_;`Kooooo3_lB4Q8=
oaTI6@ko:BTY3OlE5AD6ooooo`ko4a<C3_ofm_H=o`d=3@go00001_ooool>obl_;`ko<c<c3_lb<S8<
o`0000Kooooo3_n9RHT>oaTI6@ko1`L73OmLG5`5ooooo`ko1PH63_lg=cL>odM7A`goKFe]3Oooool0
00_ooooo3_lJ6QX>ooooo`ko:b/[3Olf=SH5ooooo`koB4Q83_l0000>obLW9a?ooooo3Ol0000>obh^
;Pkooooo3Ol_;bl6ooooo`ko4Q8B3OlI6AT>obTY:@go5ADE1_ooool>oa<C4`kom_Kf3Ol=3@d=o`00
00Kooooo3_l_;bl>oc<c<`ko<S8b3?l00006ooooo`koRHV93_lI6AT>o`L71`goG5aL1Oooool>o`H6
1Pko=cLg3_m7AdL=ofe]K@gooooo000;ooooo`ko6QXJ3_ooool>ob/[:`go=SHf1Oooool>odQ8B0ko
00003_lW9bLCooooo`go00003_l^;Rh>ooooo`go;bl_1_ooool>oa8B4Pgo6ATI3_lY:BT=oaDE5@Ko
oooo3_lC4a<>ooKfmPgo3@d=3Ol00006ooooo`ko;bl_3_lc<c<>oc8b<Pco00001_ooool>ohV9R@ko
6ATI3_l71`L=oeaLG0Gooooo3_l61PH>ocLg=`koAdM73Om]KFd=ooooo`002oooool>oaXJ6Pkooooo
3_l[:b/=ocHf=PGooooo3_m8B4P>o`0000ko9bLW4oooool=o`0000ko;Rh^3_ooool=obl_;`Kooooo
3_lB4Q8=oaTI6@ko:BTY3OlE5AD6ooooo`ko4a<C3_ofm_H=o`d=3@go00001_ooool>obl_;`ko<c<c
3_lb<S8<o`0000Kooooo3_n9RHT>oaTI6@ko1`L73OmLG5`5ooooo`ko1PH63_lg=cL>odM7A`goKFe]
3Oooool000_ooooo3_lJ6QX>ooooo`ko:b/[3Olf=SH5ooooo`koB4Q83_l0000>obLW9a?ooooo3Ol0
000>obh^;Pkooooo3Ol_;bl6ooooo`ko4Q8B3OlI6AT>obTY:@go5ADE1_ooool>oa<C4`kom_Kf3Ol=
3@d=o`0000Kooooo3_l_;bl>oc<c<`ko<S8b3?l00006ooooo`koRHV93_lI6AT>o`L71`goG5aL1Ooo
ool>o`H61Pko=cLg3_m7AdL=ofe]K@gooooo000;ooooo`ko6QXJ3_ooool>ob/[:`go=SHf1Oooool>
odQ8B0ko00003_lW9bLCooooo`go00003_l^;Rh>ooooo`go;bl_1_ooool>oa8B4Pgo6ATI3_lY:BT=
oaDE5@Kooooo3_lC4a<>ooKfmPgo3@d=3Ol00006ooooo`ko;bl_3_lc<c<>oc8b<Pco00001_ooool>
ohV9R@ko6ATI3_l71`L=oeaLG0Gooooo3_l61PH>ocLg=`koAdM73Om]KFd=ooooo`002oooool>oaXJ
6Pkooooo3_l[:b/=ocHf=PGooooo3_m8B4P>o`0000ko9bLW4oooool=o`0000ko;Rh^3_ooool=obl_
;`Kooooo3_lB4Q8=oaTI6@ko:BTY3OlE5AD6ooooo`ko4a<C3_ofm_H=o`d=3@go00001_ooool>obl_
;`ko<c<c3_lb<S8<o`0000Kooooo3_n9RHT>oaTI6@ko1`L73OmLG5`5ooooo`ko1PH63_lg=cL>odM7
A`goKFe]3Oooool000_ooooo3_lJ6QX>ooooo`ko:b/[3Olf=SH5ooooo`koB4Q83_l0000>obLW9a?o
oooo3Ol0000>obh^;Pkooooo3Ol_;bl6ooooo`ko4Q8B3OlI6AT>obTY:@go5ADE1_ooool>oa<C4`ko
m_Kf3Ol=3@d=o`0000Kooooo3_l_;bl>oc<c<`ko<S8b3?l00006ooooo`koRHV93_lI6AT>o`L71`go
G5aL1Oooool>o`H61Pko=cLg3_m7AdL=ofe]K@gooooo000;ooooo`ko6QXJ3_ooool>ob/[:`go=SHf
1Oooool>odQ8B0ko00003_lW9bLCooooo`go00003_l^;Rh>ooooo`go;bl_1_ooool>oa8B4Pgo6ATI
3_lY:BT=oaDE5@Kooooo3_lC4a<>ooKfmPgo3@d=3Ol00006ooooo`ko;bl_3_lc<c<>oc8b<Pco0000
1_ooool>ohV9R@ko6ATI3_l71`L=oeaLG0Gooooo3_l61PH>ocLg=`koAdM73Om]KFd=ooooo`002ooo
ool>oaHF5PkonOWi3_ll?3`=oc/k>`Gooooo3_lj>SX>o`d=3@ko=CDe3OoJf]X6ooooo`go4Q8B3_lg
=cL>oo7al@go3Ph>1_ooool>o`d=3@go00003_l410@=o`X:2PKooooo3_lJ6QX>ooooo`go30`<3Ol9
2@T6ooooo`ko>c/k3_lF5QH>oa<C4a;ooooo3_l^;Rh>oa8B4Pko7alO3Olf=SH5ooooo`ko00003_lR
8R8>oc8b<Pgo:b/[3Oooool000_ooooo3_lF5QH>ooWin@ko?3`l3Olk>c/5ooooo`ko>SXj3_l=3@d>
ocDe=@gof][J1_ooool=oa8B4Pko=cLg3_oalO4=o`h>3PKooooo3_l=3@d=o`0000ko10@43Ol:2PX6
ooooo`ko6QXJ3_ooool=o``<30go2@T91_ooool>oc/k>`ko5QHF3_lC4a<Booooo`ko;Rh^3_lB4Q8>
oalO7`go=SHf1Oooool>o`0000ko8R8R3_lb<S8=ob/[:`gooooo000;ooooo`ko5QHF3_oinOT>oc`l
?0go>c/k1Oooool>ocXj>Pko3@d=3_le=CD=om[JfPKooooo3OlB4Q8>ocLg=`kolO7a3Ol>3Ph6oooo
o`ko3@d=3Ol0000>o`@410go2PX:1_ooool>oaXJ6Pkooooo3Ol<30`=o`T92@Kooooo3_lk>c/>oaHF
5Pko4a<C4_ooool>obh^;Pko4Q8B3_lO7al=ocHf=PGooooo3_l0000>ob8R8Pko<S8b3Ol[:b/=oooo
o`002oooool>oaHF5PkonOWi3_ll?3`=oc/k>`Gooooo3_lj>SX>o`d=3@ko=CDe3OoJf]X6ooooo`go
4Q8B3_lg=cL>oo7al@go3Ph>1_ooool>o`d=3@go00003_l410@=o`X:2PKooooo3_lJ6QX>ooooo`go
30`<3Ol92@T6ooooo`ko>c/k3_lF5QH>oa<C4a;ooooo3_l^;Rh>oa8B4Pko7alO3Olf=SH5ooooo`ko
00003_lR8R8>oc8b<Pgo:b/[3Oooool000_ooooo3_lF5QH>ooWin@ko?3`l3Olk>c/5ooooo`ko>SXj
3_l=3@d>ocDe=@gof][J1_ooool=oa8B4Pko=cLg3_oalO4=o`h>3PKooooo3_l=3@d=o`0000ko10@4
3Ol:2PX6ooooo`ko6QXJ3_ooool=o``<30go2@T91_ooool>oc/k>`ko5QHF3_lC4a<Booooo`ko;Rh^
3_lB4Q8>oalO7`go=SHf1Oooool>o`0000ko8R8R3_lb<S8=ob/[:`gooooo000;ooooo`ko5QHF3_oi
nOT>oc`l?0go>c/k1Oooool>ocXj>Pko3@d=3_le=CD=om[JfPKooooo3OlB4Q8>ocLg=`kolO7a3Ol>
3Ph6ooooo`ko3@d=3Ol0000>o`@410go2PX:1_ooool>oaXJ6Pkooooo3Ol<30`=o`T92@Kooooo3_lk
>c/>oaHF5Pko4a<C4_ooool>obh^;Pko4Q8B3_lO7al=ocHf=PGooooo3_l0000>ob8R8Pko<S8b3Ol[
:b/=ooooo`002oooool>oaHF5PkonOWi3_ll?3`=oc/k>`Gooooo3_lj>SX>o`d=3@ko=CDe3OoJf]X6
ooooo`go4Q8B3_lg=cL>oo7al@go3Ph>1_ooool>o`d=3@go00003_l410@=o`X:2PKooooo3_lJ6QX>
ooooo`go30`<3Ol92@T6ooooo`ko>c/k3_lF5QH>oa<C4a;ooooo3_l^;Rh>oa8B4Pko7alO3Olf=SH5
ooooo`ko00003_lR8R8>oc8b<Pgo:b/[3Oooool000_ooooo3_lF5QH>ooWin@ko?3`l3Olk>c/5oooo
o`ko>SXj3_l=3@d>ocDe=@gof][J1_ooool=oa8B4Pko=cLg3_oalO4=o`h>3PKooooo3_l=3@d=o`00
00ko10@43Ol:2PX6ooooo`ko6QXJ3_ooool=o``<30go2@T91_ooool>oc/k>`ko5QHF3_lC4a<Boooo
o`ko;Rh^3_lB4Q8>oalO7`go=SHf1Oooool>o`0000ko8R8R3_lb<S8=ob/[:`gooooo000;ooooo`ko
5QHF3_oinOT>oc`l?0go>c/k1Oooool>ocXj>Pko3@d=3_le=CD=om[JfPKooooo3OlB4Q8>ocLg=`ko
lO7a3Ol>3Ph6ooooo`ko3@d=3Ol0000>o`@410go2PX:1_ooool>oaXJ6Pkooooo3Ol<30`=o`T92@Ko
oooo3_lk>c/>oaHF5Pko4a<C4_ooool>obh^;Pko4Q8B3_lO7al=ocHf=PGooooo3_l0000>ob8R8Pko
<S8b3Ol[:b/=ooooo`002oooool>oaHF5PkonOWi3_ll?3`=oc/k>`Gooooo3_lj>SX>o`d=3@ko=CDe
3OoJf]X6ooooo`go4Q8B3_lg=cL>oo7al@go3Ph>1_ooool>o`d=3@go00003_l410@=o`X:2PKooooo
3_lJ6QX>ooooo`go30`<3Ol92@T6ooooo`ko>c/k3_lF5QH>oa<C4a;ooooo3_l^;Rh>oa8B4Pko7alO
3Olf=SH5ooooo`ko00003_lR8R8>oc8b<Pgo:b/[3Oooool000_ooooo3_lF5QH>ooWin@ko?3`l3Olk
>c/5ooooo`ko>SXj3_l=3@d>ocDe=@gof][J1_ooool=oa8B4Pko=cLg3_oalO4=o`h>3PKooooo3_l=
3@d=o`0000ko10@43Ol:2PX6ooooo`ko6QXJ3_ooool=o``<30go2@T91_ooool>oc/k>`ko5QHF3_lC
4a<Booooo`ko;Rh^3_lB4Q8>oalO7`go=SHf1Oooool>o`0000ko8R8R3_lb<S8=ob/[:`gooooo000;
ooooo`ko5QHF3_oinOT>oc`l?0go>c/k1Oooool>ocXj>Pko3@d=3_le=CD=om[JfPKooooo3OlB4Q8>
ocLg=`kolO7a3Ol>3Ph6ooooo`ko3@d=3Ol0000>o`@410go2PX:1_ooool>oaXJ6Pkooooo3Ol<30`=
o`T92@Kooooo3_lk>c/>oaHF5Pko4a<C4_ooool>obh^;Pko4Q8B3_lO7al=ocHf=PGooooo3_l0000>
ob8R8Pko<S8b3Ol[:b/=ooooo`002oooool>oaHF5PkonOWi3_ll?3`=oc/k>`Gooooo3_lj>SX>o`d=
3@ko=CDe3OoJf]X6ooooo`go4Q8B3_lg=cL>oo7al@go3Ph>1_ooool>o`d=3@go00003_l410@=o`X:
2PKooooo3_lJ6QX>ooooo`go30`<3Ol92@T6ooooo`ko>c/k3_lF5QH>oa<C4a;ooooo3_l^;Rh>oa8B
4Pko7alO3Olf=SH5ooooo`ko00003_lR8R8>oc8b<Pgo:b/[3Oooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool000_ooooo3_l10@4>oo[jnPko<c<c3OnSXj<5ooooo`ko5ADE3_l0000>oahN7R3ooooo3_lc
<c<>obd];@go<30`1_ooool>omCDe0goQ8B43_mADE4=o`0000Kooooo3_l51@D>o`0000go8B4Q3OlU
9BD6ooooo`kof=SH3_li>CT>ooknoPcoShn?1_ooool>oo7al@ko>c/k3_lB4Q8=obh^;PGooooo3_l<
30`>omWIf@kof][J3OlW9bL=ooooo`002oooool>o`410@kon_[j3_lc<c<=oj>SX`Gooooo3_lE5AD>
o`0000ko7QhN8?ooool>oc<c<`ko;Bd]3Ol`<306ooooo`koe=CD3On4Q8@>oe5AD@go00001_ooool>
o`D51@ko00003OlQ8B4=obDU9@Kooooo3_oHf=P>ocTi>@koo_kn3?n?Shl6ooooo`kolO7a3_lk>c/>
oa8B4Pgo;Rh^1Oooool>o``<30kofMWI3_oJf]X=obLW9`gooooo000;ooooo`ko0@413_ojn_X>oc<c
<`goXj>S1Oooool>oaDE5@ko00003_lN7QhPooooo`ko<c<c3_l];Bd=oc0`<0Kooooo3_oDe=@=ohB4
Q0koDE5A3Ol00006ooooo`ko1@D53_l0000=ob4Q8@go9BDU1_ooool>omSHf0ko>CTi3_ono_h<ohn?
S`Kooooo3_oalO4>oc/k>`ko4Q8B3Ol^;Rh5ooooo`ko30`<3_oIfMT>om[JfPgo9bLW3Oooool000_o
oooo3_l10@4>oo[jnPko<c<c3OnSXj<5ooooo`ko5ADE3_l0000>oahN7R3ooooo3_lc<c<>obd];@go
<30`1_ooool>omCDe0goQ8B43_mADE4=o`0000Kooooo3_l51@D>o`0000go8B4Q3OlU9BD6ooooo`ko
f=SH3_li>CT>ooknoPcoShn?1_ooool>oo7al@ko>c/k3_lB4Q8=obh^;PGooooo3_l<30`>omWIf@ko
f][J3OlW9bL=ooooo`002oooool>o`410@kon_[j3_lc<c<=oj>SX`Gooooo3_lE5AD>o`0000ko7QhN
8?ooool>oc<c<`ko;Bd]3Ol`<306ooooo`koe=CD3On4Q8@>oe5AD@go00001_ooool>o`D51@ko0000
3OlQ8B4=obDU9@Kooooo3_oHf=P>ocTi>@koo_kn3?n?Shl6ooooo`kolO7a3_lk>c/>oa8B4Pgo;Rh^
1Oooool>o``<30kofMWI3_oJf]X=obLW9`gooooo000;ooooo`ko0@413_ojn_X>oc<c<`goXj>S1Ooo
ool>oaDE5@ko00003_lN7QhPooooo`ko<c<c3_l];Bd=oc0`<0Kooooo3_oDe=@=ohB4Q0koDE5A3Ol0
0006ooooo`ko1@D53_l0000=ob4Q8@go9BDU1_ooool>omSHf0ko>CTi3_ono_h<ohn?S`Kooooo3_oa
lO4>oc/k>`ko4Q8B3Ol^;Rh5ooooo`ko30`<3_oIfMT>om[JfPgo9bLW3Oooool000_ooooo3_l10@4>
oo[jnPko<c<c3OnSXj<5ooooo`ko5ADE3_l0000>oahN7R3ooooo3_lc<c<>obd];@go<30`1_ooool>
omCDe0goQ8B43_mADE4=o`0000Kooooo3_l51@D>o`0000go8B4Q3OlU9BD6ooooo`kof=SH3_li>CT>
ooknoPcoShn?1_ooool>oo7al@ko>c/k3_lB4Q8=obh^;PGooooo3_l<30`>omWIf@kof][J3OlW9bL=
ooooo`002oooool>o`410@kon_[j3_lc<c<=oj>SX`Gooooo3_lE5AD>o`0000ko7QhN8?ooool>oc<c
<`ko;Bd]3Ol`<306ooooo`koe=CD3On4Q8@>oe5AD@go00001_ooool>o`D51@ko00003OlQ8B4=obDU
9@Kooooo3_oHf=P>ocTi>@koo_kn3?n?Shl6ooooo`kolO7a3_lk>c/>oa8B4Pgo;Rh^1Oooool>o``<
30kofMWI3_oJf]X=obLW9`gooooo000;ooooo`ko0@413_ojn_X>oc<c<`goXj>S1Oooool>oaDE5@ko
00003_lN7QhPooooo`ko<c<c3_l];Bd=oc0`<0Kooooo3_oDe=@=ohB4Q0koDE5A3Ol00006ooooo`ko
1@D53_l0000=ob4Q8@go9BDU1_ooool>omSHf0ko>CTi3_ono_h<ohn?S`Kooooo3_oalO4>oc/k>`ko
4Q8B3Ol^;Rh5ooooo`ko30`<3_oIfMT>om[JfPgo9bLW3Oooool000_ooooo3_l10@4>oo[jnPko<c<c
3OnSXj<5ooooo`ko5ADE3_l0000>oahN7R3ooooo3_lc<c<>obd];@go<30`1_ooool>omCDe0goQ8B4
3_mADE4=o`0000Kooooo3_l51@D>o`0000go8B4Q3OlU9BD6ooooo`kof=SH3_li>CT>ooknoPcoShn?
1_ooool>oo7al@ko>c/k3_lB4Q8=obh^;PGooooo3_l<30`>omWIf@kof][J3OlW9bL=ooooo`002ooo
ool>o`410@kon_[j3_lc<c<=oj>SX`Gooooo3_lE5AD>o`0000ko7QhN8?ooool>oc<c<`ko;Bd]3Ol`
<306ooooo`koe=CD3On4Q8@>oe5AD@go00001_ooool>o`D51@ko00003OlQ8B4=obDU9@Kooooo3_oH
f=P>ocTi>@koo_kn3?n?Shl6ooooo`kolO7a3_lk>c/>oa8B4Pgo;Rh^1Oooool>o``<30kofMWI3_oJ
f]X=obLW9`gooooo000;ooooo`ko0@413_ojn_X>oc<c<`goXj>S1Oooool>oaDE5@ko00003_lN7QhP
ooooo`ko<c<c3_l];Bd=oc0`<0Kooooo3_oDe=@=ohB4Q0koDE5A3Ol00006ooooo`ko1@D53_l0000=
ob4Q8@go9BDU1_ooool>omSHf0ko>CTi3_ono_h<ohn?S`Kooooo3_oalO4>oc/k>`ko4Q8B3Ol^;Rh5
ooooo`ko30`<3_oIfMT>om[JfPgo9bLW3Oooool000_ooooo3_l10@4>oo[jnPko<c<c3OnSXj<5oooo
o`ko5ADE3_l0000>oahN7R3ooooo3_lc<c<>obd];@go<30`1_ooool>omCDe0goQ8B43_mADE4=o`00
00Kooooo3_l51@D>o`0000go8B4Q3OlU9BD6ooooo`kof=SH3_li>CT>ooknoPcoShn?1_ooool>oo7a
l@ko>c/k3_lB4Q8=obh^;PGooooo3_l<30`>omWIf@kof][J3OlW9bL=ooooo`002oooool>o`0000ko
oooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCo
oooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410ko
g]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`00
2oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO
3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo
3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo
3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_oo
ool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB
4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l3
0`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>
oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>
oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=
ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[
Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMG
E`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDoooo
o`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000ko
oooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCo
oooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410ko
g]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`00
2oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO
3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo
3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo
3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_oo
ool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB
4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l3
0`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>
oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>
oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=
ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[
Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMG
E`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDoooo
o`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000ko
oooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCo
oooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410ko
g]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`00
2oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_ooool=ocLg=`ko7alO
3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo
3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l30`<>on;RhPkooooo
3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>oc0`<0goWYjN1_oo
ool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>oa0@40ko5QHF3OlB
4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=ob0P80Gooooo3_l3
0`<>on;RhPkooooo3OlO7al=ooooo`002oooool>o`0000kooooo3_l@410=oj^[Z`Gooooo7?l820P>
oc0`<0goWYjN1_ooool=ocLg=`ko7alO3_lR8R8=obl_;aCooooo3OnLW9`>oeMGE`go1PH61_ooool>
oa0@40ko5QHF3OlB4Q8=oa4A4@Kooooo3_oCdm<>o`@410kog]kN3?nJVYXDooooo`ko<S8b3_l0000=
ob0P80Gooooo3_l30`<>on;RhPkooooo3OlO7al=ooooo`002oooool>oc0`<0koYJFU3_l<30`=oifM
W@Gooooo3_l>3Ph>oaPH60ko@D513OlV9RH6ooooo`go00003_l[:b/>ocLg=`go9RHV1_ooool>omKF
ePgo[Zj^3_mNGUh=oa0@40Kooooo3_lL71`>ooooo`goE5AD3Ol30`<Dooooo`ko00003_nMWId<ohn?
S`Kooooo3_ogmoL>ocDe=@ko410@3OlS8b<5ooooo`ko00003_oXj>P>oo3`l0go9BDU3Oooool000_o
oooo3_l`<30>ojFUY@ko30`<3OnMWId5ooooo`ko3Ph>3_lH61P>od51@@go9RHV1_ooool=o`0000ko
:b/[3_lg=cL=obHV9PKooooo3_oFe]H=ojj^[PkoGUiN3Ol@4106ooooo`ko71`L3_ooool=oeADE0go
0`<35?ooool>o`0000koWIfM3?n?Shl6ooooo`komoOg3_le=CD>oa0@40go8b<S1Oooool>o`0000ko
j>SX3_o`l?0=obDU9@gooooo000;ooooo`ko<30`3_nUYJD>o``<30goWIfM1Oooool>o`h>3Pko61PH
3_m1@D4=obHV9PKooooo3Ol0000>ob/[:`ko=cLg3OlV9RH6ooooo`koe]KF3On^[Zh>oeiNGPgo410@
1_ooool>oa`L70kooooo3OmDE5@=o`<30aCooooo3_l0000>oifMW@coShn?1_ooool>ooOgm`ko=CDe
3_l@410=ob<S8`Gooooo3_l0000>onSXj0kol?3`3OlU9BD=ooooo`002oooool>oc0`<0koYJFU3_l<
30`=oifMW@Gooooo3_l>3Ph>oaPH60ko@D513OlV9RH6ooooo`go00003_l[:b/>ocLg=`go9RHV1_oo
ool>omKFePgo[Zj^3_mNGUh=oa0@40Kooooo3_lL71`>ooooo`goE5AD3Ol30`<Dooooo`ko00003_nM
WId<ohn?S`Kooooo3_ogmoL>ocDe=@ko410@3OlS8b<5ooooo`ko00003_oXj>P>oo3`l0go9BDU3Ooo
ool000_ooooo3_l`<30>ojFUY@ko30`<3OnMWId5ooooo`ko3Ph>3_lH61P>od51@@go9RHV1_ooool=
o`0000ko:b/[3_lg=cL=obHV9PKooooo3_oFe]H=ojj^[PkoGUiN3Ol@4106ooooo`ko71`L3_ooool=
oeADE0go0`<35?ooool>o`0000koWIfM3?n?Shl6ooooo`komoOg3_le=CD>oa0@40go8b<S1Oooool>
o`0000koj>SX3_o`l?0=obDU9@gooooo000;ooooo`ko<30`3_nUYJD>o``<30goWIfM1Oooool>o`h>
3Pko61PH3_m1@D4=obHV9PKooooo3Ol0000>ob/[:`ko=cLg3OlV9RH6ooooo`koe]KF3On^[Zh>oeiN
GPgo410@1_ooool>oa`L70kooooo3OmDE5@=o`<30aCooooo3_l0000>oifMW@coShn?1_ooool>ooOg
m`ko=CDe3_l@410=ob<S8`Gooooo3_l0000>onSXj0kol?3`3OlU9BD=ooooo`002oooool>oc0`<0ko
YJFU3_l<30`=oifMW@Gooooo3_l>3Ph>oaPH60ko@D513OlV9RH6ooooo`go00003_l[:b/>ocLg=`go
9RHV1_ooool>omKFePgo[Zj^3_mNGUh=oa0@40Kooooo3_lL71`>ooooo`goE5AD3Ol30`<Dooooo`ko
00003_nMWId<ohn?S`Kooooo3_ogmoL>ocDe=@ko410@3OlS8b<5ooooo`ko00003_oXj>P>oo3`l0go
9BDU3Oooool000_ooooo3_l`<30>ojFUY@ko30`<3OnMWId5ooooo`ko3Ph>3_lH61P>od51@@go9RHV
1_ooool=o`0000ko:b/[3_lg=cL=obHV9PKooooo3_oFe]H=ojj^[PkoGUiN3Ol@4106ooooo`ko71`L
3_ooool=oeADE0go0`<35?ooool>o`0000koWIfM3?n?Shl6ooooo`komoOg3_le=CD>oa0@40go8b<S
1Oooool>o`0000koj>SX3_o`l?0=obDU9@gooooo000;ooooo`ko<30`3_nUYJD>o``<30goWIfM1Ooo
ool>o`h>3Pko61PH3_m1@D4=obHV9PKooooo3Ol0000>ob/[:`ko=cLg3OlV9RH6ooooo`koe]KF3On^
[Zh>oeiNGPgo410@1_ooool>oa`L70kooooo3OmDE5@=o`<30aCooooo3_l0000>oifMW@coShn?1_oo
ool>ooOgm`ko=CDe3_l@410=ob<S8`Gooooo3_l0000>onSXj0kol?3`3OlU9BD=ooooo`002oooool>
oc0`<0koYJFU3_l<30`=oifMW@Gooooo3_l>3Ph>oaPH60ko@D513OlV9RH6ooooo`go00003_l[:b/>
ocLg=`go9RHV1_ooool>omKFePgo[Zj^3_mNGUh=oa0@40Kooooo3_lL71`>ooooo`goE5AD3Ol30`<D
ooooo`ko00003_nMWId<ohn?S`Kooooo3_ogmoL>ocDe=@ko410@3OlS8b<5ooooo`ko00003_oXj>P>
oo3`l0go9BDU3Oooool000_ooooo3_l`<30>ojFUY@ko30`<3OnMWId5ooooo`ko3Ph>3_lH61P>od51
@@go9RHV1_ooool=o`0000ko:b/[3_lg=cL=obHV9PKooooo3_oFe]H=ojj^[PkoGUiN3Ol@4106oooo
o`ko71`L3_ooool=oeADE0go0`<35?ooool>o`0000koWIfM3?n?Shl6ooooo`komoOg3_le=CD>oa0@
40go8b<S1Oooool>o`0000koj>SX3_o`l?0=obDU9@gooooo000;ooooo`ko<30`3_nUYJD>o``<30go
WIfM1Oooool>o`h>3Pko61PH3_m1@D4=obHV9PKooooo3Ol0000>ob/[:`ko=cLg3OlV9RH6ooooo`ko
e]KF3On^[Zh>oeiNGPgo410@1_ooool>oa`L70kooooo3OmDE5@=o`<30aCooooo3_l0000>oifMW@co
Shn?1_ooool>ooOgm`ko=CDe3_l@410=ob<S8`Gooooo3_l0000>onSXj0kol?3`3OlU9BD=ooooo`00
2oooool>oc0`<0koYJFU3_l<30`=oifMW@Gooooo3_l>3Ph>oaPH60ko@D513OlV9RH6ooooo`go0000
3_l[:b/>ocLg=`go9RHV1_ooool>omKFePgo[Zj^3_mNGUh=oa0@40Kooooo3_lL71`>ooooo`goE5AD
3Ol30`<Dooooo`ko00003_nMWId<ohn?S`Kooooo3_ogmoL>ocDe=@ko410@3OlS8b<5ooooo`ko0000
3_oXj>P>oo3`l0go9BDU3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC
4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>
3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?
cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>
oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=
obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>
olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>
om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=
3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6oooo
o`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW
9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko
71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKo
oooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko
71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go
6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;
1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI
3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX
3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnS
Xj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQ
XJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]
KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Ooo
ool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=
ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=
o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5
ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5oooo
o`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=ogin
OPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQX
J0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_o
oooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko
=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go
6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko
2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF
3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@410
3Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo
3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^
;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l6
1PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_oo
ool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6
a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>
o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6
ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>
obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7Ad@go6a/K3Oooool000_ooooo3_l^;Rh>oda<
C0ko71`L3OnSXj<5ooooo`ko5QHF3_lC4a<>o`d=3@go2`/;1_ooool=ob@T90ko=CDe3_l61PH=obh^
;PKooooo3_nQXJ4=oginOPko@4103Ol>3Ph6ooooo`ko6ATI3_l30`<=o`L71`go6a/K1_ooool>olo?
c`ko71`L3_m]KFd<ofQXJ0Kooooo3_o?cll>obLW9`ko:2PX3OlU9BD5ooooo`ko2@T93_o6a/H>om7A
d@go6a/K3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ
:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV
9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_om
oOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>
oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=
ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<
ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool0
00_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/
;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K
6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>oooo
o`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61Pko
DU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo
<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko
30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG
1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo
3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV
3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ
:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV
9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_om
oOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>
oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=
ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<
ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool0
00_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/
;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K
6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>oooo
o`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61Pko
DU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo
<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko
30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG
1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo
3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV
3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>oa<C4`ko1@D53OlZ
:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=ojFUY@koCTi>3OlV
9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<ofIVIPKooooo3_om
oOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool000_ooooo3_nk^k/>
oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/;0Kooooo3_l<30`=
ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K6`ko20P83_lB4Q8<
ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>ooooo`go>c/k3Oooool0
00_ooooo3_nk^k/>oa<C4`ko1@D53OlZ:RX5ooooocOo5aLG1_ooool=o`H61PkoDU9B3_ooool=ob`/
;0Kooooo3_l<30`=ojFUY@koCTi>3OlV9RH6ooooo`ko?clo3_nn_[h=ocHf=Pgo<c<c1_ooool>oa/K
6`ko20P83_lB4Q8<ofIVIPKooooo3_omoOd>o`T92@koIVIV3Ol20P85ooooo`ko30`<3_l:2PX>oooo
o`go>c/k3Oooool000_ooooo3_o<c<`>o`D51@ko00003OlH61P5ooooo`ko5aLG3_l;2`/>ob8R8Q?o
oooo3Ol;2`/>oh>3P`ko_kno3OlH61P6ooooo`ko00003OoEeMD>obl_;`go61PH1_ooool>ofMWI`ko
XZ:R3OlN7Qh=o`h>3PKooooo3_lV9RH>o`0000ko9bLW3?l=3@d6ooooo`kojNWY3_l0000>ohf=S@go
30`<1Oooool>oa8B4Pko8b<S3_lC4a<=oa/K6`gooooo000;ooooo`koc<c<3_l51@D>o`0000go61PH
1Oooool>oaLG5`ko2`/;3_lR8R8Cooooo`go2`/;3_n3Ph<>okno_`go61PH1_ooool>o`0000goeMGE
3_l_;bl=oaPH60Kooooo3_mWIfL>oj:RXPgo7QhN3Ol>3Ph6ooooo`ko9RHV3_l0000>obLW9`co3@d=
1_ooool>onWYj@ko00003_n=SHd=o``<30Gooooo3_lB4Q8>ob<S8`ko4a<C3OlK6a/=ooooo`002ooo
ool>olc<c0ko1@D53_l0000=oaPH60Gooooo3_lG5aL>o`/;2`ko8R8R4oooool=o`/;2`koPh>33_no
_kl=oaPH60Kooooo3_l0000=omGEe@ko;bl_3OlH61P6ooooo`koIfMW3_nRXZ8=oahN7Pgo3Ph>1_oo
ool>obHV9Pko00003_lW9bL<o`d=3@Kooooo3_oYjNT>o`0000koSHf=3Ol<30`5ooooo`ko4Q8B3_lS
8b<>oa<C4`go6a/K3Oooool000_ooooo3_o<c<`>o`D51@ko00003OlH61P5ooooo`ko5aLG3_l;2`/>
ob8R8Q?ooooo3Ol;2`/>oh>3P`ko_kno3OlH61P6ooooo`ko00003OoEeMD>obl_;`go61PH1_ooool>
ofMWI`koXZ:R3OlN7Qh=o`h>3PKooooo3_lV9RH>o`0000ko9bLW3?l=3@d6ooooo`kojNWY3_l0000>
ohf=S@go30`<1Oooool>oa8B4Pko8b<S3_lC4a<=oa/K6`gooooo000;ooooo`koc<c<3_l51@D>o`00
00go61PH1Oooool>oaLG5`ko2`/;3_lR8R8Cooooo`go2`/;3_n3Ph<>okno_`go61PH1_ooool>o`00
00goeMGE3_l_;bl=oaPH60Kooooo3_mWIfL>oj:RXPgo7QhN3Ol>3Ph6ooooo`ko9RHV3_l0000>obLW
9`co3@d=1_ooool>onWYj@ko00003_n=SHd=o``<30Gooooo3_lB4Q8>ob<S8`ko4a<C3OlK6a/=oooo
o`002oooool>olc<c0ko1@D53_l0000=oaPH60Gooooo3_lG5aL>o`/;2`ko8R8R4oooool=o`/;2`ko
Ph>33_no_kl=oaPH60Kooooo3_l0000=omGEe@ko;bl_3OlH61P6ooooo`koIfMW3_nRXZ8=oahN7Pgo
3Ph>1_ooool>obHV9Pko00003_lW9bL<o`d=3@Kooooo3_oYjNT>o`0000koSHf=3Ol<30`5ooooo`ko
4Q8B3_lS8b<>oa<C4`go6a/K3Oooool000_ooooo3_o<c<`>o`D51@ko00003OlH61P5ooooo`ko5aLG
3_l;2`/>ob8R8Q?ooooo3Ol;2`/>oh>3P`ko_kno3OlH61P6ooooo`ko00003OoEeMD>obl_;`go61PH
1_ooool>ofMWI`koXZ:R3OlN7Qh=o`h>3PKooooo3_lV9RH>o`0000ko9bLW3?l=3@d6ooooo`kojNWY
3_l0000>ohf=S@go30`<1Oooool>oa8B4Pko8b<S3_lC4a<=oa/K6`gooooo000;ooooo`koc<c<3_l5
1@D>o`0000go61PH1Oooool>oaLG5`ko2`/;3_lR8R8Cooooo`go2`/;3_n3Ph<>okno_`go61PH1_oo
ool>o`0000goeMGE3_l_;bl=oaPH60Kooooo3_mWIfL>oj:RXPgo7QhN3Ol>3Ph6ooooo`ko9RHV3_l0
000>obLW9`co3@d=1_ooool>onWYj@ko00003_n=SHd=o``<30Gooooo3_lB4Q8>ob<S8`ko4a<C3OlK
6a/=ooooo`002oooool>olc<c0ko1@D53_l0000=oaPH60Gooooo3_lG5aL>o`/;2`ko8R8R4oooool=
o`/;2`koPh>33_no_kl=oaPH60Kooooo3_l0000=omGEe@ko;bl_3OlH61P6ooooo`koIfMW3_nRXZ8=
oahN7Pgo3Ph>1_ooool>obHV9Pko00003_lW9bL<o`d=3@Kooooo3_oYjNT>o`0000koSHf=3Ol<30`5
ooooo`ko4Q8B3_lS8b<>oa<C4`go6a/K3Oooool000_ooooo3_o<c<`>o`D51@ko00003OlH61P5oooo
o`ko5aLG3_l;2`/>ob8R8Q?ooooo3Ol;2`/>oh>3P`ko_kno3OlH61P6ooooo`ko00003OoEeMD>obl_
;`go61PH1_ooool>ofMWI`koXZ:R3OlN7Qh=o`h>3PKooooo3_lV9RH>o`0000ko9bLW3?l=3@d6oooo
o`kojNWY3_l0000>ohf=S@go30`<1Oooool>oa8B4Pko8b<S3_lC4a<=oa/K6`gooooo000;ooooo`ko
c<c<3_l51@D>o`0000go61PH1Oooool>oaLG5`ko2`/;3_lR8R8Cooooo`go2`/;3_n3Ph<>okno_`go
61PH1_ooool>o`0000goeMGE3_l_;bl=oaPH60Kooooo3_mWIfL>oj:RXPgo7QhN3Ol>3Ph6ooooo`ko
9RHV3_l0000>obLW9`co3@d=1_ooool>onWYj@ko00003_n=SHd=o``<30Gooooo3_lB4Q8>ob<S8`ko
4a<C3OlK6a/=ooooo`002oooool>olc<c0ko1@D53_l0000=oaPH60Gooooo3_lG5aL>o`/;2`ko8R8R
4oooool=o`/;2`koPh>33_no_kl=oaPH60Kooooo3_l0000=omGEe@ko;bl_3OlH61P6ooooo`koIfMW
3_nRXZ8=oahN7Pgo3Ph>1_ooool>obHV9Pko00003_lW9bL<o`d=3@Kooooo3_oYjNT>o`0000koSHf=
3Ol<30`5ooooo`ko4Q8B3_lS8b<>oa<C4`go6a/K3Oooool000_ooooo3_o<c<`>o`D51@ko00003OlH
61P5ooooo`ko5aLG3_l;2`/>ob8R8Q?ooooo3Ol;2`/>oh>3P`ko_kno3OlH61P6ooooo`ko00003OoE
eMD>obl_;`go61PH1_ooool>ofMWI`koXZ:R3OlN7Qh=o`h>3PKooooo3_lV9RH>o`0000ko9bLW3?l=
3@d6ooooo`kojNWY3_l0000>ohf=S@go30`<1Oooool>oa8B4Pko8b<S3_lC4a<=oa/K6`gooooo000;
ooooo`koc<c<3_l51@D>o`0000go61PH1Oooool>oaLG5`ko2`/;3_lR8R8Cooooo`go2`/;3_n3Ph<>
okno_`go61PH1_ooool>o`0000goeMGE3_l_;bl=oaPH60Kooooo3_mWIfL>oj:RXPgo7QhN3Ol>3Ph6
ooooo`ko9RHV3_l0000>obLW9`co3@d=1_ooool>onWYj@ko00003_n=SHd=o``<30Gooooo3_lB4Q8>
ob<S8`ko4a<C3OlK6a/=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM
7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6oooo
o`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKF
ePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko
8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko
:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`ko
Z:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko0000
3OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo
3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<
3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Ooo
ool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJ
FUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_oo
ool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol]
;Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=
o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=
oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolL
o`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM
7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6oooo
o`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKF
ePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko
8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko
:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`ko
Z:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko0000
3OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo
3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<
3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Ooo
ool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJ
FUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_oo
ool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol]
;Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=
o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=
oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolL
o`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko8b<S3_lA4A4>oadM
7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko:BTY3OlK6a/6oooo
o`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`koZ:RX3_l?3`l>omKF
ePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko00003OlI6AT5ooooo`ko
8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo3_l0000=ooooo`ko
:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<3_lE5ADBooooo`ko
Z:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`006Oooool>o`X:2Pko0000
3OlI6AT5ooooo`ko8b<S3_lA4A4>oadM7@go5aLG1_ooool=o`D51@ko^;Rh3_mJFUX=o`410@Kooooo
3_l0000=ooooo`ko:BTY3OlK6a/6ooooo`ko[jn_3_mOGel=oaHF5Pgo00001_ooool>odI6APko30`<
3_lE5ADBooooo`koZ:RX3_l?3`l>omKFePgo;bl_1OoooolLo`0000ko7alO3Ol];Bd=ooooo`002ooo
ool>onCTi0ko7AdM3_l0000=o`<30`Gooooo3_l0000>o`d=3@ko6QXJ3Olm?Cd6ooooo`go7AdM3_mj
NWX>ocHf=Pgo00001_ooool>o`l?3`gojNWY3_lI6AT=oadM7ACooooo3_lT92@=ob<S8`go2@T91_oo
ool>oc0`<0ko6a/K3_lL71`<oaHF5PKooooo3_mTI6@>oa`L70kooooo3OlJ6QX5ooooo`ko4a<C3_l6
1PH>oaHF5Pgo:2PX3Oooool000_ooooo3_oTi>@>oadM7@ko00003Ol30`<5ooooo`ko00003_l=3@d>
oaXJ6Pgo?Cdm1_ooool=oadM7@koNWYj3_lf=SH=o`0000Kooooo3_l?3`l=onWYj@ko6ATI3OlM7AdD
ooooo`ko92@T3OlS8b<=o`T92@Kooooo3_l`<30>oa/K6`ko71`L3?lF5QH6ooooo`koI6AT3_lL71`>
ooooo`go6QXJ1Oooool>oa<C4`ko1PH63_lF5QH=obPX:0gooooo000;ooooo`koi>CT3_lM7Ad>o`00
00go0`<31Oooool>o`0000ko3@d=3_lJ6QX=ocdm?@Kooooo3OlM7Ad>ogYjNPko=SHf3Ol00006oooo
o`ko3`l?3OoYjNT>oaTI6@go7AdM5?ooool>ob@T90go8b<S3Ol92@T6ooooo`ko<30`3_lK6a/>oa`L
70co5QHF1_ooool>ofATI0ko71`L3_ooool=oaXJ6PGooooo3_lC4a<>o`H61Pko5QHF3OlX:2P=oooo
o`002oooool>onCTi0ko7AdM3_l0000=o`<30`Gooooo3_l0000>o`d=3@ko6QXJ3Olm?Cd6ooooo`go
7AdM3_mjNWX>ocHf=Pgo00001_ooool>o`l?3`gojNWY3_lI6AT=oadM7ACooooo3_lT92@=ob<S8`go
2@T91_ooool>oc0`<0ko6a/K3_lL71`<oaHF5PKooooo3_mTI6@>oa`L70kooooo3OlJ6QX5ooooo`ko
4a<C3_l61PH>oaHF5Pgo:2PX3Oooool000_ooooo3_oTi>@>oadM7@ko00003Ol30`<5ooooo`ko0000
3_l=3@d>oaXJ6Pgo?Cdm1_ooool=oadM7@koNWYj3_lf=SH=o`0000Kooooo3_l?3`l=onWYj@ko6ATI
3OlM7AdDooooo`ko92@T3OlS8b<=o`T92@Kooooo3_l`<30>oa/K6`ko71`L3?lF5QH6ooooo`koI6AT
3_lL71`>ooooo`go6QXJ1Oooool>oa<C4`ko1PH63_lF5QH=obPX:0gooooo000;ooooo`koi>CT3_lM
7Ad>o`0000go0`<31Oooool>o`0000ko3@d=3_lJ6QX=ocdm?@Kooooo3OlM7Ad>ogYjNPko=SHf3Ol0
0006ooooo`ko3`l?3OoYjNT>oaTI6@go7AdM5?ooool>ob@T90go8b<S3Ol92@T6ooooo`ko<30`3_lK
6a/>oa`L70co5QHF1_ooool>ofATI0ko71`L3_ooool=oaXJ6PGooooo3_lC4a<>o`H61Pko5QHF3OlX
:2P=ooooo`002oooool>onCTi0ko7AdM3_l0000=o`<30`Gooooo3_l0000>o`d=3@ko6QXJ3Olm?Cd6
ooooo`go7AdM3_mjNWX>ocHf=Pgo00001_ooool>o`l?3`gojNWY3_lI6AT=oadM7ACooooo3_lT92@=
ob<S8`go2@T91_ooool>oc0`<0ko6a/K3_lL71`<oaHF5PKooooo3_mTI6@>oa`L70kooooo3OlJ6QX5
ooooo`ko4a<C3_l61PH>oaHF5Pgo:2PX3Oooool000_ooooo3_oTi>@>oadM7@ko00003Ol30`<5oooo
o`ko00003_l=3@d>oaXJ6Pgo?Cdm1_ooool=oadM7@koNWYj3_lf=SH=o`0000Kooooo3_l?3`l=onWY
j@ko6ATI3OlM7AdDooooo`ko92@T3OlS8b<=o`T92@Kooooo3_l`<30>oa/K6`ko71`L3?lF5QH6oooo
o`koI6AT3_lL71`>ooooo`go6QXJ1Oooool>oa<C4`ko1PH63_lF5QH=obPX:0gooooo000;ooooo`ko
i>CT3_lM7Ad>o`0000go0`<31Oooool>o`0000ko3@d=3_lJ6QX=ocdm?@Kooooo3OlM7Ad>ogYjNPko
=SHf3Ol00006ooooo`ko3`l?3OoYjNT>oaTI6@go7AdM5?ooool>ob@T90go8b<S3Ol92@T6ooooo`ko
<30`3_lK6a/>oa`L70co5QHF1_ooool>ofATI0ko71`L3_ooool=oaXJ6PGooooo3_lC4a<>o`H61Pko
5QHF3OlX:2P=ooooo`002oooool>onCTi0ko7AdM3_l0000=o`<30`Gooooo3_l0000>o`d=3@ko6QXJ
3Olm?Cd6ooooo`go7AdM3_mjNWX>ocHf=Pgo00001_ooool>o`l?3`gojNWY3_lI6AT=oadM7ACooooo
3_lT92@=ob<S8`go2@T91_ooool>oc0`<0ko6a/K3_lL71`<oaHF5PKooooo3_mTI6@>oa`L70kooooo
3OlJ6QX5ooooo`ko4a<C3_l61PH>oaHF5Pgo:2PX3Oooool000_ooooo3_oTi>@>oadM7@ko00003Ol3
0`<5ooooo`ko00003_l=3@d>oaXJ6Pgo?Cdm1_ooool=oadM7@koNWYj3_lf=SH=o`0000Kooooo3_l?
3`l=onWYj@ko6ATI3OlM7AdDooooo`ko92@T3OlS8b<=o`T92@Kooooo3_l`<30>oa/K6`ko71`L3?lF
5QH6ooooo`koI6AT3_lL71`>ooooo`go6QXJ1Oooool>oa<C4`ko1PH63_lF5QH=obPX:0gooooo000;
ooooo`koi>CT3_lM7Ad>o`0000go0`<31Oooool>o`0000ko3@d=3_lJ6QX=ocdm?@Kooooo3OlM7Ad>
ogYjNPko=SHf3Ol00006ooooo`ko3`l?3OoYjNT>oaTI6@go7AdM5?ooool>ob@T90go8b<S3Ol92@T6
ooooo`ko<30`3_lK6a/>oa`L70co5QHF1_ooool>ofATI0ko71`L3_ooool=oaXJ6PGooooo3_lC4a<>
o`H61Pko5QHF3OlX:2P=ooooo`002oooool>onCTi0ko7AdM3_l0000=o`<30`Gooooo3_l0000>o`d=
3@ko6QXJ3Olm?Cd6ooooo`go7AdM3_mjNWX>ocHf=Pgo00001_ooool>o`l?3`gojNWY3_lI6AT=oadM
7ACooooo3_lT92@=ob<S8`go2@T91_ooool>oc0`<0ko6a/K3_lL71`<oaHF5PKooooo3_mTI6@>oa`L
70kooooo3OlJ6QX5ooooo`ko4a<C3_l61PH>oaHF5Pgo:2PX3Oooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooo
mOooool000_ooooo3_lM7Ad>oa<C4`ko;Rh^3Onm_Kd5ooooo`ko:BTY3_lQ8B4>ocLg=a?ooooo3OmL
G5`>oa/K6`koF5QH3Om9BDT6ooooo`ko7QhN3Ol`<30>o``<30go00001_ooool>ofIVIPko0P823Ol<
30`=oa8B4PKooooo3_l92@T>oaTI6@ko5ADE3?m]KFd6ooooo`ko8b<S3_l0000>oeaLG0goD51@1Ooo
ool>o`X:2Pko6QXJ3_o:b/X=obh^;Pgooooo000;ooooo`ko7AdM3_lC4a<>obh^;Pgo_Kfm1Oooool>
obTY:@ko8B4Q3_lg=cLCooooo`goG5aL3_lK6a/>oeQHF0goBDU91_ooool>oahN7Pgo<30`3_l<30`=
o`0000Kooooo3_mVIVH>o`820Pgo30`<3OlB4Q86ooooo`ko2@T93_lI6AT>oaDE5@coKFe]1_ooool>
ob<S8`ko00003_mLG5`=oe1@D0Gooooo3_l:2PX>oaXJ6Pkob/[:3Ol^;Rh=ooooo`002oooool>oadM
7@ko4a<C3_l^;Rh=okfm_@Gooooo3_lY:BT>ob4Q8@ko=cLg4oooool=oeaLG0ko6a/K3_mHF5P=odU9
B@Kooooo3_lN7Qh=oc0`<0ko30`<3Ol00006ooooo`koIVIV3_l20P8=o``<30go4Q8B1_ooool>o`T9
2@ko6ATI3_lE5AD<ofe]K@Kooooo3_lS8b<>o`0000koG5aL3Om@D505ooooo`ko2PX:3_lJ6QX>ol[:
bPgo;Rh^3Oooool000_ooooo3_lM7Ad>oa<C4`ko;Rh^3Onm_Kd5ooooo`ko:BTY3_lQ8B4>ocLg=a?o
oooo3OmLG5`>oa/K6`koF5QH3Om9BDT6ooooo`ko7QhN3Ol`<30>o``<30go00001_ooool>ofIVIPko
0P823Ol<30`=oa8B4PKooooo3_l92@T>oaTI6@ko5ADE3?m]KFd6ooooo`ko8b<S3_l0000>oeaLG0go
D51@1Oooool>o`X:2Pko6QXJ3_o:b/X=obh^;Pgooooo000;ooooo`ko7AdM3_lC4a<>obh^;Pgo_Kfm
1Oooool>obTY:@ko8B4Q3_lg=cLCooooo`goG5aL3_lK6a/>oeQHF0goBDU91_ooool>oahN7Pgo<30`
3_l<30`=o`0000Kooooo3_mVIVH>o`820Pgo30`<3OlB4Q86ooooo`ko2@T93_lI6AT>oaDE5@coKFe]
1_ooool>ob<S8`ko00003_mLG5`=oe1@D0Gooooo3_l:2PX>oaXJ6Pkob/[:3Ol^;Rh=ooooo`002ooo
ool>oadM7@ko4a<C3_l^;Rh=okfm_@Gooooo3_lY:BT>ob4Q8@ko=cLg4oooool=oeaLG0ko6a/K3_mH
F5P=odU9B@Kooooo3_lN7Qh=oc0`<0ko30`<3Ol00006ooooo`koIVIV3_l20P8=o``<30go4Q8B1_oo
ool>o`T92@ko6ATI3_lE5AD<ofe]K@Kooooo3_lS8b<>o`0000koG5aL3Om@D505ooooo`ko2PX:3_lJ
6QX>ol[:bPgo;Rh^3Oooool000_ooooo3_lM7Ad>oa<C4`ko;Rh^3Onm_Kd5ooooo`ko:BTY3_lQ8B4>
ocLg=a?ooooo3OmLG5`>oa/K6`koF5QH3Om9BDT6ooooo`ko7QhN3Ol`<30>o``<30go00001_ooool>
ofIVIPko0P823Ol<30`=oa8B4PKooooo3_l92@T>oaTI6@ko5ADE3?m]KFd6ooooo`ko8b<S3_l0000>
oeaLG0goD51@1Oooool>o`X:2Pko6QXJ3_o:b/X=obh^;Pgooooo000;ooooo`ko7AdM3_lC4a<>obh^
;Pgo_Kfm1Oooool>obTY:@ko8B4Q3_lg=cLCooooo`goG5aL3_lK6a/>oeQHF0goBDU91_ooool>oahN
7Pgo<30`3_l<30`=o`0000Kooooo3_mVIVH>o`820Pgo30`<3OlB4Q86ooooo`ko2@T93_lI6AT>oaDE
5@coKFe]1_ooool>ob<S8`ko00003_mLG5`=oe1@D0Gooooo3_l:2PX>oaXJ6Pkob/[:3Ol^;Rh=oooo
o`002oooool>oadM7@ko4a<C3_l^;Rh=okfm_@Gooooo3_lY:BT>ob4Q8@ko=cLg4oooool=oeaLG0ko
6a/K3_mHF5P=odU9B@Kooooo3_lN7Qh=oc0`<0ko30`<3Ol00006ooooo`koIVIV3_l20P8=o``<30go
4Q8B1_ooool>o`T92@ko6ATI3_lE5AD<ofe]K@Kooooo3_lS8b<>o`0000koG5aL3Om@D505ooooo`ko
2PX:3_lJ6QX>ol[:bPgo;Rh^3Oooool000_ooooo3_lM7Ad>oa<C4`ko;Rh^3Onm_Kd5ooooo`ko:BTY
3_lQ8B4>ocLg=a?ooooo3OmLG5`>oa/K6`koF5QH3Om9BDT6ooooo`ko7QhN3Ol`<30>o``<30go0000
1_ooool>ofIVIPko0P823Ol<30`=oa8B4PKooooo3_l92@T>oaTI6@ko5ADE3?m]KFd6ooooo`ko8b<S
3_l0000>oeaLG0goD51@1Oooool>o`X:2Pko6QXJ3_o:b/X=obh^;Pgooooo000;ooooo`ko7AdM3_lC
4a<>obh^;Pgo_Kfm1Oooool>obTY:@ko8B4Q3_lg=cLCooooo`goG5aL3_lK6a/>oeQHF0goBDU91_oo
ool>oahN7Pgo<30`3_l<30`=o`0000Kooooo3_mVIVH>o`820Pgo30`<3OlB4Q86ooooo`ko2@T93_lI
6AT>oaDE5@coKFe]1_ooool>ob<S8`ko00003_mLG5`=oe1@D0Gooooo3_l:2PX>oaXJ6Pkob/[:3Ol^
;Rh=ooooo`002oooool>oadM7@ko4a<C3_l^;Rh=okfm_@Gooooo3_lY:BT>ob4Q8@ko=cLg4oooool=
oeaLG0ko6a/K3_mHF5P=odU9B@Kooooo3_lN7Qh=oc0`<0ko30`<3Ol00006ooooo`koIVIV3_l20P8=
o``<30go4Q8B1_ooool>o`T92@ko6ATI3_lE5AD<ofe]K@Kooooo3_lS8b<>o`0000koG5aL3Om@D505
ooooo`ko2PX:3_lJ6QX>ol[:bPgo;Rh^3Oooool000_ooooo3_lM7Ad>oa<C4`ko;Rh^3Onm_Kd5oooo
o`ko:BTY3_lQ8B4>ocLg=a?ooooo3OmLG5`>oa/K6`koF5QH3Om9BDT6ooooo`ko7QhN3Ol`<30>o``<
30go00001_ooool>ofIVIPko0P823Ol<30`=oa8B4PKooooo3_l92@T>oaTI6@ko5ADE3?m]KFd6oooo
o`ko8b<S3_l0000>oeaLG0goD51@1Oooool>o`X:2Pko6QXJ3_o:b/X=obh^;Pgooooo000;oooooaco
3@d=3_lK6a/=ooCdm0Gooooo3_lE5AD>o`0000koBTY:3OmiNGT6ooooo`go@D513_l@410>ofYZJPgo
PH611_ooool>obDU9@go:2PX3_lN7Qh=oc0`<0Kooooo3_lU9BD>oa`L70go00003Om7AdL6ooooo`ko
71`L3_l0000>oa<C4a;ooooo3_ld=3@>o`0000ko=3@d3OmGEeL5ooooo`ko00003_lK6a/>onGUi@go
7AdM3Oooool000_ooooo7?l=3@d>oa/K6`gom?Cd1Oooool>oaDE5@ko00003_m:BTX=ogUiN@Kooooo
3Om1@D4>oa0@40koJVYZ3On1PH46ooooo`ko9BDU3OlX:2P>oahN7Pgo<30`1_ooool>obDU9@ko71`L
3Ol0000=odM7A`Kooooo3_lL71`>o`0000ko4a<C4_ooool>oc@d=0ko00003_ld=3@=oeMGE`Gooooo
3_l0000>oa/K6`koiNGU3OlM7Ad=ooooo`002ooooolLo`d=3@ko6a/K3Oodm?@5ooooo`ko5ADE3_l0
000>odY:BPgoNGUi1_ooool=od51@@ko410@3_mZJVX=oh61P@Kooooo3_lU9BD=obPX:0ko7QhN3Ol`
<306ooooo`ko9BDU3_lL71`=o`0000goAdM71_ooool>oa`L70ko00003_lC4a<Booooo`ko=3@d3_l0
000>oc@d=0goEeMG1Oooool>o`0000ko6a/K3_oUiND=oadM7@gooooo000;oooooaco3@d=3_lK6a/=
ooCdm0Gooooo3_lE5AD>o`0000koBTY:3OmiNGT6ooooo`go@D513_l@410>ofYZJPgoPH611_ooool>
obDU9@go:2PX3_lN7Qh=oc0`<0Kooooo3_lU9BD>oa`L70go00003Om7AdL6ooooo`ko71`L3_l0000>
oa<C4a;ooooo3_ld=3@>o`0000ko=3@d3OmGEeL5ooooo`ko00003_lK6a/>onGUi@go7AdM3Oooool0
00_ooooo7?l=3@d>oa/K6`gom?Cd1Oooool>oaDE5@ko00003_m:BTX=ogUiN@Kooooo3Om1@D4>oa0@
40koJVYZ3On1PH46ooooo`ko9BDU3OlX:2P>oahN7Pgo<30`1_ooool>obDU9@ko71`L3Ol0000=odM7
A`Kooooo3_lL71`>o`0000ko4a<C4_ooool>oc@d=0ko00003_ld=3@=oeMGE`Gooooo3_l0000>oa/K
6`koiNGU3OlM7Ad=ooooo`002ooooolLo`d=3@ko6a/K3Oodm?@5ooooo`ko5ADE3_l0000>odY:BPgo
NGUi1_ooool=od51@@ko410@3_mZJVX=oh61P@Kooooo3_lU9BD=obPX:0ko7QhN3Ol`<306ooooo`ko
9BDU3_lL71`=o`0000goAdM71_ooool>oa`L70ko00003_lC4a<Booooo`ko=3@d3_l0000>oc@d=0go
EeMG1Oooool>o`0000ko6a/K3_oUiND=oadM7@gooooo000;oooooaco3@d=3_lK6a/=ooCdm0Gooooo
3_lE5AD>o`0000koBTY:3OmiNGT6ooooo`go@D513_l@410>ofYZJPgoPH611_ooool>obDU9@go:2PX
3_lN7Qh=oc0`<0Kooooo3_lU9BD>oa`L70go00003Om7AdL6ooooo`ko71`L3_l0000>oa<C4a;ooooo
3_ld=3@>o`0000ko=3@d3OmGEeL5ooooo`ko00003_lK6a/>onGUi@go7AdM3Oooool000_ooooo7?l=
3@d>oa/K6`gom?Cd1Oooool>oaDE5@ko00003_m:BTX=ogUiN@Kooooo3Om1@D4>oa0@40koJVYZ3On1
PH46ooooo`ko9BDU3OlX:2P>oahN7Pgo<30`1_ooool>obDU9@ko71`L3Ol0000=odM7A`Kooooo3_lL
71`>o`0000ko4a<C4_ooool>oc@d=0ko00003_ld=3@=oeMGE`Gooooo3_l0000>oa/K6`koiNGU3OlM
7Ad=ooooo`002ooooolLo`d=3@ko6a/K3Oodm?@5ooooo`ko5ADE3_l0000>odY:BPgoNGUi1_ooool=
od51@@ko410@3_mZJVX=oh61P@Kooooo3_lU9BD=obPX:0ko7QhN3Ol`<306ooooo`ko9BDU3_lL71`=
o`0000goAdM71_ooool>oa`L70ko00003_lC4a<Booooo`ko=3@d3_l0000>oc@d=0goEeMG1Oooool>
o`0000ko6a/K3_oUiND=oadM7@gooooo000;oooooaco3@d=3_lK6a/=ooCdm0Gooooo3_lE5AD>o`00
00koBTY:3OmiNGT6ooooo`go@D513_l@410>ofYZJPgoPH611_ooool>obDU9@go:2PX3_lN7Qh=oc0`
<0Kooooo3_lU9BD>oa`L70go00003Om7AdL6ooooo`ko71`L3_l0000>oa<C4a;ooooo3_ld=3@>o`00
00ko=3@d3OmGEeL5ooooo`ko00003_lK6a/>onGUi@go7AdM3Oooool000_ooooo7?l=3@d>oa/K6`go
m?Cd1Oooool>oaDE5@ko00003_m:BTX=ogUiN@Kooooo3Om1@D4>oa0@40koJVYZ3On1PH46ooooo`ko
9BDU3OlX:2P>oahN7Pgo<30`1_ooool>obDU9@ko71`L3Ol0000=odM7A`Kooooo3_lL71`>o`0000ko
4a<C4_ooool>oc@d=0ko00003_ld=3@=oeMGE`Gooooo3_l0000>oa/K6`koiNGU3OlM7Ad=ooooo`00
2ooooolLo`d=3@ko6a/K3Oodm?@5ooooo`ko5ADE3_l0000>odY:BPgoNGUi1_ooool=od51@@ko410@
3_mZJVX=oh61P@Kooooo3_lU9BD=obPX:0ko7QhN3Ol`<306ooooo`ko9BDU3_lL71`=o`0000goAdM7
1_ooool>oa`L70ko00003_lC4a<Booooo`ko=3@d3_l0000>oc@d=0goEeMG1Oooool>o`0000ko6a/K
3_oUiND=oadM7@gooooo000;oooooaco3@d=3_lK6a/=ooCdm0Gooooo3_lE5AD>o`0000koBTY:3Omi
NGT6ooooo`go@D513_l@410>ofYZJPgoPH611_ooool>obDU9@go:2PX3_lN7Qh=oc0`<0Kooooo3_lU
9BD>oa`L70go00003Om7AdL6ooooo`ko71`L3_l0000>oa<C4a;ooooo3_ld=3@>o`0000ko=3@d3OmG
EeL5ooooo`ko00003_lK6a/>onGUi@go7AdM3Oooool000_ooooo7?l=3@d>oa/K6`gom?Cd1Oooool>
oaDE5@ko00003_m:BTX=ogUiN@Kooooo3Om1@D4>oa0@40koJVYZ3On1PH46ooooo`ko9BDU3OlX:2P>
oahN7Pgo<30`1_ooool>obDU9@ko71`L3Ol0000=odM7A`Kooooo3_lL71`>o`0000ko4a<C4_ooool>
oc@d=0ko00003_ld=3@=oeMGE`Gooooo3_l0000>oa/K6`koiNGU3OlM7Ad=ooooo`002oooool>o`00
00ko20P83_lY:BTBooooo`ko61PH3_l>3Ph>ocDe=@go5QHF1_ooool=oc8b<Pko4A4A3_nf][H=ol_;
b`Kooooo3_lE5AD=obPX:0ko6a/K3Ol>3Ph6ooooo`ko1PH63_mcLg<=oa8B4PgoKFe]1_ooool>ob<S
8`ko10@43_m1@D4<on[ZjPKooooo3_n[Zj/>ob<S8`ko:b/[3Om7AdL5ooooo`ko1`L73_lF5QH>oooo
o`go9BDU3Oooool000_ooooo3_l0000>o`P820ko:BTY4_ooool>oaPH60ko3Ph>3_le=CD=oaHF5PKo
oooo3Olb<S8>oa4A4@ko][Jf3Oo;bl/6ooooo`ko5ADE3OlX:2P>oa/K6`go3Ph>1_ooool>o`H61Pko
Lg=c3OlB4Q8=ofe]K@Kooooo3_lS8b<>o`@410ko@D513?oZj^X6ooooo`koZj^[3_lS8b<>ob/[:`go
AdM71Oooool>o`L71`ko5QHF3_ooool=obDU9@gooooo000;ooooo`ko00003_l820P>obTY:A;ooooo
3_lH61P>o`h>3Pko=CDe3OlF5QH6ooooo`go<S8b3_lA4A4>okJf]Pgobl_;1_ooool>oaDE5@go:2PX
3_lK6a/=o`h>3PKooooo3_l61PH>og=cL`go4Q8B3Om]KFd6ooooo`ko8b<S3_l410@>od51@@coj^[Z
1_ooool>oj^[Z`ko8b<S3_l[:b/=odM7A`Gooooo3_l71`L>oaHF5Pkooooo3OlU9BD=ooooo`002ooo
ool>o`0000ko20P83_lY:BTBooooo`ko61PH3_l>3Ph>ocDe=@go5QHF1_ooool=oc8b<Pko4A4A3_nf
][H=ol_;b`Kooooo3_lE5AD=obPX:0ko6a/K3Ol>3Ph6ooooo`ko1PH63_mcLg<=oa8B4PgoKFe]1_oo
ool>ob<S8`ko10@43_m1@D4<on[ZjPKooooo3_n[Zj/>ob<S8`ko:b/[3Om7AdL5ooooo`ko1`L73_lF
5QH>ooooo`go9BDU3Oooool000_ooooo3_l0000>o`P820ko:BTY4_ooool>oaPH60ko3Ph>3_le=CD=
oaHF5PKooooo3Olb<S8>oa4A4@ko][Jf3Oo;bl/6ooooo`ko5ADE3OlX:2P>oa/K6`go3Ph>1_ooool>
o`H61PkoLg=c3OlB4Q8=ofe]K@Kooooo3_lS8b<>o`@410ko@D513?oZj^X6ooooo`koZj^[3_lS8b<>
ob/[:`goAdM71Oooool>o`L71`ko5QHF3_ooool=obDU9@gooooo000;ooooo`ko00003_l820P>obTY
:A;ooooo3_lH61P>o`h>3Pko=CDe3OlF5QH6ooooo`go<S8b3_lA4A4>okJf]Pgobl_;1_ooool>oaDE
5@go:2PX3_lK6a/=o`h>3PKooooo3_l61PH>og=cL`go4Q8B3Om]KFd6ooooo`ko8b<S3_l410@>od51
@@coj^[Z1_ooool>oj^[Z`ko8b<S3_l[:b/=odM7A`Gooooo3_l71`L>oaHF5Pkooooo3OlU9BD=oooo
o`002oooool>o`0000ko20P83_lY:BTBooooo`ko61PH3_l>3Ph>ocDe=@go5QHF1_ooool=oc8b<Pko
4A4A3_nf][H=ol_;b`Kooooo3_lE5AD=obPX:0ko6a/K3Ol>3Ph6ooooo`ko1PH63_mcLg<=oa8B4Pgo
KFe]1_ooool>ob<S8`ko10@43_m1@D4<on[ZjPKooooo3_n[Zj/>ob<S8`ko:b/[3Om7AdL5ooooo`ko
1`L73_lF5QH>ooooo`go9BDU3Oooool000_ooooo3_l0000>o`P820ko:BTY4_ooool>oaPH60ko3Ph>
3_le=CD=oaHF5PKooooo3Olb<S8>oa4A4@ko][Jf3Oo;bl/6ooooo`ko5ADE3OlX:2P>oa/K6`go3Ph>
1_ooool>o`H61PkoLg=c3OlB4Q8=ofe]K@Kooooo3_lS8b<>o`@410ko@D513?oZj^X6ooooo`koZj^[
3_lS8b<>ob/[:`goAdM71Oooool>o`L71`ko5QHF3_ooool=obDU9@gooooo000;ooooo`ko00003_l8
20P>obTY:A;ooooo3_lH61P>o`h>3Pko=CDe3OlF5QH6ooooo`go<S8b3_lA4A4>okJf]Pgobl_;1_oo
ool>oaDE5@go:2PX3_lK6a/=o`h>3PKooooo3_l61PH>og=cL`go4Q8B3Om]KFd6ooooo`ko8b<S3_l4
10@>od51@@coj^[Z1_ooool>oj^[Z`ko8b<S3_l[:b/=odM7A`Gooooo3_l71`L>oaHF5Pkooooo3OlU
9BD=ooooo`002oooool>o`0000ko20P83_lY:BTBooooo`ko61PH3_l>3Ph>ocDe=@go5QHF1_ooool=
oc8b<Pko4A4A3_nf][H=ol_;b`Kooooo3_lE5AD=obPX:0ko6a/K3Ol>3Ph6ooooo`ko1PH63_mcLg<=
oa8B4PgoKFe]1_ooool>ob<S8`ko10@43_m1@D4<on[ZjPKooooo3_n[Zj/>ob<S8`ko:b/[3Om7AdL5
ooooo`ko1`L73_lF5QH>ooooo`go9BDU3Oooool000_ooooo3_l0000>o`P820ko:BTY4_ooool>oaPH
60ko3Ph>3_le=CD=oaHF5PKooooo3Olb<S8>oa4A4@ko][Jf3Oo;bl/6ooooo`ko5ADE3OlX:2P>oa/K
6`go3Ph>1_ooool>o`H61PkoLg=c3OlB4Q8=ofe]K@Kooooo3_lS8b<>o`@410ko@D513?oZj^X6oooo
o`koZj^[3_lS8b<>ob/[:`goAdM71Oooool>o`L71`ko5QHF3_ooool=obDU9@gooooo000;ooooo`ko
00003_l820P>obTY:A;ooooo3_lH61P>o`h>3Pko=CDe3OlF5QH6ooooo`go<S8b3_lA4A4>okJf]Pgo
bl_;1_ooool>oaDE5@go:2PX3_lK6a/=o`h>3PKooooo3_l61PH>og=cL`go4Q8B3Om]KFd6ooooo`ko
8b<S3_l410@>od51@@coj^[Z1_ooool>oj^[Z`ko8b<S3_l[:b/=odM7A`Gooooo3_l71`L>oaHF5Pko
oooo3OlU9BD=ooooo`002oooool>o`0000ko20P83_lY:BTBooooo`ko61PH3_l>3Ph>ocDe=@go5QHF
1_ooool=oc8b<Pko4A4A3_nf][H=ol_;b`Kooooo3_lE5AD=obPX:0ko6a/K3Ol>3Ph6ooooo`ko1PH6
3_mcLg<=oa8B4PgoKFe]1_ooool>ob<S8`ko10@43_m1@D4<on[ZjPKooooo3_n[Zj/>ob<S8`ko:b/[
3Om7AdL5ooooo`ko1`L73_lF5QH>ooooo`go9BDU3Oooool000_ooooo3_l@410>o`<30`ko61PH3Oo0
`<05ooooo`ko6a/K3_lC4a<>oc<c<`go00001_ooool=od92@Pko00003_ooool=ojBTY0Kooooo3_lC
4a<=ooooo`koIVIV3Ole=CD6ooooo`ko61PH3_ooool=o`d=3@goVIVI1_ooool>o`X:2Pko6a/K3_lD
51@<o`T92ACooooo3_mDE5@>o`l?3`goD51@1Oooool>o`P820ko5aLG3_o1`L4=ob`/;0gooooo000;
ooooo`ko410@3_l30`<>oaPH60go`<301Oooool>oa/K6`ko4a<C3_lc<c<=o`0000Kooooo3Om2@T8>
o`0000kooooo3OnTY:@6ooooo`ko4a<C3Oooool>ofIVIPgo=CDe1_ooool>oaPH60kooooo3Ol=3@d=
oiVIV@Kooooo3_l:2PX>oa/K6`ko51@D3?l92@TDooooo`koE5AD3_l?3`l=oe1@D0Gooooo3_l820P>
oaLG5`ko`L713Ol/;2`=ooooo`002oooool>oa0@40ko0`<33_lH61P=ol30`0Gooooo3_lK6a/>oa<C
4`ko<c<c3Ol00006ooooo`go@T923_l0000>ooooo`goY:BT1_ooool>oa<C4`gooooo3_mVIVH=ocDe
=@Kooooo3_lH61P>ooooo`go3@d=3OnIVIT6ooooo`ko2PX:3_lK6a/>oa@D50co2@T95?ooool>oeAD
E0ko3`l?3Om@D505ooooo`ko20P83_lG5aL>ol71`@go;2`/3Oooool000_ooooo3_l@410>o`<30`ko
61PH3Oo0`<05ooooo`ko6a/K3_lC4a<>oc<c<`go00001_ooool=od92@Pko00003_ooool=ojBTY0Ko
oooo3_lC4a<=ooooo`koIVIV3Ole=CD6ooooo`ko61PH3_ooool=o`d=3@goVIVI1_ooool>o`X:2Pko
6a/K3_lD51@<o`T92ACooooo3_mDE5@>o`l?3`goD51@1Oooool>o`P820ko5aLG3_o1`L4=ob`/;0go
oooo000;ooooo`ko410@3_l30`<>oaPH60go`<301Oooool>oa/K6`ko4a<C3_lc<c<=o`0000Kooooo
3Om2@T8>o`0000kooooo3OnTY:@6ooooo`ko4a<C3Oooool>ofIVIPgo=CDe1_ooool>oaPH60kooooo
3Ol=3@d=oiVIV@Kooooo3_l:2PX>oa/K6`ko51@D3?l92@TDooooo`koE5AD3_l?3`l=oe1@D0Gooooo
3_l820P>oaLG5`ko`L713Ol/;2`=ooooo`002oooool>oa0@40ko0`<33_lH61P=ol30`0Gooooo3_lK
6a/>oa<C4`ko<c<c3Ol00006ooooo`go@T923_l0000>ooooo`goY:BT1_ooool>oa<C4`gooooo3_mV
IVH=ocDe=@Kooooo3_lH61P>ooooo`go3@d=3OnIVIT6ooooo`ko2PX:3_lK6a/>oa@D50co2@T95?oo
ool>oeADE0ko3`l?3Om@D505ooooo`ko20P83_lG5aL>ol71`@go;2`/3Oooool000_ooooo3_l@410>
o`<30`ko61PH3Oo0`<05ooooo`ko6a/K3_lC4a<>oc<c<`go00001_ooool=od92@Pko00003_ooool=
ojBTY0Kooooo3_lC4a<=ooooo`koIVIV3Ole=CD6ooooo`ko61PH3_ooool=o`d=3@goVIVI1_ooool>
o`X:2Pko6a/K3_lD51@<o`T92ACooooo3_mDE5@>o`l?3`goD51@1Oooool>o`P820ko5aLG3_o1`L4=
ob`/;0gooooo000;ooooo`ko410@3_l30`<>oaPH60go`<301Oooool>oa/K6`ko4a<C3_lc<c<=o`00
00Kooooo3Om2@T8>o`0000kooooo3OnTY:@6ooooo`ko4a<C3Oooool>ofIVIPgo=CDe1_ooool>oaPH
60kooooo3Ol=3@d=oiVIV@Kooooo3_l:2PX>oa/K6`ko51@D3?l92@TDooooo`koE5AD3_l?3`l=oe1@
D0Gooooo3_l820P>oaLG5`ko`L713Ol/;2`=ooooo`002oooool>oa0@40ko0`<33_lH61P=ol30`0Go
oooo3_lK6a/>oa<C4`ko<c<c3Ol00006ooooo`go@T923_l0000>ooooo`goY:BT1_ooool>oa<C4`go
oooo3_mVIVH=ocDe=@Kooooo3_lH61P>ooooo`go3@d=3OnIVIT6ooooo`ko2PX:3_lK6a/>oa@D50co
2@T95?ooool>oeADE0ko3`l?3Om@D505ooooo`ko20P83_lG5aL>ol71`@go;2`/3Oooool000_ooooo
3_l@410>o`<30`ko61PH3Oo0`<05ooooo`ko6a/K3_lC4a<>oc<c<`go00001_ooool=od92@Pko0000
3_ooool=ojBTY0Kooooo3_lC4a<=ooooo`koIVIV3Ole=CD6ooooo`ko61PH3_ooool=o`d=3@goVIVI
1_ooool>o`X:2Pko6a/K3_lD51@<o`T92ACooooo3_mDE5@>o`l?3`goD51@1Oooool>o`P820ko5aLG
3_o1`L4=ob`/;0gooooo000;ooooo`ko410@3_l30`<>oaPH60go`<301Oooool>oa/K6`ko4a<C3_lc
<c<=o`0000Kooooo3Om2@T8>o`0000kooooo3OnTY:@6ooooo`ko4a<C3Oooool>ofIVIPgo=CDe1_oo
ool>oaPH60kooooo3Ol=3@d=oiVIV@Kooooo3_l:2PX>oa/K6`ko51@D3?l92@TDooooo`koE5AD3_l?
3`l=oe1@D0Gooooo3_l820P>oaLG5`ko`L713Ol/;2`=ooooo`002oooool>oa0@40ko0`<33_lH61P=
ol30`0Gooooo3_lK6a/>oa<C4`ko<c<c3Ol00006ooooo`go@T923_l0000>ooooo`goY:BT1_ooool>
oa<C4`gooooo3_mVIVH=ocDe=@Kooooo3_lH61P>ooooo`go3@d=3OnIVIT6ooooo`ko2PX:3_lK6a/>
oa@D50co2@T95?ooool>oeADE0ko3`l?3Om@D505ooooo`ko20P83_lG5aL>ol71`@go;2`/3Oooool0
00_ooooo3_l@410>o`<30`ko61PH3Oo0`<05ooooo`ko6a/K3_lC4a<>oc<c<`go00001_ooool=od92
@Pko00003_ooool=ojBTY0Kooooo3_lC4a<=ooooo`koIVIV3Ole=CD6ooooo`ko61PH3_ooool=o`d=
3@goVIVI1_ooool>o`X:2Pko6a/K3_lD51@<o`T92ACooooo3_mDE5@>o`l?3`goD51@1Oooool>o`P8
20ko5aLG3_o1`L4=ob`/;0gooooo000;ooooo`ko410@3_l30`<>oaPH60go`<301Oooool>oa/K6`ko
4a<C3_lc<c<=o`0000Kooooo3Om2@T8>o`0000kooooo3OnTY:@6ooooo`ko4a<C3Oooool>ofIVIPgo
=CDe1_ooool>oaPH60kooooo3Ol=3@d=oiVIV@Kooooo3_l:2PX>oa/K6`ko51@D3?l92@TDooooo`ko
E5AD3_l?3`l=oe1@D0Gooooo3_l820P>oaLG5`ko`L713Ol/;2`=ooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`006Ooo
ool>ocHf=PkoYjNW3OoQhN45ooooo`koShn?3_l@410>o`@410gonOWi1_ooool=ob0P80koDU9B3_o_
knl=o`l?3`Kooooo3_l>3Ph=o`0000ko51@D3Ole=CD6ooooo`koEeMG3_ooool=o`X:2Pgo820P1_oo
ool>obLW9`ko5aLG3_l;2`/<ob<S8`Kooooo3_oTi>@>oc8b<Pko00003Ol>3Ph5ooooo`ko8B4Q3_l>
3Ph>ol;2`PgoMgMg3Oooool001Wooooo3_lf=SH>ojNWY`gohN7Q1Oooool>ohn?S`ko410@3_l410@=
ooWin@Kooooo3OlP820>oe9BDPkokno_3Ol?3`l6ooooo`ko3Ph>3Ol0000>oa@D50go=CDe1_ooool>
oeMGE`kooooo3Ol:2PX=ob0P80Kooooo3_lW9bL>oaLG5`ko2`/;3?lS8b<6ooooo`koi>CT3_lb<S8>
o`0000go3Ph>1Oooool>ob4Q8@ko3Ph>3_o2`/8=ogMgM`gooooo000Iooooo`ko=SHf3_nWYjL=on7Q
h@Gooooo3_n?Shl>oa0@40ko10@43OoinOT6ooooo`go820P3_mBDU8>ono_k`go3`l?1_ooool>o`h>
3Pgo00003_lD51@=ocDe=@Kooooo3_mGEeL>ooooo`go2PX:3OlP8206ooooo`ko9bLW3_lG5aL>o`/;
2`co8b<S1_ooool>onCTi0ko<S8b3_l0000=o`h>3PGooooo3_lQ8B4>o`h>3Pko`/;23OmgMgL=oooo
o`006Oooool>ocHf=PkoYjNW3OoQhN45ooooo`koShn?3_l@410>o`@410gonOWi1_ooool=ob0P80ko
DU9B3_o_knl=o`l?3`Kooooo3_l>3Ph=o`0000ko51@D3Ole=CD6ooooo`koEeMG3_ooool=o`X:2Pgo
820P1_ooool>obLW9`ko5aLG3_l;2`/<ob<S8`Kooooo3_oTi>@>oc8b<Pko00003Ol>3Ph5ooooo`ko
8B4Q3_l>3Ph>ol;2`PgoMgMg3Oooool001Wooooo3_lf=SH>ojNWY`gohN7Q1Oooool>ohn?S`ko410@
3_l410@=ooWin@Kooooo3OlP820>oe9BDPkokno_3Ol?3`l6ooooo`ko3Ph>3Ol0000>oa@D50go=CDe
1_ooool>oeMGE`kooooo3Ol:2PX=ob0P80Kooooo3_lW9bL>oaLG5`ko2`/;3?lS8b<6ooooo`koi>CT
3_lb<S8>o`0000go3Ph>1Oooool>ob4Q8@ko3Ph>3_o2`/8=ogMgM`gooooo000Iooooo`ko=SHf3_nW
YjL=on7Qh@Gooooo3_n?Shl>oa0@40ko10@43OoinOT6ooooo`go820P3_mBDU8>ono_k`go3`l?1_oo
ool>o`h>3Pgo00003_lD51@=ocDe=@Kooooo3_mGEeL>ooooo`go2PX:3OlP8206ooooo`ko9bLW3_lG
5aL>o`/;2`co8b<S1_ooool>onCTi0ko<S8b3_l0000=o`h>3PGooooo3_lQ8B4>o`h>3Pko`/;23Omg
MgL=ooooo`006Oooool>ocHf=PkoYjNW3OoQhN45ooooo`koShn?3_l@410>o`@410gonOWi1_ooool=
ob0P80koDU9B3_o_knl=o`l?3`Kooooo3_l>3Ph=o`0000ko51@D3Ole=CD6ooooo`koEeMG3_ooool=
o`X:2Pgo820P1_ooool>obLW9`ko5aLG3_l;2`/<ob<S8`Kooooo3_oTi>@>oc8b<Pko00003Ol>3Ph5
ooooo`ko8B4Q3_l>3Ph>ol;2`PgoMgMg3Oooool001Wooooo3_lf=SH>ojNWY`gohN7Q1Oooool>ohn?
S`ko410@3_l410@=ooWin@Kooooo3OlP820>oe9BDPkokno_3Ol?3`l6ooooo`ko3Ph>3Ol0000>oa@D
50go=CDe1_ooool>oeMGE`kooooo3Ol:2PX=ob0P80Kooooo3_lW9bL>oaLG5`ko2`/;3?lS8b<6oooo
o`koi>CT3_lb<S8>o`0000go3Ph>1Oooool>ob4Q8@ko3Ph>3_o2`/8=ogMgM`gooooo000Iooooo`ko
=SHf3_nWYjL=on7Qh@Gooooo3_n?Shl>oa0@40ko10@43OoinOT6ooooo`go820P3_mBDU8>ono_k`go
3`l?1_ooool>o`h>3Pgo00003_lD51@=ocDe=@Kooooo3_mGEeL>ooooo`go2PX:3OlP8206ooooo`ko
9bLW3_lG5aL>o`/;2`co8b<S1_ooool>onCTi0ko<S8b3_l0000=o`h>3PGooooo3_lQ8B4>o`h>3Pko
`/;23OmgMgL=ooooo`006Oooool>ocHf=PkoYjNW3OoQhN45ooooo`koShn?3_l@410>o`@410gonOWi
1_ooool=ob0P80koDU9B3_o_knl=o`l?3`Kooooo3_l>3Ph=o`0000ko51@D3Ole=CD6ooooo`koEeMG
3_ooool=o`X:2Pgo820P1_ooool>obLW9`ko5aLG3_l;2`/<ob<S8`Kooooo3_oTi>@>oc8b<Pko0000
3Ol>3Ph5ooooo`ko8B4Q3_l>3Ph>ol;2`PgoMgMg3Oooool001Wooooo3_lf=SH>ojNWY`gohN7Q1Ooo
ool>ohn?S`ko410@3_l410@=ooWin@Kooooo3OlP820>oe9BDPkokno_3Ol?3`l6ooooo`ko3Ph>3Ol0
000>oa@D50go=CDe1_ooool>oeMGE`kooooo3Ol:2PX=ob0P80Kooooo3_lW9bL>oaLG5`ko2`/;3?lS
8b<6ooooo`koi>CT3_lb<S8>o`0000go3Ph>1Oooool>ob4Q8@ko3Ph>3_o2`/8=ogMgM`gooooo000I
ooooo`ko=SHf3_nWYjL=on7Qh@Gooooo3_n?Shl>oa0@40ko10@43OoinOT6ooooo`go820P3_mBDU8>
ono_k`go3`l?1_ooool>o`h>3Pgo00003_lD51@=ocDe=@Kooooo3_mGEeL>ooooo`go2PX:3OlP8206
ooooo`ko9bLW3_lG5aL>o`/;2`co8b<S1_ooool>onCTi0ko<S8b3_l0000=o`h>3PGooooo3_lQ8B4>
o`h>3Pko`/;23OmgMgL=ooooo`006Oooool>ocHf=PkoYjNW3OoQhN45ooooo`koShn?3_l@410>o`@4
10gonOWi1_ooool=ob0P80koDU9B3_o_knl=o`l?3`Kooooo3_l>3Ph=o`0000ko51@D3Ole=CD6oooo
o`koEeMG3_ooool=o`X:2Pgo820P1_ooool>obLW9`ko5aLG3_l;2`/<ob<S8`Kooooo3_oTi>@>oc8b
<Pko00003Ol>3Ph5ooooo`ko8B4Q3_l>3Ph>ol;2`PgoMgMg3Oooool000_ooooo3_omoOd>oahN7Pko
UYJF3Oo>c/h5ooooo`koSHf=3_l0000>o`d=3A?ooooo3OlO7al>ob`/;0kooooo3Ol00006ooooo`ko
4a<C3Oooool>og1`L0go=CDe1_ooool>of5QH@kof=SH3Ol20P8=o`P820Kooooo3_l/;2`>oa0@40ko
4a<C3?lS8b<6ooooo`kolO7a3_lD51@>o`h>3Pgo5ADE1Oooool>o`P820ko3`l?3_ooool=og9bLPgo
oooo000;ooooo`kooOgm3_lN7Qh>oiJFUPgoc/k>1Oooool>ohf=S@ko00003_l=3@dCooooo`go7alO
3_l/;2`>ooooo`go00001_ooool>oa<C4`gooooo3_m`L70=ocDe=@Kooooo3_mQHF4>omSHf0go0P82
3Ol820P6ooooo`ko;2`/3_l@410>oa<C4`co8b<S1_ooool>oo7al@ko51@D3_l>3Ph=oaDE5@Gooooo
3_l820P>o`l?3`kooooo3OmbLW8=ooooo`002oooool>oogmo@ko7QhN3_nFUYH=olk>cPGooooo3_n=
SHd>o`0000ko3@d=4oooool=oalO7`ko;2`/3_ooool=o`0000Kooooo3_lC4a<=ooooo`koL71`3Ole
=CD6ooooo`koHF5Q3_oHf=P=o`820Pgo20P81_ooool>ob`/;0ko410@3_lC4a<<ob<S8`Kooooo3_oa
lO4>oa@D50ko3Ph>3OlE5AD5ooooo`ko20P83_l?3`l>ooooo`goLW9b3Oooool000_ooooo3_omoOd>
oahN7PkoUYJF3Oo>c/h5ooooo`koSHf=3_l0000>o`d=3A?ooooo3OlO7al>ob`/;0kooooo3Ol00006
ooooo`ko4a<C3Oooool>og1`L0go=CDe1_ooool>of5QH@kof=SH3Ol20P8=o`P820Kooooo3_l/;2`>
oa0@40ko4a<C3?lS8b<6ooooo`kolO7a3_lD51@>o`h>3Pgo5ADE1Oooool>o`P820ko3`l?3_ooool=
og9bLPgooooo000;ooooo`kooOgm3_lN7Qh>oiJFUPgoc/k>1Oooool>ohf=S@ko00003_l=3@dCoooo
o`go7alO3_l/;2`>ooooo`go00001_ooool>oa<C4`gooooo3_m`L70=ocDe=@Kooooo3_mQHF4>omSH
f0go0P823Ol820P6ooooo`ko;2`/3_l@410>oa<C4`co8b<S1_ooool>oo7al@ko51@D3_l>3Ph=oaDE
5@Gooooo3_l820P>o`l?3`kooooo3OmbLW8=ooooo`002oooool>oogmo@ko7QhN3_nFUYH=olk>cPGo
oooo3_n=SHd>o`0000ko3@d=4oooool=oalO7`ko;2`/3_ooool=o`0000Kooooo3_lC4a<=ooooo`ko
L71`3Ole=CD6ooooo`koHF5Q3_oHf=P=o`820Pgo20P81_ooool>ob`/;0ko410@3_lC4a<<ob<S8`Ko
oooo3_oalO4>oa@D50ko3Ph>3OlE5AD5ooooo`ko20P83_l?3`l>ooooo`goLW9b3Oooool000_ooooo
3_omoOd>oahN7PkoUYJF3Oo>c/h5ooooo`koSHf=3_l0000>o`d=3A?ooooo3OlO7al>ob`/;0kooooo
3Ol00006ooooo`ko4a<C3Oooool>og1`L0go=CDe1_ooool>of5QH@kof=SH3Ol20P8=o`P820Kooooo
3_l/;2`>oa0@40ko4a<C3?lS8b<6ooooo`kolO7a3_lD51@>o`h>3Pgo5ADE1Oooool>o`P820ko3`l?
3_ooool=og9bLPgooooo000;ooooo`kooOgm3_lN7Qh>oiJFUPgoc/k>1Oooool>ohf=S@ko00003_l=
3@dCooooo`go7alO3_l/;2`>ooooo`go00001_ooool>oa<C4`gooooo3_m`L70=ocDe=@Kooooo3_mQ
HF4>omSHf0go0P823Ol820P6ooooo`ko;2`/3_l@410>oa<C4`co8b<S1_ooool>oo7al@ko51@D3_l>
3Ph=oaDE5@Gooooo3_l820P>o`l?3`kooooo3OmbLW8=ooooo`002oooool>oogmo@ko7QhN3_nFUYH=
olk>cPGooooo3_n=SHd>o`0000ko3@d=4oooool=oalO7`ko;2`/3_ooool=o`0000Kooooo3_lC4a<=
ooooo`koL71`3Ole=CD6ooooo`koHF5Q3_oHf=P=o`820Pgo20P81_ooool>ob`/;0ko410@3_lC4a<<
ob<S8`Kooooo3_oalO4>oa@D50ko3Ph>3OlE5AD5ooooo`ko20P83_l?3`l>ooooo`goLW9b3Oooool0
00_ooooo3_omoOd>oahN7PkoUYJF3Oo>c/h5ooooo`koSHf=3_l0000>o`d=3A?ooooo3OlO7al>ob`/
;0kooooo3Ol00006ooooo`ko4a<C3Oooool>og1`L0go=CDe1_ooool>of5QH@kof=SH3Ol20P8=o`P8
20Kooooo3_l/;2`>oa0@40ko4a<C3?lS8b<6ooooo`kolO7a3_lD51@>o`h>3Pgo5ADE1Oooool>o`P8
20ko3`l?3_ooool=og9bLPgooooo000;ooooo`kooOgm3_lN7Qh>oiJFUPgoc/k>1Oooool>ohf=S@ko
00003_l=3@dCooooo`go7alO3_l/;2`>ooooo`go00001_ooool>oa<C4`gooooo3_m`L70=ocDe=@Ko
oooo3_mQHF4>omSHf0go0P823Ol820P6ooooo`ko;2`/3_l@410>oa<C4`co8b<S1_ooool>oo7al@ko
51@D3_l>3Ph=oaDE5@Gooooo3_l820P>o`l?3`kooooo3OmbLW8=ooooo`002oooool>oogmo@ko7QhN
3_nFUYH=olk>cPGooooo3_n=SHd>o`0000ko3@d=4oooool=oalO7`ko;2`/3_ooool=o`0000Kooooo
3_lC4a<=ooooo`koL71`3Ole=CD6ooooo`koHF5Q3_oHf=P=o`820Pgo20P81_ooool>ob`/;0ko410@
3_lC4a<<ob<S8`Kooooo3_oalO4>oa@D50ko3Ph>3OlE5AD5ooooo`ko20P83_l?3`l>ooooo`goLW9b
3Oooool000_ooooo3_omoOd>oahN7PkoUYJF3Oo>c/h5ooooo`koSHf=3_l0000>o`d=3A?ooooo3OlO
7al>ob`/;0kooooo3Ol00006ooooo`ko4a<C3Oooool>og1`L0go=CDe1_ooool>of5QH@kof=SH3Ol2
0P8=o`P820Kooooo3_l/;2`>oa0@40ko4a<C3?lS8b<6ooooo`kolO7a3_lD51@>o`h>3Pgo5ADE1Ooo
ool>o`P820ko3`l?3_ooool=og9bLPgooooo000;ooooo`kooOgm3_lN7Qh>oiJFUPgoc/k>1Oooool>
ohf=S@ko00003_l=3@dCooooo`go7alO3_l/;2`>ooooo`go00001_ooool>oa<C4`gooooo3_m`L70=
ocDe=@Kooooo3_mQHF4>omSHf0go0P823Ol820P6ooooo`ko;2`/3_l@410>oa<C4`co8b<S1_ooool>
oo7al@ko51@D3_l>3Ph=oaDE5@Gooooo3_l820P>o`l?3`kooooo3OmbLW8=ooooo`002oooool>oiZJ
VPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCT
i0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006oooo
o`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ
:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko
410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKo
oooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko
30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG
3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@41
1_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b
3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi
3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7
alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mG
EeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP
820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=
ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>
od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>
o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=
ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6oooo
o`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno
_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S
8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Go
oooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo
5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000co
f=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`00
2oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ
3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B
3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo
3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nN
WYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI
6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_oo
ool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>
oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>
onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006
ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>
obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>
3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYj
NPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`
l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiZJVPko
5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go
0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko
<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko
^KVi3On3Ph<=ooooo`002oooool>oiZJVPko5aLG3_nMWId=ojRXZ0Gooooo3_nNWYh>o`h>3Pko410@
3Oo7alL6ooooo`go:RXZ3_l?3`l>onCTi0go0@411_ooool>od92@Pgo5aLG3_lI6AT=ogYjNPKooooo
3_mGEeL>okno_`go4Q8B3Ol00006ooooo`ko<S8b3_l71`L>o`0000cof=SH1_ooool>oo3`l0ko30`<
3_lP820=ob<S8`Gooooo3_l:2PX>obXZ:Pko^KVi3On3Ph<=ooooo`002oooool>oiRHV0ko00003_nM
WId=ooclo0Gooooo3_m_Kfl>oaDE5@ko51@D3OnCTi<6ooooo`go<30`3_l61PH>olC4a0go:RXZ1_oo
ool>o`d=3@go5QHF3_l<30`=oaLG5`Kooooo3_lc<c<>ohJ6QPgo9RHV3Ol10@46ooooo`ko8R8R3_l4
10@>oaLG5b3ooooo3_l<30`>obHV9Pgo4Q8B1Oooool>o`0000koADE53_m;Bd/=om3@d0gooooo000;
ooooo`koV9RH3_l0000>oifMW@goo?cl1Oooool>ofm_K`ko5ADE3_lD51@=oi>CT`Kooooo3Ol`<30>
o`H61Pkoa<C43OlZ:RX6ooooo`ko3@d=3OlF5QH>o``<30go5aLG1_ooool>oc<c<`koQXJ63OlV9RH=
o`410@Kooooo3_lR8R8>o`@410ko5aLG8?ooool>o``<30ko9RHV3OlB4Q85ooooo`ko00003_m5ADD>
od];B`god=3@3Oooool000_ooooo3_nHV9P>o`0000koWIfM3Oolo?`5ooooo`koKfm_3_lE5AD>oa@D
50goTi>C1_ooool=oc0`<0ko1PH63_o4a<@=obXZ:PKooooo3_l=3@d=oaHF5Pko30`<3OlG5aL6oooo
o`ko<c<c3_n6QXH=obHV9Pgo0@411_ooool>ob8R8Pko10@43_lG5aLPooooo`ko30`<3_lV9RH=oa8B
4PGooooo3_l0000>odE5A@koBd];3Oo@d=0=ooooo`002oooool>oiRHV0ko00003_nMWId=ooclo0Go
oooo3_m_Kfl>oaDE5@ko51@D3OnCTi<6ooooo`go<30`3_l61PH>olC4a0go:RXZ1_ooool>o`d=3@go
5QHF3_l<30`=oaLG5`Kooooo3_lc<c<>ohJ6QPgo9RHV3Ol10@46ooooo`ko8R8R3_l410@>oaLG5b3o
oooo3_l<30`>obHV9Pgo4Q8B1Oooool>o`0000koADE53_m;Bd/=om3@d0gooooo000;ooooo`koV9RH
3_l0000>oifMW@goo?cl1Oooool>ofm_K`ko5ADE3_lD51@=oi>CT`Kooooo3Ol`<30>o`H61Pkoa<C4
3OlZ:RX6ooooo`ko3@d=3OlF5QH>o``<30go5aLG1_ooool>oc<c<`koQXJ63OlV9RH=o`410@Kooooo
3_lR8R8>o`@410ko5aLG8?ooool>o``<30ko9RHV3OlB4Q85ooooo`ko00003_m5ADD>od];B`god=3@
3Oooool000_ooooo3_nHV9P>o`0000koWIfM3Oolo?`5ooooo`koKfm_3_lE5AD>oa@D50goTi>C1_oo
ool=oc0`<0ko1PH63_o4a<@=obXZ:PKooooo3_l=3@d=oaHF5Pko30`<3OlG5aL6ooooo`ko<c<c3_n6
QXH=obHV9Pgo0@411_ooool>ob8R8Pko10@43_lG5aLPooooo`ko30`<3_lV9RH=oa8B4PGooooo3_l0
000>odE5A@koBd];3Oo@d=0=ooooo`002oooool>oiRHV0ko00003_nMWId=ooclo0Gooooo3_m_Kfl>
oaDE5@ko51@D3OnCTi<6ooooo`go<30`3_l61PH>olC4a0go:RXZ1_ooool>o`d=3@go5QHF3_l<30`=
oaLG5`Kooooo3_lc<c<>ohJ6QPgo9RHV3Ol10@46ooooo`ko8R8R3_l410@>oaLG5b3ooooo3_l<30`>
obHV9Pgo4Q8B1Oooool>o`0000koADE53_m;Bd/=om3@d0gooooo000;ooooo`koV9RH3_l0000>oifM
W@goo?cl1Oooool>ofm_K`ko5ADE3_lD51@=oi>CT`Kooooo3Ol`<30>o`H61Pkoa<C43OlZ:RX6oooo
o`ko3@d=3OlF5QH>o``<30go5aLG1_ooool>oc<c<`koQXJ63OlV9RH=o`410@Kooooo3_lR8R8>o`@4
10ko5aLG8?ooool>o``<30ko9RHV3OlB4Q85ooooo`ko00003_m5ADD>od];B`god=3@3Oooool000_o
oooo3_nHV9P>o`0000koWIfM3Oolo?`5ooooo`koKfm_3_lE5AD>oa@D50goTi>C1_ooool=oc0`<0ko
1PH63_o4a<@=obXZ:PKooooo3_l=3@d=oaHF5Pko30`<3OlG5aL6ooooo`ko<c<c3_n6QXH=obHV9Pgo
0@411_ooool>ob8R8Pko10@43_lG5aLPooooo`ko30`<3_lV9RH=oa8B4PGooooo3_l0000>odE5A@ko
Bd];3Oo@d=0=ooooo`002oooool>oiRHV0ko00003_nMWId=ooclo0Gooooo3_m_Kfl>oaDE5@ko51@D
3OnCTi<6ooooo`go<30`3_l61PH>olC4a0go:RXZ1_ooool>o`d=3@go5QHF3_l<30`=oaLG5`Kooooo
3_lc<c<>ohJ6QPgo9RHV3Ol10@46ooooo`ko8R8R3_l410@>oaLG5b3ooooo3_l<30`>obHV9Pgo4Q8B
1Oooool>o`0000koADE53_m;Bd/=om3@d0gooooo000;ooooo`koV9RH3_l0000>oifMW@goo?cl1Ooo
ool>ofm_K`ko5ADE3_lD51@=oi>CT`Kooooo3Ol`<30>o`H61Pkoa<C43OlZ:RX6ooooo`ko3@d=3OlF
5QH>o``<30go5aLG1_ooool>oc<c<`koQXJ63OlV9RH=o`410@Kooooo3_lR8R8>o`@410ko5aLG8?oo
ool>o``<30ko9RHV3OlB4Q85ooooo`ko00003_m5ADD>od];B`god=3@3Oooool000_ooooo3_nHV9P>
o`0000koWIfM3Oolo?`5ooooo`koKfm_3_lE5AD>oa@D50goTi>C1_ooool=oc0`<0ko1PH63_o4a<@=
obXZ:PKooooo3_l=3@d=oaHF5Pko30`<3OlG5aL6ooooo`ko<c<c3_n6QXH=obHV9Pgo0@411_ooool>
ob8R8Pko10@43_lG5aLPooooo`ko30`<3_lV9RH=oa8B4PGooooo3_l0000>odE5A@koBd];3Oo@d=0=
ooooo`002oooool>oiRHV0ko00003_nMWId=ooclo0Gooooo3_m_Kfl>oaDE5@ko51@D3OnCTi<6oooo
o`go<30`3_l61PH>olC4a0go:RXZ1_ooool>o`d=3@go5QHF3_l<30`=oaLG5`Kooooo3_lc<c<>ohJ6
QPgo9RHV3Ol10@46ooooo`ko8R8R3_l410@>oaLG5b3ooooo3_l<30`>obHV9Pgo4Q8B1Oooool>o`00
00koADE53_m;Bd/=om3@d0gooooo000;ooooo`koV9RH3_l0000>oifMW@goo?cl1Oooool>ofm_K`ko
5ADE3_lD51@=oi>CT`Kooooo3Ol`<30>o`H61Pkoa<C43OlZ:RX6ooooo`ko3@d=3OlF5QH>o``<30go
5aLG1_ooool>oc<c<`koQXJ63OlV9RH=o`410@Kooooo3_lR8R8>o`@410ko5aLG8?ooool>o``<30ko
9RHV3OlB4Q85ooooo`ko00003_m5ADD>od];B`god=3@3Oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-0.869594, -0.874171, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-5.26781, \
-0.874171, 0.0732273, 0.0732273}, {{132, 186.625}, {487.062, 432.438}} -> \
{-9.66602, -0.874171, 0.0732273, 0.0732273}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-14.0688, -0.874171, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {487.062, 432.438}} -> {-18.467, -0.874171, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {487.062, 432.438}} -> {-22.8698, -0.874171, 0.0732273, \
0.0732273}, {{372.375, 427}, {487.062, 432.438}} -> {-27.268, -0.874171, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {487.062, 432.438}} -> {-31.6662, \
-0.874171, 0.0732273, 0.0732273}, {{11.875, 66.5}, {427, 372.375}} -> \
{-0.869594, -5.27238, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {427, \
372.375}} -> {-5.26781, -5.27238, 0.0732273, 0.0732273}, {{132, 186.625}, \
{427, 372.375}} -> {-9.66602, -5.27238, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {427, 372.375}} -> {-14.0688, -5.27238, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {427, 372.375}} -> {-18.467, -5.27238, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {427, 372.375}} -> {-22.8698, -5.27238, \
0.0732273, 0.0732273}, {{372.375, 427}, {427, 372.375}} -> {-27.268, \
-5.27238, 0.0732273, 0.0732273}, {{432.438, 487.062}, {427, 372.375}} -> \
{-31.6662, -5.27238, 0.0732273, 0.0732273}, {{11.875, 66.5}, {366.938, \
312.312}} -> {-0.869594, -9.6706, 0.0732273, 0.0732273}, {{71.9375, 126.562}, \
{366.938, 312.312}} -> {-5.26781, -9.6706, 0.0732273, 0.0732273}, {{132, \
186.625}, {366.938, 312.312}} -> {-9.66602, -9.6706, 0.0732273, 0.0732273}, \
{{192.125, 246.75}, {366.938, 312.312}} -> {-14.0688, -9.6706, 0.0732273, \
0.0732273}, {{252.188, 306.812}, {366.938, 312.312}} -> {-18.467, -9.6706, \
0.0732273, 0.0732273}, {{312.312, 366.938}, {366.938, 312.312}} -> {-22.8698, \
-9.6706, 0.0732273, 0.0732273}, {{372.375, 427}, {366.938, 312.312}} -> \
{-27.268, -9.6706, 0.0732273, 0.0732273}, {{432.438, 487.062}, {366.938, \
312.312}} -> {-31.6662, -9.6706, 0.0732273, 0.0732273}, {{11.875, 66.5}, \
{306.812, 252.188}} -> {-0.869594, -14.0734, 0.0732273, 0.0732273}, \
{{71.9375, 126.562}, {306.812, 252.188}} -> {-5.26781, -14.0734, 0.0732273, \
0.0732273}, {{132, 186.625}, {306.812, 252.188}} -> {-9.66602, -14.0734, \
0.0732273, 0.0732273}, {{192.125, 246.75}, {306.812, 252.188}} -> {-14.0688, \
-14.0734, 0.0732273, 0.0732273}, {{252.188, 306.812}, {306.812, 252.188}} -> \
{-18.467, -14.0734, 0.0732273, 0.0732273}, {{312.312, 366.938}, {306.812, \
252.188}} -> {-22.8698, -14.0734, 0.0732273, 0.0732273}, {{372.375, 427}, \
{306.812, 252.188}} -> {-27.268, -14.0734, 0.0732273, 0.0732273}, {{432.438, \
487.062}, {306.812, 252.188}} -> {-31.6662, -14.0734, 0.0732273, 0.0732273}, \
{{11.875, 66.5}, {246.75, 192.125}} -> {-0.869594, -18.4716, 0.0732273, \
0.0732273}, {{71.9375, 126.562}, {246.75, 192.125}} -> {-5.26781, -18.4716, \
0.0732273, 0.0732273}, {{132, 186.625}, {246.75, 192.125}} -> {-9.66602, \
-18.4716, 0.0732273, 0.0732273}, {{192.125, 246.75}, {246.75, 192.125}} -> \
{-14.0688, -18.4716, 0.0732273, 0.0732273}, {{252.188, 306.812}, {246.75, \
192.125}} -> {-18.467, -18.4716, 0.0732273, 0.0732273}, {{312.312, 366.938}, \
{246.75, 192.125}} -> {-22.8698, -18.4716, 0.0732273, 0.0732273}, {{372.375, \
427}, {246.75, 192.125}} -> {-27.268, -18.4716, 0.0732273, 0.0732273}, \
{{432.438, 487.062}, {246.75, 192.125}} -> {-31.6662, -18.4716, 0.0732273, \
0.0732273}, {{11.875, 66.5}, {186.625, 132}} -> {-0.869594, -22.8744, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {186.625, 132}} -> {-5.26781, \
-22.8744, 0.0732273, 0.0732273}, {{132, 186.625}, {186.625, 132}} -> \
{-9.66602, -22.8744, 0.0732273, 0.0732273}, {{192.125, 246.75}, {186.625, \
132}} -> {-14.0688, -22.8744, 0.0732273, 0.0732273}, {{252.188, 306.812}, \
{186.625, 132}} -> {-18.467, -22.8744, 0.0732273, 0.0732273}, {{312.312, \
366.938}, {186.625, 132}} -> {-22.8698, -22.8744, 0.0732273, 0.0732273}, \
{{372.375, 427}, {186.625, 132}} -> {-27.268, -22.8744, 0.0732273, \
0.0732273}, {{432.438, 487.062}, {186.625, 132}} -> {-31.6662, -22.8744, \
0.0732273, 0.0732273}, {{11.875, 66.5}, {126.562, 71.9375}} -> {-0.869594, \
-27.2726, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {126.562, 71.9375}} -> \
{-5.26781, -27.2726, 0.0732273, 0.0732273}, {{132, 186.625}, {126.562, \
71.9375}} -> {-9.66602, -27.2726, 0.0732273, 0.0732273}, {{192.125, 246.75}, \
{126.562, 71.9375}} -> {-14.0688, -27.2726, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {126.562, 71.9375}} -> {-18.467, -27.2726, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {126.562, 71.9375}} -> {-22.8698, -27.2726, 0.0732273, \
0.0732273}, {{372.375, 427}, {126.562, 71.9375}} -> {-27.268, -27.2726, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {126.562, 71.9375}} -> {-31.6662, \
-27.2726, 0.0732273, 0.0732273}, {{11.875, 66.5}, {66.5, 11.875}} -> \
{-0.869594, -31.6708, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {66.5, \
11.875}} -> {-5.26781, -31.6708, 0.0732273, 0.0732273}, {{132, 186.625}, \
{66.5, 11.875}} -> {-9.66602, -31.6708, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {66.5, 11.875}} -> {-14.0688, -31.6708, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {66.5, 11.875}} -> {-18.467, -31.6708, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {66.5, 11.875}} -> {-22.8698, -31.6708, \
0.0732273, 0.0732273}, {{372.375, 427}, {66.5, 11.875}} -> {-27.268, \
-31.6708, 0.0732273, 0.0732273}, {{432.438, 487.062}, {66.5, 11.875}} -> \
{-31.6662, -31.6708, 0.0732273, 0.0732273}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.133279 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1F155B13
1A3CFF3C
08252400
2F17221E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0238095 0.253695 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7C021E67
D68D0038
FFF73611
44033C5B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0238095 0.374111 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2F48EDFF
7806EF9A
CD00B753
0A97AEDE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0238095 0.494527 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C3FF9903
2BCBB711
007DAB29
BBB81210
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0238095 0.614943 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
564D15FF
1F401B38
0E090009
2B2A212F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0238095 0.735359 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19400818
66420056
0F18084C
4A2119FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0238095 0.855774 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
009A2723
00344D17
0C0F2F31
4AFF4225
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0238095 0.97619 0.133279 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BA950D07
BBECA801
4DFFF100
9E4D0642
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.144226 0.133279 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
63151D00
FF430720
2C140012
1B361112
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.144226 0.253695 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
094D2A1F
1406025B
FF6E005A
0C7D003F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.144226 0.374111 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2A111335
0F030515
330904FF
33001934
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.144226 0.494527 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2EBA2249
00F59DA3
01B7FFA4
4B870A12
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.144226 0.614943 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
18674C24
00143D3E
5F152297
43FF1A11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.144226 0.735359 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6E02FF41
67132C17
461B0F0D
4B00808A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.144226 0.855774 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A27178A
1A350F18
002D042C
0C56FF1D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.144226 0.97619 0.253695 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
26081429
08280532
04000F08
FF4A023C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.264641 0.133279 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2D16020A
14090E09
1A0F060B
FF341E00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.264641 0.253695 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
72002478
FF38115E
7A301627
15342B4F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.264641 0.374111 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00111237
1325FF0D
21272132
1111100C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.264641 0.494527 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
121C011A
28FF3732
0F231F43
001A1445
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.264641 0.614943 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
122500FF
252B0134
1A153233
1C1C095C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.264641 0.735359 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
111A1C5D
080E190A
0012071C
21173AFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.264641 0.855774 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
16FF7C4A
13344B6B
270E3C2C
004D1D33
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.264641 0.97619 0.374111 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF9F1470
D8B41A00
ADBF3B02
C62C2A9A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.385057 0.133279 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1D00061A
190C1541
13291CFF
18191B1A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.385057 0.253695 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0111021B
301B2017
FF006508
1C020019
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.385057 0.374111 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0B020515
2C0B26FF
000B0C42
2004291A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.385057 0.494527 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E110321
0425021E
02FF2D40
003F1651
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.385057 0.614943 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2CFF1912
0C4E0410
00230714
14252925
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.385057 0.735359 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0113011F
00090813
190C1529
3A2B07FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.385057 0.855774 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
032F9B36
2F003F55
A4361B45
0EA8FF11
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.385057 0.97619 0.494527 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F08E0A00
4E74110E
11743848
FF211942
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.505473 0.133279 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0D042900
0D003106
070AFF06
1919281B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.505473 0.253695 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
68053B37
CF37001E
E4F32128
3C06FF3F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.505473 0.374111 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0C56688D
4F13B2FB
8600FFDF
298C5537
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.505473 0.494527 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ACFF1E09
24AB4144
00B47690
FEF70513
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.505473 0.614943 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5D004AFF
21183E7C
3D261F63
2B112432
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.505473 0.735359 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
051E1740
1F1800E3
1A14090F
6B1908FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.505473 0.855774 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
16001E47
181D1537
0D1F0A06
16FF3963
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.505473 0.97619 0.614943 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AF5C0007
BEF3341D
8AFF9439
831C2108
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.625889 0.133279 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1E1C0600
2A1B1303
FF3F0D17
1012120D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.625889 0.253695 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
001F4D5C
940D2992
FF3E0A91
095F5634
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.625889 0.374111 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
324E1C01
043E4A5E
243B82FF
74411300
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.625889 0.494527 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
111B1214
00113D25
0623FF0C
25103A33
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.625889 0.614943 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1C3C1403
11110607
05150B00
00FF3629
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.625889 0.735359 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2B14E86F
68132921
A2770009
2034D1FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.625889 0.855774 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5223300D
2C141610
0D003427
350AFF31
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.625889 0.97619 0.735359 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00042016
1B001725
2D00041C
FF1F1903
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.746305 0.133279 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2E011112
25150015
281E0F07
FF123930
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.746305 0.253695 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0A220614
FF291F00
04030208
0A220B22
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.746305 0.374111 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
183DFF3C
1C19BA36
270C5526
00394529
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.746305 0.494527 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
090E0A0A
10FF260D
0E0B0023
0F0D3926
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.746305 0.614943 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
291D38FF
0018083A
18120310
21163521
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.746305 0.735359 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
363B270E
2D255000
33133C4D
3B5415FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.746305 0.855774 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2CFFF329
0061CD3F
390E998C
AAFBEE17
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.746305 0.97619 0.855774 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF2E152A
53240E29
4814002D
2A291661
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.866721 0.133279 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
28006B72
0E3B3596
138366C3
1569FFAA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.866721 0.253695 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
201B0403
35190500
FF680A0C
00070D1B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.866721 0.374111 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
36002028
280B0EFF
00200842
080E271C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.866721 0.494527 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
231D3B0D
17581B00
05FF4436
430B2717
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.866721 0.614943 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
12200D04
0B41121D
00430913
1EFF261F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.866721 0.735359 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05070C1F
120F072F
0E200015
0C092CFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.866721 0.855774 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
08022E00
0A150F06
0A0C1802
1E06FF1B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.866721 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 1 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF1E1D49
5711000B
3E1E150E
88151E44
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`002oooool>oalO7`ko5ADE3_mKFe/=oa<C4`Gooooo
3_mlO7`>o`820Pko7QhN3OmWIfL6ooooo`go;bl_3_m8B4P>ong]kA?ooooo3_o3`l<=ooooo`koVIVI
3Ol30`<6ooooo`koEUIF3_m=CDd=oaDE5A?ooooo3_lI6AT>od10@0ko20P83?lH61P6ooooo`ko0000
3_nJVYX>obLW9`go8b<S1Oooool>okZj^PkoUIFE3_l=3@d=o`L71`gooooo000;ooooo`ko7alO3_lE
5AD>oe]KF`go4a<C1Oooool>ogalO0ko0P823_lN7Qh=ofMWI`Kooooo3Ol_;bl>odQ8B0kokNg]4ooo
ool>ol?3``gooooo3_nIVIT=o`<30`Kooooo3_mFEUH>ode=C@go5ADE4oooool>oaTI6@ko@4103_l8
20P<oaPH60Kooooo3_l0000>oiZJVPko9bLW3OlS8b<5ooooo`ko^[Zj3_nEUID>o`d=3@go1`L73Ooo
ool000_ooooo3_lO7al>oaDE5@koFe]K3OlC4a<5ooooo`koO7al3_l20P8>oahN7PgoIfMW1_ooool=
obl_;`koB4Q83_o]kNdCooooo`ko`l?33Oooool>oiVIV@go0`<31_ooool>oeIFEPkoCDe=3OlE5ADC
ooooo`ko6ATI3_m0@40>o`P820co61PH1_ooool>o`0000koVYZJ3_lW9bL=ob<S8`Gooooo3_nj^[X>
oiFEU@ko3@d=3Ol71`L=ooooo`002oooool>oalO7`ko5ADE3_mKFe/=oa<C4`Gooooo3_mlO7`>o`82
0Pko7QhN3OmWIfL6ooooo`go;bl_3_m8B4P>ong]kA?ooooo3_o3`l<=ooooo`koVIVI3Ol30`<6oooo
o`koEUIF3_m=CDd=oaDE5A?ooooo3_lI6AT>od10@0ko20P83?lH61P6ooooo`ko00003_nJVYX>obLW
9`go8b<S1Oooool>okZj^PkoUIFE3_l=3@d=o`L71`gooooo000;ooooo`ko7alO3_lE5AD>oe]KF`go
4a<C1Oooool>ogalO0ko0P823_lN7Qh=ofMWI`Kooooo3Ol_;bl>odQ8B0kokNg]4oooool>ol?3``go
oooo3_nIVIT=o`<30`Kooooo3_mFEUH>ode=C@go5ADE4oooool>oaTI6@ko@4103_l820P<oaPH60Ko
oooo3_l0000>oiZJVPko9bLW3OlS8b<5ooooo`ko^[Zj3_nEUID>o`d=3@go1`L73Oooool000_ooooo
3_lO7al>oaDE5@koFe]K3OlC4a<5ooooo`koO7al3_l20P8>oahN7PgoIfMW1_ooool=obl_;`koB4Q8
3_o]kNdCooooo`ko`l?33Oooool>oiVIV@go0`<31_ooool>oeIFEPkoCDe=3OlE5ADCooooo`ko6ATI
3_m0@40>o`P820co61PH1_ooool>o`0000koVYZJ3_lW9bL=ob<S8`Gooooo3_nj^[X>oiFEU@ko3@d=
3Ol71`L=ooooo`002oooool>oalO7`ko5ADE3_mKFe/=oa<C4`Gooooo3_mlO7`>o`820Pko7QhN3OmW
IfL6ooooo`go;bl_3_m8B4P>ong]kA?ooooo3_o3`l<=ooooo`koVIVI3Ol30`<6ooooo`koEUIF3_m=
CDd=oaDE5A?ooooo3_lI6AT>od10@0ko20P83?lH61P6ooooo`ko00003_nJVYX>obLW9`go8b<S1Ooo
ool>okZj^PkoUIFE3_l=3@d=o`L71`gooooo000;ooooo`ko7alO3_lE5AD>oe]KF`go4a<C1Oooool>
ogalO0ko0P823_lN7Qh=ofMWI`Kooooo3Ol_;bl>odQ8B0kokNg]4oooool>ol?3``gooooo3_nIVIT=
o`<30`Kooooo3_mFEUH>ode=C@go5ADE4oooool>oaTI6@ko@4103_l820P<oaPH60Kooooo3_l0000>
oiZJVPko9bLW3OlS8b<5ooooo`ko^[Zj3_nEUID>o`d=3@go1`L73Oooool000_ooooo3_lO7al>oaDE
5@koFe]K3OlC4a<5ooooo`koO7al3_l20P8>oahN7PgoIfMW1_ooool=obl_;`koB4Q83_o]kNdCoooo
o`ko`l?33Oooool>oiVIV@go0`<31_ooool>oeIFEPkoCDe=3OlE5ADCooooo`ko6ATI3_m0@40>o`P8
20co61PH1_ooool>o`0000koVYZJ3_lW9bL=ob<S8`Gooooo3_nj^[X>oiFEU@ko3@d=3Ol71`L=oooo
o`002oooool>oalO7`ko5ADE3_mKFe/=oa<C4`Gooooo3_mlO7`>o`820Pko7QhN3OmWIfL6ooooo`go
;bl_3_m8B4P>ong]kA?ooooo3_o3`l<=ooooo`koVIVI3Ol30`<6ooooo`koEUIF3_m=CDd=oaDE5A?o
oooo3_lI6AT>od10@0ko20P83?lH61P6ooooo`ko00003_nJVYX>obLW9`go8b<S1Oooool>okZj^Pko
UIFE3_l=3@d=o`L71`gooooo000;ooooo`ko7alO3_lE5AD>oe]KF`go4a<C1Oooool>ogalO0ko0P82
3_lN7Qh=ofMWI`Kooooo3Ol_;bl>odQ8B0kokNg]4oooool>ol?3``gooooo3_nIVIT=o`<30`Kooooo
3_mFEUH>ode=C@go5ADE4oooool>oaTI6@ko@4103_l820P<oaPH60Kooooo3_l0000>oiZJVPko9bLW
3OlS8b<5ooooo`ko^[Zj3_nEUID>o`d=3@go1`L73Oooool000_ooooo3_lO7al>oaDE5@koFe]K3OlC
4a<5ooooo`koO7al3_l20P8>oahN7PgoIfMW1_ooool=obl_;`koB4Q83_o]kNdCooooo`ko`l?33Ooo
ool>oiVIV@go0`<31_ooool>oeIFEPkoCDe=3OlE5ADCooooo`ko6ATI3_m0@40>o`P820co61PH1_oo
ool>o`0000koVYZJ3_lW9bL=ob<S8`Gooooo3_nj^[X>oiFEU@ko3@d=3Ol71`L=ooooo`002oooool>
oalO7`ko5ADE3_mKFe/=oa<C4`Gooooo3_mlO7`>o`820Pko7QhN3OmWIfL6ooooo`go;bl_3_m8B4P>
ong]kA?ooooo3_o3`l<=ooooo`koVIVI3Ol30`<6ooooo`koEUIF3_m=CDd=oaDE5A?ooooo3_lI6AT>
od10@0ko20P83?lH61P6ooooo`ko00003_nJVYX>obLW9`go8b<S1Oooool>okZj^PkoUIFE3_l=3@d=
o`L71`gooooo000;ooooo`ko7alO3_lE5AD>oe]KF`go4a<C1Oooool>ogalO0ko0P823_lN7Qh=ofMW
I`Kooooo3Ol_;bl>odQ8B0kokNg]4oooool>ol?3``gooooo3_nIVIT=o`<30`Kooooo3_mFEUH>ode=
C@go5ADE4oooool>oaTI6@ko@4103_l820P<oaPH60Kooooo3_l0000>oiZJVPko9bLW3OlS8b<5oooo
o`ko^[Zj3_nEUID>o`d=3@go1`L73Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`ko
e]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko
]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKo
oooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo
3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH6
3_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph
1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k
3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=
SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA
4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0
000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>
oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=
oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>
ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>
ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`00
00go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46oooo
o`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d
=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0ko
oooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKo
oooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko
@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go
0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph
1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO
3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=
3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll
?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[
:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0
000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Ooo
ool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=
ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=
oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5
ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5oooo
o`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;
b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIF
EPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_o
oooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko
1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go
>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko
^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF
3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg
3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_ooool>ofIVIPko@T923_l0000<oeIFEPKooooo
3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/k>`>ojRXZ0go0@413Oooool000_ooooo3_lJ
6QX>oc`l?0kooooo3Oll?3`5ooooo`koe]KF3_n=SHd>o`0000go>3Ph1_ooool=ogQhN0ko1PH63_o_
knl=oiZJVPKooooo3_l[:b/=ol_;b`ko]kNg3OlA4A46ooooo`ko7alO3_m0@40=oa/K6`go>3Ph1_oo
ool>ofIVIPko@T923_l0000<oeIFEPKooooo3_l0000>oc@d=0koCDe=3OlG5aL5ooooo`ko^k^k3_o/
k>`>ojRXZ0go0@413Oooool000_ooooo3_l820P>obDU9@ko92@T3Ol0000Cooooo`komoOg3_lf=SH=
oa4A4@Kooooo3Oo=cLd>o`0000ko]kNg3OmCDe<6ooooo`ko00003OmmOGd>oj^[Z`go:BTY1_ooool>
o`h>3Pko2@T93Ol0000=o`T92@Kooooo3_l?3`l>oaPH60ko20P83?m<C4`6ooooo`ko30`<3_l?3`l>
obl_;`go<C4a1Oooool>ode=C@kooooo3_oalO4=o`0000gooooo000;ooooo`ko20P83_lU9BD>ob@T
90go00004oooool>ooOgm`ko=SHf3OlA4A46ooooo`gocLg=3_l0000>okNg]`goDe=C1_ooool>o`00
00goOGem3_n[Zj/=obTY:@Kooooo3_l>3Ph>o`T92@go00003Ol92@T6ooooo`ko3`l?3_lH61P>o`P8
20coC4a<1_ooool>o``<30ko3`l?3_l_;bl=oc4a<@Gooooo3_m=CDd>ooooo`kolO7a3Ol0000=oooo
o`002oooool>o`P820ko9BDU3_lT92@=o`0001?ooooo3_ogmoL>ocHf=Pgo4A4A1_ooool=olg=c@ko
00003_ng]kL=oe=CD`Kooooo3_l0000=ogemO@koZj^[3OlY:BT6ooooo`ko3Ph>3_l92@T=o`0000go
2@T91_ooool>o`l?3`ko61PH3_l820P<oda<C0Kooooo3_l<30`>o`l?3`ko;bl_3Ola<C45ooooo`ko
CDe=3_ooool>oo7al@go00003Oooool000_ooooo3_l820P>obDU9@ko92@T3Ol0000Cooooo`komoOg
3_lf=SH=oa4A4@Kooooo3Oo=cLd>o`0000ko]kNg3OmCDe<6ooooo`ko00003OmmOGd>oj^[Z`go:BTY
1_ooool>o`h>3Pko2@T93Ol0000=o`T92@Kooooo3_l?3`l>oaPH60ko20P83?m<C4`6ooooo`ko30`<
3_l?3`l>obl_;`go<C4a1Oooool>ode=C@kooooo3_oalO4=o`0000gooooo000;ooooo`ko20P83_lU
9BD>ob@T90go00004oooool>ooOgm`ko=SHf3OlA4A46ooooo`gocLg=3_l0000>okNg]`goDe=C1_oo
ool>o`0000goOGem3_n[Zj/=obTY:@Kooooo3_l>3Ph>o`T92@go00003Ol92@T6ooooo`ko3`l?3_lH
61P>o`P820coC4a<1_ooool>o``<30ko3`l?3_l_;bl=oc4a<@Gooooo3_m=CDd>ooooo`kolO7a3Ol0
000=ooooo`002oooool>o`P820ko9BDU3_lT92@=o`0001?ooooo3_ogmoL>ocHf=Pgo4A4A1_ooool=
olg=c@ko00003_ng]kL=oe=CD`Kooooo3_l0000=ogemO@koZj^[3OlY:BT6ooooo`ko3Ph>3_l92@T=
o`0000go2@T91_ooool>o`l?3`ko61PH3_l820P<oda<C0Kooooo3_l<30`>o`l?3`ko;bl_3Ola<C45
ooooo`koCDe=3_ooool>oo7al@go00003Oooool000_ooooo3_l820P>obDU9@ko92@T3Ol0000Coooo
o`komoOg3_lf=SH=oa4A4@Kooooo3Oo=cLd>o`0000ko]kNg3OmCDe<6ooooo`ko00003OmmOGd>oj^[
Z`go:BTY1_ooool>o`h>3Pko2@T93Ol0000=o`T92@Kooooo3_l?3`l>oaPH60ko20P83?m<C4`6oooo
o`ko30`<3_l?3`l>obl_;`go<C4a1Oooool>ode=C@kooooo3_oalO4=o`0000gooooo000;ooooo`ko
20P83_lU9BD>ob@T90go00004oooool>ooOgm`ko=SHf3OlA4A46ooooo`gocLg=3_l0000>okNg]`go
De=C1_ooool>o`0000goOGem3_n[Zj/=obTY:@Kooooo3_l>3Ph>o`T92@go00003Ol92@T6ooooo`ko
3`l?3_lH61P>o`P820coC4a<1_ooool>o``<30ko3`l?3_l_;bl=oc4a<@Gooooo3_m=CDd>ooooo`ko
lO7a3Ol0000=ooooo`002oooool>o`P820ko9BDU3_lT92@=o`0001?ooooo3_ogmoL>ocHf=Pgo4A4A
1_ooool=olg=c@ko00003_ng]kL=oe=CD`Kooooo3_l0000=ogemO@koZj^[3OlY:BT6ooooo`ko3Ph>
3_l92@T=o`0000go2@T91_ooool>o`l?3`ko61PH3_l820P<oda<C0Kooooo3_l<30`>o`l?3`ko;bl_
3Ola<C45ooooo`koCDe=3_ooool>oo7al@go00003Oooool000_ooooo3_l820P>obDU9@ko92@T3Ol0
000Cooooo`komoOg3_lf=SH=oa4A4@Kooooo3Oo=cLd>o`0000ko]kNg3OmCDe<6ooooo`ko00003Omm
OGd>oj^[Z`go:BTY1_ooool>o`h>3Pko2@T93Ol0000=o`T92@Kooooo3_l?3`l>oaPH60ko20P83?m<
C4`6ooooo`ko30`<3_l?3`l>obl_;`go<C4a1Oooool>ode=C@kooooo3_oalO4=o`0000gooooo000;
ooooo`ko20P83_lU9BD>ob@T90go00004oooool>ooOgm`ko=SHf3OlA4A46ooooo`gocLg=3_l0000>
okNg]`goDe=C1_ooool>o`0000goOGem3_n[Zj/=obTY:@Kooooo3_l>3Ph>o`T92@go00003Ol92@T6
ooooo`ko3`l?3_lH61P>o`P820coC4a<1_ooool>o``<30ko3`l?3_l_;bl=oc4a<@Gooooo3_m=CDd>
ooooo`kolO7a3Ol0000=ooooo`002oooool>o`P820ko9BDU3_lT92@=o`0001?ooooo3_ogmoL>ocHf
=Pgo4A4A1_ooool=olg=c@ko00003_ng]kL=oe=CD`Kooooo3_l0000=ogemO@koZj^[3OlY:BT6oooo
o`ko3Ph>3_l92@T=o`0000go2@T91_ooool>o`l?3`ko61PH3_l820P<oda<C0Kooooo3_l<30`>o`l?
3`ko;bl_3Ola<C45ooooo`koCDe=3_ooool>oo7al@go00003Oooool000_ooooo3_l820P>obDU9@ko
92@T3Ol0000Cooooo`komoOg3_lf=SH=oa4A4@Kooooo3Oo=cLd>o`0000ko]kNg3OmCDe<6ooooo`ko
00003OmmOGd>oj^[Z`go:BTY1_ooool>o`h>3Pko2@T93Ol0000=o`T92@Kooooo3_l?3`l>oaPH60ko
20P83?m<C4`6ooooo`ko30`<3_l?3`l>obl_;`go<C4a1Oooool>ode=C@kooooo3_oalO4=o`0000go
oooo000;ooooo`ko20P83_lU9BD>ob@T90go00004oooool>ooOgm`ko=SHf3OlA4A46ooooo`gocLg=
3_l0000>okNg]`goDe=C1_ooool>o`0000goOGem3_n[Zj/=obTY:@Kooooo3_l>3Ph>o`T92@go0000
3Ol92@T6ooooo`ko3`l?3_lH61P>o`P820coC4a<1_ooool>o``<30ko3`l?3_l_;bl=oc4a<@Gooooo
3_m=CDd>ooooo`kolO7a3Ol0000=ooooo`002oooool>obl_;`ko5aLG3_lR8R8=oahN7PGooooo3_m4
A4@>o`<30`ko?3`l3OmKFe/6ooooo`go2PX:3_nGUiL>ojj^[Pgog]kN1_ooool>ok^k^`go^;Rh3_lB
4Q8=oa0@40Kooooo3_l[:b/>obXZ:Pgo8B4Q3Ol_;bl6ooooo`koBTY:3_lQ8B4>oaTI6A;ooooo3_m:
BTX>ooooo`ko@T923OlU9BD5ooooo`koWYjN3_m=CDd>o`H61Pgo@T923Oooool000_ooooo3_l_;bl>
oaLG5`ko8R8R3OlN7Qh5ooooo`koA4A43_l30`<>oc`l?0goFe]K1_ooool=o`X:2PkoUiNG3_n^[Zh=
omkNgPKooooo3_nk^k/=okRh^0ko4Q8B3Ol@4106ooooo`ko:b/[3_lZ:RX=ob4Q8@go;bl_1_ooool>
odY:BPko8B4Q3_lI6ATBooooo`koBTY:3_ooool>od92@Pgo9BDU1Oooool>oijNWPkoCDe=3_l61PH=
od92@Pgooooo000;ooooo`ko;bl_3_lG5aL>ob8R8Pgo7QhN1Oooool>odA4A0ko0`<33_ll?3`=oe]K
F`Kooooo3Ol:2PX>oiNGU`ko[Zj^3OoNg]h6ooooo`ko^k^k3Onh^;P>oa8B4Pgo410@1_ooool>ob/[
:`ko:RXZ3OlQ8B4=obl_;`Kooooo3_m:BTX>ob4Q8@ko6ATI4_ooool>odY:BPkooooo3_m2@T8=obDU
9@Gooooo3_nNWYh>ode=C@ko1PH63Om2@T8=ooooo`002oooool>obl_;`ko5aLG3_lR8R8=oahN7PGo
oooo3_m4A4@>o`<30`ko?3`l3OmKFe/6ooooo`go2PX:3_nGUiL>ojj^[Pgog]kN1_ooool>ok^k^`go
^;Rh3_lB4Q8=oa0@40Kooooo3_l[:b/>obXZ:Pgo8B4Q3Ol_;bl6ooooo`koBTY:3_lQ8B4>oaTI6A;o
oooo3_m:BTX>ooooo`ko@T923OlU9BD5ooooo`koWYjN3_m=CDd>o`H61Pgo@T923Oooool000_ooooo
3_l_;bl>oaLG5`ko8R8R3OlN7Qh5ooooo`koA4A43_l30`<>oc`l?0goFe]K1_ooool=o`X:2PkoUiNG
3_n^[Zh=omkNgPKooooo3_nk^k/=okRh^0ko4Q8B3Ol@4106ooooo`ko:b/[3_lZ:RX=ob4Q8@go;bl_
1_ooool>odY:BPko8B4Q3_lI6ATBooooo`koBTY:3_ooool>od92@Pgo9BDU1Oooool>oijNWPkoCDe=
3_l61PH=od92@Pgooooo000;ooooo`ko;bl_3_lG5aL>ob8R8Pgo7QhN1Oooool>odA4A0ko0`<33_ll
?3`=oe]KF`Kooooo3Ol:2PX>oiNGU`ko[Zj^3OoNg]h6ooooo`ko^k^k3Onh^;P>oa8B4Pgo410@1_oo
ool>ob/[:`ko:RXZ3OlQ8B4=obl_;`Kooooo3_m:BTX>ob4Q8@ko6ATI4_ooool>odY:BPkooooo3_m2
@T8=obDU9@Gooooo3_nNWYh>ode=C@ko1PH63Om2@T8=ooooo`002oooool>obl_;`ko5aLG3_lR8R8=
oahN7PGooooo3_m4A4@>o`<30`ko?3`l3OmKFe/6ooooo`go2PX:3_nGUiL>ojj^[Pgog]kN1_ooool>
ok^k^`go^;Rh3_lB4Q8=oa0@40Kooooo3_l[:b/>obXZ:Pgo8B4Q3Ol_;bl6ooooo`koBTY:3_lQ8B4>
oaTI6A;ooooo3_m:BTX>ooooo`ko@T923OlU9BD5ooooo`koWYjN3_m=CDd>o`H61Pgo@T923Oooool0
00_ooooo3_l_;bl>oaLG5`ko8R8R3OlN7Qh5ooooo`koA4A43_l30`<>oc`l?0goFe]K1_ooool=o`X:
2PkoUiNG3_n^[Zh=omkNgPKooooo3_nk^k/=okRh^0ko4Q8B3Ol@4106ooooo`ko:b/[3_lZ:RX=ob4Q
8@go;bl_1_ooool>odY:BPko8B4Q3_lI6ATBooooo`koBTY:3_ooool>od92@Pgo9BDU1Oooool>oijN
WPkoCDe=3_l61PH=od92@Pgooooo000;ooooo`ko;bl_3_lG5aL>ob8R8Pgo7QhN1Oooool>odA4A0ko
0`<33_ll?3`=oe]KF`Kooooo3Ol:2PX>oiNGU`ko[Zj^3OoNg]h6ooooo`ko^k^k3Onh^;P>oa8B4Pgo
410@1_ooool>ob/[:`ko:RXZ3OlQ8B4=obl_;`Kooooo3_m:BTX>ob4Q8@ko6ATI4_ooool>odY:BPko
oooo3_m2@T8=obDU9@Gooooo3_nNWYh>ode=C@ko1PH63Om2@T8=ooooo`002oooool>obl_;`ko5aLG
3_lR8R8=oahN7PGooooo3_m4A4@>o`<30`ko?3`l3OmKFe/6ooooo`go2PX:3_nGUiL>ojj^[Pgog]kN
1_ooool>ok^k^`go^;Rh3_lB4Q8=oa0@40Kooooo3_l[:b/>obXZ:Pgo8B4Q3Ol_;bl6ooooo`koBTY:
3_lQ8B4>oaTI6A;ooooo3_m:BTX>ooooo`ko@T923OlU9BD5ooooo`koWYjN3_m=CDd>o`H61Pgo@T92
3Oooool000_ooooo3_l_;bl>oaLG5`ko8R8R3OlN7Qh5ooooo`koA4A43_l30`<>oc`l?0goFe]K1_oo
ool=o`X:2PkoUiNG3_n^[Zh=omkNgPKooooo3_nk^k/=okRh^0ko4Q8B3Ol@4106ooooo`ko:b/[3_lZ
:RX=ob4Q8@go;bl_1_ooool>odY:BPko8B4Q3_lI6ATBooooo`koBTY:3_ooool>od92@Pgo9BDU1Ooo
ool>oijNWPkoCDe=3_l61PH=od92@Pgooooo000;ooooo`ko;bl_3_lG5aL>ob8R8Pgo7QhN1Oooool>
odA4A0ko0`<33_ll?3`=oe]KF`Kooooo3Ol:2PX>oiNGU`ko[Zj^3OoNg]h6ooooo`ko^k^k3Onh^;P>
oa8B4Pgo410@1_ooool>ob/[:`ko:RXZ3OlQ8B4=obl_;`Kooooo3_m:BTX>ob4Q8@ko6ATI4_ooool>
odY:BPkooooo3_m2@T8=obDU9@Gooooo3_nNWYh>ode=C@ko1PH63Om2@T8=ooooo`002oooool>obl_
;`ko5aLG3_lR8R8=oahN7PGooooo3_m4A4@>o`<30`ko?3`l3OmKFe/6ooooo`go2PX:3_nGUiL>ojj^
[Pgog]kN1_ooool>ok^k^`go^;Rh3_lB4Q8=oa0@40Kooooo3_l[:b/>obXZ:Pgo8B4Q3Ol_;bl6oooo
o`koBTY:3_lQ8B4>oaTI6A;ooooo3_m:BTX>ooooo`ko@T923OlU9BD5ooooo`koWYjN3_m=CDd>o`H6
1Pgo@T923Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T9
3_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R
3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo
3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mS
Hf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC
4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_oo
ool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l8
20P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>
obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6
ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>
obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE
5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe
=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^
KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D
50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo
7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko
61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko
5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM
3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo
3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P82
3_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY
3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_oo
ool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mW
IfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:
RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005
ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=
okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<
od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool0
00_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ
:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<
C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5oooo
o`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko
2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko
8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Ko
oooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo
3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A
3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T
1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV
3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=
CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9
BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:
2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool000_ooooo3_mSHf<>
oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=
ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6ooooo`ko61PH3_mWIfL=oda<C0go92@T1_ooool>
ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>
oa@D50go:BTY3Oooool000_ooooo3_mSHf<>oaDE5@ko7AdM3Ol00005ooooo`ko2@T93_m=CDd>obXZ
:Pgo7alO1_ooool=obXZ:Pko4A4A3_lC4a<=ocDe=@Kooooo3_l^;Rh=okZj^Pko8R8R3Om9BDT6oooo
o`ko61PH3_mWIfL=oda<C0go92@T1_ooool>ofi^KPko0P823_ooool<od51@@Kooooo3_l:2PX>obLW
9`ko5aLG3On:RXX5ooooo`ko9RHV3_l820P>oa@D50go:BTY3Oooool001Wooooo3_m3@d<>o`L71`go
820P1Oooool>oa@D50ko1PH63_l20P8=oe]KF`Kooooo3Ol?3`l>o`<30`ko1@D53OlE5AD6ooooo`ko
00003OoemOD>oifMW@goXj>S1_ooool>o`0000ko51@D3Olm?Cd=ochn?PKooooo3_mWIfL>oa<C4`ko
;2`/3?lG5aL6ooooo`ko6QXJ3_le=CD>o`l?3`go61PH1Oooool>o`P820ko:2PX3_l51@D=oc8b<Pgo
oooo000Iooooo`ko@d=33_l71`L=ob0P80Gooooo3_lD51@>o`H61Pko0P823OmKFe/6ooooo`go3`l?
3_l30`<>o`D51@go5ADE1_ooool>o`0000gomOGe3_nMWId=oj>SX`Kooooo3_l0000>oa@D50go?Cdm
3Oln?Sh6ooooo`koIfMW3_lC4a<>ob`/;0co5aLG1_ooool>oaXJ6Pko=CDe3_l?3`l=oaPH60Gooooo
3_l820P>obPX:0ko1@D53Olb<S8=ooooo`006Oooool>od=3@`ko1`L73OlP8205ooooo`ko51@D3_l6
1PH>o`820PgoFe]K1_ooool=o`l?3`ko0`<33_l51@D=oaDE5@Kooooo3_l0000=ooGem@koWIfM3OnS
Xj<6ooooo`ko00003_lD51@=ocdm?@go?Shn1_ooool>ofMWI`ko4a<C3_l/;2`<oaLG5`Kooooo3_lJ
6QX>ocDe=@ko3`l?3OlH61P5ooooo`ko20P83_lX:2P>o`D51@go<S8b3Oooool001Wooooo3_m3@d<>
o`L71`go820P1Oooool>oa@D50ko1PH63_l20P8=oe]KF`Kooooo3Ol?3`l>o`<30`ko1@D53OlE5AD6
ooooo`ko00003OoemOD>oifMW@goXj>S1_ooool>o`0000ko51@D3Olm?Cd=ochn?PKooooo3_mWIfL>
oa<C4`ko;2`/3?lG5aL6ooooo`ko6QXJ3_le=CD>o`l?3`go61PH1Oooool>o`P820ko:2PX3_l51@D=
oc8b<Pgooooo000Iooooo`ko@d=33_l71`L=ob0P80Gooooo3_lD51@>o`H61Pko0P823OmKFe/6oooo
o`go3`l?3_l30`<>o`D51@go5ADE1_ooool>o`0000gomOGe3_nMWId=oj>SX`Kooooo3_l0000>oa@D
50go?Cdm3Oln?Sh6ooooo`koIfMW3_lC4a<>ob`/;0co5aLG1_ooool>oaXJ6Pko=CDe3_l?3`l=oaPH
60Gooooo3_l820P>obPX:0ko1@D53Olb<S8=ooooo`006Oooool>od=3@`ko1`L73OlP8205ooooo`ko
51@D3_l61PH>o`820PgoFe]K1_ooool=o`l?3`ko0`<33_l51@D=oaDE5@Kooooo3_l0000=ooGem@ko
WIfM3OnSXj<6ooooo`ko00003_lD51@=ocdm?@go?Shn1_ooool>ofMWI`ko4a<C3_l/;2`<oaLG5`Ko
oooo3_lJ6QX>ocDe=@ko3`l?3OlH61P5ooooo`ko20P83_lX:2P>o`D51@go<S8b3Oooool001Wooooo
3_m3@d<>o`L71`go820P1Oooool>oa@D50ko1PH63_l20P8=oe]KF`Kooooo3Ol?3`l>o`<30`ko1@D5
3OlE5AD6ooooo`ko00003OoemOD>oifMW@goXj>S1_ooool>o`0000ko51@D3Olm?Cd=ochn?PKooooo
3_mWIfL>oa<C4`ko;2`/3?lG5aL6ooooo`ko6QXJ3_le=CD>o`l?3`go61PH1Oooool>o`P820ko:2PX
3_l51@D=oc8b<Pgooooo000Iooooo`ko@d=33_l71`L=ob0P80Gooooo3_lD51@>o`H61Pko0P823OmK
Fe/6ooooo`go3`l?3_l30`<>o`D51@go5ADE1_ooool>o`0000gomOGe3_nMWId=oj>SX`Kooooo3_l0
000>oa@D50go?Cdm3Oln?Sh6ooooo`koIfMW3_lC4a<>ob`/;0co5aLG1_ooool>oaXJ6Pko=CDe3_l?
3`l=oaPH60Gooooo3_l820P>obPX:0ko1@D53Olb<S8=ooooo`006Oooool>od=3@`ko1`L73OlP8205
ooooo`ko51@D3_l61PH>o`820PgoFe]K1_ooool=o`l?3`ko0`<33_l51@D=oaDE5@Kooooo3_l0000=
ooGem@koWIfM3OnSXj<6ooooo`ko00003_lD51@=ocdm?@go?Shn1_ooool>ofMWI`ko4a<C3_l/;2`<
oaLG5`Kooooo3_lJ6QX>ocDe=@ko3`l?3OlH61P5ooooo`ko20P83_lX:2P>o`D51@go<S8b3Oooool0
01Wooooo3_m3@d<>o`L71`go820P1Oooool>oa@D50ko1PH63_l20P8=oe]KF`Kooooo3Ol?3`l>o`<3
0`ko1@D53OlE5AD6ooooo`ko00003OoemOD>oifMW@goXj>S1_ooool>o`0000ko51@D3Olm?Cd=ochn
?PKooooo3_mWIfL>oa<C4`ko;2`/3?lG5aL6ooooo`ko6QXJ3_le=CD>o`l?3`go61PH1Oooool>o`P8
20ko:2PX3_l51@D=oc8b<Pgooooo000Iooooo`ko@d=33_l71`L=ob0P80Gooooo3_lD51@>o`H61Pko
0P823OmKFe/6ooooo`go3`l?3_l30`<>o`D51@go5ADE1_ooool>o`0000gomOGe3_nMWId=oj>SX`Ko
oooo3_l0000>oa@D50go?Cdm3Oln?Sh6ooooo`koIfMW3_lC4a<>ob`/;0co5aLG1_ooool>oaXJ6Pko
=CDe3_l?3`l=oaPH60Gooooo3_l820P>obPX:0ko1@D53Olb<S8=ooooo`006Oooool>od=3@`ko1`L7
3OlP8205ooooo`ko51@D3_l61PH>o`820PgoFe]K1_ooool=o`l?3`ko0`<33_l51@D=oaDE5@Kooooo
3_l0000=ooGem@koWIfM3OnSXj<6ooooo`ko00003_lD51@=ocdm?@go?Shn1_ooool>ofMWI`ko4a<C
3_l/;2`<oaLG5`Kooooo3_lJ6QX>ocDe=@ko3`l?3OlH61P5ooooo`ko20P83_lX:2P>o`D51@go<S8b
3Oooool001Wooooo3_m3@d<>o`L71`go820P1Oooool>oa@D50ko1PH63_l20P8=oe]KF`Kooooo3Ol?
3`l>o`<30`ko1@D53OlE5AD6ooooo`ko00003OoemOD>oifMW@goXj>S1_ooool>o`0000ko51@D3Olm
?Cd=ochn?PKooooo3_mWIfL>oa<C4`ko;2`/3?lG5aL6ooooo`ko6QXJ3_le=CD>o`l?3`go61PH1Ooo
ool>o`P820ko:2PX3_l51@D=oc8b<Pgooooo000;ooooo`ko;2`/3_lD51@>o`0000go4Q8B4oooool>
ofi^KPko00003OmJFUX6ooooo`go<c<c3_l92@T>o`@411?ooooo3_l10@4=okNg]`kooooo3OnTY:@6
ooooo`koGemO3_lE5AD=ob8R8PgoUiNG1_ooool>odI6APko6a/K3_l?3`l<o`d=3@Kooooo3_l0000>
obd];@ko10@43Ol/;2`5ooooo`ko10@43_l0000>o`l?3`go20P83Oooool000_ooooo3_l/;2`>oa@D
50ko00003OlB4Q8Cooooo`koKVi^3_l0000=oeYJFPKooooo3Olc<c<>o`T92@ko10@44oooool>o`41
0@go]kNg3_ooool=ojBTY0Kooooo3_mOGel>oaDE5@go8R8R3OnGUiL6ooooo`koATI63_lK6a/>o`l?
3`co3@d=1_ooool>o`0000ko;Bd]3_l410@=ob`/;0Gooooo3_l410@>o`0000ko3`l?3Ol820P=oooo
o`002oooool>ob`/;0ko51@D3_l0000=oa8B4Q?ooooo3_m^KVh>o`0000goFUYJ1_ooool=oc<c<`ko
2@T93_l410@Cooooo`ko0@413Ong]kL>ooooo`goY:BT1_ooool>oemOG`ko5ADE3OlR8R8=oiNGU`Ko
oooo3_m6ATH>oa/K6`ko3`l?3?l=3@d6ooooo`ko00003_l];Bd>o`@410go;2`/1Oooool>o`@410ko
00003_l?3`l=o`P820gooooo000;ooooo`ko;2`/3_lD51@>o`0000go4Q8B4oooool>ofi^KPko0000
3OmJFUX6ooooo`go<c<c3_l92@T>o`@411?ooooo3_l10@4=okNg]`kooooo3OnTY:@6ooooo`koGemO
3_lE5AD=ob8R8PgoUiNG1_ooool>odI6APko6a/K3_l?3`l<o`d=3@Kooooo3_l0000>obd];@ko10@4
3Ol/;2`5ooooo`ko10@43_l0000>o`l?3`go20P83Oooool000_ooooo3_l/;2`>oa@D50ko00003OlB
4Q8Cooooo`koKVi^3_l0000=oeYJFPKooooo3Olc<c<>o`T92@ko10@44oooool>o`410@go]kNg3_oo
ool=ojBTY0Kooooo3_mOGel>oaDE5@go8R8R3OnGUiL6ooooo`koATI63_lK6a/>o`l?3`co3@d=1_oo
ool>o`0000ko;Bd]3_l410@=ob`/;0Gooooo3_l410@>o`0000ko3`l?3Ol820P=ooooo`002oooool>
ob`/;0ko51@D3_l0000=oa8B4Q?ooooo3_m^KVh>o`0000goFUYJ1_ooool=oc<c<`ko2@T93_l410@C
ooooo`ko0@413Ong]kL>ooooo`goY:BT1_ooool>oemOG`ko5ADE3OlR8R8=oiNGU`Kooooo3_m6ATH>
oa/K6`ko3`l?3?l=3@d6ooooo`ko00003_l];Bd>o`@410go;2`/1Oooool>o`@410ko00003_l?3`l=
o`P820gooooo000;ooooo`ko;2`/3_lD51@>o`0000go4Q8B4oooool>ofi^KPko00003OmJFUX6oooo
o`go<c<c3_l92@T>o`@411?ooooo3_l10@4=okNg]`kooooo3OnTY:@6ooooo`koGemO3_lE5AD=ob8R
8PgoUiNG1_ooool>odI6APko6a/K3_l?3`l<o`d=3@Kooooo3_l0000>obd];@ko10@43Ol/;2`5oooo
o`ko10@43_l0000>o`l?3`go20P83Oooool000_ooooo3_l/;2`>oa@D50ko00003OlB4Q8Cooooo`ko
KVi^3_l0000=oeYJFPKooooo3Olc<c<>o`T92@ko10@44oooool>o`410@go]kNg3_ooool=ojBTY0Ko
oooo3_mOGel>oaDE5@go8R8R3OnGUiL6ooooo`koATI63_lK6a/>o`l?3`co3@d=1_ooool>o`0000ko
;Bd]3_l410@=ob`/;0Gooooo3_l410@>o`0000ko3`l?3Ol820P=ooooo`002oooool>ob`/;0ko51@D
3_l0000=oa8B4Q?ooooo3_m^KVh>o`0000goFUYJ1_ooool=oc<c<`ko2@T93_l410@Cooooo`ko0@41
3Ong]kL>ooooo`goY:BT1_ooool>oemOG`ko5ADE3OlR8R8=oiNGU`Kooooo3_m6ATH>oa/K6`ko3`l?
3?l=3@d6ooooo`ko00003_l];Bd>o`@410go;2`/1Oooool>o`@410ko00003_l?3`l=o`P820gooooo
000;ooooo`ko;2`/3_lD51@>o`0000go4Q8B4oooool>ofi^KPko00003OmJFUX6ooooo`go<c<c3_l9
2@T>o`@411?ooooo3_l10@4=okNg]`kooooo3OnTY:@6ooooo`koGemO3_lE5AD=ob8R8PgoUiNG1_oo
ool>odI6APko6a/K3_l?3`l<o`d=3@Kooooo3_l0000>obd];@ko10@43Ol/;2`5ooooo`ko10@43_l0
000>o`l?3`go20P83Oooool000_ooooo3_l/;2`>oa@D50ko00003OlB4Q8Cooooo`koKVi^3_l0000=
oeYJFPKooooo3Olc<c<>o`T92@ko10@44oooool>o`410@go]kNg3_ooool=ojBTY0Kooooo3_mOGel>
oaDE5@go8R8R3OnGUiL6ooooo`koATI63_lK6a/>o`l?3`co3@d=1_ooool>o`0000ko;Bd]3_l410@=
ob`/;0Gooooo3_l410@>o`0000ko3`l?3Ol820P=ooooo`002oooool>ob`/;0ko51@D3_l0000=oa8B
4Q?ooooo3_m^KVh>o`0000goFUYJ1_ooool=oc<c<`ko2@T93_l410@Cooooo`ko0@413Ong]kL>oooo
o`goY:BT1_ooool>oemOG`ko5ADE3OlR8R8=oiNGU`Kooooo3_m6ATH>oa/K6`ko3`l?3?l=3@d6oooo
o`ko00003_l];Bd>o`@410go;2`/1Oooool>o`@410ko00003_l?3`l=o`P820gooooo000;ooooo`ko
;2`/3_lD51@>o`0000go4Q8B4oooool>ofi^KPko00003OmJFUX6ooooo`go<c<c3_l92@T>o`@411?o
oooo3_l10@4=okNg]`kooooo3OnTY:@6ooooo`koGemO3_lE5AD=ob8R8PgoUiNG1_ooool>odI6APko
6a/K3_l?3`l<o`d=3@Kooooo3_l0000>obd];@ko10@43Ol/;2`5ooooo`ko10@43_l0000>o`l?3`go
20P83Oooool000_ooooo3_l/;2`>oa@D50ko00003OlB4Q8Cooooo`koKVi^3_l0000=oeYJFPKooooo
3Olc<c<>o`T92@ko10@44oooool>o`410@go]kNg3_ooool=ojBTY0Kooooo3_mOGel>oaDE5@go8R8R
3OnGUiL6ooooo`koATI63_lK6a/>o`l?3`co3@d=1_ooool>o`0000ko;Bd]3_l410@=ob`/;0Gooooo
3_l410@>o`0000ko3`l?3Ol820P=ooooo`002oooool>oa/K6`ko=SHf3_lA4A4=oa8B4PGooooo3_l<
30`>ogemO@ko00003Olo?cl6ooooo`go<c<c3_l0000>oaTI6@go=3@d1_ooool>od];B`goQhN73_l:
2PX=oa8B4PKooooo3_m3@d<>ooooo`go6QXJ3OlA4A46ooooo`koBd];3_l0000>oh20P0coRXZ:1_oo
ool>o``<30koEUIF3_ooool=oadM7A?ooooo3_m:BTX>o`820Pgo?3`l3Oooool000_ooooo3_lK6a/>
ocHf=Pko4A4A3OlB4Q85ooooo`ko30`<3_mmOGd>o`0000go?clo1_ooool=oc<c<`ko00003_lI6AT=
oc@d=0Kooooo3_m;Bd/=ohN7Q`ko2PX:3OlB4Q86ooooo`ko@d=33_ooool=oaXJ6Pgo4A4A1_ooool>
od];B`ko00003_n0P80<ohZ:RPKooooo3_l<30`>oeIFEPkooooo3OlM7AdCooooo`koBTY:3_l20P8=
oc`l?0gooooo000;ooooo`ko6a/K3_lf=SH>oa4A4@go4Q8B1Oooool>o``<30koOGem3_l0000=oclo
?`Kooooo3Olc<c<>o`0000ko6ATI3Old=3@6ooooo`koBd];3On7QhL>o`X:2Pgo4Q8B1_ooool>od=3
@`kooooo3OlJ6QX=oa4A4@Kooooo3_m;Bd/>o`0000koP8203?n:RXX6ooooo`ko30`<3_mFEUH>oooo
o`go7AdM4oooool>odY:BPko0P823Oll?3`=ooooo`002oooool>oa/K6`ko=SHf3_lA4A4=oa8B4PGo
oooo3_l<30`>ogemO@ko00003Olo?cl6ooooo`go<c<c3_l0000>oaTI6@go=3@d1_ooool>od];B`go
QhN73_l:2PX=oa8B4PKooooo3_m3@d<>ooooo`go6QXJ3OlA4A46ooooo`koBd];3_l0000>oh20P0co
RXZ:1_ooool>o``<30koEUIF3_ooool=oadM7A?ooooo3_m:BTX>o`820Pgo?3`l3Oooool000_ooooo
3_lK6a/>ocHf=Pko4A4A3OlB4Q85ooooo`ko30`<3_mmOGd>o`0000go?clo1_ooool=oc<c<`ko0000
3_lI6AT=oc@d=0Kooooo3_m;Bd/=ohN7Q`ko2PX:3OlB4Q86ooooo`ko@d=33_ooool=oaXJ6Pgo4A4A
1_ooool>od];B`ko00003_n0P80<ohZ:RPKooooo3_l<30`>oeIFEPkooooo3OlM7AdCooooo`koBTY:
3_l20P8=oc`l?0gooooo000;ooooo`ko6a/K3_lf=SH>oa4A4@go4Q8B1Oooool>o``<30koOGem3_l0
000=oclo?`Kooooo3Olc<c<>o`0000ko6ATI3Old=3@6ooooo`koBd];3On7QhL>o`X:2Pgo4Q8B1_oo
ool>od=3@`kooooo3OlJ6QX=oa4A4@Kooooo3_m;Bd/>o`0000koP8203?n:RXX6ooooo`ko30`<3_mF
EUH>ooooo`go7AdM4oooool>odY:BPko0P823Oll?3`=ooooo`002oooool>oa/K6`ko=SHf3_lA4A4=
oa8B4PGooooo3_l<30`>ogemO@ko00003Olo?cl6ooooo`go<c<c3_l0000>oaTI6@go=3@d1_ooool>
od];B`goQhN73_l:2PX=oa8B4PKooooo3_m3@d<>ooooo`go6QXJ3OlA4A46ooooo`koBd];3_l0000>
oh20P0coRXZ:1_ooool>o``<30koEUIF3_ooool=oadM7A?ooooo3_m:BTX>o`820Pgo?3`l3Oooool0
00_ooooo3_lK6a/>ocHf=Pko4A4A3OlB4Q85ooooo`ko30`<3_mmOGd>o`0000go?clo1_ooool=oc<c
<`ko00003_lI6AT=oc@d=0Kooooo3_m;Bd/=ohN7Q`ko2PX:3OlB4Q86ooooo`ko@d=33_ooool=oaXJ
6Pgo4A4A1_ooool>od];B`ko00003_n0P80<ohZ:RPKooooo3_l<30`>oeIFEPkooooo3OlM7AdCoooo
o`koBTY:3_l20P8=oc`l?0gooooo000;ooooo`ko6a/K3_lf=SH>oa4A4@go4Q8B1Oooool>o``<30ko
OGem3_l0000=oclo?`Kooooo3Olc<c<>o`0000ko6ATI3Old=3@6ooooo`koBd];3On7QhL>o`X:2Pgo
4Q8B1_ooool>od=3@`kooooo3OlJ6QX=oa4A4@Kooooo3_m;Bd/>o`0000koP8203?n:RXX6ooooo`ko
30`<3_mFEUH>ooooo`go7AdM4oooool>odY:BPko0P823Oll?3`=ooooo`002oooool>oa/K6`ko=SHf
3_lA4A4=oa8B4PGooooo3_l<30`>ogemO@ko00003Olo?cl6ooooo`go<c<c3_l0000>oaTI6@go=3@d
1_ooool>od];B`goQhN73_l:2PX=oa8B4PKooooo3_m3@d<>ooooo`go6QXJ3OlA4A46ooooo`koBd];
3_l0000>oh20P0coRXZ:1_ooool>o``<30koEUIF3_ooool=oadM7A?ooooo3_m:BTX>o`820Pgo?3`l
3Oooool000_ooooo3_lK6a/>ocHf=Pko4A4A3OlB4Q85ooooo`ko30`<3_mmOGd>o`0000go?clo1_oo
ool=oc<c<`ko00003_lI6AT=oc@d=0Kooooo3_m;Bd/=ohN7Q`ko2PX:3OlB4Q86ooooo`ko@d=33_oo
ool=oaXJ6Pgo4A4A1_ooool>od];B`ko00003_n0P80<ohZ:RPKooooo3_l<30`>oeIFEPkooooo3OlM
7AdCooooo`koBTY:3_l20P8=oc`l?0gooooo000;ooooo`ko6a/K3_lf=SH>oa4A4@go4Q8B1Oooool>
o``<30koOGem3_l0000=oclo?`Kooooo3Olc<c<>o`0000ko6ATI3Old=3@6ooooo`koBd];3On7QhL>
o`X:2Pgo4Q8B1_ooool>od=3@`kooooo3OlJ6QX=oa4A4@Kooooo3_m;Bd/>o`0000koP8203?n:RXX6
ooooo`ko30`<3_mFEUH>ooooo`go7AdM4oooool>odY:BPko0P823Oll?3`=ooooo`002oooool>oa/K
6`ko=SHf3_lA4A4=oa8B4PGooooo3_l<30`>ogemO@ko00003Olo?cl6ooooo`go<c<c3_l0000>oaTI
6@go=3@d1_ooool>od];B`goQhN73_l:2PX=oa8B4PKooooo3_m3@d<>ooooo`go6QXJ3OlA4A46oooo
o`koBd];3_l0000>oh20P0coRXZ:1_ooool>o``<30koEUIF3_ooool=oadM7A?ooooo3_m:BTX>o`82
0Pgo?3`l3Oooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool0
0?oooooomOooool00?oooooomOooool00?oooooomOooool000_ooooo3_l];Bd>oaHF5Pko0P823Ol:
2PX5ooooo`koLW9b3_l0000>ob@T90goN7Qh1_ooool=o`0000ko4A4A3_lB4Q8=ocLg=`Kooooo3_lB
4Q8=oa`L70ko0@413OlJ6QX6ooooo`ko4Q8B3_lU9BD=o`0001?ooooo3_lA4A4>oaXJ6Pko71`L3?mM
GEd6ooooo`ko5QHF3_ooool>ogalO0goBTY:4oooool>oinOW`ko51@D3Om`L70=ooooo`002oooool>
obd];@ko5QHF3_l20P8=o`X:2PGooooo3_mbLW8>o`0000ko92@T3OmhN7P6ooooo`go00003_lA4A4>
oa8B4Pgo=cLg1_ooool>oa8B4Pgo71`L3_l10@4=oaXJ6PKooooo3_lB4Q8>obDU9@go00004oooool>
oa4A4@ko6QXJ3_lL71`<oeeMG@Kooooo3_lF5QH>ooooo`koO7al3Om:BTXCooooo`koWinO3_lD51@=
og1`L0gooooo000;ooooo`ko;Bd]3_lF5QH>o`820Pgo2PX:1Oooool>og9bLPko00003_lT92@=ogQh
N0Kooooo3Ol0000>oa4A4@ko4Q8B3Olg=cL6ooooo`ko4Q8B3OlL71`>o`410@go6QXJ1_ooool>oa8B
4Pko9BDU3Ol0000Cooooo`ko4A4A3_lJ6QX>oa`L70coGEeM1_ooool>oaHF5Pkooooo3_mlO7`=odY:
BQ?ooooo3_nOWil>oa@D50goL71`3Oooool000_ooooo3_l];Bd>oaHF5Pko0P823Ol:2PX5ooooo`ko
LW9b3_l0000>ob@T90goN7Qh1_ooool=o`0000ko4A4A3_lB4Q8=ocLg=`Kooooo3_lB4Q8=oa`L70ko
0@413OlJ6QX6ooooo`ko4Q8B3_lU9BD=o`0001?ooooo3_lA4A4>oaXJ6Pko71`L3?mMGEd6ooooo`ko
5QHF3_ooool>ogalO0goBTY:4oooool>oinOW`ko51@D3Om`L70=ooooo`002oooool>obd];@ko5QHF
3_l20P8=o`X:2PGooooo3_mbLW8>o`0000ko92@T3OmhN7P6ooooo`go00003_lA4A4>oa8B4Pgo=cLg
1_ooool>oa8B4Pgo71`L3_l10@4=oaXJ6PKooooo3_lB4Q8>obDU9@go00004oooool>oa4A4@ko6QXJ
3_lL71`<oeeMG@Kooooo3_lF5QH>ooooo`koO7al3Om:BTXCooooo`koWinO3_lD51@=og1`L0gooooo
000;ooooo`ko;Bd]3_lF5QH>o`820Pgo2PX:1Oooool>og9bLPko00003_lT92@=ogQhN0Kooooo3Ol0
000>oa4A4@ko4Q8B3Olg=cL6ooooo`ko4Q8B3OlL71`>o`410@go6QXJ1_ooool>oa8B4Pko9BDU3Ol0
000Cooooo`ko4A4A3_lJ6QX>oa`L70coGEeM1_ooool>oaHF5Pkooooo3_mlO7`=odY:BQ?ooooo3_nO
Wil>oa@D50goL71`3Oooool000_ooooo3_l];Bd>oaHF5Pko0P823Ol:2PX5ooooo`koLW9b3_l0000>
ob@T90goN7Qh1_ooool=o`0000ko4A4A3_lB4Q8=ocLg=`Kooooo3_lB4Q8=oa`L70ko0@413OlJ6QX6
ooooo`ko4Q8B3_lU9BD=o`0001?ooooo3_lA4A4>oaXJ6Pko71`L3?mMGEd6ooooo`ko5QHF3_ooool>
ogalO0goBTY:4oooool>oinOW`ko51@D3Om`L70=ooooo`002oooool>obd];@ko5QHF3_l20P8=o`X:
2PGooooo3_mbLW8>o`0000ko92@T3OmhN7P6ooooo`go00003_lA4A4>oa8B4Pgo=cLg1_ooool>oa8B
4Pgo71`L3_l10@4=oaXJ6PKooooo3_lB4Q8>obDU9@go00004oooool>oa4A4@ko6QXJ3_lL71`<oeeM
G@Kooooo3_lF5QH>ooooo`koO7al3Om:BTXCooooo`koWinO3_lD51@=og1`L0gooooo000;ooooo`ko
;Bd]3_lF5QH>o`820Pgo2PX:1Oooool>og9bLPko00003_lT92@=ogQhN0Kooooo3Ol0000>oa4A4@ko
4Q8B3Olg=cL6ooooo`ko4Q8B3OlL71`>o`410@go6QXJ1_ooool>oa8B4Pko9BDU3Ol0000Cooooo`ko
4A4A3_lJ6QX>oa`L70coGEeM1_ooool>oaHF5Pkooooo3_mlO7`=odY:BQ?ooooo3_nOWil>oa@D50go
L71`3Oooool000_ooooo3_l];Bd>oaHF5Pko0P823Ol:2PX5ooooo`koLW9b3_l0000>ob@T90goN7Qh
1_ooool=o`0000ko4A4A3_lB4Q8=ocLg=`Kooooo3_lB4Q8=oa`L70ko0@413OlJ6QX6ooooo`ko4Q8B
3_lU9BD=o`0001?ooooo3_lA4A4>oaXJ6Pko71`L3?mMGEd6ooooo`ko5QHF3_ooool>ogalO0goBTY:
4oooool>oinOW`ko51@D3Om`L70=ooooo`002oooool>obd];@ko5QHF3_l20P8=o`X:2PGooooo3_mb
LW8>o`0000ko92@T3OmhN7P6ooooo`go00003_lA4A4>oa8B4Pgo=cLg1_ooool>oa8B4Pgo71`L3_l1
0@4=oaXJ6PKooooo3_lB4Q8>obDU9@go00004oooool>oa4A4@ko6QXJ3_lL71`<oeeMG@Kooooo3_lF
5QH>ooooo`koO7al3Om:BTXCooooo`koWinO3_lD51@=og1`L0gooooo000;ooooo`ko;Bd]3_lF5QH>
o`820Pgo2PX:1Oooool>og9bLPko00003_lT92@=ogQhN0Kooooo3Ol0000>oa4A4@ko4Q8B3Olg=cL6
ooooo`ko4Q8B3OlL71`>o`410@go6QXJ1_ooool>oa8B4Pko9BDU3Ol0000Cooooo`ko4A4A3_lJ6QX>
oa`L70coGEeM1_ooool>oaHF5Pkooooo3_mlO7`=odY:BQ?ooooo3_nOWil>oa@D50goL71`3Oooool0
00_ooooo3_l];Bd>oaHF5Pko0P823Ol:2PX5ooooo`koLW9b3_l0000>ob@T90goN7Qh1_ooool=o`00
00ko4A4A3_lB4Q8=ocLg=`Kooooo3_lB4Q8=oa`L70ko0@413OlJ6QX6ooooo`ko4Q8B3_lU9BD=o`00
01?ooooo3_lA4A4>oaXJ6Pko71`L3?mMGEd6ooooo`ko5QHF3_ooool>ogalO0goBTY:4oooool>oinO
W`ko51@D3Om`L70=ooooo`002oooool>oa@D50ko2@T93_l>3Ph=o`T92A?ooooo3_lh>3P>oa4A4@go
GUiN1_ooool=oa<C4`ko9BDU3_ooool=o`d=3@Kooooo3_lX:2P=ooooo`ko=cLg3Olb<S86ooooo`ko
9BDU3_l[:b/=o`410@go=3@d1_ooool>o`P820ko3Ph>3_lI6AT<o`X:2PKooooo3_lC4a<>oc@d=0ko
Bd];3Om[Jf/5ooooo`kof=SH3_nd];@>oaXJ6Pgo00003Oooool000_ooooo3_lD51@>o`T92@ko3Ph>
3Ol92@TCooooo`ko>3Ph3_lA4A4=oeiNGPKooooo3OlC4a<>obDU9@kooooo3Ol=3@d6ooooo`ko:2PX
3Oooool>ocLg=`go<S8b1_ooool>obDU9@ko:b/[3Ol10@4=oc@d=0Kooooo3_l820P>o`h>3Pko6ATI
3?l:2PX6ooooo`ko4a<C3_ld=3@>od];B`goJf][1Oooool>omSHf0ko];Bd3_lJ6QX=o`0000gooooo
000;ooooo`ko51@D3_l92@T>o`h>3Pgo2@T94oooool>ocPh>0ko4A4A3OmNGUh6ooooo`go4a<C3_lU
9BD>ooooo`go3@d=1_ooool>obPX:0gooooo3_lg=cL=oc8b<PKooooo3_lU9BD>ob/[:`go0@413Old
=3@6ooooo`ko20P83_l>3Ph>oaTI6@co2PX:1_ooool>oa<C4`ko=3@d3_m;Bd/=of][J`Gooooo3_oH
f=P>okBd]0ko6QXJ3Ol0000=ooooo`002oooool>oa@D50ko2@T93_l>3Ph=o`T92A?ooooo3_lh>3P>
oa4A4@goGUiN1_ooool=oa<C4`ko9BDU3_ooool=o`d=3@Kooooo3_lX:2P=ooooo`ko=cLg3Olb<S86
ooooo`ko9BDU3_l[:b/=o`410@go=3@d1_ooool>o`P820ko3Ph>3_lI6AT<o`X:2PKooooo3_lC4a<>
oc@d=0koBd];3Om[Jf/5ooooo`kof=SH3_nd];@>oaXJ6Pgo00003Oooool000_ooooo3_lD51@>o`T9
2@ko3Ph>3Ol92@TCooooo`ko>3Ph3_lA4A4=oeiNGPKooooo3OlC4a<>obDU9@kooooo3Ol=3@d6oooo
o`ko:2PX3Oooool>ocLg=`go<S8b1_ooool>obDU9@ko:b/[3Ol10@4=oc@d=0Kooooo3_l820P>o`h>
3Pko6ATI3?l:2PX6ooooo`ko4a<C3_ld=3@>od];B`goJf][1Oooool>omSHf0ko];Bd3_lJ6QX=o`00
00gooooo000;ooooo`ko51@D3_l92@T>o`h>3Pgo2@T94oooool>ocPh>0ko4A4A3OmNGUh6ooooo`go
4a<C3_lU9BD>ooooo`go3@d=1_ooool>obPX:0gooooo3_lg=cL=oc8b<PKooooo3_lU9BD>ob/[:`go
0@413Old=3@6ooooo`ko20P83_l>3Ph>oaTI6@co2PX:1_ooool>oa<C4`ko=3@d3_m;Bd/=of][J`Go
oooo3_oHf=P>okBd]0ko6QXJ3Ol0000=ooooo`002oooool>oa@D50ko2@T93_l>3Ph=o`T92A?ooooo
3_lh>3P>oa4A4@goGUiN1_ooool=oa<C4`ko9BDU3_ooool=o`d=3@Kooooo3_lX:2P=ooooo`ko=cLg
3Olb<S86ooooo`ko9BDU3_l[:b/=o`410@go=3@d1_ooool>o`P820ko3Ph>3_lI6AT<o`X:2PKooooo
3_lC4a<>oc@d=0koBd];3Om[Jf/5ooooo`kof=SH3_nd];@>oaXJ6Pgo00003Oooool000_ooooo3_lD
51@>o`T92@ko3Ph>3Ol92@TCooooo`ko>3Ph3_lA4A4=oeiNGPKooooo3OlC4a<>obDU9@kooooo3Ol=
3@d6ooooo`ko:2PX3Oooool>ocLg=`go<S8b1_ooool>obDU9@ko:b/[3Ol10@4=oc@d=0Kooooo3_l8
20P>o`h>3Pko6ATI3?l:2PX6ooooo`ko4a<C3_ld=3@>od];B`goJf][1Oooool>omSHf0ko];Bd3_lJ
6QX=o`0000gooooo000;ooooo`ko51@D3_l92@T>o`h>3Pgo2@T94oooool>ocPh>0ko4A4A3OmNGUh6
ooooo`go4a<C3_lU9BD>ooooo`go3@d=1_ooool>obPX:0gooooo3_lg=cL=oc8b<PKooooo3_lU9BD>
ob/[:`go0@413Old=3@6ooooo`ko20P83_l>3Ph>oaTI6@co2PX:1_ooool>oa<C4`ko=3@d3_m;Bd/=
of][J`Gooooo3_oHf=P>okBd]0ko6QXJ3Ol0000=ooooo`002oooool>oa@D50ko2@T93_l>3Ph=o`T9
2A?ooooo3_lh>3P>oa4A4@goGUiN1_ooool=oa<C4`ko9BDU3_ooool=o`d=3@Kooooo3_lX:2P=oooo
o`ko=cLg3Olb<S86ooooo`ko9BDU3_l[:b/=o`410@go=3@d1_ooool>o`P820ko3Ph>3_lI6AT<o`X:
2PKooooo3_lC4a<>oc@d=0koBd];3Om[Jf/5ooooo`kof=SH3_nd];@>oaXJ6Pgo00003Oooool000_o
oooo3_lD51@>o`T92@ko3Ph>3Ol92@TCooooo`ko>3Ph3_lA4A4=oeiNGPKooooo3OlC4a<>obDU9@ko
oooo3Ol=3@d6ooooo`ko:2PX3Oooool>ocLg=`go<S8b1_ooool>obDU9@ko:b/[3Ol10@4=oc@d=0Ko
oooo3_l820P>o`h>3Pko6ATI3?l:2PX6ooooo`ko4a<C3_ld=3@>od];B`goJf][1Oooool>omSHf0ko
];Bd3_lJ6QX=o`0000gooooo000;ooooo`ko51@D3_l92@T>o`h>3Pgo2@T94oooool>ocPh>0ko4A4A
3OmNGUh6ooooo`go4a<C3_lU9BD>ooooo`go3@d=1_ooool>obPX:0gooooo3_lg=cL=oc8b<PKooooo
3_lU9BD>ob/[:`go0@413Old=3@6ooooo`ko20P83_l>3Ph>oaTI6@co2PX:1_ooool>oa<C4`ko=3@d
3_m;Bd/=of][J`Gooooo3_oHf=P>okBd]0ko6QXJ3Ol0000=ooooo`002oooool>oa@D50ko2@T93_l>
3Ph=o`T92A?ooooo3_lh>3P>oa4A4@goGUiN1_ooool=oa<C4`ko9BDU3_ooool=o`d=3@Kooooo3_lX
:2P=ooooo`ko=cLg3Olb<S86ooooo`ko9BDU3_l[:b/=o`410@go=3@d1_ooool>o`P820ko3Ph>3_lI
6AT<o`X:2PKooooo3_lC4a<>oc@d=0koBd];3Om[Jf/5ooooo`kof=SH3_nd];@>oaXJ6Pgo00003Ooo
ool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=
ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=
oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5
ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5oooo
o`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S
8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L
70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_o
oooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko
9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo
<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko
[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj
3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO
3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo
3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ
6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ
8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_oo
ool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no
_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>
oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6
ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>
o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?
3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b
<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`00
00ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k
>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo
9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko
6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko
?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH6
3Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo
3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B
3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P82
3Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_oo
ool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE
5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/
;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5
ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=
ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<
oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool0
00_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q
8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b
<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5oooo
o`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`ko
NWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko
7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Ko
oooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]3_no_kl>oc/k>`go0P823Oooool000_ooooo
3_lJ6QX>o`l?3`ko1PH63Ol;2`/5ooooo`koNWYj3_l`<30>oaHF5Pgo9bLW1_ooool=ob4Q8@ko9bLW
3_lQ8B4=oc8b<PKooooo3_l?3`l=ob<S8`ko7alO3Om3@d<6ooooo`ko6QXJ3_lE5AD=oc8b<Pgo<c<c
1_ooool>o`0000ko4Q8B3_l71`L<oa`L70Kooooo3_lW9bL>o`h>3Pko?3`l3Ol/;2`5ooooo`ko[Jf]
3_no_kl>oc/k>`go0P823Oooool001Wooooo3_ld=3@>oahN7Pgo00001Oooool>oaDE5@ko=3@d3_l[
:b/=odm?C`Kooooo6olA4A4>oa0@40go30`<1_ooool>o`0000go6QXJ3_lD51@=odE5A@Kooooo7?lL
71`=o`T92@goG5aL1_ooool>ob4Q8@ko5aLG3_lj>SXBooooo`ko00003_m=CDd>oadM7@go<c<c1Ooo
ool>olK6aPko;2`/3_lZ:RX=oiZJVPgooooo000Iooooo`ko=3@d3_lN7Qh=o`0000Gooooo3_lE5AD>
oc@d=0ko:b/[3Om?Cdl6oooooa_o4A4A3_l@410=o``<30Kooooo3_l0000=oaXJ6Pko51@D3Om5ADD6
oooooaco71`L3Ol92@T=oeaLG0Kooooo3_lQ8B4>oaLG5`ko>SXj4_ooool>o`0000koCDe=3_lM7Ad=
oc<c<`Gooooo3_o6a/H>ob`/;0ko:RXZ3OnJVYX=ooooo`006Oooool>oc@d=0ko7QhN3Ol00005oooo
o`ko5ADE3_ld=3@>ob/[:`goCdm?1_oooolKoa4A4@ko410@3Ol<30`6ooooo`ko00003OlJ6QX>oa@D
50goADE51_oooolLoa`L70go2@T93OmLG5`6ooooo`ko8B4Q3_lG5aL>ocXj>Q;ooooo3_l0000>ode=
C@ko7AdM3Olc<c<5ooooo`koa/K63_l/;2`>obXZ:PgoVYZJ3Oooool001Wooooo3_ld=3@>oahN7Pgo
00001Oooool>oaDE5@ko=3@d3_l[:b/=odm?C`Kooooo6olA4A4>oa0@40go30`<1_ooool>o`0000go
6QXJ3_lD51@=odE5A@Kooooo7?lL71`=o`T92@goG5aL1_ooool>ob4Q8@ko5aLG3_lj>SXBooooo`ko
00003_m=CDd>oadM7@go<c<c1Oooool>olK6aPko;2`/3_lZ:RX=oiZJVPgooooo000Iooooo`ko=3@d
3_lN7Qh=o`0000Gooooo3_lE5AD>oc@d=0ko:b/[3Om?Cdl6oooooa_o4A4A3_l@410=o``<30Kooooo
3_l0000=oaXJ6Pko51@D3Om5ADD6oooooaco71`L3Ol92@T=oeaLG0Kooooo3_lQ8B4>oaLG5`ko>SXj
4_ooool>o`0000koCDe=3_lM7Ad=oc<c<`Gooooo3_o6a/H>ob`/;0ko:RXZ3OnJVYX=ooooo`006Ooo
ool>oc@d=0ko7QhN3Ol00005ooooo`ko5ADE3_ld=3@>ob/[:`goCdm?1_oooolKoa4A4@ko410@3Ol<
30`6ooooo`ko00003OlJ6QX>oa@D50goADE51_oooolLoa`L70go2@T93OmLG5`6ooooo`ko8B4Q3_lG
5aL>ocXj>Q;ooooo3_l0000>ode=C@ko7AdM3Olc<c<5ooooo`koa/K63_l/;2`>obXZ:PgoVYZJ3Ooo
ool001Wooooo3_ld=3@>oahN7Pgo00001Oooool>oaDE5@ko=3@d3_l[:b/=odm?C`Kooooo6olA4A4>
oa0@40go30`<1_ooool>o`0000go6QXJ3_lD51@=odE5A@Kooooo7?lL71`=o`T92@goG5aL1_ooool>
ob4Q8@ko5aLG3_lj>SXBooooo`ko00003_m=CDd>oadM7@go<c<c1Oooool>olK6aPko;2`/3_lZ:RX=
oiZJVPgooooo000Iooooo`ko=3@d3_lN7Qh=o`0000Gooooo3_lE5AD>oc@d=0ko:b/[3Om?Cdl6oooo
oa_o4A4A3_l@410=o``<30Kooooo3_l0000=oaXJ6Pko51@D3Om5ADD6oooooaco71`L3Ol92@T=oeaL
G0Kooooo3_lQ8B4>oaLG5`ko>SXj4_ooool>o`0000koCDe=3_lM7Ad=oc<c<`Gooooo3_o6a/H>ob`/
;0ko:RXZ3OnJVYX=ooooo`006Oooool>oc@d=0ko7QhN3Ol00005ooooo`ko5ADE3_ld=3@>ob/[:`go
Cdm?1_oooolKoa4A4@ko410@3Ol<30`6ooooo`ko00003OlJ6QX>oa@D50goADE51_oooolLoa`L70go
2@T93OmLG5`6ooooo`ko8B4Q3_lG5aL>ocXj>Q;ooooo3_l0000>ode=C@ko7AdM3Olc<c<5ooooo`ko
a/K63_l/;2`>obXZ:PgoVYZJ3Oooool001Wooooo3_ld=3@>oahN7Pgo00001Oooool>oaDE5@ko=3@d
3_l[:b/=odm?C`Kooooo6olA4A4>oa0@40go30`<1_ooool>o`0000go6QXJ3_lD51@=odE5A@Kooooo
7?lL71`=o`T92@goG5aL1_ooool>ob4Q8@ko5aLG3_lj>SXBooooo`ko00003_m=CDd>oadM7@go<c<c
1Oooool>olK6aPko;2`/3_lZ:RX=oiZJVPgooooo000Iooooo`ko=3@d3_lN7Qh=o`0000Gooooo3_lE
5AD>oc@d=0ko:b/[3Om?Cdl6oooooa_o4A4A3_l@410=o``<30Kooooo3_l0000=oaXJ6Pko51@D3Om5
ADD6oooooaco71`L3Ol92@T=oeaLG0Kooooo3_lQ8B4>oaLG5`ko>SXj4_ooool>o`0000koCDe=3_lM
7Ad=oc<c<`Gooooo3_o6a/H>ob`/;0ko:RXZ3OnJVYX=ooooo`006Oooool>oc@d=0ko7QhN3Ol00005
ooooo`ko5ADE3_ld=3@>ob/[:`goCdm?1_oooolKoa4A4@ko410@3Ol<30`6ooooo`ko00003OlJ6QX>
oa@D50goADE51_oooolLoa`L70go2@T93OmLG5`6ooooo`ko8B4Q3_lG5aL>ocXj>Q;ooooo3_l0000>
ode=C@ko7AdM3Olc<c<5ooooo`koa/K63_l/;2`>obXZ:PgoVYZJ3Oooool001Wooooo3_ld=3@>oahN
7Pgo00001Oooool>oaDE5@ko=3@d3_l[:b/=odm?C`Kooooo6olA4A4>oa0@40go30`<1_ooool>o`00
00go6QXJ3_lD51@=odE5A@Kooooo7?lL71`=o`T92@goG5aL1_ooool>ob4Q8@ko5aLG3_lj>SXBoooo
o`ko00003_m=CDd>oadM7@go<c<c1Oooool>olK6aPko;2`/3_lZ:RX=oiZJVPgooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l2
0P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_oo
ool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_
;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>
o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6
ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>
oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=
o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K
6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/
;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^K
V`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo
6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko
7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko
0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000go
oooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo
3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo
3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf
1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Ooo
ool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA
4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO
7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;
ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>
o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=
oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>
oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`41
0@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<3
0`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6oooo
o`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko
7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko
1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKo
oooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0ko
SXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A
3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q
1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<3
3_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0
000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE
5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l1
0@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:
2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H61Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=
oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6ooooo`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>
ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>
oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`0000gooooo000;ooooo`ko7AdM3_l0000>o`H6
1Pgo6QXJ1Oooool>o`410@ko4A4A3_l20P8=oa/K6`Kooooo3Ol;2`/>o`820Pko1@D53OlE5AD6oooo
o`ko7QhN3OlA4A4>o`<30`go8B4Q1_ooool>ob`/;0kooooo3OlI6AT=oa8B4PKooooo3_l10@4>oa<C
4`ko0@413?lO7al6ooooo`ko0`<33_l_;bl>oi^KV`go=SHf1Oooool>oo3`l0koSXj>3_l:2PX=o`00
00gooooo000;ooooo`ko6ATI3_l<30`>oaDE5@go@D511Oooool>oc0`<0ko6a/K3_lP820=oaLG5`Ko
oooo3Ol/;2`>o`/;2`ko9RHV4oooool>o`@410go9BDU3_l20P8=oahN7PKooooo3_l<30`>odi>CPgo
10@43Ol@4106ooooo`ko00003_l92@T>o`P820co4a<C1_ooool>obl_;`ko00003_lo?cl=oeEEE@Go
oooo3_m>CTh>ogAdM0ko4A4A3Ol>3Ph=ooooo`002oooool>oaTI6@ko30`<3_lE5AD=od51@@Gooooo
3_l`<30>oa/K6`ko820P3OlG5aL6ooooo`go;2`/3_l;2`/>obHV9Q?ooooo3_l410@=obDU9@ko0P82
3OlN7Qh6ooooo`ko30`<3_m>CTh=o`@410go410@1_ooool>o`0000ko2@T93_l820P<oa<C4`Kooooo
3_l_;bl>o`0000ko?clo3OmEEED5ooooo`koCTi>3_mdM7@>oa4A4@go3Ph>3Oooool000_ooooo3_lI
6AT>o``<30ko5ADE3Om1@D45ooooo`ko<30`3_lK6a/>ob0P80go5aLG1_ooool=ob`/;0ko2`/;3_lV
9RHCooooo`ko10@43OlU9BD>o`820Pgo7QhN1_ooool>o``<30koCTi>3Ol410@=oa0@40Kooooo3_l0
000>o`T92@ko20P83?lC4a<6ooooo`ko;bl_3_l0000>oclo?`goEEEE1Oooool>odi>CPkoM7Ad3_lA
4A4=o`h>3Pgooooo000;ooooo`ko6ATI3_l<30`>oaDE5@go@D511Oooool>oc0`<0ko6a/K3_lP820=
oaLG5`Kooooo3Ol/;2`>o`/;2`ko9RHV4oooool>o`@410go9BDU3_l20P8=oahN7PKooooo3_l<30`>
odi>CPgo10@43Ol@4106ooooo`ko00003_l92@T>o`P820co4a<C1_ooool>obl_;`ko00003_lo?cl=
oeEEE@Gooooo3_m>CTh>ogAdM0ko4A4A3Ol>3Ph=ooooo`002oooool>oaTI6@ko30`<3_lE5AD=od51
@@Gooooo3_l`<30>oa/K6`ko820P3OlG5aL6ooooo`go;2`/3_l;2`/>obHV9Q?ooooo3_l410@=obDU
9@ko0P823OlN7Qh6ooooo`ko30`<3_m>CTh=o`@410go410@1_ooool>o`0000ko2@T93_l820P<oa<C
4`Kooooo3_l_;bl>o`0000ko?clo3OmEEED5ooooo`koCTi>3_mdM7@>oa4A4@go3Ph>3Oooool000_o
oooo3_lI6AT>o``<30ko5ADE3Om1@D45ooooo`ko<30`3_lK6a/>ob0P80go5aLG1_ooool=ob`/;0ko
2`/;3_lV9RHCooooo`ko10@43OlU9BD>o`820Pgo7QhN1_ooool>o``<30koCTi>3Ol410@=oa0@40Ko
oooo3_l0000>o`T92@ko20P83?lC4a<6ooooo`ko;bl_3_l0000>oclo?`goEEEE1Oooool>odi>CPko
M7Ad3_lA4A4=o`h>3Pgooooo000;ooooo`ko6ATI3_l<30`>oaDE5@go@D511Oooool>oc0`<0ko6a/K
3_lP820=oaLG5`Kooooo3Ol/;2`>o`/;2`ko9RHV4oooool>o`@410go9BDU3_l20P8=oahN7PKooooo
3_l<30`>odi>CPgo10@43Ol@4106ooooo`ko00003_l92@T>o`P820co4a<C1_ooool>obl_;`ko0000
3_lo?cl=oeEEE@Gooooo3_m>CTh>ogAdM0ko4A4A3Ol>3Ph=ooooo`002oooool>oaTI6@ko30`<3_lE
5AD=od51@@Gooooo3_l`<30>oa/K6`ko820P3OlG5aL6ooooo`go;2`/3_l;2`/>obHV9Q?ooooo3_l4
10@=obDU9@ko0P823OlN7Qh6ooooo`ko30`<3_m>CTh=o`@410go410@1_ooool>o`0000ko2@T93_l8
20P<oa<C4`Kooooo3_l_;bl>o`0000ko?clo3OmEEED5ooooo`koCTi>3_mdM7@>oa4A4@go3Ph>3Ooo
ool000_ooooo3_lI6AT>o``<30ko5ADE3Om1@D45ooooo`ko<30`3_lK6a/>ob0P80go5aLG1_ooool=
ob`/;0ko2`/;3_lV9RHCooooo`ko10@43OlU9BD>o`820Pgo7QhN1_ooool>o``<30koCTi>3Ol410@=
oa0@40Kooooo3_l0000>o`T92@ko20P83?lC4a<6ooooo`ko;bl_3_l0000>oclo?`goEEEE1Oooool>
odi>CPkoM7Ad3_lA4A4=o`h>3Pgooooo000;ooooo`ko6ATI3_l<30`>oaDE5@go@D511Oooool>oc0`
<0ko6a/K3_lP820=oaLG5`Kooooo3Ol/;2`>o`/;2`ko9RHV4oooool>o`@410go9BDU3_l20P8=oahN
7PKooooo3_l<30`>odi>CPgo10@43Ol@4106ooooo`ko00003_l92@T>o`P820co4a<C1_ooool>obl_
;`ko00003_lo?cl=oeEEE@Gooooo3_m>CTh>ogAdM0ko4A4A3Ol>3Ph=ooooo`002oooool>oaTI6@ko
30`<3_lE5AD=od51@@Gooooo3_l`<30>oa/K6`ko820P3OlG5aL6ooooo`go;2`/3_l;2`/>obHV9Q?o
oooo3_l410@=obDU9@ko0P823OlN7Qh6ooooo`ko30`<3_m>CTh=o`@410go410@1_ooool>o`0000ko
2@T93_l820P<oa<C4`Kooooo3_l_;bl>o`0000ko?clo3OmEEED5ooooo`koCTi>3_mdM7@>oa4A4@go
3Ph>3Oooool000_ooooo3_lI6AT>o``<30ko5ADE3Om1@D45ooooo`ko<30`3_lK6a/>ob0P80go5aLG
1_ooool=ob`/;0ko2`/;3_lV9RHCooooo`ko10@43OlU9BD>o`820Pgo7QhN1_ooool>o``<30koCTi>
3Ol410@=oa0@40Kooooo3_l0000>o`T92@ko20P83?lC4a<6ooooo`ko;bl_3_l0000>oclo?`goEEEE
1Oooool>odi>CPkoM7Ad3_lA4A4=o`h>3Pgooooo000;ooooo`ko6ATI3_l<30`>oaDE5@go@D511Ooo
ool>oc0`<0ko6a/K3_lP820=oaLG5`Kooooo3Ol/;2`>o`/;2`ko9RHV4oooool>o`@410go9BDU3_l2
0P8=oahN7PKooooo3_l<30`>odi>CPgo10@43Ol@4106ooooo`ko00003_l92@T>o`P820co4a<C1_oo
ool>obl_;`ko00003_lo?cl=oeEEE@Gooooo3_m>CTh>ogAdM0ko4A4A3Ol>3Ph=ooooo`002oooool>
oa<C4`ko:BTY3_lL71`Pooooo`ko00003_mUIFD=o`P820Kooooo3Ol0000>o`/;2`ko30`<3Om2@T86
ooooo`ko0P823Oooool>obd];@go@4101_ooool>o`0000ko8b<S3Ol71`L=oa@D50Kooooo3_lI6AT>
o``<30ko5ADE3?lY:BT6ooooo`koY:BT3_lf=SH>oa/K6`goADE51Oooool>oa4A4@koM7Ad3_lh>3P=
odQ8B0gooooo000;ooooo`ko4a<C3_lY:BT>oa`L723ooooo3_l0000>ofEUI@go20P81_ooool=o`00
00ko2`/;3_l<30`=od92@PKooooo3_l20P8=ooooo`ko;Bd]3Om0@406ooooo`ko00003_lS8b<=o`L7
1`go51@D1_ooool>oaTI6@ko30`<3_lE5AD<obTY:@Kooooo3_nTY:@>ocHf=Pko6a/K3Om5ADD5oooo
o`ko4A4A3_mdM7@>ocPh>0goB4Q83Oooool000_ooooo3_lC4a<>obTY:@ko71`L8?ooool>o`0000ko
IFEU3Ol820P6ooooo`go00003_l;2`/>o``<30go@T921_ooool>o`820Pgooooo3_l];Bd=od10@0Ko
oooo3_l0000>ob<S8`go1`L73OlD51@6ooooo`ko6ATI3_l<30`>oaDE5@co:BTY1_ooool>ojBTY0ko
=SHf3_lK6a/=odE5A@Gooooo3_lA4A4>ogAdM0ko>3Ph3Om8B4P=ooooo`002oooool>oa<C4`ko:BTY
3_lL71`Pooooo`ko00003_mUIFD=o`P820Kooooo3Ol0000>o`/;2`ko30`<3Om2@T86ooooo`ko0P82
3Oooool>obd];@go@4101_ooool>o`0000ko8b<S3Ol71`L=oa@D50Kooooo3_lI6AT>o``<30ko5ADE
3?lY:BT6ooooo`koY:BT3_lf=SH>oa/K6`goADE51Oooool>oa4A4@koM7Ad3_lh>3P=odQ8B0gooooo
000;ooooo`ko4a<C3_lY:BT>oa`L723ooooo3_l0000>ofEUI@go20P81_ooool=o`0000ko2`/;3_l<
30`=od92@PKooooo3_l20P8=ooooo`ko;Bd]3Om0@406ooooo`ko00003_lS8b<=o`L71`go51@D1_oo
ool>oaTI6@ko30`<3_lE5AD<obTY:@Kooooo3_nTY:@>ocHf=Pko6a/K3Om5ADD5ooooo`ko4A4A3_md
M7@>ocPh>0goB4Q83Oooool000_ooooo3_lC4a<>obTY:@ko71`L8?ooool>o`0000koIFEU3Ol820P6
ooooo`go00003_l;2`/>o``<30go@T921_ooool>o`820Pgooooo3_l];Bd=od10@0Kooooo3_l0000>
ob<S8`go1`L73OlD51@6ooooo`ko6ATI3_l<30`>oaDE5@co:BTY1_ooool>ojBTY0ko=SHf3_lK6a/=
odE5A@Gooooo3_lA4A4>ogAdM0ko>3Ph3Om8B4P=ooooo`002oooool>oa<C4`ko:BTY3_lL71`Poooo
o`ko00003_mUIFD=o`P820Kooooo3Ol0000>o`/;2`ko30`<3Om2@T86ooooo`ko0P823Oooool>obd]
;@go@4101_ooool>o`0000ko8b<S3Ol71`L=oa@D50Kooooo3_lI6AT>o``<30ko5ADE3?lY:BT6oooo
o`koY:BT3_lf=SH>oa/K6`goADE51Oooool>oa4A4@koM7Ad3_lh>3P=odQ8B0gooooo000;ooooo`ko
4a<C3_lY:BT>oa`L723ooooo3_l0000>ofEUI@go20P81_ooool=o`0000ko2`/;3_l<30`=od92@PKo
oooo3_l20P8=ooooo`ko;Bd]3Om0@406ooooo`ko00003_lS8b<=o`L71`go51@D1_ooool>oaTI6@ko
30`<3_lE5AD<obTY:@Kooooo3_nTY:@>ocHf=Pko6a/K3Om5ADD5ooooo`ko4A4A3_mdM7@>ocPh>0go
B4Q83Oooool000_ooooo3_lC4a<>obTY:@ko71`L8?ooool>o`0000koIFEU3Ol820P6ooooo`go0000
3_l;2`/>o``<30go@T921_ooool>o`820Pgooooo3_l];Bd=od10@0Kooooo3_l0000>ob<S8`go1`L7
3OlD51@6ooooo`ko6ATI3_l<30`>oaDE5@co:BTY1_ooool>ojBTY0ko=SHf3_lK6a/=odE5A@Gooooo
3_lA4A4>ogAdM0ko>3Ph3Om8B4P=ooooo`002oooool>oa<C4`ko:BTY3_lL71`Pooooo`ko00003_mU
IFD=o`P820Kooooo3Ol0000>o`/;2`ko30`<3Om2@T86ooooo`ko0P823Oooool>obd];@go@4101_oo
ool>o`0000ko8b<S3Ol71`L=oa@D50Kooooo3_lI6AT>o``<30ko5ADE3?lY:BT6ooooo`koY:BT3_lf
=SH>oa/K6`goADE51Oooool>oa4A4@koM7Ad3_lh>3P=odQ8B0gooooo000;ooooo`ko4a<C3_lY:BT>
oa`L723ooooo3_l0000>ofEUI@go20P81_ooool=o`0000ko2`/;3_l<30`=od92@PKooooo3_l20P8=
ooooo`ko;Bd]3Om0@406ooooo`ko00003_lS8b<=o`L71`go51@D1_ooool>oaTI6@ko30`<3_lE5AD<
obTY:@Kooooo3_nTY:@>ocHf=Pko6a/K3Om5ADD5ooooo`ko4A4A3_mdM7@>ocPh>0goB4Q83Oooool0
00_ooooo3_lC4a<>obTY:@ko71`L8?ooool>o`0000koIFEU3Ol820P6ooooo`go00003_l;2`/>o``<
30go@T921_ooool>o`820Pgooooo3_l];Bd=od10@0Kooooo3_l0000>ob<S8`go1`L73OlD51@6oooo
o`ko6ATI3_l<30`>oaDE5@co:BTY1_ooool>ojBTY0ko=SHf3_lK6a/=odE5A@Gooooo3_lA4A4>ogAd
M0ko>3Ph3Om8B4P=ooooo`002oooool>oa<C4`ko:BTY3_lL71`Pooooo`ko00003_mUIFD=o`P820Ko
oooo3Ol0000>o`/;2`ko30`<3Om2@T86ooooo`ko0P823Oooool>obd];@go@4101_ooool>o`0000ko
8b<S3Ol71`L=oa@D50Kooooo3_lI6AT>o``<30ko5ADE3?lY:BT6ooooo`koY:BT3_lf=SH>oa/K6`go
ADE51Oooool>oa4A4@koM7Ad3_lh>3P=odQ8B0gooooo000;ooooo`ko4a<C3_lY:BT>oa`L723ooooo
3_l0000>ofEUI@go20P81_ooool=o`0000ko2`/;3_l<30`=od92@PKooooo3_l20P8=ooooo`ko;Bd]
3Om0@406ooooo`ko00003_lS8b<=o`L71`go51@D1_ooool>oaTI6@ko30`<3_lE5AD<obTY:@Kooooo
3_nTY:@>ocHf=Pko6a/K3Om5ADD5ooooo`ko4A4A3_mdM7@>ocPh>0goB4Q83Oooool000_ooooo3_lH
61P>oaTI6@ko6a/K3OlJ6QX5ooooo`ko71`L3_l20P8>o`0000go6ATI1_ooool=ob0P80ko10@43_lY
:BT=oaXJ6PKooooo3_l0000=oclo?`ko5QHF3OmADE46ooooo`ko51@D3_lU9BD=obTY:@go9BDU1_oo
ool>ocXj>Pko:b/[3_l71`LBooooo`ko3Ph>3_nXZ:P>ooooo`go4A4A4oooool>ob4Q8@ko6ATI3Om2
@T8=ooooo`002oooool>oaPH60ko6ATI3_lK6a/=oaXJ6PGooooo3_lL71`>o`820Pko00003OlI6AT6
ooooo`go820P3_l410@>obTY:@go6QXJ1_ooool>o`0000go?clo3_lF5QH=oe5AD@Kooooo3_lD51@>
obDU9@go:BTY3OlU9BD6ooooo`ko>SXj3_l[:b/>o`L71a;ooooo3_l>3Ph>ojRXZ0kooooo3OlA4A4C
ooooo`ko8B4Q3_lI6AT=od92@Pgooooo000;ooooo`ko61PH3_lI6AT>oa/K6`go6QXJ1Oooool>oa`L
70ko0P823_l0000=oaTI6@Kooooo3OlP820>o`@410ko:BTY3OlJ6QX6ooooo`ko00003Olo?cl>oaHF
5PgoDE5A1_ooool>oa@D50ko9BDU3OlY:BT=obDU9@Kooooo3_lj>SX>ob/[:`ko1`L74_ooool>o`h>
3PkoZ:RX3_ooool=oa4A4A?ooooo3_lQ8B4>oaTI6@go@T923Oooool000_ooooo3_lH61P>oaTI6@ko
6a/K3OlJ6QX5ooooo`ko71`L3_l20P8>o`0000go6ATI1_ooool=ob0P80ko10@43_lY:BT=oaXJ6PKo
oooo3_l0000=oclo?`ko5QHF3OmADE46ooooo`ko51@D3_lU9BD=obTY:@go9BDU1_ooool>ocXj>Pko
:b/[3_l71`LBooooo`ko3Ph>3_nXZ:P>ooooo`go4A4A4oooool>ob4Q8@ko6ATI3Om2@T8=ooooo`00
2oooool>oaPH60ko6ATI3_lK6a/=oaXJ6PGooooo3_lL71`>o`820Pko00003OlI6AT6ooooo`go820P
3_l410@>obTY:@go6QXJ1_ooool>o`0000go?clo3_lF5QH=oe5AD@Kooooo3_lD51@>obDU9@go:BTY
3OlU9BD6ooooo`ko>SXj3_l[:b/>o`L71a;ooooo3_l>3Ph>ojRXZ0kooooo3OlA4A4Cooooo`ko8B4Q
3_lI6AT=od92@Pgooooo000;ooooo`ko61PH3_lI6AT>oa/K6`go6QXJ1Oooool>oa`L70ko0P823_l0
000=oaTI6@Kooooo3OlP820>o`@410ko:BTY3OlJ6QX6ooooo`ko00003Olo?cl>oaHF5PgoDE5A1_oo
ool>oa@D50ko9BDU3OlY:BT=obDU9@Kooooo3_lj>SX>ob/[:`ko1`L74_ooool>o`h>3PkoZ:RX3_oo
ool=oa4A4A?ooooo3_lQ8B4>oaTI6@go@T923Oooool000_ooooo3_lH61P>oaTI6@ko6a/K3OlJ6QX5
ooooo`ko71`L3_l20P8>o`0000go6ATI1_ooool=ob0P80ko10@43_lY:BT=oaXJ6PKooooo3_l0000=
oclo?`ko5QHF3OmADE46ooooo`ko51@D3_lU9BD=obTY:@go9BDU1_ooool>ocXj>Pko:b/[3_l71`LB
ooooo`ko3Ph>3_nXZ:P>ooooo`go4A4A4oooool>ob4Q8@ko6ATI3Om2@T8=ooooo`002oooool>oaPH
60ko6ATI3_lK6a/=oaXJ6PGooooo3_lL71`>o`820Pko00003OlI6AT6ooooo`go820P3_l410@>obTY
:@go6QXJ1_ooool>o`0000go?clo3_lF5QH=oe5AD@Kooooo3_lD51@>obDU9@go:BTY3OlU9BD6oooo
o`ko>SXj3_l[:b/>o`L71a;ooooo3_l>3Ph>ojRXZ0kooooo3OlA4A4Cooooo`ko8B4Q3_lI6AT=od92
@Pgooooo000;ooooo`ko61PH3_lI6AT>oa/K6`go6QXJ1Oooool>oa`L70ko0P823_l0000=oaTI6@Ko
oooo3OlP820>o`@410ko:BTY3OlJ6QX6ooooo`ko00003Olo?cl>oaHF5PgoDE5A1_ooool>oa@D50ko
9BDU3OlY:BT=obDU9@Kooooo3_lj>SX>ob/[:`ko1`L74_ooool>o`h>3PkoZ:RX3_ooool=oa4A4A?o
oooo3_lQ8B4>oaTI6@go@T923Oooool000_ooooo3_lH61P>oaTI6@ko6a/K3OlJ6QX5ooooo`ko71`L
3_l20P8>o`0000go6ATI1_ooool=ob0P80ko10@43_lY:BT=oaXJ6PKooooo3_l0000=oclo?`ko5QHF
3OmADE46ooooo`ko51@D3_lU9BD=obTY:@go9BDU1_ooool>ocXj>Pko:b/[3_l71`LBooooo`ko3Ph>
3_nXZ:P>ooooo`go4A4A4oooool>ob4Q8@ko6ATI3Om2@T8=ooooo`002oooool>oaPH60ko6ATI3_lK
6a/=oaXJ6PGooooo3_lL71`>o`820Pko00003OlI6AT6ooooo`go820P3_l410@>obTY:@go6QXJ1_oo
ool>o`0000go?clo3_lF5QH=oe5AD@Kooooo3_lD51@>obDU9@go:BTY3OlU9BD6ooooo`ko>SXj3_l[
:b/>o`L71a;ooooo3_l>3Ph>ojRXZ0kooooo3OlA4A4Cooooo`ko8B4Q3_lI6AT=od92@Pgooooo000;
ooooo`ko61PH3_lI6AT>oa/K6`go6QXJ1Oooool>oa`L70ko0P823_l0000=oaTI6@Kooooo3OlP820>
o`@410ko:BTY3OlJ6QX6ooooo`ko00003Olo?cl>oaHF5PgoDE5A1_ooool>oa@D50ko9BDU3OlY:BT=
obDU9@Kooooo3_lj>SX>ob/[:`ko1`L74_ooool>o`h>3PkoZ:RX3_ooool=oa4A4A?ooooo3_lQ8B4>
oaTI6@go@T923Oooool000_ooooo3_lH61P>oaTI6@ko6a/K3OlJ6QX5ooooo`ko71`L3_l20P8>o`00
00go6ATI1_ooool=ob0P80ko10@43_lY:BT=oaXJ6PKooooo3_l0000=oclo?`ko5QHF3OmADE46oooo
o`ko51@D3_lU9BD=obTY:@go9BDU1_ooool>ocXj>Pko:b/[3_l71`LBooooo`ko3Ph>3_nXZ:P>oooo
o`go4A4A4oooool>ob4Q8@ko6ATI3Om2@T8=ooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002ooo
ool>o`d=3@ko10@43_lY:BT=o`0000Gooooo3_mXJ6P>o`D51@ko>c/k3Olg=cL6ooooo`go30`<3_mF
EUH>ofQXJ0goSHf=1_ooool>ojb/[0gooooo3_lN7Qh=o`T92@Kooooo3_mMGEd>o`0000goBTY:4ooo
ool>o`D51@ko7QhN3_lG5aL<od10@0Kooooo3_lF5QH>o`0000ko7QhN3Om7AdL5ooooo`ko[jn_3_mL
G5`>o`0000go1`L73Oooool000_ooooo3_l=3@d>o`@410ko:BTY3Ol00005ooooo`koJ6QX3_l51@D>
oc/k>`go=cLg1_ooool=o``<30koEUIF3_mXJ6P=ohf=S@Kooooo3_n/[:`=ooooo`ko7QhN3Ol92@T6
ooooo`koGEeM3_l0000=odY:BQ?ooooo3_l51@D>oahN7Pko5aLG3?m0@406ooooo`ko5QHF3_l0000>
oahN7PgoAdM71Oooool>ojn_[`koG5aL3_l0000=o`L71`gooooo000;ooooo`ko3@d=3_l410@>obTY
:@go00001Oooool>ofQXJ0ko1@D53_lk>c/=ocLg=`Kooooo3Ol<30`>oeIFEPkoJ6QX3On=SHd6oooo
o`ko[:b/3Oooool>oahN7Pgo2@T91_ooool>oeeMG@ko00003Om:BTXCooooo`ko1@D53_lN7Qh>oaLG
5`co@4101_ooool>oaHF5Pko00003_lN7Qh=odM7A`Gooooo3_n_[jl>oeaLG0ko00003Ol71`L=oooo
o`002oooool>o`d=3@ko10@43_lY:BT=o`0000Gooooo3_mXJ6P>o`D51@ko>c/k3Olg=cL6ooooo`go
30`<3_mFEUH>ofQXJ0goSHf=1_ooool>ojb/[0gooooo3_lN7Qh=o`T92@Kooooo3_mMGEd>o`0000go
BTY:4oooool>o`D51@ko7QhN3_lG5aL<od10@0Kooooo3_lF5QH>o`0000ko7QhN3Om7AdL5ooooo`ko
[jn_3_mLG5`>o`0000go1`L73Oooool000_ooooo3_l=3@d>o`@410ko:BTY3Ol00005ooooo`koJ6QX
3_l51@D>oc/k>`go=cLg1_ooool=o``<30koEUIF3_mXJ6P=ohf=S@Kooooo3_n/[:`=ooooo`ko7QhN
3Ol92@T6ooooo`koGEeM3_l0000=odY:BQ?ooooo3_l51@D>oahN7Pko5aLG3?m0@406ooooo`ko5QHF
3_l0000>oahN7PgoAdM71Oooool>ojn_[`koG5aL3_l0000=o`L71`gooooo000;ooooo`ko3@d=3_l4
10@>obTY:@go00001Oooool>ofQXJ0ko1@D53_lk>c/=ocLg=`Kooooo3Ol<30`>oeIFEPkoJ6QX3On=
SHd6ooooo`ko[:b/3Oooool>oahN7Pgo2@T91_ooool>oeeMG@ko00003Om:BTXCooooo`ko1@D53_lN
7Qh>oaLG5`co@4101_ooool>oaHF5Pko00003_lN7Qh=odM7A`Gooooo3_n_[jl>oeaLG0ko00003Ol7
1`L=ooooo`002oooool>o`d=3@ko10@43_lY:BT=o`0000Gooooo3_mXJ6P>o`D51@ko>c/k3Olg=cL6
ooooo`go30`<3_mFEUH>ofQXJ0goSHf=1_ooool>ojb/[0gooooo3_lN7Qh=o`T92@Kooooo3_mMGEd>
o`0000goBTY:4oooool>o`D51@ko7QhN3_lG5aL<od10@0Kooooo3_lF5QH>o`0000ko7QhN3Om7AdL5
ooooo`ko[jn_3_mLG5`>o`0000go1`L73Oooool000_ooooo3_l=3@d>o`@410ko:BTY3Ol00005oooo
o`koJ6QX3_l51@D>oc/k>`go=cLg1_ooool=o``<30koEUIF3_mXJ6P=ohf=S@Kooooo3_n/[:`=oooo
o`ko7QhN3Ol92@T6ooooo`koGEeM3_l0000=odY:BQ?ooooo3_l51@D>oahN7Pko5aLG3?m0@406oooo
o`ko5QHF3_l0000>oahN7PgoAdM71Oooool>ojn_[`koG5aL3_l0000=o`L71`gooooo000;ooooo`ko
3@d=3_l410@>obTY:@go00001Oooool>ofQXJ0ko1@D53_lk>c/=ocLg=`Kooooo3Ol<30`>oeIFEPko
J6QX3On=SHd6ooooo`ko[:b/3Oooool>oahN7Pgo2@T91_ooool>oeeMG@ko00003Om:BTXCooooo`ko
1@D53_lN7Qh>oaLG5`co@4101_ooool>oaHF5Pko00003_lN7Qh=odM7A`Gooooo3_n_[jl>oeaLG0ko
00003Ol71`L=ooooo`002oooool>o`d=3@ko10@43_lY:BT=o`0000Gooooo3_mXJ6P>o`D51@ko>c/k
3Olg=cL6ooooo`go30`<3_mFEUH>ofQXJ0goSHf=1_ooool>ojb/[0gooooo3_lN7Qh=o`T92@Kooooo
3_mMGEd>o`0000goBTY:4oooool>o`D51@ko7QhN3_lG5aL<od10@0Kooooo3_lF5QH>o`0000ko7QhN
3Om7AdL5ooooo`ko[jn_3_mLG5`>o`0000go1`L73Oooool000_ooooo3_l=3@d>o`@410ko:BTY3Ol0
0005ooooo`koJ6QX3_l51@D>oc/k>`go=cLg1_ooool=o``<30koEUIF3_mXJ6P=ohf=S@Kooooo3_n/
[:`=ooooo`ko7QhN3Ol92@T6ooooo`koGEeM3_l0000=odY:BQ?ooooo3_l51@D>oahN7Pko5aLG3?m0
@406ooooo`ko5QHF3_l0000>oahN7PgoAdM71Oooool>ojn_[`koG5aL3_l0000=o`L71`gooooo000;
ooooo`ko3@d=3_l410@>obTY:@go00001Oooool>ofQXJ0ko1@D53_lk>c/=ocLg=`Kooooo3Ol<30`>
oeIFEPkoJ6QX3On=SHd6ooooo`ko[:b/3Oooool>oahN7Pgo2@T91_ooool>oeeMG@ko00003Om:BTXC
ooooo`ko1@D53_lN7Qh>oaLG5`co@4101_ooool>oaHF5Pko00003_lN7Qh=odM7A`Gooooo3_n_[jl>
oeaLG0ko00003Ol71`L=ooooo`002oooool>o`d=3@ko10@43_lY:BT=o`0000Gooooo3_mXJ6P>o`D5
1@ko>c/k3Olg=cL6ooooo`go30`<3_mFEUH>ofQXJ0goSHf=1_ooool>ojb/[0gooooo3_lN7Qh=o`T9
2@Kooooo3_mMGEd>o`0000goBTY:4oooool>o`D51@ko7QhN3_lG5aL<od10@0Kooooo3_lF5QH>o`00
00ko7QhN3Om7AdL5ooooo`ko[jn_3_mLG5`>o`0000go1`L73Oooool000_ooooo3_l=3@d>o`0000ko
<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Ko
oooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko
61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go
7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN
1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q
3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE
3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol6
1PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT
92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0
000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Ooo
ool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=
odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=
ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5
ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5oooo
o`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[
Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?S
h`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_o
oooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko
4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?Pgo
O7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko
_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?
3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D51
3Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo
3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=
3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb
/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_oo
ool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oc
lo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>
o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6
ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>
oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`00
00ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_k
n`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO
7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d
=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go
7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko
8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko
5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a
3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo
3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH
3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM
3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5ooooo`koclo?3_lg=cL>o`0000go7QhN1_oo
ool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH
61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg
=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool000_ooooo3_l=3@d>o`0000ko<C4a3Ol61PH5
ooooo`koclo?3_lg=cL>o`0000go7QhN1_ooool=odm?C`ko4a<C3_nb/[8=oo_kn`Kooooo3_lT92@=
oj^[Z`ko@D513Om4A4@6ooooo`ko8B4Q3_lH61P=ochn?PgoO7al1_ooool>oalO7`ko61PH3_l0000<
on?Sh`Kooooo3_lH61P>oadM7@ko5ADE3Olg=cL5ooooo`ko_[jn3_oclo<>oc@d=0go7AdM3Oooool0
00_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6
QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO
7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5oooo
o`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`ko
i>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0ko
MWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Ko
oooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo
3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko0000
3_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S
1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:
3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oc
lo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@
T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=
3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>
o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=
omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>
oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>
oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q
8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906oooo
o`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO
7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pko
oooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Ko
oooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko
51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go
>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX
1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm
3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:
3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol6
1PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0
000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l9
2@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Ooo
ool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=
ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=
oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5
ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5oooo
o`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd
]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?
3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_o
oooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko
00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`go
Hf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`ko
RXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo3_l71`L>o`X:2Pkooooo3Ol61PH5ooooo`koi>CT
3_oclo<>ob4Q8@go:2PX1_ooool=ohJ6QPko00003_ooool=omoOg`Kooooo3_l0000=okBd]0koMWIf
3On@T906ooooo`ko?Cdm3_lV9RH=oalO7`goHf=S1_ooool>oaXJ6Pko51@D3_l92@T<o`l?3`Kooooo
3_l=3@d>oalO7`ko2PX:3Ol61PH5ooooo`koRXZ:3_ooool>oiBDU0go>CTi3Oooool000_ooooo7?lI
6AT>obPX:0go6a/K1Oooool>oc`l?0ko1PH63_ooool=oclo?`Kooooo3OlY:BT>ohb<S0koEEEE3Olg
=cL6ooooo`koo_kn3OogmoL>o`D51@go4a<C1_ooool>ob/[:`ko4A4A3OlT92@=oc8b<PKooooo3_m[
Jf/>oaTI6@ko20P84_ooool>oaHF5Pkooooo3_li>CT=of=SH`Gooooo3_n3Ph<>oa`L70ko8B4Q3Ol8
20P=ooooo`002ooooolLoaTI6@ko:2PX3OlK6a/5ooooo`ko?3`l3_l61PH>ooooo`go?clo1_ooool=
obTY:@koS8b<3_mEEED=ocLg=`Kooooo3_ono_h=ooOgm`ko1@D53OlC4a<6ooooo`ko:b/[3_lA4A4=
ob@T90go<S8b1_ooool>of][J`ko6ATI3_l820PBooooo`ko5QHF3_ooool>ocTi>@goHf=S1Oooool>
oh>3P`ko71`L3_lQ8B4=o`P820gooooo000;oooooaco6ATI3_lX:2P=oa/K6`Gooooo3_ll?3`>o`H6
1Pkooooo3Olo?cl6ooooo`go:BTY3_n<S8`>oeEEE@go=cLg1_ooool>ooknoPgomoOg3_l51@D=oa<C
4`Kooooo3_l[:b/>oa4A4@go92@T3Olb<S86ooooo`koJf][3_lI6AT>o`P821;ooooo3_lF5QH>oooo
o`ko>CTi3OmSHf<5ooooo`koPh>33_lL71`>ob4Q8@go20P83Oooool000_ooooo7?lI6AT>obPX:0go
6a/K1Oooool>oc`l?0ko1PH63_ooool=oclo?`Kooooo3OlY:BT>ohb<S0koEEEE3Olg=cL6ooooo`ko
o_kn3OogmoL>o`D51@go4a<C1_ooool>ob/[:`ko4A4A3OlT92@=oc8b<PKooooo3_m[Jf/>oaTI6@ko
20P84_ooool>oaHF5Pkooooo3_li>CT=of=SH`Gooooo3_n3Ph<>oa`L70ko8B4Q3Ol820P=ooooo`00
2ooooolLoaTI6@ko:2PX3OlK6a/5ooooo`ko?3`l3_l61PH>ooooo`go?clo1_ooool=obTY:@koS8b<
3_mEEED=ocLg=`Kooooo3_ono_h=ooOgm`ko1@D53OlC4a<6ooooo`ko:b/[3_lA4A4=ob@T90go<S8b
1_ooool>of][J`ko6ATI3_l820PBooooo`ko5QHF3_ooool>ocTi>@goHf=S1Oooool>oh>3P`ko71`L
3_lQ8B4=o`P820gooooo000;oooooaco6ATI3_lX:2P=oa/K6`Gooooo3_ll?3`>o`H61Pkooooo3Olo
?cl6ooooo`go:BTY3_n<S8`>oeEEE@go=cLg1_ooool>ooknoPgomoOg3_l51@D=oa<C4`Kooooo3_l[
:b/>oa4A4@go92@T3Olb<S86ooooo`koJf][3_lI6AT>o`P821;ooooo3_lF5QH>ooooo`ko>CTi3OmS
Hf<5ooooo`koPh>33_lL71`>ob4Q8@go20P83Oooool000_ooooo7?lI6AT>obPX:0go6a/K1Oooool>
oc`l?0ko1PH63_ooool=oclo?`Kooooo3OlY:BT>ohb<S0koEEEE3Olg=cL6ooooo`koo_kn3OogmoL>
o`D51@go4a<C1_ooool>ob/[:`ko4A4A3OlT92@=oc8b<PKooooo3_m[Jf/>oaTI6@ko20P84_ooool>
oaHF5Pkooooo3_li>CT=of=SH`Gooooo3_n3Ph<>oa`L70ko8B4Q3Ol820P=ooooo`002ooooolLoaTI
6@ko:2PX3OlK6a/5ooooo`ko?3`l3_l61PH>ooooo`go?clo1_ooool=obTY:@koS8b<3_mEEED=ocLg
=`Kooooo3_ono_h=ooOgm`ko1@D53OlC4a<6ooooo`ko:b/[3_lA4A4=ob@T90go<S8b1_ooool>of][
J`ko6ATI3_l820PBooooo`ko5QHF3_ooool>ocTi>@goHf=S1Oooool>oh>3P`ko71`L3_lQ8B4=o`P8
20gooooo000;oooooaco6ATI3_lX:2P=oa/K6`Gooooo3_ll?3`>o`H61Pkooooo3Olo?cl6ooooo`go
:BTY3_n<S8`>oeEEE@go=cLg1_ooool>ooknoPgomoOg3_l51@D=oa<C4`Kooooo3_l[:b/>oa4A4@go
92@T3Olb<S86ooooo`koJf][3_lI6AT>o`P821;ooooo3_lF5QH>ooooo`ko>CTi3OmSHf<5ooooo`ko
Ph>33_lL71`>ob4Q8@go20P83Oooool000_ooooo7?lI6AT>obPX:0go6a/K1Oooool>oc`l?0ko1PH6
3_ooool=oclo?`Kooooo3OlY:BT>ohb<S0koEEEE3Olg=cL6ooooo`koo_kn3OogmoL>o`D51@go4a<C
1_ooool>ob/[:`ko4A4A3OlT92@=oc8b<PKooooo3_m[Jf/>oaTI6@ko20P84_ooool>oaHF5Pkooooo
3_li>CT=of=SH`Gooooo3_n3Ph<>oa`L70ko8B4Q3Ol820P=ooooo`002ooooolLoaTI6@ko:2PX3OlK
6a/5ooooo`ko?3`l3_l61PH>ooooo`go?clo1_ooool=obTY:@koS8b<3_mEEED=ocLg=`Kooooo3_on
o_h=ooOgm`ko1@D53OlC4a<6ooooo`ko:b/[3_lA4A4=ob@T90go<S8b1_ooool>of][J`ko6ATI3_l8
20PBooooo`ko5QHF3_ooool>ocTi>@goHf=S1Oooool>oh>3P`ko71`L3_lQ8B4=o`P820gooooo000;
oooooaco6ATI3_lX:2P=oa/K6`Gooooo3_ll?3`>o`H61Pkooooo3Olo?cl6ooooo`go:BTY3_n<S8`>
oeEEE@go=cLg1_ooool>ooknoPgomoOg3_l51@D=oa<C4`Kooooo3_l[:b/>oa4A4@go92@T3Olb<S86
ooooo`koJf][3_lI6AT>o`P821;ooooo3_lF5QH>ooooo`ko>CTi3OmSHf<5ooooo`koPh>33_lL71`>
ob4Q8@go20P83Oooool000_ooooo7?lI6AT>obPX:0go6a/K1Oooool>oc`l?0ko1PH63_ooool=oclo
?`Kooooo3OlY:BT>ohb<S0koEEEE3Olg=cL6ooooo`koo_kn3OogmoL>o`D51@go4a<C1_ooool>ob/[
:`ko4A4A3OlT92@=oc8b<PKooooo3_m[Jf/>oaTI6@ko20P84_ooool>oaHF5Pkooooo3_li>CT=of=S
H`Gooooo3_n3Ph<>oa`L70ko8B4Q3Ol820P=ooooo`00oooooooeooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`002ooo
ool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>
CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol3
0`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0
000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>
oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=
oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>
oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN
7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L
70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6oooo
o`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@4
10ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`ko
CDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Ko
oooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko
8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L
3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@41
1_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[
3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P
3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmL
G5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL
71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`
<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=
o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>
oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>
onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=
ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6oooo
o`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l
?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=
3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Go
oooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go
6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0co
Kfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`00
2oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b
3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D
3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo
3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0
000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB
4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_oo
ool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>
oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>
oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6
ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9BDPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>
o`@410ko820P3OlF5QH=ooooo`002oooool>oahN7Pko71`L3_l61PH=o`0000Gooooo3_l0000>oalO
7`koCDe=3OmLG5`6ooooo`go<S8b3_m>CTh>oa`L70go0@411_ooool>oa4A4@go6a/K3_lB4Q8=oa@D
50Kooooo3_lL71`>oc`l?0go51@D3Ol30`<6ooooo`ko:b/[3_lD51@>onSXj0coKfm_1_ooool>oe9B
DPko8b<S3_l`<30=o`d=3@Gooooo3_l0000>o`@410ko820P3OlF5QH=ooooo`002oooool>obXZ:Pko
6a/K3_lC4a<=o`<30`Gooooo3_nDU9@>o`d=3@ko:BTY3OnBTY86ooooo`go10@43_ln?Sh>odY:BPgo
GUiN1_ooool>o`0000go4A4A3_lm?Cd=obDU9@Kooooo7?lA4A4=o`H61Pgo1`L71_ooool>ofQXJ0ko
4a<C3_lY:BT<ob4Q8@Kooooo3_l/;2`>oa@D50ko5QHF3Ol@4105ooooo`ko6a/K3_l0000>oaLG5`go
9BDU3Oooool000_ooooo3_lZ:RX>oa/K6`ko4a<C3Ol30`<5ooooo`koU9BD3_l=3@d>obTY:@goTY:B
1_ooool=o`@410ko?Shn3_m:BTX=oeiNGPKooooo3_l0000=oa4A4@ko?Cdm3OlU9BD6oooooaco4A4A
3Ol61PH=o`L71`Kooooo3_mXJ6P>oa<C4`ko:BTY3?lQ8B46ooooo`ko;2`/3_lD51@>oaHF5Pgo410@
1Oooool>oa/K6`ko00003_lG5aL=obDU9@gooooo000;ooooo`ko:RXZ3_lK6a/>oa<C4`go0`<31Ooo
ool>oiBDU0ko3@d=3_lY:BT=oi:BTPKooooo3Ol410@>ochn?PkoBTY:3OmNGUh6ooooo`ko00003OlA
4A4>ocdm?@go9BDU1_oooolLoa4A4@go1PH63Ol71`L6ooooo`koJ6QX3_lC4a<>obTY:@co8B4Q1_oo
ool>ob`/;0ko51@D3_lF5QH=oa0@40Gooooo3_lK6a/>o`0000ko5aLG3OlU9BD=ooooo`002oooool>
obXZ:Pko6a/K3_lC4a<=o`<30`Gooooo3_nDU9@>o`d=3@ko:BTY3OnBTY86ooooo`go10@43_ln?Sh>
odY:BPgoGUiN1_ooool>o`0000go4A4A3_lm?Cd=obDU9@Kooooo7?lA4A4=o`H61Pgo1`L71_ooool>
ofQXJ0ko4a<C3_lY:BT<ob4Q8@Kooooo3_l/;2`>oa@D50ko5QHF3Ol@4105ooooo`ko6a/K3_l0000>
oaLG5`go9BDU3Oooool000_ooooo3_lZ:RX>oa/K6`ko4a<C3Ol30`<5ooooo`koU9BD3_l=3@d>obTY
:@goTY:B1_ooool=o`@410ko?Shn3_m:BTX=oeiNGPKooooo3_l0000=oa4A4@ko?Cdm3OlU9BD6oooo
oaco4A4A3Ol61PH=o`L71`Kooooo3_mXJ6P>oa<C4`ko:BTY3?lQ8B46ooooo`ko;2`/3_lD51@>oaHF
5Pgo410@1Oooool>oa/K6`ko00003_lG5aL=obDU9@gooooo000;ooooo`ko:RXZ3_lK6a/>oa<C4`go
0`<31Oooool>oiBDU0ko3@d=3_lY:BT=oi:BTPKooooo3Ol410@>ochn?PkoBTY:3OmNGUh6ooooo`ko
00003OlA4A4>ocdm?@go9BDU1_oooolLoa4A4@go1PH63Ol71`L6ooooo`koJ6QX3_lC4a<>obTY:@co
8B4Q1_ooool>ob`/;0ko51@D3_lF5QH=oa0@40Gooooo3_lK6a/>o`0000ko5aLG3OlU9BD=ooooo`00
2oooool>obXZ:Pko6a/K3_lC4a<=o`<30`Gooooo3_nDU9@>o`d=3@ko:BTY3OnBTY86ooooo`go10@4
3_ln?Sh>odY:BPgoGUiN1_ooool>o`0000go4A4A3_lm?Cd=obDU9@Kooooo7?lA4A4=o`H61Pgo1`L7
1_ooool>ofQXJ0ko4a<C3_lY:BT<ob4Q8@Kooooo3_l/;2`>oa@D50ko5QHF3Ol@4105ooooo`ko6a/K
3_l0000>oaLG5`go9BDU3Oooool000_ooooo3_lZ:RX>oa/K6`ko4a<C3Ol30`<5ooooo`koU9BD3_l=
3@d>obTY:@goTY:B1_ooool=o`@410ko?Shn3_m:BTX=oeiNGPKooooo3_l0000=oa4A4@ko?Cdm3OlU
9BD6oooooaco4A4A3Ol61PH=o`L71`Kooooo3_mXJ6P>oa<C4`ko:BTY3?lQ8B46ooooo`ko;2`/3_lD
51@>oaHF5Pgo410@1Oooool>oa/K6`ko00003_lG5aL=obDU9@gooooo000;ooooo`ko:RXZ3_lK6a/>
oa<C4`go0`<31Oooool>oiBDU0ko3@d=3_lY:BT=oi:BTPKooooo3Ol410@>ochn?PkoBTY:3OmNGUh6
ooooo`ko00003OlA4A4>ocdm?@go9BDU1_oooolLoa4A4@go1PH63Ol71`L6ooooo`koJ6QX3_lC4a<>
obTY:@co8B4Q1_ooool>ob`/;0ko51@D3_lF5QH=oa0@40Gooooo3_lK6a/>o`0000ko5aLG3OlU9BD=
ooooo`002oooool>obXZ:Pko6a/K3_lC4a<=o`<30`Gooooo3_nDU9@>o`d=3@ko:BTY3OnBTY86oooo
o`go10@43_ln?Sh>odY:BPgoGUiN1_ooool>o`0000go4A4A3_lm?Cd=obDU9@Kooooo7?lA4A4=o`H6
1Pgo1`L71_ooool>ofQXJ0ko4a<C3_lY:BT<ob4Q8@Kooooo3_l/;2`>oa@D50ko5QHF3Ol@4105oooo
o`ko6a/K3_l0000>oaLG5`go9BDU3Oooool000_ooooo3_lZ:RX>oa/K6`ko4a<C3Ol30`<5ooooo`ko
U9BD3_l=3@d>obTY:@goTY:B1_ooool=o`@410ko?Shn3_m:BTX=oeiNGPKooooo3_l0000=oa4A4@ko
?Cdm3OlU9BD6oooooaco4A4A3Ol61PH=o`L71`Kooooo3_mXJ6P>oa<C4`ko:BTY3?lQ8B46ooooo`ko
;2`/3_lD51@>oaHF5Pgo410@1Oooool>oa/K6`ko00003_lG5aL=obDU9@gooooo000;ooooo`ko:RXZ
3_lK6a/>oa<C4`go0`<31Oooool>oiBDU0ko3@d=3_lY:BT=oi:BTPKooooo3Ol410@>ochn?PkoBTY:
3OmNGUh6ooooo`ko00003OlA4A4>ocdm?@go9BDU1_oooolLoa4A4@go1PH63Ol71`L6ooooo`koJ6QX
3_lC4a<>obTY:@co8B4Q1_ooool>ob`/;0ko51@D3_lF5QH=oa0@40Gooooo3_lK6a/>o`0000ko5aLG
3OlU9BD=ooooo`002oooool>obXZ:Pko6a/K3_lC4a<=o`<30`Gooooo3_nDU9@>o`d=3@ko:BTY3OnB
TY86ooooo`go10@43_ln?Sh>odY:BPgoGUiN1_ooool>o`0000go4A4A3_lm?Cd=obDU9@Kooooo7?lA
4A4=o`H61Pgo1`L71_ooool>ofQXJ0ko4a<C3_lY:BT<ob4Q8@Kooooo3_l/;2`>oa@D50ko5QHF3Ol@
4105ooooo`ko6a/K3_l0000>oaLG5`go9BDU3Oooool000_ooooo3_lZ:RX>oa/K6`ko4a<C3Ol30`<5
ooooo`koU9BD3_l=3@d>obTY:@goTY:B1_ooool=o`@410ko?Shn3_m:BTX=oeiNGPKooooo3_l0000=
oa4A4@ko?Cdm3OlU9BD6oooooaco4A4A3Ol61PH=o`L71`Kooooo3_mXJ6P>oa<C4`ko:BTY3?lQ8B46
ooooo`ko;2`/3_lD51@>oaHF5Pgo410@1Oooool>oa/K6`ko00003_lG5aL=obDU9@gooooo000Ioooo
o`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Coooo
o`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMg
M`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L
70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko
>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Ko
oooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko
00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A
1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE
3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW
1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln
?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_oo
ool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0
000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=
oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>
ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6
ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Ioooo
o`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Coooo
o`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMg
M`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L
70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko
>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Ko
oooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko
00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A
1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE
3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW
1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln
?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_oo
ool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0
000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=
oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>
ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6
ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L70gooooo000Ioooo
o`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko>c/k3_n2PX8Coooo
o`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMg
M`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko00003_l410@=oa`L
70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A1_ooool=ob@T90ko
>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE3Ol;2`/=o`0000Ko
oooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW1Oooool>obd];@ko
00003_l410@=oa`L70gooooo000Iooooo`ko?clo3_l=3@d=oaLG5a?ooooo3_ln?Sh>o`X:2PgoTI6A
1_ooool=ob@T90ko>c/k3_n2PX8Cooooo`ko1PH63OlS8b<>ooooo`go30`<1_ooool>o`D51@ko5ADE
3Ol;2`/=o`0000Kooooo3_nRXZ8>ogMgM`ko00003?l92@T6ooooo`ko3@d=3_l0000>oc@d=0go9bLW
1Oooool>obd];@ko00003_l410@=oa`L70gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l9
2@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj
>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le
=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=
o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>
obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>
om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;oooo
o`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C
4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6oooo
o`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<3
0`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`go
M7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go
=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko
7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF
3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo
3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo
3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l9
2@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj
>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le
=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=
o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>
obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>
om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;oooo
o`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C
4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6oooo
o`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<3
0`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`go
M7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go
=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko
7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF
3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo
3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo
3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=o`d=3@Gooooo3_l9
2@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>obDU9@go410@3_lj
>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>om7AdA;ooooo3_le
=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;ooooo`ko410@7?lB4Q8=
o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C4`go00001_ooool>
obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6ooooo`ko820P3_ld=3@>
om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<30`gooooo000;oooo
o`ko410@7?lB4Q8=o`d=3@Gooooo3_l92@T>oemOG`koEUIF3Old=3@6ooooo`goM7Ad3_m1@D4>oa<C
4`go00001_ooool>obDU9@go410@3_lj>SX=oc<c<`Kooooo3_l0000>ooooo`go=SHf3OlY:BT6oooo
o`ko820P3_ld=3@>om7AdA;ooooo3_le=CD>o`X:2Pkooooo3Ola<C4Cooooo`ko7alO3_lI6AT=o`<3
0`gooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Ooo
ool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>
3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/
;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>
oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6
ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<
o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;oooo
o`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm
?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf
=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ
:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Ko
oooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go
>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko
;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R
3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo
3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c
3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Ooo
ool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>
3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/
;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>
oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6
ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<
o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;oooo
o`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm
?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf
=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ
:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Ko
oooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go
>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko
;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R
3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo
3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c
3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>oa4A4@go4Q8B1Ooo
ool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6ooooo`ko2@T93Ol>
3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/
;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;ooooo`ko;Rh^3_l10@4>
oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm?@kooooo3Oll?3`6
ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf=Pko>c/k3_lW9bL<
o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ:Pgooooo000;oooo
o`ko;Rh^3_l10@4>oa4A4@go4Q8B1Oooool>o`X:2Pko8R8R3_l61PH=oa@D50Kooooo3OlH61P>ocdm
?@kooooo3Oll?3`6ooooo`ko2@T93Ol>3PhKo`X:2PKooooo3_lY:BT>oadM7@go>3Ph4oooool>ocHf
=Pko>c/k3_lW9bL<o`h>3PKooooo3_l/;2`>ooooo`kolo?c3OlY:BTCooooo`ko;Rh^3_lE5AD=obXZ
:Pgooooo000;ooooo`ko9BDU3_lE5AD>o`0000go5ADE4oooool>obTY:@ko7alO3Ol00006ooooo`go
71`L3_lI6AT>okZj^Pgo=SHf1_ooool>oa0@40gooooo3_lV9RH=o`d=3@Kooooo3_l0000>oaPH60go
20P83Olj>SX6ooooo`ko;Bd]3_lU9BD>oe1@D0co00001_ooool>o`0000koHF5Q3_o=cLd=oclo?`Go
oooo3_mCDe<>ob@T90ko3Ph>3OlY:BT=ooooo`002oooool>obDU9@ko5ADE3_l0000=oaDE5A?ooooo
3_lY:BT>oalO7`go00001_ooool=oa`L70ko6ATI3_nj^[X=ocHf=PKooooo3_l@410=ooooo`ko9RHV
3Ol=3@d6ooooo`ko00003_lH61P=o`P820go>SXj1_ooool>obd];@ko9BDU3_m@D50<o`0000Kooooo
3_l0000>of5QH@kocLg=3Olo?cl5ooooo`koDe=C3_lT92@>o`h>3Pgo:BTY3Oooool000_ooooo3_lU
9BD>oaDE5@ko00003OlE5ADCooooo`ko:BTY3_lO7al=o`0000Kooooo3OlL71`>oaTI6@ko^[Zj3Olf
=SH6ooooo`ko410@3Oooool>obHV9Pgo3@d=1_ooool>o`0000ko61PH3Ol820P=ocXj>PKooooo3_l]
;Bd>obDU9@koD51@3?l00006ooooo`ko00003_mQHF4>olg=c@go?clo1Oooool>oe=CD`ko92@T3_l>
3Ph=obTY:@gooooo000;ooooo`ko9BDU3_lE5AD>o`0000go5ADE4oooool>obTY:@ko7alO3Ol00006
ooooo`go71`L3_lI6AT>okZj^Pgo=SHf1_ooool>oa0@40gooooo3_lV9RH=o`d=3@Kooooo3_l0000>
oaPH60go20P83Olj>SX6ooooo`ko;Bd]3_lU9BD>oe1@D0co00001_ooool>o`0000koHF5Q3_o=cLd=
oclo?`Gooooo3_mCDe<>ob@T90ko3Ph>3OlY:BT=ooooo`002oooool>obDU9@ko5ADE3_l0000=oaDE
5A?ooooo3_lY:BT>oalO7`go00001_ooool=oa`L70ko6ATI3_nj^[X=ocHf=PKooooo3_l@410=oooo
o`ko9RHV3Ol=3@d6ooooo`ko00003_lH61P=o`P820go>SXj1_ooool>obd];@ko9BDU3_m@D50<o`00
00Kooooo3_l0000>of5QH@kocLg=3Olo?cl5ooooo`koDe=C3_lT92@>o`h>3Pgo:BTY3Oooool000_o
oooo3_lU9BD>oaDE5@ko00003OlE5ADCooooo`ko:BTY3_lO7al=o`0000Kooooo3OlL71`>oaTI6@ko
^[Zj3Olf=SH6ooooo`ko410@3Oooool>obHV9Pgo3@d=1_ooool>o`0000ko61PH3Ol820P=ocXj>PKo
oooo3_l];Bd>obDU9@koD51@3?l00006ooooo`ko00003_mQHF4>olg=c@go?clo1Oooool>oe=CD`ko
92@T3_l>3Ph=obTY:@gooooo000;ooooo`ko9BDU3_lE5AD>o`0000go5ADE4oooool>obTY:@ko7alO
3Ol00006ooooo`go71`L3_lI6AT>okZj^Pgo=SHf1_ooool>oa0@40gooooo3_lV9RH=o`d=3@Kooooo
3_l0000>oaPH60go20P83Olj>SX6ooooo`ko;Bd]3_lU9BD>oe1@D0co00001_ooool>o`0000koHF5Q
3_o=cLd=oclo?`Gooooo3_mCDe<>ob@T90ko3Ph>3OlY:BT=ooooo`002oooool>obDU9@ko5ADE3_l0
000=oaDE5A?ooooo3_lY:BT>oalO7`go00001_ooool=oa`L70ko6ATI3_nj^[X=ocHf=PKooooo3_l@
410=ooooo`ko9RHV3Ol=3@d6ooooo`ko00003_lH61P=o`P820go>SXj1_ooool>obd];@ko9BDU3_m@
D50<o`0000Kooooo3_l0000>of5QH@kocLg=3Olo?cl5ooooo`koDe=C3_lT92@>o`h>3Pgo:BTY3Ooo
ool000_ooooo3_lU9BD>oaDE5@ko00003OlE5ADCooooo`ko:BTY3_lO7al=o`0000Kooooo3OlL71`>
oaTI6@ko^[Zj3Olf=SH6ooooo`ko410@3Oooool>obHV9Pgo3@d=1_ooool>o`0000ko61PH3Ol820P=
ocXj>PKooooo3_l];Bd>obDU9@koD51@3?l00006ooooo`ko00003_mQHF4>olg=c@go?clo1Oooool>
oe=CD`ko92@T3_l>3Ph=obTY:@gooooo000;ooooo`ko9BDU3_lE5AD>o`0000go5ADE4oooool>obTY
:@ko7alO3Ol00006ooooo`go71`L3_lI6AT>okZj^Pgo=SHf1_ooool>oa0@40gooooo3_lV9RH=o`d=
3@Kooooo3_l0000>oaPH60go20P83Olj>SX6ooooo`ko;Bd]3_lU9BD>oe1@D0co00001_ooool>o`00
00koHF5Q3_o=cLd=oclo?`Gooooo3_mCDe<>ob@T90ko3Ph>3OlY:BT=ooooo`002oooool>obDU9@ko
5ADE3_l0000=oaDE5A?ooooo3_lY:BT>oalO7`go00001_ooool=oa`L70ko6ATI3_nj^[X=ocHf=PKo
oooo3_l@410=ooooo`ko9RHV3Ol=3@d6ooooo`ko00003_lH61P=o`P820go>SXj1_ooool>obd];@ko
9BDU3_m@D50<o`0000Kooooo3_l0000>of5QH@kocLg=3Olo?cl5ooooo`koDe=C3_lT92@>o`h>3Pgo
:BTY3Oooool000_ooooo3_lU9BD>oaDE5@ko00003OlE5ADCooooo`ko:BTY3_lO7al=o`0000Kooooo
3OlL71`>oaTI6@ko^[Zj3Olf=SH6ooooo`ko410@3Oooool>obHV9Pgo3@d=1_ooool>o`0000ko61PH
3Ol820P=ocXj>PKooooo3_l];Bd>obDU9@koD51@3?l00006ooooo`ko00003_mQHF4>olg=c@go?clo
1Oooool>oe=CD`ko92@T3_l>3Ph=obTY:@gooooo000;ooooo`ko9BDU3_lE5AD>o`0000go5ADE4ooo
ool>obTY:@ko7alO3Ol00006ooooo`go71`L3_lI6AT>okZj^Pgo=SHf1_ooool>oa0@40gooooo3_lV
9RH=o`d=3@Kooooo3_l0000>oaPH60go20P83Olj>SX6ooooo`ko;Bd]3_lU9BD>oe1@D0co00001_oo
ool>o`0000koHF5Q3_o=cLd=oclo?`Gooooo3_mCDe<>ob@T90ko3Ph>3OlY:BT=ooooo`002oooool>
obDU9@ko5ADE3_l0000=oaDE5A?ooooo3_lY:BT>oalO7`go00001_ooool=oa`L70ko6ATI3_nj^[X=
ocHf=PKooooo3_l@410=ooooo`ko9RHV3Ol=3@d6ooooo`ko00003_lH61P=o`P820go>SXj1_ooool>
obd];@ko9BDU3_m@D50<o`0000Kooooo3_l0000>of5QH@kocLg=3Olo?cl5ooooo`koDe=C3_lT92@>
o`h>3Pgo:BTY3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`82
0Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6oooo
o`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>
3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko
3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKo
oooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko
4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go
;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P8
1_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH
3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI
3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol7
1`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>
3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll
?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Ooo
ool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=
obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=
o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5
ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5oooo
o`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;
2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=
C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_o
oooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko
30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go
410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`ko
B4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@4
3_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko0000
3OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo
3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX
:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mE
EED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_oo
ool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD
51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>
o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6
ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>
o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN
7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV
9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c
<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`00
00go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo
20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko
61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3Pko
VIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]3Oooool000_ooooo3_lX:2P>oahN7Pko3`l?
3Ol71`L5ooooo`ko10@43_l30`<>o`820Pgo20P81_ooool=obLW9`ko30`<3_mEEED=obHV9PKooooo
3_l>3Ph=o`/;2`ko00003OlS8b<6ooooo`ko61PH3_lB4Q8=o`<30`go410@1_ooool>oc<c<`ko4a<C
3_ll?3`<ode=C@Kooooo3_li>CT>o`h>3PkoVIVI3On<S8`5ooooo`koB4Q83_lD51@>o`0000go;Bd]
3Oooool001Wooooo3_lB4Q8>ocTi>@go<30`1Oooool>o`X:2Pko8R8R3_l;2`/=ob8R8PKooooo3Ol0
000>ocTi>@koADE53OlY:BT6ooooo`ko3`l?3Ol=3@d>ocTi>@go9RHV1_ooool>ob4Q8@ko5QHF3Ole
=CD=ob4Q8@Kooooo3_lk>c/>oeADE0ko5ADE4_ooool>ojZZZPkono_k3_o^k^h=oaLG5`Gooooo3_lZ
:RX>obTY:@ko5QHF3OmQHF4=ooooo`006Oooool>oa8B4Pko>CTi3Ol`<305ooooo`ko2PX:3_lR8R8>
o`/;2`go8R8R1_ooool=o`0000ko>CTi3_m5ADD=obTY:@Kooooo3_l?3`l=o`d=3@ko>CTi3OlV9RH6
ooooo`ko8B4Q3_lF5QH=ocDe=@go8B4Q1_ooool>oc/k>`koE5AD3_lE5ADBooooo`koZZZZ3_okno/>
onk^kPgo5aLG1Oooool>obXZ:Pko:BTY3_lF5QH=of5QH@gooooo000Iooooo`ko4Q8B3_li>CT=oc0`
<0Gooooo3_l:2PX>ob8R8Pko2`/;3OlR8R86ooooo`go00003_li>CT>odE5A@go:BTY1_ooool>o`l?
3`go3@d=3_li>CT=obHV9PKooooo3_lQ8B4>oaHF5Pgo=CDe3OlQ8B46ooooo`ko>c/k3_mDE5@>oaDE
5A;ooooo3_nZZZX>oo_kn`kok^k^3OlG5aL5ooooo`ko:RXZ3_lY:BT>oaHF5PgoHF5Q3Oooool001Wo
oooo3_lB4Q8>ocTi>@go<30`1Oooool>o`X:2Pko8R8R3_l;2`/=ob8R8PKooooo3Ol0000>ocTi>@ko
ADE53OlY:BT6ooooo`ko3`l?3Ol=3@d>ocTi>@go9RHV1_ooool>ob4Q8@ko5QHF3Ole=CD=ob4Q8@Ko
oooo3_lk>c/>oeADE0ko5ADE4_ooool>ojZZZPkono_k3_o^k^h=oaLG5`Gooooo3_lZ:RX>obTY:@ko
5QHF3OmQHF4=ooooo`006Oooool>oa8B4Pko>CTi3Ol`<305ooooo`ko2PX:3_lR8R8>o`/;2`go8R8R
1_ooool=o`0000ko>CTi3_m5ADD=obTY:@Kooooo3_l?3`l=o`d=3@ko>CTi3OlV9RH6ooooo`ko8B4Q
3_lF5QH=ocDe=@go8B4Q1_ooool>oc/k>`koE5AD3_lE5ADBooooo`koZZZZ3_okno/>onk^kPgo5aLG
1Oooool>obXZ:Pko:BTY3_lF5QH=of5QH@gooooo000Iooooo`ko4Q8B3_li>CT=oc0`<0Gooooo3_l:
2PX>ob8R8Pko2`/;3OlR8R86ooooo`go00003_li>CT>odE5A@go:BTY1_ooool>o`l?3`go3@d=3_li
>CT=obHV9PKooooo3_lQ8B4>oaHF5Pgo=CDe3OlQ8B46ooooo`ko>c/k3_mDE5@>oaDE5A;ooooo3_nZ
ZZX>oo_kn`kok^k^3OlG5aL5ooooo`ko:RXZ3_lY:BT>oaHF5PgoHF5Q3Oooool001Wooooo3_lB4Q8>
ocTi>@go<30`1Oooool>o`X:2Pko8R8R3_l;2`/=ob8R8PKooooo3Ol0000>ocTi>@koADE53OlY:BT6
ooooo`ko3`l?3Ol=3@d>ocTi>@go9RHV1_ooool>ob4Q8@ko5QHF3Ole=CD=ob4Q8@Kooooo3_lk>c/>
oeADE0ko5ADE4_ooool>ojZZZPkono_k3_o^k^h=oaLG5`Gooooo3_lZ:RX>obTY:@ko5QHF3OmQHF4=
ooooo`006Oooool>oa8B4Pko>CTi3Ol`<305ooooo`ko2PX:3_lR8R8>o`/;2`go8R8R1_ooool=o`00
00ko>CTi3_m5ADD=obTY:@Kooooo3_l?3`l=o`d=3@ko>CTi3OlV9RH6ooooo`ko8B4Q3_lF5QH=ocDe
=@go8B4Q1_ooool>oc/k>`koE5AD3_lE5ADBooooo`koZZZZ3_okno/>onk^kPgo5aLG1Oooool>obXZ
:Pko:BTY3_lF5QH=of5QH@gooooo000Iooooo`ko4Q8B3_li>CT=oc0`<0Gooooo3_l:2PX>ob8R8Pko
2`/;3OlR8R86ooooo`go00003_li>CT>odE5A@go:BTY1_ooool>o`l?3`go3@d=3_li>CT=obHV9PKo
oooo3_lQ8B4>oaHF5Pgo=CDe3OlQ8B46ooooo`ko>c/k3_mDE5@>oaDE5A;ooooo3_nZZZX>oo_kn`ko
k^k^3OlG5aL5ooooo`ko:RXZ3_lY:BT>oaHF5PgoHF5Q3Oooool001Wooooo3_lB4Q8>ocTi>@go<30`
1Oooool>o`X:2Pko8R8R3_l;2`/=ob8R8PKooooo3Ol0000>ocTi>@koADE53OlY:BT6ooooo`ko3`l?
3Ol=3@d>ocTi>@go9RHV1_ooool>ob4Q8@ko5QHF3Ole=CD=ob4Q8@Kooooo3_lk>c/>oeADE0ko5ADE
4_ooool>ojZZZPkono_k3_o^k^h=oaLG5`Gooooo3_lZ:RX>obTY:@ko5QHF3OmQHF4=ooooo`006Ooo
ool>oa8B4Pko>CTi3Ol`<305ooooo`ko2PX:3_lR8R8>o`/;2`go8R8R1_ooool=o`0000ko>CTi3_m5
ADD=obTY:@Kooooo3_l?3`l=o`d=3@ko>CTi3OlV9RH6ooooo`ko8B4Q3_lF5QH=ocDe=@go8B4Q1_oo
ool>oc/k>`koE5AD3_lE5ADBooooo`koZZZZ3_okno/>onk^kPgo5aLG1Oooool>obXZ:Pko:BTY3_lF
5QH=of5QH@gooooo000Iooooo`ko4Q8B3_li>CT=oc0`<0Gooooo3_l:2PX>ob8R8Pko2`/;3OlR8R86
ooooo`go00003_li>CT>odE5A@go:BTY1_ooool>o`l?3`go3@d=3_li>CT=obHV9PKooooo3_lQ8B4>
oaHF5Pgo=CDe3OlQ8B46ooooo`ko>c/k3_mDE5@>oaDE5A;ooooo3_nZZZX>oo_kn`kok^k^3OlG5aL5
ooooo`ko:RXZ3_lY:BT>oaHF5PgoHF5Q3Oooool001Wooooo3_lB4Q8>ocTi>@go<30`1Oooool>o`X:
2Pko8R8R3_l;2`/=ob8R8PKooooo3Ol0000>ocTi>@koADE53OlY:BT6ooooo`ko3`l?3Ol=3@d>ocTi
>@go9RHV1_ooool>ob4Q8@ko5QHF3Ole=CD=ob4Q8@Kooooo3_lk>c/>oeADE0ko5ADE4_ooool>ojZZ
ZPkono_k3_o^k^h=oaLG5`Gooooo3_lZ:RX>obTY:@ko5QHF3OmQHF4=ooooo`006Oooool>oa8B4Pko
>CTi3Ol`<305ooooo`ko2PX:3_lR8R8>o`/;2`go8R8R1_ooool=o`0000ko>CTi3_m5ADD=obTY:@Ko
oooo3_l?3`l=o`d=3@ko>CTi3OlV9RH6ooooo`ko8B4Q3_lF5QH=ocDe=@go8B4Q1_ooool>oc/k>`ko
E5AD3_lE5ADBooooo`koZZZZ3_okno/>onk^kPgo5aLG1Oooool>obXZ:Pko:BTY3_lF5QH=of5QH@go
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo000;ooooo`ko:2PX3_l0000>of][J`goLW9b1Oooool>ob0P80ko6a/K3_l4
10@=o`<30`Kooooo3Olf=SH>o`0000ko820P3OlX:2P6ooooo`ko8b<S3OlM7Ad>oc/k>`go3@d=1_oo
ool>oa8B4Pko820P3Ol=3@d=o`@410Kooooo3_l51@D>o`L71`ko30`<3?lO7al6ooooo`ko20P83_l2
0P8>obh^;Pgo00004oooool>oahN7Pko7AdM3Om9BDT=ooooo`002oooool>obPX:0ko00003_m[Jf/=
og9bLPGooooo3_lP820>oa/K6`ko10@43Ol30`<6ooooo`go=SHf3_l0000>ob0P80go:2PX1_ooool>
ob<S8`go7AdM3_lk>c/=o`d=3@Kooooo3_lB4Q8>ob0P80go3@d=3Ol410@6ooooo`ko1@D53_l71`L>
o``<30co7alO1_ooool>o`P820ko0P823_l^;Rh=o`0001?ooooo3_lN7Qh>oadM7@goBDU93Oooool0
00_ooooo3_lX:2P>o`0000koJf][3OmbLW85ooooo`ko820P3_lK6a/>o`@410go0`<31_ooool=ocHf
=Pko00003_lP820=obPX:0Kooooo3_lS8b<=oadM7@ko>c/k3Ol=3@d6ooooo`ko4Q8B3_lP820=o`d=
3@go10@41_ooool>o`D51@ko1`L73_l<30`<oalO7`Kooooo3_l820P>o`820Pko;Rh^3Ol0000Coooo
o`ko7QhN3_lM7Ad=odU9B@gooooo000;ooooo`ko:2PX3_l0000>of][J`goLW9b1Oooool>ob0P80ko
6a/K3_l410@=o`<30`Kooooo3Olf=SH>o`0000ko820P3OlX:2P6ooooo`ko8b<S3OlM7Ad>oc/k>`go
3@d=1_ooool>oa8B4Pko820P3Ol=3@d=o`@410Kooooo3_l51@D>o`L71`ko30`<3?lO7al6ooooo`ko
20P83_l20P8>obh^;Pgo00004oooool>oahN7Pko7AdM3Om9BDT=ooooo`002oooool>obPX:0ko0000
3_m[Jf/=og9bLPGooooo3_lP820>oa/K6`ko10@43Ol30`<6ooooo`go=SHf3_l0000>ob0P80go:2PX
1_ooool>ob<S8`go7AdM3_lk>c/=o`d=3@Kooooo3_lB4Q8>ob0P80go3@d=3Ol410@6ooooo`ko1@D5
3_l71`L>o``<30co7alO1_ooool>o`P820ko0P823_l^;Rh=o`0001?ooooo3_lN7Qh>oadM7@goBDU9
3Oooool000_ooooo3_lX:2P>o`0000koJf][3OmbLW85ooooo`ko820P3_lK6a/>o`@410go0`<31_oo
ool=ocHf=Pko00003_lP820=obPX:0Kooooo3_lS8b<=oadM7@ko>c/k3Ol=3@d6ooooo`ko4Q8B3_lP
820=o`d=3@go10@41_ooool>o`D51@ko1`L73_l<30`<oalO7`Kooooo3_l820P>o`820Pko;Rh^3Ol0
000Cooooo`ko7QhN3_lM7Ad=odU9B@gooooo000;ooooo`ko:2PX3_l0000>of][J`goLW9b1Oooool>
ob0P80ko6a/K3_l410@=o`<30`Kooooo3Olf=SH>o`0000ko820P3OlX:2P6ooooo`ko8b<S3OlM7Ad>
oc/k>`go3@d=1_ooool>oa8B4Pko820P3Ol=3@d=o`@410Kooooo3_l51@D>o`L71`ko30`<3?lO7al6
ooooo`ko20P83_l20P8>obh^;Pgo00004oooool>oahN7Pko7AdM3Om9BDT=ooooo`002oooool>obPX
:0ko00003_m[Jf/=og9bLPGooooo3_lP820>oa/K6`ko10@43Ol30`<6ooooo`go=SHf3_l0000>ob0P
80go:2PX1_ooool>ob<S8`go7AdM3_lk>c/=o`d=3@Kooooo3_lB4Q8>ob0P80go3@d=3Ol410@6oooo
o`ko1@D53_l71`L>o``<30co7alO1_ooool>o`P820ko0P823_l^;Rh=o`0001?ooooo3_lN7Qh>oadM
7@goBDU93Oooool000_ooooo3_lX:2P>o`0000koJf][3OmbLW85ooooo`ko820P3_lK6a/>o`@410go
0`<31_ooool=ocHf=Pko00003_lP820=obPX:0Kooooo3_lS8b<=oadM7@ko>c/k3Ol=3@d6ooooo`ko
4Q8B3_lP820=o`d=3@go10@41_ooool>o`D51@ko1`L73_l<30`<oalO7`Kooooo3_l820P>o`820Pko
;Rh^3Ol0000Cooooo`ko7QhN3_lM7Ad=odU9B@gooooo000;ooooo`ko:2PX3_l0000>of][J`goLW9b
1Oooool>ob0P80ko6a/K3_l410@=o`<30`Kooooo3Olf=SH>o`0000ko820P3OlX:2P6ooooo`ko8b<S
3OlM7Ad>oc/k>`go3@d=1_ooool>oa8B4Pko820P3Ol=3@d=o`@410Kooooo3_l51@D>o`L71`ko30`<
3?lO7al6ooooo`ko20P83_l20P8>obh^;Pgo00004oooool>oahN7Pko7AdM3Om9BDT=ooooo`002ooo
ool>obPX:0ko00003_m[Jf/=og9bLPGooooo3_lP820>oa/K6`ko10@43Ol30`<6ooooo`go=SHf3_l0
000>ob0P80go:2PX1_ooool>ob<S8`go7AdM3_lk>c/=o`d=3@Kooooo3_lB4Q8>ob0P80go3@d=3Ol4
10@6ooooo`ko1@D53_l71`L>o``<30co7alO1_ooool>o`P820ko0P823_l^;Rh=o`0001?ooooo3_lN
7Qh>oadM7@goBDU93Oooool000_ooooo3_lX:2P>o`0000koJf][3OmbLW85ooooo`ko820P3_lK6a/>
o`@410go0`<31_ooool=ocHf=Pko00003_lP820=obPX:0Kooooo3_lS8b<=oadM7@ko>c/k3Ol=3@d6
ooooo`ko4Q8B3_lP820=o`d=3@go10@41_ooool>o`D51@ko1`L73_l<30`<oalO7`Kooooo3_l820P>
o`820Pko;Rh^3Ol0000Cooooo`ko7QhN3_lM7Ad=odU9B@gooooo000;ooooo`ko:2PX3_l0000>of][
J`goLW9b1Oooool>ob0P80ko6a/K3_l410@=o`<30`Kooooo3Olf=SH>o`0000ko820P3OlX:2P6oooo
o`ko8b<S3OlM7Ad>oc/k>`go3@d=1_ooool>oa8B4Pko820P3Ol=3@d=o`@410Kooooo3_l51@D>o`L7
1`ko30`<3?lO7al6ooooo`ko20P83_l20P8>obh^;Pgo00004oooool>oahN7Pko7AdM3Om9BDT=oooo
o`002oooool>o`h>3Pko>c/k3_le=CD=oiJFUPGooooo3_le=CD>oaTI6@ko1@D53Ol00006ooooo`go
:2PX3_l;2`/>o`h>3Q?ooooo3_lG5aL=oeQHF0ko6a/K3Ol00006ooooo`ko2`/;3_m1@D4=oa8B4Pgo
7AdM1_ooool>oa8B4Pko3`l?3_l71`L<obl_;`Kooooo3_l:2PX>oaDE5@ko3`l?3Ol61PH5ooooo`ko
EeMG3_lA4A4>o`0000go2`/;3Oooool000_ooooo3_l>3Ph>oc/k>`ko=CDe3OnFUYH5ooooo`ko=CDe
3_lI6AT>o`D51@go00001_ooool=obPX:0ko2`/;3_l>3PhCooooo`ko5aLG3OmHF5P>oa/K6`go0000
1_ooool>o`/;2`ko@D513OlB4Q8=oadM7@Kooooo3_lB4Q8>o`l?3`ko1`L73?l_;bl6ooooo`ko2PX:
3_lE5AD>o`l?3`go1PH61Oooool>oeMGE`ko4A4A3_l0000=o`/;2`gooooo000;ooooo`ko3Ph>3_lk
>c/>ocDe=@goUYJF1Oooool>ocDe=@ko6ATI3_l51@D=o`0000Kooooo3OlX:2P>o`/;2`ko3Ph>4ooo
ool>oaLG5`goF5QH3_lK6a/=o`0000Kooooo3_l;2`/>od51@@go4Q8B3OlM7Ad6ooooo`ko4Q8B3_l?
3`l>o`L71`co;bl_1_ooool>o`X:2Pko5ADE3_l?3`l=o`H61PGooooo3_mGEeL>oa4A4@ko00003Ol;
2`/=ooooo`002oooool>o`h>3Pko>c/k3_le=CD=oiJFUPGooooo3_le=CD>oaTI6@ko1@D53Ol00006
ooooo`go:2PX3_l;2`/>o`h>3Q?ooooo3_lG5aL=oeQHF0ko6a/K3Ol00006ooooo`ko2`/;3_m1@D4=
oa8B4Pgo7AdM1_ooool>oa8B4Pko3`l?3_l71`L<obl_;`Kooooo3_l:2PX>oaDE5@ko3`l?3Ol61PH5
ooooo`koEeMG3_lA4A4>o`0000go2`/;3Oooool000_ooooo3_l>3Ph>oc/k>`ko=CDe3OnFUYH5oooo
o`ko=CDe3_lI6AT>o`D51@go00001_ooool=obPX:0ko2`/;3_l>3PhCooooo`ko5aLG3OmHF5P>oa/K
6`go00001_ooool>o`/;2`ko@D513OlB4Q8=oadM7@Kooooo3_lB4Q8>o`l?3`ko1`L73?l_;bl6oooo
o`ko2PX:3_lE5AD>o`l?3`go1PH61Oooool>oeMGE`ko4A4A3_l0000=o`/;2`gooooo000;ooooo`ko
3Ph>3_lk>c/>ocDe=@goUYJF1Oooool>ocDe=@ko6ATI3_l51@D=o`0000Kooooo3OlX:2P>o`/;2`ko
3Ph>4oooool>oaLG5`goF5QH3_lK6a/=o`0000Kooooo3_l;2`/>od51@@go4Q8B3OlM7Ad6ooooo`ko
4Q8B3_l?3`l>o`L71`co;bl_1_ooool>o`X:2Pko5ADE3_l?3`l=o`H61PGooooo3_mGEeL>oa4A4@ko
00003Ol;2`/=ooooo`002oooool>o`h>3Pko>c/k3_le=CD=oiJFUPGooooo3_le=CD>oaTI6@ko1@D5
3Ol00006ooooo`go:2PX3_l;2`/>o`h>3Q?ooooo3_lG5aL=oeQHF0ko6a/K3Ol00006ooooo`ko2`/;
3_m1@D4=oa8B4Pgo7AdM1_ooool>oa8B4Pko3`l?3_l71`L<obl_;`Kooooo3_l:2PX>oaDE5@ko3`l?
3Ol61PH5ooooo`koEeMG3_lA4A4>o`0000go2`/;3Oooool000_ooooo3_l>3Ph>oc/k>`ko=CDe3OnF
UYH5ooooo`ko=CDe3_lI6AT>o`D51@go00001_ooool=obPX:0ko2`/;3_l>3PhCooooo`ko5aLG3OmH
F5P>oa/K6`go00001_ooool>o`/;2`ko@D513OlB4Q8=oadM7@Kooooo3_lB4Q8>o`l?3`ko1`L73?l_
;bl6ooooo`ko2PX:3_lE5AD>o`l?3`go1PH61Oooool>oeMGE`ko4A4A3_l0000=o`/;2`gooooo000;
ooooo`ko3Ph>3_lk>c/>ocDe=@goUYJF1Oooool>ocDe=@ko6ATI3_l51@D=o`0000Kooooo3OlX:2P>
o`/;2`ko3Ph>4oooool>oaLG5`goF5QH3_lK6a/=o`0000Kooooo3_l;2`/>od51@@go4Q8B3OlM7Ad6
ooooo`ko4Q8B3_l?3`l>o`L71`co;bl_1_ooool>o`X:2Pko5ADE3_l?3`l=o`H61PGooooo3_mGEeL>
oa4A4@ko00003Ol;2`/=ooooo`002oooool>o`h>3Pko>c/k3_le=CD=oiJFUPGooooo3_le=CD>oaTI
6@ko1@D53Ol00006ooooo`go:2PX3_l;2`/>o`h>3Q?ooooo3_lG5aL=oeQHF0ko6a/K3Ol00006oooo
o`ko2`/;3_m1@D4=oa8B4Pgo7AdM1_ooool>oa8B4Pko3`l?3_l71`L<obl_;`Kooooo3_l:2PX>oaDE
5@ko3`l?3Ol61PH5ooooo`koEeMG3_lA4A4>o`0000go2`/;3Oooool000_ooooo3_l>3Ph>oc/k>`ko
=CDe3OnFUYH5ooooo`ko=CDe3_lI6AT>o`D51@go00001_ooool=obPX:0ko2`/;3_l>3PhCooooo`ko
5aLG3OmHF5P>oa/K6`go00001_ooool>o`/;2`ko@D513OlB4Q8=oadM7@Kooooo3_lB4Q8>o`l?3`ko
1`L73?l_;bl6ooooo`ko2PX:3_lE5AD>o`l?3`go1PH61Oooool>oeMGE`ko4A4A3_l0000=o`/;2`go
oooo000;ooooo`ko3Ph>3_lk>c/>ocDe=@goUYJF1Oooool>ocDe=@ko6ATI3_l51@D=o`0000Kooooo
3OlX:2P>o`/;2`ko3Ph>4oooool>oaLG5`goF5QH3_lK6a/=o`0000Kooooo3_l;2`/>od51@@go4Q8B
3OlM7Ad6ooooo`ko4Q8B3_l?3`l>o`L71`co;bl_1_ooool>o`X:2Pko5ADE3_l?3`l=o`H61PGooooo
3_mGEeL>oa4A4@ko00003Ol;2`/=ooooo`002oooool>o`h>3Pko>c/k3_le=CD=oiJFUPGooooo3_le
=CD>oaTI6@ko1@D53Ol00006ooooo`go:2PX3_l;2`/>o`h>3Q?ooooo3_lG5aL=oeQHF0ko6a/K3Ol0
0006ooooo`ko2`/;3_m1@D4=oa8B4Pgo7AdM1_ooool>oa8B4Pko3`l?3_l71`L<obl_;`Kooooo3_l:
2PX>oaDE5@ko3`l?3Ol61PH5ooooo`koEeMG3_lA4A4>o`0000go2`/;3Oooool000_ooooo3_l>3Ph>
oc/k>`ko=CDe3OnFUYH5ooooo`ko=CDe3_lI6AT>o`D51@go00001_ooool=obPX:0ko2`/;3_l>3PhC
ooooo`ko5aLG3OmHF5P>oa/K6`go00001_ooool>o`/;2`ko@D513OlB4Q8=oadM7@Kooooo3_lB4Q8>
o`l?3`ko1`L73?l_;bl6ooooo`ko2PX:3_lE5AD>o`l?3`go1PH61Oooool>oeMGE`ko4A4A3_l0000=
o`/;2`gooooo000;ooooo`ko4a<C3_n3Ph<>ofIVIPgo`l?34oooool>ofQXJ0ko2PX:3Ol<30`6oooo
o`go00003_lP820>o`P820go@T921_ooool>o`D51@gooooo3_m4A4@=ocHf=PKooooo3_l0000>od=3
@`go2@T93OlC4a<6ooooo`ko3Ph>3_lP820>o`0000co5ADE1_ooool>o`X:2Pko30`<3_lH61P=o`82
0PGooooo3_ln?Sh>oahN7Pko5ADE3Ol>3Ph=ooooo`002oooool>oa<C4`koPh>33_mVIVH=ol?3`a?o
oooo3_mXJ6P>o`X:2Pgo30`<1_ooool=o`0000ko820P3_l820P=od92@PKooooo3_l51@D=ooooo`ko
A4A43Olf=SH6ooooo`ko00003_m3@d<=o`T92@go4a<C1_ooool>o`h>3Pko820P3_l0000<oaDE5@Ko
oooo3_l:2PX>o``<30ko61PH3Ol20P85ooooo`ko?Shn3_lN7Qh>oaDE5@go3Ph>3Oooool000_ooooo
3_lC4a<>oh>3P`koIVIV3Oo3`l<Cooooo`koJ6QX3_l:2PX=o``<30Kooooo3Ol0000>ob0P80ko20P8
3Om2@T86ooooo`ko1@D53Oooool>odA4A0go=SHf1_ooool>o`0000ko@d=33Ol92@T=oa<C4`Kooooo
3_l>3Ph>ob0P80ko00003?lE5AD6ooooo`ko2PX:3_l<30`>oaPH60go0P821Oooool>ochn?Pko7QhN
3_lE5AD=o`h>3Pgooooo000;ooooo`ko4a<C3_n3Ph<>ofIVIPgo`l?34oooool>ofQXJ0ko2PX:3Ol<
30`6ooooo`go00003_lP820>o`P820go@T921_ooool>o`D51@gooooo3_m4A4@=ocHf=PKooooo3_l0
000>od=3@`go2@T93OlC4a<6ooooo`ko3Ph>3_lP820>o`0000co5ADE1_ooool>o`X:2Pko30`<3_lH
61P=o`820PGooooo3_ln?Sh>oahN7Pko5ADE3Ol>3Ph=ooooo`002oooool>oa<C4`koPh>33_mVIVH=
ol?3`a?ooooo3_mXJ6P>o`X:2Pgo30`<1_ooool=o`0000ko820P3_l820P=od92@PKooooo3_l51@D=
ooooo`koA4A43Olf=SH6ooooo`ko00003_m3@d<=o`T92@go4a<C1_ooool>o`h>3Pko820P3_l0000<
oaDE5@Kooooo3_l:2PX>o``<30ko61PH3Ol20P85ooooo`ko?Shn3_lN7Qh>oaDE5@go3Ph>3Oooool0
00_ooooo3_lC4a<>oh>3P`koIVIV3Oo3`l<Cooooo`koJ6QX3_l:2PX=o``<30Kooooo3Ol0000>ob0P
80ko20P83Om2@T86ooooo`ko1@D53Oooool>odA4A0go=SHf1_ooool>o`0000ko@d=33Ol92@T=oa<C
4`Kooooo3_l>3Ph>ob0P80ko00003?lE5AD6ooooo`ko2PX:3_l<30`>oaPH60go0P821Oooool>ochn
?Pko7QhN3_lE5AD=o`h>3Pgooooo000;ooooo`ko4a<C3_n3Ph<>ofIVIPgo`l?34oooool>ofQXJ0ko
2PX:3Ol<30`6ooooo`go00003_lP820>o`P820go@T921_ooool>o`D51@gooooo3_m4A4@=ocHf=PKo
oooo3_l0000>od=3@`go2@T93OlC4a<6ooooo`ko3Ph>3_lP820>o`0000co5ADE1_ooool>o`X:2Pko
30`<3_lH61P=o`820PGooooo3_ln?Sh>oahN7Pko5ADE3Ol>3Ph=ooooo`002oooool>oa<C4`koPh>3
3_mVIVH=ol?3`a?ooooo3_mXJ6P>o`X:2Pgo30`<1_ooool=o`0000ko820P3_l820P=od92@PKooooo
3_l51@D=ooooo`koA4A43Olf=SH6ooooo`ko00003_m3@d<=o`T92@go4a<C1_ooool>o`h>3Pko820P
3_l0000<oaDE5@Kooooo3_l:2PX>o``<30ko61PH3Ol20P85ooooo`ko?Shn3_lN7Qh>oaDE5@go3Ph>
3Oooool000_ooooo3_lC4a<>oh>3P`koIVIV3Oo3`l<Cooooo`koJ6QX3_l:2PX=o``<30Kooooo3Ol0
000>ob0P80ko20P83Om2@T86ooooo`ko1@D53Oooool>odA4A0go=SHf1_ooool>o`0000ko@d=33Ol9
2@T=oa<C4`Kooooo3_l>3Ph>ob0P80ko00003?lE5AD6ooooo`ko2PX:3_l<30`>oaPH60go0P821Ooo
ool>ochn?Pko7QhN3_lE5AD=o`h>3Pgooooo000;ooooo`ko4a<C3_n3Ph<>ofIVIPgo`l?34oooool>
ofQXJ0ko2PX:3Ol<30`6ooooo`go00003_lP820>o`P820go@T921_ooool>o`D51@gooooo3_m4A4@=
ocHf=PKooooo3_l0000>od=3@`go2@T93OlC4a<6ooooo`ko3Ph>3_lP820>o`0000co5ADE1_ooool>
o`X:2Pko30`<3_lH61P=o`820PGooooo3_ln?Sh>oahN7Pko5ADE3Ol>3Ph=ooooo`002oooool>oa<C
4`koPh>33_mVIVH=ol?3`a?ooooo3_mXJ6P>o`X:2Pgo30`<1_ooool=o`0000ko820P3_l820P=od92
@PKooooo3_l51@D=ooooo`koA4A43Olf=SH6ooooo`ko00003_m3@d<=o`T92@go4a<C1_ooool>o`h>
3Pko820P3_l0000<oaDE5@Kooooo3_l:2PX>o``<30ko61PH3Ol20P85ooooo`ko?Shn3_lN7Qh>oaDE
5@go3Ph>3Oooool000_ooooo3_lC4a<>oh>3P`koIVIV3Oo3`l<Cooooo`koJ6QX3_l:2PX=o``<30Ko
oooo3Ol0000>ob0P80ko20P83Om2@T86ooooo`ko1@D53Oooool>odA4A0go=SHf1_ooool>o`0000ko
@d=33Ol92@T=oa<C4`Kooooo3_l>3Ph>ob0P80ko00003?lE5AD6ooooo`ko2PX:3_l<30`>oaPH60go
0P821Oooool>ochn?Pko7QhN3_lE5AD=o`h>3Pgooooo000;ooooo`ko4a<C3_n3Ph<>ofIVIPgo`l?3
4oooool>ofQXJ0ko2PX:3Ol<30`6ooooo`go00003_lP820>o`P820go@T921_ooool>o`D51@gooooo
3_m4A4@=ocHf=PKooooo3_l0000>od=3@`go2@T93OlC4a<6ooooo`ko3Ph>3_lP820>o`0000co5ADE
1_ooool>o`X:2Pko30`<3_lH61P=o`820PGooooo3_ln?Sh>oahN7Pko5ADE3Ol>3Ph=ooooo`002ooo
ool>oaDE5@koJFUY3_ooool=ojZZZPGooooo3_l0000>o`L71`ko3@d=3OlK6a/6ooooo`go20P83_l>
3Ph>obLW9`go71`L1_ooool>od=3@`go2`/;3_lW9bL=oaLG5`Kooooo3_lN7Qh>ooooo`go9RHV3OlO
7al6ooooo`ko30`<3_l92@T>ob`/;1;ooooo3_lN7Qh>o`H61Pkooooo3OlK6a/5ooooo`koR8R83_lE
5AD>oahN7PgoA4A43Oooool000_ooooo3_lE5AD>ofUYJ@kooooo3OnZZZX5ooooo`ko00003_l71`L>
o`d=3@go6a/K1_ooool=o`P820ko3Ph>3_lW9bL=oa`L70Kooooo3_m3@d<=o`/;2`ko9bLW3OlG5aL6
ooooo`ko7QhN3_ooool=obHV9Pgo7alO1_ooool>o``<30ko2@T93_l/;2`Booooo`ko7QhN3_l61PH>
ooooo`go6a/K1Oooool>ohR8R0ko5ADE3_lN7Qh=odA4A0gooooo000;ooooo`ko5ADE3_mYJFT>oooo
o`goZZZZ1Oooool>o`0000ko1`L73_l=3@d=oa/K6`Kooooo3Ol820P>o`h>3Pko9bLW3OlL71`6oooo
o`ko@d=33Ol;2`/>obLW9`go5aLG1_ooool>oahN7Pkooooo3OlV9RH=oalO7`Kooooo3_l<30`>o`T9
2@ko;2`/4_ooool>oahN7Pko1PH63_ooool=oa/K6`Gooooo3_n8R8P>oaDE5@ko7QhN3Om4A4@=oooo
o`002oooool>oaDE5@koJFUY3_ooool=ojZZZPGooooo3_l0000>o`L71`ko3@d=3OlK6a/6ooooo`go
20P83_l>3Ph>obLW9`go71`L1_ooool>od=3@`go2`/;3_lW9bL=oaLG5`Kooooo3_lN7Qh>ooooo`go
9RHV3OlO7al6ooooo`ko30`<3_l92@T>ob`/;1;ooooo3_lN7Qh>o`H61Pkooooo3OlK6a/5ooooo`ko
R8R83_lE5AD>oahN7PgoA4A43Oooool000_ooooo3_lE5AD>ofUYJ@kooooo3OnZZZX5ooooo`ko0000
3_l71`L>o`d=3@go6a/K1_ooool=o`P820ko3Ph>3_lW9bL=oa`L70Kooooo3_m3@d<=o`/;2`ko9bLW
3OlG5aL6ooooo`ko7QhN3_ooool=obHV9Pgo7alO1_ooool>o``<30ko2@T93_l/;2`Booooo`ko7QhN
3_l61PH>ooooo`go6a/K1Oooool>ohR8R0ko5ADE3_lN7Qh=odA4A0gooooo000;ooooo`ko5ADE3_mY
JFT>ooooo`goZZZZ1Oooool>o`0000ko1`L73_l=3@d=oa/K6`Kooooo3Ol820P>o`h>3Pko9bLW3OlL
71`6ooooo`ko@d=33Ol;2`/>obLW9`go5aLG1_ooool>oahN7Pkooooo3OlV9RH=oalO7`Kooooo3_l<
30`>o`T92@ko;2`/4_ooool>oahN7Pko1PH63_ooool=oa/K6`Gooooo3_n8R8P>oaDE5@ko7QhN3Om4
A4@=ooooo`002oooool>oaDE5@koJFUY3_ooool=ojZZZPGooooo3_l0000>o`L71`ko3@d=3OlK6a/6
ooooo`go20P83_l>3Ph>obLW9`go71`L1_ooool>od=3@`go2`/;3_lW9bL=oaLG5`Kooooo3_lN7Qh>
ooooo`go9RHV3OlO7al6ooooo`ko30`<3_l92@T>ob`/;1;ooooo3_lN7Qh>o`H61Pkooooo3OlK6a/5
ooooo`koR8R83_lE5AD>oahN7PgoA4A43Oooool000_ooooo3_lE5AD>ofUYJ@kooooo3OnZZZX5oooo
o`ko00003_l71`L>o`d=3@go6a/K1_ooool=o`P820ko3Ph>3_lW9bL=oa`L70Kooooo3_m3@d<=o`/;
2`ko9bLW3OlG5aL6ooooo`ko7QhN3_ooool=obHV9Pgo7alO1_ooool>o``<30ko2@T93_l/;2`Boooo
o`ko7QhN3_l61PH>ooooo`go6a/K1Oooool>ohR8R0ko5ADE3_lN7Qh=odA4A0gooooo000;ooooo`ko
5ADE3_mYJFT>ooooo`goZZZZ1Oooool>o`0000ko1`L73_l=3@d=oa/K6`Kooooo3Ol820P>o`h>3Pko
9bLW3OlL71`6ooooo`ko@d=33Ol;2`/>obLW9`go5aLG1_ooool>oahN7Pkooooo3OlV9RH=oalO7`Ko
oooo3_l<30`>o`T92@ko;2`/4_ooool>oahN7Pko1PH63_ooool=oa/K6`Gooooo3_n8R8P>oaDE5@ko
7QhN3Om4A4@=ooooo`002oooool>oaDE5@koJFUY3_ooool=ojZZZPGooooo3_l0000>o`L71`ko3@d=
3OlK6a/6ooooo`go20P83_l>3Ph>obLW9`go71`L1_ooool>od=3@`go2`/;3_lW9bL=oaLG5`Kooooo
3_lN7Qh>ooooo`go9RHV3OlO7al6ooooo`ko30`<3_l92@T>ob`/;1;ooooo3_lN7Qh>o`H61Pkooooo
3OlK6a/5ooooo`koR8R83_lE5AD>oahN7PgoA4A43Oooool000_ooooo3_lE5AD>ofUYJ@kooooo3OnZ
ZZX5ooooo`ko00003_l71`L>o`d=3@go6a/K1_ooool=o`P820ko3Ph>3_lW9bL=oa`L70Kooooo3_m3
@d<=o`/;2`ko9bLW3OlG5aL6ooooo`ko7QhN3_ooool=obHV9Pgo7alO1_ooool>o``<30ko2@T93_l/
;2`Booooo`ko7QhN3_l61PH>ooooo`go6a/K1Oooool>ohR8R0ko5ADE3_lN7Qh=odA4A0gooooo000;
ooooo`ko5ADE3_mYJFT>ooooo`goZZZZ1Oooool>o`0000ko1`L73_l=3@d=oa/K6`Kooooo3Ol820P>
o`h>3Pko9bLW3OlL71`6ooooo`ko@d=33Ol;2`/>obLW9`go5aLG1_ooool>oahN7Pkooooo3OlV9RH=
oalO7`Kooooo3_l<30`>o`T92@ko;2`/4_ooool>oahN7Pko1PH63_ooool=oa/K6`Gooooo3_n8R8P>
oaDE5@ko7QhN3Om4A4@=ooooo`002oooool>oaDE5@koJFUY3_ooool=ojZZZPGooooo3_l0000>o`L7
1`ko3@d=3OlK6a/6ooooo`go20P83_l>3Ph>obLW9`go71`L1_ooool>od=3@`go2`/;3_lW9bL=oaLG
5`Kooooo3_lN7Qh>ooooo`go9RHV3OlO7al6ooooo`ko30`<3_l92@T>ob`/;1;ooooo3_lN7Qh>o`H6
1Pkooooo3OlK6a/5ooooo`koR8R83_lE5AD>oahN7PgoA4A43Oooool000_ooooo3_lE5AD>ofUYJ@ko
oooo3OnZZZX5ooooo`ko00003_l71`L>o`d=3@go6a/K1_ooool=o`P820ko3Ph>3_lW9bL=oa`L70Ko
oooo3_m3@d<=o`/;2`ko9bLW3OlG5aL6ooooo`ko7QhN3_ooool=obHV9Pgo7alO1_ooool>o``<30ko
2@T93_l/;2`Booooo`ko7QhN3_l61PH>ooooo`go6a/K1Oooool>ohR8R0ko5ADE3_lN7Qh=odA4A0go
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-0.200041, -0.200041, 0.0168338, \
0.0168338}, {{11.875, 66.5}, {487.062, 432.438}} -> {-0.869594, -0.874171, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {487.062, 432.438}} -> {-5.26781, \
-0.874171, 0.0732273, 0.0732273}, {{132, 186.625}, {487.062, 432.438}} -> \
{-9.66602, -0.874171, 0.0732273, 0.0732273}, {{192.125, 246.75}, {487.062, \
432.438}} -> {-14.0688, -0.874171, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {487.062, 432.438}} -> {-18.467, -0.874171, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {487.062, 432.438}} -> {-22.8698, -0.874171, 0.0732273, \
0.0732273}, {{372.375, 427}, {487.062, 432.438}} -> {-27.268, -0.874171, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {487.062, 432.438}} -> {-31.6662, \
-0.874171, 0.0732273, 0.0732273}, {{11.875, 66.5}, {427, 372.375}} -> \
{-0.869594, -5.27238, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {427, \
372.375}} -> {-5.26781, -5.27238, 0.0732273, 0.0732273}, {{132, 186.625}, \
{427, 372.375}} -> {-9.66602, -5.27238, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {427, 372.375}} -> {-14.0688, -5.27238, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {427, 372.375}} -> {-18.467, -5.27238, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {427, 372.375}} -> {-22.8698, -5.27238, \
0.0732273, 0.0732273}, {{372.375, 427}, {427, 372.375}} -> {-27.268, \
-5.27238, 0.0732273, 0.0732273}, {{432.438, 487.062}, {427, 372.375}} -> \
{-31.6662, -5.27238, 0.0732273, 0.0732273}, {{11.875, 66.5}, {366.938, \
312.312}} -> {-0.869594, -9.6706, 0.0732273, 0.0732273}, {{71.9375, 126.562}, \
{366.938, 312.312}} -> {-5.26781, -9.6706, 0.0732273, 0.0732273}, {{132, \
186.625}, {366.938, 312.312}} -> {-9.66602, -9.6706, 0.0732273, 0.0732273}, \
{{192.125, 246.75}, {366.938, 312.312}} -> {-14.0688, -9.6706, 0.0732273, \
0.0732273}, {{252.188, 306.812}, {366.938, 312.312}} -> {-18.467, -9.6706, \
0.0732273, 0.0732273}, {{312.312, 366.938}, {366.938, 312.312}} -> {-22.8698, \
-9.6706, 0.0732273, 0.0732273}, {{372.375, 427}, {366.938, 312.312}} -> \
{-27.268, -9.6706, 0.0732273, 0.0732273}, {{432.438, 487.062}, {366.938, \
312.312}} -> {-31.6662, -9.6706, 0.0732273, 0.0732273}, {{11.875, 66.5}, \
{306.812, 252.188}} -> {-0.869594, -14.0734, 0.0732273, 0.0732273}, \
{{71.9375, 126.562}, {306.812, 252.188}} -> {-5.26781, -14.0734, 0.0732273, \
0.0732273}, {{132, 186.625}, {306.812, 252.188}} -> {-9.66602, -14.0734, \
0.0732273, 0.0732273}, {{192.125, 246.75}, {306.812, 252.188}} -> {-14.0688, \
-14.0734, 0.0732273, 0.0732273}, {{252.188, 306.812}, {306.812, 252.188}} -> \
{-18.467, -14.0734, 0.0732273, 0.0732273}, {{312.312, 366.938}, {306.812, \
252.188}} -> {-22.8698, -14.0734, 0.0732273, 0.0732273}, {{372.375, 427}, \
{306.812, 252.188}} -> {-27.268, -14.0734, 0.0732273, 0.0732273}, {{432.438, \
487.062}, {306.812, 252.188}} -> {-31.6662, -14.0734, 0.0732273, 0.0732273}, \
{{11.875, 66.5}, {246.75, 192.125}} -> {-0.869594, -18.4716, 0.0732273, \
0.0732273}, {{71.9375, 126.562}, {246.75, 192.125}} -> {-5.26781, -18.4716, \
0.0732273, 0.0732273}, {{132, 186.625}, {246.75, 192.125}} -> {-9.66602, \
-18.4716, 0.0732273, 0.0732273}, {{192.125, 246.75}, {246.75, 192.125}} -> \
{-14.0688, -18.4716, 0.0732273, 0.0732273}, {{252.188, 306.812}, {246.75, \
192.125}} -> {-18.467, -18.4716, 0.0732273, 0.0732273}, {{312.312, 366.938}, \
{246.75, 192.125}} -> {-22.8698, -18.4716, 0.0732273, 0.0732273}, {{372.375, \
427}, {246.75, 192.125}} -> {-27.268, -18.4716, 0.0732273, 0.0732273}, \
{{432.438, 487.062}, {246.75, 192.125}} -> {-31.6662, -18.4716, 0.0732273, \
0.0732273}, {{11.875, 66.5}, {186.625, 132}} -> {-0.869594, -22.8744, \
0.0732273, 0.0732273}, {{71.9375, 126.562}, {186.625, 132}} -> {-5.26781, \
-22.8744, 0.0732273, 0.0732273}, {{132, 186.625}, {186.625, 132}} -> \
{-9.66602, -22.8744, 0.0732273, 0.0732273}, {{192.125, 246.75}, {186.625, \
132}} -> {-14.0688, -22.8744, 0.0732273, 0.0732273}, {{252.188, 306.812}, \
{186.625, 132}} -> {-18.467, -22.8744, 0.0732273, 0.0732273}, {{312.312, \
366.938}, {186.625, 132}} -> {-22.8698, -22.8744, 0.0732273, 0.0732273}, \
{{372.375, 427}, {186.625, 132}} -> {-27.268, -22.8744, 0.0732273, \
0.0732273}, {{432.438, 487.062}, {186.625, 132}} -> {-31.6662, -22.8744, \
0.0732273, 0.0732273}, {{11.875, 66.5}, {126.562, 71.9375}} -> {-0.869594, \
-27.2726, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {126.562, 71.9375}} -> \
{-5.26781, -27.2726, 0.0732273, 0.0732273}, {{132, 186.625}, {126.562, \
71.9375}} -> {-9.66602, -27.2726, 0.0732273, 0.0732273}, {{192.125, 246.75}, \
{126.562, 71.9375}} -> {-14.0688, -27.2726, 0.0732273, 0.0732273}, {{252.188, \
306.812}, {126.562, 71.9375}} -> {-18.467, -27.2726, 0.0732273, 0.0732273}, \
{{312.312, 366.938}, {126.562, 71.9375}} -> {-22.8698, -27.2726, 0.0732273, \
0.0732273}, {{372.375, 427}, {126.562, 71.9375}} -> {-27.268, -27.2726, \
0.0732273, 0.0732273}, {{432.438, 487.062}, {126.562, 71.9375}} -> {-31.6662, \
-27.2726, 0.0732273, 0.0732273}, {{11.875, 66.5}, {66.5, 11.875}} -> \
{-0.869594, -31.6708, 0.0732273, 0.0732273}, {{71.9375, 126.562}, {66.5, \
11.875}} -> {-5.26781, -31.6708, 0.0732273, 0.0732273}, {{132, 186.625}, \
{66.5, 11.875}} -> {-9.66602, -31.6708, 0.0732273, 0.0732273}, {{192.125, \
246.75}, {66.5, 11.875}} -> {-14.0688, -31.6708, 0.0732273, 0.0732273}, \
{{252.188, 306.812}, {66.5, 11.875}} -> {-18.467, -31.6708, 0.0732273, \
0.0732273}, {{312.312, 366.938}, {66.5, 11.875}} -> {-22.8698, -31.6708, \
0.0732273, 0.0732273}, {{372.375, 427}, {66.5, 11.875}} -> {-27.268, \
-31.6708, 0.0732273, 0.0732273}, {{432.438, 487.062}, {66.5, 11.875}} -> \
{-31.6662, -31.6708, 0.0732273, 0.0732273}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize histograms", "Subsection"],

Cell["\<\
The graphics below illustrate the histogram over the VQ codebooks \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(colors = {Red, Green, Blue, Orange};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(BarChart[Sequence\  @@ \ #, BarStyle \[Rule] colors, 
            BarEdgeStyle \[Rule] colors, Frame \[Rule] True, 
            ImageSize \[Rule] 500] &\)\  /@ \ hist;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 2.77179 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1533 -24 -4.5 ]
[-0.0125 .1533 0 4.5 ]
[-0.0125 .29189 -18 -4.5 ]
[-0.0125 .29189 0 4.5 ]
[-0.0125 .43048 -24 -4.5 ]
[-0.0125 .43048 0 4.5 ]
[-0.0125 .56907 -18 -4.5 ]
[-0.0125 .56907 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1533 m
.00625 .1533 L
s
[(0.05)] -0.0125 .1533 1 0 Mshowa
0 .29189 m
.00625 .29189 L
s
[(0.1)] -0.0125 .29189 1 0 Mshowa
0 .43048 m
.00625 .43048 L
s
[(0.15)] -0.0125 .43048 1 0 Mshowa
0 .56907 m
.00625 .56907 L
s
[(0.2)] -0.0125 .56907 1 0 Mshowa
.125 Mabswid
0 .04243 m
.00375 .04243 L
s
0 .07015 m
.00375 .07015 L
s
0 .09787 m
.00375 .09787 L
s
0 .12559 m
.00375 .12559 L
s
0 .18102 m
.00375 .18102 L
s
0 .20874 m
.00375 .20874 L
s
0 .23646 m
.00375 .23646 L
s
0 .26418 m
.00375 .26418 L
s
0 .31961 m
.00375 .31961 L
s
0 .34733 m
.00375 .34733 L
s
0 .37505 m
.00375 .37505 L
s
0 .40277 m
.00375 .40277 L
s
0 .4582 m
.00375 .4582 L
s
0 .48592 m
.00375 .48592 L
s
0 .51364 m
.00375 .51364 L
s
0 .54135 m
.00375 .54135 L
s
0 .59679 m
.00375 .59679 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1533 m
1 .1533 L
s
.99375 .29189 m
1 .29189 L
s
.99375 .43048 m
1 .43048 L
s
.99375 .56907 m
1 .56907 L
s
.125 Mabswid
.99625 .04243 m
1 .04243 L
s
.99625 .07015 m
1 .07015 L
s
.99625 .09787 m
1 .09787 L
s
.99625 .12559 m
1 .12559 L
s
.99625 .18102 m
1 .18102 L
s
.99625 .20874 m
1 .20874 L
s
.99625 .23646 m
1 .23646 L
s
.99625 .26418 m
1 .26418 L
s
.99625 .31961 m
1 .31961 L
s
.99625 .34733 m
1 .34733 L
s
.99625 .37505 m
1 .37505 L
s
.99625 .40277 m
1 .40277 L
s
.99625 .4582 m
1 .4582 L
s
.99625 .48592 m
1 .48592 L
s
.99625 .51364 m
1 .51364 L
s
.99625 .54135 m
1 .54135 L
s
.99625 .59679 m
1 .59679 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .01666 L
.02181 .01666 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .01666 L
.02181 .01666 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .08768 L
.03738 .08768 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .08768 L
.03738 .08768 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .11395 L
.05296 .11395 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .11395 L
.05296 .11395 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
F
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .11882 L
.09969 .11882 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .11882 L
.09969 .11882 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .10811 L
.11526 .10811 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .10811 L
.11526 .10811 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .09936 L
.14642 .09936 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .09936 L
.14642 .09936 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .01569 L
.16199 .01569 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .01569 L
.16199 .01569 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .10617 L
.17757 .10617 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .10617 L
.17757 .10617 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .01472 L
.19315 .01472 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .01472 L
.19315 .01472 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .01472 L
.20872 .01472 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .01472 L
.20872 .01472 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .09936 L
.2243 .09936 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .09936 L
.2243 .09936 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .09255 L
.23988 .09255 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .09255 L
.23988 .09255 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .01472 L
.25545 .01472 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .01472 L
.25545 .01472 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .01472 L
.27103 .01472 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .01472 L
.27103 .01472 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .08574 L
.2866 .08574 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .08574 L
.2866 .08574 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .13633 L
.30218 .13633 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .13633 L
.30218 .13633 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .01472 L
.31776 .01472 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .01472 L
.31776 .01472 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .01569 L
.33333 .01569 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .01569 L
.33333 .01569 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .11395 L
.34891 .11395 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .11395 L
.34891 .11395 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .11006 L
.36449 .11006 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .11006 L
.36449 .11006 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .01569 L
.38006 .01569 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .01569 L
.38006 .01569 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .01569 L
.39564 .01569 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .01569 L
.39564 .01569 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .1159 L
.41121 .1159 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .1159 L
.41121 .1159 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .11103 L
.42679 .11103 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .11103 L
.42679 .11103 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .01472 L
.44237 .01472 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .01472 L
.44237 .01472 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .09838 L
.47352 .09838 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .09838 L
.47352 .09838 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .1013 L
.4891 .1013 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .1013 L
.4891 .1013 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .01472 L
.52025 .01472 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .01472 L
.52025 .01472 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .08963 L
.53583 .08963 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .08963 L
.53583 .08963 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .12368 L
.5514 .12368 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .12368 L
.5514 .12368 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .01763 L
.56698 .01763 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .01763 L
.56698 .01763 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .01472 L
.58255 .01472 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .01472 L
.58255 .01472 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .1159 L
.59813 .1159 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .1159 L
.59813 .1159 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .08768 L
.61371 .08768 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .08768 L
.61371 .08768 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .01472 L
.62928 .01472 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .01472 L
.62928 .01472 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .09644 L
.64486 .09644 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .09644 L
.64486 .09644 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .01763 L
.66044 .01763 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .01763 L
.66044 .01763 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .10325 L
.67601 .10325 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .10325 L
.67601 .10325 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .01763 L
.69159 .01763 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .01763 L
.69159 .01763 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .1013 L
.72274 .1013 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .1013 L
.72274 .1013 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .09255 L
.73832 .09255 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .09255 L
.73832 .09255 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .01472 L
.75389 .01472 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .01472 L
.75389 .01472 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .01569 L
.76947 .01569 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .01569 L
.76947 .01569 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .09547 L
.78505 .09547 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .09547 L
.78505 .09547 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .01569 L
.80062 .01569 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .01569 L
.80062 .01569 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .01666 L
.8162 .01666 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .01666 L
.8162 .01666 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .09449 L
.84735 .09449 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .09449 L
.84735 .09449 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .09352 L
.86293 .09352 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .09352 L
.86293 .09352 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .03223 L
.8785 .03223 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .03223 L
.8785 .03223 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .11006 L
.90966 .11006 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .11006 L
.90966 .11006 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .08963 L
.92523 .08963 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .08963 L
.92523 .08963 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .1013 L
.97196 .1013 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .1013 L
.97196 .1013 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .09838 L
.98754 .09838 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .09838 L
.98754 .09838 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .04682 L
.02492 .04682 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .04682 L
.02492 .04682 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .01569 L
.0405 .01569 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .01569 L
.0405 .01569 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .01861 L
.05607 .01861 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .01861 L
.05607 .01861 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .21027 L
.07165 .21027 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .21027 L
.07165 .21027 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .02542 L
.08723 .02542 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .02542 L
.08723 .02542 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .01472 L
.1028 .01472 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .01472 L
.1028 .01472 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .01472 L
.11838 .01472 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .01472 L
.11838 .01472 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .26572 L
.13396 .26572 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .26572 L
.13396 .26572 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .01569 L
.14953 .01569 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .01569 L
.14953 .01569 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .01958 L
.16511 .01958 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .01958 L
.16511 .01958 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .01763 L
.18069 .01763 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .01763 L
.18069 .01763 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .05071 L
.19626 .05071 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .05071 L
.19626 .05071 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .02736 L
.21184 .02736 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .02736 L
.21184 .02736 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .01666 L
.24299 .01666 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .01666 L
.24299 .01666 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .19762 L
.25857 .19762 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .19762 L
.25857 .19762 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .01763 L
.27414 .01763 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .01763 L
.27414 .01763 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .01569 L
.28972 .01569 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .01569 L
.28972 .01569 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .01861 L
.3053 .01861 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .01861 L
.3053 .01861 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .20151 L
.32087 .20151 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .20151 L
.32087 .20151 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .02347 L
.33645 .02347 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .02347 L
.33645 .02347 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .02055 L
.35202 .02055 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .02055 L
.35202 .02055 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .17816 L
.38318 .17816 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .17816 L
.38318 .17816 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .02444 L
.41433 .02444 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .02444 L
.41433 .02444 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .01763 L
.42991 .01763 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .01763 L
.42991 .01763 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .02347 L
.44548 .02347 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .02347 L
.44548 .02347 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .01569 L
.46106 .01569 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .01569 L
.46106 .01569 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .01569 L
.47664 .01569 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .01569 L
.47664 .01569 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .20346 L
.50779 .20346 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .20346 L
.50779 .20346 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .01958 L
.52336 .01958 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .01958 L
.52336 .01958 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .01861 L
.53894 .01861 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .01861 L
.53894 .01861 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .01569 L
.55452 .01569 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .01569 L
.55452 .01569 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .19859 L
.57009 .19859 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .19859 L
.57009 .19859 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .22389 L
.6324 .22389 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .22389 L
.6324 .22389 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .02153 L
.66355 .02153 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .02153 L
.66355 .02153 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .01666 L
.6947 .01666 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .01666 L
.6947 .01666 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01861 L
.71028 .01861 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01861 L
.71028 .01861 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .14119 L
.75701 .14119 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .14119 L
.75701 .14119 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .02542 L
.80374 .02542 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .02542 L
.80374 .02542 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .1733 L
.81931 .1733 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .1733 L
.81931 .1733 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .01666 L
.85047 .01666 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .01666 L
.85047 .01666 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .1626 L
.88162 .1626 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .1626 L
.88162 .1626 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .01569 L
.94393 .01569 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .01569 L
.94393 .01569 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .54203 L
.01246 .54203 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .54203 L
.01246 .54203 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .04779 L
.02804 .04779 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .04779 L
.02804 .04779 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .01569 L
.04361 .01569 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .01569 L
.04361 .01569 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .01569 L
.05919 .01569 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .01569 L
.05919 .01569 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .22097 L
.07477 .22097 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .22097 L
.07477 .22097 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .02347 L
.09034 .02347 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .02347 L
.09034 .02347 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .01472 L
.1215 .01472 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .01472 L
.1215 .01472 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .27059 L
.13707 .27059 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .27059 L
.13707 .27059 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .01666 L
.16822 .01666 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .01666 L
.16822 .01666 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .01472 L
.1838 .01472 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .01472 L
.1838 .01472 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .02153 L
.19938 .02153 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .02153 L
.19938 .02153 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .02931 L
.21495 .02931 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .02931 L
.21495 .02931 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .01472 L
.23053 .01472 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .01472 L
.23053 .01472 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .27448 L
.26168 .27448 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .27448 L
.26168 .27448 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .01472 L
.29283 .01472 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .01472 L
.29283 .01472 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .01569 L
.30841 .01569 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .01569 L
.30841 .01569 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .20443 L
.32399 .20443 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .20443 L
.32399 .20443 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .01666 L
.33956 .01666 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .01666 L
.33956 .01666 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .17524 L
.38629 .17524 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .17524 L
.38629 .17524 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .01472 L
.4486 .01472 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .01472 L
.4486 .01472 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .35328 L
.5109 .35328 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .35328 L
.5109 .35328 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .01569 L
.52648 .01569 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .01569 L
.52648 .01569 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .01472 L
.54206 .01472 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .01472 L
.54206 .01472 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .16941 L
.57321 .16941 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .16941 L
.57321 .16941 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .15189 L
.63551 .15189 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .15189 L
.63551 .15189 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .01472 L
.69782 .01472 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .01472 L
.69782 .01472 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .29588 L
.76012 .29588 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .29588 L
.76012 .29588 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .01472 L
.79128 .01472 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .01472 L
.79128 .01472 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .15579 L
.82243 .15579 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .15579 L
.82243 .15579 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .06336 L
.88474 .06336 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .06336 L
.88474 .06336 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .01569 L
.01558 .01569 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .01569 L
.01558 .01569 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .10617 L
.03115 .10617 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .10617 L
.03115 .10617 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .01958 L
.04673 .01958 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .01958 L
.04673 .01958 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .02736 L
.06231 .02736 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .02736 L
.06231 .02736 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .01666 L
.07788 .01666 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .01666 L
.07788 .01666 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .11492 L
.09346 .11492 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .11492 L
.09346 .11492 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .02639 L
.10903 .02639 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .02639 L
.10903 .02639 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .04779 L
.12461 .04779 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .04779 L
.12461 .04779 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .01666 L
.14019 .01666 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .01666 L
.14019 .01666 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .04001 L
.15576 .04001 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .04001 L
.15576 .04001 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .15189 L
.17134 .15189 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .15189 L
.17134 .15189 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .02834 L
.18692 .02834 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .02834 L
.18692 .02834 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .16065 L
.20249 .16065 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .16065 L
.20249 .16065 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .12368 L
.21807 .12368 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .12368 L
.21807 .12368 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .02153 L
.23364 .02153 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .02153 L
.23364 .02153 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .02834 L
.24922 .02834 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .02834 L
.24922 .02834 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .01569 L
.2648 .01569 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .01569 L
.2648 .01569 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .1373 L
.28037 .1373 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .1373 L
.28037 .1373 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .0225 L
.29595 .0225 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .0225 L
.29595 .0225 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .04196 L
.31153 .04196 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .04196 L
.31153 .04196 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .01861 L
.3271 .01861 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .01861 L
.3271 .01861 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .14314 L
.34268 .14314 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .14314 L
.34268 .14314 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .04001 L
.35826 .04001 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .04001 L
.35826 .04001 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .02736 L
.37383 .02736 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .02736 L
.37383 .02736 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .02153 L
.38941 .02153 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .02153 L
.38941 .02153 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .09838 L
.40498 .09838 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .09838 L
.40498 .09838 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .03709 L
.42056 .03709 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .03709 L
.42056 .03709 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .03125 L
.43614 .03125 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .03125 L
.43614 .03125 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .1159 L
.45171 .1159 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .1159 L
.45171 .1159 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .11882 L
.46729 .11882 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .11882 L
.46729 .11882 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .02542 L
.48287 .02542 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .02542 L
.48287 .02542 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .01861 L
.49844 .01861 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .01861 L
.49844 .01861 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .01666 L
.51402 .01666 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .01666 L
.51402 .01666 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .12854 L
.5296 .12854 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .12854 L
.5296 .12854 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .0439 L
.54517 .0439 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .0439 L
.54517 .0439 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .03223 L
.56075 .03223 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .03223 L
.56075 .03223 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .02736 L
.57632 .02736 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .02736 L
.57632 .02736 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .12563 L
.5919 .12563 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .12563 L
.5919 .12563 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .01958 L
.60748 .01958 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .01958 L
.60748 .01958 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .02055 L
.62305 .02055 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .02055 L
.62305 .02055 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .03904 L
.63863 .03904 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .03904 L
.63863 .03904 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .03223 L
.65421 .03223 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .03223 L
.65421 .03223 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .1587 L
.66978 .1587 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .1587 L
.66978 .1587 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .0225 L
.68536 .0225 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .0225 L
.68536 .0225 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .12465 L
.70093 .12465 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .12465 L
.70093 .12465 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .11687 L
.71651 .11687 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .11687 L
.71651 .11687 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .02153 L
.73209 .02153 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .02153 L
.73209 .02153 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .02055 L
.74766 .02055 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .02055 L
.74766 .02055 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .02834 L
.76324 .02834 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .02834 L
.76324 .02834 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .13146 L
.77882 .13146 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .13146 L
.77882 .13146 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .02055 L
.79439 .02055 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .02055 L
.79439 .02055 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .11395 L
.80997 .11395 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .11395 L
.80997 .11395 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .03223 L
.82555 .03223 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .03223 L
.82555 .03223 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .09644 L
.84112 .09644 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .09644 L
.84112 .09644 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .02153 L
.8567 .02153 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .02153 L
.8567 .02153 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .02055 L
.87227 .02055 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .02055 L
.87227 .02055 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .05947 L
.88785 .05947 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .05947 L
.88785 .05947 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .10909 L
.90343 .10909 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .10909 L
.90343 .10909 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .02834 L
.919 .02834 L
.919 .01472 L
F
.91589 .01472 m
.91589 .02834 L
.919 .02834 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .01763 L
.93458 .01763 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .01763 L
.93458 .01763 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .10617 L
.95016 .10617 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .10617 L
.95016 .10617 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .08087 L
.96573 .08087 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .08087 L
.96573 .08087 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .01763 L
.98131 .01763 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .01763 L
.98131 .01763 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .01958 L
.99688 .01958 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .01958 L
.99688 .01958 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol0000;ooooo`00:Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000<ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000003?ooool002Sooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Uoooooooo0000aOl0000;ooooo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`007?ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o
0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_oo
O`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l0
0?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o
0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o
0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo
0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go
0000ool00?l0o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003o
o`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o
0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004
ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0
0?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`00
00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003o
oomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o
0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l0
0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo0003o`00
0?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
0_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0_ooO`000oooooooo`00ool00002ooooo`?o
ogl000Coo`00o`3o0?l0o`3o0?l00oooO`001?oooooo0?l0o`3o0?l00?l3oomo0004ooooool0o`3o
0?l0o`00o`?oogl00_oo0002ooooo`?oogl00_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o003o
0oooO`02ool000;ooooo0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00;oo`000_l0o`03oomo00;o
oooo00?o0?l0o`00ooooO`000_ooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?oooooo
ogl0oomo0?ooO`02ool000;o0?l00oooO`02ooooo`03o`3o0?l00?oo003o00Cooooo0_l0o`03oomo
00?oo`0000Cooooooomo0?ooO`3oogl00_oo0002o`3o0003ooooooooO`3oogl000;ooooo00?o0?l0
o`00ool00?l00_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl00_oo0002o`3o0003ooooooooO`3o
ogl000?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`05ooooo`;oogl00_oo0002
o`3o0005ooooooooO`3oogl0oooooooo00000_l0o`000oooooooogl0oomo0002ooooo`;o0?l000?o
oooooomo0?ooO`001Oooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`000oooooooo`00ool0
0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00;ooooo0_l0o`001Oooooooogl0oomo
0?ooooooo`0000;o0?l000Cooooooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000Goooooool00?l0
o`3o0?l0o`00o`02oomo00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool0
0?oo00000_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;ooooo0_ooO`00
0oooooooo`00o`3o0002o`3o00;oogl000?oooooool00?oo00000_ooool3oomo0004ool00?l0o`3o
0?l0o`3o00?oogl000Coooooo`3o0?l0o`3o0?l00oooO`02ool000;ooooo0oooO`02ool000;ooooo
0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00Cooooo0oooO`02ool000;ooooo0oooO`02ooooo`;o
0?l00oooO`02ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo00;oo`000_l0o`03oomo00?o
o`0000Cooooooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool0
0004ooooooooO`3oogl0oomo00?oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00ooo0002
ooooo`;oogl00ooo0002ooooo`;oogl000?o0000ooooooooool02Oooool001_ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`02o`3o00;o003o0oooool2o`3o0004o`00ooooO`3o
ogl0ooooo`;oo`000_ooool3oomo0004ool00?l0o`3o0?l0o`3o00?oogl000?oooooo`3o0?l0o`00
0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0002ooooo`?oogl00_oo0002ooooo`?o
ogl000?oooooo`3o0?l0o`000_l00?l2ooooo`;oo`000_ooool3oomo0004ooooool0o`3o0?l0o`3o
00?oogl00ooo00001?ooooooogl0oomo0?ooO`02ooooo`03o`3o0?l00?ooogl000;oogl00_ooool0
0ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo
0?ooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool00004ooooooooO`3oogl0oomo00;o
o`000_l0o`000oooooooogl0oomo0002ooooo`03o`3o0?l00?oo003o00;oogl00_ooool2o`3o0003
ooooooooO`3oogl000;oo`000_l0o`000oooooooogl0oomo0003ool000;ooooo0_ooO`02ooooo`03
o`3o0?l00?oo003o00;oogl01Oooool2oomo00;oo`000_l0o`001?ooooooogl0oomo0?ooool2ool0
00;ooooo0_ooO`02ooooo`;o0?l000?ooooooomo0?ooO`001Oooool2oomo0003oooooooo003oo`00
00;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool01?l0o`3o003oo`00ool00?l3
ooooo`;o0?l000Gooooooomo0?ooO`3oooooool00002o`3o0004ooooooooO`3oogl0ooooo`;oo`00
0_ooool2oomo00;ooooo0_l0o`000ol00?ooogl0oomo0005ooooo`;oogl000?oooooool00?oo0000
0_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3o
oooo0_oo0002ooooo`;oogl00_ooool3o`3o00;oogl000?oooooool00?oo00000_ooool3oomo00Co
oooo0oooO`001?oooooo0?l0o`3o0?l0o`03oomo00;oo`000_ooool3oomo00;oo`000_ooool3oomo
0004ooooool0o`3o0?l0o`00o`?oogl01?ooool3oomo00;oo`000_ooool3oomo00;ooooo0_l0o`03
oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo00001?ooooooogl0oomo0?oo
O`03ool00004ooooooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl0
0ooo00001?ooooooogl0oomo0?ooO`03ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?o
o`000_ooool2oomo0003o`000?oooooooooo00Wooooo000Looooo`;o00001oooool00ol0003ooooo
ooooo`02o`3o00;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000;o
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool0
00;ooooo0oooO`02ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`;ooooo0_oo0002oooo
o`?oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo0002
oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Co
oooooomo0?ooO`3oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo00001?ooooooogl0
oomo0?ooO`03ool000;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`?ooooo0_l0o`000ooo
ooooogl0oomo0003ool000;ooooo0_ooO`03ool000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o
00;oogl01Oooool2oomo00;oo`000_l0o`001?ooooooogl0oomo0?ooool2ool000;ooooo0_ooO`02
ooooo`;o0?l000?ooooooomo0?ooO`001Oooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`00
0oooooooo`00ool00006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`000oooooooo`00ool0
0002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`000ol00?ooogl0oomo
0005ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo
0?ooool2ool000;ooooo0_ooO`02ooooo`?o0?l00_ooO`000oooooooo`00ool00002ooooo`?oogl0
1?ooool3oomo00Cooooo0oooO`02ool000;ooooo0oooO`02ool000Kooooo0_l0o`001?l00?ooogl0
oomo0?ooO`04ooooo`?oogl00_oo0007ooooo`;o0?l00oooO`02ooooo`03o`3o0?l00?ooogl000;o
ogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0004ooooo`;oo`0000?o0?l0o`00
ooooO`000_ooO`04ooooo`?oogl00ooo00001?ooooooogl0oomo0?ooO`03ool000Wooooo0_ooO`05
ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool2
ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?oo
O`02ool000;ooooo0oooO`02ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`;ooooo0_oo
0002ooooo`?oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl0
0_ooool00ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00;o
oooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000;ooooo0_ooO`02ooooo`04
o`3o0?l00?oo003oo`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000;ooooo0_ooO`03ool0
00;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`02ool000;o0?l000Cooooo
oomo0?ooO`3ooooo0_oo0002ooooo`;oogl00_ooool2o`3o0003ooooooooO`3oogl000Gooooo0_oo
O`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo00001_ooool01?l0o`3o003oo`00
ool00?l6ooooo`;oogl000?oooooool00?oo00000_ooool2oomo0003oooooooo003oo`0000;ooooo
0_ooO`02ooooo`;o0?l000?o003ooomo0?ooO`001Oooool2oomo0003oooooooo003oo`0000Gooooo
0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl01Oooool2oomo0003
oooooooo003oo`0000Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o0004
o`00ooooO`3oogl0oomo00Cooooo0oooO`02ool000Oooooo0_l0o`03oomo00;ooooo00?o0?l0o`00
ooooO`000_ooO`04ooooo`?oogl00ooo0004ooooo`?oo`001?ooool2ool00003o`3o0?l00?ooogl0
00;oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0009ooooo`;oogl01Oooool2
oomo00?oo`001?ooool3ool000Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo0002
ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`02ool000;ooooo0oooO`02
ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`;ooooo0_oo0002ooooo`?oogl01?ooool3
oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl00_ooool00ol0o`3o003ooomo
0002oomo00?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00ool00?l0
1_ooool3oomo00?oo`001?ooool3ool000;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`Ko
oooo0_ooO`03ool000;ooooo0_ooO`03ool000;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00
o`Kooooo0_ooO`03ool000;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl01Oooool2oomo
00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo00001_ooool01?l0
o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00000_ooool2oomo0003oooooooo003o
o`0000;ooooo0_ooO`02ooooo`;o0?l000?o003ooomo0?ooO`001Oooool2oomo0003oooooooo003o
o`0000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl01Ooo
ool2oomo0003oooooooo003oo`0000Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_oo
ool2o`3o0004o`00ooooO`3oogl0oomo00Cooooo0oooO`02ool000Oooooo0_l0o`03oomo00;ooooo
00?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo0004ooooo`?oo`001?ooool2ool00003o`3o
0?l00?ooogl000;oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0009ooooo`;o
ogl01Oooool2oomo00?oo`001?ooool3ool000Cooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Go
oooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`000_ooool3oomo0003
ooooool0o`3o0?l000;o003o0_ooool2ool000;ooooo0oooO`04ooooo`?oogl00ooo00001?oooooo
ogl0oomo0?ooO`02ooooo`;o0?l00oooO`03ooooo`04o`00ooooO`3oogl0oomo00?oo`001?ooool3
ool00004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?oo
ool3ool000;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000;ooooo
0_ooO`03ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`000_ooool2oomo0003
oooooooo003oo`0000;ooooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000Go
oooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`000oooooooo`00ool00002oooo
o`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0_ooO`000ooo
ooooo`00ool00005ooooo`;oo`001_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`000_ooool2
oomo00Gooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Oooool2
ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl00_oo0009ooooo`?oogl00_oo
ool00ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool000Cooooo0ooo0004ooooo`;oo`0000?o
0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo00001?ooooooogl0oomo0?ooO`03ool000Wooooo
0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`02o`3o00;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`00
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0002ooooo`?oogl0
00?oooooo`3o0?l0o`000_l00?l2ooooo`;oo`000_ooool3oomo00Cooooo0oooO`03ool000Kooooo
0_l0o`03oomo00Cooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?oo003o00Kooooo
0oooO`03ool000Cooooo0ooo0002ooooo`;oogl00_ooool01?l0o`3o003oo`00ool00?l6ooooo`;o
ogl00ooo0002ooooo`;oogl00ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool0
00;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000ooo
ooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?ooooo
ool00?oo00000_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l00_l00?l6
ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?oo
ool2ool000;ooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00Cooooo0ooo
O`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_oo
ool00ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool000Cooooo0ooo0004ooooo`;oo`0000?o
0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo0004ooooo`?oo`002Oooool2oomo00Gooooo0_oo
O`03ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001_oo
ool2o`3o00;o003o1_ooool3oomo00;oo`001Oooool2ool000;ooooo0oooO`000ooooooo0?l0o`3o
0002o`00o`;ooooo0_oo0002ooooo`?oogl01?ooool3oomo00?oo`001_ooool2o`3o00?oogl01?oo
ool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?oo
ool3ool000;ooooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000;ooooo
0_ooO`03ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`000_ooool2oomo0003
oooooooo003oo`0000Wooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Ko
oooo00Co0?l0o`00ool00?oo003o1_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`000ooo
ooooo`00ool00002ooooo`;oogl00_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo003oo`00
00Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl01Oooool2
oomo0003oooooooo003oo`0000Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2
o`3o00;o003o1_ooool3oomo00;oo`002Oooool3oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`04
ooooo`?oogl00ooo0004ooooo`?oo`001?ooool2ool00003o`3o0?l00?ooogl000;oogl01?ooool3
oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o0oooool2o`3o
0004o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02
ool000Gooooo0_oo0002ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l2ooooo`;oo`000_ooool3
oomo00Cooooo0oooO`03ool000Kooooo0_l0o`03oomo00Cooooo0oooO`03ool000Cooooo0ooo0006
ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0002ooooo`;oogl00_ooool0
1?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0002ooooo`;oogl00ooo0006ooooo`04o`3o0?l0
0?oo003oo`00o`Kooooo0_ooO`03ool000;ooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl0
1Oooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Ko
oooo0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o00;o
003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?oo
O`3ooooo0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool0
00Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_ooool00ol0
o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo
00Cooooo0oooO`03ool000Cooooo0ooo0009ooooo`;oogl01Oooool2oomo00?oo`001?ooool3ool0
00Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`?o
oooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l6oooo
o`?oogl00_oo0005ooooo`;oo`000_ooool3oomo0003ooooool0o`3o0?l000;o003o0_ooool2ool0
00;ooooo0oooO`04ooooo`?oogl00ooo0006ooooo`;o0?l00oooO`04ooooo`?oogl00ooo0004oooo
o`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`000_ooool2oomo
00;ooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`000_ooool2oomo00?oo`001_ooool0
1?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0002ooooo`;oogl000?oooooool00?oo00002Ooo
ool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00
ool00?l6ooooo`;oogl000?oooooool00?oo00000_ooool2oomo0003oooooooo003oo`0000Kooooo
0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o0004o`00
ooooO`3oogl0ooooo`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`04ooooo`?o
ogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`002Oooool3oomo00;o
oooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0o`00oooo
O`000_ooO`04ooooo`?oogl00ooo0004ooooo`?oo`002Oooool2oomo00Gooooo0_ooO`03ool000Co
oooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001_ooool2o`3o00;o
003o1_ooool3oomo00;oo`001Oooool2ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`;o
oooo0_oo0002ooooo`?oogl01?ooool3oomo00?oo`001_ooool2o`3o00?oogl01?ooool3oomo00?o
o`001?ooool3ool000Kooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000;o
oooo0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000;ooooo0_ooO`03ool0
00Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001Oooool2ool000Wooooo0_ooO`05
ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o1_oo
ool2oomo0003oooooooo003oo`0000;ooooo0_ooO`000oooooooo`00ool00006ooooo`;o0?l00_l0
0?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo
0?ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`00
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl0
1?ooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`00
1?ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?l3ooooo`;o0?l000Co
003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`00
1Oooool2ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`;ooooo0_oo0009ooooo`?oogl0
0ooo0006ooooo`;o0?l00oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003o
o`00o`06ooooo`?oogl00ooo0004ooooo`?oo`000_ooool2oomo00;ooooo00Co0?l0o`00ool00?oo
003o1_ooool2oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo
00?oo`001Oooool2ool000Wooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool0
00Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`00
0oooooooo`00ool00006ooooo`;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2
ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3
oomo00Cooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0009
ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool0
0ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool000Cooooo0ooo0009ooooo`;oogl01Oooool2
oomo00?oo`001?ooool3ool000?ooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`02o`3o
00;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02
o`00o`Kooooo0oooO`02ool000Gooooo0_oo0002ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l2
ooooo`;oo`002Oooool3oomo00?oo`001_ooool2o`3o00?oogl01?ooool3oomo00?oo`001?ooool3
ool000Kooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000Kooooo00Co0?l0
o`00ool00?oo003o1_ooool2oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o
1_ooool2oomo00?oo`001Oooool2ool000Wooooo0_ooO`05ooooo`;oogl000?oooooool00?oo0000
1Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo0003oooooooo003oo`0000;o
oooo0_ooO`000oooooooo`00ool00006ooooo`;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo
00001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`;oogl000?oooooool00?oo
00002Oooool3oomo00Cooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?o
ogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?o
o`001_ooool00ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool000Cooooo0ooo0009ooooo`;o
ogl01Oooool2oomo00?oo`001?ooool3ool000Cooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Go
oooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`000_ooool3oomo0003
ooooool0o`3o0?l000;o003o0_ooool2ool000Wooooo0oooO`03ool000Kooooo0_l0o`03oomo00Co
oooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Co
oooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006oooo
o`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Gooooo0_oo0009ooooo`;oogl01Oooool2
oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_oo
O`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo
003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool2oomo0003oooooooo
003oo`0000Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o1_oo
ool3oomo00;oo`002Oooool3oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?oo
ool3ool000Kooooo00?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo0004ooooo`?oo`002Ooo
ool2oomo00Gooooo0_ooO`03ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00;o0?l00_l00?l5ooooo`04o`00ooooO`3oogl0ooooo`;oo`001Ooo
ool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0002ooooo`?oogl000?o
ooooo`3o0?l0o`000_l00?l2ooooo`;oo`002Oooool3oomo00?oo`001_ooool2o`3o00?oogl01?oo
ool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?oo
ool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001?ooool3ool000Kooooo
00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001Oooool2ool000Wooooo0_ooO`05ooooo`;o
ogl000?oooooool00?oo00001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo
0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`;oogl000?oooooool0
0?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`;oogl000?oooooool0
0?oo00002Oooool3oomo00Cooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l6oooo
o`?oogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004oooo
o`?oo`001_ooool00ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool000Cooooo0ooo0009oooo
o`;oogl01Oooool2oomo00?oo`001?ooool3ool000Cooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;o
o`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;o
oooo0_oo0009ooooo`?oogl00ooo0006ooooo`;o0?l00oooO`04ooooo`?oogl00ooo0004ooooo`?o
o`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o
003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005
ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Ooo
ool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_oo
ool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?oo
ool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0ooo
O`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l0
0?ooogl000;oogl01?ooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo
0004ooooo`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6
ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03
ool000Sooooo0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06
ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo
0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`00
2Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003o
o`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Ko
oooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wo
oooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Oooool2ool000Ko
oooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Ko
oooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl01?ooool3oomo00?o
o`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooo
oooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`00
1_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl0
0ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`00
1_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o
003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000ooo
ooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?ooooo
ool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005
ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009
ooooo`?oogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02
ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006
ooooo`03o`3o0?l00?ooogl000;oogl01?ooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05
ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006oooo
o`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool0
00Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0
o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo
0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_oo
ool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo
0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o
0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`00
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl0
1?ooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`00
1?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_oo
ool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo
0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0ooo
O`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo
0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`00
1_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Go
oooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6oooo
o`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000ooo
ooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000ooo
ooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00
o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool0
00Cooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl01?ooool3oomo00?oo`001?ooool3ool0
00Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Go
oooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o
003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo0004ooooo`?o
o`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o
003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005
ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Ooo
ool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_oo
ool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?oo
ool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0ooo
O`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l0
0?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0009ooooo`;oogl01Oooool2oomo00?oo`001?oo
ool3ool000Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3
oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`?oogl00ooo0008
ooooo`?oogl01?ooool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0o`00ool00?l01_ooool3
oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001?oo
ool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001Oooool2ool000Wooooo
0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo
003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`;o
ogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`;o
ogl000?oooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o
0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?o
ogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?o
o`002Oooool2oomo00Gooooo0_ooO`03ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo0000
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l0
0_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3oomo00Cooooo0oooO`03ool000Cooooo
0ooo0006ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`04o`3o
0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00
o`Kooooo0_ooO`03ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo0003oooooooo003oo`00
00Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`000oooooooo`00ool00005
ooooo`;oo`001_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006
ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`04
ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`002Oooool3
oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000Kooooo0_l0o`07
ooooo`?oogl00ooo0004ooooo`?oo`002Oooool2oomo00Gooooo0_ooO`03ool000Cooooo0ooo0004
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6oooo
o`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool0
00Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3oomo
00Cooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool0
00Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006
ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Gooooo0_oo0009ooooo`;oogl01Ooo
ool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo
0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool2oomo0003oooo
oooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool2oomo0003oooo
oooo003oo`0000Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o
1_ooool3oomo00;oo`002Oooool3oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`00
1?ooool3ool000Kooooo0_l0o`07ooooo`?oogl00ooo0004ooooo`?oo`002Oooool2oomo00Gooooo
0_ooO`03ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0
o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o1_oo
ool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`?oogl00ooo
0008ooooo`?oogl01?ooool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0o`00ool00?l01_oo
ool3oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`00
1?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001Oooool2ool000Wo
oooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo00Co0?l0o`00ool0
0?oo003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6oooo
o`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009oooo
o`;oogl000?oooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool000Gooooo0_oo0006oooo
o`;o0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06oooo
o`?oogl00ooo0004ooooo`?oo`001_ooool2o`3o00Oooooo0oooO`03ool000Cooooo0ooo0009oooo
o`;oogl01Oooool2oomo00?oo`001?ooool3ool000?ooooo0_l0000;ooooo`009Oooool00ol0003o
ooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o
0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wo
oooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o
003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6oooo
o`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005
ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool0
1?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0
o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o0_oo
ool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Ooo
ool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o0?l0
0?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`;o0?l01oooool3oomo00?oo`001?oo
ool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo003o
o`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2
o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo0004
ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool0
1?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00
ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00
ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo
00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;o
o`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?o
ogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wo
oooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`;o
0?l01oooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?o
o`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl0
0_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo
0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl0
0ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?o
o`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo
00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`00
0oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`00
0oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02
o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03
ool000Cooooo0ooo0006ooooo`;o0?l01oooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05
ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006oooo
o`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool0
00Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0
o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo
0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_oo
ool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo
0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o
0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`00
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`;o0?l01oooool3oomo00?oo`00
1?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004ooooo`?oo`001?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0003oooooooo
003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0005ooooo`;oo`001_oo
ool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`04ooooo`?oogl00ooo
0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_oo
ool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003o
o`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000ooooooo
o`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool0
0?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009oooo
o`?oogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool0
00Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006oooo
o`;o0?l01oooool3oomo00?oo`001?ooool3ool000Wooooo0_ooO`05ooooo`;oogl00ooo0004oooo
o`?oo`001?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?o
ogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000So
oooo0oooO`04ooooo`?oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`06ooooo`?o
ogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0004oooo
o`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2
oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool0
0?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_oo
O`000oooooooo`00ool00005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0_oo
O`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0
o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0ooo
O`03ool000Cooooo0ooo0006ooooo`;o0?l01oooool3oomo00?oo`001?ooool3ool000Wooooo0_oo
O`07ooooo`?oo`001?ooool3ool000Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2
o`3o00;o003o1_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009
ooooo`?oogl00ooo0008ooooo`?oogl01?ooool3oomo00?oo`001?ooool3ool000Kooooo00?o0?l0
o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_oo
ool2oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`00
1Oooool2ool000Wooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo
00Co0?l0o`00ool00?oo003o1_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006ooooo`;o
0?l00_l00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo0_l0o`02o`00o`;o
oooo0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool000Go
oooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o
003oo`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool2o`3o00Oooooo0oooO`03ool000Co
oooo0ooo0009ooooo`;oogl01oooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo0000
1Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l0
0_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3oomo00Cooooo0oooO`03ool000Cooooo
0ooo0006ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003o
o`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6oooo
o`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl000?oooooool00?oo00001Oooool2
ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool2
o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3
oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02
ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Cooooo0ooo0006ooooo`;o0?l01oooool3
oomo00?oo`001?ooool3ool000Wooooo0_ooO`07ooooo`?oo`001?ooool3ool000Cooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`08oooo
o`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00
o`;ooooo0_oo0009ooooo`?oogl00ooo0008ooooo`?oogl01?ooool3oomo00?oo`001?ooool3ool0
00Kooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o0?l00?oo003o
o`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_oo
O`03ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000Gooooo0_oo
0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`00
1_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000gooooo0_l0o`02o`00o`;ooooo
0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool000Gooooo
0_oo0006ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_ooool00ol0o`3o003o
o`00o`06ooooo`?oogl00ooo0004ooooo`?oo`001_ooool2o`3o00Oooooo0oooO`03ool000Cooooo
0ooo0009ooooo`;oogl01oooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0
o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Ooo
ool3oomo00?oo`002?ooool3oomo00Cooooo0oooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l0
0?oo003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl0
0ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo0005ooooo`;o
o`002Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`001_ooool01?l0o`3o
003oo`00ool00?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000ooo
ooooo`00ool0000=ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool2oomo0003oooooooo003oo`00
00Wooooo0oooO`04ooooo`?oogl00_oo0005ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3oomo
00;oo`002Oooool3oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`001?ooool3ool0
00Kooooo0_l0o`07ooooo`?oogl00ooo000@ooooo`;oogl01oooool3ool000Cooooo0ooo0004oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;o
ogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o
0?l00_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3oomo00Cooooo0oooO`03ool000go
oooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00
o`Kooooo0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03
ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000Gooooo0_oo0006
ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`08ooooo`;oo`001_ooool2o`3o00;o003o1_oo
ool2oomo0003oooooooo003oo`0000gooooo0_l0o`02o`00o`;ooooo0_oo0009ooooo`;oogl000?o
ooooool00?oo00002Oooool3oomo00Cooooo0oooO`02ool000gooooo0_l0o`02o`00o`Kooooo0ooo
O`02ool000Wooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000gooooo0_l0
o`07ooooo`?oogl00ooo000@ooooo`;oogl01oooool3ool000Cooooo0ooo0004ooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`?o00000_l0o`02o`00o`Kooooo0_ooO`08ooooo`;oo`001_ooool2
o`3o00;o003o1_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0009
ooooo`?oogl00ooo0008ooooo`?oogl01?ooool3oomo00?oo`003Oooool00ol0o`3o003oo`00o`06
ooooo`?oogl01oooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001?oo
ool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`001Oooool2ool000Wooooo
0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo
003o1_ooool2oomo00Sooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo
00003Oooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?o
ogl01?ooool3oomo00;oo`003Oooool2o`3o00;o003o1_ooool3oomo00_ooooo0oooO`02ooooo`03
o`3o0?l00?oo003o00Kooooo0oooO`0@ooooo`;o0?l01oooool3oomo00?oo`004?ooool2oomo00Oo
oooo0ooo0004ooooo`?oo`000oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo
0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3oomo00Cooooo
0oooO`03ool000gooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o
0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00
o`Kooooo0_ooO`03ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo0003oooooooo003oo`00
00Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`08ooooo`;oo`001_ooool2
o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000gooooo0_l0o`02o`00o`gooooo0_ooO`00
0oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00;oo`003Oooool2o`3o00;o003o1_ooool3
oomo00_ooooo0oooO`02ooooo`03o`3o0?l00?oo003o01Wooooo0_l0o`07ooooo`?oogl00ooo000@
ooooo`;oogl01oooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00
o`Kooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l=ooooo`?oogl00ooo0008oooo
o`?oogl01?ooool3oomo013ooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006oooo
o`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo
003oo`00o`Sooooo0ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`08ooooo`;oo`001_oo
ool01?l0o`3o003oo`00ool00?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo
0_ooO`000oooooooo`00ool0000=ooooo`;o0?l00_l00?l=ooooo`;oogl000?oooooool00?oo0000
2Oooool3oomo00Cooooo0oooO`02ool000gooooo0_l0o`02o`00o`Kooooo0oooO`0;ooooo`?oogl0
0_ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l01oooool3oomo00?oo`004?ooool2oomo00Oooooo
0ooo000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?l6ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo
0006ooooo`;o0?l00_l00?l=ooooo`?oogl00ooo0008ooooo`?oogl01?ooool3oomo013ooooo00?o
0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo
0_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Sooooo0ooo0005ooooo`;o
o`002Oooool2oomo00Gooooo0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`08oooo
o`;oo`001_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000gooooo0_l0o`02o`00
o`gooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01?ooool3oomo00oooooo0_l0o`02o`00
o`Kooooo0oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l01oooool3oomo
00?oo`004?ooool2oomo01Gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00_l0o`02o`00o`Kooooo0_ooO`08ooooo`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;o
o`001Oooool2ool000Kooooo0_l0o`02o`00o`gooooo0oooO`03ool000Sooooo0oooO`04ooooo`?o
ogl04?ooool00ol0o`3o003oo`00o`06ooooo`?oogl01oooool3ool000Kooooo00Co0?l0o`00ool0
0?oo003o1_ooool2oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o2?ooool3
ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo013ooooo00Co0?l0o`00ool00?oo003o1_oo
ool2oomo00Sooooo0_oo0006ooooo`;o0?l00_l00?l6ooooo`;oogl000?oooooool00?oo00003Ooo
ool2o`3o00;o003o3Oooool2oomo00cooooo0oooO`04ooooo`?oogl03oooool2o`3o00;o003o1_oo
ool3oomo00_ooooo0oooO`02ooooo`03o`3o0?l00?oo003o01Wooooo0_l0o`07ooooo`?oogl00ooo
000@ooooo`;oogl05Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003o4?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`02ool000Gooooo0_oo0006
ooooo`;o0?l00_l00?l=ooooo`?oogl02oooool3oomo00Cooooo0oooO`0@ooooo`03o`3o0?l00?oo
003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl00ooo
0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l8ooooo`?oo`001Oooool2ool000Wooooo
0_ooO`05ooooo`;oogl04?ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl02?ooool2ool000Ko
oooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool0000=ooooo`;o0?l00_l00?l=ooooo`;o
ogl03?ooool3oomo00Cooooo0oooO`0?ooooo`;o0?l00_l00?l6ooooo`?oogl02oooool3oomo00;o
oooo00?o0?l0o`00ool00?l06Oooool2o`3o00Oooooo0oooO`03ool002Oooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oa3ooooo0_oo0006ooooo`;o0?l0
0_l00?l6ooooo`?oogl00_oo000=ooooo`;o0?l00_l00?l=ooooo`?oogl02oooool3oomo00Cooooo
0oooO`0@ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003o
o`00ool00?l6ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l8oooo
o`?oo`001Oooool2ool000Wooooo0_ooO`05ooooo`;oogl04?ooool01?l0o`3o003oo`00ool00?l6
ooooo`;oogl02?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool0000=
ooooo`;o0?l00_l00?l=ooooo`;oogl03?ooool3oomo00Cooooo0oooO`0?ooooo`;o0?l00_l00?l6
ooooo`?oogl02oooool3oomo00;ooooo00?o0?l0o`00ool00?l06Oooool2o`3o00[ooooo0ooo000W
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l@oooo
o`;oo`001_ooool2o`3o00;o003o1_ooool3oomo00;oo`003Oooool2o`3o00;o003o3Oooool3oomo
00_ooooo0oooO`04ooooo`?oogl04?ooool00ol0o`3o003oo`00o`06ooooo`?oogl01oooool3ool0
00Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00?oo`003Oooool01?l0o`3o003oo`00ool0
0?l8ooooo`?oo`004?ooool2oomo00Gooooo0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00o`Kooooo
0_ooO`08ooooo`;oo`001_ooool2o`3o00;o003o1_ooool2oomo0003oooooooo003oo`0000gooooo
0_l0o`02o`00o`gooooo0_ooO`0<ooooo`?oogl01?ooool3oomo00oooooo0_l0o`02o`00o`Kooooo
0oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o4?ooool2ool000Kooooo0_l0
o`02o`00o`Kooooo0oooO`02ool000gooooo0_l0o`02o`00o`gooooo0oooO`0;ooooo`?oogl01?oo
ool3oomo013ooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o0?l0
0?oo003oo`00o`Kooooo0_ooO`03ool000gooooo00Co0?l0o`00ool00?oo003o2?ooool3ool0013o
oooo0_ooO`05ooooo`;oogl04?ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl02?ooool2ool0
00Kooooo0_l0o`02o`00o`Kooooo0_ooO`000oooooooo`00ool0000=ooooo`;o0?l00_l00?l=oooo
o`;oogl03?ooool3oomo00Cooooo0oooO`0?ooooo`;o0?l00_l00?l6ooooo`?oogl02oooool3oomo
00;ooooo00?o0?l0o`00ool00?l06Oooool2o`3o03Cooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00o`Wooooo0_oo000=ooooo`;o
0?l00_l00?l=ooooo`?oogl02oooool3oomo00Cooooo0oooO`0@ooooo`03o`3o0?l00?oo003o00Ko
oooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl04?ooool01?l0
o`3o003oo`00ool00?lRooooo`;oogl04?ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl02?oo
ool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`0@ooooo`;o0?l00_l00?l=ooooo`;oogl03?oo
ool3oomo00Cooooo0oooO`0?ooooo`;o0?l00_l00?l6ooooo`?oogl04?ooool00ol0o`3o003oo`00
o`0Iooooo`;o0?l0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003o6?ooool2o`3o00;o003o2Oooool2ool000gooooo0_l0o`02o`00o`gooooo0oooO`0;
ooooo`?oogl01?ooool3oomo013ooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006
ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00ob;ooooo
0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`08ooooo`;oo`001_ooool2o`3o00;o
003o1_ooool2oomo013ooooo0_l0o`02o`00o`gooooo0_ooO`0<ooooo`?oogl05_ooool2o`3o00;o
003o1_ooool3oomo013ooooo00?o0?l0o`00ool00?l06Oooool2o`3o03Cooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo
0_l0o`02o`00o`gooooo0oooO`0;ooooo`?oogl01?ooool3oomo013ooooo00?o0?l0o`00ool00?l0
1_ooool3oomo00Oooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`0@ooooo`04
o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00Sooooo0_oo0006
ooooo`;o0?l00_l00?l6ooooo`;oogl04?ooool2o`3o00;o003o3Oooool2oomo00cooooo0oooO`0F
ooooo`;o0?l00_l00?l6ooooo`?oogl04?ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o
00;o003o6?ooool2o`3o00;o003o3Oooool3oomo00_ooooo0oooO`04ooooo`?oogl04?ooool00ol0
o`3o003oo`00o`06ooooo`?oogl01oooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2
oomo013ooooo00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl0
2?ooool2ool000Kooooo0_l0o`02o`00o`Kooooo0_ooO`0@ooooo`;o0?l00_l00?l=ooooo`;oogl0
3?ooool3oomo01Kooooo0_l0o`02o`00o`Kooooo0oooO`0@ooooo`03o`3o0?l00?oo003o01Wooooo
0_l0o`0dooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0o`02o`00oaSooooo0_l0
o`02o`00oaSooooo0_l0o`02o`00o`gooooo0oooO`0;ooooo`?oogl05oooool00ol0o`3o003oo`00
o`06ooooo`?oogl01oooool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo013ooooo
00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl04?ooool2o`3o
00;o003o1_ooool2oomo013ooooo0_l0o`02o`00o`gooooo0_ooO`0Uooooo`;o0?l00_l00?l6oooo
o`?oogl04?ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0<oooool2o`0000_ooooo000Uooooo`03
o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=ooooo`?o
ogl02oooool3oomo01Oooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006ooooo`04
o`3o0?l00?oo003oo`00o`Kooooo0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00ocCooooo00Co0?l0
o`00ool00?oo003o1_ooool2oomo013ooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`gooooo0_oo
O`0Uooooo`;o0?l00_l00?l6ooooo`?oogl04?ooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2
o`3o00;o003o6?ooool2o`3o00;o003o3Oooool3oomo00_ooooo0oooO`0Gooooo`03o`3o0?l00?oo
003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl04?oo
ool01?l0o`3o003oo`00ool00?ldooooo`04o`3o0?l00?oo003oo`00oaSooooo0_l0o`02o`00oaSo
oooo0_l0o`02o`00o`gooooo0_ooO`0Uooooo`;o0?l00_l00?l6ooooo`?oogl04?ooool00ol0o`3o
003oo`00o`0Iooooo`;o0?l0=?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o3Oooool3oomo00_ooooo
0oooO`0Gooooo`03o`3o0?l00?oo003o00Kooooo0oooO`07ooooo`?oo`001_ooool01?l0o`3o003o
o`00ool00?l6ooooo`;oogl04?ooool01?l0o`3o003oo`00ool00?ldooooo`04o`3o0?l00?oo003o
o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`gooooo0_ooO`0Uooooo`;o0?l00_l00?lI
ooooo`03o`3o0?l00?oo003o01Wooooo0_l0o`0dooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=oooo
o`?oogl02oooool3oomo01Oooooo00?o0?l0o`00ool00?l01_ooool3oomo00Oooooo0ooo0006oooo
o`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`0@ooooo`04o`3o0?l00?oo003oo`00ocCooooo00Co
0?l0o`00ool00?oo003o6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o3Oooool2oomo02Gooooo
0_l0o`02o`00oaWooooo00?o0?l0o`00ool00?l06Oooool2o`3o03Cooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0
o`02o`00o`gooooo0oooO`0;ooooo`?oogl05oooool00ol0o`3o003oo`00o`06ooooo`?oogl01ooo
ool3ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo013ooooo00Co0?l0o`00ool00?oo
003o=?ooool01?l0o`3o003oo`00ool00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=oooo
o`;oogl09Oooool2o`3o00;o003o6Oooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o
003o6?ooool2o`3o00;o003o3Oooool3oomo00_ooooo0oooO`0Gooooo`03o`3o0?l00?oo003o01Wo
oooo00Co0?l0o`00ool00?oo003o1_ooool2oomo013ooooo00Co0?l0o`00ool00?oo003o=?ooool0
1?l0o`3o003oo`00ool00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=ooooo`;oogl09Ooo
ool2o`3o00;o003o6Oooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2
o`3o00;o003o3Oooool3oomo00_ooooo0oooO`0Gooooo`03o`3o0?l00?oo003o01Wooooo00Co0?l0
o`00ool00?oo003o1_ooool2oomo013ooooo00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003o
o`00ool00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=ooooo`;oogl09Oooool2o`3o00;o
003o6Oooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0=?ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o
3Oooool3oomo00_ooooo0oooO`0Gooooo`03o`3o0?l00?oo003o01Wooooo00Co0?l0o`00ool00?oo
003o1_ooool2oomo013ooooo00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool00?lH
ooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=ooooo`;oogl09oooool2o`00oaWooooo00?o0?l0
o`00ool00?l06Oooool2o`3o03Cooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`gooooo0oooO`0;oooo
o`?oogl05oooool00ol0o`3o003oo`00o`0Iooooo`04o`3o0?l00?oo003oo`00oaSooooo00Co0?l0
o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool00?lHooooo`;o0?l00_l00?lHooooo`;o0?l0
0_l00?l=ooooo`;oogl09oooool2o`00oaWooooo00?o0?l0o`00ool00?l06Oooool2o`3o03Cooooo
00?o0000ooooooooool02Oooool000[ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`?o00001oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?oo
ool2o`3o00;o003o3Oooool3oomo00_ooooo0oooO`0Gooooo`03o`3o0?l00?oo003o01Wooooo00Co
0?l0o`00ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?ldooooo`04o`3o0?l00?oo003oo`00
oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`gooooo0_ooO`0Wooooo`;o003o6Oooool00ol0
o`3o003oo`00o`0Iooooo`;o0?l0=?ooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l0
0?l=ooooo`?oogl02oooool3oomo01Oooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00
ool00?lHooooo`04o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o
00;o003o6?ooool2o`3o00;o003o3Oooool2oomo02Oooooo0_l00?lIooooo`03o`3o0?l00?oo003o
01Wooooo0_l0o`0dooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`?o00000_l0o`02
o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`gooooo0oooO`0;ooooo`?oogl05oooool0
0ol0o`3o003oo`00o`0Iooooo`04o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o
=?ooool01?l0o`3o003oo`00ool00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l=ooooo`;o
ogl09oooool2o`00oaWooooo00?o0?l0o`00ool00?l06Oooool2o`3o03;ooooo0ol0000;ooooo`00
2Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2o`3o
00;o003o6oooool3oomo01Oooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?lH
ooooo`04o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o00;o003o
6?ooool3o`3o00kooooo0_ooO`0Wooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Iooooo`;o0?l0
=?ooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooo`000?ooool01?l00007ooooo`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o
0?l00_l00?lHooooo`;o0?l00_l00?lKooooo`?oogl05oooool00ol0o`3o003oo`00o`0Iooooo`04
o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool0
0?lHooooo`;o0?l00_l00?lHooooo`?o0?l03_ooool2oomo02Oooooo0_l00?lIooooo`;o0?l06_oo
ool2o`3o03Cooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000[ooooo00?o0000ooooooooool00_l0o`02o`00oaSo
oooo0_l0o`02o`00oaSooooo0_l0o`02o`00oa_ooooo0oooO`0Gooooo`03o`3o0?l00?oo003o01Wo
oooo00Co0?l0o`00ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?ldooooo`04o`3o0?l00?oo
003oo`00oaSooooo0_l0o`02o`00oaSooooo0ol0o`0>ooooo`;oogl09oooool2o`00oaWooooo0_l0
o`0Jooooo`;o0?l0=?ooool00ol0003oooooooooo`09ooooo`002_ooool2o`0000[ooooo0_l00002
ooooo`Go00001_ooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2
o`3o00;o003o6oooool3oomo01Oooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool0
0?lHooooo`04o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o00;o
003o6?ooool3o`3o03Oooooo0_l00?lIooooo`;o0?l06_ooool2o`3o03Cooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo
0_l0o`02o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?lHooooo`04
o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o00;o003o6?ooool3
o`3o03Oooooo0_l00?lIooooo`;o0?l0D?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o=Oooool00ol0
o`3o003oo`00o`0Iooooo`04o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o=?oo
ool01?l0o`3o003oo`00ool00?lHooooo`;o0?l00_l00?lHooooo`?o0?l0=oooool2o`00oaWooooo
0_l0o`1@ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?leooooo`03o`3o0?l00?oo003o01Wooooo00Co
0?l0o`00ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?ldooooo`04o`3o0?l00?oo003oo`00
oaSooooo0_l0o`02o`00oaSooooo0ol0o`0gooooo`;o003o6Oooool2o`3o053ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSo
oooo0_l0o`02o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?lHoooo
o`04o`3o0?l00?oo003oo`00ocCooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o00;o003o6?oo
ool3o`3o03Oooooo0_l00?lIooooo`;o0?l0D?ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o=Oooool0
0ol0o`3o003oo`00o`0Iooooo`04o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o
=?ooool01?l0o`3o003oo`00ool00?lHooooo`?o0?l06Oooool3o`3o03Oooooo0_l00?lIooooo`;o
0?l0D?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
6?ooool2o`3o00;o003o6?ooool2o`3o00;o003o=Oooool00ol0o`3o003oo`00o`0Iooooo`04o`3o
0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o=?ooool01?l0o`3o003oo`00ool00?lH
ooooo`?o0?l06Oooool3o`3o03Oooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?leoooo
o`03o`3o0?l00?oo003o01Wooooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o03Kooooo00Co0?l0
o`00ool00?oo003o6?ooool3o`3o01Wooooo0ol0o`0gooooo`;o003oJoooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2
o`3o00;o003o=Oooool00ol0o`3o003oo`00o`0Iooooo`04o`3o0?l00?oo003oo`00oe3ooooo00Co
0?l0o`00ool00?oo003o6?ooool3o`3o01Wooooo0ol0o`0gooooo`;o003oJoooool00ol0003ooooo
ooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?lHooooo`;o0?l00_l00?lHooooo`;o0?l00_l0
0?leooooo`03o`3o0?l00?oo003o01Wooooo00Co0?l0o`00ool00?oo003oD?ooool01?l0o`3o003o
o`00ool00?lHooooo`?o0?l06Oooool3o`3o03Oooooo0_l00?mZooooo`;o00002oooool002Gooooo
00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00ocGooooo
00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04o`3o0?l00?oo003oo`00
oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00ocGo
oooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04o`3o0?l00?oo003o
o`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00
ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04o`3o0?l00?oo
003oo`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02
o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04o`3o0?l0
0?oo003oo`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0
o`02o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04o`3o
0?l00?oo003oo`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo
0_l0o`02o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@ooooo`04
o`3o0?l00?oo003oo`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSo
oooo0_l0o`02o`00ocGooooo00?o0?l0o`00ool00?l06Oooool01?l0o`3o003oo`00ool00?m@oooo
o`04o`3o0?l00?oo003oo`00oaSooooo0ol0o`0Iooooo`?o0?l0=oooool2o`00of_ooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00
oaSooooo0_l0o`02o`00ocKooooo0_l00?lIooooo`04o`3o0?l00?oo003oo`00oe3ooooo00Co0?l0
o`00ool00?oo003o6?ooool3o`3o01Wooooo0ol0o`0gooooo`;o003oJoooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6?ooool2o`3o00;o003o6?ooool2
o`3o00;o003o=_ooool2o`00oaWooooo00Co0?l0o`00ool00?oo003oD?ooool01?l0o`3o003oo`00
ool00?ldooooo`?o0?l0=oooool2o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00oaSooooo0_l0o`02o`00ocKooooo0_l0
0?lJooooo`?o003oD?ooool01?l0o`3o003oo`00ool00?ldooooo`?o0?l0=oooool2o`00of_ooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0
o`02o`00oaSooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003o=?ooool3o`3o03Oooooo0_l0
0?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0o`02o`00oaSooooo0_l0o`02
o`00oaSooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003o=?ooool3o`3o03Oooooo0_l00?mZ
ooooo`;o00002oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00
oaSooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003o=?ooool3o`3o03Oooooo0_l00?m[oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?lJooooo`;o
003o6?ooool2o`3o00;o003o=_ooool2o`00ofkooooo0ol00?ldooooo`?o0?l0=oooool2o`00of_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo
0_l00?lHooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ocCooooo0ol0o`0gooooo`;o003o
Joooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o6_oo
ool2o`00oaSooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003o=?ooool3o`3o03Oooooo0_l0
0?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?lJ
ooooo`;o003o6?ooool2o`3o00;o003o=_ooool2o`00ofkooooo0ol00?ldooooo`?o0?l0=oooool2
o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00
oa[ooooo0_l00?lHooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ocCooooo0ol0o`0goooo
o`;o003oJoooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003o=?ooool2o`3o00;o003o=_ooool2o`00ofkooooo0ol00?ldooooo`?o0?l0=oooool2o`00of_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo
0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003oK_ooool2o`00of_ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0_l0o`02o`00ocKooooo0_l0
0?m^ooooo`?o003oK_ooool2o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00_l0o`02o`00ocCooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003oK_ooool2
o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00
ocCooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003oK_ooool2o`00of_ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0_l0o`02o`00ocKo
oooo0_l00?m^ooooo`?o003oK_ooool2o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo
0ol00002o`3o00;o003o=?ooool2o`3o00;o003o=_ooool2o`00ofkooooo0ol00?m^ooooo`;o003o
J_ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l0
0?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3
o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?ldooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o
0?l00_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l00?lfooooo`;o003o
K_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00;o0?l00_l00?ldooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l0
0?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ld
ooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l00?lfoooo
o`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ofko
oooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?ldooooo`;o0?l00_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`;o0?l00_l0
0?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`?o00000_l0o`02o`00ocCooooo0_l0o`02o`00ocKooooo0_l00?m^ooooo`?o003oK_ooool2
o`00of[ooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o=?ooool2o`3o
00;o003o=_ooool2o`00ofkooooo0ol00?m^ooooo`;o003oJoooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`02o`3o00;o003o=_ooool2o`00ocKooooo0_l00?m^ooooo`?o
003oK_ooool2o`00of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0_l0o`02o`00ocKooooo0_l00?lfooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?m^ooooo`;o003oK_oo
ool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?m^ooooo`;o003oK_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003oK_ooool2o`00
of_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00omko
oooo0ol00?m^ooooo`;o003oJoooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003og_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003oK_ooool2o`00of_ooooo00?o
0000ooooooooool02Oooool0013ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00007
ooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003oK_ooool2o`00of_ooooo00?o0000
ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003oK_ooool2o`00of_ooooo00?o0000
ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003oK_ooool2o`00of_ooooo00?o0000
ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06
ooooo`?o00000_l0o`02o`00omkooooo0ol00?m^ooooo`;o003oJOooool3o`0000_ooooo000?oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
o`3o00;o003og_ooool3o`00ofkooooo0_l00?m[ooooo`03o`000?oooooooooo00Wooooo000?oooo
o`04o`000?ooooooooooo`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00;o0?l00_l00?oN
ooooo`?o003oK_ooool2o`00of_ooooo00?o0000ooooooooool02Oooool0013ooooo0_l0000:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l0o`02o`00omkooooo0ol00?oKoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o
003ofoooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
g_ooool3o`00om_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0
o`02o`00omkooooo0ol00?oKooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?oNooooo`?o003ofoooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003og_ooool3o`00om_ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00omkooooo0ol00?oKooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003ofoooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003og_ooool3o`00om_ooooo00?o
0000ooooooooool02Oooool002Gooooo0ol00002o`3o00;o003og_ooool3o`00om[ooooo0_l0000;
ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003og_ooool3o`00om_ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00omkooooo0ol00?oKooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003o
foooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003og_oo
ool3o`00om_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00omkooooo0ol00?oKooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?oNooooo`?o003ofoooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`02o`3o00;o003og_ooool3o`00om_ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00_l0o`02o`00omkooooo0ol00?oKooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003ofoooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003og_ooool3o`00om_ooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00omkooooo0ol00?oKoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o
003ofoooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?oNooooo`?o003o
f_ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oNooooo`?o003ofooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003og_ooool3
o`00om_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00
oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0
o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo0ol00002
o`3o00;o003ooooooonlooooo`;o00002oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00
oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0
o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo
0ol00002o`3o00;o003ooooooonlooooo`;o00002oooool002Gooooo00?o0000ooooooooool00_l0
o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool000[ooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00001oooool00ol0003ooooo
ooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`00
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool3o`0000;o0?l00_l00?oooooook_ooooo0ol0000;ooooo`002Oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l00007ooooo`03o`000?oooooooooo
00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooo
oooo00002?ooool2o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02o`3o
00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000:ooooo`;o00002_ooool01?l0003o
ooooooooooooool5o`0000Kooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonm
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooo
okgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooo
oooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
oooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo0ol00002o`3o00;o003ooooooonl
ooooo`;o00002oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonm
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooo
okgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooo
oooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
oooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o
00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0o`02o`00oooo
oooo_?ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonm
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooo
okgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooo
oooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
oooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o
00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0o`02
o`00oooooooo_?ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooo
okgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooo
oooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
oooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o
00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000;o
0?l00_l00?oooooookcooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
oooooonmooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00Wooooo000@ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool000oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`003oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo0ol00003
o`3o0?oooooo_?ooool3o`0000_ooooo000?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000@ooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo
0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`009Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool002Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo000Uoooooooo0000aOl0000;
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o0000
1Oooool3o`0000?ooooo0ol00004ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`?o0000
1?ooool2o`0000;ooooo0ol00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co0000
1?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go0000
0_ooool5o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go0000
0_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o0000
0oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co0000
1?ooool3o`0000?ooooo1?l00003ooooo`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000
o`000004o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co0000
0_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co0000
1?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co0000
1?ooool3o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000Cooooo0ol0000;ooooo`00:Ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o
00001?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2
o`0000?ooooo00?o0000ooooooooool00_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000
o`000?oooooo0000ooooool0003ooooo0_l00003ooooo`;o000000Ooooooo`000?oooooo0000oooo
ool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooo
oooo0000ooooool0003oooooo`000?ooool00_l00002ooooo`05o`000?oooooo0000ooooool00000
0_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo00Co0000ooooool0003o00000_ooool2o`0000Cooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000001Oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_oo
ool2o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00Co0000ooooool0003o00001?ooool2
o`0000Gooooo0_l00006ooooo`;o00000_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooo
oooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`;o00000ooo
ool01?l0003oooooo`000?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go0000
1Oooool2o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l000000ooooooo0000o`000004
o`0000Gooooo00Go0000ooooool0003oooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`00
0?oooooo000000?ooooo0_l00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go0000
0_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o000000Co0000
0_ooool5o`000003ooooool0003o000000Co00001Oooool2o`0000;ooooo00?o0000ooooooooool0
0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool2o`00
0003ooooool0003o000000Co00001Oooool2o`000003ooooool0003ooooo00;ooooo0_l00004oooo
o`05o`000?oooooo0000ooooool000000oooool2o`0000;ooooo00?o0000ooooooooool00_l00002
ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002
ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000003o`0000_ooooo000Y
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`04o`0000Kooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo1?l000000ooooooo0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Ko
oooo0_l00002ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000005ooooo`;o00001?ooool3o`00
00;ooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Go00001Oooool2o`00
00?ooooo1?l00003ooooo`Co00000oooool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2
o`0000Cooooo0ol00002ooooo`03o`000?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005
ooooo`;o00000oooool4o`0000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
00000ooooooo0000ooooo`02ooooo`04o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000oooool01?l0003oooooooooool00002ooooo`Go00000oooool01?l0003o
ooooo`000?l00003ooooo`Co00000oooool5o`0000;ooooo00?o0000ooooooooool00_l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000oooool2o`000004ooooool0003o
ooooo`0000;ooooo00?o0000ooooool000001Oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`?o000000Coooooo`000?oooooooooo
1?l00003ooooo`Co00000oooool4o`0000?ooooo1?l00003ooooo`Co00000_ooool01?l0003ooooo
ooooool0000<ooooo`00:Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool4o`0000?ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooool000001?ooool01?l0003oooooo`000?l00004ooooo`;o00000oooool00ol0003o
ooooooooo`02o`0000Gooooo0_l00003ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04
o`000?ooooooooooo`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
ool0003o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo
0000ooooool0003ooooo1?l000000ooooooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo
00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`;o00001Oooool2o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool0
0_ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool2o`000003ooooool0003ooooo
00?ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000
ooooool000000oooool4o`0000;ooooo1Ol00002ooooo`05o`000?oooooo0000ooooool000001?oo
ool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo
1?l00003ooooo`Co00000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo
1Ol00003ooooo`Co00000_ooool5o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooooooool2o`0000Cooooo0_l00002ooooo`05o`000?oooooooooo
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000003?ooool002Sooooo0_l0
0004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Co
oooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooooooo`?o00001?ooool4o`0000?ooooo0ol00003ooooo`03o`000?oooooo000000;o00000_oo
ool00ol0003oooooo`000002o`0000Cooooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo
0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000;ooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`00
0?oooooo0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003
ooooool0003ooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol000001_oooooo0000oooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003oooooooooo`;o00000ooo
ool01?l0003oooooo`000?l00003ooooo`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo
00?o0000ooooooooool00_l00004ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo
00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000oooooooo
ool00_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000
oooooooooooooooo0ol00003ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`00
00?ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo
000000;ooooo00Go0000ooooool0003oooooo`000004ooooo`;o00003?ooool002Wooooo00?o0000
ooooooooool00oooool3o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?oo
ool2o`0000?ooooo1Ol00003ooooo`?o00001?ooool3o`0000;ooooo00?o0000ooooooooool00ooo
ool2o`0000Gooooo0_l00004ooooo`?o00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo
1Ol00004ooooo`;o00000oooool5o`0000?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo
0ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo
1Ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo
1?l00004ooooo`?o00000_ooool6o`0000Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo
1?l00004ooooo`?o00001?ooool00ol0003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo
0_l00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo
1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go000000?oooooo`000?l00000
1?l00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo
0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-4.70015, -0.0170195, 0.142355, \
0.000799977}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 4.47182 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10415 -24 -4.5 ]
[-0.0125 .10415 0 4.5 ]
[-0.0125 .19359 -24 -4.5 ]
[-0.0125 .19359 0 4.5 ]
[-0.0125 .28302 -24 -4.5 ]
[-0.0125 .28302 0 4.5 ]
[-0.0125 .37246 -24 -4.5 ]
[-0.0125 .37246 0 4.5 ]
[-0.0125 .4619 -18 -4.5 ]
[-0.0125 .4619 0 4.5 ]
[-0.0125 .55133 -24 -4.5 ]
[-0.0125 .55133 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10415 m
.00625 .10415 L
s
[(0.02)] -0.0125 .10415 1 0 Mshowa
0 .19359 m
.00625 .19359 L
s
[(0.04)] -0.0125 .19359 1 0 Mshowa
0 .28302 m
.00625 .28302 L
s
[(0.06)] -0.0125 .28302 1 0 Mshowa
0 .37246 m
.00625 .37246 L
s
[(0.08)] -0.0125 .37246 1 0 Mshowa
0 .4619 m
.00625 .4619 L
s
[(0.1)] -0.0125 .4619 1 0 Mshowa
0 .55133 m
.00625 .55133 L
s
[(0.12)] -0.0125 .55133 1 0 Mshowa
.125 Mabswid
0 .03707 m
.00375 .03707 L
s
0 .05943 m
.00375 .05943 L
s
0 .08179 m
.00375 .08179 L
s
0 .12651 m
.00375 .12651 L
s
0 .14887 m
.00375 .14887 L
s
0 .17123 m
.00375 .17123 L
s
0 .21595 m
.00375 .21595 L
s
0 .23831 m
.00375 .23831 L
s
0 .26067 m
.00375 .26067 L
s
0 .30538 m
.00375 .30538 L
s
0 .32774 m
.00375 .32774 L
s
0 .3501 m
.00375 .3501 L
s
0 .39482 m
.00375 .39482 L
s
0 .41718 m
.00375 .41718 L
s
0 .43954 m
.00375 .43954 L
s
0 .48426 m
.00375 .48426 L
s
0 .50662 m
.00375 .50662 L
s
0 .52897 m
.00375 .52897 L
s
0 .57369 m
.00375 .57369 L
s
0 .59605 m
.00375 .59605 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10415 m
1 .10415 L
s
.99375 .19359 m
1 .19359 L
s
.99375 .28302 m
1 .28302 L
s
.99375 .37246 m
1 .37246 L
s
.99375 .4619 m
1 .4619 L
s
.99375 .55133 m
1 .55133 L
s
.125 Mabswid
.99625 .03707 m
1 .03707 L
s
.99625 .05943 m
1 .05943 L
s
.99625 .08179 m
1 .08179 L
s
.99625 .12651 m
1 .12651 L
s
.99625 .14887 m
1 .14887 L
s
.99625 .17123 m
1 .17123 L
s
.99625 .21595 m
1 .21595 L
s
.99625 .23831 m
1 .23831 L
s
.99625 .26067 m
1 .26067 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32774 m
1 .32774 L
s
.99625 .3501 m
1 .3501 L
s
.99625 .39482 m
1 .39482 L
s
.99625 .41718 m
1 .41718 L
s
.99625 .43954 m
1 .43954 L
s
.99625 .48426 m
1 .48426 L
s
.99625 .50662 m
1 .50662 L
s
.99625 .52897 m
1 .52897 L
s
.99625 .57369 m
1 .57369 L
s
.99625 .59605 m
1 .59605 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .03355 L
.02181 .03355 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .03355 L
.02181 .03355 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .01628 L
.03738 .01628 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .01628 L
.03738 .01628 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .01628 L
.05296 .01628 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .01628 L
.05296 .01628 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .22504 L
.08411 .22504 L
.08411 .01472 L
F
.081 .01472 m
.081 .22504 L
.08411 .22504 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .01472 L
.09969 .01472 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .01472 L
.09969 .01472 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .13714 L
.11526 .13714 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .13714 L
.11526 .13714 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .04297 L
.14642 .04297 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .04297 L
.14642 .04297 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .0414 L
.16199 .0414 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .0414 L
.16199 .0414 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .09633 L
.17757 .09633 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .09633 L
.17757 .09633 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .01785 L
.19315 .01785 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .01785 L
.19315 .01785 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .02099 L
.20872 .02099 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .02099 L
.20872 .02099 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .28155 L
.2243 .28155 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .28155 L
.2243 .28155 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .02256 L
.23988 .02256 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .02256 L
.23988 .02256 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .01628 L
.25545 .01628 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .01628 L
.25545 .01628 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .02727 L
.27103 .02727 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .02727 L
.27103 .02727 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .07907 L
.2866 .07907 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .07907 L
.2866 .07907 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .24231 L
.30218 .24231 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .24231 L
.30218 .24231 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .01785 L
.31776 .01785 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .01785 L
.31776 .01785 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .24231 L
.33333 .24231 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .24231 L
.33333 .24231 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .03669 L
.34891 .03669 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .03669 L
.34891 .03669 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .01472 L
.36449 .01472 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .01472 L
.36449 .01472 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .02099 L
.38006 .02099 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .02099 L
.38006 .02099 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .25957 L
.39564 .25957 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .25957 L
.39564 .25957 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .24545 L
.41121 .24545 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .24545 L
.41121 .24545 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .02256 L
.44237 .02256 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .02256 L
.44237 .02256 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .02413 L
.45794 .02413 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .02413 L
.45794 .02413 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .29254 L
.47352 .29254 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .29254 L
.47352 .29254 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .01472 L
.4891 .01472 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .01472 L
.4891 .01472 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .03041 L
.52025 .03041 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .03041 L
.52025 .03041 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .02884 L
.53583 .02884 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .02884 L
.53583 .02884 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .16854 L
.5514 .16854 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .16854 L
.5514 .16854 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .01628 L
.56698 .01628 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .01628 L
.56698 .01628 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .24702 L
.58255 .24702 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .24702 L
.58255 .24702 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .03512 L
.59813 .03512 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .03512 L
.59813 .03512 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .01472 L
.61371 .01472 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .01472 L
.61371 .01472 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .02099 L
.62928 .02099 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .02099 L
.62928 .02099 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .24859 L
.64486 .24859 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .24859 L
.64486 .24859 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .04768 L
.66044 .04768 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .04768 L
.66044 .04768 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .01628 L
.69159 .01628 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .01628 L
.69159 .01628 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .05082 L
.70717 .05082 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .05082 L
.70717 .05082 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .24702 L
.72274 .24702 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .24702 L
.72274 .24702 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .02727 L
.75389 .02727 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .02727 L
.75389 .02727 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .30352 L
.78505 .30352 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .30352 L
.78505 .30352 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .24702 L
.80062 .24702 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .24702 L
.80062 .24702 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .01628 L
.8162 .01628 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .01628 L
.8162 .01628 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .18737 L
.83178 .18737 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .18737 L
.83178 .18737 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .0257 L
.84735 .0257 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .0257 L
.84735 .0257 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .01472 L
.86293 .01472 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .01472 L
.86293 .01472 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .05239 L
.8785 .05239 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .05239 L
.8785 .05239 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .19522 L
.89408 .19522 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .19522 L
.89408 .19522 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .27527 L
.90966 .27527 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .27527 L
.90966 .27527 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .19679 L
.97196 .19679 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .19679 L
.97196 .19679 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .12616 L
.02492 .12616 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .12616 L
.02492 .12616 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .34276 L
.0405 .34276 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .34276 L
.0405 .34276 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .04454 L
.05607 .04454 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .04454 L
.05607 .04454 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .12459 L
.07165 .12459 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .12459 L
.07165 .12459 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .01472 L
.08723 .01472 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .01472 L
.08723 .01472 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .39299 L
.1028 .39299 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .39299 L
.1028 .39299 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .04454 L
.11838 .04454 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .04454 L
.11838 .04454 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .33962 L
.13396 .33962 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .33962 L
.13396 .33962 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .26742 L
.14953 .26742 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .26742 L
.14953 .26742 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .14185 L
.16511 .14185 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .14185 L
.16511 .14185 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .04297 L
.18069 .04297 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .04297 L
.18069 .04297 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .04454 L
.19626 .04454 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .04454 L
.19626 .04454 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .1654 L
.21184 .1654 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .1654 L
.21184 .1654 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .01785 L
.22741 .01785 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .01785 L
.22741 .01785 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .01785 L
.24299 .01785 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .01785 L
.24299 .01785 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .31294 L
.25857 .31294 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .31294 L
.25857 .31294 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .03512 L
.27414 .03512 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .03512 L
.27414 .03512 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .11203 L
.28972 .11203 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .11203 L
.28972 .11203 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .0257 L
.3053 .0257 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .0257 L
.3053 .0257 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .10732 L
.32087 .10732 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .10732 L
.32087 .10732 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .10575 L
.35202 .10575 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .10575 L
.35202 .10575 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .02256 L
.3676 .02256 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .02256 L
.3676 .02256 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .13558 L
.38318 .13558 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .13558 L
.38318 .13558 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .02256 L
.39875 .02256 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .02256 L
.39875 .02256 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .01785 L
.41433 .01785 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .01785 L
.41433 .01785 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .06023 L
.42991 .06023 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .06023 L
.42991 .06023 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .05866 L
.44548 .05866 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .05866 L
.44548 .05866 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .02256 L
.46106 .02256 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .02256 L
.46106 .02256 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .02884 L
.47664 .02884 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .02884 L
.47664 .02884 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .35061 L
.50779 .35061 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .35061 L
.50779 .35061 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .04297 L
.52336 .04297 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .04297 L
.52336 .04297 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .09006 L
.53894 .09006 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .09006 L
.53894 .09006 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .03512 L
.55452 .03512 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .03512 L
.55452 .03512 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .04454 L
.57009 .04454 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .04454 L
.57009 .04454 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01785 L
.58567 .01785 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01785 L
.58567 .01785 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .07593 L
.60125 .07593 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .07593 L
.60125 .07593 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .11046 L
.6324 .11046 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .11046 L
.6324 .11046 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01942 L
.64798 .01942 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01942 L
.64798 .01942 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .04297 L
.66355 .04297 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .04297 L
.66355 .04297 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .0257 L
.67913 .0257 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .0257 L
.67913 .0257 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .0414 L
.6947 .0414 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .0414 L
.6947 .0414 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01942 L
.71028 .01942 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01942 L
.71028 .01942 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01628 L
.72586 .01628 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01628 L
.72586 .01628 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .0257 L
.74143 .0257 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .0257 L
.74143 .0257 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .13871 L
.75701 .13871 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .13871 L
.75701 .13871 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .07436 L
.81931 .07436 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .07436 L
.81931 .07436 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .02727 L
.83489 .02727 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .02727 L
.83489 .02727 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .0414 L
.85047 .0414 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .0414 L
.85047 .0414 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .15755 L
.88162 .15755 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .15755 L
.88162 .15755 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01785 L
.8972 .01785 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01785 L
.8972 .01785 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .02099 L
.91277 .02099 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .02099 L
.91277 .02099 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .01628 L
.94393 .01628 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .01628 L
.94393 .01628 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .01785 L
.01246 .01785 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .01785 L
.01246 .01785 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .11203 L
.02804 .11203 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .11203 L
.02804 .11203 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .02884 L
.04361 .02884 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .02884 L
.04361 .02884 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .12773 L
.05919 .12773 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .12773 L
.05919 .12773 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .01628 L
.07477 .01628 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .01628 L
.07477 .01628 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .01785 L
.09034 .01785 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .01785 L
.09034 .01785 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .01942 L
.10592 .01942 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .01942 L
.10592 .01942 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .13871 L
.1215 .13871 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .13871 L
.1215 .13871 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .05396 L
.13707 .05396 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .05396 L
.13707 .05396 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .14185 L
.15265 .14185 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .14185 L
.15265 .14185 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .06494 L
.16822 .06494 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .06494 L
.16822 .06494 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .11517 L
.1838 .11517 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .11517 L
.1838 .11517 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .03041 L
.19938 .03041 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .03041 L
.19938 .03041 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .14813 L
.21495 .14813 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .14813 L
.21495 .14813 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .03983 L
.23053 .03983 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .03983 L
.23053 .03983 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .19522 L
.24611 .19522 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .19522 L
.24611 .19522 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .02413 L
.26168 .02413 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .02413 L
.26168 .02413 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .16226 L
.27726 .16226 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .16226 L
.27726 .16226 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .11203 L
.29283 .11203 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .11203 L
.29283 .11203 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .03669 L
.30841 .03669 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .03669 L
.30841 .03669 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .02727 L
.32399 .02727 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .02727 L
.32399 .02727 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .02884 L
.33956 .02884 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .02884 L
.33956 .02884 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .14185 L
.35514 .14185 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .14185 L
.35514 .14185 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .14342 L
.37072 .14342 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .14342 L
.37072 .14342 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .05082 L
.38629 .05082 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .05082 L
.38629 .05082 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .02413 L
.40187 .02413 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .02413 L
.40187 .02413 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .03198 L
.41745 .03198 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .03198 L
.41745 .03198 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .16226 L
.43302 .16226 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .16226 L
.43302 .16226 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .12773 L
.4486 .12773 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .12773 L
.4486 .12773 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .15127 L
.46417 .15127 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .15127 L
.46417 .15127 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .03355 L
.47975 .03355 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .03355 L
.47975 .03355 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .10889 L
.49533 .10889 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .10889 L
.49533 .10889 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .01628 L
.5109 .01628 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .01628 L
.5109 .01628 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .14028 L
.52648 .14028 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .14028 L
.52648 .14028 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .05239 L
.54206 .05239 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .05239 L
.54206 .05239 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .15755 L
.55763 .15755 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .15755 L
.55763 .15755 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .03355 L
.57321 .03355 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .03355 L
.57321 .03355 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .01628 L
.58879 .01628 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .01628 L
.58879 .01628 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .06651 L
.60436 .06651 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .06651 L
.60436 .06651 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .14656 L
.61994 .14656 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .14656 L
.61994 .14656 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .07907 L
.63551 .07907 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .07907 L
.63551 .07907 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .02099 L
.65109 .02099 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .02099 L
.65109 .02099 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .17168 L
.66667 .17168 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .17168 L
.66667 .17168 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .14342 L
.68224 .14342 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .14342 L
.68224 .14342 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .03355 L
.69782 .03355 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .03355 L
.69782 .03355 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .18109 L
.7134 .18109 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .18109 L
.7134 .18109 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .03826 L
.72897 .03826 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .03826 L
.72897 .03826 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .13401 L
.74455 .13401 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .13401 L
.74455 .13401 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .09477 L
.76012 .09477 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .09477 L
.76012 .09477 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .12145 L
.7757 .12145 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .12145 L
.7757 .12145 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .02413 L
.79128 .02413 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .02413 L
.79128 .02413 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .01942 L
.80685 .01942 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .01942 L
.80685 .01942 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .09006 L
.82243 .09006 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .09006 L
.82243 .09006 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .14656 L
.83801 .14656 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .14656 L
.83801 .14656 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .15598 L
.85358 .15598 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .15598 L
.85358 .15598 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .11517 L
.86916 .11517 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .11517 L
.86916 .11517 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .13401 L
.88474 .13401 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .13401 L
.88474 .13401 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01785 L
.90031 .01785 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01785 L
.90031 .01785 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .03041 L
.91589 .03041 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .03041 L
.91589 .03041 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .13714 L
.93146 .13714 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .13714 L
.93146 .13714 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .09006 L
.94704 .09006 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .09006 L
.94704 .09006 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .07907 L
.96262 .07907 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .07907 L
.96262 .07907 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .01785 L
.97819 .01785 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .01785 L
.97819 .01785 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .07279 L
.99377 .07279 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .07279 L
.99377 .07279 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .12459 L
.01558 .12459 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .12459 L
.01558 .12459 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .14028 L
.03115 .14028 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .14028 L
.03115 .14028 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .1654 L
.04673 .1654 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .1654 L
.04673 .1654 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .02413 L
.06231 .02413 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .02413 L
.06231 .02413 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .3616 L
.07788 .3616 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .3616 L
.07788 .3616 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .01628 L
.09346 .01628 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .01628 L
.09346 .01628 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .16226 L
.10903 .16226 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .16226 L
.10903 .16226 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .01785 L
.12461 .01785 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .01785 L
.12461 .01785 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .15755 L
.14019 .15755 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .15755 L
.14019 .15755 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .05552 L
.15576 .05552 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .05552 L
.15576 .05552 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .14656 L
.17134 .14656 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .14656 L
.17134 .14656 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .02413 L
.18692 .02413 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .02413 L
.18692 .02413 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .3616 L
.20249 .3616 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .3616 L
.20249 .3616 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .03826 L
.21807 .03826 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .03826 L
.21807 .03826 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .04297 L
.23364 .04297 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .04297 L
.23364 .04297 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .01472 L
.24922 .01472 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .01472 L
.24922 .01472 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .23603 L
.2648 .23603 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .23603 L
.2648 .23603 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .01628 L
.28037 .01628 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .01628 L
.28037 .01628 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .08849 L
.29595 .08849 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .08849 L
.29595 .08849 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .02727 L
.31153 .02727 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .02727 L
.31153 .02727 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .35061 L
.3271 .35061 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .35061 L
.3271 .35061 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .0257 L
.34268 .0257 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .0257 L
.34268 .0257 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .02413 L
.35826 .02413 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .02413 L
.35826 .02413 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .01472 L
.37383 .01472 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .01472 L
.37383 .01472 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .29097 L
.38941 .29097 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .29097 L
.38941 .29097 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .01628 L
.40498 .01628 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .01628 L
.40498 .01628 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .03512 L
.42056 .03512 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .03512 L
.42056 .03512 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .01472 L
.43614 .01472 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .01472 L
.43614 .01472 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .04297 L
.45171 .04297 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .04297 L
.45171 .04297 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .01472 L
.46729 .01472 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .01472 L
.46729 .01472 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .02099 L
.48287 .02099 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .02099 L
.48287 .02099 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .01472 L
.49844 .01472 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .01472 L
.49844 .01472 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .11203 L
.51402 .11203 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .11203 L
.51402 .11203 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .02413 L
.5296 .02413 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .02413 L
.5296 .02413 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .22818 L
.54517 .22818 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .22818 L
.54517 .22818 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .05082 L
.56075 .05082 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .05082 L
.56075 .05082 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .33335 L
.57632 .33335 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .33335 L
.57632 .33335 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .01785 L
.5919 .01785 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .01785 L
.5919 .01785 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .258 L
.60748 .258 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .258 L
.60748 .258 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .01472 L
.62305 .01472 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .01472 L
.62305 .01472 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .20621 L
.63863 .20621 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .20621 L
.63863 .20621 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .01942 L
.65421 .01942 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .01942 L
.65421 .01942 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .02727 L
.66978 .02727 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .02727 L
.66978 .02727 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .01472 L
.68536 .01472 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .01472 L
.68536 .01472 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .33962 L
.70093 .33962 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .33962 L
.70093 .33962 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .01628 L
.71651 .01628 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .01628 L
.71651 .01628 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .02884 L
.73209 .02884 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .02884 L
.73209 .02884 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .01628 L
.74766 .01628 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .01628 L
.74766 .01628 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .15127 L
.76324 .15127 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .15127 L
.76324 .15127 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .01472 L
.77882 .01472 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .01472 L
.77882 .01472 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .02256 L
.79439 .02256 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .02256 L
.79439 .02256 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .02099 L
.80997 .02099 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .02099 L
.80997 .02099 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .15912 L
.82555 .15912 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .15912 L
.82555 .15912 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .01628 L
.84112 .01628 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .01628 L
.84112 .01628 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .01785 L
.8567 .01785 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .01785 L
.8567 .01785 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .01472 L
.87227 .01472 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .01472 L
.87227 .01472 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .0618 L
.88785 .0618 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .0618 L
.88785 .0618 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .01942 L
.90343 .01942 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .01942 L
.90343 .01942 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .03041 L
.919 .03041 L
.919 .01472 L
F
.91589 .01472 m
.91589 .03041 L
.919 .03041 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .01472 L
.93458 .01472 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .01472 L
.93458 .01472 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .01942 L
.95016 .01942 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .01942 L
.95016 .01942 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .01472 L
.96573 .01472 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .01472 L
.96573 .01472 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .0257 L
.98131 .0257 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .0257 L
.98131 .0257 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .01472 L
.99688 .01472 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .01472 L
.99688 .01472 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol0000;ooooo`00:Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000<ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000003?ooool002Sooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Uoooooooo0000aOl0000;ooooo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`007?ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o
0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_oo
O`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l0
0?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o
0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o
0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo
0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00?oogl000Co
o`00o`3o0?l0o`3o003o0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0
o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00oooO`001?oo003o0?l0o`3o0?l0
0?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o
0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0ooo
O`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o
0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`00
0_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`00
00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003o
o`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl0
0_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`000ol0003ooooo
ooooo`09ooooo`006oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;o0?l0
00Go003ooomo0?ooO`3oooooool00002o`3o0003o`00ooooO`3oogl000;ooooo0_l0o`001Ol00?oo
ogl0oomo0?ooO`3ooooo00;o0?l000Go003ooomo0?ooO`3oogl0ooooo`03o`3o00?oogl00_oo0000
0ooooooo003oo`00o`03ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o0005o`00oooo
O`3oogl0oomo0?ooool00_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Go003ooomo0?oo
O`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02
ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0
o`00ooooO`000_ooO`02ool00003o`3o0?l00?oo003o00Cooooo00?o0?l0o`00ooooO`000_ooO`02
ool00003o`3o0?l00?oo003o00;ooooo0_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0
o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl00ooo0002o`00o`;oogl00_oo0000
0ol0o`3o003oo`00o`02oomo00;ooooo00Go0?l0o`00ool00?oo003oooooo`02ool00003o`3o0?l0
0?oo003o00;oogl00_oo00001Ol0o`3o003oo`00ool00?oooooo00;oo`0000?o0?l0o`00ool00?l0
0_ooO`02ooooo`04o`3o0?l00?oo003oo`00o`;ooooo00Coo`00o`3o0?l00?oo003o0_ooO`000ooo
ooooo`00o`3o0003o`00o`;ooooo00Coo`00o`3o0?l00?oo003o0_ooO`03ooooo`?o003o0oooool2
o`3o0006ooooooooO`3oogl0oooooooo003o0?l00_l00?l2oomo0003oooooooo003o0?l000;o003o
0_ooO`001Oooooooo`00o`3o0?l0o`3o003o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oooo
oooo00000ol0o`02oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`04ooooo`;o003o0_ooool0
1?oo003o0?l0o`3o0?l00?l2oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`001Oooooooo`00
o`3o0?l0o`3o003o00;oogl00_ooool2o`3o00;o003o0oooool2o`3o0005o`00ooooO`3oogl0oomo
0?oo00000_l0o`02o`00o`;ooooo0_oo00000ooooooo003ooomo0002oomo0003ooooool0o`3o0?l0
00;o003o0_ooool01?oo003o0?l0o`3o0?l00?l3oomo00?ooooo0_l00?l2ooooo`;oo`0000?ooooo
o`00ooooO`000_ooO`03ool00004o`00ooooO`3oogl0oomo00;ooooo00?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?oo003o00;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?ooooo0_l0
0?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003ooomo0002oomo00?ooooo0ol00?l4ooooo`;o003o0_ooO`03ooooo`?o003o00Co
ooooool00?oo003oo`000_l00?l2oomo00?ooooo0ol00?l00ooooooo0000ooooo`0:ooooo`006ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?o0?l00_ooO`001Oooooooo`00
o`3o0?l0o`3o003o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo0?ooool00_l0o`001Ol0
0?ooogl0oomo0?ooO`3ooooo00?o0?l00oooO`02ool000Kooooo0_l0o`001Ol00?ooogl0oomo0?oo
O`3oo`0000;o0?l00_l00?l3ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o0005o`00
ooooO`3oogl0oomo0?oo00000_l0o`001?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl0
00;oogl00_ooool00ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ool0
0004o`00ooooO`3oogl0oomo00?oo`000_l00?l4ooooo`03o`3o0?l00?ooogl000;oogl00_oo0000
0ol0o`3o003oo`00o`02ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?oo
003o00;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?oo`000_l00?l2oomo00;oo`0000?o0?l0
o`00ool00?l00_ooO`02ooooo`05o`3o0?l00?oo003oo`00ooooool00_oo00000ol0o`3o003oo`00
o`02oomo00;oo`0000Go0?l0o`00ool00?oo003oooooo`03ool000;o003o0_ooO`02ooooo`04o`3o
0?l00?oo003oo`00o`;ooooo00Coo`00o`3o0?l00?oo003o0_ooO`000oooooooo`00o`3o0003o`00
o`;ooooo00Coo`00o`3o0?l00?oo003o0_ooO`03ooooo`?o003o0oooool2o`3o0006ooooooooO`3o
ogl0oooooooo003o0?l00_l00?l2oomo0003oooooooo003o0?l000;o003o0_ooO`001Oooooooo`00
o`3o0?l0o`3o003o00;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool01?oo
003o0?l0o`3o0?l00?l2oomo00Cooooo0_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`;oogl000Go
ooooool00?l0o`3o0?l0o`00o`02oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`02ooooo`;o
0?l00_l00?l3ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o00;o003o0_ooool2ool0
0003ooooool00?ooogl000;oogl000?oooooo`3o0?l0o`000_l00?l2ooooo`04ool00?l0o`3o0?l0
o`00o`?oogl00oooool2o`00o`;ooooo0_oo00000ooooooo003ooomo0002oomo00?oo`0000Co003o
oomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l00_oo
ool2ool00003o`3o0?l00?oo003o00Gooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_oo
O`03ool00004ooooooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ooooo`?o003o
1?ooool2o`00o`;oogl00oooool3o`00o`04oooooooo003oo`00ool000;ooooo0_ooO`03ooooo`?o
003o00?oooooo`000?ooool02_ooool001cooooo0_l00007ooooo`03o`000?oooooooooo00?o0?l0
0_ooO`001Oooooooo`00o`3o0?l0o`3o003o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo
0?ooool00_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00?o0?l00oooO`02ool000Kooooo0ol0o`03
oomo0003ool00?l0o`3o0?l000;o003o0oooool2o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0
o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o
003ooomo0002oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;o
ogl00ooo00001?l00?ooogl0oomo0?ooO`03ool000;o003o1?ooool00ol0o`3o003ooomo0002oomo
00;oo`0000?o0?l0o`00ool00?l00_ooool2ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0
o`3o003oo`00o`02oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ool000;o003o0_ooO`02ool0
0003o`3o0?l00?oo003o00;oogl00_ooool01Ol0o`3o003oo`00ool00?oooooo00;oo`0000?o0?l0
o`00ool00?l00_ooO`02ool00005o`3o0?l00?oo003oo`00ooooool00ooo0002o`00o`;oogl00_oo
ool01?l0o`3o003oo`00ool00?l2ooooo`04ool00?l0o`3o003oo`00o`;oogl000?oooooool00?l0
o`000ol00?l2ooooo`04ool00?l0o`3o003oo`00o`;oogl00oooool3o`00o`?ooooo0_l0o`001_oo
ooooogl0oomo0?ooooooo`00o`3o00;o003o0_ooO`000oooooooo`00o`3o0002o`00o`;oogl000Go
ooooool00?l0o`3o0?l0o`00o`02oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Go
oooo00Coo`00o`3o0?l0o`3o003o0_ooO`04ooooo`;o003o0_ooool01?oo003o0?l0o`3o0?l00?l2
oomo0004oooooooo003oo`00ooooo`;o003o0_ooool01?oo003o0?l0o`3o0?l00?l2oomo00;ooooo
0_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool00003ooooool00?oo003o00;o
oooo0_oo00000ooooooo003ooomo0002oomo0003ooooool0o`3o0?l000;o003o0_ooool01?oo003o
0?l0o`3o0?l00?l3oomo00?ooooo0_l00?l2ooooo`;oo`0000?oooooo`00ooooO`000_ooO`03ool0
0004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?oo
003o00;ooooo0_oo00000ol0o`3o003oo`00o`05ooooo`;o003o0_ooool2ool00003o`3o0?l00?oo
ogl000;oogl00ooo0004ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ooooo`?o003o1?ooool3
o`00o`Cooooo0ol00?l01?ooooooo`00ool00?oo0002ooooo`;oogl00oooool3o`00o`03ooooool0
003ooooo00[ooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`001Oooooooo`00o`3o0?l0
o`3o003o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo0?ooool00_l0o`001Ol00?ooogl0
oomo0?ooO`3ooooo00?o0?l00oooO`02ool000Kooooo0ol0o`03oomo0003ool00?l0o`3o0?l000;o
003o0oooool2o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?ooogl0oomo0?ooO`3o
o`0000;o0?l000Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo00;ooooo00?o
0?l0o`00ooooO`000_ooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?l00?ooogl0oomo
0?ooO`03ooooo`;o003o1?ooool00ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l0
0_ooool2ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;ooooo
00?o0?l0o`00ool00?l00_ooO`03ool000;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl0
0oooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ool000?o003o00Coooooool00?oo003o
o`000_l00?l2oomo00;ooooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo
0003oooooooo003oo`0000?o003o0_ooool00ooo003o0?l0o`00o`02o`00o`Cooooo0ol00?l3oooo
o`;o0?l000Kooooooomo0?ooO`3oooooool00?l0o`02o`00o`;oogl000?oooooool00?l0o`000_l0
0?l2oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3o
oooo0_oo0005ooooo`04ool00?l0o`3o0?l0o`00o`;oogl01?ooool2o`00o`?ooooo0_l0o`001?l0
0?ooogl0oomo0?ooool2ool000Gooooo00Coo`00o`3o0?l0o`3o003o0_ooO`02ooooo`;o0?l00_l0
0?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo00000ooooooo003oo`00o`02ooooo`;oo`00
00?oooooo`00ooooO`000_ooO`000ooooooo0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o
003o0oooO`03ooooo`;o003o0_ooool2ool00003ooooool00?oo003o00;ooooo0ooo0006ooooo`03
o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003oo`00o`02ooooo`;oo`0000?o0?l0o`00ool0
0?l01Oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool00004
o`00ooooO`3oogl0oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00
ool000;ooooo0_ooO`03ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o0000oooo
ooooool00ol0o`02oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`02ooooo`;o0?l000Go003o
oomo0?ooO`3oogl0ooooo`02o`3o00;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00ooo
O`000ooo003o0?l0o`3o0002o`00o`?ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l0
00Go003ooomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00
ool00?l01?ooool00ol0o`3o003ooomo0002oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03ool0
0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l4ooooo`;o0?l00oooO`02ool00003o`3o0?l00?oo
003o00;ooooo0_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02
ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002o`00o`;oogl00_oo00001?l0o`3o003oo`00ool0
0?l4ooooo`?o003o0oooool00ol0o`3o003oo`00o`02oomo00?oo`001?ooool3ool000;o003o0_oo
O`02ooooo`04o`3o0?l00?oo003oo`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ooooo`?o003o
0_ooool00ooo003o0?l0o`00o`02o`00o`Cooooo0ol00?l3ooooo`;o0?l000Kooooooomo0?ooO`3o
ooooool00?l0o`03o`00o`;ooooo00Coo`00o`3o0?l00?oo003o0_ooO`001Oooooooo`00o`3o0?l0
o`3o003o00;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool01?oo003o0?l0
o`3o0?l00?l2oomo00Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005oooo
o`04ool00?l0o`3o0?l0o`00o`;oogl00_ooool2o`3o00;o003o0oooool2o`3o0004o`00ooooO`3o
ogl0oomo00;oo`0000?oooooo`00ool00?l00_ooool2ool00003ooooool00?ooogl000;oogl000?o
ooooo`3o0?l0o`000_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?oogl00oooool2o`00o`;ooooo
0_oo0005ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l0
0_ooool2ool00003o`3o0?l00?oo003o00Gooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`00
0_ooO`03ool000Cooooo0ooo00001?l00?ooogl0oomo0?ooO`03ooooo`?o003o1?ooool3o`00o`Co
oooo0ol00?l01?ooooooo`00ool00?oo0002ooooo`;oogl00oooool3o`00o`03ooooool0003ooooo
00[ooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`001Oooooooo`00o`3o0?l0o`3o003o
00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo0?ooool00_l0o`02o`00o`?ooooo0ol0o`03
oomo00;oo`001_ooool3o`3o00?oogl000?oo`00o`3o0?l0o`000_l00?l3ooooo`;o0?l000Go003o
oomo0?ooO`3oogl0ool00002o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0o`001?l00?ooogl0
oomo0?ooO`02ool00003o`3o0?l00?oo003o00Cooooo00?o0?l0o`00ooooO`000_ooO`02ooooo`03
o`3o0?l00?ooogl000;oogl00ooo00001?l00?ooogl0oomo0?ooO`03ooooo`;o003o1?ooool2o`3o
00?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool0
00?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`000ol00?l01?ooooooo`00ool00?l0o`03
o`00o`Cooooo0ol00?l3ooooo`03o`3o0?l00?oo003o00;oogl00ooo0004ooooo`?oo`000_l00?l2
oomo00;ooooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo00?ooooo0ol0
0?l2ooooo`03ool00?l0o`3o003o00;o003o1?ooool3o`00o`?ooooo0_l0o`001_ooooooogl0oomo
0?ooooooo`00o`3o00?o003o0_ooool01?oo003o0?l0o`00ool00?l2oomo0005oooooooo003o0?l0
o`3o0?l00?l00_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`04ool00?l0
o`3o0?l0o`00o`;oogl01?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Go
oooo00?oo`00o`3o0?l0o`000_l00?l5ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo
00;oo`0000?oooooo`00ool00?l00_ooool2ool00003ooooool00?ooogl000;oogl00oooool2o`00
o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0006
ooooo`03o`3o0?l00?ooogl000;oogl00ooo0002o`00o`Cooooo00?o0?l0o`00ool00?l01Oooool2
o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool00004o`00ooooO`3o
ogl0oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool000Oooooo
0ol00?l00ooooooo0000ooooo`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl000Go
ooooool00?l0o`3o0?l0o`00o`02oomo00;ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o
0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`000ooo003o0?l0o`3o0002o`00o`?ooooo
0_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o
0004o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ool00?l01?ooool00ol0o`3o003ooomo0002
oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03ool00004o`00ooooO`3oogl0oomo00?ooooo0_l0
0?l4ooooo`;o0?l00oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0_oo00000ol0o`3o003ooomo
0002oomo00?oo`000ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`;oo`0000Co
0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ool000Cooooo
0ooo0002o`00o`;oogl00_ooool01?l0o`3o003oo`00ool00?l3ooooo`03o`3o0?l00?oo003o00;o
ogl00oooool3o`00o`;ooooo0_oo0003o`00o`Cooooo0ol00?l3ooooo`;o0?l000Kooooooomo0?oo
O`3oooooool00?l0o`03o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`001Oooooooo`00o`3o0?l0
o`3o003o00;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool01?oo003o0?l0
o`3o0?l00?l2oomo00Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005oooo
o`03ool00?l0o`3o0?l000;o003o1Oooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`02
ool00003ooooool00?oo003o00;ooooo0_oo00000ooooooo003oo`00o`05ooooo`;o003o0oooool2
o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`001Oooool3ool000Kooooo00?o
0?l0o`00ooooO`000_ooO`03ool000;o003o1?ooool00ol0o`3o003oo`00o`05ooooo`;o003o0_oo
ool2ool00003o`3o0?l00?ooogl000;oogl00ooo0004ooooo`?oo`0000Co003ooomo0?ooO`3oogl0
0oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o00Coooooool00?oo003oo`001oooool3o`00o`03
ooooool0003ooooo00[ooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`001Oooooooo`00
o`3o0?l0o`3o003o00;oogl00_ooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o
0?l00oooO`02ool000Kooooo0ol0o`03oomo0003ool00?l0o`3o0?l000;o003o0oooool2o`3o0005
o`00ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003o
oomo0?ooO`3oogl00_oo00000ol0o`3o003oo`00o`04ooooo`;o0?l00oooO`02ooooo`03o`3o0?l0
0?ooogl000;oogl00ooo00001?l00?ooogl0oomo0?ooO`03ooooo`;o003o1?ooool2o`3o00?oogl0
0_ooool00ol0o`3o003oo`00o`02ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000?o003o
0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool2ool00004o`3o0?l00?oo003oo`00o`Co
oooo0ol00?l3ooooo`03o`3o0?l00?oo003o00;oogl00ooo0004ooooo`?oo`000_l00?l2oomo00;o
oooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo00?ooooo0ol00?l2oooo
o`;oo`000ol00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000;ooooo00Co0?l0o`00
ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo0005oooooooo003o0?l0o`3o0?l00?l00_oo
O`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`04ool00?l0o`3o0?l0o`00o`;o
ogl01?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Gooooo00?oo`00o`3o
0?l0o`000_l00?l5ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00;oo`0000?ooooo
o`00ool00?l00_ooool2ool00003ooooool00?oo003o00Gooooo0_l00?l3ooooo`;o0?l000Co003o
oomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001_ooool00ol0o`3o003ooomo
0002oomo00?oo`000_l00?l4ooooo`03o`3o0?l00?oo003o00Gooooo0_l00?l2ooooo`;oo`0000?o
0?l0o`00ooooO`000_ooO`03ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol0
0?l01?ooooooo`00ool00?oo0007ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o
0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00ooo
O`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00;oo`001_ooool3o`3o00?oogl000?o
o`00o`3o0?l0o`000_l00?l3ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o0005o`00
ooooO`3oogl0oomo0?oo00000_l0o`001?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?oo003o
00Cooooo0_l0o`03oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03ool00004o`00ooooO`3oogl0
oomo00?ooooo0_l00?l4ooooo`;o0?l00oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0_oo0000
0ol0o`3o003ooomo0002oomo00?oo`000ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004
ooooo`;oo`0000Co0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_oo
O`03ool000Cooooo0ooo0002ooooo`;oogl00_ooool01?l0o`3o003oo`00ool00?l3ooooo`03o`3o
0?l00?oo003o00;oogl00oooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003oooo
ooooO`3oogl000;ooooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo0005
oooooooo003o0?l0o`3o0?l00?l00_ooO`02ooooo`?o0?l00_ooO`000oooooooo`00ool00005oooo
o`04ool00?l0o`3o0?l0o`00o`;oogl01?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?oo
ool2ool000Gooooo00?oo`00o`3o0?l0o`000_l00?l5ooooo`;o003o0oooool3o`3o00?oogl00_oo
00000ooooooo003oo`00o`02ooooo`;oo`0000?oooooo`00ool00?l01Oooool2o`00o`?ooooo0_l0
o`001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0006ooooo`03o`3o
0?l00?ooogl000;oogl00ooo0002o`00o`Cooooo00?o0?l0o`00ool00?l01Oooool2o`00o`;ooooo
0_oo00000ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o
1?ooool3o`00o`04oooooooo003oo`00ool000Oooooo0ol00?l00ooooooo0000ooooo`0:ooooo`00
9Oooool3o`0000?o0?l00_ooO`02ooooo`;o0?l000?o003ooomo0?ooO`000_ooool3o`3o00?oogl0
00?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo0003ool0
0?l0o`3o0?l000;o003o0oooool2o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?oo
ogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003oo`00o`04
ooooo`;o0?l00oooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?l00?ooogl0oomo0?oo
O`03ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo
0002oomo00?oo`000ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`;oo`0000Co
0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ool000Cooooo
0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ooooo`?o
003o0_ooool2ool000Oooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000_ooool01?l0o`3o
003oo`00ool00?l3ooooo`03o`3o0?l00?oo003o00;oogl000Goooooool00?oo003oooooo`00o`02
oomo00;ooooo0ol0o`02oomo0003oooooooo003oo`0000Kooooo0_l0o`000ol00?ooogl0oomo0004
ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool00ooo003o0?l0o`3o
0002o`00o`Gooooo0_l00?l3ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00;ooooo0_oo
00000ooooooo003oo`00o`05ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo
0_l00?l2ooooo`;oo`001Oooool3ool000Kooooo00?o0?l0o`00ooooO`000_ooO`03ool000;o003o
1?ooool00ol0o`3o003oo`00o`05ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl0
0ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o00Coooooool00?oo003o
o`001oooool3o`00o`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo
0ol0o`03oomo00;oo`001_ooool3o`3o00?oogl000?oo`00o`3o0?l0o`000_l00?l3ooooo`;o0?l0
00Go003ooomo0?ooO`3oogl0ool00002o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0o`001?l0
0?ooogl0oomo0?ooO`02ool00003o`3o0?l00?oo003o00Cooooo0_l0o`03oomo00;ooooo00?o0?l0
o`00ool00?l00_ooool3ool00004o`00ooooO`3oogl0oomo00?ooooo0_l00?l4ooooo`;o0?l00ooo
O`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0006ooooo`;o0?l000?o
oooooomo0?ooO`000ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`03o`3o
0?l00?oo003o00;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l3ooooo`03
o`3o0?l00?oo003o00;oogl00oooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003
ooooooooO`3oogl000;ooooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo
0005oooooooo003oo`00ooooool00?l00_ooO`02ooooo`?o0?l00_ooO`000oooooooo`00ool00006
ooooo`;o0?l000?o003ooomo0?ooO`001?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?oo
ool2ool000Gooooo00?oo`00o`3o0?l0o`000_l00?l5ooooo`;o003o0oooool3o`3o00?oogl00_oo
00000ooooooo003oo`00o`02ooooo`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo
0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl0
0ooo0002o`00o`Cooooo00?o0?l0o`00ool00?l01Oooool2o`00o`;ooooo0_oo00000ol0o`3o003o
oomo0002oomo00?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooo
oooo003oo`00ool000Oooooo0ol00?l00ooooooo0000ooooo`0:ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo0003oooo
ool0o`3o0?l000;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`000ooo003o0?l0
o`3o0002o`00o`?ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Go003ooomo0?oo
O`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ool00?l01?ooool2
o`3o00?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo
ool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_oo
O`03ool000Kooooo0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o
1?ooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o
0?l00?oo003oo`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`03ooooo`?o003o0_ooool2ool000Oo
oooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000_ooool01?l0o`3o003oo`00ool00?l3oooo
o`03o`3o0?l00?oo003o00;oogl000Goooooool00?oo003oooooo`00o`02oomo00;ooooo0ol0o`02
oomo0003oooooooo003oo`0000Kooooo0_l0o`000ol00?ooogl0oomo0004ooooo`;o003o0oooool2
o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool00ooo003o0?l0o`3o0002o`00o`Gooooo0_l0
0?l3ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00;ooooo0_oo0008ooooo`;o003o0ooo
ool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`001Oooool3ool000Kooooo
00?o0?l0o`00ooooO`000_ooO`03ool000;o003o1?ooool00ol0o`3o003oo`00o`05ooooo`;o003o
0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0004ooooo`?oo`001oooool3o`00o`Cooooo
0ol00?l4ooooo`?o003o00Coooooool00?oo003oo`001oooool3o`00o`03ooooool0003ooooo00[o
oooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`02ooooo`;o0?l000?o003ooomo0?ooO`00
0_ooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo
0ol0o`03oomo0003ool00?l0o`3o0?l000;o003o0oooool2o`3o0005o`00ooooO`3oogl0oomo0?oo
00000_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o0?l000Co003ooomo0?ooO`3oogl00_oo0000
0ol0o`3o003oo`00o`04ooooo`;o0?l00oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0000
1?ooooooogl0oomo0?ooO`03ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo
00000ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_oo
ool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool00ol0o`3o003oo`00o`02oomo00?oo`00
1?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o0oooool00ol0o`3o003oo`00o`02oomo00?o
oooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0002ooooo`04
o`3o0?l00?oo003oo`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`001Oooooooo`00ool00?oooooo
003o00;oogl00_ooool3o`3o00;oogl000?oooooool00?oo00001_ooool2o`3o0003o`00ooooO`3o
ogl000Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`03ool00?l0
o`3o0?l000;o003o1Oooool2o`00o`Kooooo0oooO`02ool00003ooooool00?oo003o00;ooooo0_oo
0008ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`00
1Oooool3ool000Kooooo00?o0?l0o`00ooooO`000_ooO`03ool000;o003o1Oooool2o`00o`Gooooo
0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Cooooo0ooo0007ooooo`?o003o
1?ooool3o`00o`Cooooo0ol00?l01?ooooooo`00ool00?oo0007ooooo`?o003o00?oooooo`000?oo
ool02_ooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0
oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l0
0oooO`02ool00003ooooool00?oo003o00?ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o
0?l000Go003ooomo0?ooO`3oogl0ooooo`02o`3o0004o`00ooooO`3oogl0oomo00?oo`000_l00?l6
ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03
oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Kooooo0_l0o`00
0oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo00?o
0?l0o`00ool00?l00_ooO`03ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`?ooooo
00Co0?l0o`00ool00?oo003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003
ooooooooO`3oogl000?ooooo0ol00?l3ooooo`03o`3o0?l00?oo003o00;oogl000Goooooool00?oo
003oooooo`00o`02oomo00Gooooo0_ooO`000oooooooo`00ool00006ooooo`;o0?l000?o003ooomo
0?ooO`001?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo0000
0ooooooo003oo`00o`05ooooo`;o003o1_ooool3oomo00;oo`0000?oooooo`00ool00?l00_ooool2
ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo
0005ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo00?oo`000_l00?l5ooooo`;o003o1Ooo
ool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool000Oooooo0ol0
0?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool000Oooooo0ol00?l00ooooooo0000
ooooo`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2o`3o0003o`00oooo
O`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0
o`03oomo00;oo`0000?oooooo`00ool00?l00oooool2o`3o0005o`00ooooO`3oogl0oomo0?ooool0
0_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o0?l000Co003ooomo0?ooO`3oogl00ooo0002o`00
o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o
00?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o
0003ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool0
0ol0o`3o003oo`00o`02oomo00?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o0ooo
ool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0_ooool2ool000Oooooo0ol00?l3ooooo`;o0?l0
00?ooooooomo0?ooO`000oooool3o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`001Oooooooo`00
ool00?oooooo003o00;oogl01Oooool2oomo0003oooooooo003oo`0000Kooooo0_l0o`000ol00?oo
ogl0oomo0004ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool0
0003ooooool00?oo003o00Gooooo0_l00?l6ooooo`?oogl00_oo00000ooooooo003oo`00o`02oooo
o`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2
ool000Gooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl00ooo0002o`00o`Gooooo0_l00?l5
ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0004ooooo`?oo`001oooool3
o`00o`Cooooo0ol00?l4ooooo`?o003o00Coooooool00?oo003oo`001oooool3o`00o`03ooooool0
003ooooo00[ooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`02ooooo`;o0?l000?o003o
oomo0?ooO`000_ooool3o`3o00?oogl00oooool2o`00o`?ooooo0ol0o`03oomo00;oo`001_ooool3
o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`;o0?l000Go003ooomo0?ooO`3oogl0oooo
o`02o`3o0005o`00ooooO`3oogl0oomo0?ooool00_l0o`001?l00?ooogl0oomo0?ooO`03ool000;o
003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o
0?l00oooO`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0006ooooo`;o
0?l000?ooooooomo0?ooO`000ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3oooo
o`03o`3o0?l00?oo003o00;oogl00ooo0004ooooo`?oo`001_ooool01?l0o`3o003oo`00ool00?l3
ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0
o`000oooooooogl0oomo0003ooooo`?o003o0oooool00ol0o`3o003oo`00o`02oomo0005oooooooo
003oo`00ooooool00?l00_ooO`05ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o0003o`00
ooooO`3oogl000Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o
003o1Oooool2o`00o`Kooooo0oooO`02ool00003ooooool00?oo003o00;ooooo0_oo0008ooooo`;o
003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`001Oooool3ool0
00Kooooo00?o0?l0o`00ooooO`000_ooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l2oooo
o`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00
o`Cooooo0ol00?l01?ooooooo`00ool00?oo0007ooooo`?o003o00?oooooo`000?ooool02_ooool0
02Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002oooo
o`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02ool0
0003ooooool00?oo003o00?ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o0?l000Go003o
oomo0?ooO`3oogl0ooooo`02o`3o0004o`00ooooO`3oogl0oomo00?oo`000_l00?l6ooooo`?oogl0
0_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo
0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Kooooo0_l0o`000oooooooogl0
oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo0_l0o`000ooooooo
ogl0oomo0003ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`?ooooo00Co0?l0o`00
ool00?oo003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3o
ogl000?ooooo0ol00?l3ooooo`03o`3o0?l00?oo003o00;oogl000Coooooool00?oo003ooooo0_l0
0?l6ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o0003o`00ooooO`3oogl000Cooooo0_l0
0?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o003o1Oooool2o`00o`Kooooo
0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3o
ogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo00?o
o`000_l00?l5ooooo`;o003o1Oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?o
o`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool0
00Oooooo0ol00?l00ooooooo0000ooooo`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00;o
ogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o
0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?o
ogl000Coooooo`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00?oo`000_l00?l6
ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03
oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Kooooo0_l0o`00
0oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo0_l0
o`000oooooooogl0oomo0003ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00o`?ooooo
00Co0?l0o`00ool00?oo003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003
ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooo
oooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o0003o`00ooooO`3oogl0
00Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o003o1Oooool2
o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003o
oomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001_ooool00ol0o`3o003ooomo
0002oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00ooooO`000_oo
O`03ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l01?ooooooo`00ool0
0?oo0007ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o0000ooooooooool00ol0
o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0ooo
ool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0
o`03oomo0003ooooool0o`3o0?l000;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?oo`00
0_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo
0_l0o`03oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Kooooo
0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?o
oooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0006ooooo`04o`3o0?l00?oo003oo`00
o`?ooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2
o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo
00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o0003o`00oooo
O`3oogl000Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o003o
1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l0
00Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001_ooool00ol0o`3o
003ooomo0002oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00oooo
O`000_ooO`03ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l01?oooooo
o`00ool00?oo0007ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo0ol00003o`3o00;o
ogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o
0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?o
ogl000?oooooo`3o0?l0o`000_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00ooo0002o`00
o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o
00?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o
0003ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2
o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool000Kooooo00Co0?l0o`00ool00?oo003o0ooo
ool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0_ooool2ool000Oooooo0ol00?l3ooooo`;o0?l0
00?ooooooomo0?ooO`000oooool3o`00o`?ooooo0_l0o`001?ooooooogl0oomo0?ooool2ool00003
ooooool00?oo003o00Kooooo0_ooO`000oooooooo`00ool00006ooooo`;o0?l000?o003ooomo0?oo
O`001?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Sooooo0_l00?l5oooo
o`;o003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l0
0?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0006ooooo`03o`3o0?l00?oo
ogl000;oogl00ooo0002o`00o`Gooooo0_l00?l5ooooo`;o003o1?ooool00ol0o`3o003ooomo0002
oomo00?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003o
o`00ool000Oooooo0ol00?l2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`02
ooooo`;o0?l000?o003ooomo0?ooO`000_ooool3o`3o00?oogl00oooool2o`00o`?ooooo0ol0o`03
oomo00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`00
0ooooooo0?l0o`3o0002o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`03ool000;o003o1_oo
ool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00ooo
O`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0006ooooo`;o0?l000?o
oooooomo0?ooO`000ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`;o0?l0
00?ooooooomo0?ooO`000ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o
0_ooool2ool000Oooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000oooool3o`00o`?ooooo
0_l0o`001?ooooooogl0oomo0?ooool2ool00003ooooool00?oo003o00Kooooo0_ooO`000ooooooo
o`00ool00006ooooo`;o0?l000?o003ooomo0?ooO`001?ooool2o`00o`?ooooo0_l0o`001?l00?oo
ogl0oomo0?ooool2ool000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo00?ooooo0_l00?l2oooo
o`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2
ool000Gooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl00ooo0002o`00o`Gooooo0_l00?l5
ooooo`;o003o1?ooool00ol0o`3o003ooomo0002oomo00?oo`001?ooool3ool000Oooooo0ol00?l4
ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool000Oooooo0ol00?l00ooooooo0000oooo
o`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3o
ogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03
oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3
ooooo`;o0?l000Co003ooomo0?ooO`3oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l0
0?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo
00000ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_oo
ool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`00
1?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o
0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3o
oooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00001_ooool2o`3o0003
o`00ooooO`3oogl000Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008oooo
o`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3oooo
o`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001_ooool0
0ol0o`3o003ooomo0002oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0
o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l0
1?ooooooo`00ool00?oo0007ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o0000
ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03
ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02ool00003ooooool00?oo
003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o0oooool3o`3o00?oogl00ooo0002
o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2
o`3o00?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00?oo`001_ooool2
o`3o0003ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0ooo
ool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?oo
ool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol0
0?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl0
00?oooooool00?oo00001_ooool2o`3o0003o`00ooooO`3oogl000Cooooo0_l00?l3ooooo`;o0?l0
00Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o
003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00
o`;ooooo0_oo0005ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo00?oo`000_l00?l5oooo
o`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007oooo
o`?o003o1?ooool3o`00o`Cooooo0ol00?l01?ooooooo`00ool00?oo0007ooooo`?o003o00?ooooo
o`000?ooool02_ooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol0
0?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006oooo
o`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l0
00;o003o0oooool3o`3o00?oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o
00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo00000ol0
o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_ooool01?l0
o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3
ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2
o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo
00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00001_ooool3o`3o00;oogl01?oo
ool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Sooooo0_l00?l5ooooo`;o003o
1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0
oomo0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;o
ogl00ooo0002o`00o`Gooooo0_l00?l5ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?o
o`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool0
00Oooooo0ol00?l00ooooooo0000ooooo`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00;o
ogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o
0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?o
ogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o003o1_ooool3oomo00;o
oooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o
003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl00ooo0006ooooo`;o0?l000?ooooooomo0?oo
O`000ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo
0?ooO`000ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool0
00Oooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000oooool3o`00o`?ooooo0_l0o`001?oo
ooooogl0oomo0?ooool2ool00003ooooool00?oo003o00Kooooo0_ooO`000oooooooo`00ool00006
ooooo`?o0?l00_ooO`04ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`002?oo
ool2o`00o`Gooooo0_l00?l6ooooo`?oogl00oooool2o`00o`;ooooo0_oo0008ooooo`;o003o0ooo
ool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`001Oooool3ool000Kooooo
00?o0?l0o`00ooooO`000_ooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o
00Coooooool00?oo003oo`001oooool3o`00o`03ooooool0003ooooo00[ooooo000Uooooo`03o`00
0?oooooooooo00?o0?l00_ooO`02ooooo`;o0?l000?o003ooomo0?ooO`000_ooool3o`3o00?oogl0
0oooool2o`00o`?ooooo0ol0o`03oomo00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003o
o`00o`03ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00?oo`00
0_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo
0_l0o`03oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000Kooooo
0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?o
oooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Co
oooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ooooo`?o
003o0oooool2o`3o0004ooooooooO`3oogl0ooooo`;oo`0000?oooooo`00ool00?l01_ooool2oomo
0003oooooooo003oo`0000Kooooo0ol0o`02oomo00Cooooo0_l00?l3ooooo`;o0?l000Co003ooomo
0?ooO`3ooooo0_oo0008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2
ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo
0005ooooo`?oo`001_ooool00ol0o`3o003ooomo0002oomo00?oo`000_l00?l5ooooo`;o003o1Ooo
ool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o1?oo
ool3o`00o`Cooooo0ol00?l01?ooooooo`00ool00?oo0007ooooo`?o003o00?oooooo`000?ooool0
2_ooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo
0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00ooo
O`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o0ooo
ool3o`3o00?oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo
0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo
0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00
ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo
0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003oooo
ooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooooooo
003oo`00o`06ooooo`;oogl000?oooooool00?oo00001_ooool3o`3o00;oogl01?ooool2o`00o`?o
oooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo
00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`03
ooooo`;o003o0_ooool2ool000Gooooo0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl00ooo0002
o`00o`Gooooo0_l00?l5ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3
ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`04oooooooo003oo`00ool000_ooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`00
0ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006
ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o
0?l000;o003o0oooool3o`3o00?oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo
003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`;ooooo0_oo0000
0ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_ooool0
1?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?oo
ool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0ooo
ool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo
0_oo00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Cooooo
0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`;o003o1Oooool2o`00o`Ko
oooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?oo
O`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001oooool01?l00?ooogl0oomo0?ooO`03
ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0004
ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o00Coooooool00?oo003oo`002ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2
o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02
ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?ooooo
o`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o003o1_ooool3oomo00;ooooo00?o0?l0
o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o0_ooool2
ool00003o`3o0?l00?ooogl000;oogl00ooo0006ooooo`;o0?l000?ooooooomo0?ooO`000ooo0006
ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo
0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000Oooooo0ol0
0?l3ooooo`;o0?l000?ooooooomo0?ooO`000oooool3o`00o`?ooooo0_l0o`001?ooooooogl0oomo
0?ooool2ool00003ooooool00?oo003o00Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl0
1?ooool2o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0_l0o`001?l00?oo
ogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0007ooooo`04o`00ooooO`3oogl0
oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3
ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l01?ooooooo`00ool00?oo
000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`02oomo00;ooooo0_l0o`00
0ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006
ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o
0?l000;o003o0oooool3o`3o00?oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo
003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Cooooo00?o0?l0
o`00ooooO`000_ooO`03ool000Kooooo0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0
o`00ool00?oo003o1?ooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo
0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0
o`000oooooooogl0oomo0003ooooo`?o003o0oooool2o`3o0004ooooooooO`3oogl0ooooo`;oo`00
00?oooooo`00ool00?l01_ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`04ooooo`;o003o
0oooool3o`3o00;oogl000?oooooool00?oo00002?ooool2o`00o`Gooooo0_l00?l6ooooo`?oogl0
0oooool2o`00o`;ooooo0_oo0008ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?o
oooo0_l00?l2ooooo`;oo`001Oooool3ool000Oooooo00Co003ooomo0?ooO`3oogl00ooo0002o`00
o`Gooooo0_l00?l5ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool0
00Oooooo0ol00?l4ooooo`?o003o2?ooool3ool000[ooooo0_l0000;ooooo`009Oooool00ol0003o
ooooooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?o
oooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool0
0?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o
003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o
0?l00oooO`03ooooo`;o003o1?ooool00ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003
ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o
0003ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00
o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3oooo
o`;o0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl000?ooooo
ool00?oo00002Oooool2oomo00Cooooo0_l00?l3ooooo`?o0?l00_ooO`000oooooooo`00ool00008
ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3
ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001ooo
ool01?l00?ooogl0oomo0?ooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l8ooooo`?oo`00
2oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_oo
ool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00ooo
O`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?o
ooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o003o1_ooool3oomo00;ooooo00?o
0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o1?oo
ool00ol0o`3o003ooomo0002oomo00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_oo
ool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`00
1?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o
0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3o
oooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Co
oooo0_l00?l3ooooo`?o0?l00_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Ko
oooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?oo
O`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001oooool01?l00?ooogl0oomo0?ooO`03
ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0004
ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l8ooooo`?oo`002oooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl0
00;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo
00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3oooo
o`?o0?l00oooO`03ool000;o003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool0
00Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o1?ooool00ol0o`3o003ooomo0002oomo
00?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4
ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo0ol00?l4
ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3o
ogl000?ooooo0ol00?l3ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooooooo003oo`00
o`06ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Cooooo0_l00?l3ooooo`?o0?l00_oo
O`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_oo
ool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo
0_oo0005ooooo`?oo`001oooool01?l00?ooogl0oomo0?ooO`03ool000;o003o1Oooool2o`00o`Go
oooo0_l00?l4ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`Co
oooo0ol00?l8ooooo`?oo`002oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo
0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l0
0oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o003o
1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l0
0oooO`03ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001_ooool2o`3o0003oooo
ooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003
ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;o
oooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l3ooooo`;o
0?l000Cooooooomo0?ooO`3ooooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl000?oooooool0
0?oo00002Oooool2oomo00Cooooo0_l00?l3ooooo`?o0?l00_ooO`000oooooooo`00ool00008oooo
o`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3oooo
o`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`001oooool0
1?l00?ooogl0oomo0?ooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o0?l0
0?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l8ooooo`?oo`002ooo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2
o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02
ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?ooooo
o`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ool000;o003o1_ooool3oomo00;ooooo00?o0?l0
o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o1?ooool0
0ol0o`3o003oo`00o`02ooooo`?oo`001_ooool2o`3o0003ooooooooO`3oogl000?oo`001_ooool0
1?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?oo
ool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0ooo
ool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l6ooooo`;oogl000Coooooool00?oo003ooooo
0_l00?l6ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Cooooo0_l00?l3ooooo`?o0?l0
0_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o
0_ooool2ool000Sooooo0_l00?l3ooooo`;o0?l000Co003ooomo0?ooO`3oogl00oooool2o`00o`;o
oooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Co
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl0
0_oo0006ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003oooo
ool0o`3o0?l000;o003o0oooool3o`3o00?oogl00ooo0002o`00o`Kooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Cooooo
00?o0?l0o`00ool00?l00_ooool3ool000Kooooo0_l0o`000oooooooogl0oomo0003ool000Kooooo
00Co0?l0o`00ool00?oo003o1?ooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Co
oooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l2ooooo`;oo`001oooool3o`00o`?o
oooo0_l0o`000oooooooogl0oomo0003ooooo`?o003o1_ooool2oomo0004oooooooo003oo`00oooo
o`;o003o1_ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`04ooooo`;o003o0oooool3o`3o
00;oogl000?oooooool00?oo00002?ooool2o`00o`Gooooo0_l00?l6ooooo`?oogl00oooool2o`00
o`;ooooo0_oo0008ooooo`;o003o0oooool2o`3o0004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2
ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4
ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`oooooo0ooo000;
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`02oooo
o`;o0?l000?o003ooomo0?ooO`000_ooool3o`3o00?oogl00oooool2o`00o`?ooooo0ol0o`03oomo
00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`000ooo
oooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00?oo`000_l00?l6ooooo`?oogl00_ooool00ol0
o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l4oooo
o`03o`3o0?l00?oo003o00;ooooo0ooo0006ooooo`;o0?l000?ooooooomo0?ooO`000ooo0006oooo
o`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004
ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000Oooooo0ol00?l3
ooooo`;o0?l000?ooooooomo0?ooO`000oooool3o`00o`Kooooo0_ooO`001?ooooooo`00ool00?oo
ool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`?ooooo0ol0
o`02oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo00?ooooo0_l0
0?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00?ooooo0_l00?l2ooooo`;oo`001Ooo
ool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o0?l0
0?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`oooooo0ooo000;ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5
o`0000Kooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002
ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02
ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o0oooool3
o`3o00?oogl00oooool2o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007
ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3
ool000Kooooo0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?oo
ool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o1?oo
ool3o`00o`Cooooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo
0003ooooo`?o003o1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooo
oooo003oo`0000Wooooo0_ooO`04ooooo`;o003o0oooool3o`3o00;oogl000?oooooool00?oo0000
2?ooool2o`00o`Gooooo0_l00?l6ooooo`?oogl00oooool2o`00o`;ooooo0_oo0008ooooo`;o003o
0oooool3o`3o00?oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`00
0_l00?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo
0ooo0007ooooo`?o003o3oooool3ool000_ooooo00?o0000ooooooooool02Oooool000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo0_l0o`000ol00?ooogl0oomo0002oooo
o`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02ool0
0003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o0oooool3o`3o
00?oogl00oooool2o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007oooo
o`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool0
00Kooooo0_l0o`000oooooooogl0oomo0003ool000Kooooo00Co0?l0o`00ool00?oo003o1?ooool3
o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o1?ooool3
o`00o`Cooooo0ol00?l2ooooo`;oo`001oooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003
ooooo`?o003o1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo
003oo`0000Wooooo0_ooO`04ooooo`;o003o0oooool3o`3o00;oogl000?oooooool00?oo00002?oo
ool2o`00o`Gooooo0_l00?l6ooooo`?oogl00oooool2o`00o`;ooooo0_oo0008ooooo`;o003o0ooo
ool3o`3o00?oogl00oooool2o`00o`;ooooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l0
0?l5ooooo`;o003o1Oooool2o`00o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo
0007ooooo`?o003o3oooool3ool000_ooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo
0ol00003o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo0ol0o`03oomo00?ooooo
0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l0
0oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`03ooooo`;o003o
1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l0
0oooO`03ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001_ooool2o`3o0003oooo
ooooO`3oogl000?oo`001_ooool01?l0o`3o003oo`00ool00?l4ooooo`?o003o0oooool2o`3o0003
ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;o
oooo0_oo0007ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l6ooooo`;o
ogl000Coooooool00?oo003ooooo0_l00?l6ooooo`;oogl000?oooooool00?oo00002Oooool2oomo
00Cooooo0_l00?l3ooooo`?o0?l00_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00
o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`?o0?l00oooO`03oooo
o`;o003o0_ooool2ool000Gooooo0ooo0008ooooo`?oogl00ooo0002o`00o`Gooooo0_l00?l5oooo
o`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000Oooooo0ol00?l?oooo
o`?oo`002Oooool3o`0000_ooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o0?l00_ooO`02
ooooo`;o0?l000?o003ooomo0?ooO`000_ooool3o`3o00?oogl00oooool2o`00o`?ooooo0ol0o`03
oomo00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`00
0ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00?ooooo0_l00?l6ooooo`?oogl00_ooool0
0ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l4
ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0006ooooo`;o0?l000?ooooooomo0?ooO`000ooo0006
ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo
0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000Oooooo0ol0
0?l3ooooo`;o0?l000?ooooooomo0?ooO`000oooool3o`00o`Kooooo0_ooO`001?ooooooo`00ool0
0?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`?ooooo
0ol0o`02oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo00?ooooo
0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00?ooooo0_l00?l2ooooo`;oo`00
1Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`001oooool3o`00o`oooooo0ooo000;ooooo`03o`00
0?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ol0o`02oomo
00;ooooo0_l0o`000ol00?ooogl0oomo0002ooooo`?o0?l00oooO`03ooooo`;o003o0oooool3o`3o
00?oogl00_oo0006ooooo`?o0?l00oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo
0003ooooool0o`3o0?l000;o003o0oooool3o`3o00?oogl00oooool2o`00o`Kooooo0oooO`02oooo
o`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00
o`Cooooo00?o0?l0o`00ool00?l00_ooool3ool000Kooooo0_l0o`000oooooooogl0oomo0003ool0
00Oooooo0ol00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool0
00Oooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo0007ooooo`?o003o0oooool2o`3o
0003ooooooooO`3oogl000?ooooo0ol00?l6ooooo`;oogl000Coooooool00?oo003ooooo0_l00?l6
ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Cooooo0_l00?l3ooooo`?o0?l00_ooO`00
0oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2
ool000Sooooo0_l00?l3ooooo`?o0?l00oooO`03ooooo`;o003o0_ooool2ool000Gooooo0ooo0008
ooooo`?oogl00ooo0002o`00o`Gooooo0_l00?l5ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02
ooooo`?oo`001?ooool3ool000Oooooo0ol00?l?ooooo`?oo`002oooool00ol0003oooooooooo`09
ooooo`002Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o0?l00_ooO`02ooooo`;o0?l0
00?o003ooomo0?ooO`000_ooool3o`3o00?oogl00oooool2o`00o`?ooooo0ol0o`03oomo00;oo`00
1_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`000ooooooo0?l0
o`3o0002o`00o`?ooooo0ol0o`03oomo00?ooooo0_l00?l6ooooo`?oogl00_ooool00ol0o`3o003o
o`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l4ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o1?ooool3o`00o`?ooooo
0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o1?ooool3o`00o`Cooooo
0ol00?l2ooooo`;oo`003Oooool2o`3o0003ooooooooO`3oogl000?ooooo0ol00?l6ooooo`;oogl0
00Coooooool00?oo003ooooo0_l00?l6ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Co
oooo0_l00?l3ooooo`?o0?l00_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Ko
oooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`?o0?l00oooO`03ooooo`;o
003o0_ooool2ool000Gooooo0ooo0008ooooo`?oogl00ooo0002o`00o`Gooooo0_l00?l5ooooo`;o
003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000Oooooo0ol00?l?ooooo`?o
o`002oooool00ol0003oooooooooo`09ooooo`002_ooool2o`0000[ooooo0_l00003ooooo`?o0000
1oooool00ol0003oooooooooo`03o`3o00;oogl00_ooool2o`3o0003o`00ooooO`3oogl000;ooooo
0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo0ol0o`03oomo00;oo`00
00?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l0
0oooO`03ooooo`;o003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo
0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o1?ooool00ol0o`3o003oo`00o`02ooooo`?oo`00
2Oooool2oomo00?oo`001oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`00
0ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000gooooo
0_l0o`000oooooooogl0oomo0003ooooo`?o003o1_ooool2oomo0004oooooooo003oo`00ooooo`;o
003o1_ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`04ooooo`;o003o1_ooool2oomo0003
oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;o
o`002?ooool2o`00o`?ooooo0ol0o`03oomo00?ooooo0_l00?l2ooooo`;oo`001Oooool3ool000So
oooo0oooO`03ool000;o003o1Oooool2o`00o`Gooooo0_l00?l4ooooo`03o`3o0?l00?oo003o00;o
oooo0ooo0004ooooo`?oo`001oooool3o`00o`oooooo0ooo000;ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l00_ooO`02ooooo`?o0?l00_ooO`02ooooo`?o0?l0
0oooO`03ooooo`;o003o0oooool3o`3o00?oogl00_oo0006ooooo`?o0?l00oooO`02ool00003oooo
ool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o0oooool3o`3o00?oogl0
0oooool2o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o
1?ooool2o`3o00?oogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o
1?ooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o
1?ooool3o`00o`Cooooo0ol00?l2ooooo`;oo`003Oooool2o`3o00Kooooo0ol00?l6ooooo`;oogl0
00Coooooool00?oo003ooooo0_l00?l6ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00Co
oooo0_l00?l6ooooo`;oogl000?oooooool00?oo00002?ooool2o`00o`Gooooo0_l00?l6ooooo`?o
ogl00oooool2o`00o`;ooooo0_oo0008ooooo`;o003o0oooool3o`3o00?oogl00oooool2o`00o`;o
oooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l00?l5ooooo`;o003o1Oooool2o`00o`Co
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0ol0o`02oomo00;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo
0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`00
0_l00?l3ooooo`?o0?l00oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`00
1oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`00
1oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`?oo`00
1oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000gooooo0_l0o`06ooooo`?o003o
1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`04ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00?o
oooo0_l00?l2ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`_o
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0ol0o`02oomo00;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo
0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`00
0_l00?l3ooooo`?o0?l00oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`00
1oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`00
1oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`?oo`00
1oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000gooooo0_l0o`06ooooo`?o003o
1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`04ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00?o
oooo0_l00?l2ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`_o
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0ol0o`02oomo00;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo
0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`00
0_l00?l3ooooo`?o0?l00oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`00
1oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`00
1oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`?oo`00
1oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000gooooo0_l0o`06ooooo`?o003o
1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`04ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00?o
oooo0_l00?l2ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`_o
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`02oomo00;ooooo
0ol0o`02oomo00;ooooo0ol0o`03oomo00?ooooo0_l00?l3ooooo`?o0?l00oooO`02ool000Kooooo
0ol0o`03oomo00;oo`0000?oooooo`00ool00?l00oooool3o`3o00?oogl000?oooooo`3o0?l0o`00
0_l00?l3ooooo`?o0?l00oooO`0;ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`00
1oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`00
1oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`?oo`00
1oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool2ool000gooooo0_l0o`06ooooo`?o003o
1_ooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`04ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`002?ooool2o`00o`?ooooo0ol0o`03oomo00Oo
oooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l00?l5ooooo`;o003o2oooool00ol0o`3o
003oo`00o`02ooooo`?oo`001?ooool3ool000Oooooo0ol00?l?ooooo`?oo`002oooool00ol0003o
ooooooooo`09ooooo`009Oooool3o`0000?o0?l01?ooool3o`3o00;oogl00_ooool3o`3o00?oogl0
0oooool2o`00o`Kooooo0oooO`02ool000Kooooo0ol0o`03oomo00;oo`0000?oooooo`00ool00?l0
0oooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`?o0?l00oooO`0;ooooo`?oogl0
0_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00?ooooo
0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`001oooool3o`00o`Cooooo0ol00?l3ooooo`;o0?l0
00?ooooooomo0?ooO`000ooo0004ooooo`?oo`001oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o
0_ooool2ool000gooooo0_l0o`06ooooo`?o003o1_ooool2oomo0004oooooooo003oo`00ooooo`;o
003o1_ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`04ooooo`;o003o1_ooool2oomo0003
oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;o
o`002?ooool2o`00o`?ooooo0ol0o`03oomo00Oooooo0_oo0005ooooo`?oo`002?ooool3oomo00?o
o`000_l00?l5ooooo`;o003o2oooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000Oo
oooo0ol00?l?ooooo`?oo`002_ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0
1oooool2oomo00;ooooo0ol0o`03oomo00?ooooo0_l00?l6ooooo`?oogl00_oo0006ooooo`?o0?l0
0oooO`02ool00003ooooool00?oo003o00?ooooo0ol0o`03oomo0003ooooool0o`3o0?l000;o003o
0oooool3o`3o00?oogl02oooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Oooooo
0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o2Oooool3ool000Wooooo0_ooO`03ool000Oooooo
0ol00?l4ooooo`?o003o0oooool2o`3o0003ooooooooO`3oogl000?oo`001?ooool3ool000Oooooo
0ol00?l4ooooo`?o003o1?ooool3o`00o`;ooooo0_oo000=ooooo`;o0?l01_ooool3o`00o`Kooooo
0_ooO`001?ooooooo`00ool00?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;o
ogl01?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Ko
oooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`?o0?l00oooO`07ooooo`;o
o`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`_ooooo00?o0?l0o`00ool0
0?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_ooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`07ooooo`;oogl00_ooool3o`3o00?oogl0
2oooool3oomo00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l0
0oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00_ooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Wooooo
0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o1?ooool3o`00o`?ooooo0_l0o`000oooooooogl0
oomo0003ool000Cooooo0ooo0007ooooo`?o003o2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l0
1_ooool3o`00o`Kooooo0_ooO`001?ooooooo`00ool00?ooool2o`00o`Kooooo0_ooO`000ooooooo
o`00ool00009ooooo`;oogl01?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00008ooooo`;o
003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000Sooooo0_l00?l3ooooo`?o
0?l00oooO`07ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00o`_o
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o003o3oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`07ooooo`;oogl0
0_ooool3o`3o00?oogl02oooool3oomo00;oo`001_ooool3o`3o00?oogl00_oo00000ooooooo003o
o`00o`03ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00_ooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl0
0oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o1?ooool3o`00o`?ooooo
0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o2oooool3o`00o`;ooooo
0_oo000=ooooo`;o0?l01_ooool3o`00o`Kooooo0_ooO`001?ooooooo`00ool00?ooool2o`00o`Ko
oooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`Kooooo0_ooO`000ooooooo
o`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000So
oooo0_l00?l3ooooo`?o0?l00oooO`07ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o
003o1Oooool2o`00o`_ooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0007ooooo`?o
003o3oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`07ooooo`;oogl00_ooool3o`3o00?oogl02oooool3oomo00;oo`001_ooool3o`3o00?oogl0
0_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo
0ol0o`03oomo00_ooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o
1?ooool2o`3o00?oogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o
1?ooool3o`00o`?ooooo0_l0o`000oooooooogl0oomo0003ool000Cooooo0ooo0007ooooo`?o003o
2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l01_ooool3o`00o`Kooooo0_ooO`001?ooooooo`00
ool00?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`Ko
oooo0_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o
003o0_ooool2ool000Sooooo0_l00?l3ooooo`?o0?l00oooO`07ooooo`;oo`001Oooool3ool000So
oooo0oooO`03ool000;o003o1Oooool2o`00o`_ooooo00?o0?l0o`00ool00?l00_ooool3ool000Co
oooo0ooo0007ooooo`?o003o3oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`07ooooo`;oogl00_ooool3o`3o00?oogl02oooool3oomo00;oo`00
1_ooool3o`3o00?oogl00_oo00000ooooooo003oo`00o`03ooooo`?o0?l00oooO`000ooooooo0?l0
o`3o0002o`00o`?ooooo0ol0o`03oomo00_ooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo
0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl0
0ooo0007ooooo`?o003o1?ooool3o`00o`Kooooo0_ooO`03ool000Cooooo0ooo0007ooooo`?o003o
2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l01_ooool3o`00o`Kooooo0_ooO`001?ooooooo`00
ool00?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`Ko
oooo0_ooO`000oooooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o
003o0_ooool2ool000gooooo0ol0o`03oomo00Oooooo0_oo0005ooooo`?oo`002?ooool3oomo00?o
o`000_l00?l5ooooo`;o003o2oooool2o`3o00?ooooo0ooo0004ooooo`?oo`001oooool3o`00o`oo
oooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
1oooool2oomo00;ooooo0ol0o`03oomo00_ooooo0oooO`02ool000Kooooo0ol0o`03oomo00?ooooo
0_l00?l3ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00_ooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl0
0oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o1?ooool3o`00o`Kooooo
0_ooO`03ool000Cooooo0ooo0007ooooo`?o003o2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l0
1_ooool3o`00o`Kooooo0_ooO`001?ooooooo`00ool00?ooool2o`00o`Kooooo0_ooO`000ooooooo
o`00ool00009ooooo`;oogl01?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00008ooooo`;o
003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool000gooooo0ol0o`03oomo00Oo
oooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l00?l5ooooo`;o003o2oooool2o`3o00?o
oooo0ooo0004ooooo`?oo`006Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`0;ooooo`?o0?l00oooO`0;ooooo`?oogl00_oo0006ooooo`?o0?l0
0oooO`08ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0ol0o`03oomo00_ooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl0
0oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo0007ooooo`?o003o1?ooool3o`00o`Kooooo
0_ooO`03ool000Cooooo0ooo0007ooooo`?o003o2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l0
3oooool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`04ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l5ooooo`;o
003o1_ooool3oomo00?ooooo0_l00?l2ooooo`;oo`004?ooool3oomo00Oooooo0_oo0005ooooo`?o
o`002?ooool3oomo00?oo`000_l00?l5ooooo`;o003o2oooool2o`3o00?ooooo0ooo0004ooooo`?o
o`006Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`0;ooooo`?o0?l00oooO`0;ooooo`?oogl00_oo0006ooooo`?o0?l00oooO`08ooooo`?o0?l0
0oooO`001?oooooo0?l0o`3o0?l0o`07ooooo`?oogl02oooool3oomo00;ooooo00?o0?l0o`00ool0
0?l00_ooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o2Oooool3ool000Wo
oooo0_ooO`03ool000kooooo0ol00?l6ooooo`;oogl00ooo0004ooooo`?oo`001oooool3o`00o`_o
oooo0ol00?l2ooooo`;oo`003Oooool2o`3o00oooooo0_ooO`001?ooooooo`00ool00?ooool2o`00
o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2o`00o`Kooooo0_ooO`000ooo
ooooo`00ool00008ooooo`;o003o1Oooool2o`00o`Kooooo0oooO`03ooooo`;o003o0_ooool2ool0
013ooooo0oooO`07ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000;o003o1Oooool2o`00
o`_ooooo0_l0o`03ooooo`?oo`001?ooool3ool001Wooooo0ooo000;ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00?oogl02oooool3oomo00;o
o`001_ooool3o`3o00?oogl02?ooool3o`3o00?oogl000Coooooo`3o0?l0o`3o0?l01oooool3oomo
00_ooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o
00?oogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004oooo
o`?oo`001oooool3o`00o`_ooooo0ol00?l2ooooo`;oo`003Oooool2o`3o00oooooo0_ooO`001?oo
ooooo`00ool00?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl01?ooool2
o`00o`Kooooo0_ooO`000oooooooo`00ool00008ooooo`;o003o3Oooool3oomo00?ooooo0_l00?l2
ooooo`;oo`004?ooool3oomo00Oooooo0_oo0005ooooo`?oo`002?ooool3oomo00?oo`000_l00?l5
ooooo`;o003o2oooool2o`3o00?ooooo0ooo0004ooooo`?oo`006Oooool3ool000_ooooo00?o0000
ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`03oomo00_ooooo0oooO`02ool0
00Kooooo0ol0o`03oomo00Sooooo0ol0o`03oomo0004ooooool0o`3o0?l0o`3o01Gooooo0oooO`02
ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl00oooool2
o`00o`Wooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`001oooool3
o`00o`_ooooo0ol00?l2ooooo`;oo`003Oooool2o`3o00oooooo0_ooO`001?ooooooo`00ool00?oo
ool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?ooool2oomo0003oooooooo
003oo`0000Sooooo0_l00?l=ooooo`?oogl00oooool2o`00o`;ooooo0_oo000@ooooo`?oogl01ooo
ool2ool000Gooooo0ooo0008ooooo`?oogl00ooo0007ooooo`;o003o2oooool2o`3o00?ooooo0ooo
0004ooooo`?oo`006Oooool3ool000[ooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03
o`3o00_ooooo0ol0o`03oomo00_ooooo0oooO`02ool000Kooooo0ol0o`03oomo00Sooooo0ol0o`03
oomo0004ooooool0o`3o0?l0o`3o01Gooooo0oooO`02ooooo`;o0?l00oooool3ool000Oooooo0_l0
0?l4ooooo`;o0?l00oooO`03ooooo`;o003o2Oooool3ool000Wooooo0_ooO`03ool001Oooooo0_oo
O`03ool000Cooooo0ooo0007ooooo`?o003o2oooool3o`00o`;ooooo0_oo000=ooooo`;o0?l03ooo
ool2oomo0004oooooooo003oo`00ooooo`;o003o1_ooool2oomo0003oooooooo003oo`0000Wooooo
0_ooO`0<ooooo`;oogl000?oooooool00?oo00002?ooool2o`00o`gooooo0oooO`03ooooo`;o003o
0_ooool2ool0013ooooo0oooO`07ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool000Oooooo
0_l00?l;ooooo`;o0?l00oooool3ool000Cooooo0ooo000Iooooo`?oo`002oooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`03oomo00_ooooo0ooo
O`02ool000Kooooo0ol0o`03oomo00Sooooo0ol0o`03oomo0004ooooool0o`3o0?l0o`3o01Gooooo
0oooO`02ooooo`;o0?l00oooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o
2Oooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo0007ooooo`?o003o
4?ooool2ool000gooooo0_l0o`0?ooooo`;oogl000Coooooool00?oo003ooooo0_l00?l6ooooo`;o
ogl000?oooooool00?oo00002Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00008ooooo`;o
003o3Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`006_ooool2ool000Gooooo0ooo0008ooooo`?o
ogl00ooo0007ooooo`;o003o2oooool2o`3o00?ooooo0ooo0004ooooo`?oo`006Oooool3ool000_o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l0
0oooO`0;ooooo`?oogl00_oo0006ooooo`?o0?l00oooO`08ooooo`?o0?l00oooO`001?oooooo0?l0
o`3o0?l0o`0Eooooo`?oogl00_ooool2o`3o00?ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?o
ogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?o
o`001oooool3o`00oa3ooooo0_oo000=ooooo`;o0?l03oooool2oomo0004oooooooo003oo`00oooo
o`;o003o1_ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0<ooooo`;oogl000?oooooool0
0?oo00002?ooool2o`00o`gooooo0oooO`03ooooo`;o003o0_ooool2ool001[ooooo0_oo0005oooo
o`?oo`002?ooool3oomo00?oo`001oooool2o`00o`_ooooo0_l0o`03ooooo`?oo`001?ooool3ool0
01Wooooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l02oooool3o`3o00?oogl02oooool3oomo00;oo`001_ooool3o`3o00?oogl02?ooool3o`3o00?o
ogl000Coooooo`3o0?l0o`3o0?l05Oooool3oomo00;ooooo0_l0o`03ooooo`?oo`001oooool2o`00
o`Cooooo0_l0o`03oomo00?ooooo0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo
00?oo`001?ooool3ool000Oooooo0ol00?l@ooooo`;oo`003Oooool2o`3o00oooooo0_ooO`001?oo
ooooo`00ool00?ooool2o`00o`Kooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?ooool2
oomo0003oooooooo003oo`0000Sooooo0_l00?l=ooooo`?oogl00oooool2o`00o`;ooooo0_oo000J
ooooo`;oo`001Oooool3ool000Sooooo0oooO`03ool001Cooooo0_l0o`03ooooo`?oo`001?ooool3
ool001Wooooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o00?oogl02oooool3oomo00;oo`001_ooool3o`3o00?oogl02?ooool3o`3o
00Cooooo0ol0o`0Eooooo`?oogl00_ooool2o`3o00?ooooo0ooo0007ooooo`;o003o1?ooool2o`3o
00?oogl00oooool2o`00o`Wooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004oooo
o`?oo`001oooool3o`00oa3ooooo0_oo000=ooooo`;o0?l03oooool2oomo0003oooooooo003oo`00
00Wooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`00
00Sooooo0_l00?l=ooooo`?oogl00oooool2o`00o`;ooooo0_oo000Jooooo`;oo`001Oooool3ool0
00Sooooo0oooO`03ool001Wooooo0ooo0004ooooo`?oo`006Oooool3ool000_ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l00oooO`0;ooooo`?o
ogl00_oo0006ooooo`?o0?l00oooO`08ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`02ooooo`;o
0?l00oooool3ool000Oooooo0_l00?l4ooooo`;o0?l00oooO`03ooooo`;o003o2Oooool3ool000Wo
oooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo0007ooooo`?o003o4?ooool2ool000go
oooo0_l0o`0?ooooo`;oogl000?oooooool00?oo00002Oooool2oomo0003oooooooo003oo`0000Wo
oooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002?ooool2o`00o`gooooo0oooO`03ooooo`;o
003o0_ooool2ool001[ooooo0_oo0005ooooo`?oo`002oooool3ool001Wooooo0ooo0004ooooo`?o
o`006Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`0;ooooo`?o0?l00oooO`0;ooooo`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo
0ol0o`0Eooooo`?oogl00_ooool2o`3o00?ooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl0
3_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`00
3Oooool2o`3o00oooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl000?oooooool00?oo0000
2Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00008ooooo`;o003o3Oooool3oomo00?ooooo
0_l00?l2ooooo`;oo`006_ooool2ool000Gooooo0ooo000;ooooo`?oo`006Oooool3ool000Cooooo
0ooo000Iooooo`?oo`002oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`03o`3o00_ooooo0ol0o`03oomo00_ooooo0oooO`02ool000Kooooo0ol0o`0;ooooo`?o0?l01?oo
ool3o`3o01Gooooo0oooO`02ooooo`;o0?l00oooool3ool000Oooooo0_l00?l4ooooo`;o0?l00ooo
O`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo
000=ooooo`;o0?l03oooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`000oooooooo`00ool0
0009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l=ooooo`?oogl00ooo
ool2o`00o`;ooooo0_oo000Jooooo`;oo`001Oooool3ool000_ooooo0ooo000Iooooo`?oo`001?oo
ool3ool001Wooooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l02oooool3o`3o00kooooo0oooO`02ool000Kooooo0ol0o`0;ooooo`?o0?l01?ooool3
o`3o01Gooooo0oooO`07ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03oomo00kooooo0ooo0009
ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo0_l0o`0?
ooooo`;oogl000?oooooool00?oo00002Oooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0<
ooooo`;oogl000?oooooool00?oo00002?ooool2o`00o`gooooo0oooO`03ooooo`;o003o0_ooool2
ool001[ooooo0_oo0005ooooo`?oo`002oooool3ool001Wooooo0ooo0004ooooo`?oo`006Oooool3
ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`0>oooo
o`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool0
00Oooooo0_l00?l4ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo
00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000ooo
ooooo`00ool00009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0000Sooooo0_l00?l=oooo
o`?oogl00oooool2o`00o`;ooooo0_oo000Jooooo`;oo`001Oooool3ool000_ooooo0ooo000Ioooo
o`?oo`001?ooool3ool001Wooooo0ooo000:ooooo`;o00002oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o
0?l05Oooool3oomo00Oooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl03_ooool3ool000Wo
oooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`003Oooool2o`3o00oo
oooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00cooooo0_ooO`000ooooooo
o`00ool00008ooooo`;o003o3Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`006_ooool2ool000Go
oooo0ooo000;ooooo`?oo`006Oooool3ool000Cooooo0ooo000Iooooo`?oo`002oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl0
0_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000Oooooo
0_l00?l4ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`00
1?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00
ool00009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0001Oooooo0oooO`03ooooo`;o003o
0_ooool2ool001[ooooo0_oo0005ooooo`?oo`002oooool3ool001Wooooo0ooo0004ooooo`?oo`00
6Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Ooo
ool3oomo00Oooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl03_ooool3ool000Wooooo0_oo
O`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`003Oooool2o`3o00oooooo0_oo
O`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00cooooo0_ooO`000oooooooo`00ool0
000Gooooo`?oogl00oooool2o`00o`;ooooo0_oo000Jooooo`;oo`001Oooool3ool000_ooooo0ooo
000Iooooo`?oo`001?ooool3ool001Wooooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`02ool000Kooooo0ol0o`0;
ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`001oooool2o`00o`Cooooo0_l0o`03
oomo00kooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2
ool000gooooo0_l0o`0?ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0<
ooooo`;oogl000?oooooool00?oo00005oooool3oomo00?ooooo0_l00?l2ooooo`;oo`006_ooool2
ool000Gooooo0ooo000;ooooo`?oo`006Oooool3ool000Cooooo0ooo000Iooooo`?oo`002oooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>oooo
o`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool0
00Oooooo0_l00?l4ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo
00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000ooo
ooooo`00ool00009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0001Oooooo0oooO`03oooo
o`;o003o0_ooool2ool001[ooooo0_oo0005ooooo`?oo`002oooool3ool001Wooooo0ooo0004oooo
o`?oo`006Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o
0?l05Oooool3oomo00Oooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl03_ooool3ool000Wo
oooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`003Oooool2o`3o00oo
oooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00cooooo0_ooO`000ooooooo
o`00ool0000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`002oooool3ool001Wo
oooo0ooo0004ooooo`?oo`006Oooool3ool000_ooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo
0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo0007ooooo`;o003o1?ooool2o`3o00?oogl0
3_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`00
3Oooool2o`3o00oooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00cooooo
0_ooO`000oooooooo`00ool0000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`00
2oooool3ool001Wooooo0ooo0004ooooo`?oo`006Oooool3ool000_ooooo00?o0000ooooooooool0
2Oooool000[ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00001_oo
ool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o0?l02ooo
ool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000Oooooo0_l00?l4ooooo`;o0?l00ooo
O`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo
000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?oo
ool2oomo0003oooooooo003oo`0001Oooooo0oooO`07ooooo`;oo`006_ooool2ool000Gooooo0ooo
000;ooooo`?oo`006Oooool3ool000Cooooo0ooo000Iooooo`?oo`002oooool00ol0003ooooooooo
o`09ooooo`002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl0
0_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000Oooooo
0_l00?l4ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`00
1?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00
ool00009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0001Oooooo0oooO`07ooooo`;oo`00
6_ooool2ool000Gooooo0ooo000Wooooo`?oo`001?ooool3ool001Wooooo0ooo000;ooooo`03o`00
0?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
0000ooooo`05o`0000Kooooo0ol00003o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o
0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000Oooooo0_l00?l4ooooo`;o
0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[o
oooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00ool00009ooooo`;o
ogl03?ooool2oomo0003oooooooo003oo`0001Oooooo0oooO`07ooooo`;oo`006_ooool2ool000Go
oooo0ooo000Wooooo`?oo`001?ooool3ool001Wooooo0ooo0009ooooo`?o00002oooool000Wooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006
ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000Oooooo0_l00?l4
ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3
ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00ool00009
ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0001Oooooo0oooO`07ooooo`;oo`006_ooool2
ool000Gooooo0ooo000Wooooo`?oo`001?ooool3ool001Wooooo0ooo000;ooooo`03o`000?oooooo
oooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0ooo
O`02ool000Kooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Ooo
ool2o`3o00?oogl03_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo
000Jooooo`;oo`003Oooool2o`3o00oooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Ooo
ool2oomo00cooooo0_ooO`000oooooooo`00ool0000Gooooo`?oogl01oooool2ool001[ooooo0_oo
0005ooooo`?oo`00;_ooool3ool001Wooooo0ooo000;ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Oooooo
00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo
0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l00oooO`0>ooooo`?oo`00
2Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l0
3oooool2oomo00cooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?ooool2oomo0003oooo
oooo003oo`0001Oooooo0oooO`07ooooo`;oo`006_ooool2ool000Gooooo0ooo000^ooooo`?oo`00
9oooool00ol0003oooooooooo`09ooooo`002_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_oo
ool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l00ooo
O`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo
000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03?oo
ool2oomo0003oooooooo003oo`0001Oooooo0oooO`07ooooo`;oo`006_ooool2ool000Gooooo0ooo
000^ooooo`?oo`009oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03
o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0E
ooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00kooooo0ooo0009ooooo`;oogl00ooo000G
ooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo0_l0o`0?ooooo`;oogl03?ooool2
oomo0003oooooooo003oo`0000Wooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00005oooool3
oomo00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`02ool0
00Kooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o
00?oogl03_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Joooo
o`;oo`003Oooool2o`3o00oooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo
00cooooo0_ooO`000oooooooo`00ool0000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005oooo
o`?oo`00;_ooool3ool002Oooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o
0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?o
o`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00co
oooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03oooool2ool001Oooooo0oooO`07ooooo`;o
o`006_ooool2ool000Gooooo0ooo000^ooooo`?oo`009oooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o0?l0
2oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00kooooo
0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo
0_l0o`0?ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`00
5oooool3oomo00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0ooo
O`02ool000Kooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Ooo
ool2o`3o00?oogl03_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo
000Jooooo`;oo`003Oooool2o`3o00oooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Ooo
ool2oomo00oooooo0_oo000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`00;_oo
ool3ool002Oooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;
ooooo`?o0?l03_ooool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3
oomo00Oooooo0ooo000=ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2
oomo00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`00
0oooooooo`00ool00009ooooo`;oogl03oooool2ool001Oooooo0oooO`07ooooo`;oo`006_ooool2
ool000Gooooo0ooo000^ooooo`?oo`009oooool00ol0003oooooooooo`09ooooo`009Oooool3o`00
00?o0?l02oooool3o`3o00kooooo0oooO`02ool000Kooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o
01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o00?oogl03_ooool3ool000Wooooo0_ooO`03ool0
01Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`003Oooool2o`3o00oooooo0_ooO`0<oooo
o`;oogl000?oooooool00?oo00002Oooool2oomo00oooooo0_oo000Gooooo`?oogl01oooool2ool0
01[ooooo0_oo0005ooooo`?oo`00;_ooool3ool002Kooooo0_l0000;ooooo`009Oooool00ol0003o
ooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Co
oooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00kooooo0ooo0009ooooo`;o
ogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo0_l0o`0?ooooo`;o
ogl03?ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005oooool3oomo00Oo
oooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`02ool000Kooooo
0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o00?oogl0
3_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`00
3Oooool2o`3o00oooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00002Oooool2oomo00oooooo
0_oo000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`00;_ooool3ool002Oooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_oo
ool3oomo00;oo`001_ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo
000=ooooo`;o0?l00oooO`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?oo
ool3ool001[ooooo0_oo000=ooooo`;o0?l03oooool2oomo00cooooo0_ooO`000oooooooo`00ool0
0009ooooo`;oogl03oooool2ool001Oooooo0oooO`07ooooo`;oo`006_ooool2ool000Gooooo0ooo
000^ooooo`?oo`009oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03
o`3o00_ooooo0ol0o`0>ooooo`?oogl00_oo0006ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0E
ooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00kooooo0ooo0009ooooo`;oogl00ooo000G
ooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo0_l0o`0?ooooo`;oogl03?ooool2
oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005oooool3oomo00Oooooo0_oo000J
ooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o
00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00kooooo0ooo0009oooo
o`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000gooooo0_l0o`0?oooo
o`;oogl03?ooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005oooool3oomo
00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o
0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`03oomo00ko
oooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2ool000go
oooo0_l0o`0Mooooo`;oogl000?oooooool00?oo00002Oooool2oomo00oooooo0_oo000Gooooo`?o
ogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`00;_ooool3ool002Oooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo
0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o00?oogl0
3_ooool3ool000Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`00
3Oooool2o`3o01gooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03oooool2ool001Oooooo
0oooO`07ooooo`;oo`006_ooool2ool000Gooooo0ooo000^ooooo`?oo`009oooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?oo
ool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l00ooo
O`0>ooooo`?oo`002Oooool2oomo00?oo`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo
000=ooooo`;o0?l07Oooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005ooo
ool3oomo00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08
ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`03
oomo00kooooo0ooo0009ooooo`;oogl00ooo000Gooooo`;oogl00ooo0004ooooo`?oo`006_ooool2
ool000gooooo0_l0o`0Mooooo`;oogl000?oooooool00?oo00002Oooool2oomo00oooooo0_oo000G
ooooo`?oogl01oooool2ool001[ooooo0_oo0005ooooo`?oo`00;_ooool3ool002Oooooo00?o0000
ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o
00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l04Oooool3ool0
00Wooooo0_ooO`03ool001Oooooo0_ooO`03ool000Cooooo0ooo000Jooooo`;oo`003Oooool2o`3o
01gooooo0_ooO`000oooooooo`00ool00009ooooo`;oogl03oooool2ool001Oooooo0oooO`07oooo
o`;oo`006_ooool2ool000Gooooo0ooo000^ooooo`?oo`009_ooool2o`0000_ooooo000Uooooo`03
o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o00Co
oooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`0Aooooo`?oo`002Oooool2oomo00?o
o`005oooool2oomo00?oo`001?ooool3ool001[ooooo0_oo000=ooooo`;o0?l07Oooool2oomo0003
oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005oooool3oomo00Oooooo0_oo000Jooooo`;o
o`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o00Cooooo
0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`0Mooooo`;oogl06_ooool2oomo00?oo`00
1?ooool3ool001[ooooo0_oo000=ooooo`;o0?l07Oooool2oomo0003oooooooo003oo`0000Wooooo
0_ooO`0?ooooo`;oo`005oooool3oomo00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo
0ooo000Wooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01ooo
ool3ool000gooooo0_l0o`0Mooooo`;oogl06_ooool2oomo00?oo`001?ooool3ool001[ooooo0_oo
000=ooooo`;o0?l07Oooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`0?ooooo`;oo`005ooo
ool3oomo00Oooooo0_oo000Jooooo`;oo`001Oooool3ool002kooooo0ooo000Wooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08
ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`0M
ooooo`;oogl06_ooool2oomo00?oo`008Oooool2ool000gooooo0_l0o`0Mooooo`;oogl000?ooooo
ool00?oo00002Oooool2oomo00oooooo0_oo000Gooooo`?oogl01oooool2ool001[ooooo0_oo0005
ooooo`?oo`00;_ooool3ool002Oooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o
01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o01gooooo0_ooO`0Jooooo`;oogl00ooo000Qoooo
o`;oo`003Oooool2o`3o01gooooo0_ooO`0<ooooo`;oogl0:?ooool3oomo02?ooooo0_oo000foooo
o`?oo`009oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_o
oooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oo
oooo0ooo000=ooooo`;o0?l07Oooool2oomo01[ooooo0_ooO`03ool0027ooooo0_oo000=ooooo`;o
0?l07Oooool2oomo00cooooo0_ooO`0Xooooo`?oogl08oooool2ool003Kooooo0ooo000Wooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo
0oooO`08ooooo`?o0?l02oooool3o`3o00Cooooo0ol0o`0Eooooo`?oogl01oooool3ool000gooooo
0_l0o`0Mooooo`;oogl06_ooool2oomo00?oo`008Oooool2ool000gooooo0_l0o`0Mooooo`;oogl0
3?ooool2oomo02Sooooo0oooO`0Sooooo`;oo`00=_ooool3ool002Oooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0
o`0;ooooo`?o0?l01?ooool3o`3o01Gooooo0oooO`07ooooo`?oo`003Oooool2o`3o01gooooo0_oo
O`0Jooooo`;oogl00ooo000Qooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0<ooooo`;oogl0:?oo
ool3oomo02?ooooo0_oo000fooooo`?oo`009oooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`04
ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l07Oooool2oomo01[ooooo0_ooO`03
ool0027ooooo0_oo000=ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`0Sooooo`;oo`00=_ooool3
ool002Oooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`0>oooo
o`?oogl02?ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=oooo
o`;o0?l07Oooool2oomo01[ooooo0_ooO`0Tooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0foooo
o`?oogl08oooool2ool003Kooooo0ooo000Vooooo`;o00002oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l01?ooool3o`3o01Go
oooo0oooO`07ooooo`?oo`003Oooool2o`3o01gooooo0_ooO`0Jooooo`;oogl09?ooool2ool000go
oooo0_l0o`0Mooooo`;oogl0=_ooool3oomo02?ooooo0_oo000fooooo`?oo`009oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl0
2?ooool3o`3o00_ooooo0ol0o`04ooooo`?o0?l05Oooool3oomo00Oooooo0ooo000=ooooo`;o0?l0
7Oooool2oomo01[ooooo0_ooO`0Tooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0fooooo`?oogl0
8oooool2ool003Kooooo0ooo000Wooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o00Cooooo0ol0
o`0Eooooo`?oogl01oooool3ool000gooooo0_l0o`0Mooooo`;oogl06_ooool2oomo02Cooooo0_oo
000=ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`0Sooooo`;oo`00=_ooool3ool002Oooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3
oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo00Oooooo0ooo000=ooooo`;o0?l07Oooool2
oomo01[ooooo0_ooO`0Tooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2
ool003Kooooo0ooo000Wooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o01cooooo0oooO`07oooo
o`?oo`003Oooool2o`3o01gooooo0_ooO`0Jooooo`;oogl09?ooool2ool000gooooo0_l0o`0Moooo
o`;oogl0=_ooool3oomo02?ooooo0_oo000fooooo`?oo`009oooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_o
oooo0ol0o`0Looooo`?oogl01oooool3ool000gooooo0_l0o`0Mooooo`;oogl06_ooool2oomo02Co
oooo0_oo000=ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`0Sooooo`;oo`00=_ooool3ool002Oo
oooo00?o0000ooooooooool02Oooool000[ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`?o00001oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl0
2?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl01oooool3ool000gooooo0_l0o`0Mooooo`;oogl0
6_ooool2oomo02Cooooo0_oo000=ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`0Sooooo`;oo`00
H?ooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o01cooooo0oooO`07oooo
o`?oo`003Oooool2o`3o01gooooo0_ooO`0Jooooo`;oogl09?ooool2ool000gooooo0_l0o`0Moooo
o`;oogl0=_ooool3oomo02?ooooo0_oo001Pooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0
o`0;ooooo`?o0?l07?ooool3oomo00Oooooo0ooo000=ooooo`;o0?l07Oooool2oomo01[ooooo0_oo
O`0Tooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool0063ooooo00?o
0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
ool0003ooooo00Co00001oooool3o`0000?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l0
2oooool3o`3o01cooooo0oooO`0Gooooo`;o0?l07Oooool2oomo01[ooooo0_ooO`0Tooooo`;oo`00
3Oooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool005kooooo0ol0000;ooooo`002Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002_ooool00ol0
003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Loooo
o`?oogl05oooool2o`3o01gooooo0_ooO`0Jooooo`;oogl09?ooool2ool000gooooo0_l0o`0Moooo
o`;oogl0=_ooool3oomo02?ooooo0_oo001Pooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3
o`3o01cooooo0oooO`0Gooooo`;o0?l07Oooool2oomo01[ooooo0_ooO`0Tooooo`;oo`003Oooool2
o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool0063ooooo00?o0000ooooooooool02Oooool0
00[ooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool00ol0o`0;oooo
o`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Moooo
o`;oogl06_ooool2oomo02Cooooo0_oo000=ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`0Soooo
o`;oo`00H?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_o
oooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl05oooool2o`3o01go
oooo0_ooO`10ooooo`;oo`003Oooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool0063o
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l0
3_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Mooooo`;oogl0
Coooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool0063ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0
o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Mooooo`;oogl0Coooool2o`3o01gooooo0_oo
O`0fooooo`?oogl08oooool2ool0063ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3
oomo01Oooooo0_l0o`0Mooooo`;oogl0Coooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2
ool0063ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;oooo
o`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Moooo
o`;oogl0Coooool2o`3o01gooooo0_ooO`0fooooo`?oogl08oooool2ool0063ooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00So
oooo0ol0o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Mooooo`;oogl0Coooool2o`3o01go
oooo0_ooO`0fooooo`?oogl08oooool2ool0063ooooo00?o0000ooooooooool02Oooool002Gooooo
0ol00003o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl0
5oooool2o`3o01gooooo0_ooO`1?ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`24ooooo`;o0000
2oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0
o`0;ooooo`?o0?l07?ooool3oomo01Oooooo0_l0o`0Mooooo`;oogl0Coooool2o`3o01gooooo0_oo
O`0fooooo`?oogl0QOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03
o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl05oooool2
o`3o01gooooo0_ooO`1?ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`25ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08oooo
o`?o0?l02oooool3o`3o01cooooo0oooO`0Gooooo`;o0?l07Oooool2oomo04oooooo0_l0o`0Moooo
o`;oogl0=_ooool3oomo08Gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo03Ko
oooo0_ooO`1?ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`25ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l0
2oooool3o`3o01cooooo0oooO`0fooooo`;oogl0Coooool2o`3o01gooooo0_ooO`0fooooo`?oogl0
QOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0
o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl0=_ooool2oomo04oooooo0_l0
o`0Mooooo`;oogl0=_ooool3oomo08Gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3
oomo03Kooooo0_ooO`1?ooooo`;o0?l07Oooool2oomo03Kooooo0oooO`25ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08oooo
o`?o0?l02oooool3o`3o01cooooo0oooO`0fooooo`;oogl0Coooool2o`3o01gooooo0_ooO`0foooo
o`?oogl0QOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_o
oooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl0=_ooool2oomo04oo
oooo0_l0o`0Mooooo`;oogl0=_ooool3oomo08Gooooo00?o0000ooooooooool02Oooool002Gooooo
0ol00003o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0o`0Looooo`?oogl0
=_ooool2oomo04oooooo0_l0o`0Mooooo`;oogl0=_ooool3oomo08Cooooo0_l0000;ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3o`3o00_ooooo0ol0
o`0Looooo`?oogl0=_ooool2oomo04oooooo0_l0o`0Mooooo`;oogl0=_ooool3oomo08Gooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l03_ooool3
oomo00Sooooo0ol0o`0;ooooo`?o0?l07?ooool3oomo03Kooooo0_ooO`1?ooooo`;o0?l07Oooool2
oomo03Kooooo0oooO`25ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o01cooooo0oooO`0foooo
o`;oogl0Coooool2o`3o05Gooooo0oooO`25ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l02oooool3o`3o01co
oooo0oooO`0fooooo`;oogl0Coooool2o`3o05Gooooo0oooO`25ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0oooO`08ooooo`?o0?l0
2oooool3o`3o01cooooo0oooO`0fooooo`;oogl0Coooool2o`3o05Gooooo0oooO`25ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00kooooo0ooo
O`08ooooo`?o0?l0:_ooool3oomo03Kooooo0_ooO`1?ooooo`;o0?l0gOooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0>ooooo`?oogl02?ooool3
o`3o02[ooooo0oooO`0fooooo`;oogl0Coooool2o`3o0=gooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`0Looooo`?oogl02?ooool3o`3o02[ooooo0oooO`0foooo
o`;oogl0Coooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0Looooo`?oogl02?ooool3o`3o02[ooooo0oooO`0fooooo`;oogl0Coooool2o`3o0=go
oooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o01cooooo0oooO`08ooooo`?o0?l0
:_ooool3oomo03Kooooo0_ooO`1?ooooo`;o0?l0g?ooool2o`0000_ooooo000Uooooo`03o`000?oo
oooooooo00?o0?l07?ooool3oomo00Sooooo0ol0o`0Zooooo`?oogl0oooooomWooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l07?ooool3oomo00Sooooo0ol0o`0Z
ooooo`?oogl0oooooomWooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l07?ooool3oomo00Sooooo0ol0o`0Zooooo`?oogl0oooooomWooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l07?ooool3oomo00Sooooo0ol0o`0Zooooo`?o
ogl0oooooomWooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
7?ooool3oomo00Sooooo0ol0o`0Zooooo`?oogl0oooooomWooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l09oooool3o`3o0?ooooooU?ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o02Oooooo0ol0o`3ooooooiCooooo00?o0000
ooooooooool02Oooool000[ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00001oooool00ol0003oooooooooo`03o`3o02Oooooo0ol0o`3ooooooiCooooo00?o0000oooo
ooooool02Oooool000Wooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03o`3o02Oooooo0ol0
o`3ooooooiCooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool3o`0000?o
0?l09oooool3o`3o0?ooooooT_ooool3o`0000_ooooo0009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool3o`0000Oooooo00?o0000ooooooooool00ol0o`0Woooo
o`?o0?l0oooooonDooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00ol0o`0Wooooo`?o0?l0oooooonDooooo`03o`000?oooooooooo00Wooooo0009
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00ol0o`0Wooooo`?o0?l0oooooonDooooo`03
o`000?oooooooooo00Wooooo000:ooooo`;o00002_ooool2o`0000?ooooo0ol00007ooooo`03o`00
0?oooooooooo00?o0?l09oooool3o`3o0?ooooooU?ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o02Oooooo0ol0o`3ooooooiCooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00ol0o`0Wooooo`?o0?l0oooooonDooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l09oooool3o`3o0?ooooooU?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o02Oooooo0ol0o`3ooooooiCo
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0Wooooo`?o0?l0
oooooonDooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3ooooookgooooo0_l0
000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000?o0?l0oooo
oonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo0ol0
0003o`3o0?oooooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00Wooooo000@ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`06ooooo`?o00000ol0o`3ooooookcooooo0ol0000;ooooo`003oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wo
oooo000?ooooo`04o`000?ooooooooooo`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00002_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3o
oooookgooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool3
o`0000?o0?l0oooooonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Ooo
ool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00000_ooool5o`0000Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo0ol00003o`3o0?oooooo_?ooool3o`0000_ooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
00Wooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000:
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo
__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`009Oooool3o`0000?o0?l0oooooonmooooo`;o00002oooool002Gooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_o
oooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`3ooooool7ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000;ooooo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000_ooooo000Uoooooooo0000aOl0000;ooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004ooooo`?o
00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooooooo
0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go
00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co
00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go
00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`Co
00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004ooooo`?o
00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002ooooo`Go
00000oooool4o`0000Cooooo0ol0000;ooooo`00:Oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l00002
ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool00_l0
0004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo0_l0
0003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`000?oo
oooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool0
0_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_oo
ool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2o`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000oooo
ool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooooooo
oooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooooooo
00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00000_oo
ool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004ooooo`;o
00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooooooo
ool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002oooo
o`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003ooooo
o`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002ooooo`Go
00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o000000Co
00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o000000Co
00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Oooool2
o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000000ooo
ool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;ooooo
0_l000000ooooooo0000o`000003o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo0000
ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l00006
ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000oooool0
1?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`000?oo
oooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04o`00
0?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0003o
ooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000oooool5
o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool00000
1Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003ooooo
o`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`0000?o
oooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000<ooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooooooo
0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0003o
ooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003oooo
o`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00?o
0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooooooo
0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo00Ko
0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003oooooo`00
0?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_ooool0
1Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo1Ol0
0002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`0000?o
oooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;o
oooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2
o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooooooo
oooooooo0000ooooool000003?ooool002Sooooo0_l00004ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?ooooo
0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Cooooo
0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo000000;o
00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003o
ooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool01?l0
003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003ooooo`Co
00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004ooooo`?o
00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o0000
1_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo
00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000ooooo`02
ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003ooooo
o`000004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo0ol0
0006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o0000
1?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o0000
1?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`0000?o
oooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`0000Co
oooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`0000Co
oooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`0000Co
oooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0003o
ooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`0000;o
oooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;o
oooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`000?l0
00001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`0000?o
oooo1?l00005ooooo`03o`000?oooooooooo00[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-4.70015, -0.0105493, 0.142355, \
0.000495853}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 3.23732 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09565 -30 -4.5 ]
[-0.0125 .09565 0 4.5 ]
[-0.0125 .17658 -24 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .25751 -30 -4.5 ]
[-0.0125 .25751 0 4.5 ]
[-0.0125 .33845 -18 -4.5 ]
[-0.0125 .33845 0 4.5 ]
[-0.0125 .41938 -30 -4.5 ]
[-0.0125 .41938 0 4.5 ]
[-0.0125 .50031 -24 -4.5 ]
[-0.0125 .50031 0 4.5 ]
[-0.0125 .58125 -30 -4.5 ]
[-0.0125 .58125 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09565 m
.00625 .09565 L
s
[(0.025)] -0.0125 .09565 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(0.05)] -0.0125 .17658 1 0 Mshowa
0 .25751 m
.00625 .25751 L
s
[(0.075)] -0.0125 .25751 1 0 Mshowa
0 .33845 m
.00625 .33845 L
s
[(0.1)] -0.0125 .33845 1 0 Mshowa
0 .41938 m
.00625 .41938 L
s
[(0.125)] -0.0125 .41938 1 0 Mshowa
0 .50031 m
.00625 .50031 L
s
[(0.15)] -0.0125 .50031 1 0 Mshowa
0 .58125 m
.00625 .58125 L
s
[(0.175)] -0.0125 .58125 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .04709 m
.00375 .04709 L
s
0 .06327 m
.00375 .06327 L
s
0 .07946 m
.00375 .07946 L
s
0 .11183 m
.00375 .11183 L
s
0 .12802 m
.00375 .12802 L
s
0 .14421 m
.00375 .14421 L
s
0 .16039 m
.00375 .16039 L
s
0 .19277 m
.00375 .19277 L
s
0 .20895 m
.00375 .20895 L
s
0 .22514 m
.00375 .22514 L
s
0 .24133 m
.00375 .24133 L
s
0 .2737 m
.00375 .2737 L
s
0 .28989 m
.00375 .28989 L
s
0 .30607 m
.00375 .30607 L
s
0 .32226 m
.00375 .32226 L
s
0 .35463 m
.00375 .35463 L
s
0 .37082 m
.00375 .37082 L
s
0 .38701 m
.00375 .38701 L
s
0 .40319 m
.00375 .40319 L
s
0 .43557 m
.00375 .43557 L
s
0 .45175 m
.00375 .45175 L
s
0 .46794 m
.00375 .46794 L
s
0 .48413 m
.00375 .48413 L
s
0 .5165 m
.00375 .5165 L
s
0 .53269 m
.00375 .53269 L
s
0 .54887 m
.00375 .54887 L
s
0 .56506 m
.00375 .56506 L
s
0 .59743 m
.00375 .59743 L
s
0 .61362 m
.00375 .61362 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09565 m
1 .09565 L
s
.99375 .17658 m
1 .17658 L
s
.99375 .25751 m
1 .25751 L
s
.99375 .33845 m
1 .33845 L
s
.99375 .41938 m
1 .41938 L
s
.99375 .50031 m
1 .50031 L
s
.99375 .58125 m
1 .58125 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .04709 m
1 .04709 L
s
.99625 .06327 m
1 .06327 L
s
.99625 .07946 m
1 .07946 L
s
.99625 .11183 m
1 .11183 L
s
.99625 .12802 m
1 .12802 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16039 m
1 .16039 L
s
.99625 .19277 m
1 .19277 L
s
.99625 .20895 m
1 .20895 L
s
.99625 .22514 m
1 .22514 L
s
.99625 .24133 m
1 .24133 L
s
.99625 .2737 m
1 .2737 L
s
.99625 .28989 m
1 .28989 L
s
.99625 .30607 m
1 .30607 L
s
.99625 .32226 m
1 .32226 L
s
.99625 .35463 m
1 .35463 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .38701 m
1 .38701 L
s
.99625 .40319 m
1 .40319 L
s
.99625 .43557 m
1 .43557 L
s
.99625 .45175 m
1 .45175 L
s
.99625 .46794 m
1 .46794 L
s
.99625 .48413 m
1 .48413 L
s
.99625 .5165 m
1 .5165 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .54887 m
1 .54887 L
s
.99625 .56506 m
1 .56506 L
s
.99625 .59743 m
1 .59743 L
s
.99625 .61362 m
1 .61362 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .02381 L
.02181 .02381 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .02381 L
.02181 .02381 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .01472 L
.03738 .01472 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .01472 L
.03738 .01472 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .02949 L
.05296 .02949 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .02949 L
.05296 .02949 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .03062 L
.08411 .03062 L
.08411 .01472 L
F
.081 .01472 m
.081 .03062 L
.08411 .03062 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .05335 L
.09969 .05335 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .05335 L
.09969 .05335 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .02267 L
.11526 .02267 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .02267 L
.11526 .02267 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .01699 L
.13084 .01699 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .01699 L
.13084 .01699 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .04085 L
.14642 .04085 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .04085 L
.14642 .04085 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .01472 L
.16199 .01472 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .01472 L
.16199 .01472 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .04199 L
.17757 .04199 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .04199 L
.17757 .04199 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .01472 L
.19315 .01472 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .01472 L
.19315 .01472 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .08857 L
.20872 .08857 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .08857 L
.20872 .08857 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .05221 L
.2243 .05221 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .05221 L
.2243 .05221 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .09994 L
.23988 .09994 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .09994 L
.23988 .09994 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .01585 L
.25545 .01585 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .01585 L
.25545 .01585 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .10335 L
.27103 .10335 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .10335 L
.27103 .10335 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .02835 L
.2866 .02835 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .02835 L
.2866 .02835 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .12494 L
.30218 .12494 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .12494 L
.30218 .12494 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .01472 L
.31776 .01472 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .01472 L
.31776 .01472 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .09198 L
.33333 .09198 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .09198 L
.33333 .09198 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .10562 L
.34891 .10562 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .10562 L
.34891 .10562 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .1113 L
.36449 .1113 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .1113 L
.36449 .1113 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .01699 L
.38006 .01699 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .01699 L
.38006 .01699 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .1113 L
.39564 .1113 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .1113 L
.39564 .1113 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .02608 L
.41121 .02608 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .02608 L
.41121 .02608 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .06471 L
.42679 .06471 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .06471 L
.42679 .06471 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .02267 L
.44237 .02267 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .02267 L
.44237 .02267 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .12948 L
.45794 .12948 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .12948 L
.45794 .12948 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .14084 L
.47352 .14084 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .14084 L
.47352 .14084 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .07494 L
.4891 .07494 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .07494 L
.4891 .07494 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .01472 L
.50467 .01472 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .06812 L
.52025 .06812 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .06812 L
.52025 .06812 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .02153 L
.53583 .02153 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .02153 L
.53583 .02153 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .08744 L
.5514 .08744 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .08744 L
.5514 .08744 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .0204 L
.56698 .0204 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .0204 L
.56698 .0204 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .11244 L
.58255 .11244 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .11244 L
.58255 .11244 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .10335 L
.59813 .10335 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .10335 L
.59813 .10335 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .08517 L
.61371 .08517 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .08517 L
.61371 .08517 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .01699 L
.62928 .01699 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .01699 L
.62928 .01699 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .15903 L
.64486 .15903 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .15903 L
.64486 .15903 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .01585 L
.66044 .01585 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .01585 L
.66044 .01585 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .12835 L
.67601 .12835 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .12835 L
.67601 .12835 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .02721 L
.69159 .02721 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .02721 L
.69159 .02721 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .10789 L
.70717 .10789 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .10789 L
.70717 .10789 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .12835 L
.72274 .12835 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .12835 L
.72274 .12835 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .10335 L
.73832 .10335 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .10335 L
.73832 .10335 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .01585 L
.75389 .01585 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .01585 L
.75389 .01585 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .0988 L
.76947 .0988 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .0988 L
.76947 .0988 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .03517 L
.78505 .03517 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .03517 L
.78505 .03517 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .09653 L
.80062 .09653 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .09653 L
.80062 .09653 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .0329 L
.8162 .0329 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .0329 L
.8162 .0329 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .09426 L
.83178 .09426 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .09426 L
.83178 .09426 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .0988 L
.84735 .0988 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .0988 L
.84735 .0988 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .11925 L
.86293 .11925 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .11925 L
.86293 .11925 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .02381 L
.8785 .02381 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .02381 L
.8785 .02381 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .12266 L
.89408 .12266 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .12266 L
.89408 .12266 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .03517 L
.90966 .03517 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .03517 L
.90966 .03517 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .1238 L
.92523 .1238 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .1238 L
.92523 .1238 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .03971 L
.94081 .03971 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .03971 L
.94081 .03971 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .08857 L
.95639 .08857 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .08857 L
.95639 .08857 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .12039 L
.97196 .12039 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .12039 L
.97196 .12039 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .07608 L
.98754 .07608 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .07608 L
.98754 .07608 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .04085 L
.02492 .04085 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .04085 L
.02492 .04085 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .25107 L
.0405 .25107 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .25107 L
.0405 .25107 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .04994 L
.05607 .04994 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .04994 L
.05607 .04994 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .14653 L
.07165 .14653 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .14653 L
.07165 .14653 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .02835 L
.08723 .02835 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .02835 L
.08723 .02835 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .02267 L
.1028 .02267 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .02267 L
.1028 .02267 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .10789 L
.11838 .10789 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .10789 L
.11838 .10789 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .38174 L
.13396 .38174 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .38174 L
.13396 .38174 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .02153 L
.14953 .02153 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .02153 L
.14953 .02153 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .18516 L
.16511 .18516 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .18516 L
.16511 .18516 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .03062 L
.18069 .03062 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .03062 L
.18069 .03062 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .09085 L
.19626 .09085 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .09085 L
.19626 .09085 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .01812 L
.21184 .01812 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .01812 L
.21184 .01812 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .03517 L
.22741 .03517 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .03517 L
.22741 .03517 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .29993 L
.25857 .29993 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .29993 L
.25857 .29993 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .01699 L
.27414 .01699 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .01699 L
.27414 .01699 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .07267 L
.28972 .07267 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .07267 L
.28972 .07267 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .01585 L
.3053 .01585 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .01585 L
.3053 .01585 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .11016 L
.32087 .11016 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .11016 L
.32087 .11016 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .01926 L
.33645 .01926 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .01926 L
.33645 .01926 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .01585 L
.35202 .01585 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .01585 L
.35202 .01585 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .2647 L
.38318 .2647 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .2647 L
.38318 .2647 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .0204 L
.39875 .0204 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .0204 L
.39875 .0204 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .01812 L
.41433 .01812 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .01812 L
.41433 .01812 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .01585 L
.42991 .01585 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .01585 L
.42991 .01585 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .05335 L
.44548 .05335 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .05335 L
.44548 .05335 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .01585 L
.46106 .01585 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .01585 L
.46106 .01585 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .08289 L
.50779 .08289 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .08289 L
.50779 .08289 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .0204 L
.52336 .0204 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .0204 L
.52336 .0204 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .12494 L
.53894 .12494 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .12494 L
.53894 .12494 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .01585 L
.55452 .01585 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .01585 L
.55452 .01585 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .0613 L
.57009 .0613 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .0613 L
.57009 .0613 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01926 L
.58567 .01926 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01926 L
.58567 .01926 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01699 L
.61682 .01699 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01699 L
.61682 .01699 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .10335 L
.6324 .10335 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .10335 L
.6324 .10335 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01585 L
.64798 .01585 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01585 L
.64798 .01585 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .04767 L
.66355 .04767 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .04767 L
.66355 .04767 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .04085 L
.6947 .04085 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .04085 L
.6947 .04085 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01699 L
.71028 .01699 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01699 L
.71028 .01699 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .26356 L
.75701 .26356 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .26356 L
.75701 .26356 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01585 L
.77259 .01585 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01585 L
.77259 .01585 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .02153 L
.78816 .02153 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .02153 L
.78816 .02153 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .02608 L
.81931 .02608 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .02608 L
.81931 .02608 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .04653 L
.88162 .04653 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .04653 L
.88162 .04653 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .02153 L
.94393 .02153 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .02153 L
.94393 .02153 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .42833 L
.01246 .42833 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .42833 L
.01246 .42833 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .01926 L
.02804 .01926 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .01926 L
.02804 .01926 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .16357 L
.04361 .16357 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .16357 L
.04361 .16357 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .02153 L
.05919 .02153 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .02153 L
.05919 .02153 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .34311 L
.07477 .34311 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .34311 L
.07477 .34311 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .02835 L
.09034 .02835 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .02835 L
.09034 .02835 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .0613 L
.1215 .0613 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .0613 L
.1215 .0613 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .23288 L
.13707 .23288 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .23288 L
.13707 .23288 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .34651 L
.16822 .34651 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .34651 L
.16822 .34651 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .01585 L
.1838 .01585 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .01585 L
.1838 .01585 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .25334 L
.19938 .25334 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .25334 L
.19938 .25334 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .01472 L
.21495 .01472 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .01472 L
.21495 .01472 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .0204 L
.23053 .0204 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .0204 L
.23053 .0204 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .2272 L
.26168 .2272 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .2272 L
.26168 .2272 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .03517 L
.29283 .03517 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .03517 L
.29283 .03517 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .01472 L
.30841 .01472 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .01472 L
.30841 .01472 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .30674 L
.32399 .30674 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .30674 L
.32399 .30674 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .01585 L
.33956 .01585 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .01585 L
.33956 .01585 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .12835 L
.38629 .12835 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .12835 L
.38629 .12835 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .01926 L
.41745 .01926 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .01926 L
.41745 .01926 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .02267 L
.4486 .02267 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .02267 L
.4486 .02267 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .23516 L
.5109 .23516 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .23516 L
.5109 .23516 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .07153 L
.54206 .07153 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .07153 L
.54206 .07153 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .12835 L
.57321 .12835 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .12835 L
.57321 .12835 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .25675 L
.63551 .25675 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .25675 L
.63551 .25675 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .09085 L
.66667 .09085 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .09085 L
.66667 .09085 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .02608 L
.69782 .02608 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .02608 L
.69782 .02608 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .09653 L
.76012 .09653 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .09653 L
.76012 .09653 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .01585 L
.79128 .01585 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .01585 L
.79128 .01585 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .02494 L
.82243 .02494 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .02494 L
.82243 .02494 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .02835 L
.88474 .02835 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .02835 L
.88474 .02835 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .0204 L
.01558 .0204 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .0204 L
.01558 .0204 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .12607 L
.03115 .12607 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .12607 L
.03115 .12607 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .06244 L
.04673 .06244 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .06244 L
.04673 .06244 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .13062 L
.06231 .13062 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .13062 L
.06231 .13062 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .03176 L
.07788 .03176 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .03176 L
.07788 .03176 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .12266 L
.09346 .12266 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .12266 L
.09346 .12266 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .09994 L
.10903 .09994 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .09994 L
.10903 .09994 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .12153 L
.12461 .12153 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .12153 L
.12461 .12153 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .0488 L
.14019 .0488 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .0488 L
.14019 .0488 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .10448 L
.15576 .10448 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .10448 L
.15576 .10448 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .04312 L
.17134 .04312 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .04312 L
.17134 .04312 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .10335 L
.18692 .10335 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .10335 L
.18692 .10335 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .05108 L
.20249 .05108 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .05108 L
.20249 .05108 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .07267 L
.21807 .07267 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .07267 L
.21807 .07267 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .11585 L
.23364 .11585 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .11585 L
.23364 .11585 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .02721 L
.24922 .02721 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .02721 L
.24922 .02721 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .04994 L
.2648 .04994 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .04994 L
.2648 .04994 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .06244 L
.28037 .06244 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .06244 L
.28037 .06244 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .13062 L
.29595 .13062 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .13062 L
.29595 .13062 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .03971 L
.31153 .03971 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .03971 L
.31153 .03971 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .04085 L
.3271 .04085 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .04085 L
.3271 .04085 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .05903 L
.34268 .05903 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .05903 L
.34268 .05903 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .04085 L
.35826 .04085 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .04085 L
.35826 .04085 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .0329 L
.37383 .0329 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .0329 L
.37383 .0329 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .05449 L
.38941 .05449 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .05449 L
.38941 .05449 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .05335 L
.40498 .05335 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .05335 L
.40498 .05335 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .11925 L
.42056 .11925 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .11925 L
.42056 .11925 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .06244 L
.43614 .06244 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .06244 L
.43614 .06244 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .12607 L
.45171 .12607 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .12607 L
.45171 .12607 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .02153 L
.46729 .02153 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .02153 L
.46729 .02153 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .02608 L
.48287 .02608 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .02608 L
.48287 .02608 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .03744 L
.49844 .03744 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .03744 L
.49844 .03744 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .0613 L
.51402 .0613 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .0613 L
.51402 .0613 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .08857 L
.5296 .08857 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .08857 L
.5296 .08857 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .10676 L
.54517 .10676 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .10676 L
.54517 .10676 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .05335 L
.56075 .05335 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .05335 L
.56075 .05335 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .09653 L
.57632 .09653 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .09653 L
.57632 .09653 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .05449 L
.5919 .05449 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .05449 L
.5919 .05449 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .02721 L
.60748 .02721 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .02721 L
.60748 .02721 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .06471 L
.62305 .06471 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .06471 L
.62305 .06471 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .06358 L
.63863 .06358 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .06358 L
.63863 .06358 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .02608 L
.65421 .02608 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .02608 L
.65421 .02608 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .1363 L
.66978 .1363 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .1363 L
.66978 .1363 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .03971 L
.68536 .03971 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .03971 L
.68536 .03971 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .15448 L
.70093 .15448 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .15448 L
.70093 .15448 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .05221 L
.71651 .05221 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .05221 L
.71651 .05221 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .03176 L
.73209 .03176 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .03176 L
.73209 .03176 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .01585 L
.74766 .01585 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .01585 L
.74766 .01585 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .08517 L
.76324 .08517 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .08517 L
.76324 .08517 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .02381 L
.77882 .02381 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .02381 L
.77882 .02381 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .13971 L
.79439 .13971 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .13971 L
.79439 .13971 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .02381 L
.80997 .02381 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .02381 L
.80997 .02381 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .11357 L
.82555 .11357 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .11357 L
.82555 .11357 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .02267 L
.84112 .02267 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .02267 L
.84112 .02267 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .02494 L
.8567 .02494 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .02494 L
.8567 .02494 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .02381 L
.87227 .02381 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .02381 L
.87227 .02381 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .12721 L
.88785 .12721 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .12721 L
.88785 .12721 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .02494 L
.90343 .02494 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .02494 L
.90343 .02494 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .07267 L
.919 .07267 L
.919 .01472 L
F
.91589 .01472 m
.91589 .07267 L
.919 .07267 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .01812 L
.93458 .01812 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .01812 L
.93458 .01812 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .11471 L
.95016 .11471 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .11471 L
.95016 .11471 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .01926 L
.96573 .01926 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .01926 L
.96573 .01926 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .01699 L
.98131 .01699 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .01699 L
.98131 .01699 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .01585 L
.99688 .01585 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .01585 L
.99688 .01585 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:oooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol00008ooooo`00;?ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00Oooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000Sooooo000/ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool00009ooooo`00;?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000002Oooool002_ooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00002Oooool002cooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Xoooooooo0000aOl00008ooooo`00:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002?ooool002Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Sooooo000Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0008ooooo`007oooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00Kooooo000Nooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00Kooooo000Nooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Kooooo000Nooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o
0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_oo
O`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l0
0?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o
0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o
0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo
0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go
0000ool00?l0o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003o
o`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o
0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004
ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0
0?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`00
00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003o
oomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o
0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l0
0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo0003o`00
0?oooooooooo00Kooooo000Nooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
0_l0o`001Ol00?ooogl0oomo0?ooooooo`0000;o0?l000?o003ooomo0?ooO`000_ooool2o`3o0005
o`00ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o0?l000Go003o
oomo0?ooO`3oogl0ool00002o`3o0005o`00ooooO`3oogl0oomo0?oo00000ol0o`03oomo0004ool0
0?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0o`03
oomo0004ooooool0o`3o0?l0o`00o`?oogl00_oo0002o`3o00?oogl00_ooool00ol0o`3o003ooomo
0002oomo00;oo`000_l0o`03oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ool00004oooooooo
O`3oogl0oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`02ool000;o0?l00oooO`02ool00003o`3o
0?l00?ooogl000;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00;oo`00
0_l0o`000oooooooogl0oomo0003ool000;ooooo0_ooO`03ool000;ooooo0_ooO`02ool00003o`3o
0?l00?oo003o00;oogl00_oo0002o`3o0003ooooooooO`3oogl000;oo`0000?o0?l0o`00ool00?l0
0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?l0o`000_l00?l2oomo0003oooo
oooo003oo`0000;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo0000
0_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`001Oooooooo`00o`3o0?l0o`3ooooo00;o
ogl000?oooooool00?l0o`000_l00?l2oomo0003oooooooo003oo`0000;ooooo0_ooO`001Ooooooo
o`00o`3o0?l0o`3o003o00;oogl000?oooooool00?l0o`000_l0o`02oomo0003oooooooo003oo`00
00;ooooo0_ooO`000oooooooo`00o`3o0002o`3o00;oogl000Goooooool00?l0o`3o0?l0o`00o`02
oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo
0002ooooo`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0o`03oomo00;o
o`000_ooool3oomo00;oo`001_ooool2o`3o0004o`00ooooO`3oogl0oomo00;oo`000_ooool3oomo
0004ool00?l0o`3o0?l0o`3o00?oogl00ooo00001?ooooooogl0oomo0?ooO`02ool00003o`3o0?l0
0?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?o
o`0000Cooooooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo
0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03ool000;ooooo0_ooO`02ool000;o0?l000?o
oooooomo0?ooO`000ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00ooo0004ooooo`03o`000?oo
oooooooo00Kooooo000Nooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_l0
o`001Ol00?ooogl0oomo0?ooooooo`0000;o0?l000?o003ooomo0?ooO`000_ooool2o`3o0005o`00
ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o0?l000Go003ooomo
0?ooO`3oogl0ool00002o`3o0005o`00ooooO`3oogl0oomo0?oo00000ol0o`03oomo0004ool00?l0
o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0o`03oomo
0004ooooool0o`3o0?l0o`00o`?oogl00_oo0002o`3o00?oogl00_ooool00ol0o`3o003ooomo0002
oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo00?oo`0000Co
oooooomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3o
ogl00_oo00000ol0o`3o003ooomo0002oomo00?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool0
0?l00_ooO`02ool000;o0?l000?ooooooomo0?ooO`000ooo0002ooooo`;oogl00ooo0002ooooo`;o
ogl00_ooool00ol0o`3o003oo`00o`02oomo00;oo`000_l0o`000oooooooogl0oomo0003ool000;o
003o0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?l0o`000_l00?l2oomo0003
oooooooo003oo`0000;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo
00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`001Oooooooo`00o`3o0?l0o`3ooooo
00;oogl000?oooooool00?l0o`000_l00?l2oomo0003oooooooo003oo`0000;ooooo0_ooO`001Ooo
ooooo`00o`3o0?l0o`3o003o00;oogl000?oooooool00?l0o`000_l0o`02oomo0003oooooooo003o
o`0000;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3o
ogl0ooooo`;oo`000_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;ooooo
0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`000_ooool3oomo00;oo`000_ooool3oomo00;o
o`001_ooool2o`3o0004o`00ooooO`3oogl0oomo00;oo`000_ooool3oomo0004ool00?l0o`3o0?l0
o`3o00?oogl00ooo00001?ooooooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00ooo
00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?oo
O`3oogl00_oo00000ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0000
1?ooooooogl0oomo0?ooO`03ool000Cooooo0_oo0002o`3o0003ooooooooO`3oogl000?oo`000_oo
ool2oomo00?oo`001?ooool3ool000Cooooo00?o0000ooooooooool01_ooool001oooooo0_l00007
ooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`3o00;oogl00_oo
ool2o`3o0005o`00ooooO`3oogl0oomo0?oo00000_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00;o
0?l000Go003ooomo0?ooO`3oogl0ool00002o`3o0005o`00ooooO`3oogl0oomo0?oo00000ol0o`03
oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`001?oo003o0?l0
o`3o0?l0o`03oomo0004ooooool0o`3o0?l0o`00o`?oogl00_oo0002o`3o00?oogl00_ooool00ol0
o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo0002o`3o00?oogl00ooo0000
1?ooooooogl0oomo0?ooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo
0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003o
o`00o`02oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo00;ooooo
00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`03ool000;ooooo0_ooO`000oooooooo`00
ool00002ooooo`;oogl000?oooooool00?l0o`000_l00?l2oomo0003oooooooo003oo`0000;ooooo
0_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo
00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool00002ooooo`;oogl000?oooooool00?l0o`00
0_l00?l2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3o
oooo0_oo0002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo0003oooooooo003oo`0000;o
oooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl00_ooool2o`3o
0004o`00ooooO`3oogl0ooooo`;oo`000_ooool3oomo0004ool00?l0o`3o0?l0o`00o`?oogl00_oo
0002ooooo`?oogl00_oo0002ooooo`?oogl00_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl0
0_oo0002ooooo`?oogl000Coo`00o`3o0?l0o`3o0?l00oooO`03ool00004ooooooooO`3oogl0oomo
00;oo`0000?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooo
oomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`001?ooool2ool0
00;o0?l000?ooooooomo0?ooO`000ooo0004ooooo`?oo`001?ooool3ool000Cooooo00?o0000oooo
ooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0
o`3o0?l00_ooO`02ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ool00003o`3o00?oogl000Cooooo
o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`000_ooool3oomo0004oooo
ool0o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool000;ooooo0oooO`001?oo
oooo0?l0o`3o0?l00?l3oomo00;oo`000_l0o`03oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03
ool00004ooooooooO`3oogl0oomo00;oo`000_l0o`03oomo00?oo`0000Cooooooomo0?ooO`3oogl0
0_ooool00ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo00000ol0o`3o
003ooomo0002oomo00?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ool000;o
oooo0_ooO`03ool000;ooooo0_ooO`03ool000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o00;o
ogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;o
oooo0_l0o`001?ooooooogl0oomo0?ooool2ool000Gooooo0_oo0002ooooo`;oogl000?oooooool0
0?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool00002oooo
o`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02oooo
o`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo00000_ooool2
oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo
0002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`000_ooool3oomo0004ool0
0?l0o`3o0?l0o`00o`?oogl00_oo0002ooooo`?oogl00_oo0002ooooo`?oogl00_oo0006ooooo`;o
0?l000Co003ooomo0?ooO`3oogl00_oo0002ooooo`?oogl00_oo0002ooooo`?oogl00ooo00001?oo
ooooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00ooo0004ooooo`?oo`0000Cooooo
oomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`001?ooool3ool0
00;ooooo0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06oooo
o`00:?ooool00ol0003oooooooooo`02o`3o00;o003o0oooool3o`3o00;oogl00_ooool2o`3o0005
o`00ooooO`3oogl0oomo0?oo00000ol0o`03oomo0004ooooool0o`3o0?l0o`00o`?oogl000Coo`00
o`3o0?l0o`3o003o0oooO`02ool000;ooooo0oooO`001?oooooo0?l0o`3o0?l00?l3oomo0004oooo
ool0o`3o0?l0o`00o`?oogl00_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool0
00;o0?l00oooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`02
ool000;o0?l00oooO`03ool00004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00ooooO`000_oo
O`03ool00004ooooooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ool000;ooooo
0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl0
0ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?oo`000_ooool2oomo00?oo`00
0_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Cooooooomo0?ooO`3o
oooo0_oo0005ooooo`;oo`000_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`03
o`3o0?l00?oo003o00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool0
0?l00_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0oooo
o`;oo`000_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`000oooooooo`00ool00002oooo
o`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`000_ooool2oomo00;ooooo0_l0o`00
1?l00?ooogl0oomo0?ooool2ool000;ooooo0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`00
0_ooool3oomo00;oo`000_ooool3oomo00;oo`001_ooool2o`3o0004o`00ooooO`3oogl0oomo00;o
o`001Oooool2ool000;ooooo0oooO`03ool000Cooooo0_oo0002o`3o00?oogl00ooo0004ooooo`?o
o`001?ooool3ool000Kooooo00?o0?l0o`00ooooO`000_ooO`03ool000Cooooo0ooo00001?oooooo
ogl0oomo0?ooO`03ool000Cooooo0ooo0002ooooo`;oogl00ooo0004ooooo`?oo`001?ooool3ool0
00Cooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`?o
oooo0ol0o`02oomo00;ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3oo`0000?o0?l00oooO`001?oo
oooo0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl00_oo0002ooooo`?oogl000Co
ooooo`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00;oo`000_ooool3oomo0004
ooooool0o`3o0?l0o`00o`?oogl00_oo0002o`3o00?oogl00_ooool00ol0o`3o003ooomo0002oomo
00?oo`0000Cooooooomo0?ooO`3oogl00_oo0002o`3o00?oogl00ooo0006ooooo`03o`3o0?l00?oo
ogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00ooo
0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?oo`000_ooool2oomo00?oo`000_oo
ool2oomo00?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_oo
O`05ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo
0?ooool2ool000Gooooo0_oo0005ooooo`;oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l0
0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooo
oooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;o
ogl000?oooooool00?oo00001Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?oo
O`3ooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`?oogl000Cooooo
o`3o0?l0o`3o0?l00oooO`02ool000;ooooo0oooO`02ool000;ooooo0oooO`02ool000Kooooo0_l0
o`001?l00?ooogl0oomo0?ooO`02ool000Gooooo0_oo0002ooooo`?oogl00ooo0004ooooo`?oo`00
00Cooooooomo0?ooO`3oogl00ooo0004ooooo`?oo`001?ooool3ool000Kooooo00?o0?l0o`00oooo
O`000_ooO`03ool000Cooooo0ooo00001?ooooooogl0oomo0?ooO`03ool000Cooooo0ooo0002oooo
o`;oogl00ooo0004ooooo`?oo`001?ooool3ool000Cooooo00?o0000ooooooooool01_ooool002So
oooo0ol00002o`3o00;o003o0oooool3o`3o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo
0?ooool00ol0o`03oomo0004ooooool0o`3o0?l0o`00o`?oogl00_oo0002ooooo`?oogl00_oo0002
ooooo`?oogl000Coooooo`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00;oo`00
0_ooool3oomo0004ooooool0o`3o0?l0o`00o`?oogl00_oo0002o`3o00?oogl00_ooool00ol0o`3o
003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo0002o`3o00?oogl00ooo0006oooo
o`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`02ooooo`03o`3o0?l00?oo
ogl000;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?oo`000_ooool2
oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03
ool000;ooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`00
1?ooooooogl0oomo0?ooool2ool000Gooooo0_oo0005ooooo`;oo`000_ooool2oomo00;ooooo00?o
0?l0o`00ool00?l00_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool00ol0o`3o003oo`00
o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo
0_oo0002ooooo`;oogl000?oooooool00?oo00001Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l0
00Co003ooomo0?ooO`3ooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002oooo
o`?oogl000Coooooo`3o0?l0o`3o0?l00oooO`02ool000;ooooo0oooO`02ool000;ooooo0oooO`02
ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool000Gooooo0_oo0002ooooo`?oogl00ooo
0004ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo0004ooooo`?oo`001?ooool3ool000Kooooo
0_l0o`03oomo00?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00?oo`001?ooool3ool000;o
oooo0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`000oooool2o`0000Sooooo000Xooooo`03o`00
0?oooooooooo00;o0?l00_l00?l3ooooo`?o0?l00_ooO`02ooooo`;o0?l000Go003ooomo0?ooO`3o
ogl0ooooo`03o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?o
ogl000Coooooo`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00;oo`000_ooool3
oomo0004ooooool0o`3o0?l0o`00o`?oogl00ooo00001?ooooooogl0oomo0?ooO`02ooooo`03o`3o
0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`02ool000;o0?l00oooO`03ool000Ko
oooo00?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00
ooooO`000_ooO`03ool000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002oooo
o`;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo
00?oo`000_ooool2oomo00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o
0004ooooooooO`3oogl0ooooo`;oo`001Oooool2ool000Gooooo0_oo0002ooooo`;oogl00_ooool0
0ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo
003o00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?oo
ool2ool000;ooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`000_ooool2oomo00;ooooo0_l0
o`001?l00?ooogl0oomo0?ooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;o
oooo0oooO`001?oooooo0?l0o`3o0?l0o`03oomo00;oo`000_ooool3oomo00;oo`001Oooool2ool0
00Kooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool000Gooooo0_oo0002ooooo`?oogl00ooo0004
ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo0004ooooo`?oo`001?ooool3ool000Kooooo0_l0
o`03oomo00?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00?oo`001?ooool3ool000;ooooo
0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?oo
ool00ol0003oooooooooo`02o`3o00;o003o0oooool3o`3o00;oogl00_ooool2o`3o0005o`00oooo
O`3oogl0oomo0?ooool00ol0o`03oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;oo`00
0_ooool3oomo0004ooooool0o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool0
00;ooooo0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo
ool00ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_oo0002o`3o00?oogl0
0ooo0006ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`02ooooo`03
o`3o0?l00?ooogl000;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?o
o`000_ooool2oomo00?oo`000_ooool2oomo00?oo`001_ooool00ol0o`3o003oo`00o`02oomo00?o
o`000_ooool2oomo00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004
ooooooooO`3oogl0ooooo`;oo`001Oooool2ool000Gooooo0_oo0002ooooo`;oogl00_ooool00ol0
o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o
00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2
ool000;ooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`000_ooool2oomo00;ooooo0_l0o`00
1?l00?ooogl0oomo0?ooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;ooooo
0oooO`001?oooooo0?l0o`3o0?l0o`03oomo00;oo`000_ooool3oomo00;oo`001Oooool2ool000Ko
oooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool000Gooooo0_oo0002ooooo`?oogl00ooo0008oooo
o`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Kooooo0_l0o`03oomo00?oo`001?ooool3ool0
0004ooooooooO`3oogl0oomo00?oo`001?ooool3ool000;ooooo0_ooO`03ool000Cooooo0ooo0004
ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o
00;o003o0oooool3o`3o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo0?ooool00ol0o`03
oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;oo`000_ooool3oomo0004ooooool0o`3o
0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool000;ooooo0oooO`001?oooooo0?l0
o`3o0?l00?l3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo0002oomo
00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03ool000Kooooo00?o
0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00;ooooo0_l0o`03oomo00?oo`00
0_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`03ool000;ooooo
0_ooO`03ool000Kooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`05ooooo`;oogl0
00?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo0?ooool2ool000Go
oooo0_oo0005ooooo`;oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000ooooooo
o`00ool00002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;o
oooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool0
0?oo00001Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0006
ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o0?l0
0oooO`02ool000;ooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3o
ogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Ko
oooo0_l0o`03oomo00?oo`002?ooool3oomo00?oo`001?ooool3ool000;ooooo0_ooO`03ool000Co
oooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003ooooo
ooooo`02o`3o00;o003o0oooool3o`3o00;oogl00_ooool2o`3o0005o`00ooooO`3oogl0oomo0?oo
ool00ol0o`03oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;oo`000_ooool3oomo0004
ooooool0o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool000;ooooo0oooO`00
1?oooooo0?l0o`3o0?l00?l3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool00ol0o`3o003o
oomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03ool0
00Kooooo00?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00;ooooo0_l0o`03
oomo00?oo`000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`03
ool000;ooooo0_ooO`03ool000Kooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`05
ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo0?oo
ool2ool000Gooooo0_oo0005ooooo`;oo`001_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo
003oo`0000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00000_oo
ool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;ooooo0_ooO`000oooooooo`00
ool00005ooooo`;oo`000_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Ko
oooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000;ooooo0oooO`001?oooooo0?l0o`3o0?l0o`03
oomo00;oo`000_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?oo
O`02ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Cooooo0ooo0004ooooo`?oo`001_oo
ool2o`3o00?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?oo`000_ooool2oomo00?oo`001?oo
ool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooo
oooo00;o0?l00_l00?l3ooooo`?o0?l00_ooO`02ooooo`;o0?l000Go003ooomo0?ooO`3oogl0oooo
o`03o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl000Co
ooooo`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00;oo`000_ooool3oomo0004
ooooool0o`3o0?l0o`00o`?oogl00ooo00001?ooooooogl0oomo0?ooO`02ooooo`03o`3o0?l00?oo
ogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`00
1_ooool00ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?o
ogl00ooo0006ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;o
ogl00ooo0006ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002ooooo`;oogl01Oooool2oomo0003
oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo0005oooo
o`;oo`001Oooool2ool000Kooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool00002oooo
o`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02oooo
o`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo00001Oooool2
ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0006ooooo`;o0?l000Co
003ooomo0?ooO`3ooooo0_oo0006ooooo`?o0?l00oooO`02ool000;ooooo0oooO`02ool000Gooooo
0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?o
ogl00ooo0004ooooo`?oo`001?ooool3ool000Kooooo0_l0o`03oomo00?oo`002?ooool3oomo00?o
o`002Oooool2oomo00?oo`001?ooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o0005o`00
ooooO`3oogl0oomo0?ooool00ol0o`03oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;o
o`000_ooool3oomo0004ooooool0o`3o0?l0o`00o`?oogl000Coooooo`3o0?l0o`3o003o0oooO`04
ooooo`?oogl000Coooooo`3o0?l0o`3o003o0oooO`04ooooo`?oogl00_ooool00ol0o`3o003ooomo
0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03ool000Ko
oooo00?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00;ooooo0_l0o`03oomo
00?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`000_ooool2oomo00?oo`001?ooool3
ool000Kooooo00?o0?l0o`00ool00?l00_ooO`03ool000;ooooo0_ooO`05ooooo`;oogl000?ooooo
ool00?oo00000_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo0?ooool2ool000Gooooo0_oo
0005ooooo`;oo`001_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_oo
O`02ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0
o`001?l00?ooogl0oomo0?ooool2ool000;ooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`00
0_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooool2ool000Kooooo0_l0o`001?l00?oo
ogl0oomo0?ooool2ool000Wooooo0oooO`02ool000;ooooo0oooO`02ool000Gooooo0_oo0006oooo
o`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004
ooooo`?oo`001?ooool3ool000Kooooo0_l0o`03oomo00?oo`002?ooool3oomo00?oo`002Oooool2
oomo00?oo`001?ooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Kooooo000Xoooo
o`?o00000_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l000Go003ooomo0?ooO`3oogl0ooooo`03
o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl000Cooooo
o`3o0?l0o`3o003o0oooO`001?oooooo0?l0o`3o0?l00?l3oomo00Cooooo0oooO`000ooooooo0?l0
o`3o0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0
oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`001_ooool00ol0o`3o003ooomo0002oomo
00?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo
003oo`00ooooool00ooo0002ooooo`;oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00
o`02oomo00?oo`000_ooool2oomo00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_oo
ool2o`3o0004ooooooooO`3oogl0ooooo`;oo`001Oooool2ool000Gooooo0_oo0006ooooo`03o`3o
0?l00?oo003o00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l0
0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;o
o`000_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0002ooooo`;oogl00_ooool2o`3o0004
o`00ooooO`3oogl0ooooo`;oo`001_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`002Oooool3
oomo00;oo`000_ooool3oomo00;oo`001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?oo
O`02ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Cooooo0ooo0004ooooo`?oo`001_oo
ool2o`3o00?oogl00ooo0008ooooo`?oogl00ooo0009ooooo`;oogl00ooo0004ooooo`?oo`001?oo
ool3ool000?ooooo0_l00008ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2
oomo00;ooooo0_l0o`001Ol00?ooogl0oomo0?ooO`3ooooo00?o0?l00oooO`000ooooooo0?l0o`3o
0002o`00o`Kooooo0oooO`02ool000;ooooo0oooO`001?oooooo0?l0o`3o0?l00?l3oomo0004oooo
ool0o`3o0?l0o`00o`?oogl01?ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;o
oooo00?o0?l0o`00ooooO`000_ooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo
0?ooO`3oogl00ooo0006ooooo`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?oo
O`02ooooo`;o0?l00oooO`03ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000;ooooo
0_ooO`03ool000Cooooo0ooo0006ooooo`03o`3o0?l00?oo003o00;oogl00ooo0002ooooo`;oogl0
1Oooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l000Cooooooomo0?ooO`3o
oooo0_oo0005ooooo`;oo`001Oooool2ool000Kooooo00?o0?l0o`00ool00?l00_ooO`000ooooooo
o`00ool00002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;o
oooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool0
0?oo00001Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0006
ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0009ooooo`?oogl00_oo0002ooooo`?oogl00_oo
0005ooooo`;oo`001_ooool2o`3o0004o`00ooooO`3oogl0oomo00;oo`002Oooool3oomo00?oo`00
2?ooool3oomo00?oo`001?ooool3ool000Cooooo0ooo0008ooooo`?oogl00ooo0008ooooo`?oogl0
0ooo0009ooooo`;oogl00ooo0004ooooo`?oo`001?ooool3ool000Cooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l000Go
003ooomo0?ooO`3oogl0ooooo`03o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl0
0_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o003o0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?ooogl000;o
ogl00ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`001_ooool0
0ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl00ooo
0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0002ooooo`;oogl00ooo0004ooooo`?oo`00
1_ooool00ol0o`3o003oo`00o`02oomo00?oo`000_ooool2oomo00Gooooo0_ooO`000oooooooo`00
ool00002ooooo`;oogl00_ooool2o`3o0004ooooooooO`3oogl0ooooo`;oo`001Oooool2ool000Go
oooo0_oo0006ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00000_ooool2oomo00;o
oooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004
o`00ooooO`3oogl0ooooo`;oo`000_ooool2oomo0003oooooooo003oo`0000Gooooo0_oo0002oooo
o`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`002?ooool01?l00?ooogl0oomo0?oo
ool2ool000Wooooo0oooO`02ool000;ooooo0oooO`02ool000Gooooo0_oo0006ooooo`;o0?l000Co
003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?oo`00
1?ooool3ool000Sooooo0oooO`03ool000Sooooo0oooO`03ool000Wooooo0_ooO`03ool000Cooooo
0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003ooooooooo
o`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl0
00?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o
003o0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo00001?ooooooogl0oomo0?ooO`03ool0
0004ooooooooO`3oogl0oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooo
oomo0?ooO`3oogl00_ooool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool0
0ooo0002ooooo`;oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00o`02oomo00?oo`00
0_ooool2oomo00Gooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl00_ooool2o`3o0004oooo
ooooO`3oogl0ooooo`;oo`001Oooool2ool000Gooooo0_oo0006ooooo`03o`3o0?l00?oo003o00;o
ogl000?oooooool00?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000ooooooo
o`00ool00002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0ooooo`;oo`000_ooool2oomo
0003oooooooo003oo`0000Gooooo0_oo0002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0
ooooo`;oo`002?ooool01?l00?ooogl0oomo0?ooool2ool000Wooooo0oooO`02ool000;ooooo0ooo
O`02ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl0
0ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000Sooooo
0oooO`03ool000Wooooo0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003ooooo
ooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0
o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl0
1?ooool3oomo0004ooooool0o`3o0?l0o`00o`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?o
ogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?o
o`0000Cooooooomo0?ooO`3oogl01?ooool3oomo00?oo`001_ooool00ol0o`3o003oo`00o`02oooo
o`?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo
003oo`00ooooool00ooo0002ooooo`;oogl00ooo0004ooooo`?oo`001_ooool00ol0o`3o003oo`00
o`02oomo00?oo`002Oooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`05ooooo`;oogl000?o
ooooool00?oo00001Oooool2ool000Gooooo0_oo0006ooooo`03o`3o0?l00?oo003o00;oogl000?o
ooooool00?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool0
0006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo0000
1Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`04
o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Oooool2ool000Gooooo0_oo0006oooo
o`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004
ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000Sooooo0oooO`03ool000Wooooo0_ooO`03
ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0
003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooO`04
ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo0004ooooool0o`3o
0?l0o`00o`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l0
0?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl0
1?ooool3oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3o
ogl00_ooool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0002oooo
o`;oogl00ooo0004ooooo`?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2
oomo0003oooooooo003oo`0000;ooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001Oooool2
ool000Gooooo0_oo0006ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00000_ooool2
oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00ool00006ooooo`;o0?l000Co003o
oomo0?ooO`3ooooo0_oo0005ooooo`;oo`001Oooool2ool000;ooooo0_ooO`02ooooo`;o0?l000Co
003ooomo0?ooO`3ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;o
o`001Oooool2ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009oooo
o`?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool0
00Sooooo0oooO`03ool000Wooooo0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0
003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;o
oooo0_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6oooo
o`?oogl01?ooool3oomo0004ooooool0o`3o0?l0o`00o`?oogl000?oooooo`3o0?l0o`000_l00?l6
ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02
ooooo`?oo`0000Cooooooomo0?ooO`3oogl01?ooool3oomo00?oo`001_ooool00ol0o`3o003oo`00
o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl00_ooool2o`3o00?oogl00ooo0006ooooo`05o`3o
0?l00?oo003oo`00ooooool00ooo0002ooooo`;oogl00ooo0004ooooo`?oo`001_ooool01Ol0o`3o
003oo`00ool00?oooooo00?oo`002Oooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`05oooo
o`;oogl000?oooooool00?oo00001Oooool2ool000Gooooo0_oo0006ooooo`03o`3o0?l00?oo003o
00;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`000ooo
ooooo`00ool00006ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001Oooool2
ool000;ooooo0_ooO`02ooooo`;o0?l000Co003ooomo0?ooO`3ooooo0_oo0008ooooo`04o`00oooo
O`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Oooool2ool000Gooooo0_oo0006ooooo`;o0?l0
00Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?o
o`001?ooool3ool000Sooooo0oooO`03ool000Sooooo0oooO`03ool000Wooooo0_ooO`03ool000Co
oooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003ooooo
ooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?o
ogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo0004ooooool0o`3o0?l0o`00
o`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6oooo
o`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl01?ooool3
oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl00_oo
ool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`00
1?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`000ooooooo
o`00ool00002ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000Gooooo0_oo0005ooooo`;o
o`001_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`03
o`3o0?l00?oo003o00;oogl000?oooooool00?oo00001_ooool2o`3o0004o`00ooooO`3oogl0oooo
o`;oo`001Oooool2ool000Gooooo0_oo0002ooooo`;oogl00_ooool2o`3o0004o`00ooooO`3oogl0
ooooo`;oo`002?ooool01?l00?ooogl0oomo0?ooool2ool000Wooooo0oooO`02ool000Gooooo0_oo
0005ooooo`;oo`001_ooool2o`3o0004o`00ooooO`3oogl0oomo00;oo`002Oooool3oomo00?oo`00
2?ooool3oomo00?oo`001?ooool3ool000Cooooo0ooo0008ooooo`?oogl00ooo0008ooooo`?oogl0
0ooo0009ooooo`;oogl00ooo0004ooooo`?oo`001?ooool3ool000Cooooo00?o0000ooooooooool0
1_ooool002Sooooo0ol00002o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0ooo
O`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o0?l0
0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo00001?ooooooogl0oomo0?ooO`04ooooo`?o
ogl00ooo0006ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0006ooooo`;o0?l00oooO`03ool000Ko
oooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0004ooooo`?oo`001_ooool01Ol0
o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0_ooO`00
0oooooooo`00ool00005ooooo`;oo`001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o0_oo
ool2ool000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00002?oo
ool01?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo0005ooooo`;oo`000_ooool2oomo00;ooooo
0_l0o`001?l00?ooogl0oomo0?ooool2ool000Sooooo00Co003ooomo0?ooO`3ooooo0_oo0009oooo
o`?oogl00_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooO`02
ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Cooooo0ooo0004ooooo`?oo`002?ooool3
oomo00?oo`002?ooool3oomo00?oo`002Oooool2oomo00?oo`001?ooool3ool000Cooooo0ooo0003
ooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`02oooo
o`;o0?l00_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo
0004ooooool0o`3o0?l0o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl000?ooooo
o`3o0?l0o`000_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooo
oomo0?ooO`3oogl01?ooool3oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001_oo
ool2o`3o00?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`00
1?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`0<ooooo`;o
ogl000?oooooool00?oo00001Oooool2ool000Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00
o`;ooooo0_oo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`00
00Sooooo00Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02
o`00o`;ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Ooo
ool2ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl0
0ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000Sooooo
0oooO`03ool000Wooooo0_ooO`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003ooooo
ooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0
o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Co
ooooo`3o0?l0o`3o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0
o`3o0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo00001?ooooooogl0
oomo0?ooO`04ooooo`?oogl00ooo0006ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0006ooooo`;o
0?l00oooO`03ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0004oooo
o`?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_ooO`00
0oooooooo`00ool00005ooooo`;oo`001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o0_oo
ool2ool000;ooooo0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl000?oooooool00?oo00002?oo
ool01?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo0005ooooo`;oo`001_ooool2o`3o00;o003o
0_ooool2ool000Sooooo00Co003ooomo0?ooO`3ooooo0_oo0009ooooo`?oogl00_oo0005ooooo`;o
o`001Oooool2ool000Kooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool000Wooooo0oooO`03ool0
00Sooooo0oooO`03ool000Cooooo0ooo0004ooooo`?oo`002?ooool3oomo00?oo`002?ooool3oomo
00?oo`002Oooool2oomo00?oo`001?ooool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo
00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o
003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`001?oooooo
0?l0o`3o0?l0o`03oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo0003ooooool0o`3o0?l0
00;o003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool00004ooooooooO`3oogl0
oomo00Cooooo0oooO`03ool000Kooooo00?o0?l0o`00ool00?l00_ooool3ool000Kooooo0_l0o`03
oomo00?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`001?ooool3ool000Cooooo0ooo
0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0009ooooo`;oogl03?ooool2oomo0003oooo
oooo003oo`0000Gooooo0_oo0005ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;o
ogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000Sooooo00Co003ooomo0?oo
O`3ooooo0_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0008oooo
o`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Oooool2ool000Gooooo0_oo0006
ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo
0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000Sooooo0oooO`03ool000Wooooo0_oo
O`03ool000Cooooo0ooo0004ooooo`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool0
0ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`00
0ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o0?l00ooo
O`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0ooo
O`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo00001?ooooooogl0oomo0?ooO`04ooooo`?oogl0
0ooo0006ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0006ooooo`;o0?l00oooO`03ool000Kooooo
00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0004ooooo`?oo`001_ooool01Ol0o`3o
003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`001Oooool2ool000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00;ooooo0_l0o`00
1?ooooooogl0oomo0?ooool2ool000Sooooo00Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`00
1Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;o
o`002Oooool3oomo00;oo`001Oooool2ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?oo
O`3oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool0
00Sooooo0oooO`03ool000Sooooo0oooO`03ool000Wooooo0_ooO`03ool000Cooooo0ooo0004oooo
o`?oo`001?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o
003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o0?l00oooO`000ooooooo0?l0o`3o0002o`00
o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o
00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0008oooo
o`?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`001?ooool3
ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`0<ooooo`;oogl000?o
ooooool00?oo00001Oooool2ool000Gooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo
0_ooO`02ooooo`;o0?l000Cooooooomo0?ooO`3ooooo0_oo0008ooooo`04o`00ooooO`3oogl0oooo
o`;oo`001Oooool2ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002?ooool01?l0
0?ooogl0oomo0?ooool2ool000Wooooo0oooO`02ool000Gooooo0_oo0005ooooo`;oo`001_ooool2
o`3o0004o`00ooooO`3oogl0oomo00;oo`002Oooool3oomo00?oo`002?ooool3oomo00?oo`001?oo
ool3ool000Cooooo0ooo0008ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`001?oo
ool3ool000Cooooo0ooo0004ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooo
oooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o
0?l000;o003o1_ooool3oomo00Cooooo0oooO`001?oooooo0?l0o`3o0?l0o`03oomo0003ooooool0
o`3o0?l000;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;ooooo00?o
0?l0o`00ool00?l00_ooool3ool000Sooooo0oooO`03ool000Kooooo00?o0?l0o`00ool00?l00_oo
ool3ool000Sooooo0oooO`03ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo
0ooo0004ooooo`?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo00co
oooo0_ooO`000oooooooo`00ool00005ooooo`;oo`003Oooool01?l0o`3o003oo`00ool00?l6oooo
o`;oogl00_ooool2o`3o0004ooooooooO`3oogl0ooooo`;oo`002?ooool01?l00?ooogl0oomo0?oo
ool2ool000Gooooo0_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Sooooo00Co
003ooomo0?ooO`3ooooo0_oo0009ooooo`?oogl00_oo0005ooooo`;oo`001Oooool2ool000Kooooo
0_l0o`001?l00?ooogl0oomo0?ooO`02ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Co
oooo0ooo0004ooooo`?oo`002?ooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`03ool000Co
oooo0ooo000;ooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000_l0o`02o`00o`Kooooo
0_ooO`02ooooo`;o0?l00_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl0
1?ooool3oomo0004ooooool0o`3o0?l0o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?o
ogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?o
o`002?ooool3oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?oo`002?ooool3oomo00?o
o`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`001?ooool3ool000Cooooo0ooo0006oooo
o`05o`3o0?l00?oo003oo`00ooooool00ooo0009ooooo`;oogl03?ooool2oomo0003oooooooo003o
o`0000Gooooo0_oo000=ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`02ooooo`;o0?l000Co
oooooomo0?ooO`3ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000Go
oooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002?ooool01?l00?ooogl0oomo0?ooool2ool0
00Wooooo0oooO`02ool000Gooooo0_oo0005ooooo`;oo`001_ooool2o`3o0004o`00ooooO`3oogl0
oomo00;oo`002Oooool3oomo00?oo`002?ooool3oomo00?oo`001?ooool3ool000Cooooo0ooo0008
ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`001?ooool3ool000[ooooo0_l00008
ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00
o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o
0?l0o`3o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002
o`00o`Kooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0008ooooo`?oogl00ooo0006
ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`05o`3o0?l00?oo
003oo`00ooooool00ooo0004ooooo`?oo`001?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003o
ooooo`03ool000Wooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00001Oooool2ool000gooooo
00Co0?l0o`00ool00?oo003o1_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo0?ooool2ool0
00Sooooo00Co003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02
o`00o`;ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Ooo
ool2ool000Gooooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl0
0ooo0008ooooo`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000_ooooo
0ooo0009ooooo`;oogl00ooo0004ooooo`?oo`002oooool00ol0003oooooooooo`06ooooo`00:?oo
ool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0ooo
O`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o0?l0
0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00oooo
ool00ooo0004ooooo`?oo`001?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool0
00Wooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00001Oooool2ool000gooooo00Co0?l0o`00
ool00?oo003o1_ooool2oomo00;ooooo0_l0o`001?ooooooogl0oomo0?ooool2ool000Sooooo00Co
003ooomo0?ooO`3ooooo0_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo
0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Oooool2ool000Go
oooo0_oo0006ooooo`;o0?l000Co003ooomo0?ooO`3oogl00_oo0009ooooo`?oogl00ooo0008oooo
o`?oogl00ooo0004ooooo`?oo`001?ooool3ool000Sooooo0oooO`03ool000_ooooo0ooo0009oooo
o`;oogl00ooo0004ooooo`?oo`002oooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003o
ooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo
0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o0?l00oooO`000ooo
oooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02oooo
o`03o`3o0?l00?oo003o00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`03o`3o0?l00?oo003o
00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004
ooooo`?oo`001?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_oo
O`0<ooooo`;oogl000?oooooool00?oo00001Oooool2ool000kooooo0ol00?l6ooooo`;oogl00_oo
ool2o`3o0004ooooooooO`3oogl0ooooo`;oo`002?ooool01?l00?ooogl0oomo0?ooool2ool000Go
oooo0_oo0005ooooo`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Sooooo00Co003ooomo0?oo
O`3ooooo0_oo0009ooooo`?oogl00_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`001?l0
0?ooogl0oomo0?ooO`02ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Cooooo0ooo0004
ooooo`?oo`002?ooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`03ool000Cooooo0ooo000;
ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6oooo
o`;oogl00_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo
00Cooooo0oooO`001?oooooo0?l0o`3o0?l0o`03oomo0003ooooool0o`3o0?l000;o003o1_ooool3
oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3
ool000Sooooo0oooO`03ool000Kooooo00?o0?l0o`00ool00?l00_ooool3ool000Sooooo0oooO`03
ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0004ooooo`?oo`001_oo
ool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_ooO`000oooooooo`00
ool00005ooooo`;oo`003_ooool3o`00o`Kooooo0_ooO`02ooooo`;o0?l000Cooooooomo0?ooO`3o
oooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000gooooo0_l0o`02o`00
o`;ooooo0_oo0008ooooo`04o`00ooooO`3oogl0ooooo`;oo`002Oooool3oomo00;oo`001Oooool2
ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?ooool3
oomo00?oo`001?ooool3ool000Cooooo0ooo0008ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2
oomo00?oo`001?ooool3ool000_ooooo00?o0000ooooooooool01_ooool000Oooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Oooooo00?o0000oooo
ooooool00_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l00_l00?l6ooooo`?oogl000?oooooo`3o
0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo0004ooooool0o`3o0?l0o`3o00?oogl000?ooooo
o`3o0?l0o`000_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_ooool0
0ol0o`3o003oo`00o`0=ooooo`?oogl00ooo0006ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0008
ooooo`?oogl00ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`001?oo
ool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`0<ooooo`;oogl0
00?oooooool00?oo00001Oooool2ool000kooooo0ol00?l:ooooo`;o0?l000?ooooooomo0?ooO`00
2oooool01?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo000=ooooo`;o0?l00_l00?l2ooooo`;o
o`002?ooool01?l00?ooogl0oomo0?ooool2ool000Wooooo0oooO`02ool000Gooooo0_oo0005oooo
o`;oo`001_ooool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool0
00Cooooo0ooo0004ooooo`?oo`002?ooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`07oooo
o`?oo`002oooool00ol0003oooooooooo`06ooooo`001_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l0
0_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo0004oooo
ool0o`3o0?l0o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl000?oooooo`3o0?l0
o`000_l00?l6ooooo`?oogl00oooool2o`00o`gooooo0oooO`03ool000Kooooo00?o0?l0o`00ool0
0?l00_ooool3ool000Sooooo0oooO`03ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool0
00Cooooo0ooo0004ooooo`?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2
oomo00cooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`003_ooool3o`00o`[ooooo0_l0o`00
0oooooooogl0oomo000;ooooo`04o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000gooooo0_l0
o`02o`00o`;ooooo0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00;oo`001Ooo
ool2ool000Gooooo0_oo0006ooooo`;o0?l00_l00?l2ooooo`;oo`002Oooool3oomo00?oo`002?oo
ool3oomo00?oo`001?ooool3ool000Cooooo0ooo0008ooooo`?oogl00ooo000;ooooo`?oo`002Ooo
ool2oomo00Oooooo0ooo000;ooooo`03o`000?oooooooooo00Kooooo0006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0ol00002o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo
0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl000Coooooo`3o0?l0o`3o
0?l00oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`03ooooo`;o003o3Oooool3oomo00?oo`001_ooool00ol0o`3o003oo`00o`02ooooo`?o
o`002?ooool3oomo00?oo`001_ooool01?l0o`3o003oo`00ool00?l8ooooo`?oo`001?ooool3ool0
00Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`0<ooooo`;oogl000?ooooo
ool00?oo00001Oooool2ool000kooooo0ol00?l:ooooo`;o0?l000?ooooooomo0?ooO`002oooool0
1?l00?ooogl0oomo0?ooool2ool000Gooooo0_oo000=ooooo`;o0?l00_l00?l2ooooo`;oo`002Ooo
ool2oomo0003oooooooo003oo`0000Wooooo0oooO`02ool000Gooooo0_oo0005ooooo`;oo`001_oo
ool2o`3o00;o003o0_ooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`03ool000Cooooo0ooo
0004ooooo`?oo`002?ooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`07ooooo`?oo`002Ooo
ool3o`0000Sooooo0006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l00_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`00
0_l00?l6ooooo`?oogl01?ooool3oomo0004ooooool0o`3o0?l0o`3o00?oogl000?oooooo`3o0?l0
o`000_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00oooool2o`00o`go
oooo0oooO`03ool000Kooooo00?o0?l0o`00ool00?l00_ooool3ool000Sooooo0oooO`03ool000Ko
oooo00Co0?l0o`00ool00?oo003o2?ooool3ool000Cooooo0ooo0006ooooo`05o`3o0?l00?oo003o
o`00ooooool00ooo0009ooooo`;oogl03?ooool2oomo0003oooooooo003oo`0000Gooooo0_oo000>
ooooo`?o003o2_ooool2o`3o0003ooooooooO`3oogl000_ooooo00Co003ooomo0?ooO`3ooooo0_oo
0005ooooo`;oo`003Oooool2o`3o00;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool0
0009ooooo`?oogl00_oo0005ooooo`;oo`001Oooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo
0009ooooo`?oogl00ooo0008ooooo`?oogl01oooool3ool000Cooooo0ooo0008ooooo`?oogl00ooo
000;ooooo`?oo`002Oooool2oomo00Oooooo0ooo000;ooooo`03o`000?oooooooooo00Kooooo0006
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooo000000?o00001oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;o
oooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?o
ogl000Coooooo`3o0?l0o`3o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooo
oooo0?l0o`3o0002o`00o`Kooooo0oooO`03ooooo`;o003o3Oooool3oomo00?oo`001_ooool00ol0
o`3o003oo`00o`02ooooo`?oo`002?ooool3oomo00?oo`001_ooool01?l0o`3o003oo`00ool00?l8
ooooo`?oo`001?ooool3ool000Kooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_oo
O`0<ooooo`;oogl000?oooooool00?oo00001Oooool2ool000kooooo0ol00?l:ooooo`;o0?l000?o
oooooomo0?ooO`002oooool2o`00o`;ooooo0_oo0005ooooo`;oo`003Oooool2o`3o00;o003o0_oo
ool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl00_oo0005ooooo`;oo`001Ooo
ool2ool000Kooooo0ol0o`03ooooo`;oo`002Oooool3oomo00_ooooo0oooO`07ooooo`?oo`001?oo
ool3ool000Sooooo0oooO`03ool000_ooooo0ooo0009ooooo`;oogl01oooool3ool000_ooooo00?o
0000ooooooooool01_ooool000Kooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`02o`3o00;o
003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`08ooooo`?o0?l00oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`000ooooooo
0?l0o`3o0002o`00o`Kooooo0oooO`03ooooo`;o003o3Oooool3oomo00Wooooo00?o0?l0o`00ool0
0?l00_ooool3ool000Sooooo0oooO`03ool000Kooooo00Co0?l0o`00ool00?oo003o2?ooool3ool0
00Cooooo0ooo0006ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0009ooooo`;oogl03?ooool2
oomo0003oooooooo003oo`0000Gooooo0_oo000>ooooo`?o003o2_ooool2o`3o0003ooooooooO`3o
ogl000_ooooo0_l00?l2ooooo`;oo`001Oooool2ool000gooooo0_l0o`02o`00o`;ooooo0_oo0009
ooooo`;oogl000?oooooool00?oo00002Oooool3oomo00;oo`001Oooool2ool000Gooooo0_oo0006
ooooo`?o0?l03_ooool3oomo00_ooooo0oooO`0>ooooo`?oo`002?ooool3oomo00?oo`002oooool3
ool000Wooooo0_ooO`07ooooo`?oo`002oooool00ol0003oooooooooo`06ooooo`001oooool2o`00
00[ooooo0_l00003ooooo`?o00000_ooool5o`0000Kooooo00?o0000ooooooooool00_l0o`02o`00
o`Kooooo0_ooO`02ooooo`;o0?l00_l00?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6oooo
o`?oogl02?ooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl000?oooooo`3o
0?l0o`000_l00?l6ooooo`?oogl00oooool2o`00o`gooooo0oooO`09ooooo`03o`3o0?l00?oo003o
00;ooooo0ooo0008ooooo`?oogl00ooo0006ooooo`04o`3o0?l00?oo003oo`00o`Sooooo0ooo0004
ooooo`?oo`001_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_oo
O`000oooooooo`00ool00005ooooo`;oo`003_ooool3o`00o`[ooooo0_l0o`000oooooooogl0oomo
000;ooooo`;o003o0_ooool2ool000Gooooo0_oo000=ooooo`;o0?l00_l00?l2ooooo`;oo`002Ooo
ool2oomo0003oooooooo003oo`0000Wooooo0oooO`02ool000Gooooo0_oo0005ooooo`;oo`001_oo
ool3o`3o00kooooo0oooO`0;ooooo`?oogl03_ooool3ool000Sooooo0oooO`03ool000_ooooo0ooo
0009ooooo`;oogl01oooool3ool000_ooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000
ooooooooool00_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l00_l00?l6ooooo`?oogl000?ooooo
o`3o0?l0o`000_l00?l6ooooo`?oogl02?ooool3o`3o00?oogl000?oooooo`3o0?l0o`000_l00?l:
ooooo`;o0?l00_l00?l<ooooo`;o003o3Oooool3oomo00Wooooo00?o0?l0o`00ool00?l03Oooool3
oomo00?oo`001_ooool01?l0o`3o003oo`00ool00?l8ooooo`?oo`001?ooool3ool000Kooooo00Go
0?l0o`00ool00?oo003oooooo`03ool000Wooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo0000
1Oooool2ool000kooooo0ol00?l:ooooo`;o0?l000?ooooooomo0?ooO`002oooool2o`00o`;ooooo
0_oo000Fooooo`;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl0
0_oo0005ooooo`;oo`003Oooool3o`3o00kooooo0oooO`0;ooooo`?oogl03_ooool3ool000Sooooo
0oooO`03ool000_ooooo0ooo0009ooooo`;oogl01oooool3ool000_ooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`02ooooo`;o0?l00_l0
0?l6ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl02?ooool3o`3o00?oogl000?o
ooooo`3o0?l0o`000_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o3Oooool3oomo00Wooooo00?o
0?l0o`00ool00?l03Oooool3oomo00?oo`001_ooool01?l0o`3o003oo`00ool00?l?ooooo`?oo`00
1_ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_ooO`000ooooooo
o`00ool00005ooooo`;oo`003_ooool3o`00o`[ooooo0_l0o`0>ooooo`;o003o0_ooool2ool001Ko
oooo0_l00?l2ooooo`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`02ool000Go
oooo0_oo000=ooooo`?o0?l03_ooool3oomo00_ooooo0oooO`0>ooooo`?oo`002?ooool3oomo00?o
o`002oooool3ool000Wooooo0_ooO`07ooooo`?oo`002oooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo
0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`0;ooooo`?oogl000?oooooo`3o0?l0o`00
0_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o3Oooool3oomo00Wooooo00?o0?l0o`00ool00?l0
3Oooool3oomo00?oo`001_ooool01?l0o`3o003oo`00ool00?l?ooooo`?oo`001_ooool01Ol0o`3o
003oo`00ool00?oooooo00?oo`002Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`003_ooool3o`00o`[ooooo0_l0o`0>ooooo`;o003o0_ooool2ool001Kooooo0_l00?l2oooo
o`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`07ooooo`;oo`003Oooool3o`3o
00kooooo0oooO`0;ooooo`?oogl03_ooool3ool000Sooooo0oooO`03ool000_ooooo0ooo0009oooo
o`;oogl01oooool3ool000_ooooo00?o0000ooooooooool01_ooool002Sooooo0ol00002o`3o00;o
003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`0;ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o
003o3Oooool3oomo00Wooooo00?o0?l0o`00ool00?l03Oooool3oomo00?oo`001oooool3o`00oaSo
oooo00Co0?l0o`00ool00?oo003o3Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`003_ooool3o`00o`[ooooo0_l0o`0>ooooo`;o003o0_ooool2ool001Kooooo0_l00?l2oooo
o`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`07ooooo`;oo`003Oooool3o`3o
00kooooo0oooO`0;ooooo`?oogl03_ooool3ool000Sooooo0oooO`03ool000_ooooo0ooo0009oooo
o`;oogl01oooool3ool000[ooooo0_l00008ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o
003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Ko
oooo0oooO`0;ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o
003o3Oooool3oomo00Wooooo00?o0?l0o`00ool00?l03Oooool3oomo00?oo`001oooool3o`00oaSo
oooo00Co0?l0o`00ool00?oo003o3Oooool2oomo00cooooo0_ooO`000oooooooo`00ool00005oooo
o`;oo`003_ooool3o`00o`[ooooo0_l0o`0>ooooo`;o003o6_ooool2o`00o`;ooooo0_oo0009oooo
o`;oogl000?oooooool00?oo00002Oooool3oomo00Oooooo0_oo000=ooooo`?o0?l03_ooool3oomo
01cooooo0ooo0008ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00Oooooo0ooo000;oooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;o
ogl00_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00_o
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03
o`3o0?l00?oo003o00gooooo0oooO`03ool000Oooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00
o`gooooo0_ooO`0<ooooo`;oogl000?oooooool00?oo00001Oooool2ool000kooooo0ol00?l:oooo
o`;o0?l03_ooool2o`00oa[ooooo0_l00?l2ooooo`;oo`002Oooool2oomo0003oooooooo003oo`00
00Wooooo0oooO`07ooooo`;oo`003Oooool3o`3o00kooooo0oooO`0Looooo`?oo`002?ooool3oomo
00?oo`002oooool3ool001;ooooo0ooo000;ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03
o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o003o1_ooool3oomo0003
ooooool0o`3o0?l000;o003o1_ooool3oomo00_ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`[o
oooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o00gooooo0oooO`03ool000Oo
oooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00o`gooooo0_ooO`0<ooooo`;oogl000?oooooool0
0?oo00001Oooool2ool000kooooo0ol00?l:ooooo`;o0?l03_ooool2o`00oa[ooooo0_l00?l2oooo
o`;oo`002Oooool2oomo0003oooooooo003oo`0000Wooooo0oooO`07ooooo`;oo`003Oooool3o`3o
00kooooo0oooO`0Looooo`?oo`002?ooool3oomo00?oo`002oooool3ool001;ooooo0ooo000;oooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;o
ogl00_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00_o
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03
o`3o0?l00?oo003o00gooooo0oooO`03ool000Oooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00
oa_ooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`003_ooool3o`00o`[ooooo0_l0o`0>oooo
o`;o003o6_ooool2o`00o`;ooooo0_oo0009ooooo`;oogl000?oooooool00?oo00002Oooool3oomo
00Oooooo0_oo000=ooooo`?o0?l03_ooool3oomo02Oooooo0oooO`03ool000_ooooo0ooo000Poooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;o
ogl00_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o6?ooool2o`3o00;o
003o2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l03Oooool3oomo00?o
o`001oooool3o`00oaSooooo00Co0?l0o`00ool00?oo003o6oooool2oomo0003oooooooo003oo`00
00Gooooo0_oo000>ooooo`?o003o2_ooool2o`3o00kooooo0_l00?lJooooo`;o003o0_ooool2ool0
00Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01oooool2ool000gooooo0ol0o`0>oooo
o`?oogl09oooool3oomo00kooooo0ooo000Pooooo`03o`000?oooooooooo00Kooooo000Xooooo`03
o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o003o1_ooool3oomo0003
ooooool0o`3o0?l000;o003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWo
oooo00?o0?l0o`00ool00?l03Oooool3oomo00[ooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00
oa_ooooo0_ooO`000oooooooo`00ool00005ooooo`;oo`003_ooool3o`00oa[ooooo0_l00?lJoooo
o`;o003o0_ooool2ool000Wooooo0_ooO`000oooooooo`00ool00009ooooo`?oogl01oooool2ool0
00gooooo0ol0o`0>ooooo`?oogl09oooool3oomo037ooooo00?o0000ooooooooool01_ooool002So
oooo0ol00002o`3o00;o003o2_ooool2o`3o00;o003o1_ooool3oomo0003ooooool0o`3o0?l000;o
003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool0
0?l03Oooool3oomo00[ooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00oakooooo0_oo0005oooo
o`;oo`003_ooool3o`00oa[ooooo0_l00?lJooooo`;o003o0_ooool2ool000Wooooo0_ooO`000ooo
ooooo`00ool00009ooooo`?oogl01oooool2ool000gooooo0ol0o`0>ooooo`?oogl09oooool3oomo
033ooooo0_l00008ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o
003o1_ooool3oomo0003ooooool0o`3o0?l000;o003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o
003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l03Oooool3oomo00[ooooo0ol00?lHooooo`;o
0?l08?ooool2ool000Gooooo0_oo000>ooooo`?o003o=_ooool2o`00o`;ooooo0_oo0009ooooo`;o
ogl03?ooool3oomo01Kooooo0ol0o`0>ooooo`?oogl0Foooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o003o2_ooool2o`3o00;o003o
6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l0
6_ooool3o`00oaSooooo0_l0o`0Wooooo`;oo`003_ooool3o`00ocKooooo0_l00?l2ooooo`;oo`00
2Oooool2oomo00cooooo0oooO`0Fooooo`?o0?l03_ooool3oomo05_ooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`[ooooo0_l0
o`02o`00oaSooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l0
0?oo003o01[ooooo0ol00?lHooooo`;o0?l09oooool2ool000kooooo0ol00?lfooooo`;o003o0_oo
ool2ool000Wooooo0_ooO`0<ooooo`?oogl05_ooool3o`3o00kooooo0oooO`1Kooooo`03o`000?oo
oooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l:
ooooo`;o0?l00_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o6Oooool0
0ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o02Oooooo0_oo000>ooooo`?o003o=_ooool2
o`00o`;ooooo0_oo0009ooooo`;oogl03?ooool3oomo01Kooooo0ol0o`0>ooooo`?oogl0Foooool0
0ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o
00;o003o2_ooool2o`3o00;o003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00
oaWooooo00?o0?l0o`00ool00?l06_ooool3o`00oaSooooo0_l0o`0Wooooo`;oo`003_ooool3o`00
ocKooooo0_l00?l2ooooo`;oo`005oooool3oomo01Kooooo0ol0o`0>ooooo`?oogl0Foooool00ol0
003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o
003o2_ooool2o`3o00;o003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWo
oooo00?o0?l0o`00ool00?l06_ooool3o`00oaSooooo0_l0o`0Wooooo`;oo`003_ooool3o`00ocKo
oooo0_l00?l2ooooo`;oo`005oooool3oomo01Kooooo0ol0o`1/ooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`?o00000_l0o`02o`00o`[ooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00oaSooooo
0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo
0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?l2ooooo`;oo`005oooool3oomo01Kooooo
0ol0o`1[ooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0
o`02o`00o`[ooooo0_l0o`02o`00oaSooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l0
0?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l0
0?l2ooooo`;oo`005oooool3oomo01Kooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o6?ooool2
o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3
o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00o`;ooooo0_oo000Gooooo`?oogl05_ooool3
o`3o06cooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00
o`[ooooo0_l0o`02o`00o`cooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<oooo
o`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfoooo
o`;o003o0_ooool2ool001Oooooo0oooO`0Fooooo`?o0?l0K?ooool00ol0003oooooooooo`06oooo
o`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaSo
oooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[o
oooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?l2ooooo`;oo`005oooool3oomo01Ko
oooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l0
0_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o6?ooool2o`3o00;o003o2_ooool2o`3o00;o003o
3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3o`00oaSooooo0_l0o`0gooooo`?o003o
=_ooool2o`00o`;ooooo0_oo000Gooooo`?oogl05_ooool3o`3o06cooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l0
0?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00
o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o0_ooool2ool0033ooooo0ol0
o`1/ooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000_l0o`02o`00o`[ooooo0_l0o`02
o`00o`cooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o6Oooool0
0ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o0_ooool2
ool0033ooooo0ol0o`1[ooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00
o`[ooooo0_l0o`02o`00o`cooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<oooo
o`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfoooo
o`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooooooo
ool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o
0?l00_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oo
oooo0ol00?lfooooo`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool002Sooooo
00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool2o`3o00;o003o
2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3o`00oaSooooo
0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo
000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo0_l0
o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol0
0?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003ooooooooo
o`06ooooo`003Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00007
ooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo0_l0o`02
o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol00?lH
ooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003oooooooooo`06
ooooo`003?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l0
3Oooool2o`00oaSooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o
0?l00?oo003o01[ooooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0
K?ooool00ol0003oooooooooo`06ooooo`003?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`3o00;o
003o2_ooool3o`3o00gooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o
003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o
003o=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool000cooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0ol00002o`3o
00;o003o2_ooool3o`3o00gooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<oooo
o`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfoooo
o`;o003o=?ooool3o`3o06[ooooo0ol00008ooooo`003?ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooo`000?ooool01?l00007ooooo`03o`000?oooooooooo00;o0?l00_l00?l:
ooooo`?o0?l03Oooool2o`00oaSooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lI
ooooo`03o`3o0?l00?oo003o01[ooooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ld
ooooo`?o0?l0K?ooool00ol0003oooooooooo`06ooooo`003?ooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00002_ooool00ol0003oooooooooo`02o`3o00;o003o
2_ooool3o`3o00gooooo0_l00?lHooooo`;o0?l00_l00?l:ooooo`;o0?l00_l00?l<ooooo`;o003o
6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o
=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool000gooooo0_l0000:ooooo`;o00000_oo
ool5o`0000Kooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?oo
ool2o`3o00;o003o2_ooool2o`3o00;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_oo
ool3o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oo
oooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2
o`00oaSooooo0_l0o`02o`00o`[ooooo0_l0o`02o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo
003o01[ooooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool0
0ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o
00gooooo0_l00?lHooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00
ool00?l06_ooool3o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/oooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o
0?l03Oooool2o`00oaSooooo0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o
003oo`00o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06co
oooo00?o0000ooooooooool01_ooool002Sooooo0ol00002o`3o00;o003o2_ooool3o`3o00gooooo
0_l00?lHooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l0
6_ooool3o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1[ooooo`;o0000
2?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?oo
ool2o`3o00;o003o3?ooool2o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol0
0?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003ooooooooo
o`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lH
ooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3
o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooo
oooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00
oaSooooo0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Joooo
o`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06cooooo00?o0000oooo
ooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o
003o6?ooool2o`3o00;o003o3?ooool2o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[o
oooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo
0_l00?lHooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l0
6_ooool3o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`00
0?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Ooo
ool2o`00oaSooooo0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00
o`0Jooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06cooooo00?o
0000ooooooooool01_ooool002Sooooo0ol00002o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lH
ooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3
o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1[ooooo`;o00002?ooool0
02Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool2o`3o
00;o003o3?ooool2o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol00?lHoooo
o`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003oooooooooo`06oooo
o`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lHooooo`;o
0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3o`00oaSo
oooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo
0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o
6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?oo
ool2o`3o00;o003o3?ooool2o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[ooooo0ol0
0?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003ooooooooo
o`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lH
ooooo`;o0?l00_l00?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3
o`00oaSooooo0_l0o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooo
oooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00
oaSooooo0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Joooo
o`?o003o6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06cooooo00?o0000oooo
ooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o
003o6?ooool2o`3o00;o003o3?ooool2o`00o`cooooo0_l00?lIooooo`03o`3o0?l00?oo003o01[o
oooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003o
ooooooooo`06ooooo`00:?ooool3o`0000;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo
0_l0o`02o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0Jooooo`?o003o
6?ooool2o`3o03Oooooo0ol00?lfooooo`;o003o=?ooool3o`3o06_ooooo0_l00008ooooo`00:?oo
ool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lHooooo`;o0?l00_l0
0?l<ooooo`;o003o3?ooool2o`00oaWooooo00?o0?l0o`00ool00?l06_ooool3o`00oaSooooo0_l0
o`0gooooo`?o003o=_ooool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo0_l0o`02
o`00o`cooooo0_l00?l<ooooo`;o003o6Oooool2o`3o01_ooooo0ol00?lHooooo`;o0?l0=oooool3
o`00ocKooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0
003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo0_l00?lHooooo`;o0?l00_l00?l<oooo
o`;o003o3?ooool2o`00oaWooooo0_l0o`0Kooooo`?o003o6?ooool2o`3o03Oooooo0ol00?lfoooo
o`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooooooo
ool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool3o`3o00gooooo0_l00?l<ooooo`;o
003o6Oooool2o`3o01_ooooo0ol00?lHooooo`;o0?l0=oooool3o`00ocKooooo0_l00?ldooooo`?o
0?l0K?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o
2_ooool3o`3o00gooooo0_l00?lHooooo`?o0?l03Oooool2o`00o`cooooo0_l00?lIooooo`;o0?l0
6oooool3o`00oaSooooo0_l0o`1`ooooo`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?oo
ool3o`3o00gooooo0_l00?l<ooooo`;o003o6Oooool2o`3o01_ooooo0ol00?lHooooo`;o0?l0L?oo
ool2o`00ocCooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000_l0o`02
o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool3o`3o00gooooo0_l00?l<ooooo`;o003o6Oooool2
o`3o01_ooooo0ol00?lHooooo`;o0?l0L?ooool2o`00ocCooooo0ol0o`1[ooooo`;o00002?ooool0
02Sooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool3o`3o
00gooooo0_l00?l<ooooo`;o003o6Oooool2o`3o01_ooooo0ol00?lHooooo`;o0?l0L?ooool2o`00
ocCooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o
0?l00_l00?l:ooooo`?o0?l03Oooool2o`00oaSooooo0ol0o`0=ooooo`;o003o3?ooool2o`00oaWo
oooo0_l0o`0Kooooo`?o003o6?ooool2o`3o073ooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00gooooo
0_l00?lHooooo`?o0?l03Oooool2o`00o`cooooo0_l00?lIooooo`;o0?l06oooool3o`00oaSooooo
0_l0o`1`ooooo`;o003o=?ooool3o`3o06cooooo00?o0000ooooooooool01_ooool002Sooooo00?o
0000ooooooooool00_l0o`02o`00o`[ooooo0ol0o`0=ooooo`;o003o6?ooool3o`3o00gooooo0_l0
0?l<ooooo`;o003o6Oooool2o`3o01_ooooo0ol00?lHooooo`;o0?l0L?ooool2o`00ocCooooo0ol0
o`1/ooooo`03o`000?oooooooooo00Kooooo0007ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`02
o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003o3?ooool2o`00oaWooooo0_l0o`0K
ooooo`?o003o6?ooool2o`3o073ooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003oooooooooo`06
ooooo`001_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003o
6?ooool2o`3o073ooooo0_l00?ldooooo`?o0?l0K?ooool00ol0003oooooooooo`06ooooo`001_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`?o00000_l0o`02o`00oa[ooooo0_l00?lHooooo`?o
0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003o6?ooool2o`3o073ooooo0_l00?ldooooo`?o
0?l0J_ooool3o`0000Sooooo0006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0o`0Koooo
o`?o003o6?ooool2o`3o0:Kooooo0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo0006ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003
o`0000Oooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2
o`00obOooooo0_l0o`0Kooooo`?o003o6?ooool2o`3o0:Kooooo0ol0o`1/ooooo`03o`000?oooooo
oooo00Kooooo0006ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo
0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003o6?ooool2o`3o0:Kooooo
0ol0o`1/ooooo`03o`000?oooooooooo00Kooooo0007ooooo`;o00002_ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000003o`0000Kooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l0
0?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003o6?ooool2o`3o0?oooooo5_oo
ool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2
o`00oaSooooo0ol0o`0=ooooo`;o003o9oooool2o`3o01_ooooo0ol00?oooooooc3ooooo00?o0000
ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHoooo
o`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003oooooool`ooooo`03o`000?oooooooooo
00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00go
oooo0_l00?lWooooo`;o0?l06oooool3o`00oooooooo<?ooool00ol0003oooooooooo`06ooooo`00
:?ooool3o`0000;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00gooooo0_l00?lWooooo`;o0?l0
6oooool3o`00oooooooo;oooool2o`0000Sooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l0
0?lJooooo`;o003o6?ooool3o`3o00gooooo0_l00?lWooooo`;o0?l06oooool3o`00oooooooo<?oo
ool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2
o`00oaSooooo0ol0o`0=ooooo`;o003o9oooool2o`3o01_ooooo0ol00?oooooooc3ooooo00?o0000
ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHoooo
o`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003oooooool`ooooo`03o`000?oooooooooo
00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00go
oooo0_l00?lWooooo`;o0?l06oooool3o`00oooooooo<?ooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003o
9oooool2o`3o01_ooooo0ol00?oooooooc3ooooo00?o0000ooooooooool01_ooool002Sooooo00?o
0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0
o`0Kooooo`?o003oooooool`ooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000_l0o`02
o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003oooooool_
ooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHoooo
o`?o0?l03Oooool2o`00obOooooo0_l0o`0Kooooo`?o003oooooool`ooooo`03o`000?oooooooooo
00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00go
oooo0_l00?lWooooo`;o0?l06oooool3o`00oooooooo<?ooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003o
9oooool2o`3o01_ooooo0ol00?oooooooc3ooooo00?o0000ooooooooool01_ooool002Sooooo00?o
0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00obOooooo0_l0
o`0Kooooo`?o003oooooool`ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooo
oooo00;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00gooooo0_l00?m4ooooo`?o003oooooool`
ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJoooo
o`;o003o6?ooool3o`3o00gooooo0_l00?m4ooooo`?o003oooooool`ooooo`03o`000?oooooooooo
00Kooooo000Xooooo`?o00000_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00odCo
oooo0ol00?oooooooboooooo0_l00008ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o
6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooooomgooooo`03o`000?oooooooooo00Kooooo
000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJooooo`;o003o6?ooool3o`3o00gooooo0_l0
0?ooooooogOooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02
o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00ooooooooMoooool00ol0003oooooooooo`06
ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=oooo
o`;o003ooooooomgooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o
0?l00_l00?lJooooo`;o003o6?ooool3o`3o00gooooo0_l00?ooooooogOooooo00?o0000oooooooo
ool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l0
3Oooool2o`00ooooooooMoooool00ol0003oooooooooo`06ooooo`00:?ooool3o`0000;o0?l00_l0
0?lJooooo`;o003o6?ooool3o`3o00gooooo0_l00?ooooooogKooooo0_l00008ooooo`00:?ooool0
0ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooooomg
ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?lJoooo
o`;o003o6?ooool3o`3o00gooooo0_l00?ooooooogOooooo00?o0000ooooooooool01_ooool002So
oooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l00?lHooooo`?o0?l03Oooool2o`00oooo
ooooMoooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o
6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooooomgooooo`03o`000?oooooooooo00Kooooo
000Cooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003ooooooooo
o`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooooomgooooo`03o`000?oo
oooooooo00Kooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooo
oomgooooo`03o`000?oooooooooo00Kooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02o`3o00;o003o6_ooool2o`00oaSooooo0ol0
o`0=ooooo`;o003ooooooomgooooo`03o`000?oooooooooo00Kooooo000Booooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000;o0?l00_l00?lJooooo`;o003o6?oo
ool3o`3o00gooooo0_l00?ooooooogGooooo0ol00008ooooo`004_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l0o`02o`00oa[ooooo0_l0
0?lHooooo`?o0?l03Oooool2o`00ooooooooMoooool00ol0003oooooooooo`06ooooo`004_ooool0
1?l0003oooooooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`02o`3o00;o003o6_oo
ool2o`00oaSooooo0ol0o`0=ooooo`;o003ooooooomgooooo`03o`000?oooooooooo00Kooooo000C
ooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o0?l00_l00?ld
ooooo`?o0?l03Oooool2o`00ooooooooMoooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0
003oooooooooo`02o`3o00;o003o=?ooool3o`3o0?ooooooQ_ooool00ol0003oooooooooo`06oooo
o`00:?ooool00ol0003oooooooooo`02o`3o00;o003o=?ooool3o`3o0?ooooooQ_ooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003o=?ooool3o`3o0?oooooo
Q_ooool00ol0003oooooooooo`06ooooo`00:?ooool3o`0000;o0?l00_l00?ldooooo`?o0?l0oooo
oon5ooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`3o
ooooohKooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00
ocCooooo0ol0o`3oooooohKooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooooooo
ool00_l0o`02o`00ocCooooo0ol0o`3oooooohKooooo00?o0000ooooooooool01_ooool002Sooooo
00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`3oooooohKooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`3oooooohKooooo00?o
0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`3o
ooooohKooooo00?o0000ooooooooool01_ooool002Sooooo0ol00002o`3o00;o003o=?ooool3o`3o
0?ooooooQOooool2o`0000Sooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`?o
0?l0oooooon6ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l0
0_l00?ldooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oo
oooooooo00;o0?l00_l00?ldooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`?o0?l0oooooon6ooooo`03o`000?oooooo
oooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`?o0?l0oooooon6oooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgo
oooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oooooooo
_Oooool00ol0003oooooooooo`06ooooo`00:?ooool3o`0000;o0?l00_l00?oooooookcooooo0_l0
0008ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooo
oooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000oooo
ooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`00
0?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o
0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool0
0ol0003oooooooooo`06ooooo`00:?ooool3o`0000;o0?l00_l00?oooooookcooooo0_l00008oooo
o`00:?ooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003ooooooooo
o`06ooooo`00:?ooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooo
oooo00Kooooo0007ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`00
00;ooooo0ol00007ooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000oooo
ooooool01_ooool000Kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool01_ooool000Kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool3o`0000;o0?l00_l00?oooooook_ooooo0ol00008ooooo`001_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o
0000ooooooooool01_ooool000Kooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000ol00007ooooo`03o`000?oooooooooo00;o0?l0
0_l00?oooooookgooooo00?o0000ooooooooool01_ooool000Kooooo00Co0000oooooooooooo0000
2?ooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo00?o0000oooo
ooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`06ooooo`001oooool2o`0000[o
oooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00006ooooo`03o`000?oooooooooo00;o
0?l00_l00?oooooookgooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool01_ooool002Sooooo0ol00003o`3o0?oooooo_Oooool2o`00
00Sooooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo
000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o0000
0ol0o`3ooooookgooooo0_l00008ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`06ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`06ooooo`00:?ooool3o`0000?o0?l0oooooonmooooo`;o00002?ooool002Sooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool01_ooool002Sooooo0ol00003o`3o0?oooooo_Oooool2o`0000So
oooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo
000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000=ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Oooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool000cooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`003?ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`003?ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool3o`00
00?o0?l0oooooonlooooo`?o00002?ooool000cooooo00Co0000oooooooooooo00002Oooool01?l0
003oooooooooooooool4o`0000Oooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool01_ooool000cooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06
ooooo`003Oooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000ol0o`3ooooookgooooo0_l0
0008ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06
ooooo`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06oooo
o`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00:?oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00:?ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00:?ooool3o`00
00?o0?l0oooooonmooooo`;o00002?ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool01_ooool002Sooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
1_ooool002Sooooo0ol00003o`3o0?oooooo_Oooool2o`0000Sooooo000Xooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Kooooo000Xooooo`?o00000ol0o`3ooooookgooooo0_l00008oooo
o`00:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00:?oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`00:?ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`001oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Oooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool000Ko
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Kooooo0006ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0ol00003
o`3o0?oooooo_?ooool3o`0000Sooooo0006ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool000Kooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?o00001oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`001_ooool01?l0
003oooooooooool00008ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool00000
2_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`06ooooo`001ooo
ool2o`0000[ooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`0000Kooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool01_ooool002Sooooo0ol00003o`3o0?oo
oooo_Oooool2o`0000Sooooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Kooooo000Xooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003oooooooooo`06
ooooo`00:?ooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool01_ooool002So
oooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`00:?ooool3o`0000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_l00008ooooo`00:?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000002?ooool002Soooooool00035o`0000Sooooo003oooooooGooooo003ooooo
ooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003ooooo
ooGooooo000[ooooo`?o00000oooool5o`0000?ooooo0ol00005ooooo`?o00000oooool3o`0000Co
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`;o00000_ooool3o`0000Co
oooo0ol00003ooooo`Co00000_ooool5o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000?ooooo1Ol00002ooooo`Go00000_ooool5o`000003
ooooool0003o000000Co00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;o
oooo1Ol00002ooooo`Go00000_ooool4o`0000Cooooo0ol00003ooooo`Co00000_ooool5o`0000?o
oooo1?l00004ooooo`?o00000oooool5o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000?o
oooo1Ol00003ooooo`Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`0000?o
oooo1?l00002ooooo`Go00000_ooool5o`0000?ooooo1?l00002ooooo`Go00000_ooool4o`0000Co
oooo0ol00003ooooo`Co00000_ooool5o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000;o
oooo1Ol00003ooooo`Co00001?ooool3o`0000Sooooo000/ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool00004ooooo`04o`000?oooooo0000o`0000Cooooo0_l00004ooooo`04o`000?oooooo0000
o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0000;ooooo00?o0000ooooooooool00_l00004ooooo`;o00000oooool00ol0003ooooooooo
o`02o`0000Cooooo0_l000001?oooooo0000ooooooooool2o`000003ooooool0003o000000?ooooo
00Co0000oooooooooooo00000_ooool2o`000008ooooool0003o0000ooooool0003oooooo`000?oo
ool2o`0000?ooooo0_l000001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo
0000ooooool0003ooooo00;o00000oooool02Ol0003oooooooooool0003oooooo`000?oooooo0000
ooooo`02o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`0>o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l0
0002ooooo`;o00001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool01_l0
003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Go00001_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000001?ooool01?l0003oooooo`000?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l0
0002ooooo`Go00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000Gooooo0_l00003ooooo`04o`000?oooooo0000o`0000Co
oooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool00ol0003o
ooooooooo`02o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001_ooool2o`00
00;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Oooool01Ol0003oooooo`00
0?oooooo000000?ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000000oooool2o`0000;o
oooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go000000?oooooo`000?l0
00001?l00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`000?l0
00001?l00005ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00005ooooo`;o000000?oooooo`000?l000001?l00005
ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Cooooo00Go0000ooooool0003oooooo`00
0003ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo0000
0_ooool2o`000003ooooool0003o000000?o00002?ooool002cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Co00001_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool4o`000003oooo
ool0003ooooo00?ooooo00Co0000ooooool0003o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo00Co0000oooooooooooo00001_ooool2o`0000;ooooo1?l00006oooo
o`03o`000?oooooooooo00;ooooo0ol00004ooooo`Co00000oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`?o00000_ooool00ol0003oooooooooo`02
o`0000Kooooo00?o0000ooooooooool01Ol00005ooooo`;o00000oooool4o`0000?ooooo1?l00003
ooooo`04o`000?oooooo0000o`0000Cooooo0ol00005ooooo`;o00001?ooool3o`0000;ooooo00?o
0000ooooooooool00_l00006ooooo`;o00000_ooool5o`0000Gooooo0_l00003ooooo`Co00000ooo
ool4o`0000?ooooo00Co0000oooooooooooo00000oooool2o`000003ooooool0003ooooo00;ooooo
00Co0000ooooool0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo1Ol00003ooooo`04o`000?oooooo0000o`0000?ooooo1?l00003
ooooo`Go00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000003ooooo`;o000000Coooooo`000?oooooo00000_ooool00ol0003ooooo
o`000005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`03ooooo`03o`00
0?oooooo000000;ooooo0ol000001?oooooo0000ooooooooool4o`0000?ooooo1?l00003ooooo`Co
00000oooool4o`0000?ooooo1?l00002ooooo`04o`000?ooooooooooo`0000Wooooo000/ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000004ooooo`04
o`000?oooooo0000o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00;o00001Oooool2o`00
00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo00Co0000oooooooooooo00001_ooool2
o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000
ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool4o`000003
ooooool0003ooooo00;o00000oooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo
00;o00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l00005ooooo`;o00000_oo
ool01_l0003oooooo`000?oooooo0000ooooo`Co00000_ooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`02ooooo`;o000000Koooooo`000?oo
oooo0000ooooool00003ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000002
ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000003ooooo`Co00000_oo
ool5o`0000;ooooo00Go0000ooooool0003oooooo`000004ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`Go00000oooool4o`0000?ooooo1?l00002ooooo`Go
00000oooool4o`0000?ooooo1?l00002ooooo`Go00000_ooool5o`0000?ooooo1?l00002ooooo`Go
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000009ooooo`00:oooool2o`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0ol00004ooooo`Co0000
0oooool3o`0000?ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;o0000
1?ooool2o`0000?ooooo00Co0000ooooool0003o00001?ooool3o`0000?ooooo00?o0000ooooool0
00000_l00002ooooo`03o`000?oooooo000000;o00000_ooool2o`0000;ooooo0_l00002ooooo`03
o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`?o000000?oooooo`000?ooool00_l00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool3o`000006ooooool0003oooooo`000?oooooo00000oooool01?l0
003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000Coooooo`000?oooooooooo0_l00003ooooo`04o`000?oooooo0000o`0000?o
oooo1?l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000Co
oooo0ol00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?l00002oooo
o`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool01?l0003oooooooooooooool3o`0000?ooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000oooool2o`000003ooooool0003o
oooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000000_ooool01Ol0003oooooo`00
0?oooooo000000Cooooo0_l00009ooooo`00;?ooool00ol0003oooooooooo`03ooooo`?o00001?oo
ool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`0000?ooooo
0ol00004ooooo`?o00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Cooooo
0ol00004ooooo`?o00001_ooool01?l0003oooooooooooooool5o`0000Cooooo0_l00003ooooo`Go
00000oooool3o`0000Cooooo1?l00004ooooo`?o00001?ooool3o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000;ooooo1Ol00004ooooo`?o00000_ooool5o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00002ooooo`Ko
00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00004ooooo`03
o`000?oooooo000000?ooooo1?l00003ooooo`Co00001Oooool2o`0000;ooooo1Ol00004ooooo`?o
00000_ooool5o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go
00000_ooool5o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol000000ooooooo
0000o`000004o`0000;ooooo1Ol00002ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co
00000oooool4o`0000Gooooo00?o0000ooooooooool01oooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-5.12722, -0.0145721, 0.142355, \
0.000684939}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 1.84481 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10696 -24 -4.5 ]
[-0.0125 .10696 0 4.5 ]
[-0.0125 .1992 -18 -4.5 ]
[-0.0125 .1992 0 4.5 ]
[-0.0125 .29144 -24 -4.5 ]
[-0.0125 .29144 0 4.5 ]
[-0.0125 .38368 -18 -4.5 ]
[-0.0125 .38368 0 4.5 ]
[-0.0125 .47592 -24 -4.5 ]
[-0.0125 .47592 0 4.5 ]
[-0.0125 .56816 -18 -4.5 ]
[-0.0125 .56816 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10696 m
.00625 .10696 L
s
[(0.05)] -0.0125 .10696 1 0 Mshowa
0 .1992 m
.00625 .1992 L
s
[(0.1)] -0.0125 .1992 1 0 Mshowa
0 .29144 m
.00625 .29144 L
s
[(0.15)] -0.0125 .29144 1 0 Mshowa
0 .38368 m
.00625 .38368 L
s
[(0.2)] -0.0125 .38368 1 0 Mshowa
0 .47592 m
.00625 .47592 L
s
[(0.25)] -0.0125 .47592 1 0 Mshowa
0 .56816 m
.00625 .56816 L
s
[(0.3)] -0.0125 .56816 1 0 Mshowa
.125 Mabswid
0 .03316 m
.00375 .03316 L
s
0 .05161 m
.00375 .05161 L
s
0 .07006 m
.00375 .07006 L
s
0 .08851 m
.00375 .08851 L
s
0 .1254 m
.00375 .1254 L
s
0 .14385 m
.00375 .14385 L
s
0 .1623 m
.00375 .1623 L
s
0 .18075 m
.00375 .18075 L
s
0 .21764 m
.00375 .21764 L
s
0 .23609 m
.00375 .23609 L
s
0 .25454 m
.00375 .25454 L
s
0 .27299 m
.00375 .27299 L
s
0 .30988 m
.00375 .30988 L
s
0 .32833 m
.00375 .32833 L
s
0 .34678 m
.00375 .34678 L
s
0 .36523 m
.00375 .36523 L
s
0 .40213 m
.00375 .40213 L
s
0 .42057 m
.00375 .42057 L
s
0 .43902 m
.00375 .43902 L
s
0 .45747 m
.00375 .45747 L
s
0 .49437 m
.00375 .49437 L
s
0 .51281 m
.00375 .51281 L
s
0 .53126 m
.00375 .53126 L
s
0 .54971 m
.00375 .54971 L
s
0 .58661 m
.00375 .58661 L
s
0 .60505 m
.00375 .60505 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10696 m
1 .10696 L
s
.99375 .1992 m
1 .1992 L
s
.99375 .29144 m
1 .29144 L
s
.99375 .38368 m
1 .38368 L
s
.99375 .47592 m
1 .47592 L
s
.99375 .56816 m
1 .56816 L
s
.125 Mabswid
.99625 .03316 m
1 .03316 L
s
.99625 .05161 m
1 .05161 L
s
.99625 .07006 m
1 .07006 L
s
.99625 .08851 m
1 .08851 L
s
.99625 .1254 m
1 .1254 L
s
.99625 .14385 m
1 .14385 L
s
.99625 .1623 m
1 .1623 L
s
.99625 .18075 m
1 .18075 L
s
.99625 .21764 m
1 .21764 L
s
.99625 .23609 m
1 .23609 L
s
.99625 .25454 m
1 .25454 L
s
.99625 .27299 m
1 .27299 L
s
.99625 .30988 m
1 .30988 L
s
.99625 .32833 m
1 .32833 L
s
.99625 .34678 m
1 .34678 L
s
.99625 .36523 m
1 .36523 L
s
.99625 .40213 m
1 .40213 L
s
.99625 .42057 m
1 .42057 L
s
.99625 .43902 m
1 .43902 L
s
.99625 .45747 m
1 .45747 L
s
.99625 .49437 m
1 .49437 L
s
.99625 .51281 m
1 .51281 L
s
.99625 .53126 m
1 .53126 L
s
.99625 .54971 m
1 .54971 L
s
.99625 .58661 m
1 .58661 L
s
.99625 .60505 m
1 .60505 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .02572 L
.00623 .02572 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .02572 L
.00623 .02572 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .01472 L
.02181 .01472 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .01472 L
.02181 .01472 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .0568 L
.03738 .0568 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .0568 L
.03738 .0568 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .01472 L
.05296 .01472 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .01472 L
.05296 .01472 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .15847 L
.06854 .15847 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .15847 L
.06854 .15847 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
F
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .01536 L
.09969 .01536 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .01536 L
.09969 .01536 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .01472 L
.11526 .01472 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .01472 L
.11526 .01472 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .0458 L
.13084 .0458 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .0458 L
.13084 .0458 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .01472 L
.14642 .01472 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .01472 L
.14642 .01472 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .17724 L
.16199 .17724 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .17724 L
.16199 .17724 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .01472 L
.17757 .01472 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .01472 L
.17757 .01472 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .10407 L
.19315 .10407 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .10407 L
.19315 .10407 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .01601 L
.20872 .01601 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .01601 L
.20872 .01601 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .01472 L
.2243 .01472 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .01472 L
.2243 .01472 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .01472 L
.23988 .01472 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .01472 L
.23988 .01472 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .03867 L
.25545 .03867 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .03867 L
.25545 .03867 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .01472 L
.27103 .01472 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .01472 L
.27103 .01472 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .10084 L
.2866 .10084 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .10084 L
.2866 .10084 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .01472 L
.30218 .01472 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .01472 L
.30218 .01472 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .07623 L
.31776 .07623 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .07623 L
.31776 .07623 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .01536 L
.33333 .01536 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .01536 L
.33333 .01536 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .01472 L
.34891 .01472 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .01472 L
.34891 .01472 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .01472 L
.36449 .01472 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .01472 L
.36449 .01472 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .04968 L
.38006 .04968 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .04968 L
.38006 .04968 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .01472 L
.39564 .01472 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .01472 L
.39564 .01472 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .01472 L
.41121 .01472 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .01472 L
.41121 .01472 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .08465 L
.44237 .08465 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .08465 L
.44237 .08465 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .01472 L
.47352 .01472 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .01472 L
.47352 .01472 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .01472 L
.4891 .01472 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .01472 L
.4891 .01472 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .06652 L
.50467 .06652 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .06652 L
.50467 .06652 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .01472 L
.52025 .01472 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .01472 L
.52025 .01472 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .14487 L
.53583 .14487 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .14487 L
.53583 .14487 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .01472 L
.5514 .01472 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .01472 L
.5514 .01472 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .12156 L
.56698 .12156 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .12156 L
.56698 .12156 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .01472 L
.58255 .01472 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .01472 L
.58255 .01472 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .01472 L
.59813 .01472 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .01472 L
.59813 .01472 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .01472 L
.61371 .01472 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .01472 L
.61371 .01472 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .12285 L
.62928 .12285 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .12285 L
.62928 .12285 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .01472 L
.64486 .01472 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .01472 L
.64486 .01472 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .01795 L
.66044 .01795 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .01795 L
.66044 .01795 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .18566 L
.69159 .18566 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .18566 L
.69159 .18566 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .01472 L
.72274 .01472 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .01472 L
.72274 .01472 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .07947 L
.75389 .07947 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .07947 L
.75389 .07947 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .14875 L
.78505 .14875 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .14875 L
.78505 .14875 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .01472 L
.80062 .01472 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .01472 L
.80062 .01472 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .12415 L
.8162 .12415 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .12415 L
.8162 .12415 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .01472 L
.84735 .01472 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .01472 L
.84735 .01472 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .01472 L
.86293 .01472 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .01472 L
.86293 .01472 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .09889 L
.8785 .09889 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .09889 L
.8785 .09889 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .01472 L
.90966 .01472 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .01472 L
.90966 .01472 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .1371 L
.94081 .1371 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .1371 L
.94081 .1371 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .01472 L
.97196 .01472 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .01472 L
.97196 .01472 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .01472 L
.02492 .01472 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .01472 L
.02492 .01472 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .16041 L
.0405 .16041 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .16041 L
.0405 .16041 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .01536 L
.05607 .01536 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .01536 L
.05607 .01536 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .04774 L
.07165 .04774 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .04774 L
.07165 .04774 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .01472 L
.08723 .01472 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .01472 L
.08723 .01472 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .01536 L
.1028 .01536 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .01536 L
.1028 .01536 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .01472 L
.11838 .01472 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .01472 L
.11838 .01472 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .1889 L
.13396 .1889 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .1889 L
.13396 .1889 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .01472 L
.14953 .01472 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .01472 L
.14953 .01472 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .01601 L
.16511 .01601 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .01601 L
.16511 .01601 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .01472 L
.18069 .01472 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .01472 L
.18069 .01472 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .08206 L
.19626 .08206 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .08206 L
.19626 .08206 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .01536 L
.21184 .01536 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .01536 L
.21184 .01536 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .19149 L
.25857 .19149 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .19149 L
.25857 .19149 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .01472 L
.27414 .01472 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .01472 L
.27414 .01472 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .07429 L
.28972 .07429 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .07429 L
.28972 .07429 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .01472 L
.3053 .01472 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .01472 L
.3053 .01472 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .10019 L
.32087 .10019 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .10019 L
.32087 .10019 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .01472 L
.35202 .01472 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .01472 L
.35202 .01472 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .17401 L
.38318 .17401 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .17401 L
.38318 .17401 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .01472 L
.41433 .01472 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .01472 L
.41433 .01472 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .08012 L
.44548 .08012 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .08012 L
.44548 .08012 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .01472 L
.46106 .01472 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .01472 L
.46106 .01472 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .09112 L
.50779 .09112 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .09112 L
.50779 .09112 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .01472 L
.52336 .01472 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .01472 L
.52336 .01472 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .03155 L
.53894 .03155 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .03155 L
.53894 .03155 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .06134 L
.57009 .06134 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .06134 L
.57009 .06134 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .01472 L
.60125 .01472 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .04839 L
.6324 .04839 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .04839 L
.6324 .04839 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .01472 L
.66355 .01472 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .01472 L
.66355 .01472 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .05033 L
.6947 .05033 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .05033 L
.6947 .05033 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01472 L
.71028 .01472 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01472 L
.71028 .01472 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .05486 L
.75701 .05486 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .05486 L
.75701 .05486 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .0186 L
.78816 .0186 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .0186 L
.78816 .0186 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .02054 L
.81931 .02054 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .02054 L
.81931 .02054 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .03932 L
.88162 .03932 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .03932 L
.88162 .03932 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .01731 L
.94393 .01731 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .01731 L
.94393 .01731 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .25819 L
.01246 .25819 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .25819 L
.01246 .25819 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .01472 L
.02804 .01472 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .01472 L
.02804 .01472 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .15199 L
.04361 .15199 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .15199 L
.04361 .15199 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .01472 L
.05919 .01472 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .01472 L
.05919 .01472 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .07817 L
.07477 .07817 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .07817 L
.07477 .07817 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .01472 L
.09034 .01472 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .01472 L
.09034 .01472 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .01472 L
.10592 .01472 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .01472 L
.1215 .01472 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .01472 L
.1215 .01472 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .15005 L
.13707 .15005 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .15005 L
.13707 .15005 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .01472 L
.15265 .01472 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .01795 L
.16822 .01795 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .01795 L
.16822 .01795 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .01472 L
.1838 .01472 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .01472 L
.1838 .01472 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .12803 L
.19938 .12803 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .12803 L
.19938 .12803 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .01472 L
.21495 .01472 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .01472 L
.21495 .01472 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .01472 L
.23053 .01472 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .01472 L
.23053 .01472 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .15652 L
.26168 .15652 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .15652 L
.26168 .15652 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .12285 L
.29283 .12285 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .12285 L
.29283 .12285 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .01472 L
.30841 .01472 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .01472 L
.30841 .01472 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .11961 L
.32399 .11961 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .11961 L
.32399 .11961 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .01472 L
.33956 .01472 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .01472 L
.33956 .01472 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .01472 L
.37072 .01472 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .16041 L
.38629 .16041 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .16041 L
.38629 .16041 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .01472 L
.43302 .01472 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .10472 L
.4486 .10472 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .10472 L
.4486 .10472 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .01472 L
.49533 .01472 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .13062 L
.5109 .13062 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .13062 L
.5109 .13062 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .05939 L
.54206 .05939 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .05939 L
.54206 .05939 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .01472 L
.55763 .01472 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .09501 L
.57321 .09501 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .09501 L
.57321 .09501 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .01472 L
.58879 .01472 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .08335 L
.63551 .08335 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .08335 L
.63551 .08335 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .07364 L
.69782 .07364 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .07364 L
.69782 .07364 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .10731 L
.76012 .10731 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .10731 L
.76012 .10731 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .02508 L
.79128 .02508 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .02508 L
.79128 .02508 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .02896 L
.82243 .02896 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .02896 L
.82243 .02896 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .08206 L
.88474 .08206 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .08206 L
.88474 .08206 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .0199 L
.94704 .0199 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .0199 L
.94704 .0199 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .01472 L
.01558 .01472 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .01472 L
.01558 .01472 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .06716 L
.03115 .06716 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .06716 L
.03115 .06716 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .01472 L
.04673 .01472 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .01472 L
.04673 .01472 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .07105 L
.06231 .07105 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .07105 L
.06231 .07105 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .0186 L
.07788 .0186 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .0186 L
.07788 .0186 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .06263 L
.09346 .06263 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .06263 L
.09346 .06263 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .06198 L
.10903 .06198 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .06198 L
.10903 .06198 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .06716 L
.12461 .06716 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .06716 L
.12461 .06716 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .01472 L
.14019 .01472 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .01472 L
.14019 .01472 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .08853 L
.15576 .08853 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .08853 L
.15576 .08853 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .02249 L
.17134 .02249 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .02249 L
.17134 .02249 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .06393 L
.18692 .06393 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .06393 L
.18692 .06393 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .01536 L
.20249 .01536 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .01536 L
.20249 .01536 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .06781 L
.21807 .06781 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .06781 L
.21807 .06781 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .07753 L
.23364 .07753 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .07753 L
.23364 .07753 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .06976 L
.24922 .06976 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .06976 L
.24922 .06976 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .01472 L
.2648 .01472 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .01472 L
.2648 .01472 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .05939 L
.28037 .05939 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .05939 L
.28037 .05939 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .01472 L
.29595 .01472 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .01472 L
.29595 .01472 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .05421 L
.31153 .05421 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .05421 L
.31153 .05421 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .01472 L
.3271 .01472 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .01472 L
.3271 .01472 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .0581 L
.34268 .0581 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .0581 L
.34268 .0581 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .05227 L
.35826 .05227 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .05227 L
.35826 .05227 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .06263 L
.37383 .06263 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .06263 L
.37383 .06263 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .01472 L
.38941 .01472 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .01472 L
.38941 .01472 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .0568 L
.40498 .0568 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .0568 L
.40498 .0568 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .06134 L
.42056 .06134 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .06134 L
.42056 .06134 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .0445 L
.43614 .0445 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .0445 L
.43614 .0445 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .01472 L
.45171 .01472 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .01472 L
.45171 .01472 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .05162 L
.46729 .05162 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .05162 L
.46729 .05162 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .07105 L
.48287 .07105 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .07105 L
.48287 .07105 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .05033 L
.49844 .05033 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .05033 L
.49844 .05033 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .01472 L
.51402 .01472 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .01472 L
.51402 .01472 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .05939 L
.5296 .05939 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .05939 L
.5296 .05939 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .02119 L
.54517 .02119 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .02119 L
.54517 .02119 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .05551 L
.56075 .05551 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .05551 L
.56075 .05551 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .01472 L
.57632 .01472 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .01472 L
.57632 .01472 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .05292 L
.5919 .05292 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .05292 L
.5919 .05292 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .05292 L
.60748 .05292 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .05292 L
.60748 .05292 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .05745 L
.62305 .05745 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .05745 L
.62305 .05745 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .0186 L
.63863 .0186 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .0186 L
.63863 .0186 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .05616 L
.65421 .05616 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .05616 L
.65421 .05616 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .04903 L
.66978 .04903 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .04903 L
.66978 .04903 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .04968 L
.68536 .04968 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .04968 L
.68536 .04968 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .01472 L
.70093 .01472 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .01472 L
.70093 .01472 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .05939 L
.71651 .05939 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .05939 L
.71651 .05939 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .06781 L
.73209 .06781 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .06781 L
.73209 .06781 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .06328 L
.74766 .06328 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .06328 L
.74766 .06328 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .01731 L
.76324 .01731 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .01731 L
.76324 .01731 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .03932 L
.77882 .03932 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .03932 L
.77882 .03932 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .02119 L
.79439 .02119 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .02119 L
.79439 .02119 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .04385 L
.80997 .04385 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .04385 L
.80997 .04385 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .03414 L
.82555 .03414 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .03414 L
.82555 .03414 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .0445 L
.84112 .0445 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .0445 L
.84112 .0445 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .0322 L
.8567 .0322 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .0322 L
.8567 .0322 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .04256 L
.87227 .04256 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .04256 L
.87227 .04256 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .02831 L
.88785 .02831 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .02831 L
.88785 .02831 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .03155 L
.90343 .03155 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .03155 L
.90343 .03155 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .05292 L
.919 .05292 L
.919 .01472 L
F
.91589 .01472 m
.91589 .05292 L
.919 .05292 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .03479 L
.93458 .03479 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .03479 L
.93458 .03479 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .02313 L
.95016 .02313 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .02313 L
.95016 .02313 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .0322 L
.96573 .0322 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .0322 L
.96573 .0322 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .0568 L
.98131 .0568 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .0568 L
.98131 .0568 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .05033 L
.99688 .05033 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .05033 L
.99688 .05033 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol0000;ooooo`00:Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000<ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000003?ooool002Sooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Uoooooooo0000aOl0000;ooooo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`007?ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`;oogl0
00Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl0
00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0
o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l0
0?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00
o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl000?o0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_oo
O`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0003o`000?oo
003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`?oogl000Coo`00o`3o0?l00?oo003o
0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo0005
o`000?oo003o0?l0o`3o0?l00?l00oooO`001?oo003o0?l0o`3o0?l00?l2oomo0005o`000?oo003o
0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o
0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o
003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o0?l0o`00o`?oogl0
00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0
o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool0
0?l0o`3o0?l0o`00o`?oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00oooo
O`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;o
o`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o
003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?oo003o00;o
ogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003
o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo0003o`000?oooooooooo00Wo
oooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo00000_l0o`02o`00o`Ko
oooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`001?oo003o0?l0o`3o0?l00?l3
oomo00Cooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3
oomo00;oo`0000?oooooo`00ooooO`000_ooO`04ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06
ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`02
ool00003o`3o0?l00?oo003o00Oooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_oo
O`05ooooo`;oogl01Oooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo
0_ooO`05ooooo`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl01Oooool2oomo00Gooooo
0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo0_ooO`000oooooooo`00o`3o0002o`00o`;oogl0
1Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;o
ogl000Goooooool00?l0o`3o0?l0o`00o`02oomo00Gooooo0_ooO`000oooooooo`00ool00002oooo
o`;oogl01Oooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`04oooo
o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`04ooooo`?oogl000Coo`00o`3o0?l0o`3o003o0ooo
O`04ooooo`?oogl00_oo00000ol0o`3o003ooomo0002oomo00Cooooo0oooO`04ooooo`?oogl01?oo
ool3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl01?ooool3oomo00Gooooo0_oo
O`02ool00003o`3o0?l00?oo003o00;oogl01Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?o
0000ooooooooool02Oooool001_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooool0
0002o`3o00;o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0004ool0
0?l0o`3o0?l0o`00o`?oogl01?ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0
o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl01?ooool3oomo00;oo`0000?o0?l0o`00ool0
0?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`07ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6oooo
o`;oogl01Oooool2oomo00Gooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05
ooooo`;oogl01Oooool2oomo0003oooooooo003o0?l000?o003o1_ooool2oomo00Gooooo0_ooO`05
ooooo`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl000?oooooool00?l0o`000_l00?l2
oomo00Gooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Ooo
ool2oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`05ooooo`;oogl01Oooool2oomo00Gooooo
0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ool0
0?l0o`3o0?l000;o003o1_ooool3oomo0004ool00?l0o`3o0?l0o`00o`?oogl01?ooool3oomo00;o
o`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool00003
o`3o0?l00?ooogl000;oogl01?ooool3oomo00Cooooo0oooO`05ooooo`;oogl00ooo0002o`00o`;o
ogl01Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?o0000ooooooooool02Oooool001cooooo
0_l00007ooooo`03o`000?ooooooo`0000;o0?l00_l00?l6ooooo`;oogl000Coooooool00?l0o`3o
0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool000;ooooo0oooO`04ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool00003
o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Oooooo0_ooO`02ool00004
o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;oo`0000Co0?l0o`00
ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?oooooool00?l0o`000ol00?l6
ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo0_ooO`00
0oooooooo`00o`3o0002o`00o`;oogl01Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_oo
ool2oomo00Gooooo0_ooO`05ooooo`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl0
1Oooool2oomo00Gooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl0
1?ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00;oo`0000?oooooo`00ooooO`00
0_ooO`04ooooo`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo00Cooooo0oooO`05ooooo`;o
ogl00ooo0002ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?o0000oooooooo
ool02Oooool002Gooooo00?o0000oooooooo00000_l0o`02o`00o`Kooooo0_ooO`001?ooooooo`00
o`3o0?l0o`02o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?o
ogl01?ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00;oo`002Oooool3oomo00;o
o`0000?o0?l0o`00ool00?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_oo00000ol0o`3o
003oo`00o`06ooooo`?oogl00_oo00000ol0o`3o003oo`00o`07ooooo`;oogl00_oo00001?l0o`3o
003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02ool00004o`3o0?l00?oo003o
o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003o0?l000?o003o1_ooool2
oomo00Gooooo0_ooO`05ooooo`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl000?ooooo
ool00?l0o`000ol00?l6ooooo`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Ooo
ool2oomo00Gooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl0
1Oooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl0
00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl00_oo00000ooooooo003oo`00o`06ooooo`?oogl0
0ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool00003
o`3o0?l00?ooogl000;oogl01?ooool3oomo00Cooooo0oooO`05ooooo`;oogl00ooo0002ooooo`;o
ogl01Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?o0000ooooooooool02Oooool002Gooooo
00?o0000oooooooo00000_l0o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Ko
oooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003
ool00?l0o`3o0?l000;o003o1_ooool3oomo00;oo`002Oooool3oomo00;oo`0000?o0?l0o`00ool0
0?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`07ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6oooo
o`;oogl01Oooool2oomo00Gooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05
ooooo`;oogl01Oooool2oomo0003oooooooo003o0?l000?o003o1_ooool2oomo00Gooooo0_ooO`05
ooooo`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl000?oooooool00?l0o`000ol00?l6
ooooo`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_oo
O`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool3oomo0003ool0
0?l0o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`00
0_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?o
ogl01?ooool3oomo00Cooooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo00Co
oooo0oooO`05ooooo`;oogl00ooo0009ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0004oooo
oooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00Co
oooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0009ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool00003
o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Oooooo0_ooO`02ool00004
o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;oo`0000Co0?l0o`00
ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?oooooool00?l0o`000ol00?l6
ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo0_ooO`00
0oooooooo`00o`3o0003o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_oo
O`05ooooo`;oogl01Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo
0_ooO`05ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo00Cooooo
0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool000Wooooo0oooO`03ool00004o`00
ooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?oogl01?ooool3oomo00;oo`0000?o0?l0o`00oooo
O`000_ooO`04ooooo`?oogl01?ooool3oomo00Gooooo0_ooO`03ool000Wooooo0_ooO`05ooooo`;o
ogl01Oooool2oomo0003o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l0
0_l00?l6ooooo`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0
o`000_l00?l6ooooo`?oogl01?ooool3oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Ko
oooo0oooO`02ool000Wooooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`04ooooo`?o
ogl01?ooool3oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ool0
0?l01oooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05oooo
o`;oogl00_oo00001?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`00
0oooooooo`00o`3o0003o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003o
0?l000?o003o1_ooool2oomo0003oooooooo003o0?l000?o003o1_ooool2oomo0004oooooooo003o
0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000Coooooool00?l0o`3o0?l0
0_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo
0oooO`04ooooo`?oogl01?ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00;oo`00
2Oooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl01?ooool3oomo00Cooooo0oooO`04ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Gooooo0_ooO`03ool000Wo
oooo0_ooO`05ooooo`;oogl01Oooool2oomo0003o`000?oooooooooo00Wooooo000Uooooo`?o0000
0_l0o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`000ooo003o
0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ool00?l0o`3o0?l000;o
003o1_ooool3oomo00;oo`002Oooool3oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00Co
oooo0oooO`04ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0o`3o
003oo`00o`07ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo
00Gooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2
oomo0003oooooooo003o0?l000?o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?ooooo
ool00?l0o`000ol00?l6ooooo`;oogl000?oooooool00?oo00000ol00?l6ooooo`;oogl000Cooooo
ool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`001?ooooooo`00o`3o
0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool3oomo0003ool00?l0o`3o0?l000;o003o
1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl0
0_oo0009ooooo`?oogl00ooo00001?ooooooogl0oomo0?ooO`04ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`02ool00003o`3o0?l00?oo003o00gooooo0oooO`05ooooo`;oogl00ooo0009ooooo`;o
ogl01Oooool2oomo00Gooooo0_ooO`000ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`02o`3o00;o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003
ool00?l0o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0
o`000_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?o
ogl01?ooool3oomo00Cooooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003
o`3o0?l00?oo003o00Oooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05oooo
o`;oogl01Oooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05
ooooo`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`00
0oooooooo`00o`3o0003o`00o`Kooooo0_ooO`000oooooooo`00ool00003o`00o`Kooooo0_ooO`00
1?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo0004oooooooo
003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`?oogl000?oo`00o`3o0?l0o`00
0_l00?l6ooooo`?oogl01?ooool3oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo
0oooO`02ool000Wooooo0oooO`03ool00004ooooooooO`3oogl0oomo00Cooooo0oooO`0;ooooo`?o
ogl00_oo00000ol0o`3o003oo`00o`0=ooooo`?oogl01Oooool2oomo00?oo`004?ooool2oomo00Go
oooo0_ooO`000ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o
1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o
003o1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?o
ogl00_oo0009ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Oo
oooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo
00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?ooooo
ool00?l0o`000ol00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003
o`00o`Kooooo0_ooO`000oooooooo`00ool00003o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0
o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o
1_ooool2oomo00Gooooo0_ooO`05ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl0
1?ooool3oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool000Wooooo
0oooO`03ool000Sooooo0oooO`0;ooooo`?oogl00_oo00000ol0o`3o003oo`00o`0=ooooo`?oogl0
1oooool3ool0013ooooo0_ooO`05ooooo`;oogl000?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo
0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ool0
0?l0o`3o0?l000;o003o1_ooool3oomo00;oo`002Oooool3oomo00;oo`0000?o0?l0o`00ool00?l0
1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl0
0_oo00000ol0o`3o003oo`00o`07ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6ooooo`;o
ogl01Oooool2oomo00Gooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05oooo
o`;oogl01Oooool2oomo0003oooooooo003o0?l000?o003o1_ooool2oomo00Gooooo0_ooO`05oooo
o`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl000?oooooool00?oo00000ol00?l6oooo
o`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`00
1?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool3oomo0003ool00?l0
o`3o0?l000;o003o1_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l0
0?l6ooooo`?oogl00_oo0009ooooo`?oogl00ooo0008ooooo`?oogl02oooool3oomo00;oo`0000?o
0?l0o`00ool00?l03Oooool3oomo00Oooooo0ooo000@ooooo`;oogl01Oooool2oomo0003o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl000Cooooo
ool00?l0o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?oo
ool3oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool000Wooooo0ooo
O`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo00;ooooo00?o
0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ool00?l01oooool2oomo00;oo`0000Co
0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_oo00001?l0o`3o003o
o`00ool00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Ko
oooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003o0?l000?o003o1_ooool2oomo0003
oooooooo003oo`0000?o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo
00Gooooo0_ooO`05ooooo`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2
oomo00Gooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3
oomo0003ool00?l0o`3o0?l000;o003o2Oooool2ool000Wooooo0oooO`03ool000Sooooo0oooO`0;
ooooo`?oogl00ooo0002o`00o`gooooo0oooO`07ooooo`?oo`004?ooool2oomo00Gooooo0_ooO`00
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo
0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3
oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0009
ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02
ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Oooooo0_ooO`02
ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;oo`0000Co
0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?oooooool00?l0o`00
0ol00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo
0_ooO`000oooooooo`00ool00003o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Ko
oooo0_ooO`05ooooo`;oogl01Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo
00Gooooo0_ooO`05ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo
00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Wooooo0_oo0009ooooo`?oogl00ooo0008oooo
o`?oogl03_ooool3ool000;o003o3Oooool3oomo00Oooooo0ooo000@ooooo`;oogl01Oooool2oomo
0003o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;o
ogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6oooo
o`?oogl01?ooool3oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool0
00Wooooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo
00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ool00?l01oooool2oomo
00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_oo0000
1?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Sooooo00?oo`00o`3o0?l00?l00_l0
0?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo0_oo
O`000oooooooo`00ool00003o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo
0_ooO`05ooooo`;oogl01Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Go
oooo0_ooO`05ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`000ooo003o0?l0o`3o0002o`00o`Wooooo0_oo000<ooooo`?oo`006Oooool3ool000;o
003o3Oooool3oomo00Oooooo0ooo000@ooooo`;oogl01Oooool2oomo0003o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl000Coooooool00?l0o`3o
0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo00Co
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ool000Wooooo0oooO`02ool00003
o`3o0?l00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo00;ooooo00?o0?l0o`00ool0
0?l01_ooool3oomo00;oo`0000?o0?l0o`00ool00?l01oooool2oomo00;oo`0000Co0?l0o`00ool0
0?oo003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6
ooooo`;oogl01Oooool2oomo00Sooooo00?oo`00o`3o0?l00?l00_l00?l6ooooo`;oogl01Oooool2
oomo00Gooooo0_ooO`000oooooooo`00o`3o0003o`00o`Kooooo0_ooO`000oooooooo`00ool00003
o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Ooo
ool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`?oogl0
00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl01?ooool3oomo00Cooooo0oooO`000ooo003o0?l0
o`3o0002o`00o`Wooooo0_oo000<ooooo`?oo`006Oooool3ool000;o003o3Oooool3oomo00Oooooo
0ooo000@ooooo`;oogl01Oooool2oomo0003o`000?oooooooooo00Wooooo000Uooooo`?o00000_l0
o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`02ool00003oooo
ool00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ooooool0o`3o0?l000;o003o
1_ooool3oomo00;oo`002Oooool3oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00Cooooo
0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0o`3o003o
o`00o`07ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Go
oooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl02?ooool00ooo
003o0?l0o`00o`02o`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003o0?l0
00?o003o1_ooool2oomo0003oooooooo003oo`0000?o003o1_ooool2oomo0004oooooooo003o0?l0
o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl000Coooooool00?oo003ooooo0_l0
0?l6ooooo`;oogl03?ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00Cooooo0ooo
O`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l9ooooo`;oo`003?ooool3ool001Wooooo0ooo
0002o`00o`gooooo0oooO`07ooooo`?oo`004?ooool2oomo00Gooooo0_ooO`000ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o1_ooool2oomo0004oooooooo003o
0?l0o`3o00;o003o1_ooool3oomo00;oo`0000?oooooo`00ool00?l01_ooool3oomo00Cooooo0ooo
O`04ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_oo
00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l0
0?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Oooooo0_ooO`02ool00004o`3o0?l0
0?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo00Co0?l0o`00ool00?oo
003o1_ooool2oomo00Gooooo0_ooO`08ooooo`03ool00?l0o`3o003o00;o003o3Oooool2oomo00So
oooo00?oo`00o`3o0?l00?l00_l00?l6ooooo`;oogl000?oooooool00?oo00000ol00?l6ooooo`;o
ogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`001?oo
ooooo`00ool00?ooool2o`00o`Kooooo0_ooO`0?ooooo`;oo`0000?oooooo`00ool00?l01_ooool3
oomo00Cooooo0oooO`04ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l9ooooo`;oo`003?ooool3
ool001Wooooo0ooo0002o`00o`gooooo0oooO`07ooooo`?oo`004?ooool2oomo00Oooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`Kooooo0_ooO`001?oo
ooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`02ool00003ooooool00?oo003o00Kooooo0oooO`04
ooooo`?oogl01?ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;oo`002Oooool3
oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_ooool0
0ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0o`3o003oo`00o`07ooooo`;oogl00_oo0000
1?l0o`3o003oo`00ool00?l6ooooo`;oogl03?ooool2oomo00;ooooo00Co0?l0o`00ool00?oo003o
1_ooool2oomo00Gooooo0_ooO`08ooooo`03ool00?l0o`3o003o00;o003o3Oooool2oomo00Sooooo
00?oo`00o`3o0?l00?l00_l00?l6ooooo`;oogl000?oooooool00?oo00000ol00?l6ooooo`;oogl0
00Coooooool00?l0o`3o0?l00_l00?lDooooo`;oogl000Coooooool00?oo003ooooo0_l00?l6oooo
o`;oogl03oooool2ool00003ooooool00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo
0003ool00?l0o`3o0?l000;o003o2Oooool2ool000cooooo0ooo000Iooooo`?oo`000_l00?lGoooo
o`?oo`004?ooool2oomo00Oooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00_l0o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`02ool0
0003ooooool00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo0003ooooool0o`3o0?l0
00;o003o1_ooool3oomo00;oo`002Oooool3oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo
00Cooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0
o`3o003oo`00o`09ooooo`;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00cooooo0_ooO`02
ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl02?ooool00ooo003o0?l0o`00
o`02o`00o`gooooo0_ooO`08ooooo`03ool00?l0o`3o003o00;o003o1_ooool2oomo0003oooooooo
003oo`0000?o003o2Oooool00ooo003o0?l0o`3o0002o`00oaCooooo0_ooO`001?ooooooo`00ool0
0?ooool2o`00oaOooooo0_oo00000ooooooo003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo
0oooO`02ool00003ooooool00?oo003o00Wooooo0_oo000<ooooo`?oo`006Oooool3ool000;o003o
5oooool3ool0013ooooo0_ooO`07ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o003o1_ooool3oomo00;oo`0000?o
ooooo`00ool00?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl000?oooooo`3o0?l0o`000_l0
0?l6ooooo`?oogl00_oo0009ooooo`?oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?oo
ool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l0
0?oo003o00Wooooo0_oo00001?l0o`3o003oo`00ool00?lDooooo`;oogl00_ooool01?l0o`3o003o
o`00ool00?l=ooooo`;oogl02?ooool00ooo003o0?l0o`00o`02o`00o`gooooo0_ooO`08ooooo`03
ool00?l0o`3o003o00;o003o1_ooool2oomo0003oooooooo003oo`0000?o003o2Oooool00ooo003o
0?l0o`3o0002o`00oaOooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`0000?oooooo`00ool0
0?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl00_oo00000ooooooo003oo`00o`09ooooo`;o
o`003?ooool3ool001Wooooo0ooo0002o`00oaOooooo0ooo000Iooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l6ooooo`;oogl00_ooool2o`3o00;o003o
1_ooool3oomo00;oo`0000?oooooo`00ool00?l01_ooool3oomo00Cooooo0oooO`04ooooo`?oogl0
00?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0009ooooo`?oogl00_oo00000ol0o`3o003o
o`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Wooooo
0_oo00000ol0o`3o003oo`00o`09ooooo`;oo`0000Co0?l0o`00ool00?oo003o5?ooool2oomo00;o
oooo00Co0?l0o`00ool00?oo003o3Oooool2oomo00Sooooo00?oo`00o`3o0?l00?l00_l00?l=oooo
o`;oogl02?ooool00ooo003o0?l0o`00o`02o`00o`Wooooo0_oo000<ooooo`03ool00?l0o`3o0?l0
00;o003o5oooool2ool00003ooooool00?oo003o01Oooooo0_oo00000ooooooo003oo`00o`0=oooo
o`?oogl01?ooool3oomo00;oo`0000?oooooo`00ool00?l02Oooool2ool000cooooo0ooo000Ioooo
o`?oo`000_l00?lGooooo`?oo`006Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`02ool00003
ooooool00?oo003o01Cooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ool000Wo
oooo0oooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`04ooooo`?oogl01?ooool3oomo00;o
oooo00?o0?l0o`00ool00?l02Oooool2ool00003o`3o0?l00?oo003o00Wooooo0_oo00001?l0o`3o
003oo`00ool00?lHooooo`04o`3o0?l00?oo003oo`00oaOooooo00?oo`00o`3o0?l00?l00_l00?l=
ooooo`;oogl02?ooool00ooo003o0?l0o`00o`02o`00o`Wooooo0_oo000<ooooo`;oo`0000?ooooo
o`00ool00?l05oooool2ool00003ooooool00?oo003o01Oooooo0_oo00000ooooooo003oo`00o`0=
ooooo`?oogl01?ooool3oomo00;oo`0000?oooooo`00ool00?l02Oooool2ool000cooooo0ooo000I
ooooo`?oo`000_l00?lGooooo`?oo`006Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`02o`3o00;o003o1_ooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0oooO`02ool0
0003ooooool00?oo003o01Cooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ool0
00cooooo0_oo00000ol0o`3o003oo`00o`06ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02oooo
o`03o`3o0?l00?oo003o00Wooooo0_oo00000ol0o`3o003oo`00o`09ooooo`;oo`0000Co0?l0o`00
ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?lGooooo`03ool00?l0o`3o003o00;o003o3Ooo
ool2oomo00Sooooo00?oo`00o`3o0?l00?l00_l00?l9ooooo`;oo`003?ooool2ool00003ooooool0
0?oo003o01Oooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`0000?oooooo`00ool00?l03Ooo
ool3oomo00Oooooo0_oo00000ooooooo003oo`00o`09ooooo`;oo`003?ooool3ool001Wooooo0ooo
0002o`00oaOooooo0ooo000Iooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo00000ooooooo003oo`00o`0H
ooooo`;o0?l00_l00?l6ooooo`?oogl00_oo000<ooooo`;oo`0000?o0?l0o`00ool00?l01_ooool3
oomo00Cooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`09ooooo`;oo`0000?o0?l0
o`00ool00?l02Oooool2ool00004o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o
5oooool00ooo003o0?l0o`00o`02o`00o`gooooo0_ooO`09ooooo`04o`3o0?l00?oo003oo`00o`Wo
oooo0_oo000<ooooo`;oo`0000?oooooo`00ool00?l05oooool2ool00003ooooool00?oo003o01Oo
oooo0_oo00000ooooooo003oo`00o`0=ooooo`?oogl01oooool2ool00003ooooool00?oo003o00Wo
oooo0_oo000<ooooo`?oo`006Oooool3ool000;o003o5oooool3ool001Wooooo00?o0000oooooooo
ool02Oooool002Gooooo0ol00002o`3o00;o003o2_ooool2o`3o00;o003o1_ooool3oomo00;oo`00
00?oooooo`00ool00?l06?ooool2o`3o00;o003o1_ooool3oomo00;oo`003?ooool2ool00003o`3o
0?l00?oo003o00gooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`09ooooo`;oo`00
00?o0?l0o`00ool00?l02Oooool2ool00004o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00ool0
0?oo003o5oooool00ooo003o0?l0o`00o`02o`00o`gooooo0_ooO`09ooooo`04o`3o0?l00?oo003o
o`00o`Wooooo0_oo000<ooooo`;oo`0000?oooooo`00ool00?l05oooool2ool00003ooooool00?oo
003o01Oooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`0000?oooooo`00ool00?l02Oooool2
ool000cooooo0ooo000Iooooo`?oo`000_l00?lGooooo`?oo`006?ooool2o`0000_ooooo000Uoooo
o`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`0000?oooooo`00
ool00?l06?ooool2o`3o00;o003o1_ooool3oomo00;oo`003?ooool2ool00003o`3o0?l00?oo003o
00gooooo0oooO`09ooooo`03o`3o0?l00?oo003o00Wooooo0_oo00000ol0o`3o003oo`00o`09oooo
o`;oo`0000Co0?l0o`00ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?lGooooo`03ool00?l0
o`3o003o00;o003o6?ooool01?l0o`3o003oo`00ool00?l9ooooo`;oo`003?ooool2ool00003oooo
ool00?oo003o01Oooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`0000?oooooo`00ool00?l0
5oooool2ool00003ooooool00?oo003o00Wooooo0_oo000<ooooo`?oo`006Oooool3ool000;o003o
5oooool3ool001Wooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0
o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo00000ooooooo003oo`00o`0Hooooo`;o0?l00_l0
0?l6ooooo`?oogl00_oo000<ooooo`;oo`0000?o0?l0o`00ool00?l03Oooool3oomo00Wooooo00?o
0?l0o`00ool00?l02Oooool2ool00003o`3o0?l00?oo003o00Wooooo0_oo00001?l0o`3o003oo`00
ool00?lHooooo`04o`3o0?l00?oo003oo`00oaOooooo00?oo`00o`3o0?l00?l00_l00?lHooooo`04
o`3o0?l00?oo003oo`00o`Wooooo0_oo000<ooooo`;oo`0000?oooooo`00ool00?l05oooool2ool0
0003ooooool00?oo003o01Oooooo0_oo000Jooooo`;oo`0000?oooooo`00ool00?l02Oooool2ool0
00cooooo0ooo000Iooooo`?oo`000_l00?lGooooo`?oo`006Oooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o003o2Oooool2ool00003
ooooool00?oo003o01Sooooo0_l0o`02o`00o`Kooooo0oooO`02ool000cooooo0_oo00000ol0o`3o
003oo`00o`0=ooooo`?oogl02Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l9ooooo`;o
o`0000Co0?l0o`00ool00?oo003o6?ooool01?l0o`3o003oo`00ool00?lGooooo`03ool00?l0o`3o
003o00;o003o6?ooool01?l0o`3o003oo`00ool00?l9ooooo`;oo`003?ooool2ool00003ooooool0
0?oo003o01Oooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`006_ooool2ool00003ooooool0
0?oo003o00Wooooo0_oo000<ooooo`?oo`006Oooool3ool000;o003o5oooool3ool001Wooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02
o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l6ooooo`?oogl00_oo000<ooooo`;oo`0000?o0?l0
o`00ool00?l06Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l00?oo
003oo`00oaSooooo00Co0?l0o`00ool00?oo003o5oooool00ooo003o0?l0o`00o`02o`00oaSooooo
00Co0?l0o`00ool00?oo003o2Oooool2ool000cooooo0_oo00000ooooooo003oo`00o`0Gooooo`;o
o`0000?oooooo`00ool00?l05oooool2ool001[ooooo0_oo00000ooooooo003oo`00o`09ooooo`;o
o`003?ooool3ool001Wooooo0ooo0002o`00oaOooooo0ooo000Iooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`00
6oooool2o`3o00;o003o1_ooool3oomo00;oo`003?ooool2ool00003o`3o0?l00?oo003o01Wooooo
00?o0?l0o`00ool00?l02Oooool3ool000;o003o2oooool01?l0o`3o003oo`00ool00?lHooooo`04
o`3o0?l00?oo003oo`00oaOooooo0_oo0003o`00oaSooooo00Co0?l0o`00ool00?oo003o2Oooool2
ool000cooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`0000?oooooo`00ool00?l05oooool2
ool001gooooo0_l00?l9ooooo`;oo`003?ooool3ool001Wooooo0ooo0002o`00oaOooooo0ooo000I
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l:oooo
o`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o1_ooool3oomo00;oo`003?ooool3ool0
00;o003o6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l00?oo003o
o`00oaSooooo00Co0?l0o`00ool00?oo003o5oooool2ool000?o003o6?ooool01?l0o`3o003oo`00
ool00?l9ooooo`;oo`003?ooool2ool00003ooooool00?oo003o01Oooooo0_oo00000ooooooo003o
o`00o`0Gooooo`;oo`007Oooool2o`00o`Wooooo0_oo000<ooooo`?oo`006Oooool3ool001Wooooo
0ooo000Iooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l0
0?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o1_ooool3oomo00;oo`003?oo
ool3ool000;o003o6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l0
0?oo003oo`00oaSooooo00Co0?l0o`00ool00?oo003o6Oooool3o`00oaSooooo00Co0?l0o`00ool0
0?oo003o2Oooool2ool000cooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`006_ooool2ool0
01gooooo0_l00?l9ooooo`;oo`003?ooool3ool001Wooooo0ooo000Iooooo`?oo`006Oooool00ol0
003oooooooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;o
o`006oooool2o`3o00;o003o1_ooool3oomo00;oo`003?ooool3ool000;o003o6Oooool00ol0o`3o
003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l00?oo003oo`00oaSooooo00Co0?l0o`00
ool00?oo003o6Oooool3o`00oaSooooo00Co0?l0o`00ool00?oo003o2Oooool2ool000cooooo0_oo
00000ooooooo003oo`00o`0Gooooo`;oo`006_ooool2ool001gooooo0_l00?l9ooooo`;oo`003?oo
ool3ool001Wooooo0ooo000Iooooo`?oo`006?ooool2o`0000_ooooo000Uooooo`03o`000?oooooo
oooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2
ool000cooooo0ooo0002o`00oaWooooo00?o0?l0o`00ool00?l02Oooool3ool000;o003o2oooool0
1?l0o`3o003oo`00ool00?lHooooo`04o`3o0?l00?oo003oo`00oaWooooo0ol00?lHooooo`04o`3o
0?l00?oo003oo`00o`Wooooo0_oo000<ooooo`;oo`0000?oooooo`00ool00?l05oooool2ool001[o
oooo0_oo000Mooooo`;o003o2Oooool2ool000cooooo0ooo000Iooooo`?oo`006Oooool3ool001Wo
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo
0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003?ooool3ool000;o003o
6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l00?oo003oo`00oaSo
oooo00Co0?l0o`00ool00?oo003o6Oooool3o`00oaWooooo0ol00?l9ooooo`;oo`003?ooool2ool0
0003ooooool00?oo003o01Oooooo0_oo000Jooooo`;oo`007Oooool2o`00o`Wooooo0_oo000<oooo
o`?oo`006Oooool3ool001Wooooo0ooo000Iooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o
003o2Oooool2ool000cooooo0ooo0002o`00oaWooooo00?o0?l0o`00ool00?l02Oooool3ool000;o
003o2oooool01?l0o`3o003oo`00ool00?lHooooo`04o`3o0?l00?oo003oo`00oaWooooo0ol00?lI
ooooo`?o003o2Oooool2ool000cooooo0_oo00000ooooooo003oo`00o`0Gooooo`;oo`006_ooool2
ool001gooooo0_l00?l9ooooo`;oo`003?ooool3ool001Wooooo0ooo000Iooooo`?oo`006Oooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o
00;o003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wooooo0_oo000<ooooo`?oo`000_l00?lIoooo
o`03o`3o0?l00?oo003o00Wooooo0ooo0002o`00o`_ooooo00Co0?l0o`00ool00?oo003o6?ooool0
1?l0o`3o003oo`00ool00?lIooooo`?o003o6Oooool3o`00o`Wooooo0_oo000<ooooo`;oo`006_oo
ool2ool001[ooooo0_oo000Mooooo`;o003o2Oooool2ool000cooooo0ooo000Iooooo`?oo`006Ooo
ool3ool001Wooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02
o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003?ooool3
ool000;o003o6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l;ooooo`04o`3o0?l00?oo
003oo`00oaSooooo00Co0?l0o`00ool00?oo003o6Oooool3o`00oaWooooo0ol00?l9ooooo`;oo`00
3?ooool2ool001[ooooo0_oo000Jooooo`;oo`007Oooool2o`00o`Wooooo0_oo000<ooooo`?oo`00
6Oooool3ool001Wooooo0ooo000Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Oooooo00?o0000ooooooooool00_l0
o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003?oo
ool3ool000;o003o6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`000_l00?l<ooooo`?o003o6?oo
ool01?l0o`3o003oo`00ool00?lIooooo`?o003o6Oooool3o`00o`Wooooo0_oo000<ooooo`;oo`00
6_ooool2ool001[ooooo0_oo000Mooooo`;o003o2Oooool2ool000cooooo0ooo000eooooo`?oo`00
6Oooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool0
00cooooo0ooo0002o`00oaWooooo00?o0?l0o`00ool00?l03?ooool2o`00o`cooooo0ol00?lHoooo
o`04o`3o0?l00?oo003oo`00oaWooooo0ol00?lIooooo`?o003o2Oooool2ool000cooooo0_oo000J
ooooo`;oo`006_ooool2ool001gooooo0_l00?l9ooooo`;oo`003?ooool3ool003Gooooo0ooo000I
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`?o00000_l0o`02o`00o`[ooooo0_l0
o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003oooool2o`00oaWooooo00?o
0?l0o`00ool00?l03?ooool2o`00o`cooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00ocGooooo
0ol00?l9ooooo`;oo`003?ooool2ool001[ooooo0_oo000Jooooo`;oo`007Oooool2o`00o`Wooooo
0_oo000<ooooo`?oo`00=Oooool3ool001Oooooo0ol0000;ooooo`002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02o`3o00;o003o2_ooool2o`3o00;o003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wo
oooo0_oo000?ooooo`;o003o6Oooool00ol0o`3o003oo`00o`0<ooooo`;o003o3?ooool3o`00oaSo
oooo00Co0?l0o`00ool00?oo003o=Oooool3o`00o`Wooooo0_oo000<ooooo`;oo`006_ooool2ool0
01[ooooo0_oo000Mooooo`;o003o2Oooool2ool000cooooo0ooo000eooooo`?oo`006Oooool00ol0
003oooooooooo`09ooooo`002Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
o`000?ooool01?l00007ooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9
ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool000oooooo0_l00?lIooooo`03o`3o0?l00?oo
003o00cooooo0_l00?l<ooooo`?o003o6?ooool01?l0o`3o003oo`00ool00?leooooo`?o003o2Ooo
ool2ool000cooooo0_oo000Jooooo`;oo`006_ooool2ool002Sooooo0_oo000<ooooo`?oo`00=Ooo
ool3ool001Wooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000[ooooo00?o0000ooooooooool00_l0o`02o`00o`[o
oooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003oooool2o`00oaWo
oooo00?o0?l0o`00ool00?l03?ooool2o`00o`cooooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00
ocGooooo0ol00?l9ooooo`;oo`003?ooool2ool001[ooooo0_oo000Jooooo`;oo`00:?ooool2ool0
00cooooo0ooo000eooooo`?oo`006Oooool00ol0003oooooooooo`09ooooo`002_ooool2o`0000[o
oooo0_l00002ooooo`Go00001_ooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o
003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wooooo0_oo000?ooooo`;o003o6Oooool00ol0o`3o
003oo`00o`0<ooooo`;o003o3?ooool3o`00oaSooooo00Co0?l0o`00ool00?oo003o=Oooool3o`00
o`Wooooo0_oo000<ooooo`;oo`006_ooool2ool001[ooooo0_oo000Xooooo`;oo`003?ooool3ool0
03Gooooo0ooo000Iooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool000oo
oooo0_l00?lIooooo`03o`3o0?l00?oo003o00cooooo0_l00?l<ooooo`?o003o6?ooool01?l0o`3o
003oo`00ool00?leooooo`?o003o2Oooool2ool000cooooo0_oo000Jooooo`;oo`006_ooool2ool0
02Sooooo0_oo000<ooooo`?oo`00=Oooool3ool001Wooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o
0?l00_l00?l9ooooo`;oo`003oooool2o`00oaWooooo00?o0?l0o`00ool00?l03?ooool2o`00o`co
oooo0ol00?lHooooo`04o`3o0?l00?oo003oo`00ocGooooo0ol00?l9ooooo`;oo`003?ooool2ool0
01[ooooo0_oo000Jooooo`;oo`00:?ooool2ool000cooooo0ooo000eooooo`?oo`006Oooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o
003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wooooo0_oo000?ooooo`;o003o6Oooool00ol0o`3o
003oo`00o`0<ooooo`;o003o9oooool01?l0o`3o003oo`00ool00?leooooo`?o003o2Oooool2ool0
00cooooo0_oo000Jooooo`;oo`006_ooool2ool002Sooooo0_oo000<ooooo`?oo`00=Oooool3ool0
01Wooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`[o
oooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`003oooool2o`00oaWo
oooo00?o0?l0o`00ool00?l03?ooool2o`00obOooooo00Co0?l0o`00ool00?oo003o=Oooool3o`00
o`Wooooo0_oo000Xooooo`;oo`006_ooool2ool002Sooooo0_oo000<ooooo`?oo`00=Oooool3ool0
01Wooooo00?o0000ooooooooool02Oooool002Gooooo0ol00002o`3o00;o003o2_ooool2o`3o00;o
003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wooooo0_oo000?ooooo`;o003o6Oooool00ol0o`3o
003oo`00o`0eooooo`04o`3o0?l00?oo003oo`00ocGooooo0ol00?l9ooooo`;oo`00A?ooool2ool0
02Sooooo0_oo0014ooooo`?oo`006?ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool000oo
oooo0_l00?lIooooo`03o`3o0?l00?oo003o03Gooooo00Co0?l0o`00ool00?oo003o=Oooool3o`00
o`Wooooo0_oo0014ooooo`;oo`00:?ooool2ool004Cooooo0ooo000Iooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;o
o`006oooool2o`3o00;o003o2Oooool2ool002[ooooo00?o0?l0o`00ool00?l0=Oooool01?l0o`3o
003oo`00ool00?leooooo`?o003o2Oooool2ool004Cooooo0_oo000Xooooo`;oo`00A?ooool3ool0
01Wooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`[o
oooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`00:_ooool00ol0o`3o
003oo`00o`0eooooo`04o`3o0?l00?oo003oo`00od7ooooo0_oo0014ooooo`;oo`00:?ooool2ool0
04Cooooo0ooo000Iooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool002[o
oooo00?o0?l0o`00ool00?l0=Oooool01?l0o`3o003oo`00ool00?m1ooooo`;oo`00A?ooool2ool0
02Sooooo0_oo0014ooooo`?oo`006Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`02o`3o00;o003o2_ooool2o`3o00;o003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wo
oooo0_oo000Zooooo`03o`3o0?l00?oo003o03Gooooo00Co0?l0o`00ool00?oo003o@Oooool2ool0
04Cooooo0_oo000Xooooo`;oo`00A?ooool3ool001Wooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o
0?l00_l00?l9ooooo`;oo`00:_ooool00ol0o`3o003oo`00o`0eooooo`04o`3o0?l00?oo003oo`00
od7ooooo0_oo0014ooooo`;oo`00:?ooool2ool0063ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o
0?l00_l00?l9ooooo`;oo`00:_ooool00ol0o`3o003oo`00o`0eooooo`04o`3o0?l00?oo003oo`00
od7ooooo0_oo0014ooooo`;oo`00:?ooool2ool0063ooooo00?o0000ooooooooool02Oooool002Go
oooo0ol00002o`3o00;o003o2_ooool2o`3o00;o003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wo
oooo0_oo000Zooooo`03o`3o0?l00?oo003o03Gooooo00Co0?l0o`00ool00?oo003o@Oooool2ool0
04Cooooo0_oo000Xooooo`;oo`00Goooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o
0?l00_l00?l:ooooo`;o0?l00_l00?l9ooooo`;oo`006oooool2o`3o00;o003o2Oooool2ool002[o
oooo00?o0?l0o`00ool00?l0=Oooool01?l0o`3o003oo`00ool00?n7ooooo`;oo`00:?ooool2ool0
063ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`[o
oooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`;o0?l00_l00?l9ooooo`;oo`00:_ooool00ol0o`3o
003oo`00o`0eooooo`04o`3o0?l00?oo003oo`00ohOooooo0_oo000Xooooo`;oo`00H?ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o2_ooool2o`3o00;o
003o2Oooool2ool001_ooooo0_l0o`02o`00o`Wooooo0_oo000Zooooo`03o`3o0?l00?oo003o03Go
oooo00Co0?l0o`00ool00?oo003oQoooool2ool008[ooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00o`[ooooo0_l0o`02o`00o`Wooooo0_oo000Kooooo`?o
0?l02_ooool2ool002[ooooo00?o0?l0o`00ool00?l0=Oooool01?l0o`3o003oo`00ool00?n7oooo
o`;oo`00R_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003o2_ooool3o`3o00[ooooo0_oo000Kooooo`?o0?l02_ooool2ool002[ooooo00?o0?l0o`00ool0
0?l0=Oooool01?l0o`3o003oo`00ool00?n7ooooo`;oo`00R_ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`02o`3o00;o003o2_ooool3o`3o00[ooooo0_oo000Kooooo`?o
0?l02_ooool2ool002[ooooo00?o0?l0o`00ool00?l0=Oooool01?l0o`3o003oo`00ool00?n7oooo
o`;oo`00R_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o
003o2_ooool3o`3o00[ooooo0_oo000Kooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0fooooo`04
o`3o0?l00?oo003oo`00ohOooooo0_oo002:ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o
00000_l0o`02o`00ocCooooo0ol0o`0:ooooo`;oo`00:_ooool2o`3o03Kooooo0_l0o`29ooooo`;o
o`00ROooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`?o0?l0
2_ooool2ool002[ooooo0_l0o`0fooooo`;o0?l0ROooool2ool008[ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`0:ooooo`;oo`00:_oo
ool2o`3o03Kooooo0_l0o`29ooooo`;oo`00R_ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`02o`3o00;o003o=?ooool3o`3o00[ooooo0_oo000Zooooo`;o0?l0=_ooool2
o`3o08Wooooo0_oo002:ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?ldooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0fooooo`;o0?l0ROooool2ool0
08[ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCo
oooo0ol0o`0:ooooo`;oo`00:_ooool2o`3o03Kooooo0_l0o`29ooooo`;oo`00R_ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o=?ooool3o`3o00[ooooo
0_oo000Zooooo`;o0?l0=_ooool2o`3o08Wooooo0_oo002:ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?ldooooo`?o0?l02_ooool2ool002[ooooo0_l0
o`31ooooo`;oo`00R_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02
o`3o00;o003o=?ooool3o`3o03Kooooo0_l0o`31ooooo`;oo`00R_ooool00ol0003oooooooooo`09
ooooo`009Oooool3o`0000;o0?l00_l00?ldooooo`?o0?l0=_ooool2o`3o0<7ooooo0_oo0029oooo
o`;o00002oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`0fooooo`;o
0?l0`Oooool2ool008[ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0_l0o`02o`00ocCooooo0ol0o`0fooooo`;o0?l0`Oooool2ool008[ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00ocCooooo0ol0o`0fooooo`;o0?l0oooo
oom>ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?m]
ooooo`;o0?l0oooooom>ooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmoooo
o`03o`000?oooooooooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo
00Wooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000?ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000;o0?l00_l00?oooooo
ok_ooooo0ol0000;ooooo`003oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09oooo
o`003oooool01?l0003oooooooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`02o`3o
00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00002_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0
003oooooooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?oooooookcooooo0_l0000;ooooo`00
9Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000
ooooooooool02Oooool002Gooooo0ol00002o`3o00;o003ooooooonlooooo`;o00002oooool002Go
oooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00oooooooo_Oooool00ol0003ooooo
ooooo`09ooooo`009Oooool3o`0000;o0?l00_l00?oooooookcooooo0_l0000;ooooo`009Oooool0
0ol0003oooooooooo`02o`3o00;o003ooooooonmooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00;o0?l00_l00?oooooookgooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oo
oooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Oooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool000Wooooo00Co
0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool3o`0000?o0?l0oooooonlooooo`?o00002oooool000Wooooo00Co0000oooooooooooo
00002Oooool01?l0003oooooooooooooool4o`0000Oooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooo00002?ooool2o`00
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`002_ooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00006oooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3ooooo
okgooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool3o`0000?o0?l0oooooonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3ooooookgooooo0_l0000;oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`004?ooool2o`0000Co
oooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000?ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`003oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo0ol00003
o`3o0?oooooo_?ooool3o`0000_ooooo000?ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`003oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`003oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`004?ooool2o`0000Wooooo0ol0
0007ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o0000
0ol0o`3ooooookgooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool3o`0000?o0?l0oooooonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo000Uoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3ooooookgooooo
0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`002_oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001oooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`?o00000ol0o`3ooooookcooooo0ol0000;ooooo`002Oooool01?l0003oooooooooool00007oooo
o`06o`000?ooooooooooooooool0003ooooo1?l00007ooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Oooooo00Oo
0000ooooooooooooooooo`000?oooooo000000[ooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool000[ooooo0_l00009ooooo`?o00000_ooool5o`0000Kooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oooooo
_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`?o00000ol0o`3ooooookgooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo
__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool3o`0000?o0?l0oooooonmooooo`;o00002oooool002Gooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo
000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`09ooooo`003oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`003oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo
0ol00003o`3o0?oooooo_?ooool3o`0000_ooooo000?ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00007ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000?ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`09ooooo`004?ooool2o`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3ooooookgooooo
0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool3o`00
0?oooooo`?ooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo
000Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`009Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool002Goooooool0
0035o`0000_ooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo000Xooooo`?o00000oooool5o`0000?o
oooo0ol00005ooooo`?o00000oooool3o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo00?o
oooo0ol00004ooooo`;o00000_ooool3o`0000Cooooo0ol00003ooooo`Co00000_ooool5o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000?o
oooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`0000;o
oooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool4o`0000Co
oooo0ol00003ooooo`Co00000_ooool5o`0000?ooooo1?l00004ooooo`?o00000oooool5o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000?ooooo1Ol00003ooooo`Co00000_ooool5o`000003
ooooool0003o000000Co00000_ooool5o`0000?ooooo1?l00002ooooo`Go00000_ooool5o`0000?o
oooo1?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00003ooooo`Co00000_ooool5o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000oooool4o`0000?o
oooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000_o
oooo000Yooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001Oooool01?l0003oooooooooool00004ooooo`04o`000?oooooo0000o`00
00Cooooo0_l00004ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool00_l00005
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
0004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Cooooo0_l000001?oooooo0000oooo
ooooool2o`000003ooooool0003o000000?ooooo00Co0000oooooooooooo00000_ooool2o`000008
ooooool0003o0000ooooool0003oooooo`000?ooool2o`0000?ooooo0_l000001ooooooo0000oooo
ool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool02Ol0
003oooooooooool0003oooooo`000?oooooo0000ooooo`02o`0000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooooooo
oooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`0>o`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool2o`0000;ooooo0_l00002
ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o00001?ooool2o`0000?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000005ooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool01?l0003oooooo`00
0?l00002ooooo`;o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000oooooooo
ool00_l00002ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go00001_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool01?l0003oooooo`000?l0
0004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o
0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Gooooo
0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000;o
oooo1Ol00005ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool00_l00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0
003o000000Co00001Oooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00004ooooo`05o`00
0?oooooo0000ooooool000000oooool2o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;o
oooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`000?l0
00001?l00002ooooo`Go000000?oooooo`000?l000001?l00005ooooo`;o00000_ooool00ol0003o
ooooooooo`02o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005
ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o000000?oooooo`000?ooool00_ooool2
o`0000Cooooo00Go0000ooooool0003oooooo`000003ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o000000?o0000
2oooool002Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Co00001_ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool4o`000003ooooool0003ooooo00?ooooo00Co0000ooooool0003o
00001?ooool2o`0000Kooooo00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooo
oooo00001_ooool2o`0000;ooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Gooooo0_l00004
ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool01Ol00005
ooooo`;o00000oooool4o`0000?ooooo1?l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol0
0005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l00006ooooo`;o00000_oo
ool5o`0000Gooooo0_l00003ooooo`Co00000oooool4o`0000?ooooo00Co0000oooooooooooo0000
0oooool2o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003o00000oooool4o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`0000;ooooo1Ol00003oooo
o`04o`000?oooooo0000o`0000?ooooo1?l00003ooooo`Go00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000003ooooo`;o000000Co
ooooo`000?oooooo00000_ooool00ol0003oooooo`000005ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000;ooooo0ol000001?oooooo0000
ooooooooool4o`0000?ooooo1?l00003ooooo`Co00000oooool4o`0000?ooooo1?l00002ooooo`04
o`000?ooooooooooo`0000cooooo000Yooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`Co00000ooo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooo`000004ooooo`04o`000?oooooo0000o`0000Cooooo0_l00003oooo
o`03o`000?oooooooooo00;o00001Oooool2o`0000?ooooo00?o0000ooooool000000oooool4o`00
00?ooooo00Co0000oooooooooooo00001_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1?l0003oooooo`000?l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00Ko
0000ooooool0003oooooo`000?ooool4o`000003ooooool0003ooooo00;o00000oooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool01_l0003oooooooooool0003o
ooooo`0000?ooooo0_l00005ooooo`;o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Co
00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo
0000ooooo`02ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`;o000000?ooooo
o`000?ooool00oooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000001?oo
ool00ol0003oooooo`000003ooooo`Co00000_ooool5o`0000;ooooo00Go0000ooooool0003ooooo
o`000004ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`Go
00000oooool4o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000?ooooo1?l00002ooooo`Go
00000_ooool5o`0000?ooooo1?l00002ooooo`Go00000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00000<ooooo`00
:?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooooooo0ol00004ooooo`Co00000oooool3o`0000?ooooo00?o0000ooooool00000
0_l00002ooooo`03o`000?oooooo000000;o00001?ooool2o`0000?ooooo00Co0000ooooool0003o
00001?ooool3o`0000?ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;o
00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;o
oooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`?o000000?oooooo`000?ooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
ooooool0003o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oo
oooo0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000006oooo
ool0003oooooo`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?oooooooooo
0_l00003ooooo`04o`000?oooooo0000o`0000?ooooo1?l00002ooooo`03o`000?oooooooooo00;o
00000_ooool00ol0003oooooooooo`02o`0000Cooooo0ol00002ooooo`03o`000?oooooooooo00;o
00000oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooooooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool01?l0003oooooooooooooool3o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool02?l0003oooooooooool0003oooooo`00
0?oooooo00000oooool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo
0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000Cooooo0_l0000<ooooo`00:Ooo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo
1Ol00004ooooo`;o00000oooool5o`0000?ooooo0ol00004ooooo`?o00000_ooool00ol0003ooooo
ooooo`03ooooo`;o00001Oooool2o`0000Cooooo0ol00004ooooo`?o00001_ooool01?l0003ooooo
ooooooooool5o`0000Cooooo0_l00003ooooo`Go00000oooool3o`0000Cooooo1?l00004ooooo`?o
00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000;ooooo1Ol00004ooooo`?o
00000_ooool5o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co
00000oooool4o`0000Cooooo0ol00002ooooo`Ko00001?ooool3o`0000;ooooo1Ol00003ooooo`Co
00000oooool4o`0000Cooooo0ol00004ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`Co
00001Oooool2o`0000;ooooo1Ol00004ooooo`?o00000_ooool5o`0000?ooooo1?l00003ooooo`Go
00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooooooo
0000o`000004o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00002ooooo`Co
00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`0000Gooooo00?o0000oooooooo
ool02_ooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-4.70015, -0.0255715, 0.142355, \
0.00120195}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 2.87146 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15829 -24 -4.5 ]
[-0.0125 .15829 0 4.5 ]
[-0.0125 .30186 -18 -4.5 ]
[-0.0125 .30186 0 4.5 ]
[-0.0125 .44543 -24 -4.5 ]
[-0.0125 .44543 0 4.5 ]
[-0.0125 .58901 -18 -4.5 ]
[-0.0125 .58901 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15829 m
.00625 .15829 L
s
[(0.05)] -0.0125 .15829 1 0 Mshowa
0 .30186 m
.00625 .30186 L
s
[(0.1)] -0.0125 .30186 1 0 Mshowa
0 .44543 m
.00625 .44543 L
s
[(0.15)] -0.0125 .44543 1 0 Mshowa
0 .58901 m
.00625 .58901 L
s
[(0.2)] -0.0125 .58901 1 0 Mshowa
.125 Mabswid
0 .04343 m
.00375 .04343 L
s
0 .07214 m
.00375 .07214 L
s
0 .10086 m
.00375 .10086 L
s
0 .12957 m
.00375 .12957 L
s
0 .187 m
.00375 .187 L
s
0 .21572 m
.00375 .21572 L
s
0 .24443 m
.00375 .24443 L
s
0 .27315 m
.00375 .27315 L
s
0 .33058 m
.00375 .33058 L
s
0 .35929 m
.00375 .35929 L
s
0 .388 m
.00375 .388 L
s
0 .41672 m
.00375 .41672 L
s
0 .47415 m
.00375 .47415 L
s
0 .50286 m
.00375 .50286 L
s
0 .53158 m
.00375 .53158 L
s
0 .56029 m
.00375 .56029 L
s
0 .61772 m
.00375 .61772 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15829 m
1 .15829 L
s
.99375 .30186 m
1 .30186 L
s
.99375 .44543 m
1 .44543 L
s
.99375 .58901 m
1 .58901 L
s
.125 Mabswid
.99625 .04343 m
1 .04343 L
s
.99625 .07214 m
1 .07214 L
s
.99625 .10086 m
1 .10086 L
s
.99625 .12957 m
1 .12957 L
s
.99625 .187 m
1 .187 L
s
.99625 .21572 m
1 .21572 L
s
.99625 .24443 m
1 .24443 L
s
.99625 .27315 m
1 .27315 L
s
.99625 .33058 m
1 .33058 L
s
.99625 .35929 m
1 .35929 L
s
.99625 .388 m
1 .388 L
s
.99625 .41672 m
1 .41672 L
s
.99625 .47415 m
1 .47415 L
s
.99625 .50286 m
1 .50286 L
s
.99625 .53158 m
1 .53158 L
s
.99625 .56029 m
1 .56029 L
s
.99625 .61772 m
1 .61772 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .02076 L
.00623 .02076 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .02076 L
.00623 .02076 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .05402 L
.02181 .05402 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .05402 L
.02181 .05402 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .09031 L
.03738 .09031 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .09031 L
.03738 .09031 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .01774 L
.05296 .01774 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .01774 L
.05296 .01774 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .1538 L
.06854 .1538 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .1538 L
.06854 .1538 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .01774 L
.08411 .01774 L
.08411 .01472 L
F
.081 .01472 m
.081 .01774 L
.08411 .01774 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .17094 L
.09969 .17094 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .17094 L
.09969 .17094 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .13969 L
.11526 .13969 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .13969 L
.11526 .13969 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .05705 L
.13084 .05705 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .05705 L
.13084 .05705 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .09333 L
.14642 .09333 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .09333 L
.14642 .09333 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .19311 L
.16199 .19311 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .19311 L
.16199 .19311 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .02076 L
.17757 .02076 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .02076 L
.17757 .02076 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .15783 L
.19315 .15783 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .15783 L
.19315 .15783 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .01472 L
.20872 .01472 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .01472 L
.20872 .01472 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .06813 L
.2243 .06813 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .06813 L
.2243 .06813 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .01875 L
.23988 .01875 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .01875 L
.23988 .01875 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .07922 L
.25545 .07922 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .07922 L
.25545 .07922 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .01572 L
.27103 .01572 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .01572 L
.27103 .01572 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .18807 L
.2866 .18807 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .18807 L
.2866 .18807 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .01975 L
.30218 .01975 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .01975 L
.30218 .01975 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .24653 L
.31776 .24653 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .24653 L
.31776 .24653 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .01673 L
.33333 .01673 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .01673 L
.33333 .01673 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .23141 L
.34891 .23141 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .23141 L
.34891 .23141 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .01673 L
.36449 .01673 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .01673 L
.36449 .01673 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .17799 L
.38006 .17799 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .17799 L
.38006 .17799 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .01472 L
.39564 .01472 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .01472 L
.39564 .01472 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .03689 L
.41121 .03689 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .03689 L
.41121 .03689 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .01472 L
.42679 .01472 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .01673 L
.44237 .01673 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .01673 L
.44237 .01673 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .01472 L
.45794 .01472 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .01472 L
.47352 .01472 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .01472 L
.47352 .01472 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .01572 L
.4891 .01572 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .01572 L
.4891 .01572 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .04193 L
.50467 .04193 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .04193 L
.50467 .04193 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .01875 L
.52025 .01875 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .01875 L
.52025 .01875 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .11349 L
.53583 .11349 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .11349 L
.53583 .11349 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .01472 L
.5514 .01472 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .01472 L
.5514 .01472 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .13465 L
.56698 .13465 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .13465 L
.56698 .13465 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .01572 L
.58255 .01572 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .01572 L
.58255 .01572 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .03487 L
.59813 .03487 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .03487 L
.59813 .03487 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .01774 L
.61371 .01774 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .01774 L
.61371 .01774 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .05402 L
.62928 .05402 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .05402 L
.62928 .05402 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .01572 L
.64486 .01572 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .01572 L
.64486 .01572 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .03487 L
.66044 .03487 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .03487 L
.66044 .03487 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .01472 L
.67601 .01472 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .1528 L
.69159 .1528 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .1528 L
.69159 .1528 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .01472 L
.70717 .01472 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .01875 L
.72274 .01875 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .01875 L
.72274 .01875 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .01472 L
.73832 .01472 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .18102 L
.75389 .18102 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .18102 L
.75389 .18102 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .01472 L
.76947 .01472 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .11752 L
.78505 .11752 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .11752 L
.78505 .11752 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .01472 L
.80062 .01472 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .01472 L
.80062 .01472 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .11651 L
.8162 .11651 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .11651 L
.8162 .11651 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .01472 L
.83178 .01472 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .08829 L
.84735 .08829 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .08829 L
.84735 .08829 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .01572 L
.86293 .01572 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .01572 L
.86293 .01572 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .0258 L
.8785 .0258 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .0258 L
.8785 .0258 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .01472 L
.89408 .01472 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .01472 L
.90966 .01472 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .01472 L
.90966 .01472 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .01472 L
.92523 .01472 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .01472 L
.97196 .01472 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .01472 L
.97196 .01472 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .01472 L
.98754 .01472 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .06914 L
.02492 .06914 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .06914 L
.02492 .06914 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .30801 L
.0405 .30801 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .30801 L
.0405 .30801 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .01572 L
.05607 .01572 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .01572 L
.05607 .01572 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .14977 L
.07165 .14977 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .14977 L
.07165 .14977 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .01774 L
.08723 .01774 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .01774 L
.08723 .01774 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .07519 L
.1028 .07519 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .07519 L
.1028 .07519 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .04596 L
.11838 .04596 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .04596 L
.11838 .04596 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .36848 L
.13396 .36848 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .36848 L
.13396 .36848 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .06713 L
.14953 .06713 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .06713 L
.14953 .06713 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .04999 L
.16511 .04999 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .04999 L
.16511 .04999 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .01572 L
.18069 .01572 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .01572 L
.18069 .01572 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .04495 L
.19626 .04495 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .04495 L
.19626 .04495 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .01472 L
.21184 .01472 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .01472 L
.21184 .01472 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .02379 L
.22741 .02379 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .02379 L
.22741 .02379 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .02883 L
.24299 .02883 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .02883 L
.24299 .02883 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .28382 L
.25857 .28382 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .28382 L
.25857 .28382 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .01572 L
.27414 .01572 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .01572 L
.27414 .01572 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .0641 L
.28972 .0641 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .0641 L
.28972 .0641 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .02479 L
.3053 .02479 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .02479 L
.3053 .02479 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .04193 L
.32087 .04193 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .04193 L
.32087 .04193 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .01572 L
.33645 .01572 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .01572 L
.33645 .01572 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .03487 L
.35202 .03487 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .03487 L
.35202 .03487 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .06511 L
.38318 .06511 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .06511 L
.38318 .06511 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .01673 L
.41433 .01673 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .01673 L
.41433 .01673 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .01673 L
.44548 .01673 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .01673 L
.44548 .01673 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .01472 L
.46106 .01472 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .01472 L
.46106 .01472 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .02278 L
.47664 .02278 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .02278 L
.47664 .02278 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .29692 L
.50779 .29692 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .29692 L
.50779 .29692 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .02681 L
.52336 .02681 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .02681 L
.52336 .02681 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .12961 L
.53894 .12961 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .12961 L
.53894 .12961 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .07418 L
.57009 .07418 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .07418 L
.57009 .07418 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01472 L
.58567 .01472 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .01875 L
.60125 .01875 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .01875 L
.60125 .01875 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .17799 L
.6324 .17799 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .17799 L
.6324 .17799 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01572 L
.64798 .01572 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01572 L
.64798 .01572 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .01875 L
.66355 .01875 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .01875 L
.66355 .01875 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .02983 L
.6947 .02983 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .02983 L
.6947 .02983 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01572 L
.71028 .01572 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01572 L
.71028 .01572 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01774 L
.72586 .01774 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01774 L
.72586 .01774 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .06309 L
.75701 .06309 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .06309 L
.75701 .06309 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .03991 L
.78816 .03991 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .03991 L
.78816 .03991 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .03991 L
.81931 .03991 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .03991 L
.81931 .03991 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .01774 L
.85047 .01774 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .01774 L
.85047 .01774 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .02076 L
.88162 .02076 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .02076 L
.88162 .02076 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .01472 L
.94393 .01472 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .01472 L
.94393 .01472 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .03487 L
.01246 .03487 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .03487 L
.01246 .03487 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .07922 L
.02804 .07922 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .07922 L
.02804 .07922 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .09535 L
.04361 .09535 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .09535 L
.04361 .09535 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .01975 L
.05919 .01975 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .01975 L
.05919 .01975 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .07922 L
.07477 .07922 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .07922 L
.07477 .07922 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .03386 L
.09034 .03386 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .03386 L
.09034 .03386 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .08627 L
.10592 .08627 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .08627 L
.10592 .08627 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .06813 L
.1215 .06813 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .06813 L
.1215 .06813 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .0762 L
.13707 .0762 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .0762 L
.13707 .0762 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .08829 L
.15265 .08829 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .08829 L
.15265 .08829 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .07418 L
.16822 .07418 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .07418 L
.16822 .07418 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .02983 L
.1838 .02983 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .02983 L
.1838 .02983 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .09232 L
.19938 .09232 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .09232 L
.19938 .09232 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .01975 L
.21495 .01975 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .01975 L
.21495 .01975 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .06612 L
.23053 .06612 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .06612 L
.23053 .06612 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .08728 L
.24611 .08728 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .08728 L
.24611 .08728 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .08325 L
.26168 .08325 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .08325 L
.26168 .08325 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .01774 L
.27726 .01774 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .01774 L
.27726 .01774 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .08325 L
.29283 .08325 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .08325 L
.29283 .08325 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .07216 L
.30841 .07216 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .07216 L
.30841 .07216 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .07015 L
.32399 .07015 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .07015 L
.32399 .07015 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .01875 L
.33956 .01875 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .01875 L
.33956 .01875 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .08627 L
.35514 .08627 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .08627 L
.35514 .08627 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .03185 L
.37072 .03185 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .03185 L
.37072 .03185 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .09434 L
.38629 .09434 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .09434 L
.38629 .09434 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .0379 L
.40187 .0379 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .0379 L
.40187 .0379 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .04394 L
.41745 .04394 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .04394 L
.41745 .04394 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .0762 L
.43302 .0762 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .0762 L
.43302 .0762 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .02278 L
.4486 .02278 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .02278 L
.4486 .02278 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .06209 L
.46417 .06209 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .06209 L
.46417 .06209 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .06007 L
.47975 .06007 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .06007 L
.47975 .06007 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .08426 L
.49533 .08426 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .08426 L
.49533 .08426 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .0641 L
.5109 .0641 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .0641 L
.5109 .0641 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .07922 L
.52648 .07922 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .07922 L
.52648 .07922 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .07922 L
.54206 .07922 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .07922 L
.54206 .07922 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .0389 L
.55763 .0389 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .0389 L
.55763 .0389 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .09736 L
.57321 .09736 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .09736 L
.57321 .09736 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .01774 L
.58879 .01774 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .01774 L
.58879 .01774 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .05705 L
.60436 .05705 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .05705 L
.60436 .05705 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .0389 L
.61994 .0389 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .0389 L
.61994 .0389 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .06713 L
.63551 .06713 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .06713 L
.63551 .06713 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .02278 L
.65109 .02278 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .02278 L
.65109 .02278 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .0762 L
.66667 .0762 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .0762 L
.66667 .0762 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .03689 L
.68224 .03689 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .03689 L
.68224 .03689 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .07317 L
.69782 .07317 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .07317 L
.69782 .07317 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .04999 L
.7134 .04999 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .04999 L
.7134 .04999 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .06511 L
.72897 .06511 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .06511 L
.72897 .06511 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .07922 L
.74455 .07922 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .07922 L
.74455 .07922 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .07922 L
.76012 .07922 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .07922 L
.76012 .07922 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .01673 L
.7757 .01673 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .01673 L
.7757 .01673 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .08023 L
.79128 .08023 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .08023 L
.79128 .08023 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .05604 L
.80685 .05604 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .05604 L
.80685 .05604 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .09232 L
.82243 .09232 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .09232 L
.82243 .09232 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .01975 L
.83801 .01975 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .01975 L
.83801 .01975 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .11147 L
.85358 .11147 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .11147 L
.85358 .11147 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .02479 L
.86916 .02479 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .02479 L
.86916 .02479 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .0772 L
.88474 .0772 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .0772 L
.88474 .0772 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .0389 L
.91589 .0389 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .0389 L
.91589 .0389 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .0762 L
.93146 .0762 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .0762 L
.93146 .0762 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .03487 L
.94704 .03487 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .03487 L
.94704 .03487 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .05201 L
.96262 .05201 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .05201 L
.96262 .05201 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .05705 L
.97819 .05705 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .05705 L
.97819 .05705 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .06309 L
.99377 .06309 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .06309 L
.99377 .06309 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .01572 L
.01558 .01572 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .01572 L
.01558 .01572 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .05604 L
.03115 .05604 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .05604 L
.03115 .05604 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .02479 L
.04673 .02479 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .02479 L
.04673 .02479 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .10744 L
.06231 .10744 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .10744 L
.06231 .10744 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .01875 L
.07788 .01875 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .01875 L
.07788 .01875 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .09434 L
.09346 .09434 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .09434 L
.09346 .09434 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .01774 L
.10903 .01774 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .01774 L
.10903 .01774 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .0641 L
.12461 .0641 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .0641 L
.12461 .0641 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .02681 L
.14019 .02681 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .02681 L
.14019 .02681 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .05503 L
.15576 .05503 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .05503 L
.15576 .05503 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .06612 L
.17134 .06612 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .06612 L
.17134 .06612 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .09635 L
.18692 .09635 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .09635 L
.18692 .09635 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .04394 L
.20249 .04394 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .04394 L
.20249 .04394 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .06813 L
.21807 .06813 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .06813 L
.21807 .06813 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .07922 L
.23364 .07922 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .07922 L
.23364 .07922 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .04092 L
.24922 .04092 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .04092 L
.24922 .04092 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .01774 L
.2648 .01774 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .01774 L
.2648 .01774 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .12155 L
.28037 .12155 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .12155 L
.28037 .12155 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .04697 L
.29595 .04697 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .04697 L
.29595 .04697 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .04798 L
.31153 .04798 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .04798 L
.31153 .04798 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .04495 L
.3271 .04495 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .04495 L
.3271 .04495 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .12256 L
.34268 .12256 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .12256 L
.34268 .12256 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .0258 L
.35826 .0258 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .0258 L
.35826 .0258 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .10442 L
.37383 .10442 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .10442 L
.37383 .10442 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .04294 L
.38941 .04294 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .04294 L
.38941 .04294 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .10542 L
.40498 .10542 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .10542 L
.40498 .10542 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .10442 L
.42056 .10442 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .10442 L
.42056 .10442 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .02983 L
.43614 .02983 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .02983 L
.43614 .02983 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .10744 L
.45171 .10744 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .10744 L
.45171 .10744 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .03286 L
.46729 .03286 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .03286 L
.46729 .03286 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .02681 L
.48287 .02681 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .02681 L
.48287 .02681 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .02076 L
.49844 .02076 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .02076 L
.49844 .02076 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .01673 L
.51402 .01673 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .01673 L
.51402 .01673 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .05201 L
.5296 .05201 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .05201 L
.5296 .05201 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .02379 L
.54517 .02379 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .02379 L
.54517 .02379 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .07821 L
.56075 .07821 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .07821 L
.56075 .07821 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .02379 L
.57632 .02379 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .02379 L
.57632 .02379 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .11953 L
.5919 .11953 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .11953 L
.5919 .11953 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .11752 L
.60748 .11752 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .11752 L
.60748 .11752 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .08527 L
.62305 .08527 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .08527 L
.62305 .08527 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .03185 L
.63863 .03185 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .03185 L
.63863 .03185 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .1155 L
.65421 .1155 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .1155 L
.65421 .1155 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .09031 L
.66978 .09031 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .09031 L
.66978 .09031 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .06713 L
.68536 .06713 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .06713 L
.68536 .06713 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .04898 L
.70093 .04898 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .04898 L
.70093 .04898 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .04798 L
.71651 .04798 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .04798 L
.71651 .04798 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .07922 L
.73209 .07922 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .07922 L
.73209 .07922 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .02983 L
.74766 .02983 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .02983 L
.74766 .02983 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .04596 L
.76324 .04596 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .04596 L
.76324 .04596 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .0772 L
.77882 .0772 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .0772 L
.77882 .0772 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .06209 L
.79439 .06209 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .06209 L
.79439 .06209 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .02883 L
.80997 .02883 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .02883 L
.80997 .02883 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .05604 L
.82555 .05604 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .05604 L
.82555 .05604 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .07317 L
.84112 .07317 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .07317 L
.84112 .07317 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .051 L
.8567 .051 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .051 L
.8567 .051 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .1155 L
.87227 .1155 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .1155 L
.87227 .1155 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .05805 L
.88785 .05805 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .05805 L
.88785 .05805 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .07922 L
.90343 .07922 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .07922 L
.90343 .07922 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .07418 L
.919 .07418 L
.919 .01472 L
F
.91589 .01472 m
.91589 .07418 L
.919 .07418 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .01975 L
.93458 .01975 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .01975 L
.93458 .01975 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .06511 L
.95016 .06511 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .06511 L
.95016 .06511 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .01572 L
.96573 .01572 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .01572 L
.96573 .01572 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .0389 L
.98131 .0389 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .0389 L
.98131 .0389 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .04697 L
.99688 .04697 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .04697 L
.99688 .04697 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`00:?ooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol0000;ooooo`00:Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000<ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000003?ooool002Sooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Uoooooooo0000aOl0000;ooooo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000_ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`007?ooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Kooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o
0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_oo
O`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l0
0?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o
0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`000ol0003oo`00o`3o
0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0005o`000?oo003o0?l0o`3o0?l00?l0
0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo
0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go
0000ool00?l0o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0003o
o`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o
0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004
ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l0
0?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`00
00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003o
oomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o
0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l0
0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo0003o`00
0?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo0000
0_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0_ooO`001Oooooooo`00o`3o0?l0o`3o003o
00?oogl00_oo00000ooooooo003ooomo0002oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00
o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?o
ogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o
0?l0o`00o`?oogl00ooo00001?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o
003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ooooo`04o`00ooooO`3oogl0oomo
00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0
o`3o003oo`00o`02oomo00?oo`000_l00?l2oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`03ool0
00;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl00_oo00000ol0
o`3o003oo`00o`02oomo00?ooooo0_l00?l2oomo0003oooooooo003o0?l000;o003o0_ooO`03oooo
o`;o003o0_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl000?oooooool0
0?l0o`000_l00?l2oomo0003oooooooo003o0?l000;o003o0_ooO`000oooooooo`00o`3o0002o`00
o`;oogl01?ooool01Ol00?ooogl0oomo0?ooooooo`0000;o0?l000?o003ooomo0?ooO`001?ooool0
1Ol00?ooogl0oomo0?ooooooo`0000;o0?l000Co003ooomo0?ooO`3ooooo0_oo00001_oooooo003o
oomo0?ooO`3oooooool000;o0?l000?o003ooomo0?ooO`001?ooool01Ol00?ooogl0oomo0?oooooo
o`0000;o0?l000?o003ooomo0?ooO`001?ooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co
003ooomo0?ooO`3oogl00oooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?oo
O`3oogl00oooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00ooo
ool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00oooool01?l00?oo
ogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00oooool01?l00?ooogl0oomo0?ooO`02
ool00003o`3o0?l00?ooogl000;oogl00oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l0
0?ooogl000;oogl01?ooool3oomo00?ooooo00Co003ooomo0?ooO`3oogl00oooool2o`00o`;oogl0
0oooool2o`00o`;oogl00oooool3o`00o`Cooooo0_l00?l2oomo00?ooooo0_l00?l2oomo0003o`00
0?oooooooooo00Wooooo000Kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo0000
0_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0_ooO`001Oooooooo`00o`3o0?l0o`3o003o
00?oogl00oooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00ooo
ool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?o
ogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o
0?l0o`00o`?oogl00ooo00001?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl0
0oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o
003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00oooo
O`000_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00?o
oooo0_l00?l2oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`03ooooo`;o003o0_ooO`02ool00003
o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl00ooo0002o`00o`;oogl00oooool2o`00o`;o
ogl00oooool2o`00o`;oogl00oooool2o`00o`;oogl00_ooool00ol0o`3o003oo`00o`02oomo00?o
oooo0_l00?l2oomo0003oooooooo003o0?l000?o003o0_ooool01?oo003o0?l0o`00ool00?l2oomo
0003oooooooo003o0?l000;o003o0_ooO`04ooooo`05o`00ooooO`3oogl0oooooooo00000_l0o`00
0ol00?ooogl0oomo0005ooooo`;oogl000Goooooool00?l0o`3o0?l0o`00o`02oomo00Cooooo00Go
003ooomo0?ooO`3oooooool00002o`3o0003o`00ooooO`3oogl000Cooooo00Go003ooomo0?ooO`3o
ooooool00002o`3o0003o`00ooooO`3oogl000Cooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o
0004o`00ooooO`3oogl0oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ooooooo003ooomo
0002oomo00?ooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00Co
oooo0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo0000
0ol0o`3o003ooomo0002oomo00?ooooo00Co003ooomo0?ooO`3oogl00ooo00001?l00?ooogl0oomo
0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?o
ogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooO`03ooooo`;o003o0_ooO`03oooo
o`?o003o1?ooool2o`00o`;oogl00oooool2o`00o`;oogl000?o0000ooooooooool02Oooool001co
oooo0_l00007ooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`00
o`;oogl000Goooooool00?l0o`3o0?l0o`00o`03oomo00Cooooo0oooO`000ooo003o0?l0o`3o0002
o`00o`Gooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o00;o003o0_ooool01?oo003o0?l0o`3o
0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo
0002oomo00Cooooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl00_ooool00ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ooooo`03o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02oomo00Gooooo0_oo
O`02ool00003o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl00_oo00000ol0o`3o003oo`00
o`02oomo00?ooooo0_l00?l2oomo00?oo`000_l00?l2oomo00?ooooo0_l00?l2oomo00?ooooo0_l0
0?l2oomo00?ooooo0_l00?l2oomo00;ooooo00?o0?l0o`00ool00?l00_ooO`03ooooo`?o003o0_oo
ool00ooo003o0?l0o`00o`02o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00o`3o
0002o`00o`;oogl01?ooool01Ol00?ooogl0oomo0?ooooooo`0000;o0?l000?o003ooomo0?ooO`00
1Oooool2oomo0005oooooooo003oo`00ooooool00?l00_ooO`04ooooo`05o`00ooooO`3oogl0oooo
oooo00000_l0o`000ol00?ooogl0oomo0004ooooo`04o`00ooooO`3oogl0ooooo`;oo`0000Cooooo
o`00ooooO`3oogl01?ooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3o
ogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo00Go003o
oomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00Cooooo0oooO`001?oo003o0?l0
o`3o0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo
00Cooooo0oooO`03ool00004o`00ooooO`3oogl0oomo00?ooooo00Co003ooomo0?ooO`3oogl00ooo
00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`?o
003o1?ooool2o`00o`;oogl00oooool3o`00o`Cooooo0_l00?l2oomo00?ooooo0_l00?l2oomo0003
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`04ool0
0?l0o`3o0?l0o`00o`;oogl000Goooooool00?l0o`3o0?l0o`00o`03oomo00Cooooo0oooO`000ooo
003o0?l0o`3o0002o`00o`Gooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o00;o003o0_ooool0
1?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o
003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo0000
0ol0o`3o003ooomo0002oomo00Cooooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl00_ooool0
0ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0
o`00ooooO`000_ooO`02ooooo`03o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00o`02
oomo00Gooooo0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl00_oo0000
0ol0o`3o003oo`00o`02oomo00?ooooo0_l00?l2oomo00?oo`000_l00?l2oomo00?ooooo0_l00?l2
oomo00Gooooo0_ooO`03ooooo`;o003o0_ooO`03ooooo`;o003o0_ooO`03ooooo`?o003o0_ooool0
0ooo003o0?l0o`00o`02o`00o`?ooooo00?o0?l0o`00ool00?l00_ooO`000oooooooo`00o`3o0002
o`00o`;oogl01?ooool01Ol00?ooogl0oomo0?ooooooo`0000;o0?l000?o003ooomo0?ooO`001Ooo
ool2oomo0005oooooooo003oo`00ooooool00?l00_ooO`04ooooo`05o`00ooooO`3oogl0oooooooo
00000_l0o`000ol00?ooogl0oomo0005ooooo`;oogl000Goooooool00?oo003oooooo`00o`02oomo
00Cooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00?ooooo00Co
003ooomo0?ooO`3oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`05o`00ooooO`3oogl0oomo
0?oo00000_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl000Coo`00o`3o0?l0o`3o003o0ooo
O`03ooooo`04o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl0
0ooo00001?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?oo`0000Co003ooomo
0?ooO`3oogl01?ooool3oomo00?ooooo00Co003ooomo0?ooO`3oogl00oooool3o`00o`Cooooo0_l0
0?l2oomo00?ooooo0ol00?l4ooooo`;o003o0_ooO`03ooooo`;o003o0_ooO`000ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`02o`3o00;o003o0_ooool01?oo003o0?l0o`3o0?l0
0?l2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o
1Oooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`00
o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0
o`3o0?l0o`00o`?oogl00oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?ooogl000;o
ogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo0002oomo
00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03oooo
o`;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl01Oooool2oomo00;oo`0000?o0?l0o`00
ool00?l00_ooO`03ooooo`;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00oooool2o`00
o`;oogl00ooo0002o`00o`;oogl00oooool2o`00o`;oogl01Oooool2oomo00?ooooo0_l00?l2oomo
00?ooooo0_l00?l2oomo00?ooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o0oooool00ol0
o`3o003oo`00o`02oomo0003oooooooo003o0?l000?o003o1Oooool01Ol00?ooogl0oomo0?oooooo
o`0000;o0?l00_l00?l6ooooo`;oogl000Goooooool00?oo003oooooo`00o`02oomo00Cooooo00Go
003ooomo0?ooO`3oooooool00002o`3o0003o`00ooooO`3oogl000Gooooo0_ooO`001Oooooooo`00
ool00?oooooo003o00;oogl01?ooool01Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo
0?ooO`3oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo
00Go003ooomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00Cooooo0oooO`001?oo
003o0?l0o`3o0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo
0002oomo00Cooooo0oooO`03ool00004o`00ooooO`3oogl0oomo00Cooooo0oooO`03ool00004o`00
ooooO`3oogl0oomo00Cooooo0oooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo0ol00?l4oooo
o`;o003o0_ooO`03ooooo`?o003o1?ooool2o`00o`;oogl00oooool2o`00o`;oogl000?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0
o`3o003o0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002
o`00o`Gooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o00;o003o0_ooool01?oo003o0?l0o`3o
0?l00?l3oomo0003ool00?l0o`3o0?l000;o003o0_ooool01?oo003o0?l0o`3o0?l00?l3oomo0004
ool00?l0o`3o0?l0o`00o`?oogl00oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?oo
ogl000;oogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00_ooool00ol0o`3o003ooomo
0002oomo00;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`03ooooo`;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl01Oooool2oomo00;oo`0000Co
0?l0o`00ool00?oo003o1?ooool2o`00o`;oogl00_oo00000ol0o`3o003oo`00o`02oomo00?ooooo
0_l00?l2oomo00?oo`000_l00?l2oomo00?ooooo0_l00?l2oomo00Gooooo0_ooO`03ooooo`;o003o
0_ooO`03ooooo`?o003o1?ooool3o`00o`;ooooo00?oo`00o`3o0?l00?l00_l00?l4ooooo`;o003o
0_ooO`000oooooooo`00o`3o0003o`00o`Gooooo00Go003ooomo0?ooO`3oooooool00002o`3o00;o
003o1_ooool2oomo0005oooooooo003oo`00ooooool00?l00_ooO`04ooooo`05o`00ooooO`3oogl0
oooooooo00000_l0o`000ol00?ooogl0oomo0005ooooo`;oogl000Goooooool00?oo003oooooo`00
o`02oomo00Cooooo00Go003ooomo0?ooO`3oogl0ool00002o`3o0004o`00ooooO`3oogl0oomo00?o
oooo00Co003ooomo0?ooO`3oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`05o`00ooooO`3o
ogl0oomo0?oo00000_l0o`001?l00?ooogl0oomo0?ooO`04ooooo`?oogl000Coo`00o`3o0?l0o`3o
003o0oooO`03ooooo`04o`00ooooO`3oogl0oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04oooo
o`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?oo
O`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`?o003o1?ooool2o`00o`;oogl0
0oooool3o`00o`Cooooo0_l00?l2oomo00?ooooo0_l00?l2oomo0003o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`;oogl0
00Coooooool00?l0o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l5ooooo`05
o`00ooooO`3oogl0oomo0?oo00000_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`00
0ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o
0?l00?l3oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003ooomo0002oomo00Co
oooo0oooO`03ool00004o`00ooooO`3oogl0oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo0000
0ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0o`3o003ooomo0002oomo00?ooooo0_l00?l2
oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`05ooooo`;oogl00_oo00001?l0o`3o003oo`00ool0
0?l4ooooo`;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00oooool2o`00o`;oogl00ooo
0002o`00o`;oogl00oooool2o`00o`;oogl01Oooool2oomo00?ooooo0_l00?l2oomo00?ooooo0ol0
0?l4ooooo`?o003o0_ooool00ooo003o0?l0o`00o`02o`00o`Cooooo0_l00?l2oomo0003oooooooo
003o0?l000?o003o1Oooool01Ol00?ooogl0oomo0?ooooooo`0000;o0?l00_l00?l6ooooo`;oogl0
00Goooooool00?oo003oooooo`00o`02oomo00Cooooo00Go003ooomo0?ooO`3oooooool00002o`3o
0003o`00ooooO`3oogl000Gooooo0_ooO`001Oooooooo`00ool00?oooooo003o00;oogl01?ooool0
1Ol00?ooogl0oomo0?ooO`3oo`0000;o0?l000Co003ooomo0?ooO`3oogl00oooool01?l00?ooogl0
oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo00Go003ooomo0?ooO`3oogl0ool00002
o`3o0004o`00ooooO`3oogl0oomo00Cooooo0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00?ooooo
0_l00?l2ooooo`;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo00001?l00?ooogl0
oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l0
0?ooogl0oomo0?ooO`03ooooo`?o003o1?ooool2o`00o`;oogl00oooool3o`00o`Cooooo0_l00?l2
oomo00?ooooo0_l00?l2oomo0003o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00;o0?l00_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`;oogl000Coooooool00?l0o`3o0?l00_l0
0?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l5ooooo`05o`00ooooO`3oogl0oomo0?oo0000
0_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`000ooo003o0?l0o`3o0002o`00o`;o
oooo00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00Cooooo0oooO`02
ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00ooo
ool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o
0?l00?ooogl000;oogl00oooool2o`00o`;oogl00_oo00000ol0o`3o003oo`00o`02oomo00Gooooo
0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Cooooo0_l00?l2oomo00;oo`0000?o0?l0o`00ool0
0?l00_ooO`03ooooo`;o003o0_ooO`03ool000;o003o0_ooO`03ooooo`?o003o1_ooool2oomo00?o
oooo0_l00?l2oomo00?ooooo0ol00?l4ooooo`?o003o0_ooool00ooo003o0?l0o`00o`02o`00o`Co
oooo0_l00?l2oomo0003oooooooo003o0?l000?o003o1Oooool01Ol00?ooogl0oomo0?ooooooo`00
00;o0?l00_l00?l6ooooo`;oogl000Goooooool00?oo003oooooo`00o`02oomo00Cooooo00Go003o
oomo0?ooO`3oooooool00002o`3o0003o`00ooooO`3oogl000Gooooo0_ooO`001Oooooooo`00ool0
0?oooooo003o00;oogl01?ooool01?l00?ooogl0oomo0?ooO`02ool00003ooooool00?ooogl000;o
ogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo0_l00?l2
ooooo`04ool00?l0o`3o0?l0o`00o`?oogl01?ooool3oomo0004ool00?l0o`3o0?l0o`00o`?oogl0
0oooool2o`00o`;ooooo0_oo00000ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool00004o`00
ooooO`3oogl0oomo00Cooooo0oooO`03ooooo`04o`00ooooO`3oogl0oomo00Cooooo0oooO`03oooo
o`04o`00ooooO`3oogl0oomo00?ooooo0ol00?l4ooooo`;o003o0_ooO`03ooooo`?o003o1?ooool2
o`00o`;oogl00oooool2o`00o`;oogl000?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0_ooO`001?ooooooo`00o`3o0?l0
o`02o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0o`3o
0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`000ooo003o0?l0o`3o0002o`00o`;ooooo
00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00Cooooo0oooO`02ool0
0003o`3o0?l00?ooogl000;oogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00oooool0
1?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l0
0?ooogl000;oogl00oooool2o`00o`;oogl00_oo00000ol0o`3o003oo`00o`02oomo00Gooooo0_oo
O`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_ooO`02ool00003o`3o0?l00?oo003o00;oogl0
0oooool2o`00o`;oogl00ooo0002o`00o`;oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o
1?ooool3o`00o`Cooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o1?ooool2o`00o`;oogl0
00?oooooool00?l0o`000ol00?l5ooooo`05o`00ooooO`3oogl0oooooooo00000_l0o`02o`00o`Ko
oooo0_ooO`001Oooooooo`00ool00?oooooo003o00;oogl01?ooool01Ol00?ooogl0oomo0?oooooo
o`0000;o0?l00_l00?l6ooooo`;oogl000Goooooool00?oo003oooooo`00o`02oomo00Cooooo00Co
003ooomo0?ooO`3oogl00_oo00000ooooooo003ooomo0002oomo00?ooooo00Co003ooomo0?ooO`3o
ogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool01?oo003o0?l0o`3o0?l00?l3
oomo00Cooooo0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00?ooooo0_l00?l2ooooo`;oo`0000?o
0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl0
0oooool01?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?ooO`03oooo
o`?o003o1?ooool2o`00o`;oogl00oooool3o`00o`Cooooo0_l00?l2oomo00?ooooo0_l00?l2oomo
0003o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l00oooool01?oo003o
0?l0o`3o0?l00?l2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o
0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o0_ooool01?oo003o0?l0o`3o0?l0
0?l3oomo0003ool00?l0o`3o0?l000;o003o0_ooool01?oo003o0?l0o`3o0?l00?l3oomo0004ool0
0?l0o`3o0?l0o`00o`?oogl01?ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`04ooooo`?o
ogl00ooo00001?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00;oo`0000?o0?l0
o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ooooo`;o003o0_ooO`02
ool00003o`3o0?l00?oo003o00;oogl01Oooool2oomo00?oo`000ol00?l6ooooo`;oogl00_oo0000
0ol0o`3o003oo`00o`02oomo00?ooooo0_l00?l2oomo00?oo`000_l00?l2oomo00?ooooo0ol00?l6
ooooo`;oogl00oooool3o`00o`Cooooo0ol00?l4ooooo`?o003o0_ooool00ooo003o0?l0o`00o`02
o`00o`Cooooo0_l00?l2oomo0003oooooooo003o0?l000?o003o1Oooool01Ol00?ooogl0oomo0?oo
ooooo`0000;o0?l00_l00?l6ooooo`;oogl01?ooool00ol00?ooogl0oomo0004ooooo`05o`00oooo
O`3oogl0oooooooo00000_l0o`02o`00o`Kooooo0_ooO`04ooooo`03o`00ooooO`3oogl000Cooooo
00Co003ooomo0?ooO`3oogl00_oo00000ooooooo003ooomo0002oomo00?ooooo00Co003ooomo0?oo
O`3oogl00oooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool01?oo003o0?l0o`3o0?l0
0?l3oomo00Cooooo0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00?ooooo0_l00?l2ooooo`;oo`00
00?o0?l0o`00ooooO`000_ooO`04ooooo`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?o
ogl00oooool01?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?ooO`03
ooooo`?o003o1_ooool2oomo00?ooooo0ol00?l4ooooo`;o003o0_ooO`03ooooo`;o003o0_ooO`00
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00?ooooo00Coo`00o`3o
0?l0o`3o003o0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`000ooo003o0?l0o`3o
0002o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o
0oooO`000ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o
0?l0o`3o0?l00?l3oomo00Cooooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo
00?oo`0000Co003ooomo0?ooO`3oogl00oooool01?l00?ooogl0oomo0?ooO`02ool00003o`3o0?l0
0?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl00oooool2o`00o`;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00Gooooo0_ooO`03ool000?o003o1_ooool2oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`05ooooo`;oogl00oooool2o`00o`;oogl00oooool3o`00o`Kooooo0_oo
O`03ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o1?oo
ool2o`00o`;oogl000?oooooool00?l0o`000ol00?l5ooooo`05o`00ooooO`3oogl0oooooooo0000
0_l0o`02o`00o`Kooooo0_ooO`04ooooo`03o`00ooooO`3oogl000Cooooo00Go003ooomo0?ooO`3o
ooooool00002o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`001Oooool3oomo00;o
o`0000?oooooo`00ooooO`000_ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo00Co003ooomo
0?ooO`3oogl00oooool2o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`04ooooo`?oogl000Co
o`00o`3o0?l0o`3o003o0oooO`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?ooogl000;oogl0
1?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl01?ooool3oomo00?ooooo00Co003ooomo0?oo
O`3oogl01?ooool3oomo00?ooooo00Co003ooomo0?ooO`3oogl00oooool3o`00o`Kooooo0_ooO`03
ooooo`?o003o1?ooool2o`00o`;oogl00oooool2o`00o`;oogl000?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`03ooooo`04ool00?l0o`3o0?l0o`00o`;oogl000Cooooo
ool00?l0o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl000?o
o`00o`3o0?l0o`000_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?oogl000?oo`00o`3o0?l0o`00
0_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`04oooo
o`?oogl00_oo00000ol0o`3o003ooomo0002oomo00Cooooo0oooO`03ool00004o`00ooooO`3oogl0
oomo00?ooooo00Co003ooomo0?ooO`3oogl00_oo00000ol0o`3o003oo`00o`06ooooo`?oogl00_oo
00000ol0o`3o003ooomo0002oomo00?ooooo0_l00?l2oomo00;oo`0000?o0?l0o`00ool00?l00_oo
O`05ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`02ool00003o`3o0?l00?oo003o00;oogl01Ooo
ool2oomo00?ooooo0_l00?l2oomo00?ooooo0ol00?l6ooooo`;oogl00oooool3o`00o`Cooooo0ol0
0?l4ooooo`?o003o0_ooool00ooo003o0?l0o`00o`02o`00o`Cooooo0_l00?l2oomo0003oooooooo
003o0?l000?o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo
00?o003ooomo0?ooO`001Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Co
oooo00?o003ooomo0?ooO`001Oooool3oomo00;oo`0000?oooooo`00ooooO`000_ooO`03ooooo`04
o`00ooooO`3oogl0oomo00?ooooo00Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo00Coo`00
o`3o0?l0o`3o003o0oooO`04ooooo`?oogl00_oo00000ooooooo003ooomo0002oomo00?ooooo0_l0
0?l2ooooo`?oo`0000Co003ooomo0?ooO`3oogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3o
ogl01?ooool3oomo00?ooooo00Co003ooomo0?ooO`3oogl01?ooool3oomo00Cooooo0oooO`03oooo
o`?o003o1_ooool2oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool2o`00o`;oogl000?o0000oooo
ooooool02Oooool002Gooooo0ol00003o`3o00?ooooo00Coo`00o`3o0?l0o`3o003o0_ooO`001?oo
ooooo`00o`3o0?l0o`02o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`00
0ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`000ooo003o0?l0o`3o
0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00Co
oooo0oooO`02ool00003o`3o0?l00?ooogl000;oogl01?ooool3oomo00?oo`0000Co003ooomo0?oo
O`3oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003oo`00o`06ooooo`?oogl00_oo00000ol0
o`3o003ooomo0002oomo00?ooooo0_l00?l2oomo00?oo`000_l00?l2oomo00Gooooo0_ooO`03ool0
00?o003o1_ooool2oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`05ooooo`;oogl00oooool2o`00
o`;oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l3oooo
o`04o`3o0?l00?oo003oo`00o`Cooooo0_l00?l2oomo0003oooooooo003o0?l000?o003o1_ooool2
oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`001Ooo
ool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`00
1Oooool3oomo00;oo`0000?oooooo`00ooooO`000_ooO`03ooooo`04o`00ooooO`3oogl0oomo00?o
oooo00Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`04
ooooo`?oogl00_oo00000ooooooo003ooomo0002oomo00?ooooo0_l00?l2ooooo`?oo`0000Co003o
oomo0?ooO`3oogl01?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl01?ooool3oomo00?ooooo
00Co003ooomo0?ooO`3oogl01?ooool3oomo00Cooooo0oooO`03ooooo`?o003o1_ooool2oomo00?o
oooo0ol00?l4ooooo`?o003o1?ooool2o`00o`;oogl000?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`03ooooo`04ool00?l0o`3o0?l0o`00o`;oogl000Coooooool00?l0
o`3o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl000?oo`00o`3o
0?l0o`000_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?oogl000?oo`00o`3o0?l0o`000_l00?l2
ooooo`04ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`04ooooo`?oogl0
0ooo0002o`00o`Kooooo0oooO`03ool00004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;o
o`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`03ooooo`;o
003o0_ooO`03ool000?o003o1_ooool2oomo00?oo`000ol00?l6ooooo`;oogl00_oo00001?l0o`3o
003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00?ooooo0ol00?l6ooooo`;oogl00oooool3o`00
o`Cooooo0ol00?l4ooooo`?o003o0oooool01?l0o`3o003oo`00ool00?l4ooooo`;o003o0_ooO`00
0oooooooo`00o`3o0003o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_oo
O`04ooooo`03o`00ooooO`3oogl000Gooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo
0_ooO`04ooooo`03o`00ooooO`3oogl000Gooooo0oooO`02ool00003ooooool00?ooogl000;oogl0
0oooool01?l00?ooogl0oomo0?ooO`03ooooo`04o`00ooooO`3oogl0oomo00?ooooo0_l00?l2oooo
o`04ool00?l0o`3o0?l0o`00o`?oogl01?ooool3oomo00;oo`0000?oooooo`00ooooO`000_ooO`03
ooooo`;o003o0_ooool3ool00004o`00ooooO`3oogl0oomo00Cooooo0oooO`03ool00004o`00oooo
O`3oogl0oomo00Cooooo0oooO`03ooooo`04o`00ooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?o
ogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00o`Cooooo0_l00?l2oomo0003
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l00oooool01?oo003o0?l0
o`3o0?l00?l2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3oomo0003ool00?l0o`3o0?l0
00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o0_ooool2ool00003ooooool00?ooogl0
00;oogl000?oo`00o`3o0?l0o`000_l00?l2ooooo`04ool00?l0o`3o0?l0o`00o`?oogl000Coo`00
o`3o0?l0o`3o003o0oooO`04ooooo`?oogl00ooo0002o`00o`Kooooo0oooO`03ool00004o`00oooo
O`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00;oo`00
00?o0?l0o`00ool00?l01Oooool2o`00o`;oogl00ooo0003o`00o`Kooooo0_ooO`03ool000?o003o
1_ooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`03ooooo`?o
003o1_ooool2oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`?ooooo00Co0?l0o`00ool0
0?oo003o1?ooool2o`00o`;oogl000?oooooool00?l0o`000ol00?l6ooooo`;oogl000Coooooool0
0?l0o`3o0?l00_l00?l6ooooo`;oogl01?ooool00ol00?ooogl0oomo0005ooooo`;oogl000Cooooo
ool00?l0o`3o0?l00_l00?l6ooooo`;oogl01?ooool00ol00?ooogl0oomo0005ooooo`?oogl00_oo
00000ooooooo003ooomo0002oomo00?ooooo00Co003ooomo0?ooO`3oogl00oooool01?l00?ooogl0
oomo0?ooO`03ooooo`;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool00003
ooooool00?ooogl000;oogl00oooool2o`00o`;ooooo0ooo00001?l00?ooogl0oomo0?ooO`04oooo
o`?oogl00ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl00oooool01?l00?ooogl0oomo0?oo
O`04ooooo`?oogl01?ooool3oomo00?ooooo0ol00?l6ooooo`;oogl00oooool3o`00o`Cooooo0ol0
0?l4ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o0000ooooooooool00ol0o`03
ooooo`04ool00?l0o`3o0?l0o`00o`;oogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`?oogl0
00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l2ooooo`;oo`00
00?oooooo`00ooooO`000_ooO`000ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o
003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo00Cooooo0oooO`03ool000;o003o1_ooool3oomo
00?oo`0000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003oo`00o`06
ooooo`?oogl00_oo00000ol0o`3o003oo`00o`05ooooo`?o003o00Coooooool00?oo003oo`000ol0
0?l6ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo
0_ooO`05ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00o`Cooooo
0ol00?l3ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0_l00?l2oomo0003oooooooo003o0?l000?o
003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo
0?ooO`001Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o003o
oomo0?ooO`001Oooool3oomo00;oo`0000?oooooo`00ool00?l01Oooool2o`00o`Gooooo00Co003o
oomo0?ooO`3oogl00oooool2o`00o`;ooooo00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl00_oo
00000ooooooo003ooomo0002oomo00?ooooo0_l00?l2ooooo`?oo`0000Co003ooomo0?ooO`3oogl0
1?ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl01?ooool3oomo00?ooooo00Co003ooomo0?oo
O`3oogl01?ooool3oomo00Cooooo0oooO`03ooooo`?o003o1_ooool2oomo00?ooooo0ol00?l4oooo
o`?o003o1?ooool3o`00o`03ooooool0003ooooo00[ooooo000Uooooo`03o`000?oooooooooo00?o
0?l00oooool01?oo003o0?l0o`3o0?l00?l2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool3
oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o0_ooool2
ool00003ooooool00?ooogl000;oogl000?oo`00o`3o0?l0o`000_l00?l2ooooo`04ool00?l0o`3o
0?l0o`00o`?oogl00_oo00000ooooooo003ooomo0002oomo00Cooooo0oooO`03ool000;o003o1_oo
ool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003o
o`00o`06ooooo`?oogl00_oo00000ol0o`3o003oo`00o`05ooooo`?o003o00Coooooool00?oo003o
o`000ol00?l6ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00
o`Kooooo0_ooO`05ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00
o`Cooooo0ol00?l3ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0_l00?l2oomo0003oooooooo003o
0?l000?o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o
003ooomo0?ooO`001Oooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo
00?o003ooomo0?ooO`001Oooool3oomo00;oo`0000?oooooo`00ool00?l03?ooool01?l00?ooogl0
oomo0?ooO`03ooooo`;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool00003
ooooool00?ooogl000;oogl00oooool2o`00o`;ooooo0ooo00001?l00?ooogl0oomo0?ooO`04oooo
o`?oogl00ooo0002o`00o`Kooooo0oooO`03ooooo`04o`00ooooO`3oogl0oomo00Cooooo0oooO`04
ooooo`?oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00o`Cooooo0ol00?l0
0ooooooo0000ooooo`0:ooooo`009Oooool00ol0003oooooooooo`03o`3o00Cooooo0_l0o`001Ol0
0?ooogl0oomo0?ooooooo`0000;o0?l00_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l6
ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l2ooooo`;oo`0000?oooooo`00ooooO`000_ooO`00
0ooo003o0?l0o`3o0002o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`02ool00003ooooool0
0?ooogl000;oogl01?ooool3oomo00?oo`000_l00?l6ooooo`?oogl00ooo00001?l00?ooogl0oomo
0?ooO`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o
0?l00?oo003o00Gooooo0ol00?l01?ooooooo`00ool00?oo0003o`00o`Kooooo0_ooO`03ool000?o
003o1_ooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`03oooo
o`?o003o1_ooool2oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`?ooooo00Co0?l0o`00
ool00?oo003o1?ooool3o`00o`;ooooo00?oo`00o`3o0?l00?l00_l00?l6ooooo`;oogl000Cooooo
ool00?l0o`3o0?l00_l00?l6ooooo`;oogl01?ooool00ol00?ooogl0oomo0005ooooo`;oogl00_oo
ool2o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`001Oooool3oomo00;oo`0000?o
ooooo`00ool00?l03?ooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool00ooo003o0?l0
o`3o0002o`00o`Kooooo0oooO`02ool00003ooooool00?ooogl000;oogl00oooool2o`00o`;ooooo
0ooo00001?l00?ooogl0oomo0?ooO`04ooooo`?oogl00ooo0002o`00o`Kooooo0oooO`03ooooo`04
o`00ooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?oogl00oooool3o`00o`Kooooo0_ooO`0:oooo
o`?o003o1?ooool3o`00o`03ooooool0003ooooo00[ooooo000Uooooo`03o`000?oooooooooo00?o
0?l01?ooool2o`3o00;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o
0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`;ooooo0_oo00000ooooooo
003ooomo0002oomo0003ool00?l0o`3o0?l000;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`;o
oooo0_oo00000ooooooo003ooomo0002oomo00Cooooo0oooO`03ool000;o003o1_ooool3oomo00?o
o`0000Co003ooomo0?ooO`3oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003oo`00o`06oooo
o`?oogl00_oo00000ol0o`3o003oo`00o`05ooooo`?o003o00Coooooool00?oo003oo`000ol00?l6
ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`02ool00004o`3o0?l00?oo003oo`00o`Kooooo0_oo
O`05ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`03ooooo`?o003o1?ooool3o`00o`Cooooo0ol0
0?l3ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o
1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?oo
O`001Oooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0_ooO`04ooooo`03o`00ooooO`3oogl000Go
oooo0oooO`02ool00003ooooool00?oo003o00cooooo00Co003ooomo0?ooO`3oogl00oooool2o`00
o`;ooooo00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl00_oo00000ooooooo003ooomo0002oomo
00Oooooo0ooo0002o`00o`Kooooo0oooO`03ool000;o003o1_ooool3oomo00?ooooo00Co003ooomo
0?ooO`3oogl01?ooool3oomo00Cooooo0oooO`03ooooo`?o003o1_ooool2oomo00[ooooo0ol00?l4
ooooo`?o003o00?oooooo`000?ooool02_ooool002Gooooo00?o0000ooooooooool00ol0o`04oooo
o`;o0?l00_l00?l2ooooo`03ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l0
00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o0_ooool2ool00003ooooool00?ooogl0
00;oogl000?oooooo`3o0?l0o`000_l00?l2ooooo`03ool00?l0o`3o0?l000;o003o0_ooool2ool0
0003ooooool00?ooogl000;oogl01?ooool3oomo00?oo`000_l00?l6ooooo`?oogl00ooo00001?l0
0?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?oo003o00Kooooo0oooO`02
ool00003o`3o0?l00?oo003o00Gooooo0ol00?l01?ooooooo`00ool00?oo0003o`00o`Kooooo0_oo
O`03ool000?o003o1_ooool2oomo00;oo`0000Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo
0_ooO`03ooooo`?o003o1_ooool2oomo00?ooooo0ol00?l4ooooo`?o003o1?ooool3o`00o`?ooooo
00Co0?l0o`00ool00?oo003o1?ooool3o`00o`;ooooo00?oo`00o`3o0?l00?l00_l00?l6ooooo`;o
ogl000Coooooool00?l0o`3o0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02oooo
o`;o0?l00_l00?l6ooooo`;oogl01?ooool00ol00?ooogl0oomo0005ooooo`?oogl00_oo00000ooo
oooo003oo`00o`0<ooooo`04o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`03ool00?l0o`3o
0?l000;o003o1_ooool3oomo00;oo`0000?oooooo`00ooooO`000_ooO`07ooooo`?oo`000_l00?l6
ooooo`?oogl00ooo0002o`00o`Kooooo0oooO`03ooooo`;o003o1_ooool3oomo00Cooooo0oooO`03
ooooo`?o003o1_ooool2oomo017ooooo0ol00?l00ooooooo0000ooooo`0:ooooo`009Oooool00ol0
003oooooooooo`03o`3o00Cooooo0_l0o`02o`00o`;ooooo00?oo`00o`3o0?l0o`000_l00?l6oooo
o`?oogl000?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl000?oo`00o`3o0?l0o`000_l00?l2oooo
o`;oo`0000?oooooo`00ooooO`000_ooO`000ooooooo0?l0o`3o0002o`00o`;ooooo00?oo`00o`3o
0?l0o`000_l00?l2ooooo`;oo`0000?oooooo`00ooooO`000_ooO`04ooooo`?oogl00ooo0002o`00
o`Kooooo0oooO`03ool00004o`00ooooO`3oogl0oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0
o`00ool00?l01_ooool3oomo00;oo`0000?o0?l0o`00ool00?l01Oooool3o`00o`04oooooooo003o
o`00ool000?o003o1_ooool2oomo00?oo`000ol00?l6ooooo`;oogl00_oo00001?l0o`3o003oo`00
ool00?l6ooooo`;oogl01Oooool2oomo00?ooooo0ol00?l6ooooo`;oogl00oooool3o`00o`_ooooo
0ol00?l3ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o
003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05oooo
o`;oogl00_ooool2o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`001Oooool3oomo
00;oo`0000?oooooo`00ool00?l03?ooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool0
0ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool00003ooooool00?ooogl000;oogl01oooool3
ool000;o003o1_ooool3oomo00?oo`000_l00?l6ooooo`?oogl00oooool2o`00o`Kooooo0oooO`04
ooooo`?oogl00oooool3o`00o`Kooooo0_ooO`0Aooooo`?o003o00?oooooo`000?ooool02_ooool0
02Gooooo00?o0000ooooooooool00ol0o`04ooooo`;o0?l00_l00?l2ooooo`03ool00?l0o`3o0?l0
00;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l0
00;o003o0_ooool2ool00003ooooool00?ooogl000;oogl000?oooooo`3o0?l0o`000_l00?l2oooo
o`03ool00?l0o`3o0?l000;o003o0_ooool2ool00003ooooool00?ooogl000;oogl01?ooool3oomo
00?oo`000_l00?l6ooooo`?oogl00ooo00001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2
ool00003o`3o0?l00?oo003o00Kooooo0oooO`02ool00003o`3o0?l00?oo003o00Gooooo0ol00?l0
1?ooooooo`00ool00?oo0003o`00o`Kooooo0_ooO`03ool000?o003o1_ooool2oomo00;oo`0000Co
0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo0_ooO`03ooooo`?o003o1_ooool2oomo017ooooo
0ol00?l3ooooo`04o`3o0?l00?oo003oo`00o`Cooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o
003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05oooo
o`;oogl00_ooool2o`3o00;o003o1_ooool2oomo00Cooooo00?o003ooomo0?ooO`001Oooool3oomo
00;oo`0000?oooooo`00ool00?l03?ooool01?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool0
0ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`02ool00003ooooool00?oo003o00Wooooo0ooo0002
o`00o`Kooooo0oooO`03ool000;o003o1_ooool3oomo00?ooooo0_l00?l6ooooo`?oogl01?ooool3
oomo00?ooooo0ol00?l6ooooo`;oogl04Oooool3o`00o`03ooooool0003ooooo00[ooooo000Uoooo
o`03o`000?oooooooooo00?o0?l01?ooool2o`3o00;o003o0_ooool00ooo003o0?l0o`3o0002o`00
o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00
o`;ooooo0_oo00000ooooooo003oo`00o`03ooooo`;o0?l00_l00?l2ooooo`03ool00?l0o`3o0?l0
00;o003o0_ooool2ool00003ooooool00?ooogl000;oogl01?ooool3oomo00?oo`000_l00?l6oooo
o`?oogl00ooo00001?l00?ooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool00003o`3o0?l00?oo
003o00Kooooo0oooO`03ool000;o003o1Oooool3o`00o`04oooooooo003oo`00ool000?o003o1_oo
ool2oomo00?oo`000ol00?l6ooooo`;oogl00_oo00001?l0o`3o003oo`00ool00?l6ooooo`;oogl0
1Oooool2oomo00?ooooo0ol00?l6ooooo`;oogl04Oooool3o`00o`?ooooo0_l0o`06ooooo`?o003o
0_ooool00ooo003o0?l0o`00o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Ko
oooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo0_l0o`02o`00o`Kooooo0_ooO`04ooooo`03
o`00ooooO`3oogl000Gooooo0oooO`02ool00003ooooool00?oo003o00cooooo00Co003ooomo0?oo
O`3oogl00oooool2o`00o`;ooooo0_oo00000ooooooo003oo`00o`06ooooo`?oogl00_oo00000ooo
oooo003oo`00o`09ooooo`?oo`000_l00?l6ooooo`?oogl00ooo0002o`00o`Kooooo0oooO`03oooo
o`;o003o1_ooool3oomo00Cooooo0oooO`03ooooo`?o003o1_ooool2oomo01Gooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`04ooooo`;o0?l00_l00?l2ooooo`03
ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo0003
ool00?l0o`3o0?l000;o003o0_ooool2ool00003ooooool00?oo003o00?ooooo0_l0o`02o`00o`;o
oooo0_oo00000ooooooo003oo`00o`02ooooo`;oo`0000?oooooo`00ool00?l01_ooool3oomo00?o
o`000_l00?l6ooooo`?oogl00ooo00001?ooooooogl0oomo0?ooO`03ooooo`;o003o0_ooool2ool0
0003o`3o0?l00?oo003o00Kooooo0oooO`03ool000;o003o1Oooool3o`00o`04oooooooo003oo`00
ool000?o003o1_ooool2oomo00?oo`000ol00?l6ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`05
ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`0Aooooo`?o003o0oooool2o`3o00Kooooo0ol00?l2
ooooo`03ool00?l0o`3o003o00;o003o1_ooool2oomo0004oooooooo003o0?l0o`3o00;o003o1_oo
ool2oomo00Gooooo0_ooO`05ooooo`;oogl00_ooool3o`3o00Oooooo0_ooO`04ooooo`03o`00oooo
O`3oogl000Sooooo0_oo00000ooooooo003oo`00o`0=ooooo`?oogl00oooool2o`00o`;ooooo0_oo
00000ooooooo003oo`00o`06ooooo`?oogl00_oo00000ooooooo003oo`00o`09ooooo`?oo`000_l0
0?l6ooooo`?oogl00ooo0002o`00o`Kooooo0oooO`03ooooo`;o003o1_ooool3oomo00Cooooo0ooo
O`03ooooo`?o003o7Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03
o`3o00Kooooo0_l00?l2ooooo`03ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o
0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o0_ooool2ool000Kooooo0_l0o`02
o`00o`;ooooo0_oo00000ooooooo003oo`00o`02ooooo`;oo`0000?oooooo`00ool00?l01_ooool3
oomo00?oo`000_l00?l=ooooo`?oogl00oooool2o`00o`;ooooo0_oo00000ol0o`3o003oo`00o`06
ooooo`?oogl00ooo0002o`00o`Gooooo0ol00?l01?ooooooo`00ool00?oo0003o`00o`Kooooo0_oo
O`03ool000?o003o1_ooool2oomo00?oo`000ol00?l6ooooo`;oogl01Oooool2oomo00?ooooo0ol0
0?l6ooooo`;oogl04Oooool3o`00o`?ooooo0_l0o`06ooooo`?o003o0_ooool00ooo003o0?l0o`00
o`02o`00o`Kooooo0_ooO`001?ooooooo`00o`3o0?l0o`02o`00o`Kooooo0_ooO`05ooooo`;oogl0
1Oooool2oomo00;ooooo0ol0o`07ooooo`;oogl01?ooool00ol00?ooogl0oomo0008ooooo`;oo`00
00?oooooo`00ool00?l03Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`0000?oooooo`00ool00?l0
1_ooool3oomo00;oo`0000?oooooo`00ool00?l02Oooool3ool000;o003o1_ooool3oomo00?oo`00
0_l00?l6ooooo`?oogl00oooool2o`00o`Kooooo0oooO`04ooooo`?oogl00oooool3o`00oagooooo
00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o00Kooooo0_l00?l2ooooo`03ool00?l0
o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0
o`3o0?l000;o003o0_ooool2ool000Kooooo0_l0o`02o`00o`;ooooo0_oo00000ooooooo003oo`00
o`02ooooo`;oo`0000?oooooo`00ool00?l01_ooool3oomo00?oo`000_l00?l=ooooo`?oogl00ooo
ool2o`00o`;ooooo0_oo00000ol0o`3o003oo`00o`06ooooo`?oogl00ooo0002o`00o`Gooooo0ol0
0?l01?ooooooo`00ool00?oo0009ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`03ool000?o003o
1_ooool2oomo00Gooooo0_ooO`03ooooo`?o003o1_ooool2oomo017ooooo0ol00?l3ooooo`;o0?l0
1_ooool3o`00o`;ooooo00?oo`00o`3o0?l00?l00_l00?l6ooooo`;oogl000Coooooool00?l0o`3o
0?l00_l00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02ooooo`?o0?l01oooool2oomo00Co
oooo00?o003ooomo0?ooO`002?ooool2ool00003ooooool00?oo003o00gooooo0oooO`03ooooo`;o
003o0_ooool2ool00003ooooool00?oo003o00Kooooo0oooO`02ool00003ooooool00?oo003o00Wo
oooo0ooo0002o`00o`Kooooo0oooO`03ool000;o003o1_ooool3oomo00?ooooo0_l00?l6ooooo`?o
ogl01?ooool3oomo00?ooooo0ol00?lLooooo`;o00002oooool002Gooooo00?o0000ooooooooool0
0ol0o`06ooooo`;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0
o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0o`3o0002o`00o`;ooooo0_oo0006ooooo`;o0?l0
0_l00?l2ooooo`;oo`0000?oooooo`00ool00?l00_ooool2ool00003ooooool00?oo003o00Kooooo
0oooO`03ool000;o003o3Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ool00?l0
1_ooool3oomo00?oo`000_l00?l9ooooo`?oo`002Oooool2oomo00?oo`000ol00?l6ooooo`;oogl0
0ooo0003o`00o`Kooooo0_ooO`05ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`0Aooooo`?o003o
0oooool2o`3o00Kooooo0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o1_ooool2oomo0004oooo
oooo003o0?l0o`3o00;o003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_ooool3o`3o00Oo
oooo0_ooO`04ooooo`03o`00ooooO`3oogl000Sooooo0_oo000@ooooo`?oogl00oooool2o`00o`;o
oooo0_oo00000ooooooo003oo`00o`06ooooo`?oogl00_oo00000ooooooo003oo`00o`09ooooo`?o
o`000_l00?l9ooooo`?oo`000_l00?l6ooooo`?oogl00oooool2o`00o`Kooooo0oooO`04ooooo`?o
ogl00oooool3o`00oagooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`06ooooo`;o003o0_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`000ooo003o0?l0
o`3o0002o`00o`Kooooo0oooO`02ool00003ooooool00?oo003o00;ooooo0_oo0006ooooo`;o0?l0
0_l00?l2ooooo`;oo`0000?oooooo`00ool00?l00_ooool2ool000Wooooo0oooO`03ool000;o003o
3Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`0000?o0?l0o`00ool00?l01_ooool3oomo00?oo`00
0_l00?l9ooooo`?oo`002Oooool2oomo00?oo`000ol00?l6ooooo`;oogl00ooo0003o`00o`Kooooo
0_ooO`05ooooo`;oogl00oooool3o`00o`Kooooo0_ooO`0Aooooo`?o003o0oooool2o`3o00Kooooo
0ol00?l2ooooo`03ool00?l0o`3o003o00;o003o1_ooool2oomo0004oooooooo003oo`00ooooo`;o
003o1_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_ooool3o`3o00Oooooo0_ooO`04ooooo`03
o`00ooooO`3oogl000Sooooo0_oo000@ooooo`?oogl00oooool2o`00o`;ooooo0_oo00000ooooooo
003oo`00o`06ooooo`?oogl00_oo00000ooooooo003oo`00o`09ooooo`?oo`000_l00?l9ooooo`?o
o`000_l00?l6ooooo`?oogl00oooool2o`00o`Kooooo0oooO`0:ooooo`?o003o7Oooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00Kooooo0_l00?l2ooooo`03ool0
0?l0o`3o0?l000;o003o1_ooool3oomo0003ool00?l0o`3o0?l000;o003o1_ooool3oomo00;oo`00
00?oooooo`00ool00?l00_ooool2ool000Kooooo0ol0o`03ooooo`;oo`0000?oooooo`00ool00?l0
0_ooool2ool000Wooooo0oooO`03ool000;o003o3Oooool3oomo00?ooooo0_l00?l2ooooo`;oo`00
00?o0?l0o`00ool00?l01_ooool3oomo00?oo`000_l00?l9ooooo`?oo`002Oooool2oomo00?oo`00
0ol00?l6ooooo`;oogl00ooo0003o`00o`Kooooo0_ooO`05ooooo`;oogl03?ooool2oomo017ooooo
0ol00?l3ooooo`;o0?l01_ooool3o`00o`;ooooo00?oo`00o`3o0?l00?l00_l00?l9ooooo`;oo`00
00?oooooo`00ool00?l01_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_ooool3o`3o00Oooooo
0_ooO`05ooooo`;oogl02?ooool2ool0013ooooo0oooO`03ooooo`;o003o0_ooool2ool00003oooo
ool00?oo003o00Wooooo0_oo00000ooooooo003oo`00o`09ooooo`?oo`000_l00?l9ooooo`?oo`00
0_l00?l6ooooo`?oogl02oooool3oomo02[ooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`0:ooooo`03ool00?l0o`3o0?l000;o003o1_ooool3oomo0004ool00?l0
o`3o0?l0o`3o00Oooooo0oooO`02ool00003ooooool00?oo003o00;ooooo0_oo0006ooooo`?o0?l0
0oooool2ool00003ooooool00?oo003o00;ooooo0_oo0009ooooo`?oogl00ooo0002o`00oa?ooooo
0_l00?l4ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000;o003o2Oooool3ool000Wooooo
0_ooO`03ool000?o003o1_ooool2oomo00?oo`000ol00?l6ooooo`;oogl01Oooool2oomo00cooooo
0_ooO`0Aooooo`?o003o0oooool2o`3o00_ooooo00?oo`00o`3o0?l0o`002oooool2ool00003oooo
ool00?oo003o00Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo0ol0o`07ooooo`;oogl0
1Oooool2oomo00Sooooo0_oo000Jooooo`;oo`003?ooool2ool000cooooo0ooo0002o`00o`Wooooo
0ooo0002o`00o`Kooooo0oooO`0hooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l02_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0oooO`001?oo003o0?l0o`3o
0?l0o`07ooooo`?oogl00_oo00000ooooooo003oo`00o`02ooooo`;oo`001_ooool3o`3o00?ooooo
0_oo00000ooooooo003oo`00o`02ooooo`;oo`002Oooool3oomo00?oo`000_l00?lCooooo`;o003o
1?ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0002o`00o`Wooooo0ooo0009ooooo`;oogl0
0ooo0003o`00o`Kooooo0_ooO`03ool000?o003o1_ooool2oomo00Gooooo0_ooO`0<ooooo`;oogl0
4Oooool3o`00o`?ooooo0_l0o`0;ooooo`03ool00?l0o`3o0?l000_ooooo0_oo00000ooooooo003o
o`00o`06ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02ooooo`?o0?l01oooool2oomo00Gooooo
0_ooO`08ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`000_l00?l9ooooo`?oo`00
0_l00?l6ooooo`?oogl0>?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`03o`3o00[ooooo00?oo`00o`3o0?l0o`000_l00?l6ooooo`?oogl000Coo`00o`3o0?l0o`3o0?l0
1oooool3oomo00;oo`0000?oooooo`00ool00?l00_ooool2ool000Kooooo0ol0o`03ooooo`;oo`00
00?oooooo`00ool00?l00_ooool2ool000Wooooo0oooO`03ool000;o003o4oooool2o`00o`Cooooo
0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`000ol00?l6ooooo`;oogl0
0ooo0003o`00o`Kooooo0_ooO`05ooooo`;oogl03?ooool2oomo01Oooooo0_l0o`0;ooooo`03ool0
0?l0o`3o0?l000_ooooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl01Oooool2oomo00Gooooo
0_ooO`02ooooo`?o0?l01oooool2oomo00Gooooo0_ooO`08ooooo`;oo`006_ooool2ool000cooooo
0_oo000<ooooo`?oo`000_l00?l9ooooo`?oo`000_l00?l6ooooo`?oogl0>?ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00[ooooo00?oo`00o`3o0?l0o`000_l0
0?l6ooooo`?oogl000Coo`00o`3o0?l0o`3o0?l01oooool3oomo00;oo`001Oooool2ool000Kooooo
0ol0o`03ooooo`;oo`0000?oooooo`00ool00?l00_ooool2ool000Wooooo0oooO`03ool000;o003o
6Oooool2o`3o00Oooooo0oooO`03ool000_ooooo0ooo0009ooooo`;oogl00ooo0009ooooo`;oogl0
0ooo0003o`00o`Kooooo0_ooO`05ooooo`;oogl03?ooool2oomo01Oooooo0_l0o`0;ooooo`03ool0
0?l0o`3o0?l000_ooooo0_oo00000ooooooo003oo`00o`06ooooo`;oogl01Oooool2oomo00Wooooo
0ol0o`07ooooo`;oogl01Oooool2oomo00Sooooo0_oo000Jooooo`;oo`003?ooool2ool000cooooo
0ooo0002o`00o`Wooooo0ooo0002o`00o`Kooooo0oooO`0hooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l02_ooool00ooo003o0?l0o`3o0002o`00o`Kooooo0ooo
O`001?oo003o0?l0o`3o0?l0o`07ooooo`?oogl00_oo0005ooooo`;oo`001_ooool3o`3o00?ooooo
0_oo0005ooooo`;oo`002Oooool3oomo00?oo`000_l00?lIooooo`;o0?l01oooool3oomo00?oo`00
2oooool3ool000Wooooo0_ooO`03ool000Wooooo0_ooO`03ool000?o003o1_ooool2oomo00Gooooo
0_ooO`0<ooooo`;oogl05oooool2o`3o00_ooooo00?oo`00o`3o0?l0o`002oooool2ool00003oooo
ool00?oo003o00Kooooo0_ooO`05ooooo`;oogl02Oooool3o`3o00Oooooo0_ooO`05ooooo`;oogl0
2?ooool2ool001[ooooo0_oo000<ooooo`;oo`003?ooool3ool000;o003o3?ooool2o`00o`Kooooo
0oooO`0hooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool2o`3o00;o003o1_ooool3oomo0004ool00?l0o`3o0?l0o`3o00Oooooo0oooO`02ool000Gooooo
0_oo0006ooooo`?o0?l00oooool2ool000Gooooo0_oo0009ooooo`?oogl00ooo0002o`00oaWooooo
0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`002Oooool2oomo00?oo`00
0ol00?l6ooooo`;oogl01Oooool2oomo00cooooo0_ooO`0Gooooo`;o0?l02oooool00ooo003o0?l0
o`3o000;ooooo`;oo`0000?oooooo`00ool00?l01_ooool2oomo00Gooooo0_ooO`09ooooo`?o0?l0
1oooool2oomo00oooooo0_oo000Jooooo`;oo`003?ooool2ool000cooooo0ooo0002o`00o`cooooo
0_l00?l6ooooo`?oogl0>?ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`03o`3o00_ooooo0_l0o`02o`00o`Kooooo0oooO`001?oo003o0?l0o`3o0?l0o`07ooooo`?oogl0
0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo0009ooooo`?oogl00ooo000Kooooo`;o0?l0
1oooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`03ool000Wooooo0_ooO`03ool000?o003o
1_ooool2oomo00Gooooo0_ooO`0<ooooo`;oogl05oooool2o`3o00_ooooo00?oo`00o`3o0?l0o`00
2oooool2ool00003ooooool00?oo003o00Kooooo0_ooO`05ooooo`;oogl02Oooool3o`3o00Oooooo
0_ooO`0?ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`003_ooool2o`00o`Kooooo
0oooO`0hooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00Oooooo0oooO`001?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo
0ol0o`0:ooooo`;oo`002Oooool3oomo00?oo`006oooool2o`3o00Oooooo0oooO`03ool000_ooooo
0ooo0009ooooo`;oogl00ooo0009ooooo`;oogl00ooo0009ooooo`;oogl01Oooool2oomo00cooooo
0_ooO`0Gooooo`;o0?l02oooool00ooo003o0?l0o`3o000;ooooo`;oo`0000?oooooo`00ool00?l0
1_ooool2oomo00Gooooo0_ooO`09ooooo`?o0?l01oooool2oomo00oooooo0_oo000Jooooo`;oo`00
3?ooool2ool000cooooo0ooo000>ooooo`;o003o1_ooool3oomo03Sooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l01oooool3oomo0004ool00?l0
o`3o0?l0o`3o00[ooooo0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo000<ooooo`?oo`00
6oooool2o`3o00Oooooo0oooO`03ool000_ooooo0ooo0009ooooo`;oogl00ooo0009ooooo`;oogl0
0ooo0009ooooo`;oogl01Oooool2oomo00cooooo0_ooO`0Gooooo`;o0?l02oooool00ooo003o0?l0
o`3o000;ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`09ooooo`?o0?l01oooool2oomo00oooooo
0_oo000Jooooo`;oo`003?ooool2ool000cooooo0ooo000>ooooo`;o003o1_ooool3oomo03Sooooo
00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`07ooooo`?oogl000Co
o`00o`3o0?l0o`3o0?l02_ooool2ool000Gooooo0_oo0006ooooo`?o0?l02_ooool2ool000cooooo
0ooo000Kooooo`;o0?l01oooool3oomo00?oo`002oooool3ool000Wooooo0_ooO`03ool000Wooooo
0_ooO`03ool000Wooooo0_ooO`05ooooo`;oogl03?ooool2oomo01Oooooo0_l0o`0;ooooo`03ool0
0?l0o`3o0?l000_ooooo0_oo0009ooooo`;oogl01Oooool2oomo00Wooooo0ol0o`07ooooo`;oogl0
3oooool2ool001[ooooo0_oo000<ooooo`;oo`003?ooool3ool000kooooo0_l00?l6ooooo`?oogl0
=oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00Oooooo0ooo
O`001?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo0ol0o`0:ooooo`;oo`00
3?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`00
2Oooool2oomo00?oo`002Oooool2oomo00Gooooo0_ooO`0<ooooo`;oogl05oooool2o`3o00_ooooo
00?oo`00o`3o0?l0o`002oooool2ool000Wooooo0_ooO`05ooooo`;oogl02Oooool3o`3o00Oooooo
0_ooO`0?ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`003_ooool2o`00o`Kooooo
0oooO`0hooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00Oooooo0oooO`001?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo
0ol0o`0:ooooo`;oo`003?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`00
2Oooool2oomo00?oo`002oooool3ool000Wooooo0_ooO`0Cooooo`;oogl05oooool2o`3o00_ooooo
00?oo`00o`3o0?l0o`002oooool2ool000Wooooo0_ooO`05ooooo`;oogl02Oooool3o`3o00Oooooo
0_ooO`0?ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`003_ooool2o`00o`Kooooo
0oooO`0hooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00Oooooo0oooO`001?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo
0ol0o`0:ooooo`;oo`003?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`00
2Oooool2oomo00?oo`002oooool3ool001kooooo0_ooO`0Gooooo`;o0?l02oooool00ooo003o0?l0
o`3o000;ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`09ooooo`?o0?l01oooool2oomo00oooooo
0_oo000Jooooo`;oo`003?ooool2ool000cooooo0ooo000>ooooo`;o003o1_ooool3oomo03Sooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l02_oo
ool01?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo0ol0o`0:ooooo`;oo`00
3?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`00
2oooool3ool003Oooooo0_l0o`0;ooooo`03ool00?l0o`3o0?l000_ooooo0_oo0009ooooo`;oogl0
1Oooool2oomo00Wooooo0ol0o`07ooooo`;oogl03oooool2ool001[ooooo0_oo000<ooooo`;oo`00
3?ooool3ool000kooooo0_l00?l6ooooo`?oogl0>?ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0:ooooo`04ool00?l0o`3o0?l0o`3o00[ooooo
0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo000<ooooo`?oo`006oooool2o`3o00Oooooo
0oooO`03ool000_ooooo0ooo0009ooooo`;oogl00ooo000;ooooo`?oo`00=oooool2o`3o00_ooooo
00?oo`00o`3o0?l0o`002oooool2ool000Wooooo0_ooO`05ooooo`;oogl02Oooool3o`3o00Oooooo
0_ooO`0?ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`005_ooool3oomo03Sooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l02_oo
ool01?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo0ol0o`0:ooooo`;oo`00
3?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`002Oooool2oomo00?oo`00
2oooool3ool003Oooooo0_l0o`0<ooooo`;o0?l02oooool2ool000Wooooo0_ooO`05ooooo`;oogl0
2Oooool3o`3o00Oooooo0_ooO`0?ooooo`;oo`006_ooool2ool000cooooo0_oo000<ooooo`?oo`00
5_ooool3oomo03Sooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l02_ooool01?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo
0ol0o`0:ooooo`;oo`003?ooool3ool001_ooooo0_l0o`07ooooo`?oogl00ooo000;ooooo`?oo`00
2Oooool2oomo00?oo`002oooool3ool003Oooooo0_l0o`0<ooooo`;o0?l02oooool2ool000Wooooo
0_ooO`05ooooo`;oogl02Oooool3o`3o01Sooooo0_oo000Jooooo`;oo`003?ooool2ool000cooooo
0ooo001Aooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00[ooooo00Coo`00o`3o0?l0o`3o0?l02_ooool2ool000Gooooo0_oo0006ooooo`?o0?l0
2_ooool2ool000cooooo0ooo000Kooooo`;o0?l01oooool3oomo00?oo`002oooool3ool000Wooooo
0_ooO`03ool000_ooooo0ooo000gooooo`;o0?l03?ooool2o`3o00_ooooo0_oo0009ooooo`;oogl0
4?ooool3o`3o01Sooooo0_oo000Jooooo`;oo`00K_ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0:ooooo`04ool00?l0o`3o0?l0o`3o00[ooooo
0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo000<ooooo`?oo`006oooool2o`3o00Oooooo
0oooO`03ool000_ooooo0ooo0009ooooo`;oogl00ooo000;ooooo`?oo`00=oooool2o`3o00cooooo
0_l0o`0;ooooo`;oo`006oooool3o`3o01Sooooo0_oo000Jooooo`;oo`00K_ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0:ooooo`04ool00?l0
o`3o0?l0o`3o00[ooooo0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo000<ooooo`?oo`00
6oooool2o`3o00[ooooo0ooo000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0
3?ooool2o`3o00_ooooo0_oo000Kooooo`?o0?l06?ooool2ool001[ooooo0_oo001^ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00[ooooo00Co
o`00o`3o0?l0o`3o0?l02_ooool2ool000Gooooo0_oo0006ooooo`?o0?l02_ooool2ool000cooooo
0ooo000Kooooo`;o0?l02_ooool3ool000_ooooo0ooo000;ooooo`?oo`002oooool3ool003Oooooo
0_l0o`0<ooooo`;o0?l02oooool2ool001_ooooo0ol0o`0Hooooo`;oo`006_ooool2ool006kooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l02_oo
ool01?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo0ol0o`0:ooooo`;oo`00
3?ooool3ool001_ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00
=oooool2o`3o00cooooo0_l0o`0;ooooo`;oo`006oooool3o`3o01Sooooo0_oo000Jooooo`;oo`00
K_ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000?o0?l02oooool3o`3o00[ooooo00Co
o`00o`3o0?l0o`3o0?l02_ooool2ool000Gooooo0_oo0006ooooo`?o0?l02_ooool2ool000cooooo
0ooo000Kooooo`;o0?l02_ooool3ool000_ooooo0ooo000;ooooo`?oo`002oooool3ool003Oooooo
0_l0o`0<ooooo`;o0?l02oooool2ool001_ooooo0ol0o`0Hooooo`;oo`006_ooool2ool006gooooo
0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0:ooooo`04ool00?l0
o`3o0?l0o`3o00[ooooo0_oo0005ooooo`;oo`001_ooool3o`3o00[ooooo0_oo000<ooooo`?oo`00
6oooool2o`3o00[ooooo0ooo000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0
6Oooool2ool001_ooooo0ol0o`0Hooooo`;oo`006_ooool2ool006kooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l02_ooool01?oo003o0?l0o`3o
0?l0o`0:ooooo`;oo`001Oooool2ool000Kooooo0ol0o`0:ooooo`;oo`003?ooool3ool001_ooooo
0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00=oooool2o`3o01Wooooo
0_oo000Kooooo`?o0?l06?ooool2ool001[ooooo0_oo001^ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00[ooooo00Coo`00o`3o0?l0o`3o0?l0
2_ooool2ool000Gooooo0_oo0006ooooo`?o0?l02_ooool2ool000cooooo0ooo000Kooooo`;o0?l0
2_ooool3ool000_ooooo0ooo000;ooooo`?oo`002oooool3ool003Oooooo0_l0o`0fooooo`?o0?l0
6?ooool2ool001[ooooo0_oo001^ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l02oooool3o`3o00[ooooo00Coo`00o`3o0?l0o`3o0?l02_ooool2ool000Gooooo
0_oo0006ooooo`?o0?l02_ooool2ool000cooooo0ooo000Kooooo`;o0?l02_ooool3ool000_ooooo
0ooo000;ooooo`?oo`002oooool3ool003Oooooo0_l0o`0fooooo`?o0?l06?ooool2ool001[ooooo
0_oo001^ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02ooo
ool3o`3o00[ooooo00Coo`00o`3o0?l0o`3o0?l02_ooool2ool000gooooo0ol0o`0:ooooo`;oo`00
3?ooool3ool001_ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00
=oooool2o`3o03Kooooo0ol0o`0Hooooo`;oo`006_ooool2ool006kooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l02_ooool01?oo003o0?l0o`3o
0?l0o`0:ooooo`;oo`003Oooool3o`3o00[ooooo0_oo000<ooooo`?oo`006oooool2o`3o00[ooooo
0ooo000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0=_ooool3o`3o01Sooooo
0_oo000Jooooo`;oo`00K_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`03o`3o00_ooooo0ol0o`0:ooooo`04ool00?l0o`3o0?l0o`3o00[ooooo0_oo000=ooooo`?o0?l0
2_ooool2ool000cooooo0ooo000Kooooo`;o0?l02_ooool3ool000_ooooo0ooo000;ooooo`?oo`00
2oooool3ool003Oooooo0_l0o`0fooooo`?o0?l06?ooool2ool001[ooooo0_oo001^ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00[ooooo00Co
o`00o`3o0?l0o`3o0?l02_ooool2ool000gooooo0ol0o`0:ooooo`;oo`003?ooool3ool001_ooooo
0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00=oooool2o`3o03Kooooo
0ol0o`0Hooooo`;oo`006_ooool2ool006kooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`0;ooooo`?o0?l02_ooool01?oo003o0?l0o`3o0?l0o`0:ooooo`;oo`00
3Oooool3o`3o00[ooooo0_oo000<ooooo`?oo`006oooool2o`3o00[ooooo0ooo000;ooooo`?oo`00
2oooool3ool000_ooooo0ooo000gooooo`;o0?l0=_ooool3o`3o01Sooooo0_oo000Jooooo`;oo`00
K_ooool00ol0003oooooooooo`09ooooo`002_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol00007ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o00[ooooo0_oo
000<ooooo`;oo`003Oooool3o`3o00[ooooo0_oo000<ooooo`?oo`006oooool2o`3o00[ooooo0ooo
000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0=_ooool3o`3o01Sooooo0_oo
000Jooooo`;oo`00K_ooool00ol0003oooooooooo`09ooooo`002Oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?o0?l02oooool3o`3o01Sooooo0_oo000=ooooo`?o0?l02_ooool2ool000co
oooo0ooo000Kooooo`;o0?l02_ooool3ool000_ooooo0ooo000;ooooo`?oo`002oooool3ool003Oo
oooo0_l0o`0fooooo`?o0?l0=?ooool2ool006kooooo00?o0000ooooooooool02Oooool000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l06?ooool2ool000gooooo0ol0o`0:oooo
o`;oo`003?ooool3ool001_ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;oooo
o`?oo`00=oooool2o`3o03Kooooo0ol0o`0dooooo`;oo`00K_ooool00ol0003oooooooooo`09oooo
o`002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool01?ooool3o`0000?o0?l02oooool3o`3o01Sooooo0_oo000=ooooo`?o0?l02_ooool2
ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00=oooool2
o`3o03Kooooo0ol0o`0dooooo`;oo`00K?ooool3o`0000_ooooo0009ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Oooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l06?ooool2ool000gooooo0ol0o`0:ooooo`;oo`00:_ooool2o`3o00[ooooo0ooo
000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0=_ooool3o`3o03Cooooo0_oo
001^ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool0000:ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o01So
oooo0_oo000=ooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_o
oooo0ooo000;ooooo`?oo`00=oooool2o`3o03Kooooo0ol0o`0dooooo`;oo`00K_ooool00ol0003o
ooooooooo`09ooooo`002_ooool2o`0000[ooooo0_l00002ooooo`Go00001_ooool00ol0003ooooo
ooooo`03o`3o00_ooooo0ol0o`0Hooooo`;oo`003Oooool3o`3o00[ooooo0_oo000Zooooo`;o0?l0
2_ooool3ool000_ooooo0ooo000;ooooo`?oo`002oooool3ool003Oooooo0_l0o`0fooooo`?o0?l0
=?ooool2ool006kooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l06?ooool2ool000gooooo0ol0o`0:ooooo`;oo`00:_ooool2o`3o00[ooooo0ooo
000;ooooo`?oo`002oooool3ool000_ooooo0ooo000gooooo`;o0?l0=_ooool3o`3o03Cooooo0_oo
001^ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3
o`3o01Sooooo0_oo000=ooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3
ool000_ooooo0ooo000;ooooo`?oo`00=oooool2o`3o03Kooooo0ol0o`0dooooo`;oo`00K_ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Woooo
o`?o0?l02_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;oooo
o`?oo`00=oooool2o`3o03Kooooo0ol0o`0dooooo`;oo`00K_ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l02_ooool2ool002[o
oooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo000;ooooo`?oo`00=oooool2o`3o03Ko
oooo0ol0o`0dooooo`;oo`00K_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`00
2oooool3ool000_ooooo0ooo000;ooooo`?oo`00=oooool2o`3o03Kooooo0ol0o`0dooooo`;oo`00
K_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0
o`0Wooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo
0015ooooo`;o0?l0KOooool2ool006kooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o00[ooooo0_oo000Zooooo`;o0?l02_ooool3
ool000_ooooo0ooo000;ooooo`?oo`00AOooool2o`3o06gooooo0_oo001^ooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0:oooo
o`;oo`00:_ooool2o`3o00[ooooo0ooo000;ooooo`?oo`002oooool3ool004Gooooo0_l0o`3Moooo
o`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`0;ooooo`?o0?l09oooool3o`3o00[o
oooo0_oo000Zooooo`;o0?l02_ooool3ool000_ooooo0ooo000;ooooo`?oo`00AOooool2o`3o0=co
oooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0
2_ooool2ool002[ooooo0_l0o`0:ooooo`?oo`002oooool3ool000_ooooo0ooo0015ooooo`;o0?l0
gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0
o`0Wooooo`?o0?l02_ooool2ool002[ooooo0_l0o`0Hooooo`?oo`002oooool3ool004Gooooo0_l0
o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3
o`3o02Oooooo0ol0o`0:ooooo`;oo`00:_ooool2o`3o01Sooooo0ooo000;ooooo`?oo`00AOooool2
o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;oooo
o`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`002oooool3ool004Gooooo0_l0o`3Moooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oo
oooo0ol0o`0fooooo`;o0?l06?ooool3ool000_ooooo0ooo0015ooooo`;o0?l0gOooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0
=_ooool2o`3o01Sooooo0ooo000;ooooo`?oo`00AOooool2o`3o0=gooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0
o`0Hooooo`?oo`002oooool3ool004Gooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l06?ooool3
ool000_ooooo0ooo0015ooooo`;o0?l0gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o01Sooooo0ooo000;oooo
o`?oo`00AOooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`002oooool3ool004Go
oooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
2oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l06?ooool3ool000_ooooo0ooo0015ooooo`;o0?l0
gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0
o`0Wooooo`?o0?l0=_ooool2o`3o01Sooooo0ooo000;ooooo`?oo`00AOooool2o`3o0=gooooo00?o
0000ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2
o`3o01Sooooo0ooo000;ooooo`?oo`00AOooool2o`3o0=cooooo0_l0000;ooooo`009Oooool00ol0
003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o01Sooooo0ooo000;oooo
o`?oo`00AOooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`002oooool3ool004Go
oooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
2oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l06?ooool3ool000_ooooo0ooo0015ooooo`;o0?l0
gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0
o`0Wooooo`?o0?l0=_ooool2o`3o01Sooooo0ooo000;ooooo`?oo`00AOooool2o`3o0=gooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3
o`3o03Kooooo0_l0o`0Hooooo`?oo`002oooool3ool004Gooooo0_l0o`3Mooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0foooo
o`;o0?l06?ooool3ool000_ooooo0ooo0015ooooo`;o0?l0gOooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o01So
oooo0ooo000;ooooo`?oo`00AOooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`00
Doooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`00Doooool2o`3o0=gooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3
o`3o03Kooooo0_l0o`0Hooooo`?oo`00Doooool2o`3o0=gooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hoooo
o`?oo`00Doooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`0Hooooo`?oo`00Doooool2o`3o0=go
oooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o00_ooooo0ol0o`0Wooooo`?o0?l0
=_ooool2o`3o01Sooooo0ooo001Cooooo`;o0?l0g?ooool2o`0000_ooooo000Uooooo`03o`000?oo
oooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l06?ooool3ool005?ooooo0_l0
o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3
o`3o02Oooooo0ol0o`0fooooo`;o0?l0K_ooool2o`3o0=gooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`1^oooo
o`;o0?l0gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_o
oooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o06kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l0
K_ooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`1^ooooo`;o0?l0gOooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2
o`3o06kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l0K_ooool2o`3o0=gooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Ko
oooo0_l0o`1^ooooo`;o0?l0gOooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o06kooooo0_l0o`3Mooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0
o`0fooooo`;o0?l0K_ooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`1^ooooo`;o0?l0gOooool0
0ol0003oooooooooo`09ooooo`009Oooool3o`0000?o0?l02oooool3o`3o02Oooooo0ol0o`0foooo
o`;o0?l0K_ooool2o`3o0=cooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o00_o
oooo0ol0o`0Wooooo`?o0?l0=_ooool2o`3o06kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l0
K_ooool2o`3o0=gooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0;ooooo`?o0?l09oooool3o`3o03Kooooo0_l0o`1^ooooo`;o0?l0gOooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0=_ooool2
o`3o06kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o02Oooooo0ol0o`0fooooo`;o0?l0K_ooool2o`3o0=gooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3o`3o0:Ko
oooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
2oooool3o`3o02Oooooo0ol0o`2Vooooo`;o0?l0gOooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0Y_ooool2o`3o0=gooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0;ooooo`?o0?l09oooool3
o`3o0:Kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l02oooool3o`3o02Oooooo0ol0o`2Vooooo`;o0?l0gOooool00ol0003oooooooooo`09oooo
o`004?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000oooooooo
ool00ol0o`0;ooooo`?o0?l09oooool3o`3o0:Kooooo0_l0o`3Mooooo`03o`000?oooooooooo00Wo
oooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Wo
oooo000?ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000?o
0?l02oooool3o`3o02Oooooo0ol0o`3oooooohCooooo0ol0000;ooooo`003oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ol0o`0;ooooo`?o
0?l09oooool3o`3o0?ooooooQ_ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ol0o`0;ooooo`?o
0?l09oooool3o`3o0?ooooooQ_ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003ooooo
ooooool00008ooooo`;o00002?ooool00ol0003oooooooooo`03o`3o00_ooooo0ol0o`0Wooooo`?o
0?l0oooooon6ooooo`03o`000?oooooooooo00Wooooo000@ooooo`;o00002_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o0?ooooooQ_ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o
0?ooooooQ_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Go
oooo0ol0o`3oooooohKooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool0
0ol0o`0eooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0=Oooool3o`3o0?ooooooQ_ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo
00Wooooo000Uooooo`?o00000ol0o`0eooooo`?o0?l0oooooon5ooooo`;o00002oooool002Gooooo
00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o0?ooooooQ_ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6oooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o0?oo
ooooQ_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo
0ol0o`3oooooohKooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0
o`0eooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0=Oooool3o`3o0?ooooooQ_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o0?ooooooQ_ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o
0000ooooooooool02Oooool002Gooooo0ol00003o`3o03Gooooo0ol0o`3oooooohGooooo0_l0000;
ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo0ol0o`3oooooohKooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`0eooooo`?o0?l0oooooon6ooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0=Oooool3o`3o0?oooooo
Q_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o03Gooooo0ol0
o`3oooooohKooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo0ol00003o`3o0?oooooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`?o00000ol0o`3ooooookgooooo0_l0000;ooooo`009Oooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo
__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`002_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo0ol00007ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0ol00003o`3o0?oooooo_?ooool3o`0000_ooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l00007ooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?oooooooooo
o`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool02Oooool000[ooooo0_l0000:ooooo`04o`000?oooooooooo
ooooo`Go00001_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000?o0?l0oooo
oonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Gooooo0ol00003o`3o0?oo
oooo_Oooool2o`0000_ooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00Wooooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wo
oooo000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo
000Uooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000U
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uoooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000Uooooo`?o00000ol0o`3o
oooookgooooo0_l0000;ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`09ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Oooool3o`0000?o0?l0
oooooonmooooo`;o00002oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool02Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Ooo
ool002Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool002Go
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0013ooooo
0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`09ooooo`003oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool02Oooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00Wooooo000?ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool3o`0000?o0?l0oooooonloooo
o`?o00002oooool000oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0
00oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool02Oooool0013ooooo0_l00009
ooooo`?o00001oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09oooo
o`009Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`00
9Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`09ooooo`009Ooo
ool00ol0003oooooooooo`3ooooool7ooooo00?o0000ooooooooool02Oooool002Gooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo
0?oooooo`Oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`009Oooooooo`000<Go00002oooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool002Sooooo0ol00003ooooo`Go00000oooool3o`0000Gooooo0ol00003ooooo`?o00001?ooool3
o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Cooooo0_l00002ooooo`?o00001?ooool3
o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000Cooooo0ol00003ooooo`Co00000oooool4
o`0000Cooooo0ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go000000?ooooo
o`000?l000001?l00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5
o`0000;ooooo1Ol00002ooooo`Co00001?ooool3o`0000?ooooo1?l00002ooooo`Go00000oooool4
o`0000Cooooo0ol00003ooooo`Go00000oooool4o`0000Cooooo0ol00003ooooo`Co00000oooool5
o`0000?ooooo1?l00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go00000oooool4
o`0000;ooooo1Ol00002ooooo`Go00000oooool4o`0000;ooooo1Ol00002ooooo`Co00001?ooool3
o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000Cooooo0ol00003ooooo`Co00000oooool4
o`0000Cooooo0ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00003ooooo`Co00000_ooool5
o`0000?ooooo1?l00004ooooo`?o00002oooool002Wooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Cooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooooooo`02o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00;o
00001?ooool2o`000004ooooool0003oooooooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o
00000oooool2o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003o
ooooo`000?ooool00_l00003ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo
00;o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002
ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo00ko0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;o
oooo0_l00004ooooo`;o00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ool0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000
oooooooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`06o`000?oo
oooo0000ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002ooooo`05o`000?oooooo0000
ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool00ol0003ooooooooo
o`0:ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Ol00006ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000004ooooo`04o`000?oooooo0000o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000;o
oooo1Ol00005ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00001Oooool2o`0000?ooooo00Co0000ooooool0003o00001?ooool2
o`0000Gooooo0_l00006ooooo`;o00000_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooo
oooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00006ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00005ooooo`;o000000?oooooo`000?l000001?l00005ooooo`05o`000?oooooo0000oooo
ool000000oooool2o`0000Cooooo00Go0000ooooool0003oooooo`000003ooooo`;o00000_ooool5
o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooooooo0000o`000004
o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol000000ooooooo0000o`000004
o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo
0_l000000ooooooo0000ooooo`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?o
oooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool01?l0003oooooooooool00002oooo
o`;o000000?oooooo`000?l000000ol0000;ooooo`00:Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool01?l00006ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`Co000000?oooooo`00
0?ooool00oooool01?l0003oooooo`000?l00004ooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`;o00000oooool01?l0003oooooooooool00006ooooo`;o00000_ooool4o`0000Kooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000001Oooool2o`0000Cooooo0ol00002ooooo`03o`000?oooooooooo00;o0000
1_ooool00ol0003oooooooooo`05o`0000Gooooo0_l00003ooooo`Co00000oooool4o`0000?ooooo
00Co0000ooooool0003o00001?ooool3o`0000Gooooo0_l00004ooooo`?o00000_ooool00ol0003o
ooooooooo`02o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co
00000oooool01?l0003oooooooooool00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0
003oooooo`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo00Co0000
oooooooooooo00000_ooool5o`0000?ooooo00Co0000ooooool0003o00000oooool4o`0000?ooooo
1Ol00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooo000000?ooooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo0000
00Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00?ooooo00?o0000oooo
ool000000_ooool3o`000004ooooool0003oooooooooo`Co00000oooool4o`0000?ooooo1?l00003
ooooo`Co00000oooool4o`0000;ooooo00Co0000oooooooooooo00003?ooool002Wooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000Cooooo00Co0000
ooooool0003o00001?ooool2o`0000?ooooo00?o0000ooooooooool00_l00005ooooo`;o00000ooo
ool00ol0003oooooo`000003ooooo`Co00000oooool01?l0003oooooooooool00006ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002ooooo`03
o`000?oooooooooo00;o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Co000000?ooooo
o`000?ooool00_l00003ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
0003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool2o`0000Gooooo0_l00002ooooo`06
o`000?oooooo0000ooooool0003ooooo1?l00002ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool00oooool2o`000003ooooool0003ooooo00;ooooo0_l000001_oooooo0000ooooool0
003oooooo`0000?ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooool0003oooooo`000004ooooo`03o`000?oooooo000000?ooooo1?l00002ooooo`Go
00000_ooool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000_ooool01Ol0
003oooooo`000?oooooo000000;ooooo1Ol00003ooooo`Co00000oooool4o`0000;ooooo1Ol00003
ooooo`Co00000oooool4o`0000;ooooo1Ol00002ooooo`Go00000oooool4o`0000;ooooo1Ol00002
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo
0_l00004ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000cooooo000Xooooo`;o00001?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooooooool3o`0000Cooooo1?l00003oooo
o`?o00000oooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooool000000_l00004oooo
o`;o00000oooool01?l0003oooooo`000?l00004ooooo`?o00000oooool00ol0003oooooo`000002
o`0000;ooooo00?o0000ooooool000000_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000
ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`?o000000Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo00Co0000ooooool0003o00000oooool4
o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o00001?ooool3
o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooo0000o`0000;ooooo00?o
0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000;o
oooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooooooo`?o00000oooool2o`00
00Kooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool00_l00002oooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool00003ooooo`;o000000?oooooo`000?ooool0
0_ooool2o`0000Cooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000oooo
ool000001?ooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`?o
00001_ooool01?l0003oooooooooooooool5o`0000Cooooo0_l00003ooooo`Go00000oooool3o`00
00Cooooo0ol00002ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001?ooool3o`00
00Cooooo0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003
ooooo`?o00001?ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004
ooooo`?o00000_ooool5o`0000Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004
ooooo`?o00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000;ooooo1_l00004
ooooo`?o00000_ooool5o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000Cooooo00?o0000
ooooool000000oooool4o`0000?ooooo1?l00005ooooo`;o00000_ooool5o`0000Cooooo0ol00002
ooooo`Go00000oooool4o`0000?ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002
ooooo`Go00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o
000000Co00000_ooool5o`0000;ooooo1?l00004ooooo`?o00001?ooool3o`0000?ooooo1?l00003
ooooo`Co00001Oooool00ol0003oooooooooo`0:ooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-4.70015, -0.0164288, 0.142355, \
0.000772209}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 500 309.017 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0109034 0.0155763 0.0147151 1.29094 [
[.00935 -0.0125 -3 -9 ]
[.00935 -0.0125 3 0 ]
[.02492 -0.0125 -3 -9 ]
[.02492 -0.0125 3 0 ]
[.0405 -0.0125 -3 -9 ]
[.0405 -0.0125 3 0 ]
[.05607 -0.0125 -3 -9 ]
[.05607 -0.0125 3 0 ]
[.07165 -0.0125 -3 -9 ]
[.07165 -0.0125 3 0 ]
[.08723 -0.0125 -3 -9 ]
[.08723 -0.0125 3 0 ]
[.1028 -0.0125 -3 -9 ]
[.1028 -0.0125 3 0 ]
[.11838 -0.0125 -3 -9 ]
[.11838 -0.0125 3 0 ]
[.13396 -0.0125 -3 -9 ]
[.13396 -0.0125 3 0 ]
[.14953 -0.0125 -6 -9 ]
[.14953 -0.0125 6 0 ]
[.16511 -0.0125 -6 -9 ]
[.16511 -0.0125 6 0 ]
[.18069 -0.0125 -6 -9 ]
[.18069 -0.0125 6 0 ]
[.19626 -0.0125 -6 -9 ]
[.19626 -0.0125 6 0 ]
[.21184 -0.0125 -6 -9 ]
[.21184 -0.0125 6 0 ]
[.22741 -0.0125 -6 -9 ]
[.22741 -0.0125 6 0 ]
[.24299 -0.0125 -6 -9 ]
[.24299 -0.0125 6 0 ]
[.25857 -0.0125 -6 -9 ]
[.25857 -0.0125 6 0 ]
[.27414 -0.0125 -6 -9 ]
[.27414 -0.0125 6 0 ]
[.28972 -0.0125 -6 -9 ]
[.28972 -0.0125 6 0 ]
[.3053 -0.0125 -6 -9 ]
[.3053 -0.0125 6 0 ]
[.32087 -0.0125 -6 -9 ]
[.32087 -0.0125 6 0 ]
[.33645 -0.0125 -6 -9 ]
[.33645 -0.0125 6 0 ]
[.35202 -0.0125 -6 -9 ]
[.35202 -0.0125 6 0 ]
[.3676 -0.0125 -6 -9 ]
[.3676 -0.0125 6 0 ]
[.38318 -0.0125 -6 -9 ]
[.38318 -0.0125 6 0 ]
[.39875 -0.0125 -6 -9 ]
[.39875 -0.0125 6 0 ]
[.41433 -0.0125 -6 -9 ]
[.41433 -0.0125 6 0 ]
[.42991 -0.0125 -6 -9 ]
[.42991 -0.0125 6 0 ]
[.44548 -0.0125 -6 -9 ]
[.44548 -0.0125 6 0 ]
[.46106 -0.0125 -6 -9 ]
[.46106 -0.0125 6 0 ]
[.47664 -0.0125 -6 -9 ]
[.47664 -0.0125 6 0 ]
[.49221 -0.0125 -6 -9 ]
[.49221 -0.0125 6 0 ]
[.50779 -0.0125 -6 -9 ]
[.50779 -0.0125 6 0 ]
[.52336 -0.0125 -6 -9 ]
[.52336 -0.0125 6 0 ]
[.53894 -0.0125 -6 -9 ]
[.53894 -0.0125 6 0 ]
[.55452 -0.0125 -6 -9 ]
[.55452 -0.0125 6 0 ]
[.57009 -0.0125 -6 -9 ]
[.57009 -0.0125 6 0 ]
[.58567 -0.0125 -6 -9 ]
[.58567 -0.0125 6 0 ]
[.60125 -0.0125 -6 -9 ]
[.60125 -0.0125 6 0 ]
[.61682 -0.0125 -6 -9 ]
[.61682 -0.0125 6 0 ]
[.6324 -0.0125 -6 -9 ]
[.6324 -0.0125 6 0 ]
[.64798 -0.0125 -6 -9 ]
[.64798 -0.0125 6 0 ]
[.66355 -0.0125 -6 -9 ]
[.66355 -0.0125 6 0 ]
[.67913 -0.0125 -6 -9 ]
[.67913 -0.0125 6 0 ]
[.6947 -0.0125 -6 -9 ]
[.6947 -0.0125 6 0 ]
[.71028 -0.0125 -6 -9 ]
[.71028 -0.0125 6 0 ]
[.72586 -0.0125 -6 -9 ]
[.72586 -0.0125 6 0 ]
[.74143 -0.0125 -6 -9 ]
[.74143 -0.0125 6 0 ]
[.75701 -0.0125 -6 -9 ]
[.75701 -0.0125 6 0 ]
[.77259 -0.0125 -6 -9 ]
[.77259 -0.0125 6 0 ]
[.78816 -0.0125 -6 -9 ]
[.78816 -0.0125 6 0 ]
[.80374 -0.0125 -6 -9 ]
[.80374 -0.0125 6 0 ]
[.81931 -0.0125 -6 -9 ]
[.81931 -0.0125 6 0 ]
[.83489 -0.0125 -6 -9 ]
[.83489 -0.0125 6 0 ]
[.85047 -0.0125 -6 -9 ]
[.85047 -0.0125 6 0 ]
[.86604 -0.0125 -6 -9 ]
[.86604 -0.0125 6 0 ]
[.88162 -0.0125 -6 -9 ]
[.88162 -0.0125 6 0 ]
[.8972 -0.0125 -6 -9 ]
[.8972 -0.0125 6 0 ]
[.91277 -0.0125 -6 -9 ]
[.91277 -0.0125 6 0 ]
[.92835 -0.0125 -6 -9 ]
[.92835 -0.0125 6 0 ]
[.94393 -0.0125 -6 -9 ]
[.94393 -0.0125 6 0 ]
[.9595 -0.0125 -6 -9 ]
[.9595 -0.0125 6 0 ]
[.97508 -0.0125 -6 -9 ]
[.97508 -0.0125 6 0 ]
[.99065 -0.0125 -6 -9 ]
[.99065 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14381 -18 -4.5 ]
[-0.0125 .14381 0 4.5 ]
[-0.0125 .2729 -18 -4.5 ]
[-0.0125 .2729 0 4.5 ]
[-0.0125 .402 -18 -4.5 ]
[-0.0125 .402 0 4.5 ]
[-0.0125 .53109 -18 -4.5 ]
[-0.0125 .53109 0 4.5 ]
[ 0 0 -0.125 0 ]
[.00935 .63053 -3 0 ]
[.00935 .63053 3 9 ]
[.02492 .63053 -3 0 ]
[.02492 .63053 3 9 ]
[.0405 .63053 -3 0 ]
[.0405 .63053 3 9 ]
[.05607 .63053 -3 0 ]
[.05607 .63053 3 9 ]
[.07165 .63053 -3 0 ]
[.07165 .63053 3 9 ]
[.08723 .63053 -3 0 ]
[.08723 .63053 3 9 ]
[.1028 .63053 -3 0 ]
[.1028 .63053 3 9 ]
[.11838 .63053 -3 0 ]
[.11838 .63053 3 9 ]
[.13396 .63053 -3 0 ]
[.13396 .63053 3 9 ]
[.14953 .63053 -6 0 ]
[.14953 .63053 6 9 ]
[.16511 .63053 -6 0 ]
[.16511 .63053 6 9 ]
[.18069 .63053 -6 0 ]
[.18069 .63053 6 9 ]
[.19626 .63053 -6 0 ]
[.19626 .63053 6 9 ]
[.21184 .63053 -6 0 ]
[.21184 .63053 6 9 ]
[.22741 .63053 -6 0 ]
[.22741 .63053 6 9 ]
[.24299 .63053 -6 0 ]
[.24299 .63053 6 9 ]
[.25857 .63053 -6 0 ]
[.25857 .63053 6 9 ]
[.27414 .63053 -6 0 ]
[.27414 .63053 6 9 ]
[.28972 .63053 -6 0 ]
[.28972 .63053 6 9 ]
[.3053 .63053 -6 0 ]
[.3053 .63053 6 9 ]
[.32087 .63053 -6 0 ]
[.32087 .63053 6 9 ]
[.33645 .63053 -6 0 ]
[.33645 .63053 6 9 ]
[.35202 .63053 -6 0 ]
[.35202 .63053 6 9 ]
[.3676 .63053 -6 0 ]
[.3676 .63053 6 9 ]
[.38318 .63053 -6 0 ]
[.38318 .63053 6 9 ]
[.39875 .63053 -6 0 ]
[.39875 .63053 6 9 ]
[.41433 .63053 -6 0 ]
[.41433 .63053 6 9 ]
[.42991 .63053 -6 0 ]
[.42991 .63053 6 9 ]
[.44548 .63053 -6 0 ]
[.44548 .63053 6 9 ]
[.46106 .63053 -6 0 ]
[.46106 .63053 6 9 ]
[.47664 .63053 -6 0 ]
[.47664 .63053 6 9 ]
[.49221 .63053 -6 0 ]
[.49221 .63053 6 9 ]
[.50779 .63053 -6 0 ]
[.50779 .63053 6 9 ]
[.52336 .63053 -6 0 ]
[.52336 .63053 6 9 ]
[.53894 .63053 -6 0 ]
[.53894 .63053 6 9 ]
[.55452 .63053 -6 0 ]
[.55452 .63053 6 9 ]
[.57009 .63053 -6 0 ]
[.57009 .63053 6 9 ]
[.58567 .63053 -6 0 ]
[.58567 .63053 6 9 ]
[.60125 .63053 -6 0 ]
[.60125 .63053 6 9 ]
[.61682 .63053 -6 0 ]
[.61682 .63053 6 9 ]
[.6324 .63053 -6 0 ]
[.6324 .63053 6 9 ]
[.64798 .63053 -6 0 ]
[.64798 .63053 6 9 ]
[.66355 .63053 -6 0 ]
[.66355 .63053 6 9 ]
[.67913 .63053 -6 0 ]
[.67913 .63053 6 9 ]
[.6947 .63053 -6 0 ]
[.6947 .63053 6 9 ]
[.71028 .63053 -6 0 ]
[.71028 .63053 6 9 ]
[.72586 .63053 -6 0 ]
[.72586 .63053 6 9 ]
[.74143 .63053 -6 0 ]
[.74143 .63053 6 9 ]
[.75701 .63053 -6 0 ]
[.75701 .63053 6 9 ]
[.77259 .63053 -6 0 ]
[.77259 .63053 6 9 ]
[.78816 .63053 -6 0 ]
[.78816 .63053 6 9 ]
[.80374 .63053 -6 0 ]
[.80374 .63053 6 9 ]
[.81931 .63053 -6 0 ]
[.81931 .63053 6 9 ]
[.83489 .63053 -6 0 ]
[.83489 .63053 6 9 ]
[.85047 .63053 -6 0 ]
[.85047 .63053 6 9 ]
[.86604 .63053 -6 0 ]
[.86604 .63053 6 9 ]
[.88162 .63053 -6 0 ]
[.88162 .63053 6 9 ]
[.8972 .63053 -6 0 ]
[.8972 .63053 6 9 ]
[.91277 .63053 -6 0 ]
[.91277 .63053 6 9 ]
[.92835 .63053 -6 0 ]
[.92835 .63053 6 9 ]
[.94393 .63053 -6 0 ]
[.94393 .63053 6 9 ]
[.9595 .63053 -6 0 ]
[.9595 .63053 6 9 ]
[.97508 .63053 -6 0 ]
[.97508 .63053 6 9 ]
[.99065 .63053 -6 0 ]
[.99065 .63053 6 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00935 0 m
.00935 .00625 L
s
[(1)] .00935 -0.0125 0 1 Mshowa
.02492 0 m
.02492 .00625 L
s
[(2)] .02492 -0.0125 0 1 Mshowa
.0405 0 m
.0405 .00625 L
s
[(3)] .0405 -0.0125 0 1 Mshowa
.05607 0 m
.05607 .00625 L
s
[(4)] .05607 -0.0125 0 1 Mshowa
.07165 0 m
.07165 .00625 L
s
[(5)] .07165 -0.0125 0 1 Mshowa
.08723 0 m
.08723 .00625 L
s
[(6)] .08723 -0.0125 0 1 Mshowa
.1028 0 m
.1028 .00625 L
s
[(7)] .1028 -0.0125 0 1 Mshowa
.11838 0 m
.11838 .00625 L
s
[(8)] .11838 -0.0125 0 1 Mshowa
.13396 0 m
.13396 .00625 L
s
[(9)] .13396 -0.0125 0 1 Mshowa
.14953 0 m
.14953 .00625 L
s
[(10)] .14953 -0.0125 0 1 Mshowa
.16511 0 m
.16511 .00625 L
s
[(11)] .16511 -0.0125 0 1 Mshowa
.18069 0 m
.18069 .00625 L
s
[(12)] .18069 -0.0125 0 1 Mshowa
.19626 0 m
.19626 .00625 L
s
[(13)] .19626 -0.0125 0 1 Mshowa
.21184 0 m
.21184 .00625 L
s
[(14)] .21184 -0.0125 0 1 Mshowa
.22741 0 m
.22741 .00625 L
s
[(15)] .22741 -0.0125 0 1 Mshowa
.24299 0 m
.24299 .00625 L
s
[(16)] .24299 -0.0125 0 1 Mshowa
.25857 0 m
.25857 .00625 L
s
[(17)] .25857 -0.0125 0 1 Mshowa
.27414 0 m
.27414 .00625 L
s
[(18)] .27414 -0.0125 0 1 Mshowa
.28972 0 m
.28972 .00625 L
s
[(19)] .28972 -0.0125 0 1 Mshowa
.3053 0 m
.3053 .00625 L
s
[(20)] .3053 -0.0125 0 1 Mshowa
.32087 0 m
.32087 .00625 L
s
[(21)] .32087 -0.0125 0 1 Mshowa
.33645 0 m
.33645 .00625 L
s
[(22)] .33645 -0.0125 0 1 Mshowa
.35202 0 m
.35202 .00625 L
s
[(23)] .35202 -0.0125 0 1 Mshowa
.3676 0 m
.3676 .00625 L
s
[(24)] .3676 -0.0125 0 1 Mshowa
.38318 0 m
.38318 .00625 L
s
[(25)] .38318 -0.0125 0 1 Mshowa
.39875 0 m
.39875 .00625 L
s
[(26)] .39875 -0.0125 0 1 Mshowa
.41433 0 m
.41433 .00625 L
s
[(27)] .41433 -0.0125 0 1 Mshowa
.42991 0 m
.42991 .00625 L
s
[(28)] .42991 -0.0125 0 1 Mshowa
.44548 0 m
.44548 .00625 L
s
[(29)] .44548 -0.0125 0 1 Mshowa
.46106 0 m
.46106 .00625 L
s
[(30)] .46106 -0.0125 0 1 Mshowa
.47664 0 m
.47664 .00625 L
s
[(31)] .47664 -0.0125 0 1 Mshowa
.49221 0 m
.49221 .00625 L
s
[(32)] .49221 -0.0125 0 1 Mshowa
.50779 0 m
.50779 .00625 L
s
[(33)] .50779 -0.0125 0 1 Mshowa
.52336 0 m
.52336 .00625 L
s
[(34)] .52336 -0.0125 0 1 Mshowa
.53894 0 m
.53894 .00625 L
s
[(35)] .53894 -0.0125 0 1 Mshowa
.55452 0 m
.55452 .00625 L
s
[(36)] .55452 -0.0125 0 1 Mshowa
.57009 0 m
.57009 .00625 L
s
[(37)] .57009 -0.0125 0 1 Mshowa
.58567 0 m
.58567 .00625 L
s
[(38)] .58567 -0.0125 0 1 Mshowa
.60125 0 m
.60125 .00625 L
s
[(39)] .60125 -0.0125 0 1 Mshowa
.61682 0 m
.61682 .00625 L
s
[(40)] .61682 -0.0125 0 1 Mshowa
.6324 0 m
.6324 .00625 L
s
[(41)] .6324 -0.0125 0 1 Mshowa
.64798 0 m
.64798 .00625 L
s
[(42)] .64798 -0.0125 0 1 Mshowa
.66355 0 m
.66355 .00625 L
s
[(43)] .66355 -0.0125 0 1 Mshowa
.67913 0 m
.67913 .00625 L
s
[(44)] .67913 -0.0125 0 1 Mshowa
.6947 0 m
.6947 .00625 L
s
[(45)] .6947 -0.0125 0 1 Mshowa
.71028 0 m
.71028 .00625 L
s
[(46)] .71028 -0.0125 0 1 Mshowa
.72586 0 m
.72586 .00625 L
s
[(47)] .72586 -0.0125 0 1 Mshowa
.74143 0 m
.74143 .00625 L
s
[(48)] .74143 -0.0125 0 1 Mshowa
.75701 0 m
.75701 .00625 L
s
[(49)] .75701 -0.0125 0 1 Mshowa
.77259 0 m
.77259 .00625 L
s
[(50)] .77259 -0.0125 0 1 Mshowa
.78816 0 m
.78816 .00625 L
s
[(51)] .78816 -0.0125 0 1 Mshowa
.80374 0 m
.80374 .00625 L
s
[(52)] .80374 -0.0125 0 1 Mshowa
.81931 0 m
.81931 .00625 L
s
[(53)] .81931 -0.0125 0 1 Mshowa
.83489 0 m
.83489 .00625 L
s
[(54)] .83489 -0.0125 0 1 Mshowa
.85047 0 m
.85047 .00625 L
s
[(55)] .85047 -0.0125 0 1 Mshowa
.86604 0 m
.86604 .00625 L
s
[(56)] .86604 -0.0125 0 1 Mshowa
.88162 0 m
.88162 .00625 L
s
[(57)] .88162 -0.0125 0 1 Mshowa
.8972 0 m
.8972 .00625 L
s
[(58)] .8972 -0.0125 0 1 Mshowa
.91277 0 m
.91277 .00625 L
s
[(59)] .91277 -0.0125 0 1 Mshowa
.92835 0 m
.92835 .00625 L
s
[(60)] .92835 -0.0125 0 1 Mshowa
.94393 0 m
.94393 .00625 L
s
[(61)] .94393 -0.0125 0 1 Mshowa
.9595 0 m
.9595 .00625 L
s
[(62)] .9595 -0.0125 0 1 Mshowa
.97508 0 m
.97508 .00625 L
s
[(63)] .97508 -0.0125 0 1 Mshowa
.99065 0 m
.99065 .00625 L
s
[(64)] .99065 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14381 m
.00625 .14381 L
s
[(0.1)] -0.0125 .14381 1 0 Mshowa
0 .2729 m
.00625 .2729 L
s
[(0.2)] -0.0125 .2729 1 0 Mshowa
0 .402 m
.00625 .402 L
s
[(0.3)] -0.0125 .402 1 0 Mshowa
0 .53109 m
.00625 .53109 L
s
[(0.4)] -0.0125 .53109 1 0 Mshowa
.125 Mabswid
0 .04053 m
.00375 .04053 L
s
0 .06635 m
.00375 .06635 L
s
0 .09217 m
.00375 .09217 L
s
0 .11799 m
.00375 .11799 L
s
0 .16963 m
.00375 .16963 L
s
0 .19545 m
.00375 .19545 L
s
0 .22127 m
.00375 .22127 L
s
0 .24708 m
.00375 .24708 L
s
0 .29872 m
.00375 .29872 L
s
0 .32454 m
.00375 .32454 L
s
0 .35036 m
.00375 .35036 L
s
0 .37618 m
.00375 .37618 L
s
0 .42782 m
.00375 .42782 L
s
0 .45363 m
.00375 .45363 L
s
0 .47945 m
.00375 .47945 L
s
0 .50527 m
.00375 .50527 L
s
0 .55691 m
.00375 .55691 L
s
0 .58273 m
.00375 .58273 L
s
0 .60855 m
.00375 .60855 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00935 .61178 m
.00935 .61803 L
s
[(1)] .00935 .63053 0 -1 Mshowa
.02492 .61178 m
.02492 .61803 L
s
[(2)] .02492 .63053 0 -1 Mshowa
.0405 .61178 m
.0405 .61803 L
s
[(3)] .0405 .63053 0 -1 Mshowa
.05607 .61178 m
.05607 .61803 L
s
[(4)] .05607 .63053 0 -1 Mshowa
.07165 .61178 m
.07165 .61803 L
s
[(5)] .07165 .63053 0 -1 Mshowa
.08723 .61178 m
.08723 .61803 L
s
[(6)] .08723 .63053 0 -1 Mshowa
.1028 .61178 m
.1028 .61803 L
s
[(7)] .1028 .63053 0 -1 Mshowa
.11838 .61178 m
.11838 .61803 L
s
[(8)] .11838 .63053 0 -1 Mshowa
.13396 .61178 m
.13396 .61803 L
s
[(9)] .13396 .63053 0 -1 Mshowa
.14953 .61178 m
.14953 .61803 L
s
[(10)] .14953 .63053 0 -1 Mshowa
.16511 .61178 m
.16511 .61803 L
s
[(11)] .16511 .63053 0 -1 Mshowa
.18069 .61178 m
.18069 .61803 L
s
[(12)] .18069 .63053 0 -1 Mshowa
.19626 .61178 m
.19626 .61803 L
s
[(13)] .19626 .63053 0 -1 Mshowa
.21184 .61178 m
.21184 .61803 L
s
[(14)] .21184 .63053 0 -1 Mshowa
.22741 .61178 m
.22741 .61803 L
s
[(15)] .22741 .63053 0 -1 Mshowa
.24299 .61178 m
.24299 .61803 L
s
[(16)] .24299 .63053 0 -1 Mshowa
.25857 .61178 m
.25857 .61803 L
s
[(17)] .25857 .63053 0 -1 Mshowa
.27414 .61178 m
.27414 .61803 L
s
[(18)] .27414 .63053 0 -1 Mshowa
.28972 .61178 m
.28972 .61803 L
s
[(19)] .28972 .63053 0 -1 Mshowa
.3053 .61178 m
.3053 .61803 L
s
[(20)] .3053 .63053 0 -1 Mshowa
.32087 .61178 m
.32087 .61803 L
s
[(21)] .32087 .63053 0 -1 Mshowa
.33645 .61178 m
.33645 .61803 L
s
[(22)] .33645 .63053 0 -1 Mshowa
.35202 .61178 m
.35202 .61803 L
s
[(23)] .35202 .63053 0 -1 Mshowa
.3676 .61178 m
.3676 .61803 L
s
[(24)] .3676 .63053 0 -1 Mshowa
.38318 .61178 m
.38318 .61803 L
s
[(25)] .38318 .63053 0 -1 Mshowa
.39875 .61178 m
.39875 .61803 L
s
[(26)] .39875 .63053 0 -1 Mshowa
.41433 .61178 m
.41433 .61803 L
s
[(27)] .41433 .63053 0 -1 Mshowa
.42991 .61178 m
.42991 .61803 L
s
[(28)] .42991 .63053 0 -1 Mshowa
.44548 .61178 m
.44548 .61803 L
s
[(29)] .44548 .63053 0 -1 Mshowa
.46106 .61178 m
.46106 .61803 L
s
[(30)] .46106 .63053 0 -1 Mshowa
.47664 .61178 m
.47664 .61803 L
s
[(31)] .47664 .63053 0 -1 Mshowa
.49221 .61178 m
.49221 .61803 L
s
[(32)] .49221 .63053 0 -1 Mshowa
.50779 .61178 m
.50779 .61803 L
s
[(33)] .50779 .63053 0 -1 Mshowa
.52336 .61178 m
.52336 .61803 L
s
[(34)] .52336 .63053 0 -1 Mshowa
.53894 .61178 m
.53894 .61803 L
s
[(35)] .53894 .63053 0 -1 Mshowa
.55452 .61178 m
.55452 .61803 L
s
[(36)] .55452 .63053 0 -1 Mshowa
.57009 .61178 m
.57009 .61803 L
s
[(37)] .57009 .63053 0 -1 Mshowa
.58567 .61178 m
.58567 .61803 L
s
[(38)] .58567 .63053 0 -1 Mshowa
.60125 .61178 m
.60125 .61803 L
s
[(39)] .60125 .63053 0 -1 Mshowa
.61682 .61178 m
.61682 .61803 L
s
[(40)] .61682 .63053 0 -1 Mshowa
.6324 .61178 m
.6324 .61803 L
s
[(41)] .6324 .63053 0 -1 Mshowa
.64798 .61178 m
.64798 .61803 L
s
[(42)] .64798 .63053 0 -1 Mshowa
.66355 .61178 m
.66355 .61803 L
s
[(43)] .66355 .63053 0 -1 Mshowa
.67913 .61178 m
.67913 .61803 L
s
[(44)] .67913 .63053 0 -1 Mshowa
.6947 .61178 m
.6947 .61803 L
s
[(45)] .6947 .63053 0 -1 Mshowa
.71028 .61178 m
.71028 .61803 L
s
[(46)] .71028 .63053 0 -1 Mshowa
.72586 .61178 m
.72586 .61803 L
s
[(47)] .72586 .63053 0 -1 Mshowa
.74143 .61178 m
.74143 .61803 L
s
[(48)] .74143 .63053 0 -1 Mshowa
.75701 .61178 m
.75701 .61803 L
s
[(49)] .75701 .63053 0 -1 Mshowa
.77259 .61178 m
.77259 .61803 L
s
[(50)] .77259 .63053 0 -1 Mshowa
.78816 .61178 m
.78816 .61803 L
s
[(51)] .78816 .63053 0 -1 Mshowa
.80374 .61178 m
.80374 .61803 L
s
[(52)] .80374 .63053 0 -1 Mshowa
.81931 .61178 m
.81931 .61803 L
s
[(53)] .81931 .63053 0 -1 Mshowa
.83489 .61178 m
.83489 .61803 L
s
[(54)] .83489 .63053 0 -1 Mshowa
.85047 .61178 m
.85047 .61803 L
s
[(55)] .85047 .63053 0 -1 Mshowa
.86604 .61178 m
.86604 .61803 L
s
[(56)] .86604 .63053 0 -1 Mshowa
.88162 .61178 m
.88162 .61803 L
s
[(57)] .88162 .63053 0 -1 Mshowa
.8972 .61178 m
.8972 .61803 L
s
[(58)] .8972 .63053 0 -1 Mshowa
.91277 .61178 m
.91277 .61803 L
s
[(59)] .91277 .63053 0 -1 Mshowa
.92835 .61178 m
.92835 .61803 L
s
[(60)] .92835 .63053 0 -1 Mshowa
.94393 .61178 m
.94393 .61803 L
s
[(61)] .94393 .63053 0 -1 Mshowa
.9595 .61178 m
.9595 .61803 L
s
[(62)] .9595 .63053 0 -1 Mshowa
.97508 .61178 m
.97508 .61803 L
s
[(63)] .97508 .63053 0 -1 Mshowa
.99065 .61178 m
.99065 .61803 L
s
[(64)] .99065 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14381 m
1 .14381 L
s
.99375 .2729 m
1 .2729 L
s
.99375 .402 m
1 .402 L
s
.99375 .53109 m
1 .53109 L
s
.125 Mabswid
.99625 .04053 m
1 .04053 L
s
.99625 .06635 m
1 .06635 L
s
.99625 .09217 m
1 .09217 L
s
.99625 .11799 m
1 .11799 L
s
.99625 .16963 m
1 .16963 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .22127 m
1 .22127 L
s
.99625 .24708 m
1 .24708 L
s
.99625 .29872 m
1 .29872 L
s
.99625 .32454 m
1 .32454 L
s
.99625 .35036 m
1 .35036 L
s
.99625 .37618 m
1 .37618 L
s
.99625 .42782 m
1 .42782 L
s
.99625 .45363 m
1 .45363 L
s
.99625 .47945 m
1 .47945 L
s
.99625 .50527 m
1 .50527 L
s
.99625 .55691 m
1 .55691 L
s
.99625 .58273 m
1 .58273 L
s
.99625 .60855 m
1 .60855 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
F
.5 Mabswid
.00312 .01472 m
.00312 .01472 L
.00623 .01472 L
.00623 .01472 L
.00312 .01472 L
s
.01869 .01472 m
.01869 .03964 L
.02181 .03964 L
.02181 .01472 L
F
.01869 .01472 m
.01869 .03964 L
.02181 .03964 L
.02181 .01472 L
.01869 .01472 L
s
.03427 .01472 m
.03427 .02151 L
.03738 .02151 L
.03738 .01472 L
F
.03427 .01472 m
.03427 .02151 L
.03738 .02151 L
.03738 .01472 L
.03427 .01472 L
s
.04984 .01472 m
.04984 .04689 L
.05296 .04689 L
.05296 .01472 L
F
.04984 .01472 m
.04984 .04689 L
.05296 .04689 L
.05296 .01472 L
.04984 .01472 L
s
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
F
.06542 .01472 m
.06542 .01472 L
.06854 .01472 L
.06854 .01472 L
.06542 .01472 L
s
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
F
.081 .01472 m
.081 .01472 L
.08411 .01472 L
.08411 .01472 L
.081 .01472 L
s
.09657 .01472 m
.09657 .01925 L
.09969 .01925 L
.09969 .01472 L
F
.09657 .01472 m
.09657 .01925 L
.09969 .01925 L
.09969 .01472 L
.09657 .01472 L
s
.11215 .01472 m
.11215 .03737 L
.11526 .03737 L
.11526 .01472 L
F
.11215 .01472 m
.11215 .03737 L
.11526 .03737 L
.11526 .01472 L
.11215 .01472 L
s
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
F
.12773 .01472 m
.12773 .01472 L
.13084 .01472 L
.13084 .01472 L
.12773 .01472 L
s
.1433 .01472 m
.1433 .02015 L
.14642 .02015 L
.14642 .01472 L
F
.1433 .01472 m
.1433 .02015 L
.14642 .02015 L
.14642 .01472 L
.1433 .01472 L
s
.15888 .01472 m
.15888 .03964 L
.16199 .03964 L
.16199 .01472 L
F
.15888 .01472 m
.15888 .03964 L
.16199 .03964 L
.16199 .01472 L
.15888 .01472 L
s
.17445 .01472 m
.17445 .02106 L
.17757 .02106 L
.17757 .01472 L
F
.17445 .01472 m
.17445 .02106 L
.17757 .02106 L
.17757 .01472 L
.17445 .01472 L
s
.19003 .01472 m
.19003 .01517 L
.19315 .01517 L
.19315 .01472 L
F
.19003 .01472 m
.19003 .01517 L
.19315 .01517 L
.19315 .01472 L
.19003 .01472 L
s
.20561 .01472 m
.20561 .02106 L
.20872 .02106 L
.20872 .01472 L
F
.20561 .01472 m
.20561 .02106 L
.20872 .02106 L
.20872 .01472 L
.20561 .01472 L
s
.22118 .01472 m
.22118 .08268 L
.2243 .08268 L
.2243 .01472 L
F
.22118 .01472 m
.22118 .08268 L
.2243 .08268 L
.2243 .01472 L
.22118 .01472 L
s
.23676 .01472 m
.23676 .02197 L
.23988 .02197 L
.23988 .01472 L
F
.23676 .01472 m
.23676 .02197 L
.23988 .02197 L
.23988 .01472 L
.23676 .01472 L
s
.25234 .01472 m
.25234 .01472 L
.25545 .01472 L
.25545 .01472 L
F
.25234 .01472 m
.25234 .01472 L
.25545 .01472 L
.25545 .01472 L
.25234 .01472 L
s
.26791 .01472 m
.26791 .07815 L
.27103 .07815 L
.27103 .01472 L
F
.26791 .01472 m
.26791 .07815 L
.27103 .07815 L
.27103 .01472 L
.26791 .01472 L
s
.28349 .01472 m
.28349 .06637 L
.2866 .06637 L
.2866 .01472 L
F
.28349 .01472 m
.28349 .06637 L
.2866 .06637 L
.2866 .01472 L
.28349 .01472 L
s
.29907 .01472 m
.29907 .0265 L
.30218 .0265 L
.30218 .01472 L
F
.29907 .01472 m
.29907 .0265 L
.30218 .0265 L
.30218 .01472 L
.29907 .01472 L
s
.31464 .01472 m
.31464 .01834 L
.31776 .01834 L
.31776 .01472 L
F
.31464 .01472 m
.31464 .01834 L
.31776 .01834 L
.31776 .01472 L
.31464 .01472 L
s
.33022 .01472 m
.33022 .06501 L
.33333 .06501 L
.33333 .01472 L
F
.33022 .01472 m
.33022 .06501 L
.33333 .06501 L
.33333 .01472 L
.33022 .01472 L
s
.34579 .01472 m
.34579 .02468 L
.34891 .02468 L
.34891 .01472 L
F
.34579 .01472 m
.34579 .02468 L
.34891 .02468 L
.34891 .01472 L
.34579 .01472 L
s
.36137 .01472 m
.36137 .02514 L
.36449 .02514 L
.36449 .01472 L
F
.36137 .01472 m
.36137 .02514 L
.36449 .02514 L
.36449 .01472 L
.36137 .01472 L
s
.37695 .01472 m
.37695 .01517 L
.38006 .01517 L
.38006 .01472 L
F
.37695 .01472 m
.37695 .01517 L
.38006 .01517 L
.38006 .01472 L
.37695 .01472 L
s
.39252 .01472 m
.39252 .07634 L
.39564 .07634 L
.39564 .01472 L
F
.39252 .01472 m
.39252 .07634 L
.39564 .07634 L
.39564 .01472 L
.39252 .01472 L
s
.4081 .01472 m
.4081 .06456 L
.41121 .06456 L
.41121 .01472 L
F
.4081 .01472 m
.4081 .06456 L
.41121 .06456 L
.41121 .01472 L
.4081 .01472 L
s
.42368 .01472 m
.42368 .07317 L
.42679 .07317 L
.42679 .01472 L
F
.42368 .01472 m
.42368 .07317 L
.42679 .07317 L
.42679 .01472 L
.42368 .01472 L
s
.43925 .01472 m
.43925 .02197 L
.44237 .02197 L
.44237 .01472 L
F
.43925 .01472 m
.43925 .02197 L
.44237 .02197 L
.44237 .01472 L
.43925 .01472 L
s
.45483 .01472 m
.45483 .01607 L
.45794 .01607 L
.45794 .01472 L
F
.45483 .01472 m
.45483 .01607 L
.45794 .01607 L
.45794 .01472 L
.45483 .01472 L
s
.4704 .01472 m
.4704 .01789 L
.47352 .01789 L
.47352 .01472 L
F
.4704 .01472 m
.4704 .01789 L
.47352 .01789 L
.47352 .01472 L
.4704 .01472 L
s
.48598 .01472 m
.48598 .07543 L
.4891 .07543 L
.4891 .01472 L
F
.48598 .01472 m
.48598 .07543 L
.4891 .07543 L
.4891 .01472 L
.48598 .01472 L
s
.50156 .01472 m
.50156 .01517 L
.50467 .01517 L
.50467 .01472 L
F
.50156 .01472 m
.50156 .01517 L
.50467 .01517 L
.50467 .01472 L
.50156 .01472 L
s
.51713 .01472 m
.51713 .02106 L
.52025 .02106 L
.52025 .01472 L
F
.51713 .01472 m
.51713 .02106 L
.52025 .02106 L
.52025 .01472 L
.51713 .01472 L
s
.53271 .01472 m
.53271 .01562 L
.53583 .01562 L
.53583 .01472 L
F
.53271 .01472 m
.53271 .01562 L
.53583 .01562 L
.53583 .01472 L
.53271 .01472 L
s
.54829 .01472 m
.54829 .02106 L
.5514 .02106 L
.5514 .01472 L
F
.54829 .01472 m
.54829 .02106 L
.5514 .02106 L
.5514 .01472 L
.54829 .01472 L
s
.56386 .01472 m
.56386 .01472 L
.56698 .01472 L
.56698 .01472 L
F
.56386 .01472 m
.56386 .01472 L
.56698 .01472 L
.56698 .01472 L
.56386 .01472 L
s
.57944 .01472 m
.57944 .01653 L
.58255 .01653 L
.58255 .01472 L
F
.57944 .01472 m
.57944 .01653 L
.58255 .01653 L
.58255 .01472 L
.57944 .01472 L
s
.59502 .01472 m
.59502 .06411 L
.59813 .06411 L
.59813 .01472 L
F
.59502 .01472 m
.59502 .06411 L
.59813 .06411 L
.59813 .01472 L
.59502 .01472 L
s
.61059 .01472 m
.61059 .06229 L
.61371 .06229 L
.61371 .01472 L
F
.61059 .01472 m
.61059 .06229 L
.61371 .06229 L
.61371 .01472 L
.61059 .01472 L
s
.62617 .01472 m
.62617 .01834 L
.62928 .01834 L
.62928 .01472 L
F
.62617 .01472 m
.62617 .01834 L
.62928 .01834 L
.62928 .01472 L
.62617 .01472 L
s
.64174 .01472 m
.64174 .04326 L
.64486 .04326 L
.64486 .01472 L
F
.64174 .01472 m
.64174 .04326 L
.64486 .04326 L
.64486 .01472 L
.64174 .01472 L
s
.65732 .01472 m
.65732 .02061 L
.66044 .02061 L
.66044 .01472 L
F
.65732 .01472 m
.65732 .02061 L
.66044 .02061 L
.66044 .01472 L
.65732 .01472 L
s
.6729 .01472 m
.6729 .01698 L
.67601 .01698 L
.67601 .01472 L
F
.6729 .01472 m
.6729 .01698 L
.67601 .01698 L
.67601 .01472 L
.6729 .01472 L
s
.68847 .01472 m
.68847 .02468 L
.69159 .02468 L
.69159 .01472 L
F
.68847 .01472 m
.68847 .02468 L
.69159 .02468 L
.69159 .01472 L
.68847 .01472 L
s
.70405 .01472 m
.70405 .01653 L
.70717 .01653 L
.70717 .01472 L
F
.70405 .01472 m
.70405 .01653 L
.70717 .01653 L
.70717 .01472 L
.70405 .01472 L
s
.71963 .01472 m
.71963 .03646 L
.72274 .03646 L
.72274 .01472 L
F
.71963 .01472 m
.71963 .03646 L
.72274 .03646 L
.72274 .01472 L
.71963 .01472 L
s
.7352 .01472 m
.7352 .07498 L
.73832 .07498 L
.73832 .01472 L
F
.7352 .01472 m
.7352 .07498 L
.73832 .07498 L
.73832 .01472 L
.7352 .01472 L
s
.75078 .01472 m
.75078 .01562 L
.75389 .01562 L
.75389 .01472 L
F
.75078 .01472 m
.75078 .01562 L
.75389 .01562 L
.75389 .01472 L
.75078 .01472 L
s
.76636 .01472 m
.76636 .02287 L
.76947 .02287 L
.76947 .01472 L
F
.76636 .01472 m
.76636 .02287 L
.76947 .02287 L
.76947 .01472 L
.76636 .01472 L
s
.78193 .01472 m
.78193 .01834 L
.78505 .01834 L
.78505 .01472 L
F
.78193 .01472 m
.78193 .01834 L
.78505 .01834 L
.78505 .01472 L
.78193 .01472 L
s
.79751 .01472 m
.79751 .08132 L
.80062 .08132 L
.80062 .01472 L
F
.79751 .01472 m
.79751 .08132 L
.80062 .08132 L
.80062 .01472 L
.79751 .01472 L
s
.81308 .01472 m
.81308 .04825 L
.8162 .04825 L
.8162 .01472 L
F
.81308 .01472 m
.81308 .04825 L
.8162 .04825 L
.8162 .01472 L
.81308 .01472 L
s
.82866 .01472 m
.82866 .03556 L
.83178 .03556 L
.83178 .01472 L
F
.82866 .01472 m
.82866 .03556 L
.83178 .03556 L
.83178 .01472 L
.82866 .01472 L
s
.84424 .01472 m
.84424 .01698 L
.84735 .01698 L
.84735 .01472 L
F
.84424 .01472 m
.84424 .01698 L
.84735 .01698 L
.84735 .01472 L
.84424 .01472 L
s
.85981 .01472 m
.85981 .01517 L
.86293 .01517 L
.86293 .01472 L
F
.85981 .01472 m
.85981 .01517 L
.86293 .01517 L
.86293 .01472 L
.85981 .01472 L
s
.87539 .01472 m
.87539 .01472 L
.8785 .01472 L
.8785 .01472 L
F
.87539 .01472 m
.87539 .01472 L
.8785 .01472 L
.8785 .01472 L
.87539 .01472 L
s
.89097 .01472 m
.89097 .08586 L
.89408 .08586 L
.89408 .01472 L
F
.89097 .01472 m
.89097 .08586 L
.89408 .08586 L
.89408 .01472 L
.89097 .01472 L
s
.90654 .01472 m
.90654 .06728 L
.90966 .06728 L
.90966 .01472 L
F
.90654 .01472 m
.90654 .06728 L
.90966 .06728 L
.90966 .01472 L
.90654 .01472 L
s
.92212 .01472 m
.92212 .08132 L
.92523 .08132 L
.92523 .01472 L
F
.92212 .01472 m
.92212 .08132 L
.92523 .08132 L
.92523 .01472 L
.92212 .01472 L
s
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
F
.93769 .01472 m
.93769 .01472 L
.94081 .01472 L
.94081 .01472 L
.93769 .01472 L
s
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
F
.95327 .01472 m
.95327 .01472 L
.95639 .01472 L
.95639 .01472 L
.95327 .01472 L
s
.96885 .01472 m
.96885 .03057 L
.97196 .03057 L
.97196 .01472 L
F
.96885 .01472 m
.96885 .03057 L
.97196 .03057 L
.97196 .01472 L
.96885 .01472 L
s
.98442 .01472 m
.98442 .06229 L
.98754 .06229 L
.98754 .01472 L
F
.98442 .01472 m
.98442 .06229 L
.98754 .06229 L
.98754 .01472 L
.98442 .01472 L
s
0 1 0 r
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
F
.00623 .01472 m
.00623 .60332 L
.00935 .60332 L
.00935 .01472 L
.00623 .01472 L
s
.02181 .01472 m
.02181 .01607 L
.02492 .01607 L
.02492 .01472 L
F
.02181 .01472 m
.02181 .01607 L
.02492 .01607 L
.02492 .01472 L
.02181 .01472 L
s
.03738 .01472 m
.03738 .01607 L
.0405 .01607 L
.0405 .01472 L
F
.03738 .01472 m
.03738 .01607 L
.0405 .01607 L
.0405 .01472 L
.03738 .01472 L
s
.05296 .01472 m
.05296 .01607 L
.05607 .01607 L
.05607 .01472 L
F
.05296 .01472 m
.05296 .01607 L
.05607 .01607 L
.05607 .01472 L
.05296 .01472 L
s
.06854 .01472 m
.06854 .11259 L
.07165 .11259 L
.07165 .01472 L
F
.06854 .01472 m
.06854 .11259 L
.07165 .11259 L
.07165 .01472 L
.06854 .01472 L
s
.08411 .01472 m
.08411 .09265 L
.08723 .09265 L
.08723 .01472 L
F
.08411 .01472 m
.08411 .09265 L
.08723 .09265 L
.08723 .01472 L
.08411 .01472 L
s
.09969 .01472 m
.09969 .03511 L
.1028 .03511 L
.1028 .01472 L
F
.09969 .01472 m
.09969 .03511 L
.1028 .03511 L
.1028 .01472 L
.09969 .01472 L
s
.11526 .01472 m
.11526 .01653 L
.11838 .01653 L
.11838 .01472 L
F
.11526 .01472 m
.11526 .01653 L
.11838 .01653 L
.11838 .01472 L
.11526 .01472 L
s
.13084 .01472 m
.13084 .11667 L
.13396 .11667 L
.13396 .01472 L
F
.13084 .01472 m
.13084 .11667 L
.13396 .11667 L
.13396 .01472 L
.13084 .01472 L
s
.14642 .01472 m
.14642 .01472 L
.14953 .01472 L
.14953 .01472 L
F
.14642 .01472 m
.14642 .01472 L
.14953 .01472 L
.14953 .01472 L
.14642 .01472 L
s
.16199 .01472 m
.16199 .01517 L
.16511 .01517 L
.16511 .01472 L
F
.16199 .01472 m
.16199 .01517 L
.16511 .01517 L
.16511 .01472 L
.16199 .01472 L
s
.17757 .01472 m
.17757 .01562 L
.18069 .01562 L
.18069 .01472 L
F
.17757 .01472 m
.17757 .01562 L
.18069 .01562 L
.18069 .01472 L
.17757 .01472 L
s
.19315 .01472 m
.19315 .0632 L
.19626 .0632 L
.19626 .01472 L
F
.19315 .01472 m
.19315 .0632 L
.19626 .0632 L
.19626 .01472 L
.19315 .01472 L
s
.20872 .01472 m
.20872 .01472 L
.21184 .01472 L
.21184 .01472 L
F
.20872 .01472 m
.20872 .01472 L
.21184 .01472 L
.21184 .01472 L
.20872 .01472 L
s
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
F
.2243 .01472 m
.2243 .01472 L
.22741 .01472 L
.22741 .01472 L
.2243 .01472 L
s
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
F
.23988 .01472 m
.23988 .01472 L
.24299 .01472 L
.24299 .01472 L
.23988 .01472 L
s
.25545 .01472 m
.25545 .10489 L
.25857 .10489 L
.25857 .01472 L
F
.25545 .01472 m
.25545 .10489 L
.25857 .10489 L
.25857 .01472 L
.25545 .01472 L
s
.27103 .01472 m
.27103 .01472 L
.27414 .01472 L
.27414 .01472 L
F
.27103 .01472 m
.27103 .01472 L
.27414 .01472 L
.27414 .01472 L
.27103 .01472 L
s
.2866 .01472 m
.2866 .01472 L
.28972 .01472 L
.28972 .01472 L
F
.2866 .01472 m
.2866 .01472 L
.28972 .01472 L
.28972 .01472 L
.2866 .01472 L
s
.30218 .01472 m
.30218 .01472 L
.3053 .01472 L
.3053 .01472 L
F
.30218 .01472 m
.30218 .01472 L
.3053 .01472 L
.3053 .01472 L
.30218 .01472 L
s
.31776 .01472 m
.31776 .01789 L
.32087 .01789 L
.32087 .01472 L
F
.31776 .01472 m
.31776 .01789 L
.32087 .01789 L
.32087 .01472 L
.31776 .01472 L
s
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
F
.33333 .01472 m
.33333 .01472 L
.33645 .01472 L
.33645 .01472 L
.33333 .01472 L
s
.34891 .01472 m
.34891 .01472 L
.35202 .01472 L
.35202 .01472 L
F
.34891 .01472 m
.34891 .01472 L
.35202 .01472 L
.35202 .01472 L
.34891 .01472 L
s
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
F
.36449 .01472 m
.36449 .01472 L
.3676 .01472 L
.3676 .01472 L
.36449 .01472 L
s
.38006 .01472 m
.38006 .08223 L
.38318 .08223 L
.38318 .01472 L
F
.38006 .01472 m
.38006 .08223 L
.38318 .08223 L
.38318 .01472 L
.38006 .01472 L
s
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
F
.39564 .01472 m
.39564 .01472 L
.39875 .01472 L
.39875 .01472 L
.39564 .01472 L
s
.41121 .01472 m
.41121 .01472 L
.41433 .01472 L
.41433 .01472 L
F
.41121 .01472 m
.41121 .01472 L
.41433 .01472 L
.41433 .01472 L
.41121 .01472 L
s
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
F
.42679 .01472 m
.42679 .01472 L
.42991 .01472 L
.42991 .01472 L
.42679 .01472 L
s
.44237 .01472 m
.44237 .01517 L
.44548 .01517 L
.44548 .01472 L
F
.44237 .01472 m
.44237 .01517 L
.44548 .01517 L
.44548 .01472 L
.44237 .01472 L
s
.45794 .01472 m
.45794 .01517 L
.46106 .01517 L
.46106 .01472 L
F
.45794 .01472 m
.45794 .01517 L
.46106 .01517 L
.46106 .01472 L
.45794 .01472 L
s
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
F
.47352 .01472 m
.47352 .01472 L
.47664 .01472 L
.47664 .01472 L
.47352 .01472 L
s
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
F
.4891 .01472 m
.4891 .01472 L
.49221 .01472 L
.49221 .01472 L
.4891 .01472 L
s
.50467 .01472 m
.50467 .07815 L
.50779 .07815 L
.50779 .01472 L
F
.50467 .01472 m
.50467 .07815 L
.50779 .07815 L
.50779 .01472 L
.50467 .01472 L
s
.52025 .01472 m
.52025 .01472 L
.52336 .01472 L
.52336 .01472 L
F
.52025 .01472 m
.52025 .01472 L
.52336 .01472 L
.52336 .01472 L
.52025 .01472 L
s
.53583 .01472 m
.53583 .01472 L
.53894 .01472 L
.53894 .01472 L
F
.53583 .01472 m
.53583 .01472 L
.53894 .01472 L
.53894 .01472 L
.53583 .01472 L
s
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
F
.5514 .01472 m
.5514 .01472 L
.55452 .01472 L
.55452 .01472 L
.5514 .01472 L
s
.56698 .01472 m
.56698 .06501 L
.57009 .06501 L
.57009 .01472 L
F
.56698 .01472 m
.56698 .06501 L
.57009 .06501 L
.57009 .01472 L
.56698 .01472 L
s
.58255 .01472 m
.58255 .01743 L
.58567 .01743 L
.58567 .01472 L
F
.58255 .01472 m
.58255 .01743 L
.58567 .01743 L
.58567 .01472 L
.58255 .01472 L
s
.59813 .01472 m
.59813 .01517 L
.60125 .01517 L
.60125 .01472 L
F
.59813 .01472 m
.59813 .01517 L
.60125 .01517 L
.60125 .01472 L
.59813 .01472 L
s
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
F
.61371 .01472 m
.61371 .01472 L
.61682 .01472 L
.61682 .01472 L
.61371 .01472 L
s
.62928 .01472 m
.62928 .0197 L
.6324 .0197 L
.6324 .01472 L
F
.62928 .01472 m
.62928 .0197 L
.6324 .0197 L
.6324 .01472 L
.62928 .01472 L
s
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
F
.64486 .01472 m
.64486 .01472 L
.64798 .01472 L
.64798 .01472 L
.64486 .01472 L
s
.66044 .01472 m
.66044 .01472 L
.66355 .01472 L
.66355 .01472 L
F
.66044 .01472 m
.66044 .01472 L
.66355 .01472 L
.66355 .01472 L
.66044 .01472 L
s
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
F
.67601 .01472 m
.67601 .01472 L
.67913 .01472 L
.67913 .01472 L
.67601 .01472 L
s
.69159 .01472 m
.69159 .01517 L
.6947 .01517 L
.6947 .01472 L
F
.69159 .01472 m
.69159 .01517 L
.6947 .01517 L
.6947 .01472 L
.69159 .01472 L
s
.70717 .01472 m
.70717 .01472 L
.71028 .01472 L
.71028 .01472 L
F
.70717 .01472 m
.70717 .01472 L
.71028 .01472 L
.71028 .01472 L
.70717 .01472 L
s
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
F
.72274 .01472 m
.72274 .01472 L
.72586 .01472 L
.72586 .01472 L
.72274 .01472 L
s
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
F
.73832 .01472 m
.73832 .01472 L
.74143 .01472 L
.74143 .01472 L
.73832 .01472 L
s
.75389 .01472 m
.75389 .04961 L
.75701 .04961 L
.75701 .01472 L
F
.75389 .01472 m
.75389 .04961 L
.75701 .04961 L
.75701 .01472 L
.75389 .01472 L
s
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
F
.76947 .01472 m
.76947 .01472 L
.77259 .01472 L
.77259 .01472 L
.76947 .01472 L
s
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
F
.78505 .01472 m
.78505 .01472 L
.78816 .01472 L
.78816 .01472 L
.78505 .01472 L
s
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
F
.80062 .01472 m
.80062 .01472 L
.80374 .01472 L
.80374 .01472 L
.80062 .01472 L
s
.8162 .01472 m
.8162 .01472 L
.81931 .01472 L
.81931 .01472 L
F
.8162 .01472 m
.8162 .01472 L
.81931 .01472 L
.81931 .01472 L
.8162 .01472 L
s
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
F
.83178 .01472 m
.83178 .01472 L
.83489 .01472 L
.83489 .01472 L
.83178 .01472 L
s
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
F
.84735 .01472 m
.84735 .01472 L
.85047 .01472 L
.85047 .01472 L
.84735 .01472 L
s
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
F
.86293 .01472 m
.86293 .01472 L
.86604 .01472 L
.86604 .01472 L
.86293 .01472 L
s
.8785 .01472 m
.8785 .04417 L
.88162 .04417 L
.88162 .01472 L
F
.8785 .01472 m
.8785 .04417 L
.88162 .04417 L
.88162 .01472 L
.8785 .01472 L
s
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
F
.89408 .01472 m
.89408 .01472 L
.8972 .01472 L
.8972 .01472 L
.89408 .01472 L
s
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
F
.90966 .01472 m
.90966 .01472 L
.91277 .01472 L
.91277 .01472 L
.90966 .01472 L
s
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
F
.92523 .01472 m
.92523 .01472 L
.92835 .01472 L
.92835 .01472 L
.92523 .01472 L
s
.94081 .01472 m
.94081 .01472 L
.94393 .01472 L
.94393 .01472 L
F
.94081 .01472 m
.94081 .01472 L
.94393 .01472 L
.94393 .01472 L
.94081 .01472 L
s
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
F
.95639 .01472 m
.95639 .01472 L
.9595 .01472 L
.9595 .01472 L
.95639 .01472 L
s
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
F
.97196 .01472 m
.97196 .01472 L
.97508 .01472 L
.97508 .01472 L
.97196 .01472 L
s
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
F
.98754 .01472 m
.98754 .01472 L
.99065 .01472 L
.99065 .01472 L
.98754 .01472 L
s
0 0 1 r
.00935 .01472 m
.00935 .07543 L
.01246 .07543 L
.01246 .01472 L
F
.00935 .01472 m
.00935 .07543 L
.01246 .07543 L
.01246 .01472 L
.00935 .01472 L
s
.02492 .01472 m
.02492 .03012 L
.02804 .03012 L
.02804 .01472 L
F
.02492 .01472 m
.02492 .03012 L
.02804 .03012 L
.02804 .01472 L
.02492 .01472 L
s
.0405 .01472 m
.0405 .03329 L
.04361 .03329 L
.04361 .01472 L
F
.0405 .01472 m
.0405 .03329 L
.04361 .03329 L
.04361 .01472 L
.0405 .01472 L
s
.05607 .01472 m
.05607 .0265 L
.05919 .0265 L
.05919 .01472 L
F
.05607 .01472 m
.05607 .0265 L
.05919 .0265 L
.05919 .01472 L
.05607 .01472 L
s
.07165 .01472 m
.07165 .12935 L
.07477 .12935 L
.07477 .01472 L
F
.07165 .01472 m
.07165 .12935 L
.07477 .12935 L
.07477 .01472 L
.07165 .01472 L
s
.08723 .01472 m
.08723 .09809 L
.09034 .09809 L
.09034 .01472 L
F
.08723 .01472 m
.08723 .09809 L
.09034 .09809 L
.09034 .01472 L
.08723 .01472 L
s
.1028 .01472 m
.1028 .12029 L
.10592 .12029 L
.10592 .01472 L
F
.1028 .01472 m
.1028 .12029 L
.10592 .12029 L
.10592 .01472 L
.1028 .01472 L
s
.11838 .01472 m
.11838 .03012 L
.1215 .03012 L
.1215 .01472 L
F
.11838 .01472 m
.11838 .03012 L
.1215 .03012 L
.1215 .01472 L
.11838 .01472 L
s
.13396 .01472 m
.13396 .10171 L
.13707 .10171 L
.13707 .01472 L
F
.13396 .01472 m
.13396 .10171 L
.13707 .10171 L
.13707 .01472 L
.13396 .01472 L
s
.14953 .01472 m
.14953 .01698 L
.15265 .01698 L
.15265 .01472 L
F
.14953 .01472 m
.14953 .01698 L
.15265 .01698 L
.15265 .01472 L
.14953 .01472 L
s
.16511 .01472 m
.16511 .01834 L
.16822 .01834 L
.16822 .01472 L
F
.16511 .01472 m
.16511 .01834 L
.16822 .01834 L
.16822 .01472 L
.16511 .01472 L
s
.18069 .01472 m
.18069 .0197 L
.1838 .0197 L
.1838 .01472 L
F
.18069 .01472 m
.18069 .0197 L
.1838 .0197 L
.1838 .01472 L
.18069 .01472 L
s
.19626 .01472 m
.19626 .09673 L
.19938 .09673 L
.19938 .01472 L
F
.19626 .01472 m
.19626 .09673 L
.19938 .09673 L
.19938 .01472 L
.19626 .01472 L
s
.21184 .01472 m
.21184 .01607 L
.21495 .01607 L
.21495 .01472 L
F
.21184 .01472 m
.21184 .01607 L
.21495 .01607 L
.21495 .01472 L
.21184 .01472 L
s
.22741 .01472 m
.22741 .01517 L
.23053 .01517 L
.23053 .01472 L
F
.22741 .01472 m
.22741 .01517 L
.23053 .01517 L
.23053 .01472 L
.22741 .01472 L
s
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
F
.24299 .01472 m
.24299 .01472 L
.24611 .01472 L
.24611 .01472 L
.24299 .01472 L
s
.25857 .01472 m
.25857 .09039 L
.26168 .09039 L
.26168 .01472 L
F
.25857 .01472 m
.25857 .09039 L
.26168 .09039 L
.26168 .01472 L
.25857 .01472 L
s
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
F
.27414 .01472 m
.27414 .01472 L
.27726 .01472 L
.27726 .01472 L
.27414 .01472 L
s
.28972 .01472 m
.28972 .01607 L
.29283 .01607 L
.29283 .01472 L
F
.28972 .01472 m
.28972 .01607 L
.29283 .01607 L
.29283 .01472 L
.28972 .01472 L
s
.3053 .01472 m
.3053 .01743 L
.30841 .01743 L
.30841 .01472 L
F
.3053 .01472 m
.3053 .01743 L
.30841 .01743 L
.30841 .01472 L
.3053 .01472 L
s
.32087 .01472 m
.32087 .07 L
.32399 .07 L
.32399 .01472 L
F
.32087 .01472 m
.32087 .07 L
.32399 .07 L
.32399 .01472 L
.32087 .01472 L
s
.33645 .01472 m
.33645 .01607 L
.33956 .01607 L
.33956 .01472 L
F
.33645 .01472 m
.33645 .01607 L
.33956 .01607 L
.33956 .01472 L
.33645 .01472 L
s
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
F
.35202 .01472 m
.35202 .01472 L
.35514 .01472 L
.35514 .01472 L
.35202 .01472 L
s
.3676 .01472 m
.3676 .01607 L
.37072 .01607 L
.37072 .01472 L
F
.3676 .01472 m
.3676 .01607 L
.37072 .01607 L
.37072 .01472 L
.3676 .01472 L
s
.38318 .01472 m
.38318 .09039 L
.38629 .09039 L
.38629 .01472 L
F
.38318 .01472 m
.38318 .09039 L
.38629 .09039 L
.38629 .01472 L
.38318 .01472 L
s
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
F
.39875 .01472 m
.39875 .01472 L
.40187 .01472 L
.40187 .01472 L
.39875 .01472 L
s
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
F
.41433 .01472 m
.41433 .01472 L
.41745 .01472 L
.41745 .01472 L
.41433 .01472 L
s
.42991 .01472 m
.42991 .01607 L
.43302 .01607 L
.43302 .01472 L
F
.42991 .01472 m
.42991 .01607 L
.43302 .01607 L
.43302 .01472 L
.42991 .01472 L
s
.44548 .01472 m
.44548 .01472 L
.4486 .01472 L
.4486 .01472 L
F
.44548 .01472 m
.44548 .01472 L
.4486 .01472 L
.4486 .01472 L
.44548 .01472 L
s
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
F
.46106 .01472 m
.46106 .01472 L
.46417 .01472 L
.46417 .01472 L
.46106 .01472 L
s
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
F
.47664 .01472 m
.47664 .01472 L
.47975 .01472 L
.47975 .01472 L
.47664 .01472 L
s
.49221 .01472 m
.49221 .01517 L
.49533 .01517 L
.49533 .01472 L
F
.49221 .01472 m
.49221 .01517 L
.49533 .01517 L
.49533 .01472 L
.49221 .01472 L
s
.50779 .01472 m
.50779 .07861 L
.5109 .07861 L
.5109 .01472 L
F
.50779 .01472 m
.50779 .07861 L
.5109 .07861 L
.5109 .01472 L
.50779 .01472 L
s
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
F
.52336 .01472 m
.52336 .01472 L
.52648 .01472 L
.52648 .01472 L
.52336 .01472 L
s
.53894 .01472 m
.53894 .01472 L
.54206 .01472 L
.54206 .01472 L
F
.53894 .01472 m
.53894 .01472 L
.54206 .01472 L
.54206 .01472 L
.53894 .01472 L
s
.55452 .01472 m
.55452 .01517 L
.55763 .01517 L
.55763 .01472 L
F
.55452 .01472 m
.55452 .01517 L
.55763 .01517 L
.55763 .01472 L
.55452 .01472 L
s
.57009 .01472 m
.57009 .10942 L
.57321 .10942 L
.57321 .01472 L
F
.57009 .01472 m
.57009 .10942 L
.57321 .10942 L
.57321 .01472 L
.57009 .01472 L
s
.58567 .01472 m
.58567 .06773 L
.58879 .06773 L
.58879 .01472 L
F
.58567 .01472 m
.58567 .06773 L
.58879 .06773 L
.58879 .01472 L
.58567 .01472 L
s
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
F
.60125 .01472 m
.60125 .01472 L
.60436 .01472 L
.60436 .01472 L
.60125 .01472 L
s
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
F
.61682 .01472 m
.61682 .01472 L
.61994 .01472 L
.61994 .01472 L
.61682 .01472 L
s
.6324 .01472 m
.6324 .09809 L
.63551 .09809 L
.63551 .01472 L
F
.6324 .01472 m
.6324 .09809 L
.63551 .09809 L
.63551 .01472 L
.6324 .01472 L
s
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
F
.64798 .01472 m
.64798 .01472 L
.65109 .01472 L
.65109 .01472 L
.64798 .01472 L
s
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
F
.66355 .01472 m
.66355 .01472 L
.66667 .01472 L
.66667 .01472 L
.66355 .01472 L
s
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
F
.67913 .01472 m
.67913 .01472 L
.68224 .01472 L
.68224 .01472 L
.67913 .01472 L
s
.6947 .01472 m
.6947 .02106 L
.69782 .02106 L
.69782 .01472 L
F
.6947 .01472 m
.6947 .02106 L
.69782 .02106 L
.69782 .01472 L
.6947 .01472 L
s
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
F
.71028 .01472 m
.71028 .01472 L
.7134 .01472 L
.7134 .01472 L
.71028 .01472 L
s
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
F
.72586 .01472 m
.72586 .01472 L
.72897 .01472 L
.72897 .01472 L
.72586 .01472 L
s
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
F
.74143 .01472 m
.74143 .01472 L
.74455 .01472 L
.74455 .01472 L
.74143 .01472 L
s
.75701 .01472 m
.75701 .09718 L
.76012 .09718 L
.76012 .01472 L
F
.75701 .01472 m
.75701 .09718 L
.76012 .09718 L
.76012 .01472 L
.75701 .01472 L
s
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
F
.77259 .01472 m
.77259 .01472 L
.7757 .01472 L
.7757 .01472 L
.77259 .01472 L
s
.78816 .01472 m
.78816 .01472 L
.79128 .01472 L
.79128 .01472 L
F
.78816 .01472 m
.78816 .01472 L
.79128 .01472 L
.79128 .01472 L
.78816 .01472 L
s
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
F
.80374 .01472 m
.80374 .01472 L
.80685 .01472 L
.80685 .01472 L
.80374 .01472 L
s
.81931 .01472 m
.81931 .01607 L
.82243 .01607 L
.82243 .01472 L
F
.81931 .01472 m
.81931 .01607 L
.82243 .01607 L
.82243 .01472 L
.81931 .01472 L
s
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
F
.83489 .01472 m
.83489 .01472 L
.83801 .01472 L
.83801 .01472 L
.83489 .01472 L
s
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
F
.85047 .01472 m
.85047 .01472 L
.85358 .01472 L
.85358 .01472 L
.85047 .01472 L
s
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
F
.86604 .01472 m
.86604 .01472 L
.86916 .01472 L
.86916 .01472 L
.86604 .01472 L
s
.88162 .01472 m
.88162 .09764 L
.88474 .09764 L
.88474 .01472 L
F
.88162 .01472 m
.88162 .09764 L
.88474 .09764 L
.88474 .01472 L
.88162 .01472 L
s
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
F
.8972 .01472 m
.8972 .01472 L
.90031 .01472 L
.90031 .01472 L
.8972 .01472 L
s
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
F
.91277 .01472 m
.91277 .01472 L
.91589 .01472 L
.91589 .01472 L
.91277 .01472 L
s
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
F
.92835 .01472 m
.92835 .01472 L
.93146 .01472 L
.93146 .01472 L
.92835 .01472 L
s
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
F
.94393 .01472 m
.94393 .01472 L
.94704 .01472 L
.94704 .01472 L
.94393 .01472 L
s
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
F
.9595 .01472 m
.9595 .01472 L
.96262 .01472 L
.96262 .01472 L
.9595 .01472 L
s
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
F
.97508 .01472 m
.97508 .01472 L
.97819 .01472 L
.97819 .01472 L
.97508 .01472 L
s
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
F
.99065 .01472 m
.99065 .01472 L
.99377 .01472 L
.99377 .01472 L
.99065 .01472 L
s
1 .5 0 r
.01246 .01472 m
.01246 .01472 L
.01558 .01472 L
.01558 .01472 L
F
.01246 .01472 m
.01246 .01472 L
.01558 .01472 L
.01558 .01472 L
.01246 .01472 L
s
.02804 .01472 m
.02804 .03918 L
.03115 .03918 L
.03115 .01472 L
F
.02804 .01472 m
.02804 .03918 L
.03115 .03918 L
.03115 .01472 L
.02804 .01472 L
s
.04361 .01472 m
.04361 .05957 L
.04673 .05957 L
.04673 .01472 L
F
.04361 .01472 m
.04361 .05957 L
.04673 .05957 L
.04673 .01472 L
.04361 .01472 L
s
.05919 .01472 m
.05919 .04825 L
.06231 .04825 L
.06231 .01472 L
F
.05919 .01472 m
.05919 .04825 L
.06231 .04825 L
.06231 .01472 L
.05919 .01472 L
s
.07477 .01472 m
.07477 .01472 L
.07788 .01472 L
.07788 .01472 L
F
.07477 .01472 m
.07477 .01472 L
.07788 .01472 L
.07788 .01472 L
.07477 .01472 L
s
.09034 .01472 m
.09034 .01472 L
.09346 .01472 L
.09346 .01472 L
F
.09034 .01472 m
.09034 .01472 L
.09346 .01472 L
.09346 .01472 L
.09034 .01472 L
s
.10592 .01472 m
.10592 .02786 L
.10903 .02786 L
.10903 .01472 L
F
.10592 .01472 m
.10592 .02786 L
.10903 .02786 L
.10903 .01472 L
.10592 .01472 L
s
.1215 .01472 m
.1215 .03873 L
.12461 .03873 L
.12461 .01472 L
F
.1215 .01472 m
.1215 .03873 L
.12461 .03873 L
.12461 .01472 L
.1215 .01472 L
s
.13707 .01472 m
.13707 .01472 L
.14019 .01472 L
.14019 .01472 L
F
.13707 .01472 m
.13707 .01472 L
.14019 .01472 L
.14019 .01472 L
.13707 .01472 L
s
.15265 .01472 m
.15265 .04779 L
.15576 .04779 L
.15576 .01472 L
F
.15265 .01472 m
.15265 .04779 L
.15576 .04779 L
.15576 .01472 L
.15265 .01472 L
s
.16822 .01472 m
.16822 .04779 L
.17134 .04779 L
.17134 .01472 L
F
.16822 .01472 m
.16822 .04779 L
.17134 .04779 L
.17134 .01472 L
.16822 .01472 L
s
.1838 .01472 m
.1838 .05051 L
.18692 .05051 L
.18692 .01472 L
F
.1838 .01472 m
.1838 .05051 L
.18692 .05051 L
.18692 .01472 L
.1838 .01472 L
s
.19938 .01472 m
.19938 .01789 L
.20249 .01789 L
.20249 .01472 L
F
.19938 .01472 m
.19938 .01789 L
.20249 .01789 L
.20249 .01472 L
.19938 .01472 L
s
.21495 .01472 m
.21495 .06003 L
.21807 .06003 L
.21807 .01472 L
F
.21495 .01472 m
.21495 .06003 L
.21807 .06003 L
.21807 .01472 L
.21495 .01472 L
s
.23053 .01472 m
.23053 .02604 L
.23364 .02604 L
.23364 .01472 L
F
.23053 .01472 m
.23053 .02604 L
.23364 .02604 L
.23364 .01472 L
.23053 .01472 L
s
.24611 .01472 m
.24611 .04281 L
.24922 .04281 L
.24922 .01472 L
F
.24611 .01472 m
.24611 .04281 L
.24922 .04281 L
.24922 .01472 L
.24611 .01472 L
s
.26168 .01472 m
.26168 .01517 L
.2648 .01517 L
.2648 .01472 L
F
.26168 .01472 m
.26168 .01517 L
.2648 .01517 L
.2648 .01472 L
.26168 .01472 L
s
.27726 .01472 m
.27726 .02967 L
.28037 .02967 L
.28037 .01472 L
F
.27726 .01472 m
.27726 .02967 L
.28037 .02967 L
.28037 .01472 L
.27726 .01472 L
s
.29283 .01472 m
.29283 .04371 L
.29595 .04371 L
.29595 .01472 L
F
.29283 .01472 m
.29283 .04371 L
.29595 .04371 L
.29595 .01472 L
.29283 .01472 L
s
.30841 .01472 m
.30841 .05595 L
.31153 .05595 L
.31153 .01472 L
F
.30841 .01472 m
.30841 .05595 L
.31153 .05595 L
.31153 .01472 L
.30841 .01472 L
s
.32399 .01472 m
.32399 .0342 L
.3271 .0342 L
.3271 .01472 L
F
.32399 .01472 m
.32399 .0342 L
.3271 .0342 L
.3271 .01472 L
.32399 .01472 L
s
.33956 .01472 m
.33956 .03465 L
.34268 .03465 L
.34268 .01472 L
F
.33956 .01472 m
.33956 .03465 L
.34268 .03465 L
.34268 .01472 L
.33956 .01472 L
s
.35514 .01472 m
.35514 .04689 L
.35826 .04689 L
.35826 .01472 L
F
.35514 .01472 m
.35514 .04689 L
.35826 .04689 L
.35826 .01472 L
.35514 .01472 L
s
.37072 .01472 m
.37072 .05187 L
.37383 .05187 L
.37383 .01472 L
F
.37072 .01472 m
.37072 .05187 L
.37383 .05187 L
.37383 .01472 L
.37072 .01472 L
s
.38629 .01472 m
.38629 .01879 L
.38941 .01879 L
.38941 .01472 L
F
.38629 .01472 m
.38629 .01879 L
.38941 .01879 L
.38941 .01472 L
.38629 .01472 L
s
.40187 .01472 m
.40187 .0274 L
.40498 .0274 L
.40498 .01472 L
F
.40187 .01472 m
.40187 .0274 L
.40498 .0274 L
.40498 .01472 L
.40187 .01472 L
s
.41745 .01472 m
.41745 .02468 L
.42056 .02468 L
.42056 .01472 L
F
.41745 .01472 m
.41745 .02468 L
.42056 .02468 L
.42056 .01472 L
.41745 .01472 L
s
.43302 .01472 m
.43302 .02287 L
.43614 .02287 L
.43614 .01472 L
F
.43302 .01472 m
.43302 .02287 L
.43614 .02287 L
.43614 .01472 L
.43302 .01472 L
s
.4486 .01472 m
.4486 .04598 L
.45171 .04598 L
.45171 .01472 L
F
.4486 .01472 m
.4486 .04598 L
.45171 .04598 L
.45171 .01472 L
.4486 .01472 L
s
.46417 .01472 m
.46417 .04961 L
.46729 .04961 L
.46729 .01472 L
F
.46417 .01472 m
.46417 .04961 L
.46729 .04961 L
.46729 .01472 L
.46417 .01472 L
s
.47975 .01472 m
.47975 .04598 L
.48287 .04598 L
.48287 .01472 L
F
.47975 .01472 m
.47975 .04598 L
.48287 .04598 L
.48287 .01472 L
.47975 .01472 L
s
.49533 .01472 m
.49533 .01925 L
.49844 .01925 L
.49844 .01472 L
F
.49533 .01472 m
.49533 .01925 L
.49844 .01925 L
.49844 .01472 L
.49533 .01472 L
s
.5109 .01472 m
.5109 .01925 L
.51402 .01925 L
.51402 .01472 L
F
.5109 .01472 m
.5109 .01925 L
.51402 .01925 L
.51402 .01472 L
.5109 .01472 L
s
.52648 .01472 m
.52648 .03964 L
.5296 .03964 L
.5296 .01472 L
F
.52648 .01472 m
.52648 .03964 L
.5296 .03964 L
.5296 .01472 L
.52648 .01472 L
s
.54206 .01472 m
.54206 .04734 L
.54517 .04734 L
.54517 .01472 L
F
.54206 .01472 m
.54206 .04734 L
.54517 .04734 L
.54517 .01472 L
.54206 .01472 L
s
.55763 .01472 m
.55763 .05187 L
.56075 .05187 L
.56075 .01472 L
F
.55763 .01472 m
.55763 .05187 L
.56075 .05187 L
.56075 .01472 L
.55763 .01472 L
s
.57321 .01472 m
.57321 .01698 L
.57632 .01698 L
.57632 .01472 L
F
.57321 .01472 m
.57321 .01698 L
.57632 .01698 L
.57632 .01472 L
.57321 .01472 L
s
.58879 .01472 m
.58879 .03692 L
.5919 .03692 L
.5919 .01472 L
F
.58879 .01472 m
.58879 .03692 L
.5919 .03692 L
.5919 .01472 L
.58879 .01472 L
s
.60436 .01472 m
.60436 .02786 L
.60748 .02786 L
.60748 .01472 L
F
.60436 .01472 m
.60436 .02786 L
.60748 .02786 L
.60748 .01472 L
.60436 .01472 L
s
.61994 .01472 m
.61994 .02786 L
.62305 .02786 L
.62305 .01472 L
F
.61994 .01472 m
.61994 .02786 L
.62305 .02786 L
.62305 .01472 L
.61994 .01472 L
s
.63551 .01472 m
.63551 .02559 L
.63863 .02559 L
.63863 .01472 L
F
.63551 .01472 m
.63551 .02559 L
.63863 .02559 L
.63863 .01472 L
.63551 .01472 L
s
.65109 .01472 m
.65109 .03375 L
.65421 .03375 L
.65421 .01472 L
F
.65109 .01472 m
.65109 .03375 L
.65421 .03375 L
.65421 .01472 L
.65109 .01472 L
s
.66667 .01472 m
.66667 .04553 L
.66978 .04553 L
.66978 .01472 L
F
.66667 .01472 m
.66667 .04553 L
.66978 .04553 L
.66978 .01472 L
.66667 .01472 L
s
.68224 .01472 m
.68224 .03057 L
.68536 .03057 L
.68536 .01472 L
F
.68224 .01472 m
.68224 .03057 L
.68536 .03057 L
.68536 .01472 L
.68224 .01472 L
s
.69782 .01472 m
.69782 .0632 L
.70093 .0632 L
.70093 .01472 L
F
.69782 .01472 m
.69782 .0632 L
.70093 .0632 L
.70093 .01472 L
.69782 .01472 L
s
.7134 .01472 m
.7134 .05232 L
.71651 .05232 L
.71651 .01472 L
F
.7134 .01472 m
.7134 .05232 L
.71651 .05232 L
.71651 .01472 L
.7134 .01472 L
s
.72897 .01472 m
.72897 .04915 L
.73209 .04915 L
.73209 .01472 L
F
.72897 .01472 m
.72897 .04915 L
.73209 .04915 L
.73209 .01472 L
.72897 .01472 L
s
.74455 .01472 m
.74455 .0197 L
.74766 .0197 L
.74766 .01472 L
F
.74455 .01472 m
.74455 .0197 L
.74766 .0197 L
.74766 .01472 L
.74455 .01472 L
s
.76012 .01472 m
.76012 .01743 L
.76324 .01743 L
.76324 .01472 L
F
.76012 .01472 m
.76012 .01743 L
.76324 .01743 L
.76324 .01472 L
.76012 .01472 L
s
.7757 .01472 m
.7757 .03329 L
.77882 .03329 L
.77882 .01472 L
F
.7757 .01472 m
.7757 .03329 L
.77882 .03329 L
.77882 .01472 L
.7757 .01472 L
s
.79128 .01472 m
.79128 .05821 L
.79439 .05821 L
.79439 .01472 L
F
.79128 .01472 m
.79128 .05821 L
.79439 .05821 L
.79439 .01472 L
.79128 .01472 L
s
.80685 .01472 m
.80685 .02695 L
.80997 .02695 L
.80997 .01472 L
F
.80685 .01472 m
.80685 .02695 L
.80997 .02695 L
.80997 .01472 L
.80685 .01472 L
s
.82243 .01472 m
.82243 .03964 L
.82555 .03964 L
.82555 .01472 L
F
.82243 .01472 m
.82243 .03964 L
.82555 .03964 L
.82555 .01472 L
.82243 .01472 L
s
.83801 .01472 m
.83801 .03239 L
.84112 .03239 L
.84112 .01472 L
F
.83801 .01472 m
.83801 .03239 L
.84112 .03239 L
.84112 .01472 L
.83801 .01472 L
s
.85358 .01472 m
.85358 .04598 L
.8567 .04598 L
.8567 .01472 L
F
.85358 .01472 m
.85358 .04598 L
.8567 .04598 L
.8567 .01472 L
.85358 .01472 L
s
.86916 .01472 m
.86916 .04462 L
.87227 .04462 L
.87227 .01472 L
F
.86916 .01472 m
.86916 .04462 L
.87227 .04462 L
.87227 .01472 L
.86916 .01472 L
s
.88474 .01472 m
.88474 .0274 L
.88785 .0274 L
.88785 .01472 L
F
.88474 .01472 m
.88474 .0274 L
.88785 .0274 L
.88785 .01472 L
.88474 .01472 L
s
.90031 .01472 m
.90031 .02151 L
.90343 .02151 L
.90343 .01472 L
F
.90031 .01472 m
.90031 .02151 L
.90343 .02151 L
.90343 .01472 L
.90031 .01472 L
s
.91589 .01472 m
.91589 .02514 L
.919 .02514 L
.919 .01472 L
F
.91589 .01472 m
.91589 .02514 L
.919 .02514 L
.919 .01472 L
.91589 .01472 L
s
.93146 .01472 m
.93146 .02015 L
.93458 .02015 L
.93458 .01472 L
F
.93146 .01472 m
.93146 .02015 L
.93458 .02015 L
.93458 .01472 L
.93146 .01472 L
s
.94704 .01472 m
.94704 .03556 L
.95016 .03556 L
.95016 .01472 L
F
.94704 .01472 m
.94704 .03556 L
.95016 .03556 L
.95016 .01472 L
.94704 .01472 L
s
.96262 .01472 m
.96262 .03284 L
.96573 .03284 L
.96573 .01472 L
F
.96262 .01472 m
.96262 .03284 L
.96573 .03284 L
.96573 .01472 L
.96262 .01472 L
s
.97819 .01472 m
.97819 .03193 L
.98131 .03193 L
.98131 .01472 L
F
.97819 .01472 m
.97819 .03193 L
.98131 .03193 L
.98131 .01472 L
.97819 .01472 L
s
.99377 .01472 m
.99377 .02015 L
.99688 .02015 L
.99688 .01472 L
F
.99377 .01472 m
.99377 .02015 L
.99688 .02015 L
.99688 .01472 L
.99377 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 309},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003ooooooooe
ooooo`009Oooool3o`0000?ooooo1Ol00003ooooo`?o00001Oooool3o`0000?ooooo0ol00004oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000004o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002oooo
o`Go00000_ooool5o`0000;ooooo1?l00004ooooo`?o00000oooool4o`0000;ooooo1Ol00003oooo
o`Co00001?ooool3o`0000?ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Go00000oooool4o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003oooo
o`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`0000;ooooo1?l00004oooo
o`?o00000oooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool3o`0000?ooooo1?l00003oooo
o`Co00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`0000?ooooo1?l00002oooo
o`Go00000oooool4o`0000Cooooo0ol0000>ooooo`009_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooo`000?l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?oo
ool00_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool03_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0
003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00Ko0000
ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00gooooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool5o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00005ooooo`;o00000oooool01?l0003oooooo`000?l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Kooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0000Gooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00002oooo
o`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o0000
00Co00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`000003ooooool0003o0000
00Co00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`05o`000?oooooo0000ooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000kooooo000Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`04o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l000000ooooooo
0000ooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`Co00001_ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l0
0006ooooo`03o`000?oooooooooo00Go00001Oooool2o`0000?ooooo1?l00003ooooo`Co00000ooo
ool01?l0003oooooo`000?l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`03o`00
0?oooooooooo00;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool4o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04
o`000?oooooo0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool01?l0
003oooooooooool00002ooooo`Go00000oooool01?l0003oooooo`000?l00003ooooo`Co00000ooo
ool5o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooool000000oooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000002ooooo`?o000000Coooooo`000?oooooooooo1?l00003ooooo`Co00000oooool4o`00
00?ooooo1?l00003ooooo`Co00000_ooool01?l0003oooooooooool0000?ooooo`009_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool01?l0
003oooooo`000?l00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00003
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00001Oooool2o`0000;ooooo
00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool00_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo
1Ol00002ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool5o`0000?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo1?l00003ooooo`Co00000_ooool5o`0000;ooooo1Ol00003ooooo`Co00000_ooool5o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000003oooool002Gooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000?o
oooo0ol00003ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002o`0000Co
oooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo0ol00003ooooo`03o`000?oooooo0000
00;o00000_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003oooooooooo`;o00000oooool01?l0003oooooo`000?l00003oooo
o`Co00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00004oooo
o`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000004ooooo`;o00003oooool002Kooooo00?o0000ooooooooool00oooool3o`0000Cooooo
0ol00006ooooo`04o`000?ooooooooooooooo`Go00001?ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool3o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l00004ooooo`?o
00001?ooool3o`0000Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`;o00000oooool5o`00
00?ooooo0ol00004ooooo`Co00001?ooool3o`0000Cooooo0ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00002ooooo`Go00001?ooool3o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`00
00Cooooo0ol00004ooooo`?o00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool6o`00
00Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool00ol0
003oooooo`000003ooooo`Co00000oooool4o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00;ooooo1Ol00003ooooo`Co00000oooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`00
0?l000001?l00002ooooo`Go00000_ooool4o`0000Cooooo0ol00004ooooo`?o00000oooool4o`00
00?ooooo1?l00005ooooo`03o`000?oooooooooo00gooooo003oooooooGooooo003oooooooGooooo
003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo
000Roooooooo0000aOl0000>ooooo`008_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000003_ooool002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000kooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`006Oooool2o`0000Oooooo00?o0000ooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo00cooooo000Hooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooooo1
ooooo`03o`000?oooooooooo00cooooo000Hooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0ooooooo1ooooo`03o`000?oooooooooo00cooooo000Hooooo`04o`000?oooooooooo
o`0000Kooooo0_l000001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`;oogl0
00Go0000ool00?l0o`3o0?l0o`00o`03oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o
0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl0
00Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0
o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo
00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l0
0?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`000_oo
O`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o
0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo00000ol0o`3o003oo`00
o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl00_oo
00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l0
0?oo003o00;oogl000?o0000ool00?l0o`000_l00?l2oomo0003o`000?oo003o0?l000;o003o0_oo
O`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l00?l2oomo0003o`000?oo
003o0?l000;o003o0_ooO`000ol0003oo`00o`3o0002o`00o`;oogl000?o0000ool00?l0o`000_l0
0?l2oomo0003o`000?oo003o0?l000;o003o0_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl0
00Go0000ool00?l0o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00_ooO`001Ol0
003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0o`3o0?l0o`00o`02oomo0005o`000?oo
003o0?l0o`3o0?l00?l00_ooO`001Ol0003oo`00o`3o0?l0o`3o003o00;oogl000Go0000ool00?l0
o`3o0?l0o`00o`02oomo0005o`000?oo003o0?l0o`3o0?l00?l00oooO`001?oo003o0?l0o`3o0?l0
0?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0oooO`001?oo003o
0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000Coo`00o`3o0?l0o`3o003o0ooo
O`001?oo003o0?l0o`3o0?l00?l3oomo00;oo`0000?o0?l0o`00ooooO`000_ooO`02ool00003o`3o
0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`0000?o0?l0o`00ooooO`00
0_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003ooomo0002oomo00;oo`00
00?o0?l0o`00ooooO`000_ooO`02ool00003o`3o0?l00?ooogl000;oogl00_oo00000ol0o`3o003o
o`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`02ool00003o`3o0?l00?oo003o00;oogl0
0_oo00000ol0o`3o003oo`00o`02oomo00;oo`0000?o0?l0o`00ool00?l00_ooO`000ol0003ooooo
ooooo`0<ooooo`006?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;o0?l0
0_l00?l2ooooo`;oo`0000Goooooo`00ooooO`3oogl0ooooo`02ool00003ooooool00?ooogl000;o
ogl00_oo00000ooooooo003ooomo0002oomo0003ooooool0o`3o0?l000;o003o0oooool2o`3o00;o
003o0_ooool01?oo003o0?l0o`3o0?l00?l3oomo0004ool00?l0o`3o0?l0o`00o`?oogl000?ooooo
o`3o0?l0o`000_l00?l2ooooo`;oo`0000?oooooo`00ooooO`000_ooO`02ool00003ooooool00?oo
ogl000;oogl00ooo00001?l00?ooogl0oomo0?ooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo
00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?oo
O`3oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo0000
1?ooooooogl0oomo0?ooO`03ool000;o003o0_ooO`02ool00003o`3o0?l00?oo003o00;oogl00ooo
0002ooooo`;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00
o`02oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo0003oooooooo003oo`0000;ooooo0_oo
O`000oooooooo`00ool00002ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000;ooooo0_oo
O`000oooooooo`00ool00002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo
003oo`0000;ooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0
o`001Ol00?ooogl0oomo0?ooooooo`0000;o0?l000Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;o
ogl000?oooooool00?oo00000_ooool2oomo0005oooooooo003o0?l0o`3o0?l00?l00_ooO`000ooo
ooooo`00ool00002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo0003oooooooo003oo`00
00;ooooo0oooO`02ool00003ooooool00?ooogl000;oogl00_oo0002ooooo`?oogl00_oo0002oooo
o`?oogl00_oo0002ooooo`?oogl000Coooooo`3o0?l0o`3o003o0oooO`02ool000;ooooo0oooO`02
ool000;ooooo0oooO`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl0
0ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00Cooooo0oooO`02oooo
o`03o`3o0?l00?ooogl000;oogl00ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3o
ogl0oomo00?oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00ooo0002ooooo`;oogl00ooo
0002ooooo`;oogl000?o0000ooooooooool03?ooool001Sooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`02o`3o00;o003o0_ooool2ool00005ooooool00?ooogl0oomo0?ooool0
0_oo00000ooooooo003ooomo0002oomo00;oo`0000?oooooo`00ooooO`000_ooO`000ooooooo0?l0
o`3o0002o`00o`?ooooo0_l0o`02o`00o`;ooooo00Coo`00o`3o0?l0o`3o003o0oooO`02ool00003
ooooool00?ooogl000;oogl000?oooooo`3o0?l0o`000_l00?l2ooooo`;oo`000_ooool3oomo00;o
o`000_ooool3oomo00?oo`0000Co003ooomo0?ooO`3oogl00_ooool00ol0o`3o003oo`00o`02oooo
o`?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03ool00004oooooooo
O`3oogl0oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool00004ooooooooO`3oogl0oomo00?o
o`0000Cooooooomo0?ooO`3oogl00ooo0002ooooo`;oogl00oooool2o`00o`;oogl00ooo0002oooo
o`;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00_ooool00ol0o`3o003oo`00o`02oomo
00?oo`000_ooool2oomo00?oo`000_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`000ooo
ooooo`00ool00002ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00002oooo
o`;oogl00_ooool00ol0o`3o003oo`00o`02oomo0003oooooooo003oo`0000;ooooo0_ooO`05oooo
o`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`02o`00o`Gooooo00Co003ooomo
0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00;ooooo0_l0o`00
1?l00?ooogl0oomo0?ooool2ool000;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl01Ooo
ool3oomo00;oo`0000?oooooo`00ooooO`000_ooO`04ooooo`?oogl00_oo0002ooooo`?oogl00_oo
0002ooooo`?oogl000?oooooo`3o0?l0o`000_l00?l2ooooo`;oo`000_ooool3oomo00Cooooo0ooo
O`03ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?oooooo
ogl0oomo0?ooO`04ooooo`?oogl01?ooool3oomo00;ooooo00?o0?l0o`00ooooO`000_ooO`03ool0
0004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0002ooooo`;oogl01Ooo
ool2oomo00Gooooo0_ooO`03ool000;ooooo0_ooO`03ool000;ooooo0_ooO`000ol0003ooooooooo
o`0<ooooo`006Oooool2o`0000Oooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo0_oo0000
1Ooooooo003ooomo0?ooO`3ooooo00;oo`0000?oooooo`00ooooO`000_ooO`02ool00003ooooool0
0?ooogl000;oogl000?oooooo`3o0?l0o`000_l00?l3ooooo`;o0?l00_l00?l3ooooo`;o0?l000Co
003ooomo0?ooO`3oogl00_oo00000ooooooo003ooomo0002oomo0003ooooool0o`3o0?l000;o003o
1_ooool3oomo00;oo`000_ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00_ooool00ol0o`3o
003oo`00o`02ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`03
ool00004ooooooooO`3oogl0oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool00004oooooooo
O`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo0002ooooo`;oogl00oooool2o`00o`;o
ogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00ooo0002ooooo`;oogl00_ooool01Ol0o`3o
003oo`00ool00?oooooo00?oo`000_ooool2oomo00?oo`000_ooool2oomo0003oooooooo003oo`00
00;ooooo0_ooO`000oooooooo`00ool00002ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000ooo
ooooo`00ool00006ooooo`04o`3o0?l00?oo003oo`00o`;ooooo0_oo0002ooooo`;oogl01Oooool2
oomo0003oooooooo003oo`0000;ooooo0_ooO`02ooooo`;o0?l00_l00?l5ooooo`04o`00ooooO`3o
ogl0ooooo`;oo`000_ooool2oomo0003oooooooo003oo`0000;ooooo0_ooO`04ooooo`04o`00oooo
O`3oogl0ooooo`;oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`?oogl00_oo00000ooooooo003o
oomo0002oomo00Cooooo0oooO`02ool000;ooooo0oooO`02ool000Kooooo0_l0o`02o`00o`;ooooo
0_oo0002ooooo`?oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?oooooo
ogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?oogl00_ooool0
0ol0o`3o003ooomo0002oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo
0?ooO`03ool000Wooooo0_ooO`05ooooo`;oogl00ooo0002ooooo`;oogl00ooo0004ooooo`03o`00
0?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`;oo`0000Co
ooooo`00ooooO`3oogl01?ooool01?l00?ooogl0oomo0?ooO`02ool00003ooooool00?ooogl000;o
ogl000?oooooo`3o0?l0o`000_l00?l3ooooo`;o0?l00_l00?l3ooooo`;o0?l000Co003ooomo0?oo
O`3oogl00_oo00000ooooooo003ooomo0002oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo
00;oo`000_ooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool0
0004ooooooooO`3oogl0oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0000
1?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00?oo`000_ooool2oomo00?ooooo
0_l00?l2oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo00?oo`000_ooool2oomo00;ooooo
00Go0?l0o`00ool00?oo003oooooo`03ool000;ooooo0_ooO`03ool000;ooooo0_ooO`000ooooooo
o`00ool00009ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00006ooooo`04
o`3o0?l00?oo003oo`00o`Kooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo0_l0o`02o`00
o`Gooooo00Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo00000_ooool2
oomo00Cooooo00Co003ooomo0?ooO`3ooooo0_oo0002ooooo`;oogl01Oooool2oomo00Gooooo0ooo
O`02ool000;ooooo0oooO`04ooooo`?oogl00_oo0002ooooo`?oogl00_oo0006ooooo`;o0?l00_l0
0?l6ooooo`?oogl01?ooool3oomo00?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0
oomo0?ooO`03ool00004ooooooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?oogl00_ooool00ol0
o`3o003ooomo0002oomo00?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00?oo`002Oooool2
oomo00Gooooo0_ooO`03ool000;ooooo0_ooO`03ool000Cooooo00?o0000ooooooooool03?ooool0
02;ooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo0_oo00001?oooooo003ooomo0?ooO`04
ooooo`04o`00ooooO`3oogl0oomo00;oo`0000?oooooo`00ooooO`000_ooO`000ooooooo0?l0o`3o
0002o`00o`?ooooo0_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool00003oooo
ool00?ooogl000;oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl0
1?ooool3oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`0000Cooooooomo0?ooO`3o
ogl01?ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool00004ooooooooO`3oogl0oomo
00?oo`0000Cooooooomo0?ooO`3oogl00ooo0002ooooo`;oogl00oooool2o`00o`;oogl00ooo0002
ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo
0002ooooo`;oogl00ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?o
ooooool00?oo00001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Gooooo
0_ooO`02ooooo`;o0?l00_l00?l5ooooo`04o`00ooooO`3oogl0ooooo`;oo`000_ooool2oomo0003
oooooooo003oo`0000;ooooo0_ooO`04ooooo`04o`00ooooO`3oogl0ooooo`;oo`000_ooool2oomo
00Gooooo0_ooO`05ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool000;ooooo0oooO`02ool0
00Kooooo0_l0o`02o`00o`Kooooo0oooO`04ooooo`?oogl00ooo00001?ooooooogl0oomo0?ooO`03
ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl01?ooool3oomo00Cooooo
0oooO`02ooooo`03o`3o0?l00?ooogl000;oogl00ooo0004ooooo`?oo`001?ooool3ool000Wooooo
0_ooO`05ooooo`;oogl00ooo0002ooooo`;oogl00ooo0004ooooo`03o`000?oooooooooo00cooooo
000Rooooo`03o`000?oooooooooo00;o0?l00_l00?l2ooooo`;oo`0000Coooooo`00ooooO`3oogl0
1?ooool01?l00?ooogl0oomo0?ooO`02ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`?o
oooo0_l0o`02o`00o`?ooooo0_l0o`001?l00?ooogl0oomo0?ooO`02ool00003ooooool00?ooogl0
00;oogl000?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl01?ooool3oomo
00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`002?ooool3oomo00;ooooo00?o0?l0o`00
ool00?l00_ooool3ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl01Ooo
ool2oomo00?ooooo0_l00?l2oomo00?oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_oo
ool01Ol0o`3o003oo`00ool00?oooooo00?oo`001?ooool3ool000Gooooo0_oo0009ooooo`;oogl0
1Oooool2oomo00Gooooo0_ooO`000oooooooo`00ool00006ooooo`04o`3o0?l00?oo003oo`00o`Ko
oooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo0_l0o`02o`00o`Gooooo00Co003ooomo0?oo
O`3ooooo0_oo0002ooooo`;oogl000?oooooool00?oo00000_ooool2oomo00Cooooo0_l00?l2oooo
o`;oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool0
00;ooooo0oooO`02ool000Kooooo0_l0o`02o`00o`Kooooo0oooO`04ooooo`?oogl00ooo0004oooo
o`?oo`0000Cooooooomo0?ooO`3oogl00ooo00001?ooooooogl0oomo0?ooO`04ooooo`?oogl01?oo
ool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0004ooooo`?oo`002Ooo
ool2oomo00Gooooo0_ooO`03ool000;ooooo0_ooO`03ool000Cooooo00?o0000ooooooooool03?oo
ool002;ooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo0_oo00001?oooooo003ooomo0?oo
O`04ooooo`04o`00ooooO`3oogl0oomo00;oo`000_ooool3oomo0003ooooool0o`3o0?l000;o003o
0oooool2o`3o00;o003o0oooool2o`3o00;o003o0_ooool2ool00003ooooool00?ooogl000;oogl0
00?oooooo`3o0?l0o`000_l00?l6ooooo`?oogl00_oo0002ooooo`?oogl01?ooool3oomo00;ooooo
00?o0?l0o`00ool00?l01_ooool3oomo00?oo`002?ooool3oomo00;ooooo00?o0?l0o`00ool00?l0
0_ooool3ool00004ooooooooO`3oogl0oomo00?oo`0000Cooooooomo0?ooO`3oogl01Oooool2oomo
00?ooooo0_l00?l2oomo00?oo`000_ooool2oomo00Gooooo0_ooO`05ooooo`;oogl00_ooool01Ol0
o`3o003oo`00ool00?oooooo00?oo`001?ooool3ool000Gooooo0_oo0009ooooo`;oogl01Oooool2
oomo00Gooooo0_ooO`000oooooooo`00ool00006ooooo`04o`3o0?l00?oo003oo`00o`Kooooo0_oo
O`05ooooo`;oogl01Oooool2oomo00;ooooo0_l0o`02o`00o`Gooooo00Co003ooomo0?ooO`3ooooo
0_oo0005ooooo`;oo`002?ooool2o`00o`;ooooo0_oo0002ooooo`;oogl01Oooool2oomo00Gooooo
0oooO`04ooooo`?oogl01?ooool3oomo00;oo`000_ooool3oomo00;oo`001_ooool2o`3o00;o003o
1_ooool3oomo00Cooooo0oooO`03ool000Cooooo0ooo00001?ooooooogl0oomo0?ooO`03ool00004
ooooooooO`3oogl0oomo00Cooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02oooo
o`?oo`001?ooool3ool000Cooooo0ooo0009ooooo`;oogl01Oooool2oomo00?oo`000_ooool2oomo
00?oo`001?ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`02o`3o00;o
003o0_ooool2ool000;ooooo0_ooO`04ooooo`04o`00ooooO`3oogl0oomo00;oo`000_ooool3oomo
0003ooooool0o`3o0?l000;o003o0oooool2o`3o00;o003o0oooool2o`3o00;o003o0_ooool2ool0
00;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ool000;ooooo0oooO`04oooo
o`?oogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0008ooooo`?oogl00_ooool00ol0
o`3o003oo`00o`02ooooo`?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00Gooooo0_ooO`03
ooooo`;o003o0_ooO`03ool000;ooooo0_ooO`05ooooo`;oogl01Oooool2oomo00;ooooo00Go0?l0
o`00ool00?oo003oooooo`03ool000Cooooo0ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_oo
O`05ooooo`;oogl000?oooooool00?oo00001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl0
1Oooool2oomo00Gooooo0_ooO`02ooooo`;o0?l00_l00?l5ooooo`04o`00ooooO`3oogl0ooooo`;o
o`001Oooool2ool000Sooooo0_l00?l2ooooo`;oo`000_ooool2oomo00Gooooo0_ooO`0<ooooo`?o
ogl01?ooool3oomo00;oo`000_ooool3oomo00;oo`001_ooool2o`3o00;o003o1_ooool3oomo00Co
oooo0oooO`03ool000Cooooo0ooo00001?ooooooogl0oomo0?ooO`03ool00004ooooooooO`3oogl0
oomo00Cooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3
ool000Cooooo0ooo0009ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`03ool000Cooooo00?o0000
ooooooooool03?ooool002;ooooo00?o0000ooooooooool00_l0o`02o`00o`;ooooo0_oo0002oooo
o`;oogl01Oooool3oomo00;oo`000_ooool3oomo0003ooooool0o`3o0?l000;o003o0oooool2o`3o
00;o003o0oooool2o`3o00;o003o0_ooool2ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00
o`Kooooo0oooO`02ool000;ooooo0oooO`04ooooo`?oogl00_ooool00ol0o`3o003oo`00o`06oooo
o`?oogl00ooo0008ooooo`?oogl00_ooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool0
0004ooooooooO`3oogl0oomo00Gooooo0_ooO`03ooooo`;o003o0_ooO`03ool000;ooooo0_ooO`05
ooooo`;oogl01Oooool2oomo00;ooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo
0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`05ooooo`;oogl000?oooooool00?oo00001_oo
ool01?l0o`3o003oo`00ool00?l6ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`02ooooo`;o0?l0
0_l00?l5ooooo`04o`00ooooO`3oogl0ooooo`;oo`001Oooool2ool000Sooooo0_l00?l2ooooo`;o
o`002Oooool2oomo00cooooo0oooO`04ooooo`?oogl00_oo0002ooooo`?oogl00_oo0006ooooo`;o
0?l00_l00?l=ooooo`?oogl00ooo0004ooooo`?oo`0000Cooooooomo0?ooO`3oogl00ooo0008oooo
o`?oogl01?ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0004oooo
o`?oo`002Oooool2oomo00kooooo0ooo0004ooooo`03o`000?oooooooooo00cooooo000Rooooo`03
o`000?oooooooooo00;o0?l00_l00?l2ooooo`;oo`000_ooool2oomo00Gooooo0oooO`02ool000;o
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo0_l0o`02o`00o`Gooooo0_l00?l2ooooo`;o
o`000_ooool3oomo0003ooooool0o`3o0?l000;o003o1_ooool3oomo00;oo`000_ooool3oomo00Co
oooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Sooooo0oooO`02ooooo`03
o`3o0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`0000Cooooooomo0?ooO`3oogl01Oooool2oomo
00?ooooo0ol00?l01?ooooooo`00ool00?oo0009ooooo`;oogl01Oooool2oomo00;ooooo00Go0?l0
o`00ool00?oo003oooooo`03ool000Cooooo0ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_oo
O`05ooooo`;oogl000?oooooool00?oo00001_ooool01?l0o`3o003oo`00ool00?l6ooooo`;oogl0
1Oooool2oomo00Gooooo0_ooO`02ooooo`;o0?l00_l00?l5ooooo`04o`00ooooO`3oogl0ooooo`;o
o`001Oooool2ool000Sooooo0_l00?l2ooooo`;oo`002Oooool2oomo00cooooo0oooO`04ooooo`?o
ogl00_oo0002ooooo`?oogl00_oo0006ooooo`;o0?l00_l00?l=ooooo`?oogl00ooo0004ooooo`?o
o`0000Cooooooomo0?ooO`3oogl02oooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o
00;ooooo0ooo0004ooooo`?oo`001?ooool3ool001Wooooo0ooo0004ooooo`03o`000?oooooooooo
00cooooo000Rooooo`?o00000_l0o`02o`00o`;ooooo0_oo0002ooooo`;oogl01Oooool3oomo00;o
o`000_ooool3oomo0003ooooool0o`3o0?l000;o003o0oooool2o`3o00;o003o1Oooool2o`00o`Ko
oooo0oooO`000ooooooo0?l0o`3o0002o`00o`Kooooo0oooO`02ool000;ooooo0oooO`04ooooo`?o
ogl00_ooool00ol0o`3o003oo`00o`06ooooo`?oogl00ooo0008ooooo`?oogl00_ooool00ol0o`3o
003oo`00o`02ooooo`?oo`001?ooool3ool00004ooooooooO`3oogl0oomo00Gooooo0_ooO`03oooo
o`?o003o00Coooooool00?oo003oo`002Oooool2oomo00Gooooo0_ooO`02ooooo`05o`3o0?l00?oo
003oo`00ooooool00ooo0004ooooo`?oo`001Oooool2ool000Wooooo0_ooO`05ooooo`;oogl01Ooo
ool2oomo0003oooooooo003oo`0000Kooooo00Co0?l0o`00ool00?oo003o1_ooool2oomo00Gooooo
0_ooO`05ooooo`;oogl00_ooool2o`3o00;o003o1Oooool2o`00o`;ooooo0_oo0005ooooo`;oo`00
2?ooool2o`00o`;ooooo0_oo0009ooooo`;oogl03?ooool3oomo00Cooooo0oooO`04ooooo`?oogl0
0_oo0006ooooo`;o0?l00_l00?l=ooooo`?oogl00ooo0004ooooo`?oo`0000Cooooooomo0?ooO`3o
ogl02oooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00;ooooo0ooo0004ooooo`?o
o`001?ooool3ool001Wooooo0ooo0003ooooo`;o00003_ooool002;ooooo00?o0000ooooooooool0
0_l0o`02o`00o`gooooo0oooO`02ool000;ooooo0oooO`000ooooooo0?l0o`3o0002o`00o`?ooooo
0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l00?l6ooooo`?oogl01?ooool3oomo00Cooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000Sooooo0oooO`02ooooo`03o`3o
0?l00?oo003o00;ooooo0ooo0004ooooo`?oo`0000Cooooooomo0?ooO`3oogl01Oooool2oomo00?o
oooo0ol00?l01?ooooooo`00ool00?oo0009ooooo`;oogl01Oooool2oomo00;ooooo00Go0?l0o`00
ool00?oo003oooooo`03ool000Cooooo0ooo0005ooooo`;oo`002Oooool2oomo00Gooooo0_ooO`05
ooooo`;oogl000?oooooool00?oo00001_ooool01?l0o`3o003oo`00ool00?l=ooooo`;oogl01Ooo
ool2oomo00;ooooo0_l0o`02o`00o`Gooooo0_l00?l2ooooo`;oo`001Oooool2ool000Sooooo0_l0
0?l2ooooo`;oo`002Oooool2oomo00cooooo0oooO`04ooooo`?oogl01?ooool3oomo00;oo`001_oo
ool2o`3o00;o003o3Oooool3oomo00?oo`001?ooool3ool000oooooo0oooO`04ooooo`?oogl00_oo
ool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000Cooooo0ooo000Iooooo`?oo`001?oo
ool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`02o`3o00;o003o3Oooool3
oomo00;oo`000_ooool3oomo0003ooooool0o`3o0?l000;o003o0oooool2o`3o00;o003o1Oooool2
o`00o`[ooooo0_l0o`02o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3oomo00;ooooo00?o0?l0
o`00ool00?l01_ooool3oomo00?oo`003Oooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3
ool00004ooooooooO`3oogl0oomo00Gooooo0_ooO`03ooooo`?o003o00Coooooool00?oo003oo`00
2Oooool2oomo00Gooooo0_ooO`02ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?o
o`001Oooool2ool000Wooooo0_ooO`05ooooo`;oogl01Oooool2oomo0003oooooooo003oo`0000Ko
oooo00Co0?l0o`00ool00?oo003o3Oooool2oomo00Gooooo0_ooO`02ooooo`;o0?l00_l00?l5oooo
o`;o003o0_ooool2ool000Gooooo0_oo0008ooooo`;o003o0_ooool2ool000Wooooo0_ooO`0<oooo
o`?oogl01?ooool3oomo00Cooooo0oooO`02ool000Kooooo0_l0o`02o`00o`gooooo0oooO`03ool0
00Cooooo0ooo000?ooooo`?oogl01?ooool3oomo00;ooooo00?o0?l0o`00ool00?l00_ooool3ool0
00Cooooo0ooo0004ooooo`?oo`006Oooool3ool000Cooooo00?o0000ooooooooool03?ooool002;o
oooo00?o0000ooooooooool00_l0o`02o`00o`gooooo0oooO`02ool000;ooooo0oooO`000ooooooo
0?l0o`3o0002o`00o`?ooooo0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l00?l6ooooo`?o
ogl01?ooool3oomo00Cooooo0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000go
oooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0009ooooo`;oogl00oooool3o`00o`04
oooooooo003oo`00ool000Wooooo0_ooO`05ooooo`;oogl00_ooool01Ol0o`3o003oo`00ool00?oo
oooo00?oo`001?ooool3ool000Gooooo0_oo0009ooooo`;oogl01Oooool2oomo00Gooooo0_ooO`00
0oooooooo`00ool00006ooooo`04o`3o0?l00?oo003oo`00o`gooooo0_ooO`05ooooo`;oogl00_oo
ool2o`3o00;o003o1Oooool2o`00o`;ooooo0_oo0005ooooo`;oo`002?ooool2o`00o`gooooo0_oo
O`0<ooooo`?oogl01?ooool3oomo00Cooooo0oooO`02ool000Kooooo0_l0o`02o`00o`gooooo0ooo
O`03ool000Cooooo0ooo000?ooooo`?oogl02_ooool2o`00o`;ooooo0ooo0004ooooo`?oo`001?oo
ool3ool001Wooooo0ooo0004ooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00;o0?l00_l00?l=ooooo`?oogl01?ooool3oomo0003ooooool0o`3o0?l000;o003o0oooool2
o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00o`Kooooo0oooO`04ooooo`?oogl01?ooool3
oomo00;ooooo00?o0?l0o`00ool00?l01_ooool3oomo00?oo`003Oooool00ol0o`3o003oo`00o`02
ooooo`?oo`001?ooool3ool000Wooooo0_ooO`03ooooo`?o003o00Coooooool00?oo003oo`004?oo
ool2oomo00;ooooo00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0005ooooo`;oo`00
4?ooool2oomo00Sooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00oaCooooo0_ooO`02ooooo`;o
0?l00_l00?l5ooooo`;o003o0_ooool2ool000Gooooo0_oo0008ooooo`;o003o6oooool3oomo00Co
oooo0oooO`04ooooo`?oogl00_oo0006ooooo`;o0?l00_l00?l=ooooo`?oogl00ooo0004ooooo`?o
o`007?ooool2o`00o`;ooooo0ooo0004ooooo`?oo`001?ooool3ool001Wooooo0ooo0004ooooo`03
o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00;o0?l00_l00?l=ooooo`?oogl0
2?ooool2o`3o00;o003o0oooool2o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00oaCooooo
0oooO`02ooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000gooooo00?o0?l0o`00ool00?l0
0_ooool3ool000Cooooo0ooo0009ooooo`;oogl00oooool3o`00o`04oooooooo003oo`00ool0013o
oooo0_ooO`02ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`001Oooool2ool0
013ooooo0_ooO`08ooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?lDooooo`;oogl00_ooool2
o`3o00;o003o1Oooool2o`00o`;ooooo0_oo0005ooooo`;oo`002?ooool2o`00oa_ooooo0oooO`04
ooooo`?oogl01oooool2ool000Kooooo0_l0o`02o`00o`gooooo0oooO`03ool002?ooooo0_l00?l2
ooooo`?oo`001?ooool3ool000Cooooo0ooo000Iooooo`?oo`001?ooool00ol0003oooooooooo`0<
ooooo`008_ooool00ol0003oooooooooo`02o`3o00;o003o3Oooool3oomo00Sooooo0_l0o`02o`00
o`?ooooo0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l00?lIooooo`03o`3o0?l00?oo003o
00Kooooo0oooO`03ool000gooooo00?o0?l0o`00ool00?l00_ooool3ool000Cooooo0ooo0009oooo
o`;oogl00oooool3o`00o`04oooooooo003oo`00ool0013ooooo0_ooO`02ooooo`05o`3o0?l00?oo
003oo`00ooooool00ooo0004ooooo`?oo`001Oooool2ool001[ooooo0_oo0006ooooo`04o`3o0?l0
0?oo003oo`00oaCooooo0_ooO`02ooooo`;o0?l00_l00?l5ooooo`;o003o0_ooool2ool000Gooooo
0_oo0008ooooo`;o003o6oooool3oomo00Cooooo0oooO`07ooooo`;oo`002?ooool2o`00o`gooooo
0oooO`03ool002?ooooo0_l00?l2ooooo`?oo`001?ooool3ool000Cooooo0ooo000Iooooo`?oo`00
1?ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`02o`3o00;o003o3Ooo
ool3oomo00Sooooo0_l0o`02o`00o`?ooooo0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l0
0?lIooooo`03o`3o0?l00?oo003o00Kooooo0oooO`03ool000gooooo00?o0?l0o`00ool00?l00_oo
ool3ool000Cooooo0ooo0009ooooo`;oogl00oooool3o`00o`04oooooooo003oo`00ool001Cooooo
00Go0?l0o`00ool00?oo003oooooo`03ool000Cooooo0ooo0005ooooo`;oo`006_ooool2ool000Ko
oooo00Co0?l0o`00ool00?oo003o6?ooool2o`3o00;o003o1Oooool2o`00o`;ooooo0_oo0005oooo
o`;oo`002?ooool2o`00oa_ooooo0oooO`0>ooooo`;oo`002?ooool2o`00o`gooooo0oooO`03ool0
02?ooooo0_l00?l2ooooo`?oo`001?ooool3ool000Cooooo0ooo000Iooooo`?oo`001?ooool00ol0
003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`02o`3o00;o003o3Oooool3oomo00So
oooo0_l0o`02o`00o`?ooooo0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l00?lIooooo`03
o`3o0?l00?oo003o00Kooooo0oooO`03ool000gooooo00?o0?l0o`00ool00?l00_ooool3ool000Co
oooo0ooo000>ooooo`?o003o00Coooooool00?oo003oo`005?ooool01Ol0o`3o003oo`00ool00?oo
oooo00?oo`001?ooool3ool000Gooooo0_oo000Jooooo`;oo`001_ooool01?l0o`3o003oo`00ool0
0?lHooooo`;o0?l00_l00?l5ooooo`;o003o0_ooool2ool000Gooooo0_oo0008ooooo`;o003o6ooo
ool3oomo00kooooo0_oo0008ooooo`;o003o3Oooool3oomo00?oo`008oooool2o`00o`;ooooo0ooo
0004ooooo`?oo`001?ooool3ool001Wooooo0ooo0004ooooo`03o`000?oooooooooo00cooooo000R
ooooo`03o`000?oooooooooo00;o0?l00_l00?l=ooooo`?oogl02?ooool2o`3o00;o003o0oooool2
o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00oaWooooo00?o0?l0o`00ool00?l01_ooool3
oomo00?oo`003Oooool00ol0o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000kooooo0ol00?l0
1?ooooooo`00ool00?oo000Dooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`00
1Oooool2ool001[ooooo0_oo0006ooooo`04o`3o0?l00?oo003oo`00oaSooooo0_l0o`02o`00o`Go
oooo0_l00?l2ooooo`;oo`001Oooool2ool000Sooooo0_l00?lKooooo`?oogl03_ooool2ool000So
oooo0_l00?l@ooooo`?oo`008oooool2o`00o`;ooooo0ooo0004ooooo`?oo`001?ooool3ool001Wo
oooo0ooo0004ooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00;o0?l0
0_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5ooooo`;o003o2_ooool2o`3o00;o003o
6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`003Oooool00ol0o`3o003oo`00o`02ooooo`?oo`00
1?ooool3ool000kooooo0ol00?l01?ooooooo`00ool00?oo000Dooooo`05o`3o0?l00?oo003oo`00
ooooool00ooo0004ooooo`?oo`001Oooool2ool001[ooooo0_oo0006ooooo`04o`3o0?l00?oo003o
o`00oaSooooo0_l0o`02o`00o`Gooooo0_l00?l2ooooo`;oo`001Oooool2ool000Sooooo0_l00?lK
ooooo`?oogl03_ooool2ool000Sooooo0_l00?l@ooooo`?oo`008oooool2o`00o`;ooooo0ooo0004
ooooo`?oo`001?ooool3ool001Wooooo0ooo0004ooooo`03o`000?oooooooooo00cooooo000Roooo
o`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5oooo
o`;o003o2_ooool2o`3o00;o003o6Oooool00ol0o`3o003oo`00o`09ooooo`?oo`003Oooool00ol0
o`3o003oo`00o`02ooooo`?oo`001?ooool3ool000kooooo0ol00?l01?ooooooo`00ool00?oo000D
ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo0004ooooo`?oo`001Oooool2ool001[ooooo0_oo
0006ooooo`04o`3o0?l00?oo003oo`00oaSooooo0_l0o`02o`00o`Gooooo0_l00?l2ooooo`;oo`00
3oooool2o`00oa_ooooo0oooO`0>ooooo`;oo`002?ooool2o`00oa3ooooo0ooo000Sooooo`;o003o
0_ooool3ool000Cooooo0ooo0004ooooo`?oo`008?ooool00ol0003oooooooooo`0<ooooo`008_oo
ool3o`0000;o0?l00_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5ooooo`;o003o2_oo
ool2o`3o00;o003o6_ooool2o`00o`Wooooo0ooo000=ooooo`03o`3o0?l00?oo003o00;ooooo0ooo
0004ooooo`?oo`003_ooool3o`00oaSooooo00Go0?l0o`00ool00?oo003oooooo`03ool000cooooo
0_oo000Jooooo`;oo`001_ooool01?l0o`3o003oo`00ool00?lJooooo`;o003o1Oooool2o`00oa?o
oooo0_l00?l/ooooo`;oo`002?ooool2o`00oa3ooooo0ooo000Sooooo`;o003o0_ooool3ool000Co
oooo0ooo0004ooooo`?oo`007oooool2o`0000kooooo000Rooooo`03o`000?oooooooooo00;o0?l0
0_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5ooooo`;o003o2_ooool2o`3o00;o003o
6_ooool2o`00o`Wooooo0ooo000=ooooo`03o`3o0?l00?oo003o00;ooooo0ooo000Eooooo`?o003o
6?ooool01Ol0o`3o003oo`00ool00?oooooo00?oo`003?ooool2ool001[ooooo0_oo0006ooooo`04
o`3o0?l00?oo003oo`00oa[ooooo0_l00?l5ooooo`;o003o4oooool2o`00obcooooo0_oo0008oooo
o`;o003o4?ooool3ool002?ooooo0_l00?l2ooooo`?oo`002oooool3ool0023ooooo00?o0000oooo
ooooool03?ooool002;ooooo00?o0000ooooooooool00_l0o`02o`00oaSooooo0_l0o`02o`00o`?o
oooo0_l0o`02o`00o`Gooooo0_l00?l:ooooo`;o0?l00_l00?lJooooo`;o003o2Oooool3ool000go
oooo00?o0?l0o`00ool00?l00_ooool3ool001Gooooo0ol00?lHooooo`05o`3o0?l00?oo003oo`00
ooooool00ooo000<ooooo`;oo`006_ooool2ool000Kooooo00Co0?l0o`00ool00?oo003o6_ooool2
o`00oa[ooooo0_l00?l/ooooo`;oo`002?ooool2o`00oa3ooooo0ooo000Sooooo`;o003o0_ooool3
ool000_ooooo0ooo000Pooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
00;o0?l00_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5ooooo`;o003o2_ooool2o`3o
00;o003o6_ooool2o`00o`Wooooo0ooo000=ooooo`03o`3o0?l00?oo003o00;ooooo0ooo000`oooo
o`05o`3o0?l00?oo003oo`00ooooool00ooo000<ooooo`;oo`006_ooool2ool000Kooooo00Co0?l0
o`00ool00?oo003o6_ooool2o`00oa[ooooo0_l00?l/ooooo`;oo`002?ooool2o`00oa3ooooo0ooo
000Sooooo`;o003o0_ooool3ool000_ooooo0ooo000Pooooo`03o`000?oooooooooo00cooooo000R
ooooo`03o`000?oooooooooo00;o0?l00_l00?lHooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5
ooooo`;o003o2_ooool2o`3o00;o003o6_ooool2o`00o`Wooooo0ooo000=ooooo`03o`3o0?l00?oo
003o00;ooooo0ooo000`ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo000Xooooo`;oo`001_oo
ool01?l0o`3o003oo`00ool00?lJooooo`;o003o6_ooool2o`00obcooooo0_oo0008ooooo`;o003o
4?ooool3ool002?ooooo0_l00?l2ooooo`?oo`002oooool3ool0023ooooo00?o0000ooooooooool0
3?ooool002;ooooo00?o0000ooooooooool00ol0o`0Iooooo`;o0?l00_l00?l3ooooo`;o0?l00_l0
0?l5ooooo`;o003o2_ooool2o`3o00;o003o6_ooool2o`00o`Wooooo0ooo000=ooooo`03o`3o0?l0
0?oo003o00;ooooo0ooo000`ooooo`05o`3o0?l00?oo003oo`00ooooool00ooo000`ooooo`04o`3o
0?l00?oo003oo`00oa[ooooo0_l00?lJooooo`;o003o=_ooool2o`00oa3ooooo0ooo000Sooooo`;o
003o0_ooool3ool000_ooooo0ooo000Pooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`00
0?oooooooooo00?o0?l06Oooool2o`3o00;o003o0oooool2o`3o00;o003o1Oooool2o`00o`[ooooo
0_l0o`02o`00oa[ooooo0_l00?l9ooooo`?oo`003Oooool00ol0o`3o003oo`00o`0eooooo`04o`3o
0?l00?oo003oo`00ocGooooo0ol00?lJooooo`;o003o6_ooool2o`00ocKooooo0_l00?l@ooooo`?o
o`008oooool2o`00o`;ooooo0ooo000;ooooo`?oo`008?ooool00ol0003oooooooooo`0<ooooo`00
8_ooool00ol0003oooooooooo`03o`3o01Wooooo0_l0o`02o`00o`?ooooo0_l0o`02o`00o`Gooooo
0_l00?l:ooooo`;o0?l00_l00?lJooooo`;o003o2Oooool3ool000gooooo00?o0?l0o`00ool00?l0
=Oooool01?l0o`3o003oo`00ool00?mBooooo`;o003o6_ooool2o`00ocKooooo0_l00?l@ooooo`?o
o`008oooool2o`00o`;ooooo0ooo000;ooooo`?oo`008?ooool00ol0003oooooooooo`0<ooooo`00
8_ooool00ol0003oooooooooo`03o`3o01Wooooo0_l0o`02o`00o`?ooooo0_l0o`02o`00o`Gooooo
0_l00?l:ooooo`;o0?l00_l00?lJooooo`;o003o6Oooool00ol0o`3o003oo`00o`0fooooo`?o003o
D_ooool2o`00oa[ooooo0_l00?lfooooo`;o003o=_ooool2o`00o`;ooooo0ooo000^ooooo`03o`00
0?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l06Oooool2o`3o00;o003o0ooo
ool2o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00oa[ooooo0_l00?lIooooo`03o`3o0?l0
0?oo003o03Kooooo0ol00?mBooooo`;o003o6_ooool2o`00ocKooooo0_l00?lfooooo`;o003o0_oo
ool3ool002kooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`0I
ooooo`;o0?l00_l00?l3ooooo`;o0?l00_l00?l5ooooo`;o003o2_ooool2o`3o00;o003o6_ooool2
o`00oaWooooo00?o0?l0o`00ool00?l0=_ooool3o`00oe;ooooo0_l00?lJooooo`;o003o=_ooool2
o`00ocKooooo0_l00?lcooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
00?o0?l06Oooool2o`3o00;o003o0oooool2o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00
oa[ooooo0_l00?lIooooo`03o`3o0?l00?oo003o03Kooooo0ol00?mBooooo`;o003o6_ooool2o`00
ocKooooo0_l00?lfooooo`;o003o<oooool00ol0003oooooooooo`0<ooooo`008_ooool3o`0000?o
0?l06Oooool2o`3o00;o003o0oooool2o`3o00;o003o1Oooool2o`00o`[ooooo0_l0o`02o`00oa[o
oooo0_l00?lIooooo`;o0?l0S?ooool2o`00oa[ooooo0_l00?lfooooo`;o003o=_ooool2o`00oc;o
oooo0_l0000>ooooo`008_ooool00ol0003oooooooooo`03o`3o01Wooooo0_l0o`02o`00o`Gooooo
0_l00?l5ooooo`;o003o2_ooool2o`3o00;o003o6_ooool2o`00oaWooooo0_l0o`2<ooooo`;o003o
6_ooool2o`00ocKooooo0_l00?lfooooo`;o003o<oooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`03o`3o01Wooooo0_l0o`02o`00o`Gooooo0_l00?l5ooooo`;o003o2_oo
ool2o`3o00;o003o6_ooool2o`00oaWooooo0_l0o`2<ooooo`;o003o6_ooool2o`00ocKooooo0_l0
0?lfooooo`;o003o<oooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o01Wooooo0_l0o`02o`00o`cooooo0_l00?l:ooooo`;o0?l00_l00?leooooo`;o0?l0S?ooool2
o`00okoooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`0Ioooo
o`;o0?l00_l00?l<ooooo`;o003o2_ooool2o`3o00;o003o=Oooool2o`3o08cooooo0_l00?nooooo
o`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l06Oooool2o`3o00;o
003o3?ooool2o`00o`[ooooo0ol0o`0fooooo`;o0?l0S?ooool2o`00okoooooo00?o0000oooooooo
ool03?ooool002;ooooo00?o0000ooooooooool00ol0o`0Iooooo`;o0?l00_l00?l<ooooo`;o003o
2_ooool3o`3o0<Cooooo0_l00?noooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l06Oooool2o`3o00;o003o3?ooool2o`00o`[ooooo0ol0o`34ooooo`;o003o_ooo
ool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o01Wooooo0_l0o`02
o`00o`cooooo0_l00?l:ooooo`?o0?l0oooooon6ooooo`03o`000?oooooooooo00cooooo000Roooo
o`03o`000?oooooooooo00?o0?l06Oooool2o`3o00;o003o3?ooool2o`00o`[ooooo0ol0o`3ooooo
ohKooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`0Kooooo`;o
003o3?ooool2o`00o`[ooooo0ol0o`3oooooohKooooo00?o0000ooooooooool03?ooool002;ooooo
0ol00003o`3o01_ooooo0_l00?l<ooooo`;o003o2_ooool3o`3o0?ooooooQOooool2o`0000kooooo
000Rooooo`03o`000?oooooooooo00?o0?l06oooool2o`00o`cooooo0_l00?oooooooi?ooooo00?o
0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`0Kooooo`;o003ooooooonQ
ooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l06oooool2o`00
ooooooooXOooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o01_o
oooo0_l00?oooooooj7ooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0
0ol0o`0Kooooo`;o003ooooooonQooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000=ooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`0<ooooo`003?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool000cooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000<ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01_ooool3o`0000?o0?l0oooooonlooooo`?o00003_ooool000cooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000<ooooo`04o`000?ooooooooooo`0000So
oooo0_l00008ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00co
oooo000=ooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03
o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`00
0?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oo
oooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00cooooo000Rooooo`?o00000ol0o`3ooooookgooooo0_l0000>ooooo`008_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo
__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__oo
ool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`0<ooooo`008_ooool3o`0000?o0?l0oooooonmooooo`;o00003_ooool002;ooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooo
okkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookko
oooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool03?ooool002;ooooo0ol00003o`3o0?oooooo_Oooool2o`0000kooooo000Roooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnoooo
o`03o`000?oooooooooo00cooooo000Rooooo`?o00000ol0o`3ooooookgooooo0_l0000>ooooo`00
8_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003Oooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00006ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00cooooo000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo0ol00003o`3o0?oooooo_?oo
ool3o`0000kooooo000<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`0<ooooo`003Oooool2o`0000Wooooo0ol00007ooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o
0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0
oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooo
oonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonn
ooooo`03o`000?oooooooooo00cooooo000Rooooo`?o00000ol0o`3ooooookgooooo0_l0000>oooo
o`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`00
8_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool3o`0000?o0?l0oooooonmooooo`;o
00003_ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
3?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?oo
ool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool0
02;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;o
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo0ol00003o`3o0?oooooo_Ooo
ool2o`0000kooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00co
oooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo
000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000R
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Roooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`?o00000ol0o`3ooooo
okgooooo0_l0000>ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<
ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<oooo
o`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`00
8_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool03?ooool000cooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool03?ooool000cooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`04ooooo`?o00000ol0o`3ooooookcooooo0ol0000>ooooo`003?ooool01?l0003oooooooooool0
0009ooooo`;o00001oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`0<ooooo`003?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool000cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`?o00001ooo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool3o`0000?o0?l0oooooonmooooo`;o
00003_ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
3?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?oo
ool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool0
02;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;o
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo0ol00003o`3o0?oooooo_Ooo
ool2o`0000kooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooo
oooo00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo
00cooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00co
oooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo
000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000R
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Roooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`?o00000ol0o`3o
oooookgooooo0_l0000>ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003o
ooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooo
ooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003ooooooooo
o`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<
ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<oooo
o`008_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`00
8_ooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool3o`0000?o
0?l0oooooonmooooo`;o00003_ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo
00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o
0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000
ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooo
ooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000oooooooo
ool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool0
3?ooool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?oo
ool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool0
00gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo
00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000<ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0
003oooooooooo`0<ooooo`003?ooool01?l0003oooooooooool00007ooooo`Go00001_ooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0ol00003o`3o0?oooooo_?ooool3
o`0000kooooo000<ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`003?ooool01?l0
003oooooooooool00009ooooo`;o00001oooool00ol0003oooooooooo`03o`3o0?oooooo__ooool0
0ol0003oooooooooo`0<ooooo`003Oooool2o`0000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003o
ooooooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooo
ooooo`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003ooooooooo
o`03o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03
o`3o0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o
0?oooooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oo
oooo__ooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`03o`3o0?oooooo
__ooool00ol0003oooooooooo`0<ooooo`008_ooool3o`0000?o0?l0oooooonmooooo`;o00003_oo
ool002;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool0
02;ooooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;o
oooo00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo
00?o0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o
0000ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000
ooooooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooo
ooooool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000oooooooo
ool00ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0
0ol0o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0
o`3ooooookkooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool00ol0o`3o
oooookkooooo00?o0000ooooooooool03?ooool002;ooooo0ol00003o`3o0?oooooo_Oooool2o`00
00kooooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00co
oooo000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo
000Rooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000R
ooooo`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Roooo
o`03o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03
o`000?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`00
0?oooooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oo
oooooooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooo
oooo00?o0?l0oooooonnooooo`03o`000?oooooooooo00cooooo000Rooooo`03o`000?oooooooooo
0?oooooo`Oooool00ol0003oooooooooo`0<ooooo`008_ooool00ol0003oooooooooo`3ooooool7o
oooo00?o0000ooooooooool03?ooool002;ooooo0ol0003ooooool3ooooo0_l0000>ooooo`008_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool002;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo000Rooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`008_ooooooo`000<Go00003_oo
ool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00?oooooomOoo
ool00?oooooomOooool00?oooooomOooool002Gooooo0ol00003ooooo`Go00000oooool3o`0000Go
oooo0ol00003ooooo`?o00001?ooool3o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Co
oooo0_l00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000Co
oooo0ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00003ooooo`Co00000oooool5o`0000;o
oooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go00000_ooool5o`0000;o
oooo1Ol00002ooooo`Go00000_ooool5o`0000;ooooo1Ol00002ooooo`Co00001?ooool3o`0000?o
oooo1?l00002ooooo`Go00000oooool4o`0000Cooooo0ol00003ooooo`Go00000oooool4o`0000Co
oooo0ol00003ooooo`Co00000oooool5o`0000?ooooo1?l00002ooooo`Go000000?oooooo`000?l0
00001?l00002ooooo`Go00000oooool4o`0000;ooooo1Ol00002ooooo`Go00000oooool4o`0000;o
oooo1Ol00002ooooo`Co00001?ooool3o`0000?ooooo1?l00002ooooo`Go00000oooool4o`0000Co
oooo0ol00003ooooo`Co00000oooool4o`0000Cooooo0ol00003ooooo`Co00000oooool4o`0000Co
oooo0ol00003ooooo`Co00000_ooool5o`0000?ooooo1?l00004ooooo`?o00003_ooool002Kooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003o00001?ooool2o`00
00Cooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`02o`0000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Cooooo0_l0
0003ooooo`03o`000?oooooooooo00;o00001?ooool2o`000004ooooool0003oooooooooo`;o0000
00?oooooo`000?l000000oooool01?l0003oooooooooool00002ooooo`;o000000Soooooo`000?l0
003oooooo`000?oooooo0000ooooo`;o00000oooool2o`000007ooooool0003oooooo`000?oooooo
0000ooooo`02o`000005ooooool0003oooooo`000?ooool00_l00003ooooo`09o`000?oooooooooo
o`000?oooooo0000ooooool0003ooooo00;o00000_ooool01Ol0003oooooo`000?oooooo000000;o
oooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooooooool00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00ko0000ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`04o`000?oooooo0000o`0000;ooooo0_l00004ooooo`;o00000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000Gooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo
0_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool00ol0003oooooooooo`0=ooooo`009_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ol00006ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000004ooooo`04o`000?oooooo0000o`0000Cooooo0_l0
0005ooooo`;o00001_ooool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001Oooool2o`0000?ooooo
00Co0000ooooool0003o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool5o`0000Go
oooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00006ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00005ooooo`;o000000?oooooo`000?l000001?l0
0005ooooo`05o`000?oooooo0000ooooool000000oooool2o`0000Cooooo00Go0000ooooool0003o
ooooo`000003ooooo`;o00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`0000;o
oooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000;o
oooo1Ol000000ooooooo0000o`000004o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;o
00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l00000
0ooooooo0000o`000004o`0000Gooooo0_l000000ooooooo0000ooooo`02ooooo`;o00001?ooool0
1Ol0003oooooo`000?oooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`009_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01?l00006ooooo`03o`000?oooooooooo00;ooooo
0ol00004ooooo`Co000000?oooooo`000?ooool00oooool01?l0003oooooo`000?l00004ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000oooool01?l0003oooooooooool00006oooo
o`;o00000_ooool4o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Cooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000001Oooool2o`0000Cooooo0ol00002
ooooo`03o`000?oooooooooo00;o00001_ooool00ol0003oooooooooo`05o`0000Gooooo0_l00003
ooooo`Co00000oooool4o`0000?ooooo00Co0000ooooool0003o00001?ooool3o`0000Gooooo0_l0
0004ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000Kooooo0_l00002ooooo`Go00001Ooo
ool2o`0000?ooooo1?l00003ooooo`Co00000oooool01?l0003oooooooooool00003ooooo`;o0000
00?oooooo`000?ooool00_ooool01?l0003oooooo`000?l00003ooooo`Co00000_ooool2o`000003
ooooool0003o000000?ooooo00Co0000oooooooooooo00000_ooool5o`0000?ooooo00Co0000oooo
ool0003o00000oooool4o`0000?ooooo1Ol00002ooooo`03o`000?oooooooooo00;o00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooo000000?ooooo0_l000001?oooooo0000oooo
ool00002ooooo`03o`000?oooooo000000Gooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003ooooo00?ooooo00?o0000ooooool000000_ooool3o`000004ooooool0003oooooooooo`Co
00000oooool4o`0000?ooooo1?l00003ooooo`Co00000oooool4o`0000;ooooo00Co0000oooooooo
oooo00003oooool002Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooo000000Cooooo00Co0000ooooool0003o00001?ooool2o`0000?ooooo00?o0000oooo
ooooool00_l00005ooooo`;o00000oooool00ol0003oooooo`000003ooooo`Co00000oooool01?l0
003oooooooooool00006ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oooooo
0000o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool01_l0003oooooo`00
0?oooooo0000ooooo`Co000000?oooooo`000?ooool00_l00003ooooo`04o`000?ooooooooooo`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool00_ooool2o`00
00;ooooo00?o0000ooooooooool00_l00003ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool2o`0000Gooooo0_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo1?l00002ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo00;o
oooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo0_l000000ooooooo0000ooooo`03
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000004ooooo`03o`000?oo
oooo000000?ooooo1?l00002ooooo`Go00000_ooool01Ol0003oooooo`000?oooooo000000Cooooo
00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo1Ol00003ooooo`Co
00000oooool4o`0000;ooooo1Ol00003ooooo`Co00000oooool4o`0000;ooooo1Ol00002ooooo`Go
00000oooool4o`0000;ooooo1Ol00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000oooooo000Uooooo`;o0000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ooooool3o`0000Cooooo1?l00003ooooo`?o00000oooool00ol0003oooooo`000002o`0000;ooooo
00?o0000ooooool000000_l00004ooooo`;o00000oooool01?l0003oooooo`000?l00004ooooo`?o
00000oooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooool000000_l00002ooooo`;o
00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003o
ooooo`000?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol000000ooo
oooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o000000Koooooo`000?oooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo
00Co0000ooooool0003o00000oooool4o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03
o`000?oooooooooo00;o00001?ooool3o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04
o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo
00;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oo
ooooooooooooo`?o00000oooool2o`0000Kooooo00?o0000ooooooooool00oooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003
ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Cooooo00Go0000ooooool0003oooooo`00
0002ooooo`05o`000?oooooo0000ooooool000001?ooool2o`0000oooooo000Vooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`?o00001_ooool01?l0003oooooooooooooool5o`0000Cooooo
0_l00003ooooo`Go00000oooool3o`0000Cooooo0ol00002ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`;o00001?ooool3o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooooooo`Go
00001?ooool2o`0000?ooooo1Ol00003ooooo`?o00001?ooool4o`0000Cooooo0ol00004ooooo`?o
00000oooool4o`0000?ooooo1?l00004ooooo`?o00000_ooool5o`0000Cooooo0ol00002ooooo`Go
00000oooool4o`0000?ooooo1?l00004ooooo`?o00001?ooool3o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000;ooooo1_l00004ooooo`?o00000_ooool5o`0000?ooooo1?l00003ooooo`Co
00001?ooool3o`0000Cooooo00?o0000ooooool000000oooool4o`0000?ooooo1?l00005ooooo`;o
00000_ooool5o`0000Cooooo0ol00002ooooo`Go00000oooool4o`0000?ooooo1Ol00002ooooo`Go
00000_ooool5o`0000;ooooo1Ol00002ooooo`Go00000_ooool5o`000003ooooool0003o000000Co
00000_ooool5o`000003ooooool0003o000000Co00000_ooool5o`0000;ooooo1?l00004ooooo`?o
00001?ooool3o`0000?ooooo1?l00003ooooo`Co00001Oooool00ol0003oooooooooo`0=ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 499}, {308, 0}} -> {-4.27309, -0.0365428, 0.142355, \
0.00171764}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test images", "Subsection"],

Cell[CellGroupData[{

Cell["Define test image data", "Subsubsection"],

Cell[BoxData[{
    \(\(testPos1 = {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(testPos2 = {160, 320};\)\), "\[IndentingNewLine]", 
    \(\(testOffset = {4, 4};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize test image data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(testData = \(TakeMatrix[#, testPos1, testPos2] &\)\  /@ \ 
          texImages;\)\), "\[IndentingNewLine]", 
    \(\(testVis = \[IndentingNewLine]BlockMatrix[
          Partition[testData, 2]];\)\), "\[IndentingNewLine]", 
    \(\(ShowImage[testVis];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
%%ImageSize: 640 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0015625 0 0.0015625 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
640 string
640 320 8 [640 0 0 320 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AB5E5E7B85BA6E395C7E86B74630526966B16E2B4E835AA6CC4E2A66AE8DAB85335961AF
5A803D356783556C7F19495D6C416373245069613B7E455F6E983347592E5A6443326A35
526684383C5243348DA6333F7B422E75BF432F484D518E862F435856669E642B56577469
993F35516664AF5527536D556CA43F21458654AAB735414E6756A8C339435B6A57AB7F36
4E6A7564CD564561A67A87D5643A797C68A0C72F506B9C97A5912D5E71C184C93242778E
9B5C91324A6695775CB5545075A0517D8D445861613177484F5474463653364F72784977
5A4A8AB34945633F7EC36C43714D6ABB933B786788B2BC545A8651A2722A576B5462B64C
317C8A54B2B5494A957176C96C4250787471A84941526172AA8E313B4D6D9AC369314572
8096D66A3A3F7A7461C2473E6A6F66A6CC4F2A6DA57799D3591C63995251B663496493A9
C0884B695F55765153535B7E63716CBCA18166593048364B38562B4F38565F5E3D35443F
5756483D4D40392E4B534F3F56506B4F332D4C43504D504157934F4D40565158304A4E79
586597494660556B62516A689177476985848751514D71706D714D607A6574748377524F
767A84697B758A689B688686A07BA4707AA3648D9383AF57765F635C6A6281429A747FBB
47B6C6317B81364C4B5C4C3F5F464254577F4F4A486E773F624E5A5B4061625D601F6764
63723E514F7E7288AC232B496B4A69445E524C494F622A72595866314657374F62538766
817A2B495E4B513F87528246A588406F635A847B395C50616A5568467D47505C7174A25A
9CBA68B08094718FA16D9A6471797A9580546177767C7D8E5D718A788484527B6A9779C0
766F69A79E2C677233A8A34258456187899F83788456746CA58DAEAF
7B82765F4D848049763E45617065762A2590A04453491E3C95682F513759698A5137804B
52B36527426F327AB92D237093558FB22B2F756262D07D203D7F5170892B3E606057B12F
3462684F7A81214A40857C80B8243E4D76847FA430365F7B5171A21742445950BA832254
76725EA1273A798F4B545A283F71AB5F73403651987D67743D3656A27A5E87403E8BA654
5B704B45A9D04D676B423E8FAE3A8B543943957549543151629A61535A3078A07D3B588D
4260CB8F31647E6274DC673A6C786CC6E53835746D56CAA830666E6F8ACE43476C908CCF
9E27509E69B4B731368DBDA6B75B334DBB84BE5E356CA58A9D68445D7F4BAFA140478192
6B752B42669888C3BC5A4D96BF80B86F3E4F7D7F88AE3254589B6C81C13B47B8B4649AA3
4D519FAB506B36424BADA34677415155928137514F314D98AC5049693D6B705D4E57CBD1
CDB25475886B765F75746479687A7282655A4F5C4351506647634A624C686C7F4B3B6838
5F5767366B4B314361654C4574275C5E762F65622A4D7A7660534650435C525E49436260
7491B75B59A8B68388825D49B5AA6797B2B0A26A735C89843D61345B62403F64684F304C
5A43514E5E475350663D59826053553F747E71A0717FA18FA074888B83536F47646F9AB5
625D5A48718587B1675A71486C525551434C4D453B678E2E5A4C623F4650146B7221827F
425A3D6A37514E4B671F3A6F72447865826157603E5632B270556F585F8551626F729848
8F8A4D72717676477673AE48AF67317365454E5532575E626568755C7A5C5F6C694E5F55
D8B97568A7C5728CAF919E5A7875B2A1836289AFAF65465F53789388577463AA5C8B7F96
7FD572537338AE9644BEBD537D4542697E8B5D7D5F454D7B986C8AAB
7672A0793D5A7F8B81442C4D6578A43F1D2E737C74501B28537598A64F3E6A7C7E9FB639
3B64A152A55F2D3C7279569769214D75756C87352158955668441C2F6F6347601B265381
484A5F225281482C514E4556943A2D6B52355392592B56566C87A25745703A5793843044
5E4F70A55A2B7D7B5582A633355E776294752949428479BF473B4778647DB85A1E5A9E6F
7697362B6FB67B888C30595A936DA86F356D84699DB12D3A676B6B90A12B5266A98388A4
3F5276C378C086464D9DDD739D415F76C2C86691436E5E956A7D833057A48774803050AB
C5708E98384E9C6D5E7F36628D964E7A3F64CD9F4E925E579EC15775784B6EBF4F3D6B47
87C7713893623471C4986C70665984B964617C417BD267456A6E5F8CD05A3B83797494D2
5E39779480CD69294971A167C572405172AB6DA569213B5B8F96917B1B2D4953505D846D
739C77756742706B746057877A766766727E5E4938624B42396C51372E6C8E543B4A955B
5F666247604B393866734F4C66437968782990934A6E977C9C5A71864A884E574B4A476F
809AAB3C3D87C37B4C4B5069A575425F7DB8793F57534F524A4C3A4755565676655E3854
63505E57754A6B66745576A9A5557A41727C476C6E81704F685D4B405B5092388E7678B9
3872893962905D69584F6F7C75588E5E88546E594176A2416953573E6B6C39666E55C9C2
625C4B6522696C5C901A233D503D61408E7C424A586F1D614978A4464150348191607E56
6B735A4A50666F5572518574C9814C8D6F3F5B63446F525684656E6095595F6F715B6165
8D7F4A6C89808F9EAB5A7635666A6F788E8F945A6E4C888E3E7A986A94908B9DADAC6D6D
74A882636755767348B18F486C64426F6B866CA38F477C9CBA77A1C8
A9618DAD5DA0793CA0B37E702155657B427C46436F9C4082842D2FA7AD38626D4A77BA91
3E5B56347C85292E554E43958A23345E4B58B76031415266A49B2439484183A7352F4950
60958C2345595A52A0641D52707A51C1B7232B3F737EB6601F4B5C6D80993D1D4B714779
A2324666905EC755434D76926A76306F5B7B5A6B782E54689F4E728C335B697A59787647
4F80744A7C49546E805C69782C5E8082444B883B489C9C50667B2E60887E4C8E5F5678C9
7F408C59399CB4484065515CCA883D556D7892DC6B3C715D61B4CD372A725E86C24D2C4E
997AC5CE397BA86E8BE15C2A88777DB5484470AB6BC9534654C6779D7C4C5888AB86B436
47839D4EB3783741B28299A7365781A48C8FB13B43A58A7BBB8549778D9F669E50476798
9672A256418A8C3D49714D3B5DA75765642F5F737445616D3C3B91B43D2D60444F58A7B6
BC9F4957655060706151556D4759728C7E52364D37373849435A313B4052445B363F4442
4954413B43483D2A454B5648524588735D274A5B54574D548069567651665256543D4D5D
797C8C5651616F94A27E57519BAE83958494895F4C5A656955704A566C605D5E64634133
4756714F5B5A603F69706858616C7A40375B76A06D81887176665747524A933D915F7693
3CADBF58667B6E8658535D43595290847D555F6E618D9D677358624925564E6782546050
5458778F41787479883134436F516A5572625349314F1FAD5D4B50544756565C867DBF75
6A8A4F5B6B6595739B7A877FC099595B636BA5944F5857675F6E70657C4D615F6674927B
AFAF8D829FA3599D8762753A865C776E70586C5F74634D5C617B7671838A5A725E984E93
9EAF62506D5173AB9AA099546D685DA2907D59514F495F808281A397
9C755D8968AC8B2E4C58899433315B5350C2781B5180468EAE421C62BE89B7913D84A497
6FC84B274A9B6D8485293B499765899328374C946F96374A4F7E6D844F314165525C8233
3D468369558E1D35679145407B182F6A9286669218258DA34559622232778B3C694E2955
AB59525B3036698D345448337287504986612E87C34F4176753E909C4149695D518D9D39
535A617490633B61725187D1553A7A7A5EA2CD523D656C6DBBA03A40799A75BD7E4373A6
D58EDA4145698EB2A7C83C51AC9C5DA39F3144ABA065B9503346B9A0836D394F64AB7771
7C3060BE9B70A9604689BF649C46549C86527652609B825579635B839E387160415BCC79
395F4E44999C3F427C5A72A0834166994C83C37C42705F5287A34249954D76CE8C31485C
6F8DC5783061994D7BBE403F4A7E59A8CE472D6DB2449CAE3F1F33965E6EB9474C66D3CB
DCB959708C5489638461549B5F898193B184635B234E374C38662427235D677233489062
4F67743C6F4B2C39595A4B3F5D414A515B2A5A51344C64545F5C415137454B553F466253
6C848C6672939E59494A5344CDBB414B60B77D564E4259653C403F634A3F456C4E3D3C4D
50374050553D4C4F4A39508C75484D426C624D5C5C584B7F6F5353776D496C3B744A7FB8
3F63673B504E668B453B455C785C4C4E7E4C714B689CA6695E6E7261375344787A5A817D
64556A57506E8F5F6B403C3F646DAA9C9B7772654B573A5C4D6A715F677A5873764C5E52
A56946B38C697069955F8D885048546F6A52555C475475807971896A856C696871776A70
A3715AB16F9645848A768D598D6A6B9FA0607C8F85554C7274737E72628E569090C195B4
88B973848C4E7A91528BA3507278555C7F8D5F8D5F505588925A7A95
6D9D9C6546557354902E3468684B782F235B904A6E58192B90945F5D225363704A345B3B
6F7151353C4E2D7FB24D2E43463F86C94B3E6F526A9667204B5E338FB534355D3F5D7B4A
235E6250579B5F154D827382B8202A40686D9FDE21245566509DC125404C7462CD861E4A
7B536E6A28244B8C629C78262C788B6997614F515D7668A066397DA65262A24F57569D67
93A33B547D775C93953742B5B75E95614A55A6935C68414C619A606160214576A0648494
2D5DBA824D7E7B3A6FD06A3E72664497D2674C7449409EAB465F535597915362806657A8
9F39427B9A94A361506F888ECD5A427F9D6CB5543E94A696A86C3956A477BEA4293B8E93
6E92253462AB8FAA9C28495D7D89BE7B3F5B88A494B02F385A689190CF3A344FA7558677
3E51BAA2518E5F3849D2A7647A474256BF9D61814E294493AE536759283D7C7E4A60A28C
9CA45F64876E746A7882606D608390988475676744583F514050364E40615A664046806B
5A65794B7838302C5B5D68475C1D6E76821B789948628761855567813C7B49484C424345
5E7DC0515996AE85797383509AC54C6E96B6B4585E456A6F4B612748615345445851322B
424D6258595666566A4F563E5650625D605D4D673F313C4B5156563C51647F3F7B48608D
4A99913343524A5F3E3F4149584F467243594D54565F6E5C8D506656536A38234240B4A5
55823F784D837E5C7065483D7172566274634F6069675981595D816A3F465578888A8C95
A99B517C967E9C5F8893C5927F4860908F505F7568696177827A6B69704E787B7058656B
B476415F77A465C9AA928156649896816B848EA2BD6F4E72818E906B5C96668771B96960
8AC48E94A16995BF94C9AD5B764B4F736E6C4A5653436DA4987D8F93
896673974E695B4E9B582F494E5D9D41252D604986902941518B86CB4D27656671ACAB29
34786D5B96722E31556D63B6513B4B778E82B733335E81427F7319419553636B1639514E
44696A143F497E428292283FAB5F408D772E3CBFA34794343640974D396A343C769F6052
5A3C487A5E5A76363E667B4A4E6C40487C6E374C62313E81C2597F8A495D7953445E505D
6CAF563D6C5148A6A53D417C686BB66C2D4652647F823436408E7991BE2B3A538769BEDE
4749608F84D998387DB09174AA4B3086AF7D97B937417C8881BA8D2742A9877FA64E404C
CF8B92922C6193917294414A85A060A2405B8E9371A14946A5B669A1793175A9528DA741
6FAB6B6485534560D27375754E498BCD5B8B6C4A6D9F6F3564535B7DC87B44726E72C3B7
4C5462895DB5B93B31805A80D56F3A43907B65A3B83240615E7EA58E22293C625D55BA96
967865715043546467554B6B726F553F3D595D40364D4C3E3759513637515D513A405F5F
5E69694C573135366567564F65396C63621E6C7044465C616B4E397D4283534C504B4C4F
5B80BB535E85B69476575F5D4087506390C5C261775391884D7F4C6D76575E817660344C
685372546D4D59597D585D6A83587A505881516857627A4B5640655252457649876FA8B4
53C8C32D57584F712F3935336B5E455F4879424A4C7B6D3F4C547232294B1D384B25635B
5D5A4F82477B614D69114064753F6C796B725B4F507D4284637DA8794A4D607F8C5D8379
A07747728A9F915D9A57635E5D51454E4E45A3804D6653716D6368546E4F514853545E57
886648AB708257897B5A607E8A6F60837D7967616166759055A6BF4283A8A1968581537E
5D69568A896EA59A5A9A6F3655373F6E9598576B655F5E7982816A81
C45C718970A94C4950785C7826484F7D627840374E55445172315194BD61755B3E57AEAF
4067483052984B4162342868713271382F41978A355D5E497B94583E58467191332A4A49
4B7DBA6124494E30828B36254E543FA192382A458169CE663941547767B53D343F6F4E89
99214650697AB1313560624D7CBD4D45848B469BAE352D587D5E91BC3C476D8D8BA76442
675F8158BE5A2F6EBE8D808F464A60B2678D861C5B89875A7D6B374FA6A450955D334E97
A8649D2C43ABB07777BA4455C8A7596A82404FCAAC4E5C614A60BE58365C4C619E88435E
5C5EBAD1405C70567BBE5C4B796675CC8A3B867E87D6673460976EC0962E595B4E97D574
664F4784BC513C60717EA6B6425668AA65D5963E5671A17DBC67436292B999C8B23479D3
8E7BB4605253B39463CF593A5AA26F86942A4C69615F70C25A1D73BB4F4A5E507555B7C5
D7A550536969624E5E796265505E988C644B486664505669605733565E524C5D5E4C475B
575858395C3D363841454D484A3D5E5A52396E76465156496C535066484D4A4C583D4C50
64546E58595C82866C81B7AD3F8B525B7A5E70594D536F6B5B744F735658507C6E5A4051
545263575C464E4C5E565C7B898BA372696F5064486F8764746577565B49822C6E5687CA
488C7B525E5A709655558347693B434D4C394143383A44295A394F34394F303D53377876
433C45634E7C5B77870E253D524B744D605D5A615E624DAF7F6A5D44708152435B739E4F
55523189745C7A63806EB36773334585643C50594662636A57546D4C575A537062798672
CE8D4E6292C085A58774956C6E6190C17D588B95974746495183A3709679766A3B71757C
79A73A496144938551AB765B784338515670666B7E426B78A36593BB
92877E7E537386386245496F4F2B554651857720365A54677F371C659977AB8C42375D9F
84AC3D2A2C64A281C73732384E4FCEA01542545F83CA57204A7251B247204A5D566EB02E
2756739E6EC52E2130797684B2242B3B909C7FAA22324F796977852750546D53612E3874
885F5673194CA7B34F6664235C937E6A715C3C59A6603C683D51739C5148644688B08C3A
5980546DD2AD4041694C71C954416A5F6F97DA6536616B6688A03F325D6559AE8139444E
6A8BCB533E469B5FAEE34D4447AB6BACB33F5F629288B447476C8C808E742E355DA99ACC
893E568C7FCDB24A66897F88974B4796E790A869408FCB6B6C783E4D925BA558344E8E8D
4E8A2F49958B5F70514F9DB5965C9A484580AD53608B394F647B35605752445F9B554B55
757E9A7E37404F6B58CA6839514172ACDE762F56593763CD852A3C6D5661733F785C8372
A7A2525A57376751775C576F6780644462585760465441453F513B414D4F5242273C5D6C
879170436B603A4E8A774D4A53474C4F4C3B5A6B3147627C6E3859714D5B45425649433F
767C99444BA2C2864271D4B07F6E314D86C2914B54475F613A48465B4D4C436258533637
463D4B4351424B3D514151777B565A555366515F46756B949156677A76557E3B74728BCC
38BA8E38629D71616F5774747A54534F6051515C47626135A34E6D3A4D6515505D216B7E
34503D7A2C4C3F545D435658604D705665526B64444C3F5B565C70594648377E917E8B55
8F9046535A6D785C764C647E813E404A4B425F5B586A4F62665F695E6F4A64655C576569
6D644D7080594E83833D5D44786C7B786C80725F69758B8B555F642C85875256609B5B73
819F595E52425F8B6F9357445F423A72868F5F96564877A1B97FAFC3
778488A4504C8597B03F3E5D6D6FA335405A7251854E2E4277875B742F405C9671795928
6A877A466D41325C7E8948773E2B5888575E7F38367AA0438731244F844537483538624D
28425B433C6280356F4542477F60254F3B62607F4529443955938D2A31534A95C7571D3A
72668589223244766996682F4556798AB0572F4B5E7B79E077225DA173A2C5492B88B85D
A6A6503782D187B49C4D3C8BA47EBC40406F8092A6A7474257877270A2513F73CA919880
4054807A5F876B415DACA675A13E517E867C5285284DB09E4B48753277A14F44693B5597
B54E9C5A445FBB82758A417AB55539756F64CA8A455D6F75A58048478141BEA4374E7E79
79C3374580838D9B9037468A6D83AF35334D8A7996BE293F81884CA5B62B4362767CB2BE
2444736F63AD841A56B2AE649E6F2348CFD75A773F373C56A3657D6E2D534D694F65D9E0
DEC7938C91607D64554D4E715666846E8C7B6A67454B624A4F7A58506C756A6946646E7A
616B6E436E4E2F36505D4547794F535C7C3E69773B464831473B596258614D404A504148
39376346445A5C68545733363129335785B3A34F6066545E6A6445525362526A72733F49
3E4E6645473E42355073636279899B6B58645D6F434E5F755449546D753E673284685D7F
46AB96484C6182A93A3E4D7354543C5A334A46585E704B445459654D57752F4C5F4597B8
4F537187607A786166383D233B4756639073584B42664278596B6E4E494A46455C647B4C
40424DA76657685DA359877F918243605B64827E4C584F5F4E587257624A5553555F6584
9F9F627D8F97648163427C4C7C6E6369635F85787E6048584B786A4D9A805267577B816C
79AC896A826789B385A8564A5E3B6274847E424E4C4E858A606FA095
A3516981949A354C7971485A3D2D4F6626403921426720233E40538F492C32484D6A8C2F
2A507148829124464A7C5CAF7D2C484D4F84D94C283F6750CC8728575E5576952226535B
4696B92139736674E1943437597F61B6883A4663A982B7721B5CB77B5C9A2D3F75A1497E
671C678368648B442B5D883F5A7D2336838F45795F2C3A7CA65D7B8E434A96A84B717237
62BE854357473562B96D565F514FA28B444C74664F835E334870577D893E3F74695290AE
40466F6A75AF9D395D8E92BFD68D2F6A9A8A98D1502B55708CA0A02B4D8C668EB83D296C
BB61DD983259A2A2B5CC5E61A3A778AD563DA2A664A7724174B092A07E3F7CA15A878138
417A7C557F2D3F8672616F7A4252A6BD639A89568BC9A44878554870DCB445A44E326FC4
9A588B60567FD5613A7A8875A98A262C5F8467B371223F69626470782D306E754D67DFF3
9F80695672748C55786651866A89A28F9C6755534949465854563C514B4C4C50534A5060
9098683A5B5A42497B7B5B5368393C4D66647D6B33424D48624F5E614860584764404C53
6172B75A65A2B5975A4D5A48645C3B4F79969F516458666B435E34605C48417466553863
6635454659384C3C54445B687A534F4875734D6348755A26673138304C4C604061618AB4
495F4B354745484D393A3B403B4752853F543C5D3766A8507A5971713651757883654E5A
535C60694A7C7D3C680D253E5D3F5F5C645D5B573A4F239C4D5370506072776265779452
6E5E4E534F946A69BA8A948E985C3D62717AB8905A60757875796E6A8D58512E71897683
A08A599E939A929C7D68797F94769F9188678492A341455B339D882E87995886577D7C8B
81B047719662908E5B94554B4F2C466B7E838299615176AC92698380
BD9559697AD973304468719B2E313B5A47967414485645779634387A9A70A454394C7E8E
5E6A2A383F765FA3A41D4150A15D684B2B3B7A9B5B601F3352964E4C3F2B357161403F2E
2C4AB0A13E8229317BA964467433337AAB3F2E6A303AA49333375E695E963D3545644E77
AC36406A5A5AA98828425940A1B92E2A4C7650C2C7343D5E715696CD383E538E5EA6843B
43639472BF70424F83C5B5B32F5E73AA93B49E39676788847A95285480815ADA4C4B6B6D
7665BA283E81B17BA2BA3E6792C598A7A1447A8A8B6C8E354687AA7A478831429D8E5857
5B428BD15B79743853A3884395664581A040918975AFA9374F5C4BA9B83B47785386B73F
494A418DCE52265B5B5C8FC0543B7E8575A5A74A4C96B084B25C3D4D7DD3AEE378454264
8777AC52474F839491BE3F3763AA5478B83F386E8B528BB44D3C5A726068603C415F59B1
E6AD52665E3A5D71604242687C796F5C747247452D4A373C3874353F3A6871503B4F855F
54607C63786041427B7B534D693B6568633E5C664554665E7F3E47734E534D465D493D48
4F669D2E358BB7847078832F41526E7584D1A6535E685767595E4A4D6751564B5D694A3B
4C556D4A5343473F42555878825E655556866C7F4E475A525C456753534380218D6D76B3
41C9752F6C6F4C52575F4751573B50454E224AA06946695CA65264665E8B483E5266B4AD
63604C9A488B756C85282B415F598E5A84636282685F455B4E5B7761636D4671634D7E66
744154967C8D695E8B78B269CD4739656F54675F4C6E686B86696F6A70553F3E60707965
AE7A7CC199A36D998263715B7967788F53606265795D5654567162378477756C59735092
95BB76726C5CAB6E73CC685D5E4C53565E5C5A5552476C5D475A96A4
70A58C7F4885C25B872D3473963F64362654A8685B4D1E3A8452405B395281902D415F54
50927E20465D5982BE43323154528FB123404D5B64B37025557658749F21416548528129
123952837ED92E2139628768C02F173BA69A7EA429242A977B83811E4E60486168442753
866B6D6E3342558C577A7C33409255548B433564AD8F72AB33315F816458A1434D5E8D6E
5F7E2E475F983D6B5D43939257448C3E3773856F3F7E3C6786964836773F52818030526C
5472CC6E305F70557CE0554663726F78D037458E5793BF6728447670969C353D5A6182D5
922E71A662C2AE4141828A80C96262A8C061C2713F93BD657B683E57A56D7A71345DAB89
9062333C6EBB627536485986979AC63F556991956A9B3A576772547C683068679350716F
3F68829D5F6D562956D2A24374493848A890476746384F8593375365326B78573E6B9260
9DC65B556A45674C544854896390B397AB6D59572A5947493B65473D484D495B3E426A51
64686C466C51433761635852561E4A62583E5C6334484D3D5F756F87526C6A4F6E4E545C
6170975456959BA78B5E76875C3D3C50729FB0555556677366794D587867596B6B6A404C
5D50544C5C5C5348686B805C8473756B6C876A8D485E6C80696D786150437C2EA28A86AC
648E7E305D456CA44938525C61457766563249484847A55065475B41375D3D5D6A5F9681
44535D6E4261474050292A374A4863587E614D59526A4E7A57626C5D4B4E4D897F69BF56
75602C65435852518458825E7763404A4E72A979495559735E5B7A58555954505B636D63
AE7D8DAE84A3729D6458527F8D635C8561616BA19D50504C6CAC855183768A8B5A697A76
5E81566654469C7F699855464F42406A818F695C775F8D7E8482757F
637F978D494D95629C552937874F96522C435E609D9F1746596C6DB4392963997854981B
444B85585F4D243E3D506C7D472D3F6E6176B2342751A249877C2B3052685F831E2B817B
2D577925318E85407E42335D8E873F794D416A96632F5F325776AB452666506D864B334B
474B869534446562579D9140475E5A63AB4A3046535C7BB7512360865771D2842B917B63
8DE260375D6852A2BE404A6D7F7BDE5D395C7C92869D354078A5AA689838556EBA98B288
31495BA9749A87424A828062AF4856597D6F51AA3E3789B27AB8642A56C583687E2D2563
C55E87664061C89A75753B4688A550B9814ECFB85F9D864979AC4B4C626D798B33435B70
96A43946517D6B8A5A285162626CCC933D6B6B7A77C73A356F625390B42742A2906491AB
3337A8B66EB17D262E78B17BC47735585F808AC399285555595888B21F2F6F683E59C1BF
62BE5359846B755D67656B7B618AB99A7D6D5F614360515447723A544B635F6C5C4A8787
7968814F9C503D4A5F6D5F5E6826586B803F547E2A5A6E4A6949465B363F525A5642535A
535F97454B7A8B67515F5F4A6E5577837CC6934C564A5D7455614B7761526982655A5E7B
765B62607057665B6143668B975D6362A893546D7F966D3B59548A9F8F69664A5D6C9CD4
45897D5AB0634E753A7855857B6A4267415F5F53406C8E4D5B516C47354D57435863C992
5A654B694D856B4B47272A3E47558959675F6780546E51AB5F4D59747D954C5E4D435A4E
79575595595F5C65A0707F457F6D3F7768343E46385B6F73696B6B5A5651543354727256
9464475C8476589B897882644F616580545554425E4E4B52473C484CA07D685E6E866A77
719478866C5C7E60475F54596D67797557717A68553869ABAD5E97A7
B958599B8BC6554A6DA44F5837345F69578B67344C6A3D315B3773BD7E3355496E83BD47
2B4948439E7E3A46553B4BA5A62D44483380EC85233A6A4694B8334046596ABB4F143B6F
485D7D2C2147744AAA8C1C295BB76EA58B37587AAA54A9354673B28A48802F5F8990509F
3F414E8B5C6D9E36334782837C7E295BAAAA4F8171295978BB56A791314E809860D27C3D
4E7D9D71C8384053AB98787E374C69AB509D583A4784943263683E4B76536D843A496D9D
5742833D6A99B8465C926060D47337606B6082A95231576164B3852D4E8198A8D95D2C45
9185C9B73C4179AD9FDC573559A488C05A38557C72B3843F4B885F7F7D2241725DA38837
615766A6A53F397BA2579B814D63A5D7699D82435A9DB465837149608A7A548A53426891
554B583B45528F47435947556C8F364A613A50609C382F69462B4FAF5C3D603B49625764
775B5D785337467C654047797E7266687E5D543930564636336B4F413D62675A41428172
868B7C4F9460456384825D67695C7374845C538C33567A6182504894655C6B4760335870
5C5CC14C4B7C8FAC8A6F797A8559475CA2CFB75A5C4C81804D6D43598547766A74575C3B
514C554D6744574548515855624B50614968556633534D51598184514E63894A6E6463A2
599B3A2E59737E8E3952344C7C7756853A4E3D73443F6E347B356B4B69883A6E6D2F7E72
2A4D5198397D5C427B27325A62364F457753435B5A674E56415E6C544852367B7342954A
8A364746548E52325B73C680874753604E5F918C6C836F6C706075525F44658F56464042
B57D86BD6193575F59445C6A717D696262766671896B7F8B6B8A695C615E696F5277678A
989C33394654958470A3533D5C3F496364868D855E55919195909EA0
9081516D58837B374C5B8E7C341F424536A48B2143885E7588354077C177856A3070A0AC
5D8C373F59A159A7A21D41458F728551303E529868A3383561897965501A5C9CC5587319
234E6757498F242D81875179A12C565864386C95264776642D713E4469873A4064343866
7A314F5A475094A24666683997BC3C305F72599EBB384A6A5D53B2D536385E554AD0BD31
454C7185D98132647179B4BA404A588369C8AD2C555A83688EA0255E76698AC2533D529F
849CC2372487CD82CADC51499FEB8EC09E364FA4B55BB03A425695689E8D457259C254C9
4D3F8CB16C7D71295799C355AC3A4FC7B9649F424C82E2739679587FBA5655494670AD53
573D496BA49E3E4D5365629970C4D5B9878FAC3F4C7765549992364D6C5969D6832E426E
6485C95E276462526ACB553E688A4F93BB3A4162617A67B14A334460627EB04E3E57456C
F497383A5B4C594849475060453E908F7D6C55583E34293A344533433424305148397C4E
535273706F4F433E3A4F5D595321716159615D5843463D3D574B49853D3A4344674E6069
7D7EB74E4D8096A2AF898A4186316A688785965363517082526D526C84527B8194834F48
5B5B744F724854556B4E6B628D566D6C5D5F526C3D65684B5A6580595F45731C6F7AA3BF
4DC670578C7F87A382764B4C794E544737673F483474864B656E95433C44395D63458984
6D864657357968438F0E263E5348A0568D6D67694A633C8F5E687D41495736806F64BF54
591D2B50445247688B3E6C40C35A365648537B70354D636A5C567F434B52517F418C8249
8B75657D81DD4F767C848290895D64845D5274A58D4D6B7573C373385F5F56693D9D87AF
66764A565A296783AC8C3F5A7F474B719BA05D5A6A5F53857A4E8495
8EBC8566507ACA6B9D35567067476B3D322A5A517445255658403D6F3F3F8660475E7C28
4D6351266A44475A9A322F4D4C4392AE283C424A57B19327655F457CA22E324E6E589535
1C32718C5FBB642439835B7ED81D3583875397D33B39539959CD79203A8E5DB79F2E3E45
7B6E7E8127516093679A8D2863BB90698E45396FA5815F702F4D86A5706CA04D4592A585
8F803B5497A85A9B574E5BAB8C7F71354877A9727D6F30494F9A606E513148649949898D
2F63D695397E68396BBA824B614F5797D8634A71494FAC963C604F4791C4413D626D7EC3
BA32579386C7A9323578BC7AD66938599372DD3B42798587C2843D93C17F7F4F3E64AB8B
B877234D6ABBA9974A2E68603A588E874A7D7C8E5DAA263B43A06A7F8532484F84547180
3D458EB6758A634C586D944B6848324D806F5CA9683D4160893D8C50364D667B485C6476
F3DA5A617A765A656E80726F5D5585713A3537583B3F2949404F3C474E544C6B4F3A6A5A
6B754725494E313D657639385E3926364447353B2B3F48445252455E4C4455524839575D
4E4961505C5F695354626764803B3F6386955B47473F556D525D435C3B4250775E574A5E
5B404C4E583B3853604859767F5D4752707047582E74747378648D64694F7D547C7AB1B6
4F5A4C588D5D83BB697DB069A47B795E676046494D5E824F59476143615C335860758A6F
3352578764A77166832647706E44615D9A684856406D276947628B57839863B5B0556D48
973C52565490584B7781D462A0484DAC71655E8370A54A608B59685F574D6D7E62605A68
A88B5E746B6169667C4A494D67A5819C868065706E47435959754F31AF74597B48A79AA7
8CB358959062A983787B4B85653743464F6E63655B4988799E809CB8
7F64919D5759595DB68731525745A1812556493296B023336E585CB361213A704987E955
236E894EBD6C3B528163779A40286E956A8B8D253A458D54BE753053606A648C1E334C53
32837C2536446C4A555A1F254D3749764635515E51347549306F902A674C3662A0852C84
4E3C4D714F405C3D3257A64F335F4E77A8592F47595DAFB661374D8382849C463A709D6F
97A8433E7EB262D95F38459C609FB0402C6BA461A6C34A317A9F6DBA882F3F5D905CA594
363F85A38DBC7F2757B49DC7DF6E3E5DADB0ACDB485478C290C04D3C718CA279B62D4D8A
CC84B77C3490D79582814D4075B46DBC2F42D3AA4DA4643C72CE789A8842968E42708461
8EA052556F4E516BB046417A2C3A599D8491AC8385C6883663604385C84B2C707071A3AF
3F38558C76AE652E48777B63BC532D38667450CC83303F53964CA899274C4C834C4D5C53
8DB47982523938735A40396777545A4C644D4A39274F3E3C4358334E445365493F47737D
7D8E724C5C5037404C6346465740524744535E6F2B516E55674B3E795756433352554233
475A95373B6E987A5B44435A6F4944579AD7993D4D473D3A484F262E3D47353C45513820
31444B293442382D303C3A3A4C434E43426C86652E3F35373D546869625D641B5F507E93
5F8C2D4E6D66626863957E9D6B737A688974654F5C8493599F5A6446687A4253525FCD94
436868874561745E74304640545D785C8774634C43532386785F54564C525C64645C9559
64766252616074687872818FA23B4E4D56465F735B6255554B5D5B3D523E3F354A6F6E38
79605B9559A25493895E82547762797E445454689F4D526F5F9C5B3563555771788E6583
BECB725D5E627382BE881D5262344A7E898F70686D518F70938BADB1
AB6C6EB981AF425689C65EAD2B4965A571D76C3D466D5E698E2C5395905382672358A7AE
61A41B404C7045626C2750835D3B594B4A7BAA6C3364354D8DA34336565F5A9A6B20453D
44768C2D253E5243779D36344E4561BB67233E7176728A422D4065469E833635518E51C8
84393262658BA749324E786564932B387EB574A78D4669A2886ACC8E3A5687835393644A
5D8E947773393D77CC7E8A8C4D4092B656A23D555497A15EA0655A669E6B6C963129767F
6F759D3136B7B85E89C4423EA2BF566559434CAB6B425755627C902C4E7E5673C38C2F5D
948BCEA6354F6E6879B03C4A6C6E73E5562B869475D6673F4D9074C0A72C7A7B658D9539
3C836F8F8C37404F905871C6F9ECDEEFE2EC9F3F6D70D674B95A465A678A62A34E365785
6476A2304062976296954151A7BE426363534182AF654A82403E4D7E4042593E49529360
C2AA42566D44514C48494B614F3D636D625B4A4F33452B33325438333152625B3E2D6560
545758546B5B4E473E535D5B5F1F685E51322F3648472E3A474F545B4E52483B4D4B3F47
826B804842426A7A7260653C8C5A6B627D78845056645C514D5739454A5A48644B654249
3B45504C473E4647474B4F5A715C63595464514838543D7D5335585544213E1370519580
5490253D645997C84645424835257182836548865F6F6258AA59694542534A7469447A50
506261B24D7D6D4A93783F506244747686885D63768D6E7B7A7A6A6D4C5748735F4FAE66
77434754607283607D849F89A3264F575C78899444504668786275654E46586240777546
957A406D5390435254697552888A79A04F72538388565E869EDE6F226E4D536B3D6F5E77
4977579780477E747259295E924C4B7B8594717D6750939077728B84
78A46C6C68BC6F3E9A4C567088356736286E8A32384D4D7E96402A5A775AAC9F29266396
7DE2532661714FA193282A65626DBB543049867E70A941306C93696E5D2853537A65A338
244C5E5B60AE39215C957C93A8223F729166B0892645A08050B27620459791627D273D50
935E5F6D2F4296A34B8D4E37408357384F41546FB0503D6E644F9FB140496D3F65D0C03C
718B3F6DD06E3B7B645E89C55B464E4E8DCD80304961565CA17C2F72737479BB331F6373
7497EB482779C0A8A6F44D5354A5A1AF84345B6B758CA9534994847AB7B5224B84C877CB
623786AF7796AE333FA48068973A3BC3C590A64A3AB1C760804D3A6EB57D785A3F759664
605E1F59817B387C464945454872705B8EBA974E56774A569A7B37576B5576A6952A655D
4C7CCA622860524279CF7C2E5A8868767935344F7E9E95B33E39515C63759E425D4FA190
996C58777B4533646D575775664C8C90896E4C552E493A424363353E4369516343334E5A
5B655833533F2C325E6A473A5E1E3C4A674E5E6D2F414E40454C414E2F4355585140584B
52355F5052617071606A544469524B6B9E8C635B5945535D374336573C3939774746496A
5A39544959394B44473C43666B46364B84786D5B3C8438394056606D674249188D76CA78
5B71283E874B5C8B4F5E49735B40454345996160588D8D53705386575A5646484C437E6E
57635C4144738D70854E51536644745C7F7648565D8E5F7D6C647469517C7C7A6D528753
795C588E6179475B816C935593665C70625F6770555C65707A5A806847575E694E8E6459
A25C4A7D668E2555645A74796C6862754C62606D9C57838262693D3981647B7E4C93A5A7
84AA6379854480989A7D49596A61806C74764E504D70716C7385B0AA
5EA6B7804A64A27CBD444267A36CC5314F4E6C5A8559133997637C904C3359BD776E7F41
49A0B45F723C4173B25C576F2F4794B3446B8C4447957E527864448CBF603B6124337B4B
224E445269A94A243363638BD6323860616396872B2C52665E8B89222D4A5E93A7462132
5D6879A6393A49827DB775295160585C9D4A235860696C83393181AF648CB947346EC15F
9BB7576390DA75C74942798480808B392F83B3587F66514982A94E6F604461A2BB568772
35535E86568C4D3A6392DA97B6723E90D46289823680BCB34B80633191C9744B584B3CBE
A434546C688BC26541BD5A7CC9643D688A8CB65030797B7BCA8B364C8163B1A01B366C89
AE8B2C3D67A5599F8C3C31393D2B4F857CACBA6DC2C73E4193834C8C8A21357B9A4BA959
3D3C8BB354913F294D80A86C984C465A66823E698A23609C7B4E7C71335775726B4CA56A
468F6877806A3D6E6054455A65444F4C5964615238523C57466A3F533D737B644643565A
6E71704E77423F4E6F5B505B70296C7490517082335C7F4F5F53467A3D5D58434E444B3D
4958943F42778E955C4F53588C554867AAD1A94D624F505D4C6031424B3B484944524428
3D3C4A344C31423E34434C625B404A4A676E7C454A73204A4D5A603B464F5F1B493D9C93
63612D54BC3A7C8C3C883E5A3D2D6490374041694D675E63914D514D867A2C574D4ACC90
393C447F46796E7B75283952759BA1907F7B8A816074318A726F778B868560A675448F50
8C7764796B80636789A0C84E825F737C484863555769515C755460755A49879C615B4E62
905E5CA14C5A3C64736E6D54617D757B5F7365A791707786978B5246855D928C526F708C
78B77978BC7DB2B6B29853726930465B806A666A564064A46D68B293
A75775B98787474E8691477E41426E843A4C49426E6F232F5B4E68B038223D5F6E8A8030
394F76719C53213D76427EAD2E3D45806A84A3275A858C72B86B1D3A7C91A79625366073
5F8C58343F7D8961AD742451B28B61AF462082BA665DB12D4065A7546984264368C85476
402A6B6E9255972F3394B35B507A2B55AF973E606B4D7DA15835575B4D6568654E665D56
85AD574763486A99994F6E835EAD9D604161573E94A83F46827D45AC8E30506A8E529CBB
2D4C7D5E5EC68C2D53609D98CB9E49789975CDB7353078A07ACC653D54A4AC9DC5463F50
AE8CA67B24518CA37CBC593A799A929D2D548F859E9F4D275CCD63B1514767974D5E7A22
56BE7E64803E464F66427481A8ACB183A6CB763B50896652803A3178B85844505642887B
3241623B5DB96327306E5F66B384294E55503396C82C1C65705A9582232D4B725C407764
4E7F8CA250312A4E494C4C62703454698484645F3C4E3F3E354E3E3B345B465C41495F4F
4E4760525B4240366B6F565E6F33806A77636E6E344D6E7D85564B8C537058445D485A5A
6657B3504B73777F6E6D753A996A485E9AD6B65D755A72705573455E7654596B73606248
4A5153446342514B534D4F5F6F4955536C7E70423A651D4A4A49655744354C266F638983
767E2B456B688DAA496B1B4D49473743304C34663A8362475D3E512B4740255E51386D52
3B4E447D34653B507634394B56454B699A8550616A7F4C494C737552434A3B475548B44C
53554152507C515264535A58A85247564760966B3F41505D52536C4C444F4C4A507C552C
7D51536F547F6A9B824C5B5B625B78954E575B927C525567AEE35F367B4C6F76829B7D7F
84E088887C5A7CA4DD923B43715A6E69686F75774F4A6C535E82687B
9E7D57679BAC6A4858507BBD433F3F6363BD763453647A697E193096C779AD8F254FA384
98B31D57727D698B7725568B87567F401E4C554E44792F4A7BA44F554433516678345F27
2D7A5C2D43724440B185353858335BB55F2749576668CF5D374E5A4A5E953F2E47578EB7
621E36815170C967183B87618AA8313E5D8366AA81344874947FAD703E7A8D6D7FA77C2E
59B98F99A9304370B782B994405690AA70B55F3D5979AA7BC6453F81B57A7D8224415398
696B8A2553599A4684892967609067857B2385E4A76587493780C1607580354E70A15286
424BBBA63C588B4965CF7D44906566BA6E439C5D87B95A3451825ABE8B2567644184BE33
2B7E587FB93558B1944580BB9C97B89C9CD98B3A61684D5EBB6023499F50616C2F3A62AE
6A8C803D3F5C806F82864B41779B4E81822D33338F8775A1383F3F6A5A687E2F4746814E
3A5C4E597A6B22515F6E68785D35607B6A54455F3D53443F41622C403E795475504C5563
6157692B523D3C37505B4C4457295058606A6E57363F46464958595648534A405C5F4C4A
7767855558718C7245656C669A7E6F7D929C876658475B614B54375C3E3B43734C3E4552
484047475643404F4E443E626F5C594C7F7E7F555A6C334C5B53855D554265298C4574A8
A1B7336BA08D9AAB6E5F1951737D485B206C294B32775F405B576B3D5148196A59288768
4165383E39784A53501C21475839724D575152523B5C389E79475C41606E3E5D57478958
6E7468B8566D356288667A386A5F4E5E38384B4C3E5371636A4C76553D605264438B6246
8B5C476640AA6B584D636F8E7D71669A52645277B26F729B6F5B44487B5889633B6B7A70
4BA091B49659768A868C54615D395169997946535865809297809A95
71A9A48755798F8EB83A44856E5D7F253463A35F693D4A8B93583D4B3E2E75A240353F46
A3A544355C3E3098C53837685060D8AB1D35565674CB571B529A78945631425D785BC146
11608E8695BD451B65A0718BA43F2F84A46CAB773743626B81BE6B30407C854D9A482D6B
845B569F432B6FAD6186744649A5714D9D442984A64D5B72376790A746556C475AB0B98E
6F753C62CE9E42845E429BA25E476B426D94853B4C625984C0A243426D678DC44A2B674A
3D9AB53A317378619BCF473A877362A9B7263FA5A593B644394C9966A58A2246557C78D2
6E2C76AB617AAC2C459FC170BD4B5A69B27CCC3744CBCB6CC67F514F9C54A45D3E7CA979
62712B37898664C84B3D283A596F57628B87893B68872E748777437C9B4761B465375849
4F80C3603C5A40476DA98D43514A49557F2F23484F5150A1682E5F5756629B4E4942805E
546F758566431E494E504356543A5F5F7465535A36494153455B2E533B645D5A49535B77
8579692E5E4B3347647652557C376D5764484C55273F55626E4D3568535A523F5351544D
4F578B3D3B93B4A76B515F64776A3D6CADD4AC4969575D5955603A5A483A3B534C484237
493B55424C303E45354A3E5F613B524D515F6F565E8033625A4E76755C4256297C576792
7B7E234DA86495C45D895C586D4C516041523D564A86794C5D4E5E404C51396B715A8E6E
4B41567A538750535B3946615D69A0798A63687942512B4D565868593D49419850288953
8B79545958833645607DB75B744D638A4543605B596A4567895C6F694C66616754756755
A1614B6F5D8357776D8087546171637E5B957278A79C9FB4A3B94F308E505F654F74937E
64A56C89B462939DC08F43716A4353626275755E48447397B191A68D
6E5F77A54D5A4B53AF4A3D57629BD5532C4C736FAA372A429E835B7631473FABA0B28516
4665766AA0383734735F6E76203548905D655D1E4A74786C853A30558A565A743C3969A1
476C5F284E4F7D3F685C2457A159455D45336DA54150652C3B69AE454359535D70923A42
744452996740536E477785353B5E4160A9622B507D4A9A933A3E4C916682A13C41598AA9
B2B43B38789D7FCA6F3C58967D92BB303A8FAE6CB9A1495389D4659A784374B9A355D36D
2860C58B68AE6D4286C6C069CE4D577DD17F7E824293C7BA6379504B94CD7752AD4C4CBC
AE587E78508FC8855B70434EA27C48795276C88A3B755066B9934578694FC6B62B53A96B
879623315E4F64AE6A1D1F233533393E316E9B6888BE3C4598B454A4C5574E7D79578C39
4B50878365BA472E5C4D7A5CB04629556F6154906F233F506754785E274F9C7946457D52
5F764E536B512C6F695A4C7A88715A6687775873535C594C517A50403F414A59484E5F74
6D5572285D3328394B4F4B4F57256E659B545E932B497642584A3C5A435B523A59674D46
8389B9554A687CA977877D59626B897C9FF4A84C77746D695674395F6B524E7071575A37
4D55724D5B4D5543385247606953654F63767A5B4C7D38414C4C67464D4960157544536B
77974F5CA24B7773719069A37C5868752E56575959988078956D6F679E814B95803AB195
33553782547F5A5B675C3F414F473F66A8803D565C814E857D7E7953474F354F54348645
6B7133564F7A49655A5D7D458D3348514D3E70635C685469726D6A76665D82A064885E60
89564F846CA3659090606793745C6A895A715C929D5F5E8DA1C13E31A0406660719B808A
90C893B29261A699C1B34E5E81495D788E8173865F5090B78A92C79B
CA6763B7849F4B50748A98AE36336EAC8D8D4E4144763561644B317A68396D323E5B984C
3451414F928B335E4548629654345E4B5B88BC3D2C7C6B63B479313A505E79752C394178
597D7D283433889BAB9139394C6282963F254A5C5881CF3032406260A68F244D49847394
87265072574B863631638C63827E4B4277AF63A37731417D74557E7F435263725D824742
5989816BA14841A8CD64709B4B55C1C659755C495C9463577F5059677E42616D4B4AC1A1
3A40664372A566234A555959BB6F4053687CA7B73F317C8BA3CB7B2939896A8CE5822D4C
9C64D89C2A6E7C7299DE58297ABA869D3F3D8DA679A741516DC1859C6B2C61B670989530
42AD8F5F902B3D64874D6799EDD2AF5965A1593E5F6A4E54A863445D705F52B53F366A6D
3C60945C4E6962334D81485295BC3A54583F4887AE543C873A4E6B6638487A564545AC71
5979575E8680584B5B584868503E5F706C7078623E555142476E3D3A2F72506A49696073
5D54633D4C322C2E505A4331592844556455576B46585C4A5D585153445B625E6F5A8056
575A8660587FA07D58697966857D3E586EA27E6B5B50686750523A6A38423E7F4F3B3F55
573D565255394352493B4F82643B49475F635D612BB04968623C695F4E455F2D93438174
4FAB1C4576496F8643574C73565690925D4A4E7955AA6A516C656341434B2D7B5F3F8371
556F569C378A67386544264A5F46666977644B4F3E63437C624A6640656A2590523C7D53
808B5F844E623B797A71864C794A4D6446628377535F516F7E596E6B615C5A69528D3835
99374B8A4AA3668162616D53697478A16588636A7F6974ABDBEF562AA15B6F6B4971877C
94D983848F6D95A1B9B756636064775C947E5B5371655E7D768898A1
819557554FA278474F484D8E4A2D4738508C763247446A89AB38453F6474C1612B376576
A3A51F56606863B18D205A685D6CB62A444A6A7E89802633428481972A1F4D547475C517
286A826D78AD1D4D6D89827E992A61A98B5869772D43B99A636A393259B572326E3B3E59
87453A61405967612C43483A698E48304A435D6E8F383D504855AEAB314D4C6064C49B2D
4B626F86CD54424D897F99B8413D71A69ACA8F315C886774D77D3090AA4C798D362B7FCC
829685323093E16B9D863E5083AF96AD4E3777CC96678A39418CD9717B6B4C588EB66B86
5047BACA69A26D3764D0E075802F5D9A7A42785A72C95E42864A70AD98414A59406EB94C
3C625491A62D3B5E6151A1ACAFE8E9B99AAB513A6A875086BB764D688E6580E16B2A5B8F
4485823F42736A5180C64B3386B467A9792E2E565B5E81DD54368085436C7A504E606549
3D67606C8650255C5E6A617C87544D4E60674D4C354F42564E6B43513F6860654C687287
7C5D753259342B4261664D5172365A5A8B62676C25426A4365543D623A5B433153545947
49647952465E81B8676C7D7190854780A6C79344524B4F4F4C512D48414636494F4F4332
42435E464C3B3D3F364A3C54563F4F4C715D6A63239738435A2F5E775A3E4021773D9E7A
4CB3294F9C4D847D69893F7B686B415B3954354C41894E5B7F5F6D4459522C7C6B49876F
31503B54619F69599937294A56399E7587574C56347F27A670828E434C4C3C552A296A51
8B7149594D6B364C6371764A6742698F553B7F4D4E6468729785A1756D75849A71B64046
A13C69815494486C7170896D8481838E78AA6673AC786F898CA54C4EA092B084658DA593
85CD9189C0769698C4C859906A3F4E4350616F70413E6E9E7C74DAA9
69A1AE6B4A5575918D2442505A81A31D3F478F838B3C3C65A7984B5F163E5BAC62475132
546A5D51602845689936374D4249A6A43A575C36569B5D284A4E4E90952A30443260AF4C
184B757C78C5431C5B7C7089C12E1A4A8D6CA284323D547097B2463D576D8063C491265A
545984BC2E3C869756A1852E48809984CB4C3861906C7A81454352AF559D8A3D5B76B36F
938546507AAF7795404D499E905F71484D69B97D8DA1494055CE8A71803950A37D567877
506AC15A49545C4F95D86149617E74B0A02D54637472BC6F314D7B7690982939876F75C8
872462B55BB7AB2A2E628476A9293F737E78A53E46A28051CE53427DBA5681632F599994
7F8742506E62719A2844434F3F60644F7095AF56617A4353727C99A68F556A8B9F4C6348
47588E816B6B30384A82873D69482F686D4639456F2F3CA3984157683246A365515E835E
4B79555B916430544F53457E767274526963494F3F56384647683F3E3F5C646A4959595B
4D505745543C3230494E4E526325616A6C4753733A52604859534770406D593F68517958
6263B34F4B7889AE856C9848667D4879A4DEBD597653806E4E6C4669714E4D796E535B48
54506A4D61485852414C3F6F7142514D66686952176437475C53704E56564F287630986E
30B935437F3A8F7A5B59334A464A5888385441703D7A3E415C59685272744B84735ECA97
49575E824F694C6470585062553E5B5C9579616E4F8E4A756A555439786D276724358544
6555375459954B655470AA648F224153444B6A546C675872A68295954D565F68627A5171
BA474D7664B55A7D6550708D7958759058656CA79E989B9EA7D065599F7F615D81988789
C2F8BFCDD08FB9B1B6753C4D56536D558D6B6274394C778166899DA5
A653A2AC63804957AD6B415E2C36715A344A304B5F672342634379C135304C6D6C896D2E
48524B95C72B2F75A74D79933F4355617BAF921C435479869C35354B728C777915437991
5194592546899D57CF433B539C8C576F263B71875B4A432B58826B32585B264656823C55
712E72D5A94F5D4D2948784B58463A4990622F403F466992472D4F565D86B75639615A56
91B54F475F717B9D9E395F5F72BBB1553B574F3CA1CA4A4C5177A2BAB44851606A62C777
3B4974777AC88848458D92AFB5455D65A673B189478093B9819E6F416DC0C584CB654563
B95B958245478A5A707B3B4BAC7755BF4A44A3976C823B4B7C9D57714752AD9C3659773B
689D36616D495BA833233B49203B523557547D7B9FA92A4B6665518EB02A445A8A68A468
2B50668981B455224E66B970A97B3D47676975754D352F51955F82563B46577A53799A6D
577F5C5C8B633F4E557968978D5D7B6F7B78516D47504D454F5D4A4851715A614C736B72
6E5760364A30212C4E5443405D294B5B774E517333445C4351574A4D3C575A5C5F526E66
7D81935C52535D795B5E9D586C8C6F9690B78F715B4A65634B5F3B603E4C4A814B454F4E
554355485842445341513B736552584C7C6853492F7A3E46573C4E52523F522E9646C178
1AA135519738878E606549526A733F563D64284D33A3283752706E3E675B24BE90477E78
42604F914C6C6344624B2E464F539164575D526B35683682694C5E3D495144A4393C7749
71645C854D512C7C57476A4467374F61353F4D3C3E51675D80A4B368455F515B7CAB5260
774A839C5F8162AD6F4C656E8C607C9B5267615C7357577FB3CF4C5EA17A8D784C687C80
89B8A1A87C88AB8DACBA535E62485F71AC968584595878A6846F97A3
B17A5D9470C5463B6E826D863626547479782C2E5CA77FB0A353535B7A69973E424E8D47
687E26596E872A667F363A663F316E351D5DAA553F703B2B7193473F3B32468445285654
3F948E2B2D55403883732541525460A6361C417A3D669D21347B814D96811E52999B609E
7536315F8A549C4E27535B6983A82E3483B460B285305A6D7A7B99684551979573A43D3F
5D8A8C81962068689769A3812B58848570B55434718B97639A33378BB68663AB312C6DBD
6867722D3E799A455F602D71B46A4A71513B71B55A3F796D597AA333415A5F90C9714197
6E50BBBC335465588FBA3E356D715ED9703E747E8DCE4A49669088B4613663A360AF9840
4D8C7BAB913B637E7F567B634455564854C057385A7B6588BD383D5B836773A6455D6BA7
6A6B723A4860A44F5D81535960933F696B2E4C62624054632F38586B2043573851667266
5178585AA5543B4D5674496470535A4758766A562B51334F3F683A3741747D7942696287
7D6774465D3827336D604A526F2F596B7E4C5677314A57445A473E6E42665245584C6251
556BA44D49765A8152589B927F89457D9FDAA151634A63674A5F3D5344463E5A504F5138
55405C394E473D423244346D653C504F6357676648894F57664B4762624A48359040BC7F
21A14D5AA43B8B826D774467494C4979304A30544676274E53475843515E2E5E5F509D6E
58764F91629576567585404C61545F70597169573A6D4A95735E7E5B4D50387831437654
8D5B3D51576E31695F6FA04C652D63773F3E513B5E65606088B4B78F565C83816A72364F
8A354D68547B537D7A849275866C80B45E8666748D6460709DCF9A7B968887885390B0C1
C3CE9BA8A385A2B8D9B35783764F574C636C737738495D9470908EB9
7AA276774F7B846C6B34505B55586F295A97553047464173AD3F29623D67B69C303D583A
7DB1223F544E31A0B7293C475C62AD662D466F7571822B4853706B694E175D7F7C488D2C
215CBAA96688214361976D8CA0244A4A7B448D654D4B5D5B5E7D2D4F51915F766E304A5F
8C4D62552C4593943B3D493750704F3E473046536F3E4462292F90963B45494A4DA3962F
4452635DCF6635635B6D88BE50396F575FB6B3333F7B7176CF8527509E6B72D03934468C
599BBC224661856AC7A6213F64795FB4673A61836A87A1514972877D8F832268A3A27AAD
822B73DF719F4F345BD597747129417FC46CAA386B879072B04F54AD9550625E417AC664
5D414B618C5344743B668CA0546B825E48B29A35636E4D65A37236694C5985A859344E53
4991C047303C644C6BA9313758735383892235517B527FAE2F2D4C7B4F807B3A47618269
64875A5DA2533F604F6C4E8477A1674F72754F513A4F303F3E634C36445A4B633E5D4D69
55576041513A49515151635D5C3F5A786E46455B244867405D534D6350724A436C546D55
6076B5524A9F617B606D89555E846A94B7E2C15970634F6F62783660606052706C566850
6D60664E605460503555427663465B506656698F68755648525B504A5A5252338A3AC297
248480659B68B28E605A45544F4640682950265841A11F4254596B434A5730957453C182
335940933D55584E877343726838726AB0BB8756338940905E3C593E4C553B8D51407443
5956454C508245755A4A6668641F47582F33622C424759597D6A84603D504C4F616F347E
BE44598056885F645F525F4F6D6C6D9684895D6973888E828BB484BDC37D6E666CA19DD0
C2D6868EB4D1D78E97AB4E584A51694A8672887E3F5461B47A908FB9
8D79858D4855797C9C2949575E76B33D2173A268A25A4536868E8EBE3A2B289285A0702F
385D576FA42F192E856652721E3240694C6F7E1D50A0682F724E26508C482E4E39495E38
283D563E65734A2F755E2F89DE683064645D95AB2F3C635469A54D2D5252589ACB32366E
705499B0321E519089795E27455A63769C33425C554D74AB2F3A5B6C4F8881334B528680
966F3B48B09A6BA44D3C6377B98699264A698F9671812C5870AF6F64774C5A7293507E41
3E519B5B56733E4067A45D678C3F497CB4413B6D4555A499374F593987CB6765A16068B4
98315C9C94A6AA3746707F9F983448756874DB5D4095656DD46C3D57785096633C608B76
AA5F2C59806491A9233D6A94588C68334173A450AA5D385385A0499C672D5090A4558A62
45458384545F273C498374556C3642658F6140924041657F70567F3A256A91604364705F
6C64616B8E4B2C4C49776C82658574687F7C615F2B492C3C3C634D3C5A7D5B7544786893
6F5D753D5727242B58594D3F572343628A5156913F49804064493F713B6E534E5D457368
7D5D9C5A5C9567754C5EAA716A7740749CDDA0656353847B4F62587C494F4388474E5B57
6A4C554A5E504E5C474D3D95715261517065846F5776354C704E5B7A6850693E9035BE95
33869F6E9E58AF87615847615D543D694F6C465561BF434B546552436F662159573FBA85
3C6E446937936D4E81562D3D453364496D926647266B3DB06E4F734A5E65438A473D7256
7F55506553634972625E79637632505E3E4E7A3F47467D6764497D694F5061697B68518E
B94C557867794C7B7B54826C937697AF6B878FA47C5A5F646CAF7B718F817B5F5D97A6A3
9ED1949AAB8EB79594B65D674B565A4F88675555495C597D818A7EA0
C14E73957C903F58686441492B536D83543D23466599585161334584A83F5B36368EAC34
413B475DA4691C423A5E69C33829524F3297C0331D7E79498D461B33743D8778172A584A
54879A3B41556143B1873B435B877EC3333A539C6375A1313C63A065B92C414889A548A9
67374C938450764B2C70A743565D364A73673F73742B66C1A54E8E622F7AC17D588F5E4E
8FC2544E91663E92B038635E4E77A963336485378ECC5A386F745079C354387F567DE492
275781597CD2592B758D7199CF544E6884849FA238615BB5939C5337507476A1CD235A91
BE52B88F3695C279717A307EACA07AA5373C7C8D698B343955A85B784F315C7A4A8A7834
6C8A344D562F54C2764763683587A3524866436D96933741644B59A5B938406756569BA8
48458E617495672F5D6B6858916F234A746257A695203B906847AE5A283959574067756B
76664C4E695D314F4E4E3E3C57766B7F6A5D52604A522B4B48552B3F515C61534B636165
737878455B35293984704D527A345C75A15352A22B547639654D47773D7A513D6243625A
63649E4C4F9C6C7766619DA08A83488294CFB9776E5364814F6442553654497644615042
574751494549495F345537685541554F8B425E48476E4051755256526559626D9B5BCAA0
347ED07EA854CA9D686F4959454F52743B563D5655A5456775656046494F22636C429B7B
3F585E5C4586625CA56E34645C30804881C16C612C79345F4168854444492F724D34704C
5E574D685E8B3873657387617930676B3D38592B5D58605B7A755A65555C6A7270694D85
B95882874B6A546B69576853726D80965A7D51575964685B64AD8974AC897362537A8992
A5D2A7B1C1A0C487CAC16578535F5E45775F6866485864685D895EA7
8978627D6C9642397391656C2F2E425584A83F1E434C78B8C7274D4C6B7CC95F3678814D
8D8D11424C6647B176214D6D69547E3232526E9650782A457A925B5F3E1E60B783576F21
297576AC6DAF2D53516C446B6C3A5D636D337A3E3B449C5C465A317DC05633556E4C50C1
9E3330483976816831436167778831404B7266B2973F4C647856CE8B3949678B84BB534C
5F89845CA835575E777E9C72336C6A7A759B8A5B5494A37FC24E356275A57BC9483B66A3
567871403879AA60856C3B5F709150C1493774A07B6F89485C70B463618F4265CEA1619B
87458DD354555660A2A13C5D6E87ABC853406D4D7CD1703B67745FAE972B53645FB19235
5BA863859C2D398A85676F5D37598E8D659F4F3560B8565AB23A296CB96170D44E617291
6F92B3405B919347ACA85B4B608947613D2E464B8154636A2F4555822A3F6D443E68684F
3A5D52586746474D495543565C75735F6A6E574B244F302A33505042626E60663D6B5478
624D5A3E4F2E263F3F443D4860344B7482687A953949715C784A467D437352496043676A
7773B0514E9F96966C5B737A7E5B4B6D7CE0AB56645C81895C7A456F75633B726C626154
6054614552524A5E405B3B795B48605865476B60637B2C404E6660585C606658644ED17F
3596C076AD578A876E7C3150596952673A4C345958AE494C6B72704A4A633DA48A5AB99F
6765469B42907F4D715C343F493D784F5B85505B2977338F505369375E622476674E7561
7A5E5973545F26854773724558236755275C82314A4B56576E5C595638515D606163626F
9C51506466865E58683F564971776A926A8E536755707A5E4BA77675A1868B7070868DA7
A2DB87778BA9C275B9C6736347344C5E92625A5554516F786D6E66A9
829DB1574F6B74699C2F456747487132205E8D52773D303A7A653E6424515C8A3B525A4B
578D403471324381A33B32635F45A46127506E3875C85821596854AE58142057676BB52D
202B497972D42B3B6A7A71A4BE243C97744EC36A20557F718CAF3D376EBC7D969B4B386D
BD8B71721B4283705F86791B5C92565B6C2D4077A558485E273D4E8F495F743450718548
82812C738B733D804632A0BE404770314CAA933B52565772C6722E536051608A5C3D575D
6B9D99383650745EAAA82738459175D2753343586F9ECA733C49A091A0A6445A5D9F9DC6
6B446A886FD48A29408A89AA92224B7F6C8CC54E2B8BBA77C6523D4CB98D93693583C477
8F5D4D53816A7D823D57A7A73D6C7C5F5CA49D4D6D4B585EC0753B61583C6C967E345A54
4151C7923154604D6D9F593B4D6B597F8D2E3B554C5493B2392D445F2F6C96514755735F
595A5E638049375E535E5A67506471645C5B504F3D4F2F4137554E454A5D635D485D566C
62676C47453D3343735F494E822438628F4A3B574148542C4443416C66664744676A5C58
866A524C51523D65695E744151614974608E805C5441655A465F4956526B47694030415C
48383D454B5B4657545E2D6B68617D47703F98523B564E63646062556C4E665761239C72
3774AD71AE5CBE80635546517483525D46573A3D459A404C5073603E4F523A81716BBF96
878377A2628786549984414D5F3D63674A624B682D80416E4F54753E4E504B997E486445
656C504C6B9231644B5F69617F345A672A4C4E3B4D45705B70606B6D59666A7388907C6F
B24A8982557145766E4063597A6979945E8E6FA67561655743AB7085A9749470529FACB0
93CB908E918E964374AC918F694A56638465715D46576D844C7068B0
926F81985065695EA140415148559B301E30484093932D4453658CB32829418C5BC07C20
47514C79C13D2D65656483BA3934687F457E87262E798B5D87311D69A84C5A4E282B3C64
42AF45162E55824C5D4234778A5A4E6E3B29558C345F74282C7B6F3D5E282D435E502F57
4D3D8CB04834604B348C892F2D515D65B646283E765F78B6433865685092C04E427B7159
9BD6354E9D8576C7692560B4847D943F315ACF7A9F952266A3BE73CAA73C666B9B53C465
317A6E6368B82D3E75AD837E8F38508BBD567462326594C263B7444A68B0757C802B6E9C
AA53AD684790D26452564071BC6D436D3E6ED1813753585785873E494E71C19C2A596A6D
AFB13B578C617BC5722654A758839A383D5B9277B15A3247627C72BE9140355D9B7DA66E
3D3FB5C994BD3F304BA7B1759758213985827AB35931365B7C487F3C302F415D4C45756A
6474606D8957495A4B51406A7D8C7E6D76766F643956234A435E334D676B636A5879598E
745F7C46503933406D624A445E35375161525B8022405E3E59514D5F4567495A56446D69
7A7289454D8A737D565C75708292678577E0A458654F5E5E4A61506B48614474383B4F6D
573955483D474A583E4D4F91564B50556F4A39504D735F556E47587C56563C6B6421A150
29BAC777904DB7765C55415C51756C67364C365139A53B63706D4E4F77713C675061DC9C
4358458D49AEAD428D5E3650755F7D9465714A632A6B31764A6AA1474A4E346979436B3F
725A35545D624E6E4C69576DAC446B60524E5B5F855B4F6485544B5E3D4E63695E674D72
AD4761655F843B4F4D52674E608273926394675345555C46549A6969836558745F627582
B7D19AB8AB92A27796986C695D4E574F7778A491535F6C8C4A7F8EAE
B65F6E849BBC4665AA788F99264E867778954A2D669F638EA22E436478547F3A2C5C9843
396F252B8CA6324D3E20488F8A3D5E3C2C658F3342503958A7A021396F5B707831373C31
4BC3851D2D464D5BA3771E3D554472D25431494F5496DC3B3C4A5C85C57E2D544C5D6B9D
912243706458945E2E41635B93712A3E658C4F8B7134433F5E53906033425A7B54BB5B33
419183557E2B487285467C5931607B7036665B466A864142954058859B4D427A4D69907D
2E51705171AF6A24406F7273B36527539681A2912F4C667375AF8C405C9B6587AF265595
7E78CE5B326EA6A0AA6F2C6A916FA9A921418391859C484B8CCE6FAF5A2593CC5AA05B32
5DAA977F7B325789CD929D7142597E855DA43731839047529A59345DAD4C4F5C493F71A2
4A3E7D5D52917638534F50548472314759306ABDA34D5A4F463899A7253B5D684F5A7661
555561726C45315F4B4E4A60494A5852525F5A392D6830333B77343C4C677D6948668A78
6A5D72655F4A445F6567505167383D628A514C832F49654C604F3F774D89474356455D56
7073B14B51D2AA9F65508245565E3C626ECEBA586B5C8374596D3D5C635A3B5B42574947
5E4A634D585D4C5762603969505573497F435E57587D354B635960805F4F48445D54AD68
2A57927B995373627B8B5660444C5F7138443656388F474F5A7A57354745218756356D3F
365A518924726635695F4165693D66647884546A4E9135804F57683E4C53366F7C608E5D
8765475E4F641F662A523E56942D6A5E1D575E16573C4F4C7B3F4B623C46595F6675548F
B73A6B6351863C5542415658658F588E6E9B4664507379886F9A8F82B3A3AE82858974A2
C9E8946F949BC89198B65C6766686B6674557C5F4B5165984B727083
997D90525D995B6E6E3F608D4D3A56353990552C425F4277BF583E69698DC66E22378657
9AC5253C517B69C1902147535766BD53315651769F821A3F4A675BA14C2037455C647B2B
1F53A45E767B252E4E895A766A214D959A4A71432A48968639661D578B825B587A352F69
A266404D34465491436C42257B9B43354E49408CB3564163423F82A12B4D765C72B19F45
565D84AFD2493C556D48B9A83345567B5ABC853859687387D54141719EA7A2C5333E70AD
5A917E3A6891B07593573D6D5FB893993D70949D585D7A4A4C7FB883748C449C8B7780C6
6137A7C44B7174678EAD525E72475DC87645564753B06F4A6A6F759C9D32668D508D982C
387E7689963E56687560B9A5404B587A5EAF73354A7D515DB0403038686082BD4D47527C
707BAC403D7E8741897A274D7B827D75562C3C52815D7B782B2648844547974673577969
54835A5890484C5F447168785771854D7B70454A314E4E463E544B3B5E6049574260415D
4E5167393928363C4C5B545455383951544B4A50384E4C414C695A564767677558416E7D
9068AB766F71858B8462634459858B7A49BD9F7C5E588876495D43704A57356225465055
58526F484F62394A4D553D75465E73456E4571483F783E475F7577505459605163457B4F
3A898062916A9A89776935486B6F526C415C38501A7A4A636A704A416650156E4C4ACA7E
436C483C27867342954E304B48316757655D30563974638858667D3D4F523E7166537A55
77595A805E622A713D664F5A842E6C5A25484E1D564F73506D58685F405564678295476C
86407E664B6E3D5447485B574D749AAB648F75877C52574275C96B6774575A4C506EB795
99B5A9C8AE769D79E0CB52653E4A464D6C3A806041516B7B4D568C89
6A73C25C53736385C731469A8E8B9C2A364A7C7C98344041446E84A4332C5599736A4734
49524E406B31209198363D703026709A3A6B4D35469B4D334F2C407165293A3D346C8E31
1A3B383A95D13422554746A8C721195983656E5B293D6A7881AB312D3F705CA6AF4E2842
7A6BA28220444F9865BC7323345B684E6E2E4E46728E9CC2374E709C629BCA404B6BA977
9A813F6FBCB569C86D4943928E7A6F294864A15D5F8F384E5C8B53C07E3C63C266436859
3A6CA32D377251499BB22E3D6D55529D8F335F816DB79C323D487766B5B6464B786F7CB5
5F2C516563BA96316DA25BB4A3374A776E92832A49809C70C052375FB753AC6949A1C079
71573D5C82548E9C304C4C9A6495AD314B6F8F57805A2E397DA04A786C25487D8E3D6B40
37558EAA455C4B516B924B34693B50707E2E2A5C5F5E819B4221436E544C8B915C47927C
6F72535C6E6C4A5A555C445E7374757390744A5D3E523F5C495D344D62726875557F588C
6355914A432528525B615D427B3342558449498724406944563925543E733128443B4333
55576130325970843D377A4C614F255065C574414E45494C4B493146444A33662B50496E
5F446760506D3360485C39773A50704E7C4068484A843455715A73805C4E363E3626A46C
3F7E9E6C9E4BA8BF7A7A5F69605A636B38544963248D5C60585A533B474B299E665ED286
36666B8139937946523937534F4A75467F603C52257148884D5B6836625E46757750724A
786D454D50692C523F5B7C768F4B6E5F364A502E503F4B5067444D573D455F585C583A66
874362665478467452395B62606D615E5172585A4F4F5B635B835D5E7F63916C535C5458
8CA8655065587B417CAD4E6A434C545071408C644051729A6056857D
9E585BA16B754245889C7555295C87653E68503B85B03B3E434A579E612F4F6068CD9928
30503776CB67143F824479CE3E2B56A447B88F2E3C6C608F843622686136967213355F66
549E4425356C7D4A78491F4F97614C95322B6E6E3F60A43B569082568250394469644B95
453F3B70433F6F3E35507335424D3073A74F28676B244F9A453A574B4458A6573D654D50
A6BB48445A69679F9F3C58444197AB2E38567554A4CC485070936CAE9C334E5F9191A94A
45516A5E6FAE3B495D7778889C3F57699865B2A34353988683834D3C6098795E7B1A47A7
9053BE393856A06A8E56406ACA8C51822E64BD9948793B539C8C375F48578F773966964A
A19E4759614B66B1584979A26F91CF474865545B98982F4156615A8C8B2A477189A0C560
3A615A5F88BF3950849E7578C8373D53835479B754385B7853588D761D2D3C7144487B53
56884C57994965685265466156625F455D6E53443055463A3D634A3A616381603E5D6667
6F6F7B4558422848687B4C44533F55796C4D517D3E47604E5E413260546E3F475B44735A
685CA1454F7764A55C4659405B60415F7AD695506B5865695F6B4366786E36642E775645
514A5D404C513D5F56612C3E3C767B607B5A7856598E37445B655E66605C4248502CA975
1C686670A76DBE9A85985563475873913E3636582B754B53656C74515D5847819379F9B5
4A655098427C775E6075585556434F50A27B51572E5E31D25653663A3F596E755776A662
7F6F505C6861494B435D746690389A691B4F511E4A4853486E4947664C526A6A6B7D6E94
944C65616897328F5A626E5951777C9D6F9145574A4F5A5C679C40668665957754787C9B
88C2777D655D7C6EA4913A79464A52546B2A8251456578804D777790
B8555C7A7BBE4549536CC4A9383D437687A63E3E539F82CF8734515BB167AA3D3E5D9E7A
68AD203078B24E6374252E7D8D3C68371C438D6B648A2156AA9E4E753E3C5B944542483D
3669852E57434C3F985E375D594947B983314A473571AC2E3265555D90A62D3D4E5B66B4
9034474E4C69B347355B634977681D2B747A50B29B28284B5461B97A326085947BB06B44
5D8B7762932C437D71649F743C51B3A35BA454415390935C87375F6E9C7F878C2C3BADAB
486864304FA28131633C4462AE863D844D3A6C983C4C4C338DBC43296D7D4293CC482F7B
875DC787236287739E7D2C3E636C99CF2F325D949AC9412F588B6FBB864166795099B932
337C72A17A305567A863A4703E72778171CE484693BB5561B3404860A88271C33C3C93A3
4C8EA93F3D667230597E48649F893A6378473D90A43C586B424C76C34A4F865443497C5F
7E754C50844C546155685677626A926C76614C51284E2E3D29481C414C59587A4D794A77
58516C4C5A3B3E4F4654515765403E496F4237503F4D543B575633654779464D4D4D5C52
9078AF3F498684966F6663355379555D57A1865756526D6D39553A654D5F457245444B4C
504C53575F5F436A4552427E5E4E635276648A545E6C344B5B79766B728D728E62438C71
344756648F518C6C556E3D456973535941523253188E4E5883967948476151B77D85D6A3
51694D99447D7D426F4F364E5049824E845A343C43843D673C607253525D4B654C586740
6063577962774462567D6F6B98485A5047796D537460525766634B5D3C4D525870734961
6D3B6C5E4D7E5489505146535777548D60944C511B4A635E6690597C98899175537C8D83
81BB75854E709C5AAC9E509E5C47506B915E715F554F60835E6F9185
998BAB4E607C6849802A62AE825A822C3094B25580504A67A95239743A2F7AAB2B3F7661
5B9F3B1F3A7667957F312B4F694E9971222D595963B0291D2E72678E39254C663875A120
3245684C9D9E1E4C586D4CA0752C3A457A50A95D3127748D4E7E33395993928397313A47
8B6E615D24484D7E5783652F6491456467323D67AA4B2A111A355F963B67594E5C90A648
648B587ED99F356C673C849A394056626E95642B5D76806D995A3BA29766AEC0333E619A
58A08D3356968C5DA93B474280A169BE3D3365997B7F723F4F848D52B966304BA2916988
474086BE6F685237669F656481364AB991534A28598389609952307693416E453368B355
5C4B3296C055495A4D57AEAA3F3F674461AC5D2D4F707179BE5E3955516966D25926576C
4AA3D64334586570A090302C63836A8D9C463C4486787BA1294094926883AD554465826A
70684B4C706B5E907B5A425D9A6B5B4760554D5C4A6656565154293E4F515A5D405A4F7B
806F8E3E4F3426484B5C4A468E4C535C8C3A4C913C3F6056595540544B663A584F446960
635072533F595F6C604F84435B60465F6DBA85595A535B6449573A535655216D355D4849
4B4B534F2E512D4D475F488D475A705B99546B57536C3C68663C6C9A6F648483845E9982
425B8B6D8F46C89A5C55615D2F42565F353F3A5B3062655E674A545373623F7F8275D38A
5B81496B3FA66A3F754D31534531614B784B42431F563B8F525E6A32746F5B6F2C43663C
73663351465749815D6965637D5DA1752E54442B514F6C5770584A5B564D5E5559934E6A
6B1D5755507A5C9E5C555D5B3B557C86698C5A583E545B33627D4374985E978852587AAB
A6B058807D8CB17DAB7E4570576465605E488654434670656478698C
8285AA8645897CA7943630647587CA3143577E62C3851C61A07D71C5354D58AA896A6B35
5C567E7C91552D7773495F84302F636252825C2341A28C6566193D58544E656B1D487F73
6179483654AB52355A39286CB84240452D346C99303A4762728A492E42496A7F9645324D
47649D8B2A4B594F60BA8A2C42624071B93D314F71713A1C0F2B516166A1A0346A7A7576
A3BA355393BD6AB86A384EB591867D234C6CA1768DA43F605E8E66B496404289856BB47B
3F49965842985047749B49585E3B48937934585A4198793F537E4D4E8BA04A58616B6AA6
512C5064789D6B344C5B6B8ABA4C2B5D5B778D423E597B8BC75E3F4F8469C67B19599E75
977F4F46938A7F9D3F3091A89999A333548F7F4C80532C47919788B89C2941B4BB629658
3F4C729746743C274C78544B5938233478504D67383B7B8C6D31474C2240BA7B41719E71
56786B697944434B51534055494A504F72816D49356F413B39841D456477836A42765E6D
4E3C59657C48364555664F4A6151506A83616A8E3D4462646A5430694F91404259506A55
645BB13D42897AA5604E6B44706148718AC1975368616879486139738471358A3D5C5C47
5163645F386B3A5342744B744C5F72568D657A6B848B2F47694B5767836C7B82A256A47F
2E7F966FA06F959A7467415A2E4356623447304C118351657B5F55393E4D318E647BDD8B
3C603D91204B3A5E915C4D6B51347738995D515B23552A9A3A657A4B4B526A763B638D48
616F76855484215F4C915E73833B4B412F90561A774C56526949455C383F69664590519F
7F2F6A5F779940713C6C6C726A667A62516A4C5A4152523A636F3E63734D8455677B8FA9
ABC2548B6183A45ADCCF6F8F45414F7593407056584D6C7663457D66
D05A6AAA739D4B46AA906F65413665B53E8E4739459D575B682F3F756D47923955646D3B
5A841F408E9633445E365A9C4E2645704098AD2C224E5D979334256655529D771D1F5255
5D96552D2E6A6673A2483942566D7B9E274C4A9E777E8C3243588253A84B244778A3589C
3B1C53935A7684413870BF6C724A2B38578041BF562D2E475F4462733277A95B377A5D57
7DB06C3E5D33538E7D384757567598443861356A8AA8693A525B67A3AC324C3A5E67BA85
3D56537E5DCD463C565575C3BE3C51615865BCA3284B954F97C348465FAC8EB3992E5373
9E61A64D407EBC6BB7474168A0C7689D2E5FBA806E663878A8AB6BBC3D49A6C34D857254
74AD6E5F8D515CB0854E7CA3525FC47D4F7B523C758336415D47407A982A316A764E7F9A
32586A818AA35E3853615380A33637375253557D502035698E568F42372E6D9B3A6A5848
5469434788434C67664D466C6D6F5F675A443C422F503841384C273347433C4F39573C50
4F4C6A404D32464750505A756D30457D614B466049605B3753654B5C4D6041595948525F
9184B944478385A07B62863869724D8471927E545359866D5462426E76652C994D644D4A
50695C524D5B3A50425B498A6E89795EA46F8E7076914A4F88567E8596695D8FD274BB8D
3767735A8E3E968B596461533C57958D424B486035836F547D6D403C4E503395695DB063
3F5B495C2D5F544A665B3B4B343E7B56594B3B4435753B85566D683B4E4C4F563060773E
595C566B51423D6B47554E474F32594A194E34134A3F5846535F4C5347434A49637F5257
4D448C544C614B6B59504B72859974927F8876766856695B7B7A2A82A685AF818771A477
95B67EB18C7B8D7DA06646A15248475E60608C54434E84755A53617A
B2606A6060B05A3B4C6B959C3B31436D48B25741565B5B96922C4853616ECA5C2E3D6947
A4C82A4152605AABAD1B3D6E946C9071313E7682848F312E8593637F47244D8B594F6022
284B73487972133C6D562C5E66308191613A5635515F925D2E4D39487BAD4A48AF7864B6
8A3138574E7CB54635466D59808A2A3D46504BC26E264152655FB675404C686F59CB8D34
6D886885D13C3C90AF659A7B476BA07570B379287C85AC829D2444A0B788AA613E489EB3
71885D1F4EAD8358B1613953C3AA5386433F59AB91785B2B4B696F53883C4AA0BD644C86
3946B9AE3B58425E897E4B4E734E91EC84375D6D727F32397A6068E572236BA85090682B
446D6D9EBA493A58966DC9CA4945636196CD49465E75579AA2403A4E586A71B53B3D5A9B
6B9B982E59717678A4A14441526B4361633343537F383947375A749934446B4E41708B60
5B965D5A9C504F6B606A595D6C707175747356532658314D3B641B4C6F8C766141684D78
6950895452222F413950433A6A444C4F65304F6A3143644C55573D5141584A7A57485B56
4F49676E5E636A574349473E645757667FAB7A5A584B5761414B596558525D874C42565C
575154644B584C5A596C7492474E7291B07C90959A865C68957B8582807480AAA34A6D7B
4497807DA77AC5A58D9254695D655A673F563E4E1E8E6B5E856E714F516144956684CC7E
4D894F9E456E88598F59424E555D8748825153512D4D318A3159643D8D73626E56637F41
5C664F866A63356D51673E6A67385A52225E371B4C4A6E5158595251504664495274495F
69397858556B5B86455558833A4661688B804C534F7F7B49606D487D8C75A5586B74A97D
9ED279B7A3C1BC5B9D76416B5D725C53643F60424A7882784A546B75
8D89B3655091B3818D38598FB179B4344073AD65B13E42806C637D902F567C9543554B37
617D6137563D3C67845B38462140BEAB313A43336DCB6037483337766F2233503D89BD25
2D4556429BB71F2966653D8A942628858F66B9732D3487B1869E304A5686808AC73A5652
9D5C7C7D2156858F669B484357635465702E4D4B7A5C807C2F3E528B43736E314B7CBD8C
86914362ABB15985453A78B14A6275324D5C974950853891AF7E4864614FB7942E379059
4A978B2147717556BE7B2144614F5CBF3D285D6857B5B725487B5D6DCE77195EAF796CC2
373685B765854E334C6F71917D384F9F95639A3B519B7F577A5B4A63B080B26F46828851
644C3E5FA1A169822F404E92847B9D3541A9B1576E5330449E823869724648A0832C6849
377DBB583985555696CF59406060457DBA413861674D89C7384253735671CF5249728F80
8678535C64494D6C7552456B88776B55626E554C28633F694D7125425971744F3D504950
6065814C5E493C474D6F52456D474A67633B677B364D6B54635E42744B7A3B5E4A4B515A
5955A341447688884B4941456F55457D89B18B5963517B8C426A4D5E7263577F41475E3F
555673744F665D62467A5571515474596E5C586B8C795149747490A96E5458949653C589
345D6B628C4B70664D5E4949534D708454655062348166818B6C7F61857055909FB1B975
5F795E995999825D885F3F533D428E5D755E6770325551B3526765454A5F69774B648747
64513C84617A586A677D486D56518B714963511D58556752726E656F694A6750626C509D
7E42604C616A40603A5051676379978C574D4E6E41313A2D9C934C8182477C6F7D898B6A
AEB36BAB8C7A8E4BC09F77744A4C5D7882676D65736B7E79605F6779
805865854C5A514B85383744627792402D3F5381905A1B48543AADC52E20627D719C8C18
56756684BE7219719D8492B1372356CD537F6B1F4095C76180152B4470555C6B2F346E84
3D80442D467B75447C3624356F626A803C464F6F4B746C2F75A2933A684A405FA5804555
414A65B078474746728C7B2D4C4F5477BE532F5753458D914B265A77698BB2442A6A7563
96C73D367D8A6DCA4A27369A6F998729434B7A6F7EC43D507E839BCF9D1D71BC7B80EF6B
2F74AC53759235487BD6866F9B3C527B964D987A214FAD615D6F2D4774A2454F66396BA2
7B3E855944A9AB4C84792E79C9644D6D636ECB5A3B475C89CF8E4E77354FCBB02D688B70
79762942735670DA4A354C616599AA3449799265C789384663995F95A23E607E7F5FBC83
304CA08964A7435C8F91887676275B5D58744D69413B6573663D703729487B954E667252
514F5357674D494A4856594A4F548E945960564B37553B444465344F5F59614F4748523D
494F4D5645353224324A4F4A6B4D618F723C426A3344513F47454163575E31585859505D
746485474A7971804D564B3B654C4E4D6DA377504C4E635E4D564952646956864A524944
556362787B6F4B677A665692727E756890939E9973834B4A5F8A6F557285598496438473
4487B47E9D8ABA9B636347597B5F507E5E5B35531AA8484C5C997A4D4D4741D08F99DB88
466C509825665451893C4A59343985367F443F5E48673C742E5563514C5E6A8E2B52755A
8D583E704A81336D748456765035525137683C3B766669666B5A6762453F665861833F60
57227A4C52665D74574F578667607765715E5A7455596356655537857E509C7A7C669C9A
AEB1678C71D9B79BD4944BA85877605B816A66504E4A8D7C6375698D
B15456997CAB4D596272918A2749778075B52E3A788E667E8921458D775077294A6D6136
5167171E60802D4B6B2E3A5C6C2755434C4F7B323B4231708E472145402C7A942C2F3C3A
33906C214049554BAD79234242557DB0762051654C82C13B2656925BA3742B3F83A2A3A9
38345A908299AF244E9CB160A68B224BAE9B5BA53D3A5E9CC76486BB436466805CD04E44
5B87837469285CA9A166874D38669E695067434557A4875C7E2C5BA2D4654C5A4957D3A7
4558754570C73C345F623B9ADC522F6B673995CA3C2A805581D13032446B58A6E32A2E85
9364DF5750519060B07E3F5D7A758DBF3459A7798F7D3643958E62A1373F59B75A85633A
6B946C4E734C3F578D4E8F8C27438C5250784041697F4D559744455B8E5A58923634A0B8
516D81564C8F62386B6D5B739F3A3A505C676D9E9026366D5C61A04F2428568E3E63877E
8C854B4B5D495B585A4F4760866850434E544A54435A584E4D5B4A426B50594A38484359
5E726A3F3D30271E37564342513D394B4B2F6E57444D48485356545D4959506B4B4B5866
595867555E7A837E5D55595B535D6766698B57644B4B5A673F5B314C3F56406641504B39
50565A4D454F343C2E5A7DA1574C575C593C5F4E5C574168877096A4884E7CB8BD6C9870
536085788A8688A96F4E73623D375D5F3C5545421D724050424D4A4C5C3C386666709765
908B4C5949A156495D3B607A4F66844F964A5053345264BE526E5E2A4D565A6E506B7A52
835D5B744F6D2B88536D2E5D4B43614A498659165F49704C665B5A5A524E726966834B75
6247856D694F6B6C5B5170675C69AB654C646B664B3E465894753A7E674DBA5C59436A60
94AB3EAE989FA473C273568330473B7D8E59864C73597E7F715B6F62
A96E7863527D7767773E49794F3E854C4981873E6E533A82AF413D574681A0381F316740
8CAC211D3C6D837A9B1F41496859B57C19587144698E3723606F5D8631383F8561849D3D
2763AA5D85822B3A71A85C5956234378A7487C422D4A7BA751943A3F598D6E518D333F77
6430605238507B4F2858493A66A333334C4F548466273D45455C6A90293B534561B28525
636B6586AE563761616EA1662D406C827EB7423D5A90747FC03A3D89B47EB983354D99C2
6BA85C475D839E5EB33F3C44BD9D6287353268D8BF827F4D58707A6EA94A394FA19D6066
3C44A4CB607B38477DCA66766F42507E784C6D576D7C43344E5474B86227557566B5922C
34407583A66D3C577A589FBD4E3E6D4157AC5F2037665964B6441B45747379DB573855A1
868CA1414254825D9883345E7B6B3C4B442742708F5C49602543619A4C5A71433D877D47
3B544A535E3A5B6D65625E707D736B5A686E51482E5551364D6A3D3A69747F613B5F5A5B
3D375348533630324365463B534748634C3F374B3846525D60492B4C4D4929566F603B4C
546A783C3E7BAD8172453D294248434BA8D15D42463D3F484744233D38423C4B3B5D3C41
496B49504B47223B3749464C3A70525A735196687A753E3F5F586655654B60629B4DA089
597D6C6FAA84A69E838C60492D579C7D3E6765572FA0556B655F645E8B5B3579618BDD67
3E4F346A396D674D623D46493B496255B76F7C64464C53703355583B6D73A09B474A5C62
897A51504D7F376C6A9E5D724A558C654053493E7D42455E72565E603D49977E546577E0
8C487071A766536860634E67587E715B7767619863895E3E474C399B7B546B6795567558
A399237063B5A267914164823C4C3A495B505546435298735A77937E
8071A94E5F6463829D3E435E5D7F93385970885BCA6232327C5F797C40297B8650715741
3E858F547B57215F854D4961292C63A14E564D363A7562515628257C552B4E511E377549
21364A294D972C223F4E4A9DAD2832427250826D2945377386A15D35443D5F73B63A355F
6659A39526488389609D46214E9C826790362B649A6786AE2B2F5985657F893139A4AD47
9B83236589776D973729659B7E5D78264C67A2528956414E7C69459D85416BA156499456
44659033639E3B5BA467305DA24E6DAC5329545B4963A75142595A5EAD9E2746867275B4
5F1B588192BC38314D7F60B38B22588E7D87C64756836480AE4357AAB14D7642495FB890
8A4D2D729BAF779C2C3380CA8A727E35346EB9646F4B3B58757C3F7E583C51967F3A542F
495AA15E3F613C6B778D532C516163868027263C4A787A9E2B2746827D7D9C3D4055555B
52585D5A6B43454D3B5C57759F8F6C6C5771754D297C373E3C8A603E576D745942487557
525E5557463553533C45485579375E9D8C4049714A57542F3C474548444B346632455455
674A5E4A543F555A516030346773534B534D3D472E3B4B442B3C39463E474C55383E3B38
484E514F4D514D43424750724D584D434D667C523E4B5C777B948A857F78818AA26A9875
4B785A4F5F56A298485F6F773D40577C40606A6E4E9E7675946B64564E8F977F819C9168
52647C9157928B776F844D4F614E824C5148484B785B52965A8F7F44444D545E37546C5C
6346355959665B6E5D7257733545554E335C35215342524B67565F673B4CC59168713E62
4F4C6F575E5F69704353567F4A5C78584C435E6A363F5F4C5A5847754D6B98765796D16C
977F5D7464939476D965596A5D843350677F864A4D56A2765869796D
B1558D9267874157B5726659363D73533E853C4F80AC495C71304F96614859574EB36829
2A4342466A551D30785E6B912E2A41466CB29C273B505355B1452B2C82568B91232D3C89
559B672A2A607261B46B1E3F5A58717E373B518170859F233F55AB5890372950917A4588
373967895C607A3A577E80415841465A7F5B385F344A62B98D347B6B33567A5241876949
6AA34F4978396AA2692B5A553A6491403864654EC9B62F4B68706ACDB13A5953837EBA5E
408BA56E80D0512970686495E33E35866F86D86328419BA3648D3250569E66669124515A
7C597C4C438E8B3D55682E71D0A165663556B97A4C5635499D8D3A534B5B7C6635454853
6481363477467ED142234D7E5985C13B3340676FA0AF2F4D8D7B54A696304966888CBB57
374D797B9BAB32526EADA07B983F45699E795E7E413C58AA863952203167BA8E3E77916F
5970454A6D464958554E486355605E4B5E7958404047494339443E3D586C5C5341505056
5861874A4F3035384452445250443C2C573F4D593E484650616360664955486E4A3F5967
5355686E637091A24C5732375572876AB78A4C66473A5449332F42553335686E31494C7B
44375D6B32324B472F44798A403A3C63684248517F674223404157875A4F528BBF569C52
366A6C5B6230736C75779F8298816D67508260633FA2757165969664917775A1A1CECCAA
6055615E4E8689AEA77150504E82965A8262595C4C506593355C58494A52628B8C827B60
7F6E494E46663379746B5E8C514C5A48416C4035544673555C60606151475C809CA73777
7E58A28267444E4C284D3C647A5857395052A99A545152679166267D34345E486247574B
A786719B6E8E8677A3609281494D5A87756B613B764F8A757D91AD8B
BC655E86798F424B5C56977A39388F6B7FCD4434629B7281BD3B338FC285B831444EA069
8C91175983654A7DB02B51A28D50A5662844AD6A4D612B2D6194486F2C2F3F6D605F8430
3F88A44E5E6A305685A74B45612F4A93712B3B37455196752B5E4546A29D2A426C624B8E
5D2E49776478BB302F48744A8F742F3D5B7254AF732A2F5F825BD59E3834818D69C97231
5FA677899C2F3C65654C7D6542549D66606D5E477DD39F7D8B394980CD73805E3A5B9C8D
476F572C61899753A9592D52B08A4A6B34345F8B3F445D35768E3C2C48513D77CE413572
5A69D4A32D517D67A1672C3A8098B8AD2A2E607AB5A328414F9396B044295A7F6A985828
606E5B62843F486BA753C46F465B7967679441475F976357A2313B4C7D485D7F412B5C85
35526E324E6F682C5967484F69582D465241627B5A2332575048804D2372574B40928459
4E5F4D56663F5A47525A5F7E67867E5B725544403B7A4F494E725C394B6C7A594750625A
515B69635730485F5561474677385A6E7B4F6078414C47525A3D35624D6635734A504976
585A934364749BB058572E3B7454658DCA96614B454F47633751394C3E44343E37472934
354E3E3E433F364642515B58324D44526146594837423E415885667B63554A708464B358
31607D91AE5D8072536B4E42464E957C2D38554D2F844D785F534C3E3F45488479CDEF9C
8388597652A04B505F2250594B586C5780526B783E2A75AB4A68554C73666465353E686A
8C685F8D718E6096ABA663745157594A46483D38534E586262625B645E69AEA7684C5FAB
8F5F5957743F5B59375E496A71616A5E68405656416F41435F3527A7434461498F427B39
B586487B97D98771C76EAF917B943753528B56414462AC7A6F8A7E6D
AFAABA515C878F864D4C6782767F63544A9478427C413E5B8B4F4F53314F65452A464D29
91CD652C4E3A1B68B74C5674613A85821F3860528FA63227406A54A8621E67634075C43D
14316B4E959C262374B7698CA722306F985B937B213D519559A16D4541915BA2992F5557
8A77CE7521506F695FAC503063935B69903E3977A85D89783E3E68AF6E70733F3B76B754
664F3E4D9B9A5695443C8A7D2F41715C5DA2523C45704F61BD463F4F8373808F303B7583
62B49A1A38656450C9A32841545C5CB8542B555D5A96AB273B55565274622B6DA18576AB
39368FD96F7A2F33529773706C2F76A45A655A41578D5E81803D517B844A755B4293AE47
56604D73A752306E54399FCF5F44765D4C995C2F3E5C6462A56825403F5B6DAC742F514F
6390C83D4A796864B8C3434C656F5092A02C3C55805281B63D546F8F488F723644727C59
4C734B51944B6A5B59414B636C737E728273574A264B4F41555A54315A6C62553C684864
524D684751473C434D51596055365A866B484D6C5662543E4B737371595F5B965453587C
695C8B4B586B879F8B613D2D587D919D98A289684E51635E4054475E3D545C70475D474D
685B596F4A534C50485356735A53475970456A5A5462474D5E414452648E39547E58DE86
3B644F45623E7C98716A6567955A5064504F464521D0374B578D6543443D355944727F4A
464D847B514B427B834C7A7B5E698A689E8557744E6D536C4F7C79593B688979317F7C6C
865E4B5952846A7F4B667B8E54565D403C684339614B65544A594D4D514C528169622E61
4D32794E573A53463857688150526A4648365F5B45513D58733623522D568E464C3F9055
8D6065896B6E6D7BF164A26940583D706D857981936C7C797D5B7289
8A658870516A5F9D6B2548563C91A82741544355B7852B657C5471A3402F525275A57A18
3F5E78558838273586875CCE4A3A50694A6B9F3B407C78697E2F2D387C50505E1B2C4F8B
445951283E785F2A504B364A975A3F533A556B9C3637544F4790A32F4255426DAC404274
494FA1CE5444584856AF74353D6C4991C3543557654B91BE4D2542705591C64D48629E73
BA90355A695F78D0783E5BBA878090444296BB5B937E3B44A1C161A1863D8381485F9635
4481B96E7A82493E60D3749694465197CD647866325FC99D657E313D91B2515481494DA2
6D375C547FC3642D5B644D87A9344367729CAC464C8E59BFB84D3B466579C47B2B6F8878
AB971E49B19A60B8444E51A47A8E8E2B5B897847AC701D468E934D93772D588083569837
2D69928C607D453747897D4F853D3D378667366C422E2A60803461292C6E905B42939567
586F54535C4052775242518893885D48535D554D37554B454263623261816D58515A5975
70648E4E51223C5943515444814462677B525F75354D523F624E3358485F48673F3F4667
504C71696D5E73796C573D5E613D4E96DA975D4B3C3A354838463E583B45504C3E44344C
3D4951683B454A3D3D4F707C3F50547B6B475C4B655642567B6C6E6E59634564884D9D73
3A7F4E889E34908F9688727E967E624C466656424370535E534B5749633B3976519CB154
797B464F376A35545927433D327D7B5D872F4C747A5B7181454E433754464254344D4954
68423E7E4A56379455683F6155494C605B574536493A57425162575E5A5A4A5D6E6E4878
3E2C59487F64735B54705453655C583D623E806D2E4F396291453274344067578D5A6E4A
D47D5FB358BB836A9C5A9B693A524B8B72655553424EA18F675C8183
C4567AAB847A4155A15E76723A2F795C79A33D4366AA588E782C447F715680362363893F
3E3B49458481282842494B725B1F54443167BA42285F4461BC701D3F424A869728295073
497D88192556785390662B5569646CC3392F598D6273B9334064AF75723A27488FAA97C9
3F1F5B9D73AA722D375C97688252253E89925185402B39679650895C3548838753743D54
6D9C5A5B633E3A747C41763E3A4796573F5239427F7F433A854185A09F3850784E95C15C
2556995F9CC83F38477192AADD4D3F93B879B17C2848AE7D9BC12A315FBE88A8AE295B8C
8770BC5A3D929E5E93683746A89C7A7F397FB07B89663B61AEA45C642B47C5CB65848145
50C56D828F454E637C35726F4168B35D376466509EB13326687F4D76A93B2B69684DA162
1E395D5376BC502E47545B5FA46A3D6B605F65A4883043537B76AB3B1A2B8F814A978257
496E637277414C4B3B3F516C5554615C806C4E4336534568515653425B5D74533A536268
50575C4F7141436249715D5990486583694B666D555A616973684D6A5496539A3F534A7C
574977486571918F40522433665D968FA69269564C514F6D39563565364C47744C5C3C3D
4E4B6A5E4349443F374C3C86484B4F5664486C7B534940486E877180708E566F924FB980
436F585C7853AF7356625E57554A6059323D5D6332C428593C6F504360654B7F59ABCB38
433254654696696B903D70604C564A3E743659563E2B6EAC43694D4A4340898338605882
9E5954754C583F5C6B96546E2D676B444B483F287D403A5860484D57483E434071B94CA6
5A486053483062472C3F527E4D476D708158B27C39473B5E644E49C06263784F4B60946D
835E4E7E8DEB9563BC527D4E44534863797D65445375AF737485798A
976B7F506E924C554F3F799B3639535666A33A203F5E8BB1962A2C558057B1322B417A54
91792C39537F5E76BE332C7C983FA46535419F855CAA332242B7688A343343799C57863D
3142684665912745626C37558E2631748933576D344370663377373F4767356672535183
53264954358EBA2D2A3C523F8A871D37535753AF7B253D455F68C88723475C6665CD6525
5C9D6F94982C407B7B71B6802441656B689F3C365C9CCD66C92E4991947E8787224EA08F
538F4C294CAEA1537A305259B29D5B6F305159B6666B643D3F92723B4453386BB4543279
5649CFB83746403E5F8F34374D57A5AD30448474C89F2A346D6D9BB43E31639989A4833C
5D8072BBBE30407C8957A8963F57619B6BB35D36608AB37AA2623C4E7C8168B44D4B4E71
4E7C6C3F5174BA558C853B4178A149777C2D35609C545581322B91AC30602C3F4B566052
4B4D3D4887536C515855535E6A778B7A7574654B36714C3647725E384C4037504747315B
505E635C4F334A52558C666D58465E917A4D546C49584D3F4F4F4B686A8687A8525E5E82
6E627574775471955D692F3B523D6C4D49AA6862434D5B614A515372464C5B625061344C
525F93734B51474E3F4E4D9559525672805391775A4D3C4888777968586348649A82AD81
6E97826A8F559597876E6366B68064534F54514231A02C5233705A48584D71C85498B35E
505263764F644173925B6C6E465B616EBB6C5364864F59664B7271443F3A5048216B5F51
4E4C4750678D6778596E5D832E3F3A3443533F3F4A47434947534E504649733A455D6753
4645693451336254424F639B546D7E674A557467747E5C575C2F377F535E804F4C5E8F64
B94E4C69506D8177D5599894898164628A9F6A5273719F7D888A8987
7181C553589077A79E315E9B817982394C75818A92597662A2696276223565A73F806523
417E71407F501E4E69613777483984892A534845578656203B3943945C1D444E5C3D8F6C
1D5B5C3764B94616527C4E72C32F2C3B7555809B304B586B4BC861305A52519A9D212E65
7152707136505E715B7D38515E6F464A7A2E33628E46605F2B3261884861733B4780C854
6348354D8074486926467A825A70812D567B772C57524458B255255C72546BAF2E2F6D58
3D94931E33588866AA692F4F528A70BD35434F7B699FA12F575C8F60B47E377F96B487C6
513491B889C33E3157BC8D9A73274F889082614075A388769A3258A9794E675A3385AD7F
85543150AFA1516C41606FA36A5B7631499AB745696D334D7F9F3950424169949D456443
438DB9454C5F7A6C9A9C462C4473487EB53C27357F596AB13C344D604FB5A73D4D68886C
616A4D4D4435474B4B33324E5C54242B3F463A433738466149444E405C414344404B474D
505F694252274342427358546A4E566E925A5E934B68684B5E45404E4F67577B39424565
4F4C72485A64848F4B7256736A48496B4DB56B4C4B4F485143533E5130433A3E30494555
4946608656544B4847556A8546534F7476687D6362414369867D92905B5C8988C5B8B77F
4C79457CAA2E96869CA05665545B5F412F565B54558F634C236B4E47AA20486B64B5CE5D
776E52513D9B2F647531525027706E35572E4358635A6B704145383B502F595529695C5F
6D3D51663F5B508F5A6A457554464E4E4D513B235135453C445447513F404E3B7A7E2D63
2F33693E492B5D464A6087B8607385745F67A4854437545C5E5C7FB65555734A915A9557
B98F576F7AAC7594E5839682516E55709C8B625962749A735C737D73
A65F73D8927D556E835555652E74B12E3A583C56654B2F455357B5B4353255524CB27C23
2B394F57A044203C537071D077294C8D58C1951C2C567D458A2F193E90469A6E2D1C4585
447854152E608260734D25446C795256322C4162534F622A2B4D7D445B571F4F83564266
362E79862D465E37478667204B645D66934D31515B5A688F352745616480A44B3D5B8777
A26E2D575A525DB6651F5488609BC23F2E66A949948E295296C15CB2734F537469607122
4256534A697B363B85AA567F72457494904F61563868AE7D547C40365EA15B6C7A314D6F
7E588B3B45A3922E433D4B7BB14B4A615BB98B3B56733F87D44D3F788871C39525407B73
B57A24517B7078C747365C917D88CA3D1C59AC5594872A2951AB66AA8A25505E8372A956
29529A686F863845798E795875482C415D6D557760333D677A4E9836286994624D666341
456D49517A42666E4D415C6B7378634D644C46322F4B3826414B3A1D445148463158465B
4A3B4E464625423C354D424D4E3959655D535575486B542568463860707D528C505D4A86
6A65964766789A945A52374A594A525C67703B4B3F42444A4B524450374B46544F634934
4A61494E4F56433F3F4953583A524F985957825E66423F416B75738674573F43A17DA45A
5F7E5D5F8A60CD695D6E7B75607A6D6B4559585F54C74A6E4B8F616A724A619581E1D33D
53485F6A557935636A578C8C32656A3C7B2B50534324677B2B764D414841555E4C6D6B54
5F4C32573A5B61848AAD5D77345F7231334F2F1C5D294A444C564F554942671F6051328D
30315E3D672F654C3D447889546A7768754F806C686654646735545C5A5D5B4D4A608594
D4928FAE6A9DB0A8DE93B366425748717777724C50588B6972548395
C7557BB69BAC37596171849A294A87698B67332B4B856592991959B963549E371B618F4B
6661233169BE497684242B718A455839354F7057458141569F8F38534E39838B492B4648
35858C272A415B3C8869242D516162AE6C2532566372B144303B5F4E758F2A32577F6F8B
53363D60558A9B24333D5859826C272F4F6F64A46D31495A5E60A45A2F52578166B63340
7B994D6A623B407C9B557A4C2958AB893E584A476D895950723D438AA02F4845387CC052
265E5B4692AD351B3E63489A802C44838C729E773035697B81C74B3149556BD4BD2B558D
6155E3552770A25D8B3F4367B5775C651F61BA86876D484D8F8F7B6E3E4C5CB7709B703D
6CB3686678444B74BB4E5649304D7F7D4A65383D9AB65D3361513A78C35A446F474E8CAD
5748534D6E823C3049653D80B6681F395C434DB5C3312F474560A2872139575B48628B52
4A634F5B6544403D3F47534C464B6B53555757492A594742496B593A484D53503F504763
58536259534B4B65546F5160824E6472764F3B5C5E604E32523E364D52644753304D3F5B
4C4E74455B5268776277363E695D6A6A8F6E405A484D41523A503D574F474C5543473B43
4B40545F4554435C4E53667E656A53405A89974C4C52545A616F72806B97616DB7A5CA83
63A172656C3F8E6E6573785BAA7B636F4646665465DE446B3F83393C862D6FAB5197AF52
57666C6D41914962875A4E44316E703EB33B676379466A6E3E7A5B4647457D49285E6072
8C56484A44686C8D3D5C3E615C483B473B523437433E4E43414F4A503B5851317A525893
2C38592A414F6147434564605155826D554E6F6D3C3D4E5C62616C914F4F6540515D8E64
9D6B53679EB098C6AA819791505B4E6F906E633956739F667B6B6B9A
9B768B4C65A374605C345897546156305D96443741443C74A34538646462955A213B6550
6A78222E366442ACB52531434A5F9E6B2B5C745880AC24455D6963866621357A905FCD40
3B44735C8C7D39473C79528EA3204049925785972B48627E4A812C305084625D5A224956
6A46583E3A537254355B3B339AAF542E412E3694AC3A3E5E3C4799AB2E435D4D6CBBBA3D
58645498983A3B6E7E55B7682E37889064AB612D84887C79CE38406FA3929D594138AAA6
5A7F5B3A31A79B657970354E89766571354F67A3696A5B2352708E4D774E285CA55F4F77
394384A555694A29618635446C5392AB4B3A5E4692AA2F37644F7FBD5D2B5D6773A5C04A
4C5D57B8A63335478563BAB63442868C60CF882955A39876A57A3E4D8B9A80CD4D4B6CAE
CDAA70244E70774C809B2C387D9D50646035314F9079698B2D3561994D8A6A3B4144524D
5B432E3D544E4F524B4235465345413E442D294C365C393F30424B4C4E3B33444E4A324B
555F5A3E4221233A41523C3A494C4C415A4E4C743B3C4B4E6C464453577B5B684B634768
5F5D856A676C6C5A6E6A35435F626D92914136573D343F3D483C38562C5357705860373D
576266754D4E4E4A45587B7C374C4C6D4B3B5E453F403450515B7D9D49514F79CB7D9D4F
4D8F5C8C8A4BA78B6C60885C4B54764E5A6059626D7A5A74597C5F4E7F50668275D0C657
8E634E5344A04D92934A585749747C745B3F5B4F5A4F6F6C43674E4347386E60385C3D4F
534A5371586268B0658C455E447D7C3A5A73423C4A3D4F4D47605A61474C633A8B5F4686
4037503554546C513845618C4A6888525B6469544446495B66295C8A4355683552358D3D
BF436A79566E769CC067B2884679426D879864475E687A739962879D
73829C554F74857C8C3143938C8D8C3A4F697D77631C4677A55A838A274A82A0509F5134
4B765C45793322578F7145A1452470A63E4959303FAD9232493A245274342B3D2B39A485
213739215DA4592C474A33519E4A233F3B3D5794333D405072A2492548555797A12F4653
5F5FA96B315B745E509D3E2C535E7D8D8737485B6E597BA547354A817D8CA23C5FA395A5
C39741448E90778C4440549F737379474A5DAA3F646F3053899D42826A4A7C7F3B41603B
59846F20295C646F896F2D4D5170A69E4C3F557F81958E2F2859696A906B2D315C6778B8
3A265B8579B4712B39765B9F92324588838F9E503F849790B7434555886DA4313E518266
A35E2A3A899A609D4D4157AE965971393F658444725836326D883F554F2C4A806F3A6457
4589D669395C4B548DAC4C2148594A6A89293042625076CC4921375D4788893C55695A3D
33415564421F3F7D4128386B7E5E322541453E302848394F4D502B14424A4D4529444A4D
362F4E4A4E273446505E4351535566676559517941525F535A28334C5F6347514C543E5D
65676F415577875F456B5672723F47615B44254F4A544B493C4B2D43223A47504E4C2F48
455748564B49344245594D513F5259664465754E4751414D627A4F4C616C313A66669767
6583476F8249AC634A555C423B5B5E6D323C6E714FB67BA3756C4D79B972778391EDD854
6055676153A93370714078584879656A8245595B59368B833B7A586971669C5E4F895155
5A4B4C5B4D5E446C4464505C3B4A50423C4C4335523A495F49545F703E4D6A28614550A7
2F5E656A48448F61527D6E725450755A5A676A78584D5A5A6445548C2A4A67344F49A160
C04775A376A5546EA353AB86336B305C59666057538E996262A97C6D
A251628D8380445A9D78524B3B5772384C8B3E509D7C31535D27498D492E4E4A3E977E3B
364A2F3A854523363B3959C56A23318746A3BD28226A9B65AE311B309B70747C191F43AE
61976D24202B6F648153364435835C7935284B4B4956883A338B8B375E55334C95583E74
323053805145652749765B3255672159AF752C634D2D3E96503865423D92A94D3F61424A
A4C44D424F4B52B37B2D4B465A74AB332C415861848D253E5A6360B48F2463AC5E838233
2C6BBC656F963F3B75A555A06A4060ADD573C24F5C74B39069823E568C8056838F1B63D2
B052713B4E97C65D653A3F68B9714E4D2E5CC17F70573F53A58B4D693D74B5913F9E695C
A99F3E47666A63C2913A475E76A5CA3531625C45C3CA271F6E794FABA72F2B828965B55C
344089797669252E559F7964754C304D928E4A94561E387B7645682F2F4E876F5866683E
3F493946533555432F2F5652435659595965563739693A3753894B395256785737525466
5B4C596A552F6159444A4C5D413C4A464132294659503E1F3E3C425452524F483C3F334A
44465F836E3F5C504E4D25324E444844393A2844414052442D444951434D59503B453536
3E3F546B56564C584C4B678A535D54636D717C6A72654D535C42617D3F6638579B6DBA6D
5C9B3C5C5B35BD856269725E6361646C614853447FBB4764519E5553775996AB798B8A67
574A716B47766BA691477249195F473E5F439D786653728563B37A46484F955B2B5A5B5A
7B405B64627A71925C5B4B71574F53355768342E49384C454A64504E48474643753D5EAD
54545D2C4342704D4F63877D6C566662624D80764252415D652A5B7F45888B757E5D726D
DB776B7B66B4579EAB50978761A760A7A0A2674E5165717482738284
C254586C8AAE4047538397992A4761637E983450597B61AF8C2642656E609E272E386C39
667112354F58499BB019394F875553501D3187654D6A2C1967A13D42413943765F35482C
454D722D3A3A313547582B3E55335F6C4018485B2E5CA548204366476E652A355570679D
2F2C3A7B7087AF23255987586A81222A6F9245AC5A25377B9365A64E2654A1947379304A
628C847B8021547E7A669D4B275D637B5F86252D7569434C85322E89B75754683946A45B
2B545628439E4E286344316FAB383849564E747D39545B3A94BE432969894F93C4312C81
8970B425327FB75E953D1E4498857A531F4989819777294BA69187902F4A7CA869C14A47
889B7D89793F4070C391AB963C5DAA7F4F76452D4EA56E318A673C458851477B45466D80
4571543C6A9D51356C63573E898A272E365656869F2127617D658F761F3C46615E4C6D41
4C6C47535F495B4E52454F50565E606254413E4A2F51334A3B414D415B625F4F3D5F456C
534A51474B1D3848465E415C704F7B7C7E644C66333C454A6069685344596F643E4B6575
473F493E5D505D56658439437B5D5B542A2D314D292F513A2C2D545C33406E5838445961
3A38636537454F3C324690753B50526D3446724E774D5269596A7D8F4A7F4D85B7708A57
436B658A844F895B6268936B667668323D4659575A7C4E874D674D658535435146E8A43D
7F5C847A5D9348726A4F4A4550A6898E65476D5169437F70515E4D4A53485E63468C4747
494B65683D3F5074618453633D7B7D475D564B3A413A514544545456464F4D51AC587691
23585D48656D7B353F5B575849656E4E3F558F796456619783646D8D59747A42496D9068
B85B5C8082B781859998B87C819D6C6F55546560616F97615C798772
7C8AB54B74A1857C6C2D737E5C706F3364A977404B372F6AC6773D5A3155856537514747
5E7C332D753D349A85483B58496C7F69272B3E4F68A84B1B2F5666805A1F52807557A63E
225F694583B823235C53447CC03827505E499FAD2839618C599034324794597A7C216880
81616E48485072593B5F353E4D5B5460713A3E58803A4D5D3A3C7F8A265E673E8BB46A2A
607B4779C6643D75644C88A9363D655C61B1992648845B6BC063296DA86F7888322D8891
50915634507EA1629A3F5184A8717586373785CE6A8B96383B7BAE6078674E6B786E627A
3946B4A82B543E3F55753150603B93A73F49604269A349576948688448356B4052BE862E
46715485B93829476674A490384B733F54C46D2E51516D448D7A394363765DB3663E606D
53A57E404C739A508968434266844E626617404B66726E9D364B4E774A654E2C57566953
4848474A4229564C2F314B5D5D5749526055483525523B624B5546455D64834C3D5C5357
564E5553702548614E6E496C72548A967B5E5F8A49674B51742E3B4D4C5B5F5847463F66
5750574A7B616B744B5834455940494E3E232B523B454D533F413B552E4039474541253B
3E4E4E684A4D4D4C43534936324E60892C555E57724333465F874D624E5B4653767BDA94
717C4797864F944874875D433D5381484731504B659B3B473A6B3EA4CC3876665BA3992C
52417B596E842B81754D724D47645D955F4190575048B0A6637763716848A580345D445A
6F303A4A4C536B9463644A85324C4B344A5634414F3F49574D53586A4E5B7449653D5D6A
3D836A555E315B40575B5B4F5657635E4C6E9E6E6C735C6977426E612C5B5E476C4E6875
B039677C97CF8C96A0668D5D44593F624F75423C538398777D998F7C
825C735A4F5E6684893B537A70789132377389A29434455B6B8BB1992F435C8C5EA05136
607E6453C9601E3E715472995F2369A65E9B982E3F7AB0578049284F8F4D4453263C6182
505A4D2C418762335A412F4571743D5E323C739E4B305C3F40636D2139494C6995362E53
424D877328435F6165B360215E594974C5432A3F785F8AC93E3E5678459DCA423A7CC050
9C92484882806AB5514F64896D7B7A2A4368D38FA4793D527EB878966C3A49797742763F
507179355084304C8A842E527C6079CE8B514E874598B5533F434E578A8F374F847E8ABD
4A325F8B7FB963325877569EA5304AA55D9B5A22397D6593BC31456D636FAC46398CAC75
A14A304AA4BA629F312779A05674B847366CA54AA1572F474C6948775F1836817A397859
3D6EC866373C48327B7B333853574080895B3876403F57904A31544253A0B33D53667D41
3B60525E5136574F45555A50555A8B6D5D665F40315D3B474A534038555A825C3A5C6360
473A4A5E4527525041495367484567AC68443259445251607E515D615F59624F4543655D
4D4E684D7C8C867A495F35636061664B42324B483A35565A424F516A485463664A5F464A
53566271484C47413134644F3B56464B2769844B8173444F6358547B33983C5F9D57D370
617931836E3EAF6D5B618C679866464471444F385C73336D387C354276449A734AC7A44B
85537E5252692AAD8C3F482B307A4C5E312E574690217C753D86554A594357515A5C494C
533678714234465F6B7146532350531E60733A344E5A5F4C436B614A364640446A3B81B1
484C42244849733452658C5A4E49674557466B51374D4B565C2C608A3C5B42415A8C897B
AC317279506C6BBB9D787D5D446F3C5F514D505956666E7A70677189
AE505C759E943B515E5CAF7C344865487B6D254F6D6B33633B2A576F4F3F6D483E618237
3D50272379862C415F1B2B8182333D4239737A38347450409C7123265E526C862740496B
4F91603738637850A6911F46766058A73E3558898066CC3F404D7E576F57364777946886
3342537C54637237405E895465522743746C386239294C757B4B7A41244B88634D7B422F
4F7C545D563C4E6A884760583185CC6A3268592C719A33364E4741A0B331475B607F8959
2B665F57A5E23C237AAA4BA7943243ADB79EB3A047419F9199D44B41699A7F97BD2167C8
B9999E313FA9C94D83573650C67F6978456C95547763304B9157405A3157786F48605037
879831384C5F67A1542A505C7795BD4C294C7043B3861E2D74675EA1B93020788865B14B
404E92747A8E2F47498D5C6491791D42646B68BF8520316D70658A5A364065645C4D6E43
4058354E6B4E5D493C31604E4C7A55473E3D41423E62464444504D4A5C545C524462476A
7861564550263D5542613C505D48584F544B4E5E60603835546E743D2E5180643B3F444F
43433A655B3B4B4B6D5C2B374B2F47443B2732412D2D543D2737575A40497A5C333B625B
3124686D243B3C44343E7B814645517F48456778976F52585370686F38582F5A9B53D288
74A355B98D4C6D3B57583F3E5F625A354C446D2F6B8E3A4B3F7E558DA2529F8767D7B780
986B724887A2586658535657467B79824B4880595A32D29A457D4B8287656B7570A55250
50403B536C7A5A627AB479745A5E5A4551493C363C3A43513A52676049524D6289356159
25756F346B5D3E354D4A4B445946564E4D639D5154724E777621737F468D666D6B5770BE
A638765B87A363797255AB5B406E748A5D5548435A6A805C768D7976
8E65775060A758534E447791344948516A99472C535A57828F2541564E6E8B3A3A3A5A54
7170241740625391C5192C354F5AAD732339545F5EBA441D4E7A5C62631748725134631B
2F495E35526622364B7E4C4E713746635B2241592E385B4A2D4C28424C8339454B3A4D65
4133504354817E2C3A4B4F728A6D2739636A718F9B1D393F5D73C0802D4B5C5D7DE55D3F
827E7AAFB527436A785AB8A53A4594976EC0552756AC8C77C24B376A999F7B7F233D779D
5EAC642133B895408E4F353F9A5A506F4E37598B595E683E3F81963164503B429C3F2E5F
4D9BCF552C57925593852B496259A3A6244D7265A297354B7A72758E32496D956EAB723B
559F7E9FA82848A77F4BC18C295ABA73536E383B74C76249C04D2F569D7B4DA46C4775B4
4567863F427873438DA7412A75B14F4D652F2D9584314E792F4BA3A93142604D595E805A
6369494E493C6349393D636457824D4F4B4749442F5145645B644F677D71804F4C5C4763
4F5F5350632E42594C72465C694F628366406F693E5F4C4C7E5A644D4B685D7545764D7A
68535B48544D5C443F7A5979724555553C49435C3B28583F42413B534655515B46614442
4B4851663E4B41474958594F434E55754347665066663B416E8D717B2A614D90C4A4E78E
6680406A6A4D97405E6453485B52803E59294A3566842557457C40525D60776F70EAC13F
4D327C4E818037916B578427295D4958673A4D5C9D5E836A6A9162474A4E6A3B33532555
5C26485B665F56633A665F96659F8848545B474A4C3A445B4B545B574A53534C492C6A62
304B4660613A472536425B5C54565756664D5F5C31525955643C7A8D4B62514560608E76
913B78786E8E718B6F60916F465A455F4F5E3E495176A3608A8A7280
816FC65359887888703C569E68A088204D8B7279882A465696777A99253D548442564F24
526050376930194B91734C612C1956A03B4D62293A9B6B3536402F4E762E37523A5AB056
194568478CAD1F233755586CAC372F487451798F272E5A756B943A28457F69888A1B3A50
7259845421546267547B352D5F5C54518E1A355A6D4A596B2743558A4675872F56748332
8666456A958F475F2E3B497F434457303F9699393D493C50616A32534763A9A12A2A4D3F
4FB99C2A3C624958BE6F2D47555997C95940576766A1D5444353917DBB8A307D927284B6
3431A48C629C41385CC35CA4562E44AE57754A334B7F67819634607C514F7F494E789954
8969497D98604D9A46669A953F4E9A6A707E472F44546862A85A2A3B4F5E4DBD6F30574D
69A1C155415F493F94BE3E384E8A618FA93F2A3E806E9DC357263F95547E7138567C784A
485C606D724171613946513F454F6659575D653A2A5B42494F5D463D6674A15646675E6C
5654505A4A274F5F5761494A3A3456887E4C4B7248526267625F7261707461603F704C69
7765424C74576C764A4B263B5A4248465E343C48523F5B55563E5664334F70683B5E4751
4E4869854C484B43643D647D3E585076474C603A86773F4F4E5A40555C9C4D537E5FA483
7A8350937E5DA25E66866362BA7E5353805A5D43757D4D78367D316A7768B3653E7B5635
8F4982307C8A1D9F5E335823276F385A55346E495540906C4D784D50514F6C364B8B2C47
5B275B44384F6779747B4155415C4740756D37384B443C4B444A52493050404D5728A0A4
51595134463E74334865914A575355474C516D67607953575943728243634A3F4E749797
8F18555A6C7950677545774E375E4D6E3569404C596152718E6A8185
92527964606F485E8F525F454E688D3A385C5852A55C29503C3C909B452534697993711D
25456665CD5219215E6075C240253153488CA71E223D685779581C3A4850629440254B58
3C73642A3B6C724383601C4856693563323344733F506B345B63682B54343C5F754B376E
2D4C696F35466643648D7028515D5170D75B214A563F86BE50324C67539DC23640686C48
B4B032627B698DAF332A5A7F50788A2C2D75AD77AA9337476C8C5691843D428D845E8244
3C6AB7698C7C363A78C3508A5B3E3C8ABE5B985F3340899F509635334D8B4191623B5F89
746D7E4347BB8D30626C4CB19F303C8E89C88D33505758ADDA473E8C647BB3443E51835E
BB83395C927C8AE03F4163995569BA3562A27F4EA66D3D5A957F58B194213C92985BB37C
2F57947A6A943F214275844F832737418C7853642F333C7A5F3C5D3D3C648A4164696844
494E404A5139533A48445A564F7B484E4733424332493942435045485350544D4F484753
616C5845503841434157444548455570734B62725A724D435E4E5B475377697544885574
6253204F69807E606E652C344F474F404D364036341F51334E3D504E3D4B605D594F4546
4D515A554552474D4C496388435B49745A529F5372806773668F5E793F5C4678A689C093
91AE658F6F69A462666F8D62576B57414F485E1A8582527F458A30A6B03E54505DC6A53E
5A446C3E8380454C4A739D584B823D5E73326D376235AC7A5E8B485B564A6B423F4B4D97
A53E655C6E5D4D4A455D72612276701B4F452E403153464D38505B483E543B496A205C56
17563D374A505D525150625C5F58424F5A597E4B3B5F535A77405B69398A4C55655172A0
942C83635A80546A753F6450636C636C354A5161697887616B7B5D6C
B15574849297384C9666954E3F5DA66F6B8A4A47559E75AE642F4478A45E97453F5D7C50
67442E3663983B4F6823326D843F6042404971584B4E354A8BB7485E502C4E7D98365C3C
466991533C574550788C2C276B725DA644342D684974B3422B479351A26824376B60659E
2F244B7B5B729526415B83618166294F7B8C55AE522A4B7C8D61843D3461AC8A60B74B3A
4C9261647E1D5F8E8846526B2D5083675572403992A34E4D4D52579D964F5D656568A23C
1F494F4B8F962D3451595786A73E3F536D5999C042474B786ED3843A707049ACA3194A6D
668FBE3E4D7BB464A1532A6DC47480962253AC7B7C563655836F7C84283288886D8D3630
65BE6B708B3D4F7D8542645F3861B95A41944F3489832838702E367AC25924745F549B6C
2B4E796069C08925405F686CBB6E2137535F559148284C5D5E5CB162264A734858676C56
4F5A49545E4A6954433C4C5E6263525C6A67534D4B5E454B4D554F52696E8E4C45705887
4F686053583342595672485B5C48615A5445635E374561695D3F5F4F5D5A51554E5F316F
B76E253843546C5D4579517074344765794D424A5A35592E50334E3D293E48624D47384C
3C52546453484C47483D59796483519454896A4372723D58537777AF596F5E80A57BAD61
80AC6395705AA33484624D4A5A8D8B4752338D4E918338514974235E5E517B4B52D2A145
785881578CAC4F865B3C59352D623F728D4E56446B4BB87E64984A3F4C5C525847582C53
5D344938384A674A5658837F365D4E15514C21553D44334D434858543D664139531B7264
1F6758695D707D64574863574D444D6D606A723D406E5A8D8A3D687F2D53585F545874B4
A94658666B6E718D794F964F4450505E3E5E4D415D799E6A736A735C
8663944C4E84635F4D316B7A45634F383C6751425E34595B6C313E5F343E6A532F313E37
4E75231E495C506797361F5459547B96264F744E76B7371B5B985BB36E271F65B273734D
2746717D86A71F2E458170649234304665537359243B405D4D4F25305C83504D4B264864
843B51353D6F7648344D404173892934443632817C272F3D5844A77E303853766CA2582F
49485A8EB33A32626B6D80BB3645706D95C76C244C6E5E9BAD3A5F669981A0A03C449E73
5E995A2542AF9465B95D3752797C659234314A837B6677513D4D81569A6A368AAC5E5178
3C3CA5803A647E417474354B5C5F7EAA2D3660588F9D2A45735774AF371D626578D06727
38786D8D9330496D8974D39A21569C5866CF651F4A984D73C24E384C8A7746A8484F738D
40836E364E88BF4A627F2E47789846675A29435398385A513140858F4666444551646E44
4964695F47344A424338655252814F635038473A2B3F3A3F45523F444D444D494957675E
555E55665B2D525256676668554E67867D414F7D416D49445E2C3F566B7A6263408C3D72
79753D437B67986C4B7D404C6B625D505A4D4D5858356450554C2B2E3C3F314962452938
4B5F3C495B47364E6C43514D3F514A855160753D524E6777596E4F7442622A87A9659150
7A893C765574A64F4D576763667163494F1F4D137C6739663D8024616644835D88E89B2D
75618B5F9086418A764C6931415B4B5763465148875582717695634E5D5B684D4C714872
7C2849333B45714F686FA18D3B6A632A53542F49373D3D502C41563F2F504A406628B289
1E4D4D4B56565B76583A4D746757605754554D517777473A4D325D7B2868494B654F79A2
7347655A9DA14D455F68836E4961586632996B4C5D8A825E8D786667
727BC95556625A6F7D365F80568B8F32545E587FB14C3540756A73C1392457A55C845629
3554685F9C403849666950722C30445F6150551D41656925393C2A506A493E46214C797C
31484142609B451B3D43425AB43D2F4F43627E8921405051668E4A19355B54968E252C4A
72589A7731387D725A9C352E36695086AC2929536D64A48734415787509683385088B160
B96A3A64A7A14B672B3F4B946D705C1F427C8754A58A2E438A5036723C3E596F675F6F38
2775AA38515E3C5D7E85385642707DA65427474A77A9A03D39534057BD9032456B88C4BF
3B4A6D6879D179415A834CA7662976B2766D6E494BAA7D968335508C7D6C663950ABBC69
76472F6B8F665582434A55B9764D8B534B8D9E565C483D4A736A2948444548935B2D537C
52A6A54A2B5D76619F8332355060479DB12D394B6052A1AC292D5A81539F543A5B717C46
44603D524C345446413D614E538A5070654E6038324B4435443847487E5576574672586B
5470654E5024334C525D3F454840454E5B404A58596747467C4F6550577B716548564250
64574C619AA0B37879643A4A53294439454332334039603A4E4C6254424F675546503944
485C4D58555A474A564E596D6A7D49706085783D53604A62494C6C7E548C196D6F499B6B
A09F4879486B9633584F7B6357696245633E6239856A60794957416B657287473B846531
7251894A867A40985A386C3E4E9A2A6A7545625072749656649A584B5C54641344651E7C
82395A4A52599A84735E5F7143685F2B56502A4A33392A5142665A463E5B51334A2D6A65
3E53455944334B8B5D56907556607156523B5653365F4D5C6F2E63714A604F4A538996A1
7823505F97946C5D7F49743E4558535949785E5C507985686B70858C
8D55849EA0A24856767C966B4651716986902C3D56762D4A4825436C6F22546047566623
3B612440955F1F3865385CB3591C41474F7C8F2B1D576D40615F1D2F7E5878942F224696
52AB791F2F7F994A8C6B1B398774606220276F9F4E606D2D405877486B29333D6D5B5765
24315DAD5358682A2E736E324E471F40884C2E613F3065B25D394C3B4D78AE4147696445
79934058706091AC3C2B5272437D832B2D4D7F5AAF933A365E724FB6731B556E6B7CBA4B
38478F6D9F832967817B669C4E236283675E7D4F1B6FA0796690413178CF8EAB772154BC
874C73362E68A2618C2D3E5E8944736D33789D3E4A4E4C81B23B475A5C559742334D628A
C29A3D538A4C88CD6E3962758074BC4754736D79C39F19354C515598921C446B5F468C5D
494D9A825086452F66B18660AC612B5CB27369863F38569591716C2E4068884C5E7A8F58
506E4C6C5845524C48324D524A5D50555152643544584D414E455248875B8259556E5C67
79754F54501E45545A724D675846646F76414C6B355840415C283D3D4D4C3762426D364E
818026385E71706C4480355670486549415346444A36602A482437353340323E552D2C3F
40583E4F5645424053508C715999437F3F6E945E6F604C8E6F6372733E6856B9816EA176
7875458B717990557F71523D385A6A3E47328E43925450743E641C83914B45567FCFA661
7744974478564084705F74364A5245677E5B723C8276B986819D5D6E604C61127A992D58
6736796C583E72456F5E754D385C543D8B7225412C5A49513B4A4F3C41533D565D247780
23522F4D616889664A316E615A52514E4B516253376F535F744E66613E782F443E78709A
96435F7C81644A636B3666356D595D692DA1453F536B6B5393A16CA3
A95A5D5562A650473E3F79832D4C5A476EDF58245E8D769072353E5FA05C98793036735A
8DBE3A295AAF515781331E68A7417E7F2861AA8C5D7C24505368526942203385A157943E
4253A0686479373B59922F405D495162362A3E4F4863913723324664A466252D3F466CB9
4E22394F428CC732325574599F8B233153626AB5303B3D4F6F93A63B3938838374983A41
586155A9A63C3B6E7C50945B413F6D82718626395794656E79254759A8595D6330509992
4774454B69A04E4E7A457796C3563B7A7D63AC842B3177527BAD662E3B577AAEB9283F53
5A7EB7323E5C8182DF4823677845A8AA2157BE7A74652F5E9491AAAB3852889658923D2A
83B188B8BF4843A1AA607A5B3B5486624E96403487BF484D733A2C6DAF4D355D45599765
2D4C624961935D263E623977CB7D27305556678C5C2D3C7F729BC73D3342645459735A49
45534F554C41456442385B7E5A6646535E8067413B434455603948525C5D8853406A856B
4B6356644026494D474D4B55463D4D6F6245596C3D544A556A3F53495E6252604F6B3E3B
4B6C33476A838C92518A42757C5058495656495759386E3B503B4D4D4358594F46404051
4B66546A514056596B546F6E535A41774B885F3A57524C61806F646B4D932773705F8549
8D7D4263386F803849616D5D6D607B455B50784A966966775E582F665669994F87F4A352
535CB555624B56825452563769914861505B8C507378C279728A558B6A5B5F3E6C842C95
792F52415054828371739B61506E572A4946304429466C552F545743465453547038777E
3295536A5A595F4E472A645450635752496F8A2F3474636C78305C49335F38585D52738C
632F6468B6A182C97D51983F4D37474A2F75514B6D99B36A95745C99
6D95CA574851809361394773769D662C4989987864333E5B814668762A215898444A3124
44495B41482F404B78473448412D6A852E3D4B3974C44E194D5F53967525184C5D69BE46
2B325D70A1B21E30566E699FBF264B6D4F567955204C926A6178373187BB5D7062213167
C75173382C3A69844E6F2D37497C4A53732938BA962F403E3953B1773753584C6CBC6131
6A593A88C96E365E3F5377A23F59602F62CA5C2F4F583A7BCF40276675728FBA21246666
719F7F2A5A627E62B0343585A79192B2364795D06B878D352B7B8D637335416596646E9A
383B7C966595526982BC5C644B3F73B4665B5D48969A445257396DA34A3457406A985A20
585C6682C538335E7A8AA7772A4D727E79AB3F3150768D8DAE3F3B4B7A9C72B73034619C
597E8A304281B94C728E3E2F548A5379472140517B486B782B33647F388130415F787D47
43655762463F4F4B4F41545951755D694B41442D43503F344E394F4B5B66885C44574E66
5267514B4A24464C4B5D5D573D43527C642F3C6141553C3F614A52343F586156355E6561
689661647E5B48496B5F41544C5454403B51563847546D37473A7755404E6A48343B5F55
404A7A5F524851485C47936E7079386656955E4C7E694E7B6A7A606231663E8F8890BD5D
AFA851824E858752844F5A4F3F5660394652773398636C884B613C7262706F5B77A7984C
5F478B56746F3D843A42693D416933523953733A8954B28C8BC06D776848472D5A664C52
614C625A664585646A668758356D50485C4F393B3C627143465A573B604B3E4B4C29AD9A
4E5A53435430534E42455E635A5A8834396861304A726CA37F3B7267607C3940606893BA
6A426D759870638075525D5C705D486A428149656FACB575958D5775
805586977C783D61983F615A3B84AF2B4052373C9B4D2F2A53557E9E3C2B3B7B70B36912
30475676AE67193D5C4267AC5521445F4C679E2B1F528B4D682B2D4A706F4F6C201E578E
424E3C184FA86D34823E28458B4D354B282D61863F294A3572A04B1A30704D8C94271E37
545BAD5B19364456629B4F19535B4E82733C2A5A8D5693402F4757825692543E5D6E7D76
AE662E6AB9BF8CA5383B659C5D879134375E934F9D7B2A4B948E72773F3959A36F5A8633
4A6E914C6577435B9A974062623750AEAD3949534E51855E2A554C6DB9703169634C8DCB
3F40656A6BB37532636B51B491215D907F9B631E46935988922D486C717A95294379994E
92542A74BE8879823C5283A75248933768B697427B57346F69743D6442445997683E6F40
5D688B463F573C3F4F894D39473D479E7E2D4547536B8F97434158594CAC4F315C51695D
5D5A4564564C415742355A6F596E4B5D4C506354493934404538414860737B6D6578575F
5C6C5652462849615F60416049454F49563F47543B473045483449354E584E614060334B
5B823F43576476513C5C37553C3A4F2D3A433D34514E4D283E3343383748493E35423E46
374D4B5650433C53584B925D3856788E3F587277907672786A6C6C85537345AB6F8EC357
5868529A5F805E383F474E444C82853842257D36A7405E65486028837D6E6D7286E07C65
7A549A48835F4C875161541946824B624A5173425A64E08F5954504E473966275B814F63
5B5174434B4A743F8A6F905643B777285955263D1CBB8A49274E51324A3A3365632A715E
2C674C4A69515D44534066746A6D74425E6B64463A547B89765055482F684F676873A0E0
B35668858D868BA06E4B634E595F67815E83594857BCA55E7C938883
B1526672B3B33B4F6E50B0723335835488A5392A5A8D7E7F641D4070814CB5762D458942
405F3A2F87BE5A676C26317D7D3B6F4C2B62BA6136484A36777122373C5E679A47264166
5775731C30467650CA752B546351657B201B466D5A758A2F2C6D9F57672A2042978C52A3
2F2D57A43A506D213575724E543C2443854E39532D395B7D564B623754607A3838726352
87A54245532B56BA6D2A46403497A13B31514645B59E272D555F89A9423155676C84AF32
306A66549FCA363F89A07FB173373E798B9DCA493C4076A069CE5249766D559D573965C8
8A8F79374366BB5C942E4A61804E67562A8CE5734F6C506693424E633B51A8AA466B4559
93833556803D89CC4D415A636981BB3D326D796AA3B42837506164A5912236676545A84E
2B4C8F7F7DBE492F54906A727D3E3B669C536D632C2955555A667238334BAE4955586044
45525A584543494A443753534C604B694C49572E36564F4555404648585E7450495A6261
546A5D5241243E3E3A464D483535425B563B53663B473965563C484A5B5E5C4D405D4355
53872F427C7C8B26426857783F3B4A41414C4436544D4F2B4C19503E4348563B45274148
344F605B724647687F3A88544A5B3E6653805C45504B4854705C47574E8440885B79B969
928D878986AF98565649796582585F5477265631A54F6C68606E465D667BA5535AA77448
5544A7446F434B91564A521969903C5123507A4C643DC77471774C53483B7D4266782B5E
5C2A553678577A5E4A72935842394B3F5543364348E38A4D474E593D4C57404C4D1E8F6B
27644E786B4D5657533D4E555F624E713D4765143B605253651D8E8556572D495F725F72
775F6162D3CE879B8864A68A7E523A5D69654F494C5E737F6866848D
92749F4B588A7159444457673152564E61864B23474445758F272D4D7C429772312C5A5C
5996342848905F85C72816537F44A782173586817496253C444B576E651745578870C82F
2E455850678021334F79527F8F3B425E3D404830364B87493A49374D7969242D3E755781
4A3163546B6A753322486358814B27464C617CAC2C28576F628F7D2C437F8778A3A4454E
598E80B0A42E354D7362AB501D4AA1A570793E435B9C57698C1C2E8F7E4891722B315D89
4998433040B18C5C66373792BA639B80383382AF5642483A3C7E953A594849C87A213E50
4169CB5D31466E92AB5B1E58795CAC8222367A7E82641D58A55D887B2D5062BB5681253E
97967889A7454A938E6DAC3E415871625FAA3E4462735F7A78315B688C4545713E557A79
436768303F989D3B3F7C3B568F4A355845465675452E454C5B67A24A3755575E5F445249
5858416A4C6D5C5448465D57545D716952494F32393D422C4B47494E8E5F545A475A4F6C
606F58544B2A3839425046523F414B5552323A4E423F2A434D415140484A4148414C3F40
5772493E5D4C4D3545642E4C444759293743462A425B4F2C3D1C4F37373F543D421F323F
354D5F424B41254A4E5890666A6C46674063433D605A6D736063596C40763A905186C07A
C3847C7E56956B4F634E3F474561584A69335B1E925646404A512A625F5C87507BD37A45
6B45606CA56140652F7382353E5B4D5E39566A5A7D58C16897CE4F5A4F3A56425B725176
814D4E444C6E85755B588B5A475752396640304A82CA4F55515376484F554D4A47359980
4C5C323C51314D3359425D78628061484759513D6A7756675C56445A50675B63546265BE
735083826B779DAF7B748F5C51637A90596D7E826B8E835462617064
8267CA514B646BB0663D547D61A48829576A835C9B2A3A3B74769AA31D446C854C754416
2F4D5E3F4B302137518954894021477A3B4C422E496C6B32492F3F4E6C2833443D487769
25464C3C7FA9431B46424488C1283864586F8D69173A6F6F69783A345B916F837E1D4A45
6E63C048284937586C9D252A6572327A3F4238817B3C483D354FB0715279512F5F765841
613C43567A5540713A50696C34474D48768C4035556165739A39275D4D3590A33C2D4E44
57A86A344D5287B2C7502D5F845C8BCA442C5695766E652E55548E679846286D9B4F8267
254A586C5E712D308BC35E7A422A699A33603B2D7FB2505466314A924F3F6A50588A6728
4A4E4895B15C4E515A52C8962E56604769C95A2A5E4452A59B482567734E91CF522A7E95
5181892C2745A37F728D3D5A6A8B607E442351809281834938449580688C33475D5C7B4A
666A4F65504945574637535B566E41563E3D5841352D483553325364776E655F5E78567E
8A936D5F4527504E5A5537523D4D423E4A3E4D4F3C45324D3F2F51425659545D41683B2D
677A31448864623A655C5665292B44445748352D4C36392B411C2937433C403C4D38434F
4056716B585847526752B24C547452704F7F774C5F554A4F585D706A376C6DB9588BA250
87677CA667B656386E3C4E5241698D51746B9674AC5E796164575D9D6F5F845880D77440
4C46884B6E504C7B3B5047204D644B80436374446253D674596649685142885598A05A50
5971793D53345C57956D833F3A6B565F7060325E375B63504061614260454D524B297450
287E3D4E5D62733E43284878725E4B43558A5B5F4062635C74756658535F3A594B6C7CEB
6E3F704ACBAB5A6D6B556A575A554962574833403E8D925F7869687F
8D4F7F8B7D7C3743814E674C304B853958562846626332563B40588E6631674E5E9A7929
2A576E607A8C243B69665FAA661D415A5186B22426566A5197381A3B77617789222D697B
6E8B70232E89974E9C5D1F4B845C695A1F3F657334435030445343234726415A75453956
21387D702748621B4CAD6D1F493F4A7350242F585E5D7E3D333F587357A778284970696E
BD8C2B597C8573C7553A726B4B9288223453725EC560397C7C916DB35E30596D8171A928
467362627A523C5D649D406C6F3535696A5D874E3C565E3E63863B557166376173529F99
4651813775C671374A4E4DCB9E28438C426E6B25516B688D8D32455E6778BE3D4E808F59
8E5E1D56A7898A8B3D4378B04D736A434B6A7149956F1E657B6E53887B2B406D8B516B33
5366B06B4E6B304E518962403C353E949336473E404584642D333C5B69914F315A626944
4E585071445A4C5B4A40645D5B83527B47495B2B393C3D3D512E41528358535D50795A66
526E51614B3949363D473A594544424B4E424A3B2E34355B3A3245484B45494F514E3429
9B642C435B54572346512B512A3A4B21403F3D2E3C443530441E423245424D34471B2E39
4F4E4F3A553F4352614C6446666F5C886B8F6D516F577C6D5E5D574F496440945F979178
B85E56796DAB663A42375F54884F585255365541C8426333694E2B5E73849B6194F67A33
745E9F70914C56833E5D4D175C67344F354A4C58693F8A808676434B6476A9764E534963
57354C3A7B4B9052575380583E7D673C463F354C3E365259494660544A6056585A2E7E50
2D4D589265423D4066635E50537E61633B4F4B1D3B5E5C6D6249885B4254265058635597
64586B497978737E676775335E4B594C61573F4A586C535C606F7060
A44E5A83868A44355E62996B3B4E645E98BB2B497A746B8B4831316FAA70883E37477678
6F7F243E455D73618D2D3B4E535A91712A5F94755C7A36267E9A3C463D2A40894E425429
364D7B2E46444346686B213770455690321A46613D5392303D5C6C56A445244A806978D2
36295A72487A9B292C495C42A22C2A58655C60AD2F4D5D794D573E334A82B7615E764E43
84C14E4D5A31447A92487B382A638F6D52782F448D9142557E3050849C575C55235F9756
2F60453B99AA3349687453A5CF464952556EB8B0393B5B5695C7522D43654C9D872D548B
8299C1383165626CA0462F6DAE52796C39439663AF5B27739B576A6B25317FAB5B8E4346
6E9A55607C3A63B64B3C634C428EA73042794C52AAB74E39745861B9A3333A4E425FC47B
3157735C72C0742D4F704F8E96213D58B36B905E284C4F9C6C747B2A456695515550594B
506669704B725A5E544173838285637C52505D2B37243D355F484C5390877D6E527A837C
5D74518A472C50474E616A633E5750686549524C3447394A4837544753555F5B44512D30
595C3E46867384457066365D4A556527475346324A3B44364C26413D4D414F3D5127364D
404559505246374F5844944C5A57485E7E8E52363F32484F4C6A7A59505E85DA499D7871
C93E5A5451A25A42594A2D2C42515E65666892337D3D843252434693558DA58883947062
745E5B6FA473555C27826C348378516C3A615E6B8446B976B6A549554E60764C4F59479B
7F4452394F3954747F756B48365D48678550427830683F363B42572A414A4347413DC890
40652A4C4F7C5E48473F4A414A54433B3D6C603B6778403C4E495B4C4658464C456F62BD
7D6365658F6D5D8457616937804B54564A574A533C6E7369727E6879
8E99B6494C737B9439354C7953953A3A6B8C805B5747585F6F3837363D6578642139362C
64AD3D29443C266C86592D4E413F90AD273E735A6EB142194B8667784D263F4B6565A519
35505F4681A71C45645D455892203F6D5560955929467660516633314C913D5B6D3C3C54
65556B39353F4F47488C3E368967265147324D92552B554464788A3D3C5461748988372B
5D8E6E98823C266A8D59A54C2540725E71C1452854A38AA4D22F355E806AD0951F508B6E
6F9F5A3C57A86B72B6553D66B7778E942F395AB2926D53344E69A6626D2B3F8DA655684F
307FB09D4B8237579C592B645B5097AB3F434145AE861E35615A8FB22D28577D71A06F38
45716793A742396B7580A9503C407A616EA8444450B36799673E4266BC53957D393A72BC
495F92403D5F9D5478993845948A546B33375471343F66434751783E3D633A635451654C
554C3B3F3A56766D45394E464C5252584D413E304C43412E62454748534E5D544359455B
53634A54342E3E333D44343F2C46374C45494F485E4D344B5162605450414A4D41595E3F
83624F7C7E638E503E583A583D4E5A352F405533415442324A30643F4D40663A532F6342
45435B425448704C6761AC4B63673F745F83383B422D546A5A7962593844488C57B67053
884487846FAC7C6C8C274F3D3E514F343F314737902C643A61404B7E6872966098E5745C
77438E6F9C48576A1D6248204F4C416039665A49527DDF817D7E54566E6680725A683C4A
5057784654385E4C7E616D484D6D56333A433E4A30534951434B6A4B505E465B5A2C6A5B
387F514E4C4C4F365234734A43654E49587058493A593D6A61406056455C43683C5F51CA
6C8D92479F747FC149585E26553D6C61554E2A3138987A4F7A8A6573
6862B95A4F5954926E2C494A65CB9E1A3B826596872A4B6988649DA32E45866964AA7F16
4C5C7E61A2411C24337186A2332B497C7E7B721C3B77813D5E262B60955758521E51586A
2B474F28479C5431623E54609C5C504B3F3B64651F38503E838E341F255F5187901E4252
3F70C13D26465D528DAE513B697C5393571E23846F849635335AAC9691B850426ECB9670
984F346F807967994C325D7A3761793542708243714C325E72683482362C698D30458A39
3890812A4C5C5344A66B38627560719C432F683F56A68D204E5F7979B5541B56877DA462
1F3F8BA85CA6322A6A91559F58284E6C5E8E40215E98546F933044998F70B330375C6B54
7B5A1D65C38F7C8D4352949156817539539C683C56464F6F8F5239494047609243485C4B
5A6A9F4A3449675D7DB144385A6D5C8F4B1B4570736DA26123408E627FB53E314C64704D
6657465F464E43394A44587A70645E5A5946513A342B38214F374B4F82857C584C65576A
5A754E6333354C3C44515450294D3F65504B503D2C312B4724294E46574B535E404B3124
7E592B447D5D84455F6549623A656825344E4E2E354F4A314E2E47334948502F4F283431
3E497E4850444C565B52744B58796282597E6975643A534C695F6B777C697FC639E67053
8B2F6157589251506C494F3F5440415A59436131981B66338A3C3B7D447C844788B36B47
5E6983608E677B7F38674835575351792A5A55565156A1828D6668A6516C904F6883504E
453146315A307B415E677A4C363E49434B4B3B5133614B4952466329444743455148A66F
4252425E6064622843306C414B5E5A6651674F2E37424845493D60383931204C4B894E94
5E5357519A5758734786934763274D3B5B6B3D444F5A505A81585D7B
9D577A7B8F6E3F5E8C62A7502876C46797662638785344773928427F5D63812C43546B45
40861940A996244F5523509D731C4145556DAC39245075727340254C594D88AD23395C8A
5DB0851A37805B77A24820478B5A93731F36486152B45D353E5E72667820364B7C605C59
1D506676326B422A4E6D4C4D712B2A82994B3B6A293F827C2D3D343C48735A26385C4F66
8A4E2B435C3F6B9D6B313E615B7B96362A5C7A66964935405D7496DE4B246BA4558AC539
3475B16292702858918C6AC88C35654F765CB95A4146975F678246395C9F518D614766A5
6E697B5147916E4B4E4F47C0913B624B4A8D6F335E8F3C7E96362D4B3149B37932563C5C
B5AD345080648FCA3F3A5F8C75AB90273A7E7179B0772246836270B0882156BB8E6DD34D
2E509F8E69AB3F346AB0655B5B284B71A7637C3A264A5C7047625C1F378A7E3C4B5B674C
5E766F7B426A4F4E49384F5157736C584A4E493550514E3F674040464C5C634841655153
4B5E527739324E324145344C3D40384E4535473D46332B4E313F4F404A4E5E4C485E4921
7E582D456A5F61384F593B652F3A5529374555272E68463B42396437424A6B3844405153
4B416D4B544F615C5F5DAA5A58665D725E733248463C514861496949375888C7799E6269
708B71746FA76B676E244857874A4A3C514E584F88386829553F497833ADC53C7AAD5F43
5A3C514891465045256B522E856E49483E6851625F44B659995F494B6274894839503B93
8342473E4A3380595941635E47514047693E1F4F1D7B454E605B6849604A568C4F316E5D
2F6D3038418174394E4E704F4B6342442D937329605B3D4D50397C4E47493F49365B45A9
49858061A37A7599475B62407E49575858516069447B7C857B88996F
9B697F4B5B864A553A49744F303C465375782B2C4F6758A36B29255D618CCA3527366F45
7CBE251750874F8E921630617B618258203E6F7B6E8B432E6687456F4127406E7559642F
245E8E484054212B84722D443B2353AB5E3D4B2C2A7AA5273856425A713D274A413B80A7
2A276C734691711D2F6F566FBF2D28466D7865A12C2F3F715A73431F4960795DB0A33957
6A8386A67D324E7BB17DB330416B74785AA22C4F9A7A488477344EC7A369A06E335BB363
457A483D72C462377A524693D057655F3B72CB60357C55477DBA413951625F89892B6667
6897C63B6C91817F98231B678B6EA8772247A97FA3762239796B617C273A51AE72B05835
469369AB77384375626A75473445864D61A65A3067833B5664373A66A74952484C6490A9
415C614B4A8799255565638E9141345377719B77193F7769677F93312A5DB17E51618577
795A466A6067626762565D6E4A5135313C44533F402B473D4D485F6E6B6E6C576A7D5168
89804A702F335357574C3C4D46543F554343553938352F4B3547543E4741595D434E4937
7B5B3C496F616B434D7845703D48652F3547502A3558352E3A2F4C28453E54384C2D3A37
414279494F42574D5553854252484F6D557D2491613E5E6C96537650465182C44ECA5E51
75529C65508A3D4E6D4442314F47624B49514C3D851C61196A2F68873B52594899D56883
955C705D9F4F66601D8155234E353B50377A454E5A86EF5F916358613F526D3769695153
556378434238674B664D5C4F324C39353E3932482F55403B3B48622A3C43344C44478C62
55653E49384E463C59475A48585D575A67805F4E4161577E53303E3748535F7936624FB5
4954443C5F4F595E54906C355960A759644A2F424285655B69735F83
8498D84C476472C6492D69AF81C340344470669D91343045746D7A803E5465A3509F3E32
5F6E4F496A3030558C4D2D483C3784922F3335243592671E363B34728323263B44629749
27515F6F84A52218448460B96E1B1B3E62A1AD34242E66546D9D2A2D4A6A79B0652E3772
5D6770433353784167613B3D947C4E7246244E596D4976363C8A9C574578283D598D4640
5C2459718951486855719C55235A525A5FBE5927656A4CAC8935325D5165C8AC27396E73
6AC84E364EA7BE88BF494C6EA57ECF9A27458E9E5FD471473C797F6A77214178AB549E70
333CC39C7B7C3357816250713A3E82A852603047A9B24347714059A35C5677376CAE7041
554352BBAE414F5B689EC37F3E4C5A5695B763304F774AB1C851384A5E4A80B0313C737D
5086B83D4380B56E978E306A5F5A497B353E6E644645883F436B815C53713B4F505C4F2E
4B4D4A543E4346493F2C558C7E6548695E5945223638292E4A3A24424A5F46273B474C42
375554491F354431323C2E391B3033473B3B4B2A40334A5C30445F6A5244565D4956593B
A76748527B5F72404D65718A4451533252434E373A603F394E39502E504D524256324236
444D7145544F75556771A14B5059607C636D4B6965444B457145535965448EB06DD35E51
4D3C6C4369B2465D6344515E5B5758656154427CA04C48437E48555D42748740AADC5E49
4C48604A66355E59329B5C1F5C5239512B4138636045558ADF6C3034365B774573793D52
5143463C4D386E52563D6748557638374642293F16613E4653526D3A4A6A3A4C43257D45
314B216A454652194D46654F556263774E5E5928424837404240834144272756567666D1
62715945A3636677325D50396C3D52455A61464A3A815D707B607B85
6B668275734945668B39573D377E983152432D4B944D235570365A7B372A426E858E4415
3D638582BA611B4C4E5A5688402047607471852131507F5A97312D586450696D1E35597E
49C4822341755D42522331649F3C423827497B772C3E432E4280683139335A85621F3439
3250974821315D3A84963A274E604B935E2B2D697A6DB3403147635E9CA930454B808199
CE3D466E8B8BA9B72F63979F65A98F294E979B6CA5342B4EAC738668364163BC6F818525
488CAB44715F3067AF6E43754C3569AE5E3E683844909436A07B647292452E554E56B68C
2F4562738EBB383C6F567AC548215E8277CC621D4FB07F8F9C3C4A5F65789D343A8D8E84
AD514454A6717E6D213F77937BA6862149B98A5A88512B36898C485D5141437E6E2D6E65
4D73AB633860745B86A34B434B3F6A7D5A274C6E4A60AB6520326C656EAF393156686F46
82534E6B3E654C5B443D555F6D64547A474545304E3C412A51503F45665A694845546260
596A597A464962494D4E3F52354F485945355130412A27392D3A3A343B3A50493D506044
67513E4070A092455339324E383F4E1D32344B1F2F532E403F3A46363F4F505456494855
5B4E715F68496C7C6D7DA0647D735B7E877A467F5F4A6253894D72375463AAC18FD05782
954C7845639D5460534A4C566E55534A45613876B93D4A194E2E5A7A40A19A3285B3504D
59416660A53E6965426651426362426C295E35705F50C5505F58344B2C98B64E4450486A
6D4644636634753953387151343A46474C3F3251345C3B343D416A1B3240294C47398B66
38551E3D28464B1B47344F46527B5A54395D58428A6E345238366933534C48562E58538D
578552498F6B7A9E4B896C3F554D714A41453E583167646758707177
A155786CA556444F8C56AB4840398F5F945A3A5553A075BD7E3B3A58587FCB17364B5841
82512744706A2E6A721C3E5678325250366760452B832E2D866220365133619B392C3339
3D8A6F22324172749330225073657654233A797844896E13395B5E638E1C37618363995E
283A6A7E696E53194B7C683E5F1D335DA046555221346EA24C6847225098845781622D6A
6567395E373855A27438562C4A5D7A3534504F699C661F3A676877AD30415C8B739CD560
2A6E8776B4852D4F828D6CCA7232436E92A2DC343D3E7B5DC385214881855D74373D4780
5283532A618CA17C902331B3AD5766634074A6606D42445B87394D572468B7583E633041
7B482C53556380943A32756F7397AC24325E6A7DAE9B2D38596083A9A028475E6F6CBC72
2B4A579B9BB64B3D4D70558D96292D718A548963312C5AA1616B47474384B1605C65614C
80716E714B765A66554E6C988E6B51635C566537403247385A493E487251634D4B514C63
6969416B3640564658412851314A2D4D423D493B4F433A4F3E4963424D415357466E716D
8F5A41466E4759444D63377C4B3F5D303F424B2932572C363C363E2C424740373C32442C
3E345F2743355A3F5586A0414B5563705665567644444A387038693D5857A0A48FC6375C
5C4F684289B94451546753416148374B4986668B98596A3D7A359F9D30738045B1CF5F60
6951575F6E425D613A80572B5E576D7F456546616372B45F925F4760356D8B3054506193
7844454141325F4E683E4B4D4B4F32545B36273422605644404B6F2839553250492E7936
415B1B4F2348503C4A2747504A5E606D41694E303A494964463561403E292F4A385F4894
4A5C3B3EA152545D21645333573F512E43483A4E49835C78575E6B73
9D778B48655D43603D3D655C27583331589A3C4149342E62B13B4A463A54735C253A3266
A86219213B69548AAE22163F76578E9A1D4F645367C4481C5B7D6294561F2C4C68859D24
2D3A64465C6425535C4756873C2A34493456632C3334764B315534295C40284139285168
202F3A48449696223662686388281B2F7359937F2325516C609F641F44476064AA8E1C54
736475CA74324682987CA625258D916191BF3E3A8A9D75A17C4B5B7B8D7E9F593D5875A8
67BD55445DA15B76963F416FB058867C296687754E9F3B457D9D33425E3079BB542A6048
40B1BF4330605381B5292D536976A25F2B5F6574C2721858875491882823608779C2333A
6D8970B0743067909C80A2474A76BA749785354858726C67B131408180526888462E75C4
515B5726528788365C4D4162A0503772675F8C812E324C4E6881531F243F4D585168734E
786E6A5C444C585A39355F607164516C56574E274943403D644D41515F79694A5A5C6755
6460575B3343514E58463A403B4734693D53572F4A272C38384B594956474F56554F795E
A2664C5C8E6C7A49577D598954525B474E404C4C52513B474B444C39544D4C494D3E4A39
5858654F5B5558707D6C8167597A548A708F7156614C54786F417A5461347F6C8CC8397A
88637D428A91476B333D343D60745C493153335E764053326A39788E1E8A8A2FA1C3525F
60506E6291415E54305E45315A6949833F57416E555F974EA376404332747323574A2A5B
5D4E4F5C6A456B415E2F544A4C5B3539433230442E49403F4F51703A395C3E4B4943914A
3A4D435A3444532E4230474A4A5B434D4B5C47424B4F414F44497B2A3E38354443825CAF
4EAF6B427E5B535338715055674F5F475169454A4575546368566C8B
6977B35664695B8740325B876FAF44363D6959757A1E3F397F6CAA8A20435F7C64A62923
5D744A6AAA2E274D5559546925335A6F4A44431F6CC8982D5027205988473134354A6246
224E3C4A65902A1F544259A08623443953739B452E3046637693252536696BA24E21474E
367752212052A68A7C92243E7F6D5664212C58A96B675635314F9640404E1D46718C514D
64364D76AE434057463877853A6362344399493A5A3A48719930403A4358B39D32465854
7ACD5A3762504F83DD7A27659B5C8FBB3D2E7EA968C5543951A15693942342917A92C46D
2674CDB0A968275F7F555D803647819C4473232F8AB8557C802B41A365575830417B7540
A12C4AA37B374A564A5F91563E704941A0AF2F2A4C513579BF571F528C537CB83D335F7E
5D8893313176A8468063254391815CBC59314A96825F94221D51A2524D603D3A576A5E48
6057536036685265463C6D819579438655595B1B412A392948462243675263454A4B4F55
4A574D61374751404945413D2A393B5C3A3D3446552251493A4A41404F516A4E4C536D69
9C524151758E9A616A5738623237572741364C2C445B40473F4561494B52654E4B46475D
6546594B5D39547A667FA5526C49547673B8686380606545666B88899992CAACBCD662C1
AB6361579A8B3C4C3365364E505134593B7A47827F5E7B3A5C37847A3B5D732FC1D96E4E
646A7A699A3E87562B5E58315F525C8D416348625569B2598C7F454C468E8F4F5F574A8C
623F424E54458948573E84644550514B47433B453A59534A4F4E772F2F51395237396E33
3F40244E3547552E37396C394764495238676548485E45573A445C36423F32462E4C7A95
5F57476C9075989855744D62727F78425B5B4B5C608C5661536F7570
9363946D92514D666F558F4234726E3C5633343F706027693F4B5D712242614D628A4E18
365B3383B54C163B6A5B599F66174169658385242658A953AF4D274360667760184E6055
4EB76E2344715A699E2D395B875A7330254674925B6D3E19427C7931711D27638531403D
234B7868516C5D1F5CA13D333E3E5D7B4A1D2F4D4D6D81322B3B685D9494242350675489
A42F30438A63898E27494B665AB86F324B62847DB9413872996073593B4476B069909033
437FB14B86423A4B92DC6093443646779A7591314E536D3A7762406DB7874E7B434BA3B7
3F3F636588AC3336694E6FC68B30476A7AA45E2B544958BA8D2B315E6D97AF2B4A715F80
CC6E2170AE7BA4894656808E738B502E37AB986CA479322D838F616B5E2A3F9CA948763C
2848874A4569423B6F9B4B5C4D36314F85434B6F2E69BC7C42413C544D9F87426B6F6D3D
8F6D667A45795663473B737B8A945C88545E5D294F46483B53542A417F80854F60705A60
4A735A7E294A574059443F49264C32643D3A322D4A2936364A583B4E4944554761456E76
A53F4C5C584C58354B66327E3F44763344374E2C3B5433412F4D3237384F314136424527
4C395329452E53564991964E5E3F6E78657A7185573D4A304F3F7D386845E389CCC1569A
807087416A7B7470244B47403C594F45335B3A7688474734673590813B73775A7C8B5E6C
665763688938755342734D5589535B8A4F5F376C5773A64594736E8F3064585490775356
565D594F4C2C65465C274C41454E3D595C372C3F3F6B4D3E60586E424A503B6B442F682A
6658244E1B6154233B3750433F5735493A7B5D2A4335416A484D59367D4A403E3153538C
3A725B60964B4A4C4C765049595A64626569444E4B6B48557E51559B
9A4B57529F58384A5F63BE40303856699B3B243D555D6CC5472A756E44ACE132417F6B4E
AF55183562696DA691192F3D725566551F40583C3C682D384E61385D602D50975F5B5E4E
3B788E373E443F3D8B4622453C437C67202C4A7A7A73581A27486C43A9271B316A567963
193148A084B245294D63647687203C658E4E6F45253B82A9565537335A5F4736733F224F
7C815B955B41486B533E4D22355B804B5465255D5969387B594FA07547546744707F8D3A
355D73829F63303E509087AB7D31505460A7D83C427E8B5F9A861D509C88ACA93F325A9F
8EC994465F827A9D991938647D859B3B538A86589843237DC46D6E65294A9E836169223E
73B9697241316172415285364FA1873047375D4595A654483A454E85A7372D606A54B15E
243A796677BD40313A7358A39E32394391607A8F1E42826446A867343370BC64677C735D
7A6263796F665C556F6B7B906C8F6362575863374330533F675372695E7A5447515D6370
766F575B2E4C4E5859403E36433E2F614872353354234B5A3A4E404E49626A476A575862
8C3D46615E57613F5936387739435C274A3854394D6839432F3A2F2F376335443D485528
604765385136525D618F874F5F3F57707EAB5D676A4F514E5B3564265A198C62C9A94A99
5B758542672F385A4D62463D3B5C4248347E3D8C7C53553A5E34A89113616C38C1CA4B40
40545A5F77278D4B33593A355C41728252623B5A388AA959AF75454C2469572C533E315A
3B4C49574E3A733554286F4D4F5D4445664A3037393E4E37464962292D603246343B6B33
482F3D4F44514F2F352F4B363C6452563F666B4F434A7A9F6F605937522C434352625480
409E77536B225D44295F33474F4B5C3A5A3E4545427F46596A505C79
757669504E815B8D324F6D704F62362E62A94A3D3C2F3F6E844A5436152B7E7C415A2D23
5C8129344E2E3B53913F26533C5CA36E182F4535589B5A2A4A3E3895902A3D44567DAD27
3349565895A51F28546B6DCC64245AD16D80962046435D4E806A1846666C437930354F57
294C591A3E6A693B595A3A477245334433495364262A3A3C607B6B22414D5F4F9B832331
5D4F5C7F9B39656B50988C2A2775575EB3972F4A556457DFAB215AAE83A9D7582F688887
80C860438CA4679D8032569EB3636B683355A8AF58742F4B6B99476E601F4E97694A6D3B
2A67995D5B4142819752314E4B54AD6C1E5B666FB37D2057648DB99129256368B7AB2C2A
54857ECD73315B6E797BB2543C5A834AA6902726477963B284202B459181787528595C65
557873333B687F516C362F44685B4F61303F417B663A7F3E44496D4F214D4861685A4339
4C5055543A5557533C375A5D5768484D473F422C42423B306453475262736F4250596047
4C605E673D4E513B54433D372B3A3A5131383C3342163E32383B3D72496C59323F665658
79424248768F6A354D3361604047393143403F37415F373F394B353B3557353A2F4D4D44
49535B404A444B584AA17063744856628B9A5780775255465A435B39764AAC6AB0804AD6
6572666093524A5C175F50836469666B59734D85815F584A5546815F2174852B9E973D60
3C5138557425876B49605D5B774958575060485F4788AC55746B615D3090572B503D3A88
44474B44393356425830583B3A3F313E4A2C35433C464E465D585D4B4358445B3B3F6D34
5B44353F15624A203636633C5D773D3E475D613B503C375A3356413C6925354147475F7C
236B63586124B7572E5F335C5D4A5E366448434E547B4A567959598D
7E74B8575F4E53B552366E5855813A2F4B697C6C631A374F4754C3801C32396799BD3032
5C665483A11D2447597179A334214B993D5F5B214F5A7A479430204A9F706B48203E6486
396B3C1E3386543F591E304F873F5D323240685B1D41213F9CAD3C2C4D3B50A44C203940
3169A32B21585845AEBE2B3E5C506BAF5D215B725175BB47235E9B4E795C273F60BD8574
762E3C588E9495793060946756A44D3C80C0646E60333A9CD666593947549A9B5C67474A
619385334A594D7AC354314F78657A8B363A59888ECF3E1F52725682732528456D629E53
2F52515FBC821847815C617B2D3763A45E9A1F3B81A649A4492A68A07B728230468A6658
64284952725D8A5A2E5974815E765B346EA977375847467F973E344A464B81BF3F376758
5585B42F3753555EA05A2653717A88D0382D594F56589746284F62A355A9823C477B684B
89565B794A78576567626B6C8877537F5154532B3C3E4745586770868160654D6672645F
55794F6C374A5C4A69443C44413B2C5239402A485D2F3B3741502D322E4B4B2D555D5577
9F3F4D4F3C22434555492C44414847262A3343313C5B2E2D1D412E2A27582031274C461D
3D3F512B37344437399976375032683543515D845E635E4B5E566F26562DCF71D0825BB7
62957E4157264D68404925403446434A2D7938977552534852487689465E5A32AFB83849
3D654367825A8B5E6681594C784A4E6E6A58385F46B0AB439452474C3858553C6A4E4651
345B453D313053417C20552D324A364765362B3B4345452F433B5526314D344D3231691B
64383540164B4A374B525A4D3D5F495B399D6929382A698249633E2F572D4C3E5138549E
4679704F562D744C3E5748514B52754967425F5C5D8A5E60746558AC
9C5A686B9C3F47518081863531495F50A944173C624D91BC383143694F6B643249797C30
5F452363AC662F3E3D23439E6425553B5E637D2B365D4655874318395644908A19263B72
6AB9751B49536383C12F2957646B9E4D2043646B648A481A49A38982A91C34527D3C5D2B
253D55524052383443908356551531628E404C4D283A5D974E3E4229696B2B2243393464
724B2758443898BA31366E495FC0741D4C7D80BC7C2D2769A686C86E316A838984D69729
4CACAC86BF682C647B96A09E253E7181608DC92451BC8D3F674C6B8CBE8654783D48688E
4A6E4A3589CB7B4F622E83D05E405A3E549A582E3F3F4A998C2E54616F8FC66E3A636DA0
AB333C624B6CD3BF24426B6B91B7733854567C8DD05045497E6977AA892E2F8B8C88932B
3442907C7163264A566F4F7349345D675E3D695A253E7C7F3E6D54242655A44F44806C56
6B6161785B575F524140797F9273627B5C6F553850384B3D60575062717B683D4F5B6B55
6165595438485141543A453B3E312251455F253250183E44374F405245664F365E71676C
8A3A41676A54523553355770494F5B3F302F51383E5340423E41473E44633A53463D4934
5C575C3F4F3E324F63BE89556745574165613A6142373E6B602D2E36481F6344D8804E8E
3E866662782862801734375051734254287462BE76624552435C726B316D7880BDB1765E
585B36599144895A4C5B3D437336746657502C732A6B6D4D97474F4A4188454148413353
5C4348414B4E54445D516144545F2D344C1D25253B334E324D4B5F3A3D633D513955823A
6044474B3A51503331354B433B5C49483F5A484140354B614A59363B5A244B4D6A66618F
53A66B708E50924A538D59574A517745593A445E7EA25D5163605F7C
976A825D707645613B46A14C3E49434A789431393343708D5A30595356917E1C25576C69
BA681533619064AF6F27353E546DA232253D4F4771B73434747A518C4B343D7B5D89732C
3D66823474471E5C976E55593E356A733138522F2F77812831432E4F9D2D26403556A96C
132E4F3D57A84A25434B496D9325164D88539A821F42496B60967B173352535AA24E1B37
649B6CB1523742AF8F7961222856A8576043204A835144663C2F47903342572D3F6DA557
4067486782A45970784E5BA36531658679A1D3362F67896AA53B34706F6C8AC5384B8F74
8AC07A2333807CADBB2428788E9195314C5B6183AE373473927C9E78355085789A872F54
C28C8385463987D5977E84466E97C757894932548BA94F5788393580AD494B673357A255
3663494B70A74A3370647C905A263F63564CA594372954765F98B13E2759A6705F705743
6B49466B45714E47817A6C5871744E71444F531D374C4440504E496369656E45614C5F50
53614D613F494B445C4941424E3D375D38442F525827564947533333465E533B63705D75
A5404D665D6B664B5B2C33624A48502B343F4644405F384F1F3D3D3B30561D5625484938
63535656433B395745C48C6A76455625703A26642D4850787C4F533557458F3AA56871A6
378A6779AB40535A36682B50424F4B65485D59A6644B2D4E455F8A821F748628AF9A545A
31693F47C071C1404D615C4161456267655632501DA0843E8A434C4C3B7C583D4D3F5267
4A43315C4E3D5F3E70446551464D3C4B53212D2D44544F544C5F64362F65454C36556B30
7B403942226151363C394A445265455149624B5F5F45585F3C724F436C3E4F4853456788
527F685C5C62C65C396734925D5E654A785E585E544D545958735E6B
8583A0485C7172B949345777849B27302B7E5C8E663148697463A04B1C519B75635F213F
507C454D50225E5F83404863224EAD7C2D54373F4D9F9134483066B248284A5A2F759525
1B3B5A44AA9423214466748B3B27396866797C1D23416853797D1B254B5E58AE3A19567F
44585F2E2B385D4C7A7139327D6549582E2E3989594262253355A5524C54263A597E3135
4A323864933B684D3A84B3312E4C5E5BB08B253B5A5975D04C2A36535A9AB23B2C427368
9EB22F426A655CC6BC3753857C54AD5C416FAA77688F3A3488A0428235394570B2515E1F
2F77A6654740375198533B5E2D719D74476B2A50A78D4664514091B0443B5D4660833235
506DA09D332949725FB0B43A376CA279D0A5312850837594B33B3E4D6D64AA9239595165
62AE4A31579974666A1F2A83A2578A642E304985635570293F43677D4785474B717A6E57
8259526A5C5A58674443607389AE6E704F5355263D325054565874828D6A78496F566E5F
56784B6546575A4068414D5B44554872455749344F273F392C603644516C495D645F5195
A22C395F4C565B386636336F4941632B243649453E4C2A3F334335383D4C2D4C29454229
414352473D453E5959916E445E4E5B43473A4775505F5C516E60545C755B9B81CE8BA5CF
74A3796D984D6C714739385B3C4C4454498C4BA86769514D2B44515340AC983EB7C75069
52904C68A6655C52746F5C6C7F6189858E73526341A472567C4B8354455447374A455970
3D49354B445575517F607C5F3F4E563F5544454F4B525B345C465E3F3355547E34506525
8E414E50378646323B406152465E414D2F995F33401C595A1F5B215884545B474D318687
345D4790763B514E61744C4A4B5D63314A45456C707E5B4657515270
6D526F5E7A3D465A5E5F67374478704A5C2F3A4F5024414F46649353223D486879912626
443B6F7482192343565071742A384A5D77A62D2C305976828D332778805387643F457856
52612E2D557D6F5B5715314F5B4C762E244A94532C67272B498F3D3A46313D68501C372D
2D6D8932303D3A489596343A5645639C452A4E5A5B8B9A263456735393801C2E59996190
A82F3E54737CDEC04C3E757D84B63656768E598A6D3259B2B07B80513C739173536C552D
5CB7795490422F68BE9B65993B60AB8749729B4C64A14B2F555D5A8B68242D5F7A6BAB54
274B748AAE6F27669A62899B303483729C9A1E365D6462833A214CA98EAD8B324673715C
6A274B897A43824D2F3B8B605459403E40965E4D80382F5073582F56332D657D3D4E4B2C
4971A0433B433B85B02D1B36565C90A3222A414F3385CF502D3B416E56AC613B7F7F5848
6B5A677A41777074504F786D835552644A5E4E243C3A38364D4C45605351595668525354
615750513B515A64633E48335739376A63853E45662D5944346A3E7B5A613C3858554B59
6B364977595E813D713D6C853F4557543439445D395338632541324F3B5E3D5E2E4A4540
545D69565A5A496F72BA8D56513C4A226A272D593E3856605251584E67678F6FC87B7F87
458C709398235B6A3E52566350785B6B286F3894365B315C4A6A88791D595D358F713E54
2A60413C954C8646574C4738576D9C653E37406420837E687E3B5457375F324D9B2E4655
356B48653F37443160546D4958502D699F28332955565B41434A5C28315E36483267712A
5828323314584432242E3537214D43492850424344288C87377722394D31514B57374C4A
328137828A5B6556506C5C54525D725256474C596F634D5164545578
AB636B61BA5A3F4C5568AB3442576A77983B2B626A649BAA194A647F5F86852641797555
A2431B52805335822E2944835E39572B2553783F5A5E2C3270443B5D3A395D642D517830
6D953C2342443783B12C2945554C9F421B21485C5E823632274D629E621646544C59955C
1020445762751B242F735D6A4D1A37435D3D5F66294C93743E704D394291623774433763
C09760923B3B85A55E51504152876526644E4E69B25336524791C84A2954767682CE582C
3B7F9685D04B2E5B978B9DBF543368B778B1AA3E79AD9679BC443A6EB278A0A1463E5880
64996735688A577C9A41338361516A2B44905D415D245EAE72436D714374A9557056358D
BA35506D5958AD942F495C6675B2643F54767E74B55D2447737558B85A29628C47958122
42729773A16733406265485F3C48555B7A4472742F4676704B7045263683C15C88865748
6B5D55644968465D5454707E725E648F5B7059284939404551464A5E575C72455950624E
585F68756157553D5C4147333E3631603750344E413C6D4340542D453F5A504C5D506693
974A4A6B8B8C6C374E3633643E40583B493D35413A49274234462B3545572B342A444256
5A515D64315D677F4EA1857A7154463E633732524B46465E6E5B69556A696B40B756928A
5C966297B345645F39853B51374C2B3D1464348F4683283D213D4C6A43716B2ED7B82E50
2DA18265656184415353305B7E456F68574E4B615094894B66423F43447E39395E35546E
2D3E354D3C556E3C6B6D8A4E465235303A2948373D334F4051454D362B453955294A642D
623442402E6A392B1A3732404065424738604C584E36414E58894A3D5036493A4D256F46
218258A25D728D474C62385F475D5E5A7D5A4C515B6B4C5961605678
B3A69E525F66568334498375597327506C863E755B325A736640633D49668A333241504E
815A1428655254B6491D31605B5C94273B3A5686989B232639517EB42919486E5492953D
3B495D5E9D44274C7A75768F32284F7B577D6E183E658B545D5E1B62913C466326256188
3A5A3F293D814F233E374A677D3C2D5C3D499F771F294F53569D5F293854615494482F68
777F81C439385C6A71949827357B8E6CA74626415761819544337D92558871504F73A04B
6A7A4270A3B365A6664953A16D39714357729C50366B3B75A77330573E3C80C0692F4F41
41AEAE35444F3B7CA92E3D685E76AB35506A536F711D1B62846397553A5D5E468C752249
A7457A9149447DC36297984B5B7FC165AD61366D93B95F8E5A304479A647666645547F48
4166383A809433617337478E5D234964454D94A4312F77644597A0351F4F7C6C79705952
824E57724E6B58755251605E7568686B435B4F143D3A3F30454A53655345634F6B465B73
766040684748474C5A536F454B403D7A4B7344425D294D476A683D52356B47455364439B
9C455B5447506549783A355A454954422D4B434B38502147104823414D4A28541D3C353E
4C403343295A355F54A46D48666B62354F3B3861495253594D61606E836F6F64AD82C1AB
54897199AF3D685A2F4B2A4D3D65394C336C4F90493A334F2D7A9C663B79844F80895560
51652D5B51386031565F34435B3D7F5F5F42525C1ECF6C5C764E6E623E492B366123394B
265A43584E50765978607234484A3B345A253B1B553455274742512F274B3E5E2870641B
7523442F0F592E362B4F485143464C4A3E83473F3E446255517944526C394843540C6552
31A94DA68185B5464B601A5C395A5E4F754F57516B7F544772565278
5E78B156655D6CC0472D6B49699C381F3D564C90792C2C51627DBB571B346A72A07B2157
7A9B566F63253A6C79556D4E27474E45404E15365456566A71293F8B9936712420476D2A
2751223E8C992738422D59A5531D353562B297291C3F436FAE7E192E384C7BA5281D3A52
407D971F33717D4C8547194B8473716836404C8445558D36326198556D6D1E3876AA4164
6427538D874478403F8590413E562D4DB8BE2D495F2F6EBC512F4D4B3F7E8731555F8364
958C2E55628D74BB92384698B36BCB593F57758876A42E2A87A85AAB4F1B2370745F9136
1F4DC36C8D441F43B76A62722D40574F565C214B7B47515D393288954678604371783D5A
69406CAB5B4B736252627D423C575553A2B53F324B634FC39F2F3E556A6AAF9E3E5F685C
76B3502C73906F7994292B5F73537384372E3FA7B761CE543A3B6F7A428B3D3C877D5D4E
654F586B3E8A737A4C527C798A756A6F556B683949434833484B3F63765B75426F5A674A
5463756F4B605253552D39204F223E66456E424B534D5831445F55562A523A53544E3762
68293D798A785C2E633D5062393C3C4217383C4E44422F452B4E2F3D44403D573E4D5B6C
6E635B6A5062446D6881737F6C40557C993664582D3E3864489F58535194AA899C536765
468C80B6AA538A82434C53493C5B3E4D1E73378E4469244C1D4B76712F60702DC6982B43
1AA62F615B548F4852523B78724F85586E55655D299B4F6B6738493F405A3C3E57274368
49374D5D40464730555F6D335058323C591A3B19442746324D444D333A493D533941471F
5F1A4B3427593B3E333F3F453B4842352E553B624F378A855A69233245295D546032723C
37714FC77D7B9A585A76355C316F6B546C3F43508A96506D825B5283
6C6EA282AC465B597C856B3749727F5C79183756734F6B70282B718B43643E41648F5339
4D2F3E66742C204B483674A72F2C664B579F4F224A653FB7801F404C5F62BE36264C746F
81AD522E3D64488B51212F54826E8F2E174F957F508B3B2F507843473527527C6E30533A
2D50925C3D4D2E497B75323E2E3E5074451F5669513D7A2D2234504A768F27274A713E89
912B335B9654C05B23517150827B2945519A78889832374E7C77972D354B62599E85253E
7674546A7E343983B8616D88404F6D6F519089285A8B814D7D50397E82414B584652B274
3E5D7755AF751E3B4D607AAB3445584E7BB53A3166588ABB562476766BD24E2764AD6AA2
5D3E4D8D897ECD64345FAE7492973B3981A28474A2343C86AD5E53934C326EA76659551F
5590904A744A3C55814E46463656557E3926404E5F5D917C2F43476862A0703D8B7E5549
6B554A5942604B5D4A4E72776A5E7E6B5B5D4A3D5848413C5F44394F5D6E613C57585E4E
5854535D474D443F4A4957313E255453536A303B3C2B522861773E3C3F61443E4F704F90
742C486C5D7E60405D28316A4655494422483C3642474057415D474A6E4F2D4A2449313C
3B4033432C4E4A675C8E574A515148384A62473E565D47553B4C486D6D6F6058A1479088
5D7B5BC6B226566553664961484F375133754191435D2D5F2754503F2E6B5E479E8B3043
37843A6C4C5370435B58425A6F3F793C624F433F3EB84F7F7639413147724E3742213E46
3839374328545D2B4D42652D30321B26371031275B3B544443515237315C3C4F2964533D
5D2742403D4E17422848434B33493F38255A2F413F31515A6F8C293D462844699156753D
68AF4173616C8B2F45541B541E5F4F4C79534C4F8364595352535260
88656F679778415C4A74872D2A49406F7537214C614B8EA21B35475B5EBE752052885D89
AF2A1F548F8A6D882C515C7064616619579E884556471C5A9B4B407C2B276A691D615420
4B60713857303F5356356071344578461C2E38417A8A31283C6859928E14317455588B40
2255685674942E3B557771973C1D3671B863C64F1B36718C5E7C3633546974488D3F313D
856A526A494768A7598775385CA9505277503A77B9544F4B277D9273375748518AA35B31
4E6B658FC44D24497CA1B4C63758918170BEC52A38719DA2AD453F4D68939D872C4E58A4
7398602E95AD51993A3B577F59585B2B55896C66A04B42BACE4CA15E436C854C634F347E
A03A556547338DA43B638C4C53936E386D945A77BD94384D686B6EAD73423E768092A336
256291698E51405A6852719240416C7F884E93552543707549833B223D5F905C8172564A
7D4B5170418252724C637E66848B5D464D65801F5455483152503A5F8B69763B7A628350
6774787455644D4B774858414A3A3C4D3D565563453645234C6C5F693E4E4C574D4349A1
753E5E6A6972755C73383D573E453B4A1F3A313E3D3B263F1C51293E4D3938482A2F2B49
46552844344F3457558B5357515F65615B44446848415D696D8069534287546087378E50
60864C7F903C8967454D40483E524065415B617E655832782A5968643B704E49AC913E49
2D7D3E655B43631F56553249572E885F9F6C694F45D36264545CA55838504141572B3F4D
2F865952202F482C4775A446353E2C3F3E38543E593A4E425F5C505440485B6F39545D3F
5C294D442C7B2E3536773D4849653F496B9D3D443D405C685863305379424D404C36AA66
7B70397E6D7FBB434D5C439B49675868A35055537863656684665575
7F8E9F4C6D8FA0943C4BA97997824044589D61A8354152636753812D4E6F9E566940453B
7B59316A3C294564511E5636526A872D1B395D58783215226C64789825213D4D3E9A7219
24547072A9292A5652479EBD47364F8F57957D1936717C687F4B264E8D4F7A6E2B286280
3778573040917E3069323076913C2C4B2B5F8F7A2F4F5F3E57724C1C565C3D478E56213F
414974B84831435E499AAE20338A6D83C55133418877BA8F20395D8391B8543B55849674
B8854371B6BE86AA5B4B6DA8907AA5343490B561644F2C4A909B3A53243A789452355A37
518FB5495251568984234B805A71A5312D624B658734334B8F62B85B2F576C56A1812935
6661859C3A43549678AEA53C69788F4FC08731417C987BAD6C31425E7F577F4B535A775E
706535366F682A626B3035646F3048674035725819445D3D617A7226375267648F938E8B
844C4D816670565F6A5B5C625D595F5B49545E2D50384C4059554A4C80657C487768736D
986C544B4F596B6E55424F4055254C66475D383E5C4A665C5E57545647524F304B4F578A
4C364B87667C66356E5A6467443E4D492F483B514E3F314D1E5F30516F42454E2D403462
44582E5B364C3D6356645D9765484D8C6030685E444F597936745073456755719643A951
506C71AC963B858345504E4C4C6A355C446E4D7F546933515D937A6F5B976D50C3A63C57
368C17838856763A7C6F48536A41862F4D567949487D296F512744424F581C39842D4259
334437641A442F3E472D4634333D24496A343E2E59435432485A47373646344128665269
983D4C3346401F354D4B454E444A5C4235552343403F7E69406D1B5D6C5D7551601E6E2D
6D744183826886586B6C39554F85785D6F474B4B57524B5B54506359
597476648E5450A956514136609C4836406F3C817229444F59639334295E685180762841
4F4B61DA501C23537A73BA4119457C58715A1F3D6F923E5F362F4A6D64559B302B54763A
4F7439527F893D61482B52627529782F35506E39433D1F3C7A611E40413C738B2C1D303A
488F7E2B2E5C8B6C973F263F748971992F3657885E85942334659B5E8182224180795BAD
782C5260946DA64145729C7E937A334884BB587D902D5CB1625D68524873A247526B493C
74A137334E3D467F843C435A6B7CBE5A2947747E838C292B507B8B9D57235C6B547AB32B
4591A879B152435D8D5C87844E5392738D8B2E506B6B776C21417BAC495A212B647E4B75
433B5D8E6D55753A4F62BD885C693C3C7EA941455E484F7C9434445C4E70A6742F4A5160
71B859304A515F8FAF1F48524F4D82AD214062573E81B81D44675D3858AE2A4E8F86523A
4F5B524D316A506542506A5E9963847E496A6626454C4D374D4F9B846A585C63765E4D30
61604F7065594E4A5C404E333E2E46565159333A4B70674B60744668444D634E554E5597
6A3E4987A8A0634B552D3366464E4153364248384E3A3741335338547C4136413B494235
3F5D50363F514A6D64865B4E555364A46C3C65453D4C4E6F426E6A57549E75666C63C65F
5C63509A8B5B789A4D64683E2A3738402A4D67A34F54584E3750678165553F63C9803858
3E8F396C5665852B483F2A777E4B882B5F52844C39A1387359405D315B762227543D5B68
2E553B472B5831334146681F352F24463E2D4B2F39303D3346474C3D3340455A2F624A2F
4D306540403B184841522F35425643374B622350463940664C762E4B4C2B453E5C479335
7044468065728E49515A4C71525B566F986441506B5F4E5B724E4B5C
83627E6BB6613F6966916E366274658C7C312B557C51836D215D485442A75C31716F6165
98481E69B0536C5C333986792D39492852793E2F4D4F3A615C1E344B47459C3E1F4B4C42
61A935214C6B519044283C5C7D52B6331E4663598CAD2924507A576C421E3D7979637B21
2F3D5C786B6122285C835087391D374C624776271F4A63513558313562703737883D449E
9D4A405A353E9A5D236A855767962F2D577558989F303955576F9D3045616D7F9FB23C55
63A085899C1D417097858F8A28536E8457875E4084726230A2522B85AC5196544164977E
4ABA443891A9446F382D56B54A5D573A50854B3D61499D9F3E3155617590361F49624F96
622C52687B779F5040476A7E83B5364F66A7886DA0355D819F666E9142378AB958815326
585E875380422C84AA593868482B498A523464452E6EAC5F273F513959BB7F3C6F7C594C
6549484F416E70664558868696637B896E796A375C4F42405F41435E5D6F65464C5A715F
765D5B665760555C6037513C56454855394F433F433657455F6F4275525366515C5C559D
74444A5F4F64584C6843487458613C5F365B333B3C3324382A49345A6A51455647504557
4F6A405C3F4D3C48648D5A536B586E4874438E71504F4D97747E52706285599F9763735F
57572A5B54337F82626A5061704F394663757F665463366B1F7876604460678BEAA54347
3E832363494B683958484A585041757565724E3D669A2A54455484465C63295570232D2D
28493149134C24393952852F524928403F1A3512524A493E595F404A313C474D385C3648
682D3331493A0C3235523D463F394C455F7554453E455665748A4C676F303E425750B243
78673E6F3F5A8433533F245731604D556840495772535560655C4F80
928F744F636A6C6A3A347560516938345D31253A303F6C8C21334F4D5B9DC52730535D84
7829193F524E8DB531245C6B5197692732695D76973B2A5351346A672431627B53753717
3F83655C6215405B68373C561D4B6A4F345B4023646264426036425A592C3F532050994A
1D29293B7C913A27435961AE89293A463D7CC962234C57626DBD311936717A6FC53A3353
A18B87A93C50587352AC573079887B809534419AC97B817B23588D8A598E4C3E56716444
A0644364876E346E515A70AE413C5F4C769DA333426A614EC38C233D6B4FA3741E4D8774
6DD43F19598F79B94F2B497E6CA08D24404C71849623447D636CAF373A967C3D75542460
9B4471532F4D7C8A5A7B5F475D7C5541603A42628E5D2A4F4A6B7EA5612D39647F887A27
357B7C59914C22355A5A5B923D2D3D776F6CBB602E45748852A3572247549B6086796A66
694F5161415349574B45544865827C693E645A173736563D3E394D4A434F443B4F4C4E42
594C4D3E4347545E4639462E4D1E58513E4F31474F32534664764B574A605C556471659D
4B404B7B718B685F633F47764354545E5248393A4B37324B1E562B5C883D463F2A392E57
3A6238643F3C304D63B35A606F927D664A3C86435F625076458F5A7450738DA891749345
625E5D7E7C4C6647484A43393B6445574B4B76A950892F4743506B6B627A53447E7D465C
3D7339888B737E5A815C4D605E30805D6E5D6647577F406C694247394B502342563C5D57
303F515E23522C51443C5F243F3124464B1B2D0748354C2C465D4A41444D4E58398C4F4A
4C396A30552E13554E61393E3C356038444C1B3B4948696C35642E52874863565A5C7F41
5C303C86465B62315F5E32583C7B614E5434533964515348465D7C70
6A81A04D6F5288A234385E4185BB3144554A78B2373C5B78586F91242A87A36E84451541
7A6A549C7726337D8C56974813469B5B505A262F68934C4B3E305B5C2D4360364D994D1B
39634A67A3441F49517183812721425850A7721E2954636F9A3327597E477E5F1730675C
4850191C2873696463212D4C8060605E313462B4636C67253F5366335F49374A62813472
525B74A44F34583B4B7F963357754091BB473B536C58AAB12D45506A6EB7873155548169
C7942D56668E77B2932466999D8C8B414C85B46295862E437DA94B632E3172AD595E7B1D
41AFAA4E7A42334F89346D5A3E4D955A43603951A07C577744589B824054623F8D72274B
724B8F9C2C31446566B38B335A8E7B73AB4E343F807D75BB70235992BB7D8F43389BB574
58A8333E7E874064653049667B2F625B434B54693A5C803546486F2E2A553934879A5D48
6E5F6A683E62685B3B598F93744F54514A554B2741312B3C464C405373556238655E734A
6E707C515B5836333536362C4B2E494A5346374B50514B457B394B5A54525D5349476495
3F4869959C7E53466A576B856571586036504248534251523958426472484855324C3D5D
506B465F4544394F4C72545D5E5386947646884930383E62265B3D6F48916CAF7F7A9168
82925D5D6B63857E4D564D49766040304E69949544534952294F473B434A3368BA655974
51674E80445C5F335B4D26615C2F85424B587665796D5CAC4C2D4A2A647B233E4B25564C
2C53274A2B533C483651622C715B4A5B482D48344B3E483E425D544933385D611F582D3D
573638244F2B303B284A3541563E45345452345B4A434E726EA0295459394766844D7C35
675C475E575760485D554C63475E474B5545444B704D4F5657617A5A
5F757086B8454E74775C61373A716C6E602B4F694F397A3C43586A3C34603C4F829B2837
62413B8670294840434EB0601B24453D9690252C405D51A0891A376F6180B73023738A53
737A376978887085313757848960781E31417F55795A3137636130452F33638F36364A34
48663F22413E5A757D2C1E26574D858D242D31544E827D243C706846879133528CA95EC3
713756A36E7A963027669460AAA8433E729E71AB622B4C8F5B5962344D6A845291A33443
6593515969264873A04F62753481854A3A6E3E5475642B2A5B6E74854F223F5F6673AF2D
2A4E937DDE7C40426063BE952E49596BA0B12658696BAEB530477F7383BE4F2C65B6688E
64454FA3725B702F4D53A05B74633B6B8AA14B5D5E3B5C6B7F382E413785948D323D4546
64B25632465B5F83851B3146595162751D4154604C6BAA2B41686F6B5AB5313E6BA3574C
5A40505846644E603A636C4E645A8476678448356149394658493749537461394A506044
584E454C45393F4B49595C2D4418593433433B4A2D1F2349813E2D456A6A4C475F646776
537282504B647A7F5E27304D3F5E3B4C3D59342B4B2F2A2C56703952A4433338566E483C
4181464F60664F518CB7607F7182738A7241926C6C5B4C604C7B538E49B062D68198CD3B
5C5F47B967305638795353413C466A5641518F9E647346523E6F6B66504C3E8AB781484E
405928853556613A5B6168B5745A767251524F5583905B5D423B4C3865622D594B164850
4A694053256F33515283823F3F371B3F41254B4A57435041546C5155403D4B4C24662A71
653547334B151D44466C474262444B455E5E433A534C51515C66754C6D4A3236554B7E56
A13834644B6B6B656A64676A405B384C5A2E46473D4C4E63634D5560
835D5876AE7D454F5B8D5729393A337B98182D4B4757B3762054824D77C14F245C986B7D
B52B414971598C9327283F8A53713F2F29655452702C3F355134533F1D485E4243854D1D
65B040375D3A3C696C215E532F66B23522433B3F88A4213536415DBB45273F545F8E9B1B
326F7A4B9A381F457F747DA4223F599A945B813A275F715A4C6F21234B805B547F254369
674564662F4DA85D2A3C3D3C626E40434E3369919F40445845ABA8253A515C4EAAB42C48
6D7B59B9BB2E37739B7CB4A62A41826F86CF663F7A8771669A345C75824DA43337719A66
62611E47A6B3555A234C5CA96B4952287BB66370772658CE9D64593F407B70374E3D609B
83294B59566AA752274E6051A992363C5C8075A79B2C57809668897F22548CA281735643
629BAD7C9C3C2D447A4E466F2C28687767548C4D284C5C733977482F3B687F41695F6261
565257695F6E686350606A626981725A3C5A4B2D3E3A4045424E4965615B50445B696350
655D4C504D4B536345343F3541284E4D48413D503E35322C3F4C5B5A55595E49404F819F
4D363D556355322F4C2F3F6E4357496B405F4155544D434C384A3B605F4146573A46384D
4453414F413B3C44404B42605A5365898868A841636343663F745472539D64B85C7AA166
877F5579696C92464E3D44475F4A393A6E49739660656D763D6D6D55555553705F44595F
6B7661926161734F81594A52504369688069665D559A6F765970815167641E696A325F38
3342394E366A3D593B6671225934063C2E264B514C4349404B643F402F254B531E583346
3533442B5E2C1D373F5A5251694445559E6B454342484A7C678A37677C42414A7B66823E
4F57565B4B57714F893C414F49794D4871545D4E83585D775B586C64
A795654588A38E96314E7049917A243A715B464C242869A45C7549324F849736503D274B
6F7643643A48595F4D3D633747997B252D423646934026724F37787D13376C3F4DBA771E
4A6760B6A61F49647263A9B41D43988C568649224C87737482292769853447272547815A
32302B3155553636452B698855272B36434C8F451B3C563D5ECD3C2049503C6BC13C327A
8256ABCA2A3E57816DA53A244280737A7F2E3D5CA17EA3822B57987071A2533C4E687A52
B949434E7254429829415C8D4A52733D468594385F443F5D8771356942336E72294D6A64
8F7728255D6B7BAA383551616D9880175675539AAC3123719886892947477B719846266F
AA68A5752D4C6DA16AA75B2D53AC7A639652357B9B7252762C4B5C968F3F662B608B802F
5D603E468A5F2F53585759A0542E4444515D9E8B203F56524DA29623384D8C656F783D32
615570543C514441324E79876B4C5D58444B2E37512F1F3446382F424D83522E4068593E
47545A36484C2C383353421B28133B3B3B342F39335C525F9B3339416356454A53506A6F
33414B7E7664494B5648535F405559793E644D4250494B3D3D6846617E4F494E3D5C4763
486D49594A4944566F8B56685D717591B4516D5A4651555C2C5E6491548E54D78F92A945
72613E824F38512D474373433949753E5B2D8C884C5C3D49368D8E5A48835183BC4C635A
3E5162913A4746376F583D7A5444883F3B4B6639759764773C2F5B526F613046404D9D63
364A66733B593D533556521851380A483B27323A3047403B485A4A4744384B5026681D54
483947305B4B355E555B544B7759514453362D3E46646666506D364275516D717E5E7F41
643C5E953D50452B522D4B54395B5D73684C4048544A4A5B4B5B6B79
62676C5666485C70535D424F558C4C3B36336587261D403F607162293349818664281D26
6161799B35253D5C776DAF351752874D7B5E2B365E96439B2F2B45654341651A2C607E34
76411F34705C315E28355E77492643353F85621E353E447DB4361441575E9244182A6E65
5F6C26393F5960828B283D5E7A7E7B5928457F9E628276364580AA40A85D3E3F787A579C
5C42699D845E91354A6683326B5B444F93514F6E423A698545416B41447871345E644D6D
AC7234625D4885DD4B2B69876695833E3D5F5863BD8D253A5D686ABB5E3F4967509E8922
63924F5B86444086823F843A3B5D794C7A552F4EA26E5A652B7CAE815F82352E8D812B54
352D557B41334E316EA9AB3E3E754877C279343D677D9EA4472F585F807FAA45235F9867
A5A9334F74936F785D3F4F64924A78561F4D699C5760833248729A674187274258764F48
7055676D4B78526D44696A4C6E578C744D734B4A3B443853514F36433B454C3F6A537153
755B55444F4A3C4A42364B2B40145629363B4A5C2B3437314A2D3B536461534568706C70
2352593C3D47474C48243257616034432F4E3A38572D39353C473E5A7C464135405B3441
4166414A4D453D487E9254615C685DA6A0538F4A45594D704C5D4665425E809F7979B264
878176BC85404E228E2F3B32454A38526F385E4D534E6265315854486B7F1E8CA93C4555
455D43722675644571735F94504061564F6C96516D9472933F414B1D7B6D286D3F375B37
3E4F404F4365426748745F30544F294E3D3158462F425046505E5E4447494942426F5457
42576C33523D3A3537594649643F56446152384454502F4963854F646E3F413C5F939B64
98565374476B4658652838363B653845373E644964565A5C54686B56
5C897E9A9D3C5E7765BC3E3D535D52887A2C286A92569A4D2D4063484C793A366B854348
54312E68732F3E231F3877953B4538276389321E3A595889731E374A568E9C261E465846
B183212B506B6CC25D214978626C7A2122346F509D6619335081529A30275A6B3848492D
2B574E31691E314E604A517D192D76683C31583453556325304D4F4787721C3438495297
5E29578C6E85DC3D457B905C82863750798289CB3B355C7A627DB21F4A796A48AAB51D41
89866CACBE394485A14A876D3146704C4D89313759954751662C467995434E2F3F769B4D
454D3E57BF7930454D578B9F2F5068549278243F5C6B5EBB362D7A7B77B9273E746648A7
4C1E3E956E659C2B2A50AF847D90354D4A8661916E3069665E436E661B49C1AC4E554921
5CAA5136582E2C618D3833503D366685373050525C6AAA4220325A4646AA2C3B63615C54
60606D6B6B6F617C59747C698C9D83694C67673A50574958446E647D6F4F5058615E5C46
6E5954424F39555D45475C3B4B1C4730423029533D4B6249703D435957515E5148457B78
26323F536772645A6E35425C374745524252342E5B293E2E4C44354E7430452E46522C4D
3659464445363D40526743504D564E536A659F4772744B78347050916C656EC37685AA5F
8B774C705D38464142344E324635495C8A5AAE84513A5446236477504C642F96AE416653
4F387A993D4A505E94613A4A496E7A5E6354535C709982955671602159571C993126743A
5B604959388C4E583B9579365E622B57403A4A52534F374A4A7139553E335B63465B6188
4834444D754E26564C564C4951456954A288515C49454936509D44736964794C5CA09952
7128505435745E488A4D45473F6C5A4F3B324849613F44595A596552
93774A59905343473E707C3D444B26649B4043253451504929433C3173A8502340514482
78273D4880628A7A1949456A58AB442C4244685D952E3E4E5139746113317C54567B2724
468D544D4B234072B16181432459B35A3D5643357EA738346B35588F6F1F65543B8E7223
2F433758B633182E575A69BD28233E556477B72C396277696A792B2F6B865492AA1D358D
8D6D9C773A49C98D52B36130576B5A61573C5F6983397C66364B877A3B6E452D65B65332
5F53517AAA454C5145399ABA3C3F5E476B8E442A447C596971282A64924F8C21254F6E42
95861E3871A17172234B5CB16F9357335B8F4B73362E5B7B73554E3A446C7333672E3570
84344F563A597E7333834A5E8EA1553B6E4A4BAEAE3447685A47A9B6372E597E6EB97731
42759781C24542546D6B86972B3C515D6F61B1521D54826E506D6E1D414C763B5F744C4A
63575C5A4F5D4E4F3D60776F6F4B778C727341395B423E5662523A556F726B49666D6951
6A706D5555293D51504F543A411D4F455C3532493551516080376F578162686D5466AC8C
2341556E7C6C47465E545E884C554B623842472B3B3349364049494C4B3F62313F4C3B63
335565583A38444765775262474C49616B47643E374459562B504A64599556BA3E638B50
9D62549553495A2A51406B3D764949498A47A069705F61553798A444535616A4B0295441
3848565C615E6C475B4E456A473D4A4440607F4B5A7392C571364035AD833B6A455EA84A
3C466A764F5A599B4C6F4966C06C3C4F44324B47345D423C3D66453E543C4A49528B3851
4A436F3A5A3639353B4E3642624A533D5349407738737F3C41741D42544E6C73787B7757
8E2C657852A86D5491425430365439463638464B6E4B4C5947637669
72C3555974779F5E3E396D5FB6632D295947696F1E33525A40846213236485588B29394D
827D5A6629466C7A525E6623305365303F472C466B7C34563830798216274833689F2B27
2F396B76741D2A337B6EAA5929355575778E3D384F7C7B7A873833748E63A05120439459
878A1F30606044774E3C596E913D6532234B675C3071383662643D4F904841599A933C6C
434092A4302F6A4C45996B2D39765F7E8B29547F8E61A38A2E5B5F9861CD444546709067
8D562D75923F8AAB30394F9B9B714F1E60727A4B8D4C34695E4F68863B3C61743D7F542D
4779374C5A4B475753416B45308A912A6465538F7C2745536A7C932F374A6057B83D3146
525864A01F4B6B9160AA6A2659817563943E3373A56B7986363363B6AB8AA2323253A351
687B1D48769138515C214F8F682B61432E4C6459353F513E566B7E3030625653597D5150
7D587D6E53825860458283648E819D6D4363473F414F395449643F514F4A55426351604A
7C545D3D4B523D4F4B444D36452D592C463C4F5A333C45505A204666575558515859655F
495B5E4E586D4945562A408B6F643B523E503F2F5437452D533D45546F355030565C3B43
3C59494A50465B4F98854B645663465F59477C4866503D622C565F67465C43C4225E5D29
694054AB513742356223462D494E5E488332A137483764563D484F534A5129C4C22A7E79
629868703F70603960424A77323B56404F4D5A5D7091737B5A47412F495E4B7B444E7136
4E3D3A414C824E4A56BF97549C5C274B343A54533A5A4C464270414354426A463F4E3B70
3D38633D60593F34365943425B254F3A7E582C2D1F4C4F336B8E4258515B6A4D50BB964A
782970678FC97870892D4E3B556B336A4A4F52415858535A5E525D68
58778B66734A538548652F294A6D334D4A2E4F6D433C4F324E688B3B294C515389601B45
473E68A436194367426B935D1A447562737E1A2A406760B2322A385C519450213D707565
923E185A94674466234E718B404348173A4A4C2E5A44214E6152357A2D3466411B39422D
549351263F414F60452D3F514F71B9631B334C3F4FBC5D1E455D435EB2603338687F64CB
4E434F8C7DA395375867B3647D653951625A4D8E2A335175507A8E1E47727E45795A3D5E
74783E728450679A6B337A743CA3BF453D726752A38F323D5A3C86CB54283E5E55C97D31
396C69A6D75B2C49546DC7793039665FB387266FBE8882723E75AE746C7528478B7F519D
53354C81555B7F2E5D908C393F6B3F6279583A57695B5A7D4D2E5C623E60BB5234416368
7D8D21314375767B8B23345A7D4586731D4B726A4C93A4322762947865B7333457806B62
79617E6E5D875B68547E867471546E65647348474E5145705D754C5F675F6E527C706C66
7F596A49555945594A475F37452E6140553F3C593342615C6F3E55626A58615051718A8D
41385A5B6A5A50675B333F653D674A6245503937652F482D48384352592A502035462C53
2848523F49334A3D5A5C3F5A4D5B44555D617F4A45524D773A5F425873964A9C24777F45
B3523A96515E4E314B30493E67313A40733EA7477558624C3B72744F62664D888A4F7148
474263611D53504A67473F553F79674B555C815E819389954B47573E6A605BA3646C8C4E
634959543B5F477A516366445250256F504E565F51693C48477141424F2B424645624380
433F4F4A633125322B412F33564166335F4E424E3B6D854B476121565E6B69596070826A
9239728D7082383F531D4638384A3B51343D4B607C5A495C4556665C
5A56738D843D3F726A974828404F3BA0971D3060507B941B47546A70754C263E66875E8B
453342799D5D76471E487070516A451D46533C33461D2175673457351D497E2A35472E47
94781B1B4D5E65A02626316054798015394B55338D6C1E3D495E4CC12C2E5060526F3F1E
315C8557771E2C4960477EBB262B4C834761831F2A5B76304A5722215E7343575631335D
693A5C46455BA4543B484D39716D2B495D4380AF40275F54579FB1264E6B6F52B6882B5A
6F6E56D4A92D49546E52B29D52458C64938B363B6A8B585F572B42A0885470242C8F9E52
67423649BAB8714F254177AE558B374076B84E613C497C692C54793C7EAD3D315654479B
412B3B6E667A93322F5F885B7A94393783626ECF99425B597167D68E4B4D6086809D4530
54666D578B3331425A45498535394B7548496134324E5E60324A4438457D4F2B54745250
6662775B536864463A646D55714E746745584338495B536B5168676A60764F3C4D535C47
5849543D5A494153536B514043265830522F444E3C4F5A6D7926456E6E5F5A635D77AB89
3444626B835348526B485A7C4F634C5935514F3A62474E39544B59547741563B4E554467
475B535F4D4A565699855164465B4063373E7F4E3E4C505D36575A694F6852C23461452F
784643975E4F5B344D326428534C4F2C7F46B3225E344D3A5EA19C5D847348CEB73EA345
484A6871508A653D42385E8B4C4B4D474C85A768839FAF935E61544B696952967EA7C344
45284A443F534872428B7B64CD753E433E414C4E3445303A305835394C344E4E59752F54
2F43652D682720283049404679464543917163632C635C2665AD29505A88785E52BF8973
8F3A695588A8345560344D28475A618A5F46444C5C3E4358476B7756
A29B5063B1645F40537FC15570582C729339484A1F3E82421D61413C89853323432C60B0
61292C4C705CB14E1F1B4042417261181F493563871F182E504D874E2A375C4379AA1C3F
4F714D5C681A39406846784338475D4A47974F4C70A1536589204A8092475A24374C7443
384F344F753D1B3E3D426798482151486D72C63C20587C68976F251C49604E759A1B404B
6258957B2B45656B64983544507D57567A1B2D748749AC5F1D5D9D4B498F3421689E5051
5F38395DB4564954292878AA554D393E63602E2F63415F874C202B5D57959120285A684D
984C1F326F8AC29D27364E866ED25A2C5A7A71976B1A56AA6E808930327E5F5A7D2A2D65
8F65754642666A5E809431304EAF735784393674A15A675B3129528D4E6433345380853A
5B4F3C8AD16032584A4379A7513148555480CC5F274249656F9276284570826B508A5D52
7C6A7E564E5553433577786E91739C724B543B4251413D5967513E473F4D6246775B6A5B
88596E4860563E564C373F353D2D582F512E444D2F3B4458602442486058484D746F7589
3C44655467685663582B40746A63495844553F47623C372A5A3A454A6636402052562F4B
3C5949375C3E634E9082515A485940493B4B7444564E437441745860728E52C345813C3E
8A4D63C05A6B55435E495446582D3A4D9745983964407A38465C5D7D815B37B8B5453F26
683C535C315A534152525A7F45515D555B4D48567D7987A43F444C2FA656448746505F43
745951525F7A3851237C7C3A3A3D27573E25385E274D274D38622B334F3C613E374C3563
242F472E962B2F43404D3A2C5E30504F7353393F416C603B4B634C876A69464C33B98165
733463606B7D436F75427761626142683A4137597F43506B4E547251
58BA705B5E5BA14C324A4F68C5642338554070662629406351B04E172484A363B833286F
B48F7A7B311E5095657D9B2A273763465C5225318B95447B35264A4D3647472A43594731
48273E538A5C2F5D365A818F2B3E394D6BBA681B3A35386D902330434CA5B43A25375A6F
84A31D2D527D527C41204E6B9459832E3574B29B4C5C294375AB4F465A29275160422D73
2939557C3A5B4D254B624723532B42567A313F67525199583843584C6BC06B1C506E4374
CE5B2D4F7197A6A938335DA27F9772224F626361B5411D45674A557534365B7440AD6429
3F713D5F7E4536866D458045303F5940664839978C40675C3578B4423B53445E9B352944
5D74896E2B57623D92C1472D48777184C13E3E4E7475979B264655624BC59B1A4A7E7F4C
7968434C9EA567AB3E40416F79547C59283F5D784759621F406865444D832A2A4E667E65
5C4963716C67565C766381807E99715A495B593B3F4F515D5A5F566B4E51606461575665
6F555D5A5B6068745049575342335750632A3A5039454A647030463A6E5358575C58AE81
445266535C58414C5B4B52755067504E2A4D42364D30421F4D3B4A516B2D431E42462B55
38544840543C51498262455A4857455745506B403D47426E4C655B7787AC77CB58A47B57
94384BA13C755F423B297334594A6D4D786AB2546C807255506A6D5A576B3BC994377E36
533F4C68415A4F49553267B03D505A556657728CB8766D6441464333575369AA427E723E
432A4F2E445F5268196D74406C320F3D2C2C4F554050354B405E363B4D3E52474B5D4084
2B36453454624B3A4A5347506A475451996F4A47545E5E41548524522870466B525D5E6D
74275665848E1E4448274A1C39503E70314B5273964449745A477F5B
59697DAE8949566A659236343D614370392E394B4A525A2626346344574F2E40683E3154
2E287279423B5C321B4C854B214740596A721735457587C041204A41599B8E122D5E4179
C43B14396E7691D0332D538463B98F2F366486538D362F4C5E4F5A81233E765F35513D19
59A1772C5323456A742E2D52395A734419314772767C272A3B556774AE31213B5D4F7886
241B3E7C54A980282060825EA6321C51675376914133689253A77B2F4763A75B796B3B42
5A783F82552F6C756259774C475F9555696A3D60829D39526534619A393B58393AB8732F
574B3A8AA55232474777B17639544A7B8F66164D764EBF66313BAD90958325437D64505D
3B3B689D5C9987433B8A8257657E3F48A8523F823D529FA23D4B9B4250A1A33233514E5F
7C61233744686687691E3F616164A0762A486B5B497A702A1F49866763B8313D565A373D
61735E45495E72393D6A57486B7E6E686349334F4C42424D504A51525063443C5B635C52
60605E4A53503653484D4832323D573A463B3D41394B4468573D3943724B4B4D5D5E9570
323D588A8450484B4C424F584A6169634152523858494E1C5242644C7545601D53563C71
38545C3D5B497955AB6D5F6640565978384B6C3344484F51324D64624D6A59CE645F3A56
B07D70997B6B794F5043564D602F3E4BA463B93D80317C4C74A0C0558F5C31BAAD3A8239
4F3E655B33545552653F80B45672635B553756438C80887E6B866132884A4A884865894B
4F40723F5766415C3582804D644738494A363E5A2F6928504A643D4563405B3B3D65387A
3E3D4D498F53473C48463A395F4957387A4C3D492163663F4C833F5F296B4B55536E635A
7134656F6E7D204E471F542B414B23551D443F5F7555475A5051695E
9090546996425A44477F7232443856897C234042496FAE3E2D564C4480702535655F539C
871346695D579B4E1F3E395C40781A2A464F4B537015438C6F3E66362C419F5C4C5E2232
545D22384624497D433A4B383A4B7D383D79505C7E4729583C3885B02C20465E4B897D1D
285C865E841E19306960819B1B344B7E609BBB274F6A64488E672D476D5A39753A2349A9
75324A393C639054404A25438E8F2B354E303E7A4D2C4B4943758B2A3747526B8072233F
5B615F9EA71D3A58626AD04F4A5B7D7E9F81434382AB5F844E204C956A90A0442B70824F
9C43262C8CAA6B772E2A66BD6CAE3F2EA2B74A733F285A752D6248364D783F537542859A
503952585298942B4662575CAA883848626C89B0473150935E91D8823F569B6175B03A32
70955D8E7A31465C94485495362D74924039804C246778584868331F5E836E3E4D84474D
66435F504F514B43418A77636D719269414F493E4D514B70754B3C4C496B48505854605A
6547604A493D46543E3B454C3031433150423F462F415D7166354738605A6264796BA594
5F79714D6164495C443B4D6E5D723D574B4E434F6A41382B6258556683453E3B54543E54
46514746514B514DAF6648603C624D56484C5D4B6F5A53543E4274695D822BB744604141
933774B56F634E6468325A3953364737515F923A963E78358CC68063B15E2FB17A48A438
7C3A7065476C455262406D8B4E4E52595156674B8A458896514B3F21643D54AB4F647746
601D432A696269742A826C52762B244F39304D52494641534952373D4E4F6C4C4E5D4286
305A694D95293E1F505B47416647554C844869554B5A651F41972C4A345035542C7F5E4C
4B296F696B7B34533C306E1C494531633C585A6C743F4064594C8083
9EAD50578E68964D406D9F6F83472982C2687A442D458D794F5F322158946D4B7A24335A
7D525D572E4158752B384A36568E611F4A464466AD451D4C526E952E31317146748E153F
59673B6B551B314E4D69AD451D435E5983C25B1556843B91652345696C49641B28597256
59461F40666C30672B17315B57285B252230823C2B4736454A66223F84474AA86E252961
7068792C2445838181A033276691496E88303B6C8C78BE373B5D78667CB33F2C588D4A58
A441314E704A694E25506A783B6F2D315F8158397C3B46738B3E4E472A5D7F473D574357
726F1F375D585B9130273F7362C56125458D6EA04D2D5267449F8B194F9E4D5E951E244F
80619859285992506893382D4D7D5C98A1214A8563405F4536486F8D4B705E303F5B5641
4B402E718B432E5D514362A27A2A4E6E615D904829384F7B77BC55182E695D6C50884C4C
6E51776E6B64524347877163797AA8734C58374A4E534853574B3E5A495E4A587C68644E
5D52604B4F5C46644353684A574A623E66363E48303F41534B1C3F255F554F5D5B61C270
333D5A5C5B5F5E7B5348515A475D5578464E484254404629463A4B43543243356263375F
4147584065416061845E536E5165555C70808351354246595A665968769245B4609E4555
A33A4F7944704747403166425840543C5A579223472A683869675A4A655642BC77466739
493081763E4D42494D2C74804E703B4D4C3C5B486A5B848E474F5741723A5486557F8248
5446722D6A70455641897A3A3E221E4E424541582A6E20473C6431375B3D542D416C3F8C
394A502F5B323720473945375144684B844445492D4C5526396430392664457E3DA56857
58347E5D56673B614328512A5A5A3F50193C3687813A4D7F4F4F6F4F
52B27B6E524975863E733E4D7357294F75566D5A1F223A454C733013205F5B6C901B193D
6A51B19729293677439979192C3D714FAD541E2D69834896342977933F5E422A3E765939
5F1B21496B473E4D1F43756926412F2660AD7E20502E436C802C2F4F4055622319433740
738414254655489A5E1C35477D5587292250566C8E892D334E7043587C463D56A95D757B
28608D88465D3542556B67426E1F233678594A782D3980813764533850A66335503F4D5B
6B7E2B4C4245AFA929357A8C56B7771A3573865BC14B1F3A82559E6C1F2A486C8ABA3B2C
4C9A57737D3047718662952B4A4C604B86563E84914E6B3A3788A2424A5D4559A1563258
354979873A50564BA1A43D2F53653C8BAE41327177569D69203C55646295911F42636063
85551E4D97675D794922515577599E8720446368388A682B4E5F763D6982383E627B4C47
5655674D4D625A46465B655F6E857A685D4B3D4C4E433C56625B5C3B616C4A3B5161637A
604D4D445C514D5E4C58594E3D3F47395C323A392E413C60532849375E5F537452738A68
3D477B5E6F7E4C63453A4F62595C435D49544D46614B472F4D444C4974464E3E57703B5F
434A5C4D6D4A6C6DA671626945665F586F4C5A3441505C4E36417464556A8DD74B624355
914679A6595452573924453552634D61796894446B3E6E2B5D576A4F865441C87B3A7A3F
5F3253523C844A4853338B812F554049463F69316249937D5E655348935A4E774E847242
492E4732554A6E6548926F454946355F4A3C4E4D3848314F40533433524E5B405C6E3762
2A505336681D452F403C42244D314C32522B5F5327635D213A952E4731462D4C3D4F5D65
533763416162244C45427926373D4371314640585948657F55506A60
557D7C9F653D57AA5FA32E306B93429D4C2E3C6D527686252958AE5B6B3532537268447E
32264A8863375D261C5167383A621B3A71772A364128629348293F3A5A624B233559665F
8B20134977587C881625748A50A261262D658949C74320335F557989123B535A36AC3D29
25595B55751A275C85454652204A6F783D6C4A1B54AC472057413B45803A2B3B38434D89
283151496E87561E3D63626CAF501C475D6E78C52F45566A607F7A24599480648781173B
49605E9A84204B77556069353D4A9D5C614C255179903F5C2E3A4F644666591F5D8B5137
502F3D5F8337636839639053365A5577A97C234D4A62CA5633458651909F3140706581B2
463C54686CC794204C836B67AC7F3C4467556E973C4C567F465A673E466DA64F524A3A48
977C263F423E4B7D722D26523F2D92B930296D543886A733295051589B9F4F2B6A6C4849
4B3A524539383E42446F635B7F9C9A583D58492E37414445404A455C3E61607C645C5751
5751484B45494D4C4137362F2750472A483649352A393B4C383D6D2F5F553F6265969577
4C56705762666B7739404B474E4B2D514E3B4847603F4727503E463B643A432C6C684451
4F5B573E674A68509F6B565A4D674B5F3F567649475F4F6D48725E4C6D9357B5456D4C43
81235C8B777A7E7769517A5940385E69737FA73F724C87376B80776092493FC069479C34
6A22634C3755456E701F4B503558455449404C3E57368B7D374A3E1C953F748B488F6464
75254F157F5D4B6C256A635068293E47394A54673661345E404E3230576D913951614070
3749584193384A2149304936452F4A4286344230194B462B5A8E385B3257585F446C645F
674860527E8C434B5F3E4E2E49533D5B415E5B7984634B6B4B457164
76734F6772465E41466671424235306F9336563527376C471C47265671652D3A433561A2
2929315D6D69B1201243796F778129185A84538D7E28296366638C212E446132526B1B4E
667C4776473838785A54843B454878354D782A2D76772D522E355375432749284CA4A02B
2E483176B53C1B335A36816925424B5748B368232657775F9D42255E6E5762A35C15429A
6C50883130578B5F5D6E165895A34E5E4F395C8062457D36298783453C6B313988A04934
6A3148848F333D5B396D9B6B2D614B627A7D1F5998786C894D2171646499A01C1D7A6461
934125558C659A922B5B8680505B1E2A84B14D863A277DAB415A3634498F5353662E4683
764A92413468BE7740593839759653575B5C659A482E4F5C5F747B3B37426B607C652B2C
6A9256726E1B2E7A83637584312B5197785786502C317F5C5F70381E405F63605C617C75
624C69655F5A4E70727D6B6799A287604D51414047535B636184856D554E395277727D62
7551674E4A5A4F533F515D4337394E334E2E314151614A564B2F5033545645625575975C
283753536A55314D384350533849365837394233434039182B27411F362E4121302F3A40
31414D3D4D37594C784C555D4D4F53704D616D40534C52614E4562729FBDA8D755876B56
935B80943F5946726F4D54527E454D81807D9B6E75566E46819A9668846360B46C3C603B
5A3470563C5E55504A3A8174495C4E464C445A5F805F766642564F43804F739C55C08442
46397718533A51563F985C3942383369453B425C395B294643492A28523E4D304E6654A7
414C49324A234422542E3F314D435943513F3D444B8A7E3452614C4C4457295E5A827D53
6C526A2C578B47584B3D51374D545D663B484474554541664550865B
7A98575A6B5FB361406C5880BE603040747B9B961F456E80417729255DB048766C234E49
53355E4A275D796D375F51265E9D59305A3C2C7AB63624511A35936D2760483E7BA53140
3E3149B97D254D806D6FB14E1F575052A6E1491A6B6C45BE7C1A3A8B65708139225BB98E
8A882F346E805D8B3D2D3968425581244052853443582B3E6B881D35563C2C81A52C315A
4841775C1847553679B5511D3B5743A37D1D53615469D1611A5687448DB8472A508C5E7C
BB4623528869A5BB373B5C9463B85C4165635353AF303C7E7A21572F1C56AA6A555D2E5F
7E812B4358509E933741535264944E25566367A554344C64518B711E4E66567CA53B3669
7A72AC3D30398E96878B27465B7D647B7129546F6F588F4D34577B6F556D5A2567855943
6B51417AA0543B73693A5B83855A3D4343487152283E50515379521E465046796D6B474B
5A4B644444613C40416A87796D889A7A686035494F513C665C44454D6F6F4955677A7164
806A6F63595C4C695954534E394C594C63333D3C2B4554695E38572E545B675F5190957F
434A7951775347655C67714A414D48634653624D554F592B493C59365C3E5F2F51534B53
375262425945865D92676F6C4B5374964241432F443F4E363F3F80586877A5EB656A4D40
663482C249573C3E2D18476473888186779BA268755A77376F87A394A240728E524B6939
631B5A36336E6366525E5D6552522E4F494F5A468E53A6676487684A7E5F7B864E848251
553F4E215E33625835623643591B28402F464353274C1B5237382E1F53435C3066773259
245B6046721B372051444B697759525D7C505E503D4B493E4B57334432644F5C2470374B
445F864E5B763366462D492044343F64284C3B9661486C79555B8166
5F71729F624665A26FA02E4054713D6D2F486092623542334866381C3C32406D7D2F2D50
6E5BB09D1B26566D54716F1A2356695B83501B3187937C7F2544516F5B9D442E5B704AB8
9A1D21447C487EB43431477F39863921477E7B374E2128496433433B2927583C243E2C37
526E2B202F37307F6A193035495E95372441577084832431538F5C6591322D418F71807B
2654568B46836F304E638F658B3E2D38694C6F7E3C44629E48817C28368670385854403E
7B8933603B1D4595593A5444355F7A2E3F604A5F967D293E75419E601929605677A72A3A
6A6769799A29367D5C878F323F6E875AA5314D886C57714352558F3C71583A3794905564
334E55532E5259336E6A42385B4F4CA48D3044866C59AC7F3150574F5E715D2934626666
9B701F3879714B887B333C58795A94582438556E53796D1E454F68406C6F1C526A7B4F4E
6A5D78494462463A407E7D797B8EA27258512E2F4147424E524E41444452425C69756459
60344F444D514A5C4B483D3D33513D2C564D5140304465A67D434B5D766543584A7DDF9B
4B4261888D5B64714634515853463B515550474A643A39255B324530662E3A2A58534F42
4A58594C584C5555A665605D51684E55425953596D534D3D4B41522F6E7F4C8B40687849
72195497335C3B5B47314D32323F3875757861588D426C28BFA97A5B724C7893694C6934
572F775A475F34534C16595846584E5C674C67447C3B63613B45474B695C578873A06654
5A49594F674A59493E732C44531C2D4C3040475E33553A4B4D523E38525F73395C5A3572
25455242742E4243644646375E445B555C4B413E294C4D1A55603B4D35513B4F42794862
5238505171804254352C4D2A474168864F4C5170604F5568634F6865
676967978E3C476C67A93C2E4A64578E49212E666F9D8923264E6651C3491B4A713D617D
21296289416478112751545E758714344358355D6716607C3B495D1F2E75B1402F3B2F52
8E573149301B579E3C27464A699F6B182D435C77AC5A244E4139839D161B425E56B73E10
2455455E8917223E774A7568182E5E8437723625546166426D21394A5F6935592E303383
4C2F57382F5A9B514F5C3C3F87753548433162892C314C4B5D959D3C3852656E98772942
43765EC2A32F43546C80A641346480616D5B2853687C61898B323A82676A72293A514D3E
7B2A2D587D5550511F4C8F6C5570323293915B613B6DC8572F59614088A1212A4F4F5EA4
2E436E6B4F968B2E4173536687602E59924E7C7C3E5F62A14C77803B49618552746C312D
7E9A546471373F597930417442236FA133394E3B224D993330733C305FA23C336C7C5961
6947657159703163728C7C75AAD39F635875564C505B4E525A7B5C5953636284707E8483
895E7153535F5C7B4A536C554A4A523E5F37443039424B574C26504350553A68676B6660
5A5B57435F56446B2B3E665A3B3E335448383F475141533D4353483E6047513C494C4A4B
52565E52716262648A756768675F5C7E3F73743C304051624243573A8E8D73C749825F54
921380A4278C345333255B3C414B4C7E709D7E39513C67285F8F8653554682B05C405C46
543548473E81405D512E645F5D714C50415E8E75896790764E543736815C578057B3706A
633F4E1874485B5350794A524C483653494E584F3E5D39504B52403D554E5C2F5E6C4A80
4650535B6F3E471C5840524B444751315A2F415242566840373C427A4752415145A14171
60476E1F517335545B444B434C57645D2B655A994F3C4D6F47528453
8099506B8C56A04647605A5F6E3A3E4E5A4151511E3A837146531C1C4F8B442C432D429A
3B14364E3159B94F1B3938487EB52629523F3885B01D206D46656F203D5A88735537252C
496573A42D27294F5D4683202B788433607629546662557A422D438A73435B32345A8F41
4259183A844C2B4C383463A536304347597F7E192E52347EC06D1A43414A61BA75214152
6381AC3432486A6D87A019296074678E492C4487866B871F3660904F6E8529367879314C
8925284B784D656F1B4A5967365E53395B972E3A73384A6392434331346D79382F5D4479
AD5B194D5F4C9388222E48566DB037374E66819C212E778B596F37255A9C7F4A793D6280
6D5785383F486C486A641B5184743A5F662D5190573F794D3361B66A3F6A56345CA44D30
5261425B96471F395F50609A4424376B59689C3F2B38695D63A833384D4B5564826E5756
545852474C6A37483F6291795149545D574C3B4D3B2A304E462833435E503C4D525F506D
63684F444245445D434C5466435055596338494C92B64B7C6E3D5929566646656C8A8EA5
48497F8D9247496758728F66455B5C614B534E546749553B53405A456C346940564F465C
52575D545D507573924C5F8F5E665967767364384153785C434C75534B4BB1E13945435B
AC2C859F2C662D4826173931317B4C57539B80486F497534564C4B5E644A78A261515A45
783968465A6C43584C407142364F1F525455655F90439569454E3D3F7E618C8A4065654E
4B51542757336058567F435B5F29444D30484A543F3F3D483F41443650535C395C663B62
21524A42672C4236493A3336483C323D5B4A5E48204C4A27565F51674E7543472B554C6D
4B55743F50674676473B3D2D3549675D30403B99423D605E4F5C7359
59785257514A7B6542544C8196432C514563A39D2B12395267AD352735506590881E2E53
7D4EAF693A2C5A7468703224605A6D4DC3361E369476574F2432451B38692D3B96892948
361E499F561A4B33556EB8531B33585675A9253051425BAD4D1B48484F61802B24454341
6FA7262F585B5C9A51283F615F787619304E5846557F2B2B7D893552362C2963963F5558
2553858735803F3073C47E4D85342D77872C43543685D25B28445B677FB44035505F5D89
9944314C525C89B32339597848AA3C3070AB62698E361D4FA47174411E537E785A9C362B
94AA2D695F455EAE434160323A997F5058354B9A7235554A4C8B64214D41476E82384955
4D7DAA4536566D5590A9302B58675EAE963340516072C7683538597164A864456169716E
9A6736648D97519C6D2B4B7A7032634E1E3770723E797438336493326D3C245181664A52
758A734E5D964B554E656D67768171646D5943535B46406E5669334FA386475178855D64
70796F4D524D486F7875575D3D924E34533D4A232F4553A55C415733574D4C577D749D75
4B4D6C4F704B496C30306060623B354A3D3B4A4C5C3B4334434D50425E4E513E4C4C5140
4C5859515554715B996874625E647EA33C7C8D4B45556A31423D604276A88AA15149796E
9C798DC9567C3F4629193634303B307044B46841683C6D155631215DA8355F913D5D6A39
4F2C7438336E336649124B313E5632664E4F6051953B755D5B825F4467334B4F4A996354
564F453A5F24424B4D4E17313115354E203E4D4A464E3958514552365081824C5E4D4165
1C36303B6E4D424E443B465F5C414B6D9D3F201D2B4D3C2B7271464B3947415C335746B6
653D6A477F7B3640353B4B3340436561364A5AD05E53857853497960
588482B850434E8997982142645E6898433053936E616329374B824B703B345D67392B5D
2E3A4F4F23335E2F5A7F3A20394F376E8B46152A28488C962C425F3A68BC3C303A5D3683
781A2C5F714FD58B234F7798618C1E38576F69325324356B90376237143C826D41753316
50A5873141282F767B343C2C2554A2471D45594F6D791E1B41733B7A601C274184525F7D
1D21597F4FAD6319427A9063D13A3F5061497382152E64584F653321517F6D65AE4E2353
77693B813A2F67946F5270274864633D567B1F56A6662F51522B8587233C4244439C671E
41523D7E5A243966446A8C26325A5C88B62F455D788390364E738251A9711F58A7688E8A
2E4376986873512E58A28A577F36386BA04A51532F4866954A50613434A2B53A3B593E3B
91AD34315E71438C9A3029515E4C92861B3542563D98A8263F52755CB3841A3771945A61
5A4C7779636C3B626A75777CA3B9996D5469453D395345565F754C5A4C5157624F57616D
533E5046374B53683B344C4940473E444E38472D46403E4331293A34393837547A658B8C
909F665F6F75726D293553483F4038475137435F643C3930572A501B5A3751385B393C3D
564F4C5B4D466465AA475B79745250654480845D685970595F3B6B54948098BC545E7357
A13DA5D65F646C674128364546544C784C815D44624F681D6F543C3D753367A440494930
58235332366A445A463285556F774A4449545D74B3418659394631407736648F72AA608F
555859346A545C66665C124D501D45525C5C706947503F3B5137362D4E4D453764644D6E
4A555861804840546B534940383E47324B394940234E43384254435639576D7B4B533C52
5B5A7340B5723E5D5A394138485493905554597564595561767B9195
667745968543613B52913A2F48443BA36423586A475F942C342A374CB76116274D4A74C0
2A21487C4A77A91D2A627C5E9A752C2C66583B8B58133C81466F41254C8D5D486C6F2252
853B3C612D2B558325294C346B81492332394966902A1B364956837221203F5E43A3361C
2D7185477813294674589B5A1A4073604585392253A0774A63213A4AAD56407A44254273
515772303D5F6E3F6C46234DAB5F2B4C5130A5CA4C3F5F405EBD6B233B5E4863BF702D3D
725459B477333E7869618E392A88897A90BB322C727E5681531F3876477D771B2066924A
9A2B2F436A445D452A52764E45763D47747E65822551A776426C4C3C71A44861534A4D7E
4638522C65BD9A2B38545266B36E1F39756281A8312E446E6A949D31264587505A872A35
6E9F6E4F7D2F2E3B553D53A23A324D6C3C4F6023203D714A2B531D2B8476354A6D615251
52585C435D833457517497745A56567A75453B5C5C464C7D73533F53A4793E577090765C
765C60443D4749554E55666641554B58693650276959385A343E652246503B5A40609670
2C2F485D5E30286B383F6C544B4F3E4C3140473443483927313C4226413D4420292E4B33
36535735324E5638394C6F584A556070426B62484F6B84464A478F536062ADB96B854B8B
CD596E9E558F596B5461726F47517B7F6BB2774F67527C3884736F595F5773935A5E603E
56305D434063405B5220912E383C25484B6B623C676491633C4C3F5D7B398CAB9996645D
635540419D4A59569896484F56537191585F424E4C584547624D45465A525A416A645C90
3E52493A584646334C2C42354657564554474B555D94540D3A7F43714C47325770855974
866480576F864E62466F85454C2D47573F734FB35D56687157556E5D
7DAE4C4B8260A34E3E4B617B862A3044814FB259322E6987485E1B314085525551292F58
672D523B212D4A382C6E291F45672131572D5BBB6A2334463E95691526535458B563152F
644A72B334223F798F70A62834444F498883123662464F7226204C8188779B3927457437
625B31537339236A383A6FA63A3450364C885B19335A6253923A243E55635B985C2B375D
5C5B9C6325536749A293293079676A97693760C9647D8A2D3D689D3D5D58372E53BE5B52
893E2E5D8D3E594E273E5B6F556D282A4B755B515D272772864348452854B04027524250
996B316D495EB99C2B31724F75AC405A5A5586B1363A7780699E3B2148793392983A5B78
6884972F306BA95E6173305260A358645C3E5478744776393046775731513C48659E541B
3A46495C823A304D46566194443F49624E7A8C2B1951684F6C89281A5B87397172684E58
777B6A4D4B61544B4F6D69708CA996654F6535342D4F4D4C49653E4D3B594953526A5760
544A5E525B564A61706D4D4A579C473E4A3F4D1E3543427C2A38502A4D474851566BA26E
4B525F847F416C7649454F69743E383E512D3C4A4D352B314940392E4F353A406C3E4023
4B3F3B3B44415254825D5758514868753A5264686B56463F482B43317E72A1854955312F
69356AAA514835773A3C42578094709FACB6BD867F797F5485797F5348688AB665636C52
65516E684B5F555E585AA355536F574F6A4D636F965A8E774B4C314B4B3C98B09D69526A
4C70562A4E3F5A4F5F644350583845542C5B44523E433D4A5A384B2F3E7266407771424E
4874514454243C1E4F314C515C47515D64564F424B46363A50985F9158705C6345733A63
5B628B447C5842634748554E763F616831545E8E545A6F5864546891
52A368734347718759672A49937933713A2F8C962B3A49425694411E444242757A214356
95619E7A1541695D4FA52A0D3F78506B8E291A509E479134383A5237564C132D5D784042
441E486F552D6132315C785831442A59749E372B423B5394471530323C4BA25F222B4441
8691183F7D5A48AB461B426F3974851138748144A18523437E7D4971632346738248724D
1D4656924B65441F427D41475F242F5A69274D4C52637C3C3784604E979D3C3647745570
AD3A2C42604982872A3D554A63BA581F316B65998B2D213A7F5E7E4E295B5E6B426C272E
83A345964E25336A3E436224385545524A1F495E615B70273DB8824063482653A3574A60
3B8DB5722C555C557CA94843537280818831414D7B63B64A303D536760846A214A837754
71601D46645F5486321F46837267742B34568188409B33203276702B622C1D346D704E42
5C547B4D668C5B5B51928683A6BBA57255613B4F474A46656071497F7878556D728C775E
77566044434B4B5B3B45534C474A4348483A4B2B403E45642C27573F865330596D596256
758E715B61493F4D322B513F3B4B2F373C2B3A3D46342827422F312741312D28322B441F
4F464754443B5658904A54526D3A5A5C2A795B405A4F5B3F5F385D366C636D5E5D645146
AA2693BC59603D451F344A6C5F66746C88D7AF847479776488A28069994865884079713D
6C36873E4E8542513D3D7C304B602A51555257568D457E69454C5E54544F7D8F94927446
634C414964475E6A779C4D404823556F34524B4F474C4A51664C4A3E4D58543B52595C90
3F513B3F6F2B3C48513847435943493D4735413A2C5559305D8F3D4B453A375853665386
6B8BBE758B4470A2674F54404B3C416247916EB7745E707462556152
4F8469A744385983727E37374D8C66B9302649776A77592B2E4B734683282C4F5C465173
1D3D5F85506566203B7B8631454A2A3777472C412F35778A2939424975A7382052736297
7B1E28575A58AD8B22316A8284AF1C3667816765550F498E864382422E3357805BA22129
485D494142192F7A662A4B332E3C79441C473D335B7B26254C37306D8D2F2E4C56387793
283155785D9A751F384C5373AA2438696C53A7662D4880736A84582162B1637490513A65
746B6593394A679B54508A1F3D65B477816B234FB8AE386660205E782344553C6B9E4829
484440949A2A454F5D6DA23D39544899A53138585A7C9C30217A7A72A45F1A407050797A
3032669E657E5A3D589259737D44516686476447315074894A7C852A394C664363642632
6E5B2246423360B75B1F2F543F5AAD6D223D47352AAF77173A463C49A3671F44706F7059
6166716669974F4F4E658D686D6E78625850434B3D494E76685E4C648C58334954734E51
5965533C4C47474E4556524F50584D5253355346494C476944516C434C524D5D5967B573
323A616C80483F6D424A6C4863583B4A4C46464F493746414F3448274E30383349314919
52484C3640385A528E4F545D4A50737D5383614B55596F304B3B872F6F5EAEA047542E41
913274A3548E4D683C40594E558152945D8D54816250643C6F6F664A5F6A4F4945464247
57406840435860845E507A5249674C656153686D93528858415F464E5993C3B376785947
496349387B2C4D48739646554E32455B33633A4C5E4E3D3C7B454B474B57613C785F4160
3C6E3A4E5C41573C56465A403D5D52455A493F5241824F175D89596F4C56474C669E6A56
4257755C8F70446B3E606B618B425F56325A71BB655C7D5E4F3F4F5B
6E715578735E5F445A8245404F3A46AB5A27473532897D3B2941315C856B203B54686CAB
411245733C8F9F151644754576802A576F5043743921425B3F552F1E4A6D644385542E46
8A40446323304874395B562C4A5842185038349AA73F23411F2B735516312F514F8E5F1D
43564D968D152142465BA454252F40725E9A1F243984726A8632443C5D6A777E1F45514D
5940742F365B864D5548183B4F6E3281462E6D7127543C3B46875731433C42407C6A1C4A
524154A76C234B7D6A61B4441B4A6F56A97C26204B7C6E926E154364539EA3392F93864B
89332A3D825F87771F557E5575593133865D6D431D456B50658341377CA5425D563B5790
4C565D4856969741495D5C78A2682B6155557E9E3B3069575077B7322F446B517688292A
44652F6248193A5E592945533F275B9236526225204A6D315D521B3876A2496560774344
4E527A4F6A9A67484898958F8C9F87926E5D3D4F5243455B605D496F656D416371886058
6D5550394B493A53484D4846555A42334F405328203E4E69312A4532694B334F545E6259
464A6650603C48552223413D6D3F34414B323F5F4133324A504142434D3E3B505B3A4132
6154574F5951647697645C6B5D6672654773785A4F62614552354B2D85677D8449553024
711572BD435B3F834E495F60566553765A9155554F5E672E82925C5576659EC372678057
5F517B5854744F473B5C693C6D6D534C6B73596E995C906E5C6E5B4D5778536A3E7D5349
355E5C3D542D784B5396495D4A234B56264D44453F353D3544313C383D515A4766665C69
3B564D44622A3D2D5E324E555646325A6A5E5D3C4350583A4569406B746F494F5B8C4C5C
4B81B95C733073A95E533A2F4131625C31534885465A544E7A515383
787E514F576C854138625C6571302A657F75A5A421457E646A9730345D914D8762213978
9A53945E2E36763C2B5F2415295F252A460F273D642A343855974F1722413160B6382934
453A6CAE213244604D97B41B304757509B7F23328A685875244B547E4A6A7F1B38616037
685019418350556A253D4A7538475C1242B1833152482347A16B213F492653A66C1B4D47
5253BB751B384C71885A1F3043464B9E413475643D84951F4D687AAAAB5C1C4D656E4B9F
76254C517D5B79492E4D88935C5A26325B9971405E1D2C5F8C40422D274A6534305B2D52
A4602C4D38384C702F2B4345918B343C534DB5A82A2C443669CA6329599C529F9B323474
6D9EB133384797789E9737446BAD6AC0792D58765B528B42354D5E545D8A483F57844D30
88453D667D473A7D674D607337243E4B4068832720384B3A9177211E456F4D6564745747
484F854F688D66494B7A9679C0E198654C655A3F3651586D7471558176656D8A83757C83
6C5F554B4D59475E46595A504D4A4137472D522B284A496A4B2B5C28494F2D5D636A7F73
52527A527D5852613F3F523E614F2A454B2D494F3629342F432F4636504A45394444502B
5A474051403149589A4B454D6544464B44AD59435F566840554F5752847CB29C71815B47
7E4359876166315A2E347282664954755CC17F56352E4A1F534A46627E4A5E5C449E813D
6D527C414A553B5949719238424C3A49474852677C7695603A457B8164774F5C45514066
64494230641C4A333F713D503B264C5933513F515647433C5A3F494A4A71764B6856718A
4E5B45435D3A4B3A52353C323B4252484B3D33262F59503E76824B4C49373E4E79955592
505373576847456242675B3F4B19323A268C5594424782754E4F6E57
556A5F873F4E636C597E3240555D4D75323F737956536B2E38995B2D5C342F5B8B2B326C
40288454293A513B4F924A1C4353445F9D21364D4F49743A164247356C721B334F4B5085
761A3C6C64448259214C874954681E4257794245522D598E652F4E3B344E93421A2F2A24
887415344A4065A44A15415D43627A211F5475658E6B182866A24D6D591C42777E3E5B3D
2E3B7ECA5C8A33205B7237585E25395E74367535315978503D722946B3B5542A53522C73
B65C42683E58957F274A53646C8C38395151436C8B26275F684F9B49174468716AA83323
78A76CA03A29437F7E6B7017469D75655E3A3797785C62264E88A267813A4354A3725953
31397D73384F45396CB8483A464044B09C2744583B49BD9A2E42654855A961234D685558
C56023445A596ACB59343A58638C8A424758796E476C30264C79484B78302D596483693F
5556977B5E6947747171935D453E4F5B513B444A30545B69555B535E72563159726F4C46
5C5A472E464B575B4B4F6D7052594C3D593254243F58556E34305F3B5958385F667F9076
454E685676384A4D31474E3E5E605949482F424E392C33364D34523B5A4643424C455A41
5E4A4B473A3C514892495162685E666E437058494C6D7A344D3B6F38674CB89C46573833
7B34688C667F57664325554E59515C916BBA5F6E3E3D522B5F564B414D3F81AD374C4B3D
623E7A40385A488E43454D244A563A653B4F42706A40793F3A4032384B4C684B6F993E33
3949433D523D5643588A6A594C1D675C3E47435451494F495D3B4B52364342348E5F4855
3A82384661485A4E7D5B59605765464E5F4A4B26438645225C516B63616B4C42466A644D
46A0A563935847783964455471365A502C3F4DAF43496A5F5670745B
72656C9C624C5659829C2F2849487DAD2F213250409392281446745FB33D2931866988B6
2A3F39425B847919322751409156262A453F537B48366F6637513F225FA24D425E2B3277
71262A4A2C3BA07E1D334F5571922622385D4E81771E31567161983820476D5F658B1817
2F70495C65162B5C58324E2E214F6C464264253544894934593B384D6F2E2D514860575D
1F3255455AB4671E375149759C1A405E6F53A65F1B3F936362D24A225A8A6769944C444D
75755D9339395B8F565D8020366E8F4CA25E4142755B506E2A37555E335C3A3151826E3F
5435567C8A41575957727A313B364D606B2D354154618B2D2B635869C5703A4371658880
384A488C5FAF6B4147575D70AC3A464E8D4D6C6227394CA55E6170383D4E783B7B79302E
75963456322139798A3842572037984F213A4E2F50874820393841458042253C7B5F6A48
5755482B518A4B3C3F7D8E8698808C6E515D354A2B433B706851547C976F4B5D6C696B61
574E4C3240463C454849332B495A444B4633452B353D4F58376262274A575557605D8265
443F5C626C4549511B264B315B3D2D333A4044443D4D2B3F4D3F3A354747293A4B32742B
595D4C4947695C5C93717C516057924F418A65826D68773A524257477A6AA17F4875532B
6C2284A84F6537903E5A88B88E725A8167A8754249615D333946354970334E8130664B37
4535772C4864263D26687D356A5E2C373D7A4C746F639943577459603A747A314A5E2452
46724C334E2B71475F5F5284564C51593B4B3B4E613E5357764E3F47514F504266625E64
474D4859743C34385E33303F313D2E565C454D212C412311444240464765696D5D895A85
7A69695F53526F934D5A58354529493A3A593E574C5B59505A537B61
927F4B616E7278345768555A5F2C3A6F7E3D813C283B856046342C395D802352362E3E93
523787292583B1282249303596A1252A473F54B54D2A39564B904F254F544F83BB2D2446
70567CA2252E47763A8A5F21485D605789422A3D7C363C4D192F557E2F566C18407F562D
4B403663912F2C434D3D8948171E44376BA5361C22524C53AE3A2745626369A33B35497A
735A903333409057965A2E4176505D912E3067884951451F369AA747666035496D5D2A43
3D466D834D37453D3D53B74E2A374978A4661E3F5D634C9330194954348C621D2C5F635E
A034356C896D8B851D56834565652656795064672D607153527D3E3683B4415B463B509B
62595C2544597E475C6A407598733E765260657647336258506B8F36378060357B97372E
554E4E9D5A223B455979818E382373914A65AD2528585342876B1C49556B3C848C654F4D
606671485C75683E446D8E7B9296857A65644951454944576052585B6757656B7B534E65
55535141445445613D4E4E434F403D39452D4127484654661E21422F59402548506C5F5B
403E43446048574A37655D3A62403A454D2739482A1D2F3A4F37333B4C392D4C623F3E2C
56372F4B33222E608E343C505A483B5348793C335052664F5828462D9D429E8B7A86503C
6E2D3458505A323C2E3A5858574C4C974FAE534C3037552D776B5458704072912F68463E
4F35802F2F4A32612C3D4C1D4B3D3B593B56479C6E628F445D714349274B682C66792A49
2F3A3C4957345D3A816C37493C2F8867314E454B573A5A3F5B303A44396F62386F515E66
325B33496E384C273D3F464639573E5E684D433C606D3B116B45493F534D4637497D6988
575D6A8B9351536B5772574E5F364C473347427A3649484D5C7D7E57
6D954D5648507756384F4C55663229545950A24F23304C5864622330468D539E4629467E
4F47CE30292F674F5676253C3E744E5A4C1F3A4C7E4B66112D4552314C65374C91621E44
3B3D326B4D21564A5482A33F3F4A3760C96B22276546849C1F144E6334979A2E254F5846
863B1D3A6B64798826315AA1497747233D69855580531D36546A315358264850582E4934
37786D4626402A387C88334748394E98672E453F4AAF9F252F597961B1BF2F24738D5597
811C3188A16CB040252F919F45551F2262A774575A1A3D7A79416B371F437C434F5B3229
6C85374F3326457F3D40583E55873E415041839C4736593F6BA73825446552935728445A
72939A1B41666D5C85A42538636675CA7B2A545D5E70B35C4957677F5AB44F372C715243
933C2A4B5F354A68283656835A486830384E6C5C38563039508A432A54374D6691897C44
50568D6D6F77544C4979726CBEC28E554A4D3E4E49756A6474606E69695945737D6F606C
6951461F31383B52354E5A514E52474A432C301D1F3F435423395D2D41473E525665856C
51545E6C6340505D3125492E543C3C3B3E47433D362E342143314A313A4831323F265A37
4C514C4737334C475F4250505050724B326C3445525A7D233947512F4240A28F3B5A372A
7D23607C43653876374D836F4D4F4E5B39BD723D313D4B2CD3C4494F655C60946D6D5955
796075554255465968465D4D6B75533D6060737481697F6C324A56635A51533F65764D43
3D4839374E246B234D493768411E3B362D4829375E403B44633E3B573F4044338C4B4B56
335C39455C2B3A2B384A494A233F2C3C564754323043363751475C44585F494D437E5963
457461365054537731565D4B5747585B434F5E7E4A604D5C586F665D
566F678D46515A7564892355895E47A3554274AB46796D2047604B335A1D3A4A652D715C
334885732F414F29649C3B1D52336253731E2A56565DB956205056516E7623275C6D4F76
32274E464640A82A3E6065487D621B2167A1505D38273B8D9C4680202F5467473F652647
54491E35342D5D8D4B19453B5C85651C355C31368596272D656135819A25356351566A6D
1748785C6685232D5263487A65234E5E6F61B25A26409D7F43A8472152A36E3D9937475A
744554562C4C72923C415F3C869A512C5F42537686253F443E4B7F622C364C5675973A31
4B4B6FAE4D2B62613C98A02A4B794C728021397D507D8D2A2B7C7371754D4351965F7356
435F755761B2604F7E9B575B9A48308CC6485158273F7EB04D4770332F7F7B343C39366E
854F234B434273863E1E3F4355689F5127394B618EA2382C3255646A8333274688754543
4C5356384A7352868D9A90556757847D5857336348413F534A3D62608A6C4A4E6C765559
4E665F263C4146654C6159444C4F3B3B4F29592B304D545C394F65254F585A534C70B46A
40424F3E594640422331473D692D424742373F4B424E2D2F36333530433D3235412E4F2D
4D433C4449695256765869454D44555344603D5C554A6545583E4767AE486F7D667C3B26
89199AAD496B2F59182C4893613D527B9BA97C5A754E56333D463E4F645577CA3B61576C
75478E4D2B4F37674B545F2150523443416A4879526894393D47424B6B4257558B881E3F
27453C3A494855376B4F3E6D3D215A4E35584950664760476B422E57305B443D7152645C
3D5836667A3C5626423D39642C494F605656473F464C2D255F4F3A53563B5858427D4972
496C604E6357586C415B524D58296760364863954B6058605268625D
6560575F5A5B5A4055684E4E6D3D50826A2D3A4C345B8820283B445DA63A1E605E49A6B2
183E706F647D411C234A6C4C94342B3B827963813E2857B75B5F3A1B558834446921277C
81273E5530517A571B3742425D8D2C223C515482671632346B55AB2E1247504463971F25
6F723E6A5C1525587B3B692418475B3A486B2D17448F59435A332A31895D4F6E22335A73
4145563D41645A25494D346F832533593C468C841E35515C689771284F5B6953AA692650
4F3880AF2F2D519A5F78C7443B78A474AF8B21538B415A691B26606864856A314CBB8851
8E515974A0477A3B1F5A966353642F4E8C4A46503F69993E3F593B7DC45D3A51494BA391
4049724760BB953762905563A56E295D835985852B394B9D6C7E9A2B42577961A7802349
8F6D3C784C18388F81445B6629346084425D43194567623664312D41916F173695795665
908A734D4E5A3E39475F594F96AC584A44502A4636514F6F5F393E2B4953455F56684C59
694E4B34474D46504847454E6867404451505926313C5A652638504362483946504A6355
677155494C3139551F33582C30213A5051394D5C3527313E5441423E4B4B455563386345
5A4E4B47463F45617643553C48445D494453524A634D67635D3F393A5D409570527E6040
823E5F6F4C66425910493D574453528973A061634E4E5A31757848596847445942644C3A
4C558345484D4259508D8051595A3D48394A4173606084204E4E3456499FA8828E873F73
36492F5A52315E2B99575B62314564604343454360316D45633E345633805E3E7546706B
425725405A2E523C494B4A6252493D61623648393C504E346B284147513E613E48757EB1
708150464C315D754969654C5727615A3F4879A3493F48454E616B78
96894F90728DB6364D846A84813F395D9B5F90402C3270764A49182E4784347B2D21506E
3C35642A425F774440413241786A1F395C2F43923627304C48845117504B52668E262E4F
6C4C7E7A1A42576E668A2C304E5B665D91193862753347630E255F7A2D5D51273D443B33
532C34506C303A3A2341575E0D273933616C52232C474D427C2B1F484D4B7F94341E3C56
74AA93274D808658954329528D416BAE2F2D6EA1687580314B6EA662B286374393B45093
512B4DA7AA607E602C508473495024386874455F452161A156334A3B3B7D781B32575056
94553358785AA46C1940564A8C8E25357367887D334A6A3E53631F3A816756873E2A5795
59726C363A6DAD80A4793758507771B26332598C475F68293B5384574B703328579C482E
564A3E7080272C5258447988293B3F3D72A87B232B483F51AC701B36616655948D785B47
465C7D546069314D535768575853677D62522F623B5F50554B4D604B5C505D68675B5A72
635748213C4657563F4E61542A353A46402A4C32354F526A172F57262E353C3D38576D6D
374242497444445D334F592B55363F37463B393229342E2C433131333744312E3B1F5837
3B50445B3141475860464F48434353423E492D415A5B813D5F3F4C407B45B3963E607847
7A518B914F8F4D59414F344B3431538B47C44437373B3F39C296293A413C64A34969535B
625C823F373C2B6C2F4D48265B515F6E374356B55F6F88355474505D4035644E7D713C3C
45523F3D403E553A8359606F533D884C31303A3D63425A4F554443544E5E473E6D645453
3F58395F7A4B425557534578234C46595641443D6B832E2553254D555844563F576C4A57
48745D9C91845854428F5F51613D8D71466A92BE4D5A7A6E608A6660
769B6B693F67878A594D2E575D502D56343D556D3B43483B377A362E524A416C3D214055
4673A43F1E50504C82A727355C77609C76323D5C7D718F26334E6F57A2672D4C837C3C94
552F3C6956346B3A30766E30496F335271391F4E5C3B5D992F203C4046967B1E3C57454E
7A3315346B2F5B7917304B8B3355301026508A3E6446223A6DA8469941273B8973325A3E
2F6CA37D2F5929355479473F5C1B5B915729552E2E5F752D1962313F5E7B2C3573413D69
7E24264B434BA97A2A2D6992739D272A3F875199861C416C614186312658843D3E3E1C36
80A557723A3A8E943F6F482542865F6D2E2E4E855149863D57914236634664924B243D39
467A6A2532435F6C8C8B2A4364495CB98228377B5664A83B354A936A6DCC43354876526C
6E25416A623F456A27235E80716488381F5FB4595F5123373860392F661E2D608D5F4E4E
69765A45639F5342445E8A5D72784E44484A225A3F3D436D4D2E4C4367524040685A4951
4D7C5E263A3E3E5064685B464043404944294F3B474D4E67363F6A3B4D55545E4E638271
4B51586C7D4244573830453757343B2C4B4B464A3D452F27433C3B363B4031373B224B33
435A383930533D536C616732493D53532E411B35503C503B4849515B80586D705566796B
B04583924D4D51623E765F585A4B66673D73334A5441494D4B512D485042447A46575165
574E543C4B633F4841AA9339664D23222A492846536989433149559E496586458B631648
324C4454634E504D873049662927574235444E546E4D5F5B7B5146654D6A6D4B6E647E7B
4E7726665D31423D5E4C52974849306967505E28473A334159488D527B4C643F414C72B1
54494C5756355F6A386035495A3244392F427CBE4B48625458576794
5565899743386C837D7628386B9A66A63335586E626D7D2949466459B51B274E3A356E66
16227B795069221229715750782E1934864C5F6429424F5B344F2D2790A92F313D2D2D80
8229404F3677DF6713456A58939833405F4F5C8F5F10506A6165A546126BAB686455284E
685F26504B37517D552D5F394855882A1F4C29253477282E4D444C76472024424556663A
1D2966965B932223316654646B233E5160418C3A22407E7046BA443F6A56544EC7393870
77463E6E273968A65758633747666E285E2F3B756D483C472F416C714A49443F8B963D2B
533968AA832B3B5C4495782E384A5DA3451B4E5A5775893554665A5F773423597A6CBD52
3E49744A7394503E78874D5E8E3B445F8F6A7F5A33445568396F373149525C396A5A2D4E
A86C3355682F5BA35715364C3777A54F20363F446D912535545B414FAB351E3F92894852
4D655F3D5B5741303B6258577571905C515D234736393841563B5F463C41335C726B4C55
604A5232465141543135463F555F383F524D4F212A4B66681F324D3365514C495D5A5C56
605D5D3C695F6F552E3A663B4923323C59554F5F423330415849364E52472C4A60385E43
5A4E4652483D4C7C8745534959534B4D3D48335B623C6C3D5437354C9F30AC773E71624C
6D2B8D9F3F5D325F333B5D7A674753915398515151635D507B6F785156527A6F3B755346
4A4E7139485C32612F605E3B49463B434F5A4F7233698735474C4B5541ABB0404E33417F
32655767725A7967885B5C744D3664735356594D59578A4F4E5E4D525AA168527E677468
37522B6B6A32433645423752254B3949433C3A3D6563414D693548324B4052415B5C5655
5A8B6F77864C3542479353474F3D50513F4A5B6B3E52654F4A514F7F
945C52785E675948578147455540508C792E6A4B4B5B6938214427347A4B174C41297185
1B213E3A4DA4411B253D4963B6362124465095AD1B27354A444B332E37664053871E3052
57697FA12A3D779A2E55152B446D373F6E29256E782E3A4A384B784C21354D38698C1730
49584282822947515242AA32323F5B5773822229366855798C1F385B844C868328435896
4B6C582B4E705449765030577E3C598D344D6364264F58313083A633576C29488B88394A
523D5B9B34213B575A62752C404D82628840183981405F592947546756785232567A6736
7D3E3F547E525C353141764B794F295F82466C6D2D45B24E52662F3E806541572E3D736B
324D4944478E57354E515962AA434557616B868F31454E5960A87935405D64519E523539
7160606F6F3C2B6C893C614234376592427A3E2B4B635E3A69402F40605530569B7E4950
5A7F744A7E744E2F4581726FB3A99062545E40503C3E465165658059625145758F806277
6D54572D325764603A4E55414B6C443E4B274B2B2C434E5D11284D3C513F3F454F556C5C
3F464E485B313E672640623262382F3F5547445139352E2B402E33353B383327331D554F
444C4C55454D447172485C4A5547524A547142434C4369395247444E7943AD6F32656A5A
7B2A5B752E712E4D186C4D603C304C9B4896595C41323339AB8841758B6293A14952474E
4F5D762F49535E924F6A8148586B5264504C508C436D89434C41336B3A4F7E3F60552241
43442D62704A6B75C05E6F8835567062434E5C4B81314C435D33275F2E5253417F50696C
4957344A59353937494641734945355156525E2C627733485C2D784A7D4A4C4560565393
567B5A9B94395E4E405945456E31463E595F7BA12E3576504C584EA6
768A4D6B508C923A4759417987334456674592362C4869585C6E2D3E66975AA346273F6F
49668B25347B8145605A1E415F5F38483E1936844D365C213C855D173D63354B83461B55
3A2D70C4362569765A8B271727634963731B1A4894577C871F2C77A067AA3D36415C624A
7B242B42703D475B1E283653325843152457681B474C1A35876A315A322F47885328684A
40618C32425B3445916E1B28473B909D4622545B37889F3744508E59A198373E4D6A66AC
6B3C54547046855C2759764E3F513550A17D306030315B78211C41353A8C6C2632553750
7F6B314A41638960314042557F5F2D3C465E6D7836395D52669D2925606655762D3C6D64
436957265453614D933D2A57726A6B914A44518F577B883325667D49567F3A27A39B3639
5E36355C783E506C3152695431363343498F642736523954655C2335624B60AA9C886251
6F646B4154844F4A57668A6F73627F5A4C572741415B4E4A41376864814D39548B534358
568A5047504739445A5450434E5745535A365E39364F4B5F2737613A595C4D5D606A6B64
46586247724A4F6D3C34503F512E4A485C3C4B62443C3338573B464959443E464E306755
5F494B5946495C6B4A3E6B4E5640547C495C3F4A624F5A38505C74749966D4B65363686A
8D5676774C6D55532543294E334C417033CD3B4F4343423039442B3B4347759D66716C57
4A525A40465F314A2D5F7F537C713D41394D63A23F7A914566675E7F3B6D86706554504F
4C694352513B423B5F4778725142814F4B393F414C425E495051374E4670664A86477569
51692C6366354D48414343A53F47265E4B2F3039535528415429404245436E535F3E7DBF
75A165634F348E6C466945384C485947463D5D814948625550545B76
68848E824B45715F878B304E4E50497920304A77386841383E5F425796361F504B234738
333860342252435991602E28484E5787671E1F4B528898201D40686C7A7520354D6C4FB0
391C3A78754DA23620495C3F572E3D5F625D327E27283D582F2A411E416D681D35343D53
913515383E3F99A02729435447818B211D405F46925020474860619A3729415A7155A333
346486627A772630518B475A5624388087517F49284680462A5F2C455497596675273792
AF413F653F3EA9C141417259646328315C5D56B04F18336C445C8F2E21519D4B69762330
7C7A65A440306B9C506A363A686C4E733D247FA8555F703F4FB77E4C5C405B88752F634B
44959F454A8E4959BE9D3D3F633861BB4F404B4F477CAD512948574A6483382054896B64
5E2E3E47714C4B7022376E623E5F5018315E9B3D3C442A494B613D4478262B7C966A4551
556D5B445C4F40585F5E7154BFB9806E57572566434D4C5C533E5049574A373A505C4F59
503A4B2D294144553E3A3F32505734364E4446283A4357571B50553553595E57505E926C
415662646B4348411E235A35622A4B39424143543E442D3E49403843423D3445482D5348
505E3D5158614671594D604C61505A404A6F4652593F612A5A463A5F8E62866926548567
836E8F8F5A655A684E664C532F3C44742C693752518462456B5B104B7F214166419B5C4A
47448327444E2C82386C6E20402E324D3D5B5174354A6F35465747495676936273473855
234530575A5C644B8A3B3F66305865463F524C3F624A7550535A485355926B3D704E8876
3952295C613B48474D45395D2D52275E4D3A4D2F817C50726A41502D5836434D55414858
525C5995905049354D7849454A153E503B476FA058628E6B5B604D74
7B575094604F5B3A7D963F556051799240364E4858BB901C3E342C5DB54236334667B997
1B2A516B79BC4F2B3D8A798E771F325F724751361624434E304C1C2D606427294A264EAF
70183D38255BD9641E3937459873203D4F4E3EB95A1D47674A5385233C4174476E692031
807B3A574C1D458F754763212C578D5A38622833549C475F502A285F722F4D5B33276E7A
253E493E97771D213A4456785F19334757649F6116496C3C52BF4D194A7D5A93BE442453
A370798C302B48747B929C24587C666DC2492370953D575B3637585839524A3741834B5C
713A416660313C3247636A234054498A672B487C62809A294C585E69AE393D876354B359
2663884C7E99502B76A26A79914D3F718943726B434051634D90402F3C53593C5C353D53
6249415E4A323B6D331949343B6A85331B385B535A7F1D2756703F5FA82D193A93944A51
576C74555B6632394E93B568694D6A615459253D2E48443B5243896D504F4E5B876F6D82
76555A333F5B53664754603C49573E3C452740252944635812295247754A2D454D4A3648
3D494D34614C665E252E40415D2F514F5A3E4F6C363B2255502F354B3F39324F5A20504B
4D363973383D3B8E5436544E593E3D4E526442585944533D5F4A4E7DA2549B9B3D558162
742D4D804C84454330A396786447628663C7615346444D4776542F344C2D61A74F613137
3D3B7F3741523D6D3E5B6A4F634A3E67404066B63957742E7663365841ACB86389484A7A
368C30636F516752953760653D3C83483F5D58515839444D583A205A2651483A7846524E
42641B4D51353A4D3D423D723157275A6466525F4B3F4050503F713C562E50427E575682
4D88694F542B4F3F3C5C4A445D19522F555474A230375A44465C6662
A360555E5D7980355C884F8F913649A6875480341D689A54583D191F6593457A2E28718D
323C5A1B377A8123343A2D63A0571537435499862332523D61AD35193166496580272D69
A3478E611E3182C84F68152F53724B6A6712314B605555641A3462512F71413C65762B33
513A30756A2E393B424C72372C465E5B576E233C386E51777A1E393A5B548D7C2A3E576D
488B82194796564D9D3E225F8D384A92412F8A953D6C621E29739F3464481D37745F283D
39384B944F2749383180B3582C4C4F6AC25E2D3A3F3676A02A3552475293762F58695A80
B63F5B8864518E502B5677446962444480528E4B3C469682787B43477F754F623E2F637E
546844435897623C5E3E5C6A8E534D65614478753E41534B68A58D2940496485A14D2253
5B4672B1682E2E646754902C343672766C72382C3F74723B4F2928498C7C2A609A8D5157
8A765F395E77474A567066806C657C5756501E483A4D4B3D3F45615F9456394D7F774B53
5B6B572F47453847545D5541455A525B5B34653532535A611E2B5133334448474048755C
545153494A2D2A4F40434C3F5430432E3A4B3C453C3D172639312D2B2D3E272838175331
34442D382A4543523D435240463A5446687F4A5555585E34536645364442BA832469647F
A7336571354D465D263D587D7B5677BD6BC1596D3B56375179655770827C74B16B91593F
4860912F576B42615E668B6B6466305556684B6F418B8E3E3B4B54933B505F3452331C41
344B3956565D6C485E376775332B4E364D2E4836652D4C333F452B4E2D6D523A9B3E5F4C
3D4E195D412332454C4A516058534259535C752E575940543D274F34685C543C45434B4D
3E746C936B44904E4065264E683C5F43434372A03F3E52505655527A
64B56E6E4B629F5A9C573C54713B3E4833898642172E4B43956F1B2E4A5374C12A1F4D73
3F7C9F212847664D815F1E386497508C831F4A8A5D4C6B2526525A405739203A996C447C
2F446666233F4D435B866520493F46988C263352495D8BA52E26577853C23F1142894672
8C2721428E37725A29464D63417A35174A665F3A7D231F4C614146663B2547956153922B
2D51753135372F465D462351412833854E2145483A5E841E20505E4CA7732334616B5A99
4022307C964A97351F38828A77481D37476B4FA3532D375C6649552929498F3B484A2E40
7C723F53353D5D733E4F3E4C737A3F4F3E43C69A32485B3E96C0394F685A649E4A2F5553
56B1473954A06B73BC612E57536A6E8C36434D64669F8B213A599377A4802D2D7A7C4D48
4E3B376DA34F4B5F31406A682F473A2153706E333D4338758F401B36625467BE8569464C
5F6C604D6D60435572918B88A4949158565730413B3E4E5540375C4E4D4C374353765157
6B525B243A4838533A445A354E613E344B3E5331394B5C591F43573C4B55585453659E6B
3139496262333C471E224C4C683D45464B39404C34391C52462E30463439254A4F1F4D41
4446364523483B6C3E4D5A414F515B4340682D6E4D3C4738422F2C5A5B317348214E372F
52248D6D255A3049295F53684C85595C3E9E3F514150283854512875A23C5B7868807459
4564794459542C622E96A4415F6751614A4851854F678B454A4B444A6893993A4B443450
365846594C5053587C3C8CA93E4765333E2F3D4B8652544B5E50446E56715A597C5A6356
4F5E31675A455E4D4E584A5836642C6C5A43412A555C3F5B372E5645773A5C477A4D4F5D
6C6A666E6F38423B4A673B46511E56346D57526D535C5264705666A3
5E7F9B8945426A70DA823239716BA38B1B34617757834E23364D2C496926375C4C2F4434
214FAD7A30342C2C377838313C344C5E854C3B483486A52E1D393C479A6717193B4655C9
63224A5B4396CA2A3C747955B54C18487D43689A4A2D6B91414E6427387E853A51362F42
5D4339533537587B2B2D353D579450193541545C9D371B444046718C2F253543625DDF46
347D7E4382971D31735A459848154457573EAC451F5C774C3D6F3120477A3A4F5E373366
9550305B24415F6A2E34443C585E2B334321358A953A3D5E487D963C2347473D80792C4D
575D6EBC2C36667B5B96462B6B8F677336256EB56F6A683143765F6C6C263E50684C801F
31998531506A3B4299AE423F673851BD7E354C51376EC2613F483D3577CA4D314F4F6EAB
561B3850675D659D2531746949664A22285B82597B771F2767A64F70973F2759877F354F
4B766653807431645C698D6C5B536251535B2043354A514B556782745B583F486F664C60
7461524050534B56394E69344162443F4F36562D294C59681E213F4D554A454D454B4E51
49444A3D6B4F506136344A3F6A575442443A4B4A3A382C27452E4438383B473846215B3E
444435511D453A663B3E4F495C334D4A4A8D2F3E51495E4E58474B697540736C406C6960
724453502E6A3E43157D3D74483443974093426D37561C518256203A4826566C3A914339
335D7C14505444904062603A6C563E6633383C81366F6C2B6A744E593B52604050334254
295E2F655C574B5B7E36576D5C406653515E585A79576D4C4F4F2D643881786194727878
5B754C695D665E483C654D4F5B84424C526C6A40715841AC713C73394F2A52718A653F4B
50906A6A5B4EA4623E4A426D784E54404B65828E4B47605356797C69
A74766885E685B376AA5405138444988504A553B396A6321423A3B4AAA4B1A4E5A6A8F58
15235B8D668C2E222D685886992B314F8855573C2F6E7F4E494C1B335D7131625E1C3A71
8C3D6B4B2A5F979342612D437F65344B542261AC4E1539682D5689171C3C5A4AA9741537
654F64BC50163E7154766F232F5E924A8F8D2A3D5D833C6C5125637E7F25325225344972
374C453C556F53306C303BA1843740633630ABB12D405D5550C07E24464C485698313859
5B7676B42F3F4B726B7676283F554B628E312D2F726461631B2B776E46895C4044724444
6020495C4D2C593C435C762B4359388C6A295640326FA334615343698A2C3957626FB53D
286876688A9E364C548B848071384568A96A924D484E649482A73A3640688A546A3A2B4B
864F597A4A3A577D5B41693D30657738324A343245782B26372A2757A4352C3F95824256
4C55544B5B74304A5F8DB190757793565655264333424E3B3E40655B695C6259626E5C7F
58565336424231453743563345534D4B4A2C6736294A495C3428475451675F674D6D6D70
3B414B4657323B55262A4B38624A4A3D4545464C48412837523C3D3B4045343640395B45
56503544274D3F6950465A3759365A692876517F5C4B5F31445A3D534C279D712856576B
A03C61462374474E35572C4E2C4B368135CD38444380274B6357175E701D68904838324C
46443C2C514C1E481E897D577C5A426D4E4A6C965B9E863D445B67896C84835E5E563839
3278514E4657583C5B32A4D05850774B623747466D37484257452763325C4D4D8A445346
42613958483D37503846465B48444F7E6850443E474733784835532E8341483D3C433F51
3C58627C4A314C565963383C4C304A1D465498AD575F755B58645279
AE944B8573867E315993639D61455C52607B76212B68742F8738234B8A714D5B1F295082
45515432365B62263C382A40785C1E3C3859705E23436B32597E2217506B3C8E681C1B64
745EAB40202F8AA759AD1E244665436673242F4B92478C5C242E83514F6726295BA13339
5921328B992D583E24335D402B402D203A774733402F41516721394C4F54865C1E434858
57A94A213E503C529037273D61437A9736414085406C3E253F88BB5F7D60304584784D7A
3E305C86743E75243C4D9B3E3F4336418672365541385AA0423346423C895B244D4F4D7F
B343466764639755275483488293353D623F9759334896608C843C4E6370556B324B6A6A
4483463E82A662579039507CA3603F6146688A66324C36406AA28B3441454440895B2F42
445753904F3159655E6D9B423A426F9C5E873D31475B5859852F202E8D87597D77864648
556F5F3452654B646769595792876C49495039514E434F3848446F5E825F443F684B5267
585E4A394C4F4759425064394C573E36462A542F3A445061263E51434E5755484D4F6E5E
383E4C4969404C722D2F504B5C4C4B3C4F38474C3F3E1C3250384539494A41324239634B
594140504D4D486A4B5D6B456050546C326F4E4B5850683E60473F606C3597762C61756B
764FAD8843754983256B4E4D2E624C872AAA5146345A16496F502D6F7A1F60973B783D5B
4A5865266C582D8B3C5E7B35483D456147395A6C30626F3845473B4D4993935449222851
12542A544436464E752246422527522340314E415647524A4E5240634B68615C88456042
4C542369423C4E60394E4A884B524D67533E48416F53549C47334F3D4F6175555F475B60
367A4C993937613C3952394A4C1A711D3E354F62393A4B3C4D5E4B74
89AE8C6E47698F497A48467159413D4E2773886F344F552A8555212D5D565F98251A2D57
4C7660181B3761617D4E263B3E6971C935233654388D73204C62492D863A22415A4D3C5D
1C3166773650342D3F5E4333612042657135393E4168757F2538395B6C9D48172F6B4E76
87251738814372841F3949536B8D221A38385979A32B335D553B478E4B1C61A1434B6732
2D709431464A3D4D855D33551D254B8D57326C442E6D9B363D714C398D88292D564E3793
6C1F4E5E335CA45B2E4D52645F882A46595B6B944D30505B7B6C931E3B5F744C8B7A2F56
984D79A7373A508959966F365FA75A703837686E3D7146416396524852307AB64A395646
54AE71264173558AC8464360766C7DA5384B647E85A9482F4D83AD6A817E254C687F497E
411F484D864B75432C5F4F523A4E4D213D78742E5352223F6F4C225C413C516F6F775363
67666A5E5D773A4558736E6B586A644C49492A34335E565759766B566E55544D534B5D68
51564A3D3D3D404935384C3C3F48483E483547262741646C2C293B4959584D5C5F646D6A
3D44544473545760343A5B39434E4F4857394D4F4440304947333E4A3A484F4149305447
524632572337446A5646583D5F395D733D6A6350644962505349518F8C3E9E8443AF9669
742A7F6F27813C433A6C605A565467946AD56A913F63186B997C12687138557253714137
39718B344C3613581789742C683D2E7242466E8B5D6A6A3540524B655FAB8E546B3D3538
376D375E455E613DB53B7B8621365F3B584E5347643C5E3E3F4D1E56319676428B49724F
465C215B3432323A385A50565457227F524951304C5E416644345F4B473F454883353C4C
356D315821479058435A3E434E324A2D4F608D92484F61535B5C5E6B
707C87893F4C5E6DA84F375B7B6A858E1B33545D5B9F7D3D33594490962E416F6A678921
353FB66B756F1A37426C3E465C227091903857431D63953F38503341828928454352509D
5D2852464DB298253658395DC852175DA34266B2224B4F9945877E1E5354724074641D39
926E437A431D2B573F315A1947786C323D4F1B57875429424C2C53A647253E69456AAD3F
1D4C76556F4E2D38685A6B934B2148606E59B8543D4F808771B53E374C7B8B57603C475D
74447A6B273F486A468C3F294E52523E701A3354773D5587224EAC702A6A5A3066B05538
4F4E63B05835413A49BA8028406971A8732D566A4CAC8A353D7471AA942B3C7E6D58752F
5070AF6C727141638A74406D4339598C91597C3D387D8F606786364C5D9761356D4F5477
953D354E4A488374233F564C4D798723354D75549B821B2C5B934C8F7D1D465C68754B41
45463E2C5E77384A5A7A9473685A6686714D21422D31473A3A4168709B74495885625675
6492742F2D4536583C476B39383E3C2A33275642363F3549363036384253504C435E6C62
434F554C603C48542B254A7166423F353A453D403C4327283633352D2B4636242F37543E
4F442A452C4236723D4B5D39594252630C70384C5D4D503A5A51525C6353B37A436B705F
7B46BA802C593B672573478A325049AE3ECE4D4B5A671D605B4A2763630F7D95356B4146
31525B187152186D3351702962342A5D5E33699441C2A732554850733ABCA5364E261A35
185041514152523A76578997605A883C6239584675384854493B3263414F4A6B9B4B4A3D
314B1C5F45334652424A3D6A33462C6D432F3D274C41236E3A4D7B3D6D5D4B4C7F4A516C
4C9347A95442553F4D614C56653E8A304F447D924E43433E4767485F
C14B6D8467BA673BAAB7489249435AC98B4E732D374E8E39533B213D873C335F384A7850
1D4D3E3E54A5412545525C808F2D3B7D92758D3F233A615F6096272B46804194681B3372
8A5E904C1F50B15D767B233D636B4459492F4E6B503172454159942F2E5C453972AB471D
4D442D8288253C3D476A9A1B335F8F4D7C6A272863794D7D4D383D637A5074551A2F4A6A
4369393148472352541F2F5E4D32726D1E435A742E49322655727D2974402B809C31304D
412E70BA58324A4A5FAAAB3343625F57B350294865809EB03632588351A14C294D8F6E67
4C26556FA5877D40205B8266933A36847E4371403663CA76586F49837C4C3A6650558C49
2F514C5494B2373C7162539F883142717266A6472B40515B7BB2393337696470983D4468
6254677E254E5181736B661B3C51566067872E2A5693545462313A5868403C69614C2554
8E62533445532E36485B5F755044754B52411D462B32654937455A494B4E3F405E454A56
7086532B4D3E3C4D5666603A4D5E3F334E4E53262537444E24323D394C4436456457725C
454B553D58727F5B282950393B4449474F3441403734322C3A2F3A353E343F232F374141
4648433B464936635148594C522C5A572259394C4B3E4335373D36757539876831807250
523D6561236230493B4239593F394EB273AD726F567A26686F6D3C5B4F264F6639692F57
34435615403E1B8425726A39603A2F644130426E3967711F3A38325E41716B394F2C343F
1258306C363E5718A23580A140375E3D524D4F556155585A5E513F53359A663F72439056
4D584E9E644A4B4B324633523D462757392B39498B63479E382E504C67684C667743455E
618D58645E42613A5D7531333C2D544A44476778555B785561594F5E
89764B6D4E86873A5058707F6035424E668F732D343D655786401A4A57505E53343A5C74
449C3E334248773562371B405541436E162A6A8B334E491A49524C3A5719354C65382D36
354D885515303D5E6FA13A39564E558D7F1E2D796D51B45B1F366C6571CC392D508C9A61
B83E42506D4F5558293A6A623A5029326B803F375333318794333A66393596B83A375230
40A79C233D552D61BB56235E6E3E9496292A74A54A8940235479AF48BA5632456B605D6F
2F285C965F575A262966A67E4E602F435671618B3D33646D39526127396D823F6934477B
7B3A414A3D59A2621B3B3759B69739515E5FCA64273F688CAD8D34596E4D73B05B415A83
62A84F4360817C8595405C7988628A60384A856D4B8159393DAEB9575B472B3769763C4E
5D3557976635512B4A95824A2A4B492445B16F203E4E346BA03028427E6E63A06E602F38
3F616C596A6D598081907C7D7B696C64756642403133514F4A418D817A633E6181645471
7C5952213A4B36483D3B503139433D2D433046241B457C7E2B2C3A364C413343444E5D55
394C45405829337826295D4E58523E403F3F4A6D46422450382A364B334832404B3C5049
47313E5725362661413C582B394845485091453D4942553D44473E72753C866E3F8E7B5E
6354957034843142247351923832389449B95A75565D2F807F552B644B1C6C7E4C592944
3546522C574D329E3D79773454524C5C46446E923F7473316655475F4C88995552391D2D
155E30694A3B4D1573367687273D631746355D3252315A443B542F4F2F4D484069274C3F
3D4E274A3432374D363F3F6B3148357A544A36565B43495D3133521B5780725B715D5956
56663EA46E5D7F4A56643D3D4B1A5A1E3B4D808E4958894A45504351
9884776F4076955FA0443565A15E837A1B4C6F6F589B253660584061752E4457313F5220
4E65521F384B4354738B2332513E67B147264E5B4C8493133F62555BBE60164747747C9A
1D2E5D5D53753D1055897485A618264C746784A2343C55753C5F6F203E64411E4D363044
76632355363D9394253F4A3551983620598D52609D291D4C9D6265AA2A1F59B16D71A721
3B519A57604B27586A66506C39376E7345558726436569355979383D77A34C6C582F73BD
7326405F4068934A373A4E64739334385A5258BE95255797656B7C233F4C4B49B1582655
7F445E671D2F648B5A69382F42694B733819486945865123558D4A4D4A2B3671763C5327
53847D3573534660B67C30525F397FA83C2C5F685499552D464F8E78918120556F636D87
6D27648B6D689C352D4D8C643C5739272D59B25A59642126616D3656481C2E3A68973B3A
475252405E663B404D7F87675F5F7359565239413F5D563E4B60766774575F6280664E62
6E775136283B4844354D564146564C4B522C60271748474C2B2B3132395030594E685C65
384A6B425A3E4E68464D635759505250542E3E403A3E212A33212D3A3533282E3D334B3B
563A454C313C32753F48654F6F2E4B3A2740243F50695531506A6674815CAD9E47567792
966F925F3D564F401B4A26462F3C48C658805D4F426C1C3F3F4938453313998D42693047
49486021613F207960959E234E582D60425B5E715F64703B385545596599A657503D385B
39563F5B4C3C4C27964587AA1D2D5413432A4546473746523F453E543B7153376515652E
3A50256E41363C5935464371464647764544412246474470323D843044454B546C617977
496C5074924C4A454559464D56585D42524B786C333F5C413E4F4B54
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C966D69372C
281D1D1B2B8B5F2D231C1E2723373E363E358BAF4C2620204E695036286F37534D373648
AA898568262423252B3229262638262421532F60918F8C59293845191815151515151526
95776257AB68945E2B2831595D7274674F5E304D95868E503D365C8423201C1E1D222426
376589A6AE7D9CB97A5F5561B3A17055679CC7A1A58249302E3248414A56873155775373
8F9B9795AA8492B177585380B1D7C6BDA398856071734C2E2E2F3138475E4D4761ABB19F
9BB38C704C4036283CA9829E7B938CAE5E9394AE8A4B5498BDA08F837B98B89366B0E0C6
997FBDCAC0725B78DFCEA27CA0D5BCCF6D47485EA497724D3F44546D87A1B7C9DFBCAC8F
63667A7164507C764146576D7395764A60658F9F4E4C9AAFA47C565380BE4E2C2529354C
6259537E927477342C304A548CA4B491959F7E8ECF6948413F3F4038
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A84463127
25211C1A1D8F7A27271C201F222D2B3B464184A6894824254E6A3D2F6E3B2B2B2B323732
3D9B9F9A6D2F2524232C292729402A221F385C50B0A4975C2A2542361717161715141D4E
A8ACA9C9D0A3AB74715B53423D434E404337243B7A7F8F62412C36915E2A1F2126262A2C
2F7699AF79ACA86C46473D5D7E88613F496CA0B38D953E1B191B252B372E3D6833456475
937C9AB1C26060856F685E87CDC0ABB7C5B98E75583F372F2C2E2E2E2C43664F5388AA7A
6C8EB89C6D3C2D309B7167648741376BA6B3CF81453A495AA6A9B8B498ABC27B7490D562
6897BAAA5A404A68BACFC4C1A8DAD47F3230333D4A6A8D8F715C51519CBEC9DADBB79654
5F5148424853906A5E5E574136607C453262C25C89CB7389745250446FCB634A2D293140
564E6A96BC55A0332C2E3B8EA2BC985971996A9F7D90382D36383437
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E643E3338
37271E171C98B943271D16181B2029282F5B8B97A5B493617F72306F632E242022202633
424292A7975338282624262620432B1B1C1F6591BFD1B5A0702F2B481813141721405A45
43819E9E9AA7BB753F1F282D2F2D2525251F21366F7071854D403959935D312C2F333B59
66A6A0BBC7BCBE89675D4F927774775E5D7A8EA4B7AA68241918211E1D1E225C4E243B92
93A5516E9D9D5441443A40B3CFC6B8C1ADAF7C4C39363332353A3C3A354966A1B96EA7A6
D5BEB7BBC1BE8FB075646088753B1E2F4E3FBA9C4E3E524CBD515EB491A1C1C8A39BC46D
98B4A067343D48635BBEC1E7D2BCD2862F30343D3D444547596D72A5C6B4B7CECEAA6544
51694A3D3363784C3E3640494B6A755E424FB18553B678985B4146417FD788453E313454
6A76C2C8CA98C275564F7BA05F8F6E5B6D6B60794982683133363735
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B9D826A5E
5C69654667CBC4C4532B171817151A3225358F97A083D3DDB5607D734A322624221E2424
2B37408CB174584422201E1E2F5C5F4648658EA7B5978F867F4020511717314440323739
4F548194AEA2977C795B3424211E1E1C1C1B1D3C6A5F686A968A97A8B49E444667554B3F
626A99BCA69BA9A590796F85BCB4B38A9292BAC5B2BA7F3B1F171C1F1F21212B542C377E
93B8A26A71A8433A3964ACD290C0D5BD5E3F7690533B3D3D43423E3B3C366CC4C1787FA0
BB875764736D94D4A6A089472F47462227307CB291464970A15247803C54634591C4C0B9
9F997D452C3A404E3DAE8FE2E4CCB9CD837C909F928E7974645680B69FC49EB7B57BA251
4B4B4E3934644435382F37424B686F9D61846E5F81AED1C977473F53B46CA176432C3080
ADCDCADAD9C2B2AC7E6D7191A2593A4F7C658A4848558F3C2D2F3834
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F57574728739F714945
3D314FA1BD766EADB58638171517171F2322368A924DA7D1CCA79551383227211F1F1D1D
1E20233879B05D4F482B374A42314752645D5595A08D7475A6665A965E6134212726354A
38245A9A716D847A52778A5D331E1F1C1C1C1D55684C5A4B96B7A48A7B72616E4B36437C
614477B2ADC0977446403F417C7E6F4C6784B8B17497A9582D1C1D1D1D1F2227314E3B83
91A5B09150733F4F907A3B8C7AAA85845046297DA86146473F3D3733374AB9BD6765508D
915C3A3935346FB29D9F392020223556463B6973A6BBA19D375B426C3844613676ACDFD6
D08CA646384359403FB9ABDDD2778BD5CB6E3D34313739487BD6AD51A19572A6987854A1
5231354271693D3933332F3444676C687CB97A6791C1CAB6AEA189B5562A64CA903753AD
D0D3DDE4D5C3B5B2BFB2B8C1B5B69D92B3B3963D4451929B3B34393D
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966C4AC5F52
496F766C903D1F2C9ABC7657361917191E1E22806F6B42A8C7954638362F33221E201F1D
1E1C1D1D2B919C4E648C876553589369403C489977797470C5AAAEBF7D262D3F474A442C
1F1E506A55899873403F4B64736544362B2525784F414B445C8789C3C25A3C494E4D6B8E
3C40836A918C94857F392B2D43807251554360C25964908248221D1D1D201F2024748282
A7A29AAFA081A4D1A63937B387624688594D3139BE9D665850413C3951A7A68B4C547968
AB7B2B2E2D318570928B2F1E1E211D2C53879F9DA6B1CE88396E405E304E8E65BA94DCD7
CD95B46A6073897FA1C9C2DEB48C51B6831F201F1F2221252B97803759586F988A724642
8A532C3E8171403A3639333644706853906F88BA8EBB877D7090C787586164AFD2C0B5CE
CDC2CCD5D8BA968B97A5B3B0A1858BA9BFC37C25335CB1D2B0845FA7
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5DDEC9BA92
8D77473E5A6C21222B94AA50575A524A5A5142A59B6D3B9BB26F52332D262C26211D2020
27231C1C1E2EA3AB9EA0A85A455083783B3C35667F7C8C92D8C892A1B3949872443A2920
1C1F3E517A899C7259402121394D5660747FA6CC3A30313A875B72C7A25B3E3E3E3C3B6B
5A578543675C758879967045425C66514036408F4B4365A94940251D1D1F1D1E205FB9B1
9C91BCDAC1BDA18F8C909AD1A936387453573C2A90985855606D7891B6AB595156939572
B7B65A3A3446AA845D8D501E1D1E1F23254EBC99AE91B8D0A7BD9D9F8C8CC9D0B1AACCA3
BCBB69322824272B3D8B8ACA8D8F4C9C6F1D1C1D1F1F2122249277506793929690772F23
297B887B8969513745474038435E445A776AA2C6C69BB46294B2B57C666787C7DCDFDECC
B0D1A3CAE17A76727E8F9CAC6A4F5D667C6BB55E7F967152699FD09B
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556D0BDAF85
61545148467E28221F31AF9F807872929298B0CFCDAD8795A787C04328242625231C1C1C
20211D1D1D1D54AE94ABA37678A2878B6A9B9FAB9FAEC0AAA69AC4D8CCCA91483C231D2F
3341576A3A3A4059725D4726222732373137559E902F23686B4D5BA7792D2A282B30365B
AFC055325355544C52AC7F30292F695C382826745427487B7C3E382A1F1D1E22225FA351
4B3F75B8B57D6565696F83C7A93C2C565C59453F7A4A26242225284DA94E4C50816093B1
C6CD9F9AA0C2D6B83C736D2322202223257E70938C8CA5C94F4FA39C66D4D9B09DBBC59E
C8A68B6E2520201E246C66A581B652805F1D1C1D1D1D1F1E2BA96C6482A97E96A58A231C
1E2676DBC59E836C362F33434C4742535E686FAD615DA7CFC4D2799786AFD1CAC5C4D5D4
9C9866D4DAC06A37404C515A844A49484C6BC6A2603D39394558B269
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364BD2C49D7F
6A5655506A9438201D249CCBA9807D7E6A61755C88C1A8C2866ECD8667543C2325201E1B
1C1D202E1E215DAF6F738A433C94B2CBC89E5D966E75868A796DAAC4C4D57E8449264047
574427434A33313B315A635640262B2C37353436919E76693A4F617F7425272523232833
7FAC732A414A49464482762C2425476C4B3E25866122294A8E633E39251D1D1D20639B58
486DA5538D76463D3A3D3A59B17C3441894F52498D3F22221F24213B8C4464834D4C4E92
CFC4755A6882B79F456B7F2E21223034544F4676706B769D678A9286BCAECD8CACCDCEC9
8E696567763C1E1E1E6A5883ADC19163751D1C1C1D1D1D1E39A86D588E677B95964F241E
1E1F4199455C90A24D313A5F6264251E314E6399454B8CD2D6C268A1D5CFB08DC3A691BC
D6BCBEA9687BBC873A384B555E614A3D58ADC9902B2C33313F48858E
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451C7B8B371
58544E4C4B6148203D4C837B7E5A4B4350595A7B889EAE6C87A8CA883B41666253372E23
1D1C385E2E504A9EAF737D372E949AB38F63655332201E46866D557A94A8C4977B576548
281F1B1C2A4937332E213669534627282F3D382B3FB7B2545B7BB3BEA0352C26252A293D
81739257313F3A41444E76392321285F4B4E63CCAE6B2E23508E4E38441D1C1D2A599FB0
9C9D60705A4A29332C2A252E59B55C318B649C76C15D2A272030445D85676B5B4D436493
984E845B4242579065617E47232340503C322D68574E7B75B6974452A5D8C9BFCCD28C90
5E5E50344D7361291D745190AA7C846C9341211C1C1E1C216194696C7F3F7DA092592025
253F92AE3B2F3B4C86958B937A5D1B1E2B4B6F79434987DAD696DADDD9B5A6BDC0B7B69C
C6DCDB7E3B273B8DAF5C3C5052716D78B19C91A93A3273874F5299B9
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3CA186A1A7
6841404D545D88626557444F5C47394461857663715ABEBBADAB5C4064542F253C5B5B4E
2D1D382B4E505AA6CABAB48FA1B3826C6E48271C1C1B1919266783708F98CBD8BF78331F
1C1C1D16151D423834241E2E4E664B2E1E35747DA8B0BB984F466C84807D552E23232557
765156885B40384346446850241F227DBBB590956D918B6B2F4A954B3E291D1C5756B8B8
8873578F34381D232F272527306F9C46538D96B6B494754E4D3F2B5981524E6042416D84
3C26356D483C38637A8C9A7E5D595140312A3298503B51649D8C496AACD8CAB2D0C36B7F
664F36292D453C7C78A0677158507481AF3543261C1D1B20837360738F628AD5B2958A98
A7A095B5AA572D3949AC755F62553B2F324C9574424BBCBC94BCD3CCA8AAAABCAFC0D0CF
C8D7D78E2C2425295FB28E515572C18C5B6183C7C4C9C8CBB8A595AA
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E6756648E
AC63472F488B8A55583C3D5036375A70747E828698B5D7C0CCAD826D3D345C5C2D1E2C3A
43568B8F75A396A2B797CBCBC2CC8D371D1A17191715191B151A56A2C1C9C9D6A3241D1A
171A1A1815171B3C392B1F25252F675F4328273A99AF92C59764605F46424C58483C5A95
59604E50776D4145403D4F601F22347683B8B06E4C40636C896D66943D33375BAE8ECAA0
7B748053629F3B242D2725252B3A93855FCBC9B17B4C5C7D8F8F8FC3894E4A453C5E7756
2425263D5A413D3E80886C4653667279727188A4A86F607F548CA3A3A3C2B5B29E93ABA7
4F332C2F2E373F4A65CEA76A5E69B3B9D84F2F3D2D1A1D26A65F4873A3B5C897B0B5644E
494B49709BB95B35749136418333254E3951BD704D8DBF58478FD46C516E8DC9B75C63A5
D6B69CB7331F23232841AED9C89C94544C4256CCD8AF928A857A8FA6
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D395146414C
5F96717A6F64493A853A263B585B4435313331396CCDDDC46B8E39528C6742596C5F5574
828A8F7F8991B7BDA7AC9D8470A56E1B1616171C1B1717181B15194094BFB2C78A1C1816
1619171817181719354225202723254F6A5E7475839A71A2534F6C9A7F72778B92A9D5A7
3F5040335195A14238364162253D734E456081664749405E507CAFB6BFB7B8CBCAC4D9CC
AB627F656B6C8071672E2F2924294BB3A99EBD846B60535758576EB1A75F4443566E7828
1E201D233E5B46425B948E786554413D464E4F537AC69F41438D9E8486C1B1593F88807E
4534413D2F3E404CA1DFDCC8ACA1AFD4CBA8582F43371C50C7425D5FAECBBE71B98E615C
5F413D456D5B8C92B17C3B61CA787774A2C4C99797B26F343B8CCF4C5052347A7F3F3A79
CB927297891D1E1C1D2379D7934E647455404FBB8E37312E2F3C667C
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39634C4138
44468BAC8B4F68AEA2544B3C292A212121315A6D654EBCB1726D78203E7F9C86AFC39787
91785472783D6E6B78A36C384147845018191517171B1916171517229F8881A79F1C1515
151515151D171615182F45241F272D203BBFA6553F91805E2528458C5D37322F394680AD
793728273D7C7A935339355A76774E474F343799716549466C55909298B7A5A7A9BEB6AF
B6B2513431333C4B7986673224274796C0A8D4BD958C7A696F5B4B54A48A9C9DC27D361D
1C1C1D1D253B68537A96967E32363D201E201F2268AEB3324195648F99587C5E36747C7F
624037433C3B3B82CFC2A4A4B6ADB7D44A5FA89947567CB8CE7E616AC4C092AB6E434B53
436E603A466C569DD05974B49C828FBFCDB9BCC5A4A8312E44B6C459461F276076444453
C5837587BE411E1E212984AE604C5E728C4B64A57A292B2B33454F4F
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240404C5248
403D68C0D2B6DBCD6C574D5469593851716B5032252582C9D47684452C3761B0CACA8E6D
523E3986AA3B5E665780422C313A436E501C1716181616181B19397BC3A87CA5C64F4733
2B1F1A171A171517171733421F27494637A376504183AC70334057989D653A29282C3CC1
BE94797F7A958578907A6099A57C544E30312731728C8A564A70A8BAA099BDAE91C4C7B6
B1BA833F2A2A32383A415D7B767DA2C1D9B1908691B7B7574B51646B8E838675A479201C
1D1D1F1D2C305A6591988B88392D3220231C1C1E386AB05F6671966B3B3C685F5E716C97
844A373B3A4A8CC1B5817E7DADCBA8AF614D6494CFCCC185D2B25DA0C06B778E9F4E3B53
5B4F6069444F87BCCFB7B276434D84AFCDABD0D3C15B2B3EABC2C94B21202B5A64374F8B
CC9F7A6E91A3341F2435B55B503A47ADB094A4B296495769985F5667
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B316739235A3D3335
3A3E668F7755AD6D392023318DAAA1BF5D29232421216AA1A2B583A15A505392A3AD694C
578AAE9A81737C866A82412B27282F375A5D25181717151C405A553A409F98A5CE8C4A33
34383D444D4D483E342F32986950664B4AB48B5E476CBA994D614FBCCB845147302C56AF
6F404E577B8AA5BDA1BECDA39291814A341E1C212D2B406F7971C29C88879BA7C9C0B8AC
D1AA718768402E35323135405795A99FCBC05B4B455074827E6C62577093A9C8B45F1D1E
1C1F20384841514B8EC2675F632C29201C1D1D1D324C90C6A79E37282A34466C87514C91
A0714D697BB5C0B8A48C84645F6A7066B3814880D3C574A9ADD7BFCA6A48A49B60855035
4D66544B7666AAB884C5A5516A5E8B88ADC7D2DC982B35A8B6AB9F8A1F1E2047606F8E6A
77A59D6078B1A12729958D4B483952C9D4B5BDC4AE71696979737781
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553AA049332C
2825416555855249291C1D246125223E25232320201F7B753A3A728FA88598AFB3C1AB98
8B87A48771738788A58F55382722292C2F4A7734191E3846362321203772B2A2CCC1B98B
502F2019242E2D38343649744733455969B5886E7674AC997A859BA59C98866860559B7C
4F2C28253E4E6F99B6CED6C0B7A97B63301E1D232D2421263F9FBF946A94C1E1D1BFC8A1
8AC379434E65755F3E3D3F405FAA86B2A1D0A67354443B3F465F777B8ED3C5A5CA712F28
1F213075565E4C387B7A414B5546201E1E1C1C192E4C8EE2E0871D22252A3B7D88483B3D
B7D5CEB79E8E72A88039382D273F45685E8057918DC47EAF61BEDBAF42556D6D78586A62
39495A5452CBD06EBBC6C29B61564166B5AEB9D9AD56A5B4846772A2371D327FA0883C2C
467F9D865D75B6A299B84F49326B94B4D6C892A8A2433F5E8C5E696D
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F667F462A
2525435E8C6447411D1B1C1C19151C2423211E2026296C5F2B252A47A7B46662B3B57069
74796B5D677A757183A6814E42322B2B2F2F3CA09C4F2B25231C222E4C6EA7BCBC9A7C81
A4AF894D291D1A1A1C2025396D2C1B2148817144343AAF97363C71602A273F554968C56B
6533292932303C859EB6B8BBB19B7F7E4F3F38373D2B2A252DABADCEB28486CEA154957E
646CA49F3F394968756B4F4F9992BBAA549D6D39405C68694D415888BAB9C87679676331
3C59AE926747416FB18435394B4B431E1C1A18191F52BCC8A8B962231F272F7BD8CB9B76
C1CB886C7089A8AD3232362C273260462B428B5E3E79C9A56BCBD9D1706F3C353B5A7065
82353D5D967FB7CCC4B982C15E31697D85BECFA6C3C6AF6540556669963D76AE84443D33
44538B8E935771D1DB6358574152A1A39D6C6DBA6D262638553C3D42
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131886E8137
2226497B9D483E341C29231B15151521261D1D1D1E4B545A2521252C90B5965DA5A77267
3B3D484F4F546C8CB569657848424A4131282A6BC427272C1F1A222F66899BBFC1B4A389
787F98ADB189452B262A2E28498545255751342C306FD9D2763A64622D1C1E263D80A47E
767180352E2D368293A3988C8D947C6C615B504C5C5C6E82B4BB6BA64E423DA36D465A48
37405C72A1693D3C434F5EA790ACC98C517D371D1D1E20378ED1B697A0A7B0C3844A5190
B9BFAD8D724E495CB1A44A484992534D211C1B1A429DC6769D688D96572D3EBCC3997B5E
B4B2A59786A9D49227292E2A2A2F4C8385697280616DCCC0B8D98E85C991382A2935527A
869474674885AEC67B8BAC84BF9B769CC39F965FB0CC86473A46656BC69E7B437E704737
39316B778E8898D1E2C3A75E4763A39B514D6BCB6323251F243B3638
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B709A9A93
543E6BBF784740251C2020161515152222211E1D226E5E3F2621253D9C894F8DAC7B4E58
3F5A5D546384B1C688675054605B383A44485B60886A312E32414D4647928DCEA7A7A5AA
BD96787E8B9AB3906F45434654547E418C82495692B596A0C4AC8A54411F1F202B9A5A99
A77F8A775D3F5A60659C9E9788ABC4885A3D33334641424682CA8F9947414086794B462F
2B2C313B5693BB784C4547A59ABA97675359381D1D1D1F49855E515560525D83B49165A6
E3DABC8C4E55679FC3A9919F9D8175895C453A69A59DB749C0474D7D9BB1A8CDB3774C60
ACA46A7B7E776FA338202A25282C56C1C8AA6973BAB0D1E0D9D26B91A7A69D592D2A303C
5CB0A767ACD0CDCFB0968296A1DCD69E524353A0A7BF897C503D65B5BCA6394B9FA4302D
2B27469779A4D4D8CE5148639EBAD5CA7F577BD67D2A2820213D3339
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D807A6966
82C7D5D7614030211C211515151615201D1D1F1D336B673025222C6F715F57A8D5BA3627
303C563E44474A88354732404B525C403D7676705A984E3D4D311D296E699C8E586D91BF
BEABA9A77281827F779D987A726A9EC6BC8272B1A274533F57B9C19C7A653B3381694A77
B58180A2AD9D9A6C5F5E81795D658F6C6552342D3434343345A1B9B06B3960A8B1675F2B
27282B32373F79882B202488746662684C45491F283B53503D3233424748536C7FAF99A9
DFC3AD9471A0C5A473685045524D65714B79B4A7B6C78E88BF58485D6D8BC4CCCDB488AE
C6C26F48302C3662701F2D2529355953B8BECDBBB796C09F8DC379B1984C52848B673430
3F4A5D1D8F9EB3B4B94E385DB9D2A6352E2B365ABA96B2B6BB8AAAA37A9A2E3183DB9845
2F326EC68FAACDD5D4979AB5B2CECDB19CA6D6B7AB372F2B252E4157
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D54506045453390808A94
9DD0DBDA922D1C1C262215151515182D231D1C1C614E6329232436948B868F8894A95725
24354A262F3B4057583C56623C4A67807D5359686F94917F2117395F5555AF8F605779B7
BEADB5AB85A8C697A7736F719EAFBDD09A8B905B4738312C416779B77C7C6D88D07A4E5C
A9A17C9275779F79904C31635A545E6B59575C362A34312E3F98CFC67A7AA892B1AD6135
2B252427373F3E684820246679564F634B3A784A423734312C2E2B292F404D816E8CB5D1
E2C8B2C9917A5A504A4C9F6A60634F363365A2ADB4D0D18560A66F7EACBFBBB7BAB9C0C9
D6D79F97744C3B4D61452A24445D2D32B06CABAEAA7DBC755FBA616E7C453C3E4B81AB6C
2A2A4E3781506C97642E345E6FAF6C2628262A38A3768DD9E7CEA4576EA730379FB1C2A1
5582B2756595C1CEB2BDB8BDBFC9AC99A7A695DAD9AD625247484C4C
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439737A9597
9196A9D1994C23181D171715141523878B5736307A64442832576A75737E785C454D9B67
292B2B2124385655602926345A5C48708D603F31337D73813F454A3E3E52616454546387
4B3437301C24367CA6989AAAA6C5D77C918A584E5D72614E6A41375298705F5285B98A65
6C8EA9BFA9C2986B92412A2F7354515A4A5051583827262E369CD4D0B47A775D6C66755E
3A2A21202628323B5243377069433F7D5251432E29292D2B29282928292C44587094C7DF
BEBBBEC7AF804B5151597A6F54484E3B365F869DA3C5BFA988D6CDC5C3CBD4D0C9B3B0DA
CC8D44577B88A6B1A0A6887C763A2F628C526FB1C7A3DA5445B345405D453638383F4C56
21222F805065577C392C324F599C4E2123252D2D9B775DB9C0A0814E5EB047773B273F67
C49C5A575DC0C4875A87A6A09D9DA4AE736EC1CE9273593E37343946
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B3194B99F9D
595165B7B2945B1915151315151A2B37527889A7BBD17780867768B2AD6B4E4434315B94
5B2C2320273F58526C442522212C616C656D4630312D397C69322C2E453718292A323362
261515151515151D562F3F6A9AD2DDD198693F413F475572873C28275083715673C2A2A1
98583F6FA19FBD764B572C275168513D4F24274B8F40243E81CCC39C997C5381AD64475A
6B43252021252A2A3250A050583C3C6D536C402B2D292924202421242C425B65679DC5B6
96B4CDB8C0D7A8879286414941554A4F4A6670989B8F95BC97A3D1C9BEB182808EAADADB
93884A383B443D6792A19FA5BFBFBBCC66548CD4D0D8C8BB8CBA423C47502F3134373B3E
3825285C45604A792C31334E57AE3C242525282FA54F448062A49C4958AA812F2C4F91C3
B2B2AFA6C0C691C698677D93B19B9A8BB0C2A584895F404A5B655A54
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E38773048797094
99506282A892A44120241D1E1D1D242626283591B4B68885736853B4B86B4E4C44333042
7C662821253D504D575C3227251F226FA1B37E632D293F81593627323C2F1A1A15182652
24151515151717197860281F2D9AC2BE9F6D3B38323A3A404C5A3A3C4063A56C8CD29A61
4C4D47528965A4B99B55602C28795637383F20253DAE91A5948AA3B3A1B6836674524C48
4B6F5030272426282D3470424843364A5A67432C2D2C272524272D384A4C526FAD9A7C9A
A0AFA0C297D3C9917E667B5D393D4D49567766745F6AA6A3B1BDADAABFCDCBB66D56A6C0
9362524B42473B455290A27F7A4A67C37AB2C8CBCFBA5A8BBECC47323E3B332B2D31352D
413D327B5651506F2B2B335373D259202223292E9C413E7B559BBE5D9D71C8A69585715A
5182CBCACFB6B0A997948D81BAB9B5C4BB956264763E2B292843ABA3
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F303D3C7E55
8B4E6395C9C8A39D70594C473E373632293269C7A2999CA84D4C974336676C47464F3C26
3797794D2F3D4B4C54693F242323253E7197C1ADAB7F9EA76A5F48566044191715151A52
2F151615151515164597954A265395697776484243443F3C3D4860443D48A781818F5C42
413A389E6847496E738C79452266B187747E322120539F585C6DA7B0B9BE542D32524742
38375E63352523222929574E406A5A7A8A6A422C282C2A28262C2E38556F82A276666351
AC5D3386D3D6BBB63F265E38201E223055918A8E9B9BAF97D1954D5E8291989E493CAB92
C2785350564D493C40B9C8B4463655B1BFBFC8C4B68A675263AF8129302B3D352E2D353C
3A6155996451575F283674BBD9D3B950271F273AA338417551739EC96997B166524C3F44
4966A7A9B9B9A78F493231374889C0BB948A727F7865352733287942
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E51253D36406E
50BC62A1B396BAC1C2C29A6E504E4E5A6F5959A29A736167797B6D1E1B225C7338231F2E
253ABA8C3F2E3E484D4D51251A23215BAAA0C18D997C94B3895D403E333B38231515184A
4D1515151517181C21244AA48E69A26764231D1D1C1D1D242B4062819F778D43282D7041
3936375C7B2E304060765E8984A19F909BA47D6D547D7B48587C746B8E8E3F302D294E40
393733486141232027274E9584B1958FB78D773A25242C2A282A35545B59916574A58D98
A966334BD9C99E4B202158391C1D1D1D47916E8C6266986BC48B3F324253716D6B41A670
7930303841555D5E81A5B4C27A85B0BDC7C0CCA553515E544D5190342627354C302C3038
3F7F8D82664E7C6889BBD7BA92585CA99846338FC0494575495CB19647B26A3437313437
44667A887590A7402D2B2D2F377F8B895B45344645484F2733704B3A
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A362E32BF
A5BCA5C9A5B57379D5DAC3AF794E3D2737478E72C15C4C4857A1763F1E3826505B261B1C
1B1C5CBB962C383F3E4454331B31759193A0BFA4886647618670633D2625394944151D35
6619191C1B182A331C1C1D317DC9D5BF77261D1D1D1D1D1D1D2143548279692A26266653
312D283EA83E3B424B6639339DBB4A414D6344547ACCAD733536684E7B8E45282827325F
3C37372F436B51342E509AA29ABE8B7080926E685236312C344A5D515D806B7C726982BE
C7C5C0DCE4B4511F1D2056371D1D1C1D5A5241835F548B61A3952C24363F4B56656BA972
73211E1E2D59A193747AADA482D3B0B9CECB994B2C3D5A51463F777D25272C393E2C2D31
3C63ACA288A2C9D0C49D72914B485E6691C2BED280A59F955971CB6166863B3630293034
497A7C8D73544E3F2827292B38877A4A544A344C4740556C79613630
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B384280AC
B58DA0A4A0BFB5A196CC5E4E567E8C908EC1D16D84914F5AAE943F72352125175A431C1A
1618308DD17F4946555B62716F826F7888C6C09C5F3938364E618D6B5736313E423C5161
9866745A67658D47454245586E99D7C5B87B2B1D1C1C1C1C1D1D244970833F2A242EACD4
96524887BF8B7C7C726C80488DC6525A5C2725272889766C222D4C5D66B5672627272536
533734342B499C82758C8388A1C9986C7176515D798A7C53433C5C8398433E41455F80B9
B2A586AFD6C3311E1D1F593C1D1C1C1E6F3D3A97A79A665789CD76565050546081CCAF8F
602A273B64556E535C8B936D7EB2ABAACDC05F2926344550553D51B247232931423D414B
76BFCCDCD8D5C6C36F4A4855835252545F8BD2803848BBACB78395A7C66D3932342E3544
83ACC39F783B39542B27262C3D886D3B3F5439504547548383353F2F
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A52564B51
B2BAB3AB8FA19D96B1B4C670271E1F2E5DC7C67771CAB1B4CCBC733B271515142A5E1D1C
191D3A99D6D3BBBC80525E8D94817A81B5CCBB7943342F39622D4E60585D644036546952
4037674D53595A4F5A555A586591C28B4879A0501F1C191C25467591949E425371ACA59D
A5B0ABA59B43435669899F6FB9C2916A372E211F2594744D312C3587ADC1833E31252629
495332372C315CCDBA99785869C9A2413950A08096AEB77A626CACCE4325273A7AA7C69E
BB965D63BCB1371D1C1E6C551F1E1E3489376D6B5C96746C86DCCCC1C2D0D4D0D2E0C6B5
65494C4E4C4C7A512A3A44484465A4CCA0926B2F2E36418A857C6081A150292842A29A9B
B8B0DBAB9466B6B1462E385679695A4B518FC93F3850D1CCBEC0C1D2D4B470606A8A9ABF
C1A18B964430334F3D262828417A5F2E314F464C4C4857707731563E
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B504E53576C
A89EA8CD9C88AFA59F999C955F50483A2592C39AACAFBC975D5C88957339251A248E4221
266D8DC1A86E80A1B3B8CEC475482F2A50A8869F6F3A3D574F312E3F595B65797055505D
705849504E4E494C514F5672646CAA6B512A477D6A373C5B5A4F3C3D5372CCC699735040
4C83A1A781775043383D5465CBBFC06B2D262B3C63C39D714E303FCEB78A5F564F42454A
437C44546C5D99CF9F574D494BBDDCB1ADA4A7A9B0B6B3A3A7CBE9CC6E67887D5FA19D9D
A29C91ABD3D881212032B6C39B7B76ABB67764546E7C465DA2B694878291989D95C6D8BF
4A4348455FA06D251E1D1D284438499964886387726E5E5A65657493D06E70587CB3A2C8
C0D6BE567DAA6D39513D2024336032292A2A8F4062BED9D5C8BFC9CDBC9A5D46659097C0
907C696F3F2D3034412F26293D7055292B3B6E4B4D5B7A8BA66F6584
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C95733673605651504A
3B8D81A0413B4A759FA1B28B3B2521334C88CCB8AEC292835741393E45626B656CB5A968
6CBD9B75473C525D75ADD35F3D3127253C8772606265477A3E2927233F6B5E5F6E50495F
883C45433F3F3F393B3B466E5B65A86C5855222A82D27C34212125263E92ADBB744B493E
4287A6C06B566A756435257FA5BF93884E3A5F825D3979B6885EA1939590845A517C8C92
84A3CA9C5B8EBAD3B9503A3766C88B73837E797A8D96A5B1ABA7D4C4A389AC8283917655
4B92D1CFE0C3AF7F449C99785C55535392A3756F936C4558A8B195766076696B7098B0AB
895746425293471D1D1D1C1B223B355E76ABBD655987795D625B505BD3B8679ED3C9C5D5
D3AC7B4F7F7555242C4E431E235B7B303C3BA878CBCAB1ADAF98A98F78847D7A6A4C79B7
BB9438447527252C2F3D3E2A3F735720293652897B9786C5D5C99C93
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E4370784B3E363A
6D8D3A5E542F262947AED096391C17193178CED3CB9B6E395E705A3F393B3A341F2BABAD
B2735A3D3F47596D887CC48B4E332C26357A5B44345D7767382825232227477172756157
9A66241D1D1E1E1E212A313F5D62925A48602A2133B7451F1E22212A55836D7576523951
886B7B684D595F5C5B7187D275B08A66988987372C252F668294A27270675D99A963596D
90C4C2B1BC958990B4A85758D8C437272D2C396EA47D6C697F7B94CCC7C892ABAC4F413C
62B1D5D5CFB1979FCA984229252B2B5B80A794A2727D5B7799525E718B98937F88A9C691
772C1D216051311D1E211E1D1D20356BC9DBDDC683794F4F5B6F5853C555A1AFC0C6D6C6
C76057535F5F8B46252C597A4D469D8199B1D8CFC6AE837B738B7051485885868CA1D2CE
AD902C35583F252C382D252F557E7020293038A0D3ACB7B4C5C1A187
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A425B7D93
BABA5E2F63442B2839A6D1BD642C19235A86D8D9DFA4563C2A263D6763564B673630989A
392C59596053514D5265B1A82E353D3F4A8A6A413C6B79A77E413A323743557D94915655
7299511D1D1F1E2129292B30478C90434C4C5921237F791F1D201E2B71555F7A5F5D688F
8183732F3A3D343D547486D1A9706A709467444140262645919C5D4F3C374778A54A5F5B
6EC5C0B8C29A624E599EC3D2E5DB642D23252637766769333541679899B3DED47E464C68
A1AC91AD87BCA9C6BEBA9856211E316A416C9C93597B5D69743D2D313D435A89C8AD869F
87541C3E4C341F1C1F262C252220298D83DAD1CDD7C27C3629436A8BA3495BB5DED5BE92
9A9A3225284A4A7F232B48B49B84ADC1BEA8D0CB6C71776C3E31477174564E87BDC9D0D0
7B77382E326D2F293933284EA9C5B252455A77CDD5CEB09F9352BDD2
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B7D6A5B5C
719FAB7A3C60372D6BB69D91BB9B9594B3DBD7CFD0CB9D5D431F1B1F294781614E5F593C
4849444D52776F6A799CA9B7331D21203C7B68677C353A72CBD7D0AAB8B8CCA88368212F
4F7998352323252C2D364980A5E2B94A4849544D3259B13120201D30674A4C6E8078C993
8487665564645B462535539E92474462B16B7196996D6A9399918147312F334DB75E386C
8656AABFB2B4BEB1C0C0C0D89F8FAF572325262A544A5029272534336C8FA9DC9683919A
5A3B4591AF9FC4AB977D829A928485333B74B7896D80718059413532383C3F55B0C2B8AB
AFA5355540301D1D25261D1B1C228F9EA6D79B929DC1CCCF9952499B9E8CAEDAE0D8997B
C1C7562525305B5791607795889BBEDDDBCAD0C8713F25252423263342647A819F836E9E
7C6C552B30478037586C8EC2CCC3969E896EADBCBACCAAAD6155CC81
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E46727456504C49
46455B76825A5F6EA95C643D45C9CBDCCDDBC15D496BA1AA81684447434C64685A776367
565467946F5F93533C30627F761D1C1D3A744D1C27324375CA875E4C52849D9F8B6E1E1C
20479FC09287838E8D908DA0BAD2D0BF5D57474E2C499B671F1F1D49543B3B4BC9B38472
765B463E3B383B3523252D6A6C3F39668A45537DB2DDD48B964E766C3D30324180CDA97A
699BBCDF9D81D09C6E855DBB763B53A05F27262C5D546E2726262929554A79CDD1A46631
24292F46BD979EBBA17C5F5A61A29E4E85887A636988A7AE4F4A483C343D5FA18A668EAF
9EB9B87737211C1F211C1C1B2175A4B2B79D979692BCADC1C4C8C0CFD1CCD5D1BEBEC9BB
7D898A2B26304976C7AD8EA24D3939C6AEC8C8B5423A1F1F242323272E473E4F6F864C7B
8E845D34273B84B5B8C8B4885D598E8280C4CDA895DAACCD86CA8350
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F554B4239
3937344378ABC1CC4F1B4A502583ACAE8E9B773B2C313D4A72824E454A527779392B2220
242D6388908A4A2E201D2D5BAF3D1A266C9E461B2B583D8B79372A29231C2B677F88291C
1C2C71C39A6B62646C706F7774A2BAD0C16D3F3E4D4274A532242B9B452E33508B9C7F7C
7734252D252827292B20235256422C594E443E6997BDB06B5C5B597F855E477DA3C7A849
6B5063A162A6BE6D4F59667067352E349A862D2F59697125272B245251413BA1DC602625
232526288CD2885CC5A563514B69C7AE744F5E56596D85736F5647506773898C50454880
8391C6AE46211C1C1A191C216A9E82E07B9F8E5A599295969EB9D4E5DFAFB58C93A8ABAA
585DA04D2B395A83BB473A5D2F27338E94C0CFB33D251E2121242220253436385A666C55
85985E66578DD0DCA5857A504A5777A0C4D6DBB1A0C3E0DED29D857C
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D41393737
3B4F647697C2CBBB381F2270659BD3C8CD7F4329252525262B3A8D6A625B6083331A1C1A
1D254E81B571775C2D1D284991B48A9CCEC37A3D61553D6834231B1919191C4E6855641C
1C325866C59C413237332D302D3C6BADCDD07140515680DAC5A5BCD68D3E2E3A6470907C
8A524E60402621242B251F3556462B582C24242E68787F2E2B2E73C9AFBA7D555B8DC57E
4028285DA3B678464A4E496C7F4F332B3879963A3C617E292B2122574B46539ECD412123
2423212C7CE4DA7A6BC5AC9589BBD28A4040414B9C8B4A534C5E604978A69E513E396BCA
5B8CB19E7954211A1C172C878564C2BB83B4C0AC6D4A38364269A3D6DFCCA0958B4B3F67
936871843F275E5E8A24242F3B273B62AECAB4B22F1E1E1E201E242325313D344465816E
6DB89EA2BEC5BC98B5BE9CB7CAD0C6B7A8AAA2BBD2B0A3DACCA47370
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C6E787774
756349373233585B8D85866989D0CDD5D5A35529232828282F2E56312C274650211B1B1C
1F23232E59612D4D663E2629A4D4B78A7ABC7EA0B165574B271D1C1C1A1C1B3D712A5C4D
2C585437886F1A1A1B1F23252E2C3B6270A6CBA0609EC6A85A545783BA9F79798076806F
5B282940505845262A3F212357553E6C24202024354A692A3D84A8827DC4CABFABCEB284
211F43888E6D4C3745372A617B75313029346C964F7480504A2033594C532C54A9501F27
2B2524368FE4DEC1BCBDA6BBD3DAAFB87E6C6675C568292C38405889B7B69F61456EB581
53808CBABEA046281E4187AAB6BC666E72558697511C1E31303953D4DFD2905471553943
5E808269552F574A671C2122322D4977C2E1A089321D1D1C1D1C1D1D25273B323F576990
A4D4E4D3C692594F88C765996357555F8ECDD1C3B9AAA5B393B18090
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D68433227
211F1D1A1A151C6A6A99636CA77D4FD4D4BC977C2A282D2C2B3D442927294B1F1C1B1D1D
1F1E1D2235514B23306E6F839D9A826354677972A09163272121282C241F1C3683274E70
634F3E336A641C1C1C1C1C1C1E1F2140545777AEDAD2CB7437343C3C5486A19AB7ABB9AA
412526232423395A5227242EA9AEC48821201D233148BDAB9C865D597095745D65957B9C
5A6B743F72615A32342A2840679B58362B2D3773B191A99A4D43727862251C3F866C2328
2F303259CBCBB7635291C1B5B9D5D4C9B59B9ECFCF4F29252630428AC2A185BD9BA4661F
1D2A90A49EAA98704C7BC0C9A8566F77352A4C4F595435292B316ECED8CB5D5C53565449
475969A2775157575D1F1D1F25397CBFD2B6A66E4B1F1D1C1D1D1D21222224262F4664B6
E2D5CFCFD69CABAFA89C9682393B4682A8C0D4C7BBC7B3BA86A3D5DD
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E3393734175504A45423A
2C201C1918152B7D9080C5CD99281DAFA282A87D7038303026422D282A271B1515161B18
1C1C1C1D24504E3E1D1E5CC7939B6531231F304D547C7654462426221E1C19439C43597E
90403034596F1C1C1A1C1C1C1C1C1C245854649CE0D1B7543426313C3E487CAEBDA3B6B3
602D251F2121212B3D497E8FA9BFA8A5621F1F1F378FC481564E4B48747C423E46436341
96613B256C5C612E24242439717A4946596A6985999E8473625D6F8F8A421F647E892829
364344ABC4A5A75B64C49896BAAB97B69966607AB19D3D2D2A282D65AEB9B4E7C65E1F1A
1D33C2DCC6C2C79EA8CCCF9E7599AD471C222D1F367A784C6487BDCFD9C86C4843414755
5D54587E939AA1906736372E2F57A4B7C0836C6AAC5B4C403B2E241E211D201E26498BAC
CAC5AABDD4BEA5A285664D848490C2B4C09A89776B97D0DCD5C1BE8D
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A3276874E494338
4046382F2142514A4773C6C7AC45209C91525A855E7C513A444029252225171415131517
181B1A1D1E2F55532A1E34824F816C5E5E564B4C7B674A4F616B47261E2A368DC55C4D4C
6C8B3E33558F1B191B191C1C1C1F1C2541A35CB2BABE5C6C81504146514E5B849DA9B296
645D3022291F1F1F254E6A54496C8E5A857D3A3679877E5850524C49766A383A403D4A59
6E43211F5D5B6C321F1D20285C5B41262F4299A3A5967F5D3E372E425F745C56ACC78846
436AB0B584403F7CC59F6174B57B716938455E6C8D827E4A3E423F74898663BC851F1C22
5D8EBFC3C6D3D0AFC8DEC08D777875701C1B1C1C233B81C48D78AEC7D3C9824A4744464B
54738BB9AFBA8DADA67E65494D4C92B7D47B7DAE7348424145494E4E4C4E483E52A8D1D7
E1DF96B3753C3D40567A8CC3DCDAC67D646441394057C3DDD8B1A075
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E687548444033
2E2D344E83533F3538827C6F99A359BC9A513C3E6C68886474412F1F1C1715151212151B
1C1A1A1D1A1E37654A2341676051191A1A213C83A76D50595D6C81AA9975697DBD9D786F
5978A76971C2221C1C1C1C1C1D1C1D2F5694A0C6A4C2AE8061596D7F8D684D4E64BC7E79
6569744F2C1D1E1D366F5E5A3A41AA7B4A63A2A68B6E664344463D638A4332343E3F426A
6F67351E575D6B3B1E1F20214B4A4022223486788074664936322D32455A6C7AC2CE97B0
ACCDC07D34263A91A98C73728B8061201F2426294F5E889B536A4E9963582F67601B319A
ACB6B16696D0C4C4DCD078493C4E5457451D1C1A252A82AB866770C7D3C4B3614A454747
4D619ED4CED15C5B7E8396A18462C4D0D4CD927A644C433F40373B4F7199AABC945293B7
D3D2CFB435292F1E1C1C2856DAD3B5AB4A3629313B4796CEC5717F7F
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A3C3A3E3F
312A293D79492E2A72501F3A716EACD9DDD1AE917F7892A2925F261C1617151515151517
191A19171A1E27606D355B6B79291619242F336031232B2D2D41506D77231B2D81AA9394
8E9CB998A2DA6C61593B362A262627292F4599BFCACDCDD7CFA993856C5B86797882AF76
7B8D8A8A653A3F4E63638050443EC4BE78557FC3C59D7662382F2F868337342F334452A6
844E8188A85B93702F22201F49535C223A6C5167543D58514C54554D393C538AB185B39A
C4CBC2AD77517C4A548764536987481C212526254C585760B4C6C0AE6067297597678550
7F756E7F6E909A9DC0CB3F333F4D303E69431D1D283D84B793478BC4CD97608B966B4849
4F76BAC3BEBD8D716B8B7D8AC2B3AE707FBC9F56754B3F465C94B1C9C8B38D8DA597ACB3
ABC1D2C87B3B231C1B191F21C9ABB788302B2A3438499EA4B65E7C6E
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F43342F38
432F2358563724584A181B356D5278CEB6A09A9DACC9D4A77D6B2E1A1517191B17151515
1C1A1C1D1D1E1D44AEA09A98C3691C373D3745181514171F274B44334B482155694F6A77
67808C569ADAC25C313D61849C9EAFCEA157C0CACCB5A5B9D7DDD9B9A4A67B60232460AA
BF8E8882828F8262838BAA9A6A57BFA29B5A83B0BABEB387726C91CF762B2F322B3F51A3
8A4B3F6CCF8D7A794847493F626E8B655C4F685A30263E402528303B352956786A7AA79F
97C0765B5DA39D432C5E735162845E1C1D222525305E484658BF61746BA9A4D0BBC8B98A
5C4C5979796B624182D3A67C6A423B346C964F272D685E6F714498BCBB482D4885826D9D
AEB17F6B9192968CAEC0AA9DB365568E7F6D976D646091BBC8BF9C878486969ABBCBD8C9
9C9CBDAB9C79231B1B1B1F319A688C6E2C292831374DAC98B8557043
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A3446507B737379
858B95AE9B8AA6B8212032271327697DB4949EA29284B5B598956D3A2220253229171914
151B1C1B1F2B58A4B2B79EA96AA27D423A50221515151514151B4B49494A8398644C4343
84C78A5CB580488A7B3E25212A2D40769CBFB8BAD0B7A5B7B5CCD8CFC8412050281C226E
C7B576646C7597A887819D6972A1CBA0A09A7F948DB4C0D9CAC2928FB1472B2C2D32418F
725953479CB8883E251F27428ABCD4A466617A402C2B5D462724252E264E5044456382B1
8AB57A5B596DB378533B56519E73542B1C22251D1C2B463B46976F8999A886ABC4D3D28B
6968585D67784E7ABAAC937C9C9EA5A3CCD6D3C0AF8C71515151B9A69F2C262E415F8191
63453A526E76A461A89A8B98865F6C6169827F8B8BD8CEAD868586777567573B3F5DBAC5
9E6D5269687D6E5B2F18196F5367A54B2A2E2E37357D96A1C47B5938
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F6569585253
56515C79576081AC67383016115A6B569F6B4C7486757B9FA2A6909C7340352C261F1A15
13191B3A5E7B7A7C808E618D9279AAAA9B2D15131515151515171F5DB3B6B592844C4745
777D4C887E45372C3668733C282860A3BF9FA198D6B2AF72627BA3B6AF381C245B1F1C25
9873393A3E49AEA2918A584F79CACCA3757CBAAFC0CACAD09F52413F6E93402C302B4093
734E768563B5A33E51706F6998DB98B580888A2B28405A4324252E2553554A24233E5296
AF653B36354CAD9E5B6A7C944D534E461D1C1B1A191B55606AA7B28E8C93AAB6CAD58856
504E6460718B95A78887AD896C606981A5786FA0C6D9D4C6B9D0BD65A02C23282E3D8155
443E4D805D705D6B6A888DA05E6B62624B565C74BED0857568463932333634334E87B099
AA63354C525839475A6382854C77AC4035322C2D35B684A85053B58E
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C4275603952843642845B565246
403D8774603E3A3E7F8537152A783D4464372D21345D7EB19A8EAC6C5F7569575550362F
2C30576C604B4F5B69AE9F9FBE7F7ED484201114131515161614151F8F535C88A890544A
595C956527262F393D383F6D91B1CFA48A8A888FD8C287515056519E8679221C55371B1C
5B6D59332F3786A694875E6D9DAF885942353B8397A5AEAA725237323C86AD6732375CB8
A1757F9276A5C7B58167579E8E8C9A74B795633C2F4F533F241B1F565B48221F1E30477D
763B1D1D1E31539B52405B65524760552F1C202D414946686570BAD4D1C2C7C093CA603B
2E2D344E60A9826F5E678CA955515E5C83776BBDD6D9C4B9C5E0BE95CA6A41343040777D
72678A8EA27D4F5E6D8DA2785A754A3E3B41526CBEC4652E26252A2F3533324F6476B19C
48514B5D4E393637434B78918293AA392B282A327AAD936D397DA18C
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F33764C474F6D
60587A566B4E434E334A7A83A257467653232B2B1D1D31A5ADAF999174686D7E7568655D
546C5C5F5A5859524B7EAA9AC89463A17F16141311111515161817176F39316F8CABAD93
829054241C1D1D1F22263335A3E0A399B594619E784C6272485751678973401D25591C1C
2F6D5156473B9677525A988B4866392E2D332B427C849CAE66735A3A3241A2B28476B6DC
DAA7AF916483805743449A9550477D9266896655767B7C421F1C485446241D1C1E394D84
6A3C1C1D2127273C8E3F6A5E6C32585492575A5F605C5C5569829ED8D4CCCB9D75B45D36
27263471B88C4A4A32537E9E595F6789A68EBDD6DAC7BFA4B3C6C8BCE1BC7452505E7B81
6E64706D8688786B5C948E473B6361404246538BC7B2692C332D2F364D453F5776A3934D
3F2F55543D444337302C375D6C6879282926263AB08CB98F85644346
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C4A434140
47958E60453223292A1F286AC548418F391D224E3B2731815C7A704C536F77575B7B8D9C
9581737B7560676A84C39866BE64504E7425231C15141B262A221B192F6F304A5579BECF
9B773B1E1D1D1D1E1D1E222BAE8C7BB1BE67825826372F4273494F4E6C846A23184D2C19
1D6A3B484E7BA857474051A8763D2429292223224C6082B67C7AA8B18E6957C39DC6C38C
A4CDA9C1C3C1B79788B37E7165626AA6BB999FA9B9B8BC8C5C7C76461F1E1C1C1E394D8A
65461F282927252B6E7D8C63553E4B7BB54A5B543F2C27272C3FA1DBD3C9B888A4BFB5A0
8A8EAFCBDA6E2962314A7F812A29325B9FB0CCCBC7AFA661648ACACECF6F4E44413C5A87
7D5E4C435089A392788D3C39445E6D4646464F9FCC9DAA4A3F3A3F4E59628AAFA7C35340
36282651243F5695573435627A4A8946372B2A7DACAB994239373A46
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E7E615055
51988E563125202033281D53A57B74C93B1E1F26426888614D6AA8572C2C385D61644C70
97504F49414F4F47537A9980D0A05646574921261D1A1C1E1B1C1B171D507E514E4B5DC5
8E321F1C1C1D1C1C1C1D1D52934A6EAC957D69281E212F28396E53505776795C1B374E1D
2496644F77B6B793695357BB462420231F1C1D1F3D556DB9CBCBB1855D7A6DC5D6B96B7D
88B0C4BFBFA49CA2CED74D37251F4F9CA899C1C2AA7D8088B7DB79211E1C1C1D1D305B82
5A9F63454241444C61915B625A71AAAB98415B3A261E2220212757CDAE9EB8607ACAB485
5E574B68C67C245B3E46877E29273274386E6E8AB4B1A383718EDCE18147454A5F65838C
5F2B3D39575471A1BA812930435F925E46494B62C7B6BBA2837B8B8093919CB7C3994745
3D291F263C3D4DCF89482D569A91B5757D838AC9A9AA3F3438434458
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D874440382E
324D5E582D2A23212D312864A2B2BAAA892F20252A29836A477EB9937A362F23387D714E
A0767B7871442E25324EB5CAB0A2B6906361311D271C1A1B1B1C1C191A4368BF929197CE
BA5C2C1C1C1D1C1D1C1B1D855344598D869E3D1F1C1D28252A3C61534C4C5D765567996F
54657C8EA07D55627891A8BA64372A211A1C1E25428A9C9A77AEA9AAB1B4BCD4D7BD8077
7A9BBBC9B6ABAB9587917E3231564F43B6544B7C47433F406CD2791A1B1D1D1D1D28696B
506739302C252224216B82718C609D7073433E25211D1E1E1E2164BE6C74606091CE8635
2626263B8E9A304E473F5F71241F65423D98A67E5D68444974B1E3D36F3A3D3C4361937B
3E2533395F56839BC2822F302C5EB1AB9A9185A8CFBCBD5B49515E4C555171A1C6AC352D
2B211C1F28494ABD4D5C507B93974340597CBFC3B84E34373E426BAC
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778342D2926
2220497356453F404D4B2F7FA2A6803B6095523036395D4A6A95849C824E4C5D8B7EAE95
C0AC8D7B7275666193C5949B8D5C8999A78E95472F271C1F1C1B1C1C1A4E86BC9E839FB7
9E6E5C4C2E1F1D1D1A1B32774761AEA9A76B2E1D1D1D2B2B242C459A6B6C7EA77E4F4DA4
B3556E958E7D5A3D3F4A8DAF898165402A2026255CC0865C519FD0BCAFA1BCDCC1A29DA8
91A847A2BAD3AC816F83BC9C55281C1F9B4E41505A242723288D9A201A1A1C1B1C337786
54582622211D1D1F4B9CBDB9AF5A684F817636201C1D1C1D1D2681BF55622C2741847C24
1E21222C60AE5C445C2D3C6A304A61318295C3C24B9641252F44B8C67F332F3840578C8E
48243440575282B76E6A71352B4BC7CDD798A9CACEAEC8A97F92959DABAFCADB8A7B4C2A
2A2220213971A3C05B5D82BEAE7873273155C3ACB85A463B3F71AF7F
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C775307743322B28
251E2F4C87877B7F755C5CAEB37F714A3B51787430605678AB311D202C232A497E8F9093
C68A4F3E35323B3E67AC4846B5925F688D9E7A696762533C32241E1C3C8D9C8665425485
734E5244515A4C311E1E6B565D88AECD9F5A2E1D1C1D1C25243161C6CDA49E9B78424E81
90525660627E8B794B4485CD5F546E8674402B4DB37F4A717DA7C0935E609CD2AE664D69
668068888EAE6C45485D81C92D191B1C835C3F3860492624223DAB3F201C1B1D3258A9A4
606A221D1D1F3A7A7C645795A2838E75B57F31211C1C1C1D1C3895B56D3726213D6F953D
1C201E273794AA96B03A387F74915D8692898DA2B3783024273FAEB8C96B34353B414D76
602B3B5C4A55B4593F4B63765F8DC285A2AEB7AAB9A4AAA4A8838C817C84AAC0C287513C
25222841616B9ABD6C648DAF656CB48174B3D7D4A07B96A1ADB75F79
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83724D3325
201E223C4822292F4F627897B885707B4B415267A3A85F4367241C172030444D696F7943
667D36292724272C327D673560A36D6486AE916F59595C5A56535673C4A3948B795B7769
6A2C536471737E856E7CA96D74A0A6827F862D1C1B1D1F3066A6A7828397765A7EC57068
9D4E322F384C523F5D94CA9FA87444436D9484B790342EBDBD926E676C6585D8CF633548
494D6F81A4762A2426313BAC281816178EAF445E2A493F2D2B34BCC89B7B6A7C8381BDAE
A771422D4B6C6A4F48455286518D97B9CA884C1E1C1D1B1D285FA0B5702C29233D608851
21201D213198C1BE716C5489D0CF6D4B362C3F7B8C5B23293974CD9B6F9789372A303C75
6F2E357B58A686272B6E6B8ABCD8C3CAD6C3B2A5ACB2C3A19AA6714E524E578B99ACA563
4B394B78766581CB8F7E84ABAAD0CBB8BDD1D8A5A0484979C37F5E8F
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D18933D636E48
271F245270807C666F907E59958D787D81423E4C8BA3885B8345311D1B1E4E75563D344F
37693F211D1D202634477F443C7BAAA18A554341526058545A685468A8BCBD7A96B9934C
481D232E31395470849DABCCC98755634E4B7D2D29576E6C5A37342C2B3A75A292A3ACAF
BF763932293139285CC5B15240677F665A5DC3CF602D60716D7C5A50545574C9D1752D45
504E7D62AA76272120282B843917172CB4D08147322660503182AF78755776B091A4B2BB
86AEB18B60443D383E547A342F655A9EBEB09D85727E818A9AC1CBD972302A26385794B6
9B866D7892C3C6B174888599A37B9E82655466AEAABD9CB9BFCED9B425289AA2444876BD
8F4336A7B7DBBB897D7F799CCACB939BD1769A99A8C5B68F474C492F3D51545D8EA0AC98
919F907068597BDAA9546CBBB9DBC3C4C6CF9F896A7A5D6ABA779B66
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B472B3683
876B5F625A541D1917191D2639A45F76A7B07D78B36EA1A6A64F2E293F6B55413C252424
495B5D3D1E1A1E2126346B755EA6C8985A463C2627353E454B5163BCA2A4C7B7BA7E9FAE
621C1B1B282928303767A3D5883456574B253B976F42271E2022252426242648BFC0A4D9
BC995D3E31212D6DA57F465752525770828ABDCD918CAC695E3C211D294377C5B7AA5E3E
44609578805C301F2026235759172E894E39854F2D28245879B5963B2160C9B9AAC2AB9E
9EBECF868582767891BA31253A7C574156BEC3AC53524C4D56A1D6DA972B2827345EB7E0
E4E2CAB3726A8295B6C1A7C77148496884A9AEC3CABE966483AFCEAB1D1D35D2D5AF9DA1
9EA18BC1CD6D566A9FA09A8A899C4C3E81A292675FD0C3B0877C744B33385860666F767B
95B2B5B45D50AA5982C7C1B2D4CD9C787B857D5F405071A0C1C65A2A
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD8333774F4D3228
798B322146661C1617151615155897446CD1CB907EA295558F6D647E5C35282626252421
324F7242371C1C1D1F294C90C693AA9B4B3A382F282732302F424C68AF909DB3CEA67B39
50261C191F20252C2B2E5AB77144564E4C261C6C311C1B1C1C2025222524388382BCC6DD
C1B4A56C6384808561261C1C1D2833435F94C8C3B0CFCDAC4B4F331F1F2A72C5C5B4985F
69909AAC684C4A282729284B73356F4A441A23594C302A2075BB621D2243D5E1B08F8F85
8CA5B15D76A0BCCAC7BF483536683D273BCDCBC4772928232DB1B376C34923273B7CBA8B
6984ABC1A35049ADC193DCE0753C393F4B639DC3B19EA9697FA1BEAC2D3F99A591A7BEA0
7DAFD8B18881685B536C5F4A453913101A4697C6AB93613739456B93A8858F8A87796E6A
849592955573B12539D2DAD5C4B8665047423F785C6F7B9BACBE481D
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E41475C81
AFB66646676A5146371A1315141B876452C997473B5BB6785AA4BE77584133231E1C191C
1C2D685E352F262A253270B4AE7B79B44931302C2821262627292E42AC9DAEB9A8BF6E24
2D5327191C1D1F22212552BCBE79817672301C66371D1C1C1C1D2725233A655055B4A7CF
BFC9ABB8B9CA813C1E1C1B1A1B1D1E282E52B2BD80BCD1BA5F452D1D242972C3889ABD9D
92849E6F5D555343332925649872371D1C1A1A1E4B49403B68BC7B3B6F78D9CAC9CD9A83
779A9BAC91563E3933427792887542357ABB90A9C1835D2C75D88C4D9C953E2337659045
3974799F7CAC98B3AEC3E1D19E3E3C424E6389C7818387C8B0AB7DA4C7B1554252403668
99DAD1734A415071959B7B5F3B130E0E102D589BC9563E1D1A1D212F97312B2B353B6177
ADAFA78ED5DDCA517DA1C39058272B2E4863705F9788A6A0977E8444
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179B4BBB3AD
C690B2995E42413B3C483E24151534AF9DD1853E53705A4258955950515D655C57564033
232036A992878D988B8BC8C0C6B4B0CEBA6E3B23282B1B1E374C5E4C795E4B898A4F863F
282A451D151B1C24375B6FABBD6B675E4B4637766C201C191C1C1C2D3E58485464677AC8
A7A66F524EB773221C1C1A161C191A1A223892A18B68B4B42F26211F214683B57B6D8E6F
6B6D926A5252656B4F435D79668024161715171717355F6A9E639FB595B27A8971976B4F
4455768F844828252231334F71899BB6D6A64C58A1DFDCC5B5D8B1525BCF70354E965E1D
1B2726251C3BBAA5D0DEC689989A7C684C41509D98A0BBDAD6576CCED6A45638201C1C2B
5EC3D0B0897E7EA1BAA3B4C190391B17132061B1A466311D1C1C1B21571F1C1D2124346A
6F82CED9D6D4C8CBD9A6AF67241C1D1B1D1F33A4C7B0B6D0B482705C
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B767A799568
9672587797A26941433D2E464B2738CCC1D2B66C716D2E2842AB864B33333A46584C4C51
595663A9766C513C3941A4B4D1C3B1C3A3C2986D2920255067553A274F5D282D78776681
45383F492A2E505A5549426B90BE948C8B8B8CBDC96B35201C1918224D4842477E5183D1
BAB0763A316F51231B1C1B1C191B1C1C1A28706FAB648B975F231F345C5C415A79646340
3636426C4E5B4A51928463403C545217151715181A17259E958B7AD4BB77794230544034
403C3D62618D876D4D5567A6B07D6952C0A34C455AC7DCD8B7CDDCBE8ED8BE74968A4016
17171715171E5753D6DDA76565B57A5C675C659F8B59757EC7C5CBAFCBB142251D1A1B1E
61AEBCA15154659CA7A1849BC8BC855E51869E857A7C2A1C1C1B1D291E20202725232C5C
87A8D8C2A6946EC1DCDFA64C1E1D1C1D1D1D1D5BCCD2C5D2D08C545D
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A645C766958
925D382C2F447FA9572C322B339E75D2E07B80A59857417EB9A47D9EB892553F4642382E
2D2F8AA1A23D4E5B3D495BBFCDD09393928098C8A67F9463311B1B19224127253D9E6D64
833E354D656E5D564F443B43A7C3806F706A4D795E5F78633E292734253B405D7849B1E4
D396672F3B434D471E1C1C171A1B1B171B3DB559AAC5908B7E785661422D293076575838
342F324F7D688C60728B43342F3A6926181617171818278851887CD09064312222275127
2B3D4148412D55A1D6CFBDD7B65F38328A6C574A4FC7C55A34376381AAE3DFBABF682817
1717171A171B4686C3D1B27581A48851342232A38F6A8C9EC4C77C5EA8C3462B1A1C1D21
6FBFC2C1779487715744312E557E3F65B8BC9EA38EB45938292028231C26242527232A5B
D5C9C8ADA0928ACDC4CF6F281C1D1C1C1C22349C6C75AFB2C7B48462
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962AF975E4C
6F965D2F29272F3C6B7E462B284578A1C4BC97B9CEC6C892607C67708CCFDDA1888894AB
B4AFC57D576A545A383355A6BDB14D4044719DC5C6CDCA4C201B1C1C1923391C277B9B55
7CB6868372686340312C246E90B6947164504F606F5A4E637D7581393930364C3C68C6D7
D2CC7746493040582E1C1A1A161A1C212763D1CDA5A6C2B4BCD4713C281E1C2D7262622F
2C2F2740737F6A9A61907C483733576F19151517171A6182545052C4561D1C191B192A43
283039483E27293C8EB73EC7CAA639287970555D86D2641F1F1F254541C8E9EAD57A211D
1815161A152A3FAECFC05125265C6E1D1E3D6C5B4F493083D5D153358DC1803A221C1B28
7AA8BBD4AA4730292E2E28273262282EA7A77E8DBEDABC89816E621D23362C34415A94B6
B9BACAB4BBCDAC9B7D7A321A191C1D1C1F4791544C4C7AC4B8936F7C
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671A6886749
3233575F39221F1F2249A7A7A2753E173EC5E0D1C8BEB5A4A396969B8FA1C1605060626F
86C2C65C4B4C7C936D8A90457D9C322C3B54BABBCC5881A57E492A1D1A1A3A2E1E308A7A
6FC37A43564C527135234D78616C4A5358615F6A91677C685984B88D5A44435199C6C0B6
B9BEBB636B3F3F47461E1B17181A2129619E7B794E68AFBEC8CA6A2D1F1C20455E95662F
2E302C2E407F8183423C757E4C3E457739191D2E485584C39887A49D2F1A181719171E31
422933414C35292E409E928A3D626B3556884194AFD0351F1C1F273774CFDFD5DAC14B1A
17151718193C5FDCD9882F2122305727564E413B3C4A46699F74542E5EBDBE5137282964
45847ECA73232728221F1C1E24475C6CD0CF753752B347302A2F31353C5C4D5F748DB0A4
A4BACBD6D8D3988183693E181A1B1B1D47905F47434D8CCDB685624C
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E5A7B9098
7A503530434E322F405E79AED03818152BC0C4CEC7983B332F333344536E8AA1394B3E3B
3F64C07B41509576AEA32C1A43BF8439355F6F6E967F4141516E7D80603E6B75624984D4
B9CE9089775235387A697F4D4E35242120233B474E5B5E6E789498AAB7A2AFA077AF8A76
68A5C791A952545259563227212243867A52732A1F2B82C1C6C781401E1F574C3B925F48
433633353F579AA96334334A6E6E3842B1625B553E2723749AA9D1A23018191616161619
31422F404D3C292A3C959E301C1C39665AB06B7ABED93E33343F5296C9C2BBCEBED69546
1A151B2B3567CFE5E4831F1D202A706C403A33333739489F7F39422B45AFC96154627B58
2C796B9D6924231E17171915151934D5D6D09C567CA53A39403B425C837D695A70959E9A
8C6C93DDCBD5C735537C5A1B1A1C225F865047404556BC9CBDC96371
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664494F414E
69878C725D9D918F8D6A44304D8E28155EAA727FB37464391F1D222C4F4B4B8A7E473A33
353D9B9D42694C4162841B1B35A84F70565255453945513733353F58626F8B7A66798298
D5C9B6A954301F2032A161494D21201E201F23212130425F74B1C29FA8D8A443376C5F4B
427AC7C7CF4126232748463D34517C645F623C221D2A6DD775C2A98143395D3C4091634B
44312E2938738DAD885C412C317D959EB2782A1C191B1D2F62B4D3C07E25151617151816
1A47513E473F27293A9F421E191C1D3487C29182CDE191808287A19393AEA9AFA3BCD49C
382B415D938E9FC3BFA2432A242F7D484033302C2C2F4CA14B4D3E4A528CD6B68A72514F
3A7A6C78632D1919191A1718151627DB919A918286AB6452434C5D8791A04C86827A605B
5D5C4CCCBFCBC12D254571331C24767A4E4547454C98D0957985A667
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C51888057613B312727
282D486294C2CA932C181716184E794C827B4D2E43916171512D1D1D3343525285412926
1F296BC04B3547354386241C3B872544795335352C33354C432F3E48453A427F544B4442
98BB9A753D1D1E1D26889D502A1F1D2533425A22434E272B5FB7B9B8A1BDA439212C7145
357ACACCB287737D818E7484799B607B6230311C285EB3C5B4CC9F977492855D684B595C
4F453F5E7D5A63BBCAA39B8F7C80C5B6C03A1916181D1B1C5EA1BF91A87B291915171716
151C5D3D3F4E412D43A62B1A191C1C1D548569BED8BE7A65513F475B5FB48F467F6E82D3
C1A3C39A4F485EB8A23A615539605C2A252328292731617B303E4F486484C18898C6AEA2
8BBBC9C599541A1A2117201F1D1F79B15A8690969EB1AF62584D3A3A3E9CAC63443A2C44
3D5684D8D6747F3C21256C69368D724C4A3F444C70C17D2F2E3672A2
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258332A2423
221D1C1D4388C1471B171515171D64C9844A251D2251606F726D592B2B444434497E2823
2022329E842B433A338E6C457B8C4942324C4A2C252A2C2B43472C2E35302E725345352F
779E78872C1C1B1C34788C7E9482545B523B302D38535C2E4E65799F7D7EA669281F546E
6AAED0E2D0B89F9BB4D1CBB2CEACAC5A3538487380A475437EB2BBA55B839DCF9B1E2178
DBD9D6C99F8F8BA8B866605B709FCED4D39C231615181E3E71D1C36340546F3718171515
151820613A403A2427512217191C2020508886BAA95344424D4A535F8BC08F4C56896163
DCE9BE4C484555BF8D676B87A5B25D2B1F1B1B1F2343843B2F2A36477EB0AD6D558FD2BF
C6D9D5ACA1491A18181517151D69B765635FBBB497A6B392281F212329AE6035302D405B
8FC2D9DFCC66427C2823627E985C424E56737B3D32514F26282C346E
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C2C2C2624
211D1C18164D6D9F1B1517454D3F3EBA65291B1C1E1D64466B524D80431F24373E5A4F24
22304190C57D7573689A8264BA9F3C29251B243C452B262B2436431C1C1B228A5C2B2727
5D8B5394281B19195F61756F473A2A27261E212029253C80885350A08B9774AA493E4DAB
C2C0A586AC9C869ABAC5D9EADBD1CD672E274CA89D5F382B6C97998090818698912B4384
8B848AAFA77A7B9EAF808B758CC5C981507E983E1E37566294D8D4865337354A33291613
15181C4A415B391F2D462D191C1E212A47BF62D05D242323221E1F24395392424B54998B
C6E2813E384A7ED0AB82B5A39AB2AB794B46505C71BDCE3424213A597FA9BD7743A15939
3D7E9754575C252E281918194DA96A617957AEBDAFC7BCBB9E92939CACD8989094A6BFB3
AEB0ACAB93A1418B888099855947669CC6A746231D22402A222E324A
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A8195433292523
1E1E1A191C215A706017152F5F4455C5742C251E201F396B39262B46501B1A1D6890BE84
6B6A5960B3949EA1ADACA599C7C84F1F1B191A1A20424A2D25283656464462C9AB2D1D1F
58974B73421F1726754D6E371F212420221F1C1E1D1B205B86A9715AA2BCB29AA6A1BEBA
957549363E807038415F8E91D8A58A9E75A79F7D5A1F1D2D91AC4C2D529C989CC2A37B7E
89A1BDC6AD644E9CB349414673C88C5A615573C5A669848E6664A9AD595E3632352C2217
18171634758A3B2B2F553A1E1C1D2034817380BD2F1D1D1F1D211D1F213EAA845B4774BA
D2DA645D7E693951D6CABDB3A39EAD935C4843424A8F7F63212A3D47676BD0A58F572B1F
1E2A7F505176282A302D1D668E58605BB4924B5CBDCE58524349686654C18389806E5C60
483B6A6562736B65C1AC70675274BE9F6A3F26201D1D2C2C272C3266
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C3C2F2824
201C191716154749926526365D6D8CCEAE7F6B554F4E56776E502423403C181A3B7BCE98
91B1CBD5DCDBD5D7D4CABD9B53937C2A16171515151D4F7A534A6284A0B1C5CBCDA5421A
62BF4F3E7822175064495F23201D1C1C1C1D1D1A1C1B20514C7C9A81493C7798C7D1B284
4E4B40353439797934389970BEC9A4A4B19C472E283D536772BC5A213380B0AECAD3A482
62678E756B4E4B79434B53638DD167432E3C8CC1E0C85E3E3C4346906D475E452A282D2A
1A171B56CBD54123284C27201D20274CB54D998F1F1C1D1D1F1E1D1D1D41884A474F64AA
D2DBAA682C1B1D6B8C81AEC7C7B787B88043262525586A7147323F476C9BB8A22D221B1A
171A5574474D3D25307D989C5B488199C5733D6DADC78352433E252B5CBD734E3F332622
1F1E325E8D4B814AA79583765A6A543531362F201D1D222C292D389F
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A27448739403C342824
201C1B1716152C7141A29F9E8A899DB96A524E4A3D393B3C3E415345434B371E2F3E952D
263769B4E2E0D79B92857E37272774711F1E233351776B6082719EAC95725F5065A3BA87
A8CCA53C878C3D8350532E1E1D1C1C171A1C1C1D1A19244F477172A588859DB9D4C1B4A7
ACAD9539292B38899375B97F6ECFB4C0CBB086796437344C51436F592C4CC9B8BCD39E75
5655512D344060729E7367464565715447236FA2CD9842382A1B1B25816149694D2C2338
4D797B76B8E6AD6472967E675F7287C4C87ECB651C1D1D1D1E1D1C1D1F4D3E26282E427C
A5D35547322D2F7A58465095D1D3868DB8422320203F514B603D508DCDDCD7792220223A
362D369E5944805A8AC4B272454F53A1C8964985B654ACC29A4C5A513A693C2825252424
1D1D213A51614D6084BE9E713D383B30303B331C1C1D212728335CB0
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B7182242352723
1D1C1A18151524855D83C48C8886CB975344363943392D27212630526551664E3C5F4F2B
393F4969C0DBC6668AC7A93219152999AB8F7979593A271C2D4C69956D40232321499CD4
CDAA92A0958CA29D5A481F1D1C1C1B1919191C1D1B17384A6065585A74C28674C5AC75A8
C4D0C46448473D59C3CB594E63A4AC76A2BCBF413C4D3A25222D3B707346ADC2C8CC8947
302F51727C694146812B7079574D53605E4C9F5FA98B341A151515162D8F48595962484F
894F2C2D99CECB9161746C575F7C809FB4C9D97D21191C1D1D1A2021214A2A29272A426B
78AA1E1F2C468054634E6D7B8C969D8687962B1C1D3F4E5DA3A7CBCBA193B69783606152
434353849A7DBE8663A89D8D5F608E746B7F64999A3855B3D76C2C1F1E3E3E2729252523
221D1E39406F467654A93E603435492F2C3420191C1C1E2327348AA6
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941585C3320
1D1C1A1A1D27369593A9B5A296AD9DA4533E322E2A352E23202D3A485098A39967835154
44322C7878657EA892A48E682716168994403D42281617151516224F8D6C3E1C1932ADCC
C88B696A75BBD4A6795F4B454032211A19171719171C525C613D2D334F7C9447706A3148
77B1917593C4BDAAB5918A6F424DAFA8AAB4A75F3D1D1A16151928315EA48489ADD5BB68
6F71885D342B26288A603A2E394E539753849A7E897F15151515151515318A434F4F6090
813129665259A4C8A66B5A5863534586AFE3BE924D261B1C1C1C1D1F363A2727252F7CA9
9DA41D1D1A3C728AA4AA4E374D4E5C766A958A30376AA3C9CDD4C0562C3C7596914B433F
4347464FA080C3864EA5A1A19F75523947638CBB823F4370B4321D1D1D33462525252221
221D1E2D3D636656608C2B6D41364124262C1D1C1E1D1F27365EBAA8
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042734D4B3B
2D2829352A242C61BBC8B6B294B34E8A61312836302A4738202228363678B18A83B24C35
2932684B33685A4670A364455429177A501F25221915151515151616348F986A74AF9B87
9CD2CCC5A77CA9CEC46836212950765644271A191C3D7F72543B211F47647EC6464E1C24
384D4F222EAB93587034283BB2989CB48A90876B3E1515151717201D2564AC9FB1E7E6A5
4E3F43443E3928326D231C1D1C1F33647653835F657D16151515151516155B8541428AA2
8F959558442B648EC3B74F482D3D6FC7D2D8959A6C4D41251C1C16264F312E3E63747586
BBA36B351F5847546B763D2A4C53431F587BA2C9B09AA2CFD4D6901E2F6F8A9F96634F45
3D424A54A3AABDB88398C1B678362B3D3E4F9A957244425C8A211D1D1D2A2B2625252321
221D2525344997539EC470B25037311D22271D1C1E242D508CBAD0C1
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D83575C60
607480787477818AC7CACAD6CBB8507E84645D4C413652362C2130404B6A7C63A1714D3E
55643E46523579784B46899D58493080331E181515151515151515151734BDC385483938
58C3D8805D6693D28C836D5A311E272F384B5251587AA16F4921231D1F4A4F8A5C3B1D1C
203C3F4F3C885A485725261B6756608D655A6B47501B1515181F1C181C406B9177D7D178
29202625443B2B50341D1D1D1D1C1D298B5F6B51518819151615151616151E8A5573A987
ACAA9BA9B7616D8884ADC798A3B5C6DCDBDF8F8B834B5D6046322F525C6D6D6D49404D64
9DB4B74D6152344F4F51583259742419217AB3BE8C8F89968A67882B4C91B6CDD8C9C1B0
8F6C4F53B58AC0D18FBBD9BD8957606E8192C6487067425D971F1D1F1D2A1C2325252523
201F25283262CBA8A7C5AED17A4831212226292B475488B5AA827DC3
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E6C674E49
4A504B4E4C495EB1BCBEB09EBA9FA4A78D5B5C5D68804A362F35413E4A7C747794353356
5F4A5D481E1728505550446799A2A19927191515151515151515151515177DAB5C5E6B8F
BBD8E0B0B5C3626488888A50675E29191B1D21277B9CC678231C1E1F224041659C301915
171925429A91513E3F1F2A1949272D59554D5D3844391A19201D1C1A1C3159768CBD9645
2E1C21252C394352231D1C1A171C1E1D4784595D508B1C15151515151715173FC1B396B9
9B7796A3A5507D664B489FE1BD8681B9B8CC9B70718E5053617FA1979170492A3744384E
7D78467CBD3C393F42446671A3782119339DC28840384559695D6498ACA6B7C3CD928C7E
9AC4CDD0D1DBE3D8D1CFE1D2BCA89F978E98B85257814E6690211D1F2027151F22241F1C
1D1C212345BFB4CCC7D2C2D58D506C7D7E7085B9B4D1B87C4D3E76A1
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C4582339617BA0
BCB48184A1A3A6A4C1C3BB7A6CA693C9894A36313F4677474047391D1B2B67BE6F326849
3C5A4C322F1B191719234E4D4D5DD0A3511D151514151514151311151415686D7E918B81
94CBBA3F7240293852A4928F61436C52241517217CBED0BD874A32211E365A86BA351515
19171B1D62814D50231213153920245C7853543D363E222721211C1C192664929FB88D35
301C1C1F1F2F5648211F231E1B1C1E1D2978638684AF2B151515151115151643B89ABF91
398A86919E4032395E488DDA60373A5DA4ABB763578E6481A2A08A97815C493D4E3C2F5B
772E2C40B0C2CD6E485391D8DB8B5D276E63913F2F3F3D42527486C376AAC3848B76513F
3B49658CD0C79BC4AC94CCBC9D60443D40447C8A4853936E9D28191D1D19161D1D211D1C
1C1C205BB88C7DD6B4958CC27983A599A3A5ACCFC78E4D343259849F
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B2C57CFDC
D7B58C664B3D3A2E977E63558D8FAFCFCE9348251F1E254B542F151718208BA4627D4645
4C2A202534421D1717171E37574C92A766501713111311141514131314217A392B3D312B
44A3713C371C1C1B2555AA5A6D7137426B4A578EA99662616A6F6C68669CC96D936E1717
1615171C4D5F4A5417101510381F238EC07C957F453C393C221C1517172168AFDECB9233
20161B1921423D2B291D1C171515181A2151886C78CC5E473119171515225CB1947BBB99
585C384F7F1F20244A64B9A360303E4A867C97664C56526F6E758180463C474952513E65
591D1B3CA2D3F0E6D9C0D0D9B5735E7D4E579B3D2D322D243EC2C7C47B6870374D7B3E46
4333333FB0C46FBA94637AA45F312C3031344A7B53448B80A2321B191C191C331F1F1D1D
1E3393B27D7095BAAE858DBD998ED2AAB5D1DBB566353D2F59728445
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D4185B47D
7551362925283849A7693240484A48B291618A98988789AFBF8847404D6DCCD9C6713A32
1F23231D212E23151715151627677F879A5C5E1E141315171412151C31849D2B1C26242B
4394634A1F191A1A1C1F49713D577D52347DC47659774F4E5F6564726A558076A8A63A19
151416153656552E2A0E1514392F8DB25B436838578DA5684A301718192058BAE5E1D568
3817202B413D1E1B1926251E191B1A2B403E5075B9E0C55A472D171C48908181603B5CA8
A5766D47792520252C607646741D203043524A5F515D72466C7959441E1E1C2A394C5EA2
62491A2E92D1CFB6AFC1C8C5414F9D7A7586AA50363327349ACBC1C1A9812F2328544D29
3C597B86BBD09BAA4E3C4B8747392C282B2B365074486893A3451B183C6B43735C31313E
84A27D5D6F9A92AFADAA79C1A7A2C58886C5DA597C7554777D8C396D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165564E4F46
434D43413A361B181C534D2833878BB0D1812E3489D9C8A15D3D332629325FB5D26A2B22
282427221E191416151515151734708484A585B28B676F767A8A8391B7D0CE552224252F
4D9A524A1C1919171C1C1D5D633546627A7C8E454D837F533628202C353A775F62A7836B
3117171C3D57601C1810151445979A83405C2A1931519FC1AF86863C2659A0D9E0E9D5D1
85352D274124191C1A1E36221B2A312A221F34A9DED9CBC2B98C7D84A2886E6242284267
7B8A99B7703E26262B35252655191617225E49516F86AE61586E60321C1C1E1E26357BB2
8B681D2D94CC7056597964598B654081AAB49752482D41888F7CC4B7B7A335262129592C
29359D9084B97F9A3C323D53403D30292A2C35425B8B8C80AD7C2F698630282D51767A73
6A627981A1A76F8A738E7CAFAB88CD9C7ACBBAA1B7BEBCA08938714D
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A4B453F4F
5457301C151715141314474838595CADDCD4B5AAAD7C4F4C5A433031312541A7C8B12B1C
1C191D22221E191615131515151A5784AFD1A8725F4F45413F45576B85AACDC059251F28
598F603218171717151A1C21685E323C639BB78B5B46441F15191B161619438D5B656D62
80692F1A408C5A1F100E153F80897D5A5328151116304E4696D2ADA08FC1CAC8B1D2D2C1
CCA4474F31171717161918333424181C1B1F66DDE1B58B8792C7CFCC97B4B35E2D343746
5A69825453654E21282F2C2252191616213D6B72A6BA8DBA7671782F1E263B5587B3CACD
764A4E6BD2C59096878088AB9D884C51BABD744E698BA7957E9EC5C4A5A780462622394B
2D2B6A867B9C9488393440391C28383530342B2D4073A4B0BDB59E863530426873677999
90806C75919A9489363967C5C2B2C9D3CDC6655C67A3A9A36D964F72
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D835796855D33
223D241D1615151310111047564869B1C4CDBCDAB55D5E6C7B7D79746A687B8B9C9C8F33
3D2C1C191E1F1E1F1F191D17171B4E7074B1AE894A3B3B412F3743393434579D92653D43
778E66231C18181615171A19218E614332A2C08B191C482A1716151A171A264796688B33
56627E89A5953213102D664B399A5C653C1615101417464A315BCBD6D69F956A5C99CEBE
B6B7B6BE1B1815151516152D2019171A1E5ACDCDD9BC899CABADC0CDD9D98D56313B4243
4A4C3F63503C5F4C26252F295D1A15162B2D88BFB4A984679CA794828AA3AE825F4F5A90
703BA6B092BF80736A567CA093898883C1C5A77D7469CAA16DA9A06C709B92715748355D
40347E958C9AB2893A3247341D1E2C3B3232292A3B8EBEC8D0CEC9758AA6A18A63595D6F
95AFCBCDD5D8DBBA8A8EB5CCCAC3D1D4D7A75E8598B6AEB6C8BDA88C
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A558A9D3625
1F3623191817151511101224899294644E59ADCAD57E555E5F4539374276C78897989BA5
5E5D54231C252F292A27341D1B1C4D756F7E5B8D8A473A362419191C211D1C4A968C97B0
9E906724171515181715171A192C8A563D727C8519183C311A1515151C1D151755979A31
2248567ECE94272F635E2C246CCAA178171511111413375E6D425DD6CA956135324EB6C5
938AAAB443171515151515461D191A2F74C1738FAA78436292B6A6BAB8D18C7246493319
1D381F1C40563D556B302E33591A1717252386D4949FC69BB1C9CABC8E5E402C2C35466C
B7A08C95B96F625B5A687B7F98A5BEA3BDBD6C527AC1C6374C794F1E223FAA5A4D453D6E
636A98B1C1BDC67B292D3C341E1D21383C2E2E33457BC3CFCBD4D89A85796A838C968481
78787B97C4BEBABDB1AACADAE9DA8DBFD4D1CBB8A1C0AEBBC2BE7660
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B73682550775625
1E3226171515151313161E326C7A654A3A4983CAD1992D409A8B6B4E5D6EB2B36C4A6384
A9604981A55D536A9C6B5841352F5F8873775D523A29352E3B463832312326306BB4B589
6598494B1915151515151517161748945146678617172539191A1C191D1F1C171D76B672
20203E3163C79E7C45395C6E7276BA822C15141310152475B994A3D2CD7E3748436A8DBA
73637F70A5732315131D3B704A424590B85C379C6A7ABFE4BC8697999BC7896F4F181517
1735201719264944657433506E28191B1D418C8EAD99D4B8ACC2CDC354352B252F322B2D
C6BA6C887B7C433B566A76AAB1AAC6DC9083A7B9755A8A2965662D1C1C2D6E44233E6867
8B7B81909CAFC8763A31402B1F1C19293B5444464A62ADBBB9CED0C7BF8F806852424241
4B50738E8389874156B5DDD4DAD3A0A6CDA49BA8C3857AB7B6BDAB59
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868484D7B2B
1D2C3017161515132E3E424A24171B44583B77C4AFC88D53485A6F5A3A20296D894B3538
5E9C819DD38F5E4536303038455983A78F808756201D1A1B16141D506E3C33375A77939E
83903C2B482915151816171718151B567E5267792D171946331C1A1618171B1C1931DCBC
4E24275CA9BEC7B2C09C6579794D2C3B673B22181313189AB6A3A2CCC09B7F8C989C9BA5
6E5252779093AB5E4F392924252E82B8574C76AA5F8AB1E0B55A404164B1834933171514
172F2E181819214C516383AAB673352C3C8D593B65CFE1CF8882A2A79A503B3C2D181739
AEC486675D53557E9A999C9F9D828FA5C8A8BE9455346C347C5E1E191B2C51641F238A9F
A76E2C29539FD9A25D45351D1E1C1B1D1D3DB7BCA9AFC9C2BFC3C98F5D433E3C3F3F454B
6A6D48283A386933408BA879936BACD6CACEA7CC76566B8DAA787E38
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A38856445267
242E361717151C1E4C5932191515151525669FC6CCC7CEC48B47436A2C1A151D43784F4D
3953B9D1BC8C7584645435252227787C89A19B60241C1A1C161311351E15151E2B315485
A59129182A452818151418171515191C7776746F661C2592974F2A1D17181A1B3871DDD5
AE9F9DB69EC6D6CBA18C733919181B1A1F456284772E5592BB824CADA087664D403E688B
6E57505D918673BCB1403A435197C86D58735F81552D44B57123242436658F5232151615
15222C1719181927A2C0C5C79AA3C9CFD09C363266B1A78DAA826AA489775C473D3B394C
8CC2AC54687E9B814F3526285C346BB0C1A69A5C836083876A351B181C25436A3B557D43
3894818BC2E2E1DCBA952D1B1B1C1C1D1D2D4A41518AB894ADA4AE8E322C2F384861584F
2F1F1C1C222F5E3D3D6A93606D3C81C29EC9D6A0342D354A76907140
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A7C5D4957
79858B3537291B1848241D1715141515151B92C6BFBDACC2411B1C5D965D4B4938386A52
625662C074352A313441606F807BBAAEA3765958321D1C1D19181E1F1515152B201F2256
A68D391B15193739171717161617171728A88A7C8268545D424E4D4B4648577B797996B5
D0DFE4D6CAD6CACC9E4A2E19141B2219151B225A94C4BA9D88C7D1CA6F312A2124262618
536E5550566C3B6CCDD1BE8CBDDED4967D4443722D252890663C25202B41987536171715
15151F15161619508AC0A090A6909BBDDBB84F578598554B66979A8D5E545760272A3E63
7677D8958C642F1C1D191A1D48625E6EB096505DA17570AA67241A1A1A172756A97D3931
29B0B88D8FAE96887094361B1719191B202B454C4D41797C996247A5564358584B2F201C
1C1D1C1B1D1E4033383C8B6F7257B8CBA7A7D1923536374862B57E4E
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F806A5263
8C7D656351352319231915151513131313105C9B748652A426191B207085748959785A65
3A414781AF4D3615151515172B7B7DAFAE974360481E1C1B181D28191719338235313449
B39F65301A17182637231715151515151748ADA2A4872816171D2E466F878A826C421B28
88DDDBD9E0CFB68A82552B2015151A191719191E2973D7D56D7A98D7831D293C2F151415
1C517D5B628B8F78D9D2D64E93C2B5CF552C7463232629676472362F353D8D6D55291515
15161715171B4E89633E71A1B9D2D9BCABCCB77D87634B3D2E3A756E40272B454F373459
6C64CBCE6647231C1D1B1B1C3AA262494D6C794C6094AEC17919181A17171D2E682D1D1F
669A4F4C5B7E442D4E473C21181918214257624A45634F6D8C633B7B7C37221C18151A1D
1C191C171B1D3334413A7ACDAA86849E87D1D3C66E3C3E4E7B955C4F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639515D5059
768F75665A4B471D131D17141011141313154B85696D4896351B1410131B2D331E231517
5A3A29317DA654201814151514395B5FB1C676524C46211C222C392C27212589CFA6A4B4
C6C174361B1C181719352B17151415151521A7B4BBAB8F658481795B6C675C361D1C1515
1FACCDABD0D2A057806C393C382E282B2D26231F2365A5B64E4641A97C292C1610151514
121D629AB591BEC7C69CB36C7D74627E88814D262022253B7B714731484A5B744B542715
1515151A325F784828253DADC4D1D6B7ABC9CECC743B24201E233F4C331A17223B616C5E
8A64AA6F5E342D1C1D1D1D2F76B7915B3E2E5F71436BB6BD8E18171A1C1A19203F1C2066
C0514F59412042422E363E373F2F384E6789604337665D6D6A6E6DAD5816171818181918
191B1819191E2D322E3587B6A8A05B7CA6D1CF6B949683707829223A
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958493A4C55
63877E5452572F22462013161513120E12155071726E477F46161010100D0F1210151413
195B3C243C72A64E21191715132FA57EB78D638A8F5B4A414122292E26204D87A5655567
A299AA6835191D1D1A19313E2A221D1C2F686CCAD3CCA8607683746455443E2C2120201A
36AAD088B4A7552338587E9A795352515354655B818E598241293B9D4E35161010151416
13152F80C792C6CC92666E9E93554F7CC1841F1D1D1D1B23734D572C395049725E53602F
151D2F4E5F48342623233EA5A0AB9BAFB9AF8CC142211F211D252F4534191B1919275FAC
945578426C30331B1B1D34556D3A397B684B487191A9C89DA14117181D17191D322361BB
6355502B1A1C1D394756354072C0B5C4D6D487473DA08AA2B8BE814D6D1D151619171918
171A1E201C1D403A345DA59FC1C4949CB9DBC87050679A8E601E2141
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B6F5C5284
6B85783D2D495C301E190E151212100E0E29676393775763761D120F0E100D0E0D111512
1435C398738490AA70291D12175ED9D5CDC39A9DB1A98069705E4C3A3D716F3D52466A9A
9B6C8692842A1517191C379F9A6D7195974331B0A9B0D0713F34362C364255606A77315B
8A9EC5B5BC74341921262C3F79BB8C47322E2F4BB09141514B1C31903B36251413151511
14131747776EC16D372A23419B70664251A1411E1521201D464C50301A202258804B445F
5E5F5051562D1E1E222B6D68725E8AA3A585438C521D20221D242C49341B1C15171C3F70
5E5A67345A3B24261D335057312423443F435B5E67D9A973627925171C191C292C6CB370
5140231C19161C1F485B8E5D57B7CBBBA7A6B5B9CAD7CBAAB1AC49353D471A1815151518
162024211D23424553918955AE4D203AAABE6BA7806F857D2F1D1F44
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B3F445B50
9A91645B281D33543B161117102522193598A375BB806A70A26F27150E0E0E0D0E100F12
1B698A8296B7C68C949E4F3083C4DCBF7A4F4550554F6581745F7071ABBB755C616E4E47
6D96B079739F4B44575953403327303D4C547F959094BE501C283B17171D28343756AE9B
4CA1D7D0C5521F17191F1B1D2656721B151615186B5C2527641A2C8D32273C1513111111
1314123D4F71A66780847A728F342421233B6B3A171B3B26276B45551D192B5952793F77
B34551755C1F1B1C1A387573865D44385B7A517681221A1F25355965533A25171A2E5465
6354632C3E561D413A424C2D2021212D35282C3356B55C4F47565419171B1C3681A37154
361C1C1C1A1A1D1E2D769C5D4060BDA3A3B7C1B0A1C5B2AA846A573E2E433215151B1518
1A1E231D202452487F7046606D1C224DCA7A5479B882603726232F38
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF6134292E8C
5D845D8E361D1C275E582C3F525C6872708AD3B8CDB0A35A9540172B100E0D0D0E0D0F2E
60543226264481B1959ACDD2ADC1D3BC5F322F345B3E4D614A2324329F835644424E283C
6B7193908B71A58F66504030323F5062756E9386BDA0CC952C2917151316212132269172
96AB9ECABB971E0E131B1F27272A4C491A1915175A4E211B6F2931AF421E37191313130E
10151444398A7E4E6134261E3B171E20252D2B504A17173B3C6A4862501C2D64474A7A9E
AE674E2D211B23232C7482605F2C352C345C738AB764323041505A6D57504148525F765C
854D6F2E3062324744413E22212F1D27271F22262BAD573A5C25586F1A19339F906E6D26
1718171817171B1C1F7BBF54464EA5B4B7B9C3C1BAA39B87B39D82603C3147211717151A
17201E1D232B647C6C384B8A251C2D819E534970A5B56C2B36302E37
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865372A275A
775475A0915C5E728C9175643F2A26496D878CB2D0CC622783741512100E0D12233B4A3D
2830211E1F28358A616CCED5AAC4D28EA267363B686360626C43241E407239333944552D
201D3391A9BA9D999B5541525E555158699BC3A686B4AE6C5974542917151A151522A4C3
B85F5BA2BF8B6A1715171F2326262A3B4A2D1B2D654820195F8B99D9A8312C2D14131515
1015176E4D9E5E2535191C1B4A352427262B31386153181736745889CB9994B4A554A7B3
8031201D1F1F2230848D6953762A302B29376EBCC6A8968471554B563E405C4446446181
BF67BB9B8693B8A58594231A1C1E171D212A35509AE0B42F5D712364636ABE827964241A
151B18191917171B2059C8A58F91B3CDC1B7AC9B68676E8763768B9165343B4517161719
192522202868B596634780532126338E5C3F54569C5AA5895B645159
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088372D2628
87495FADA39E5C4F4C75867C7E9094532C29318AD2C3957893AD29273652504C3A281E1F
211F1B1E1D1B1C5393B6E0E0D5A86EA1ADC09A83A4B78F8D433B43374174564A3E2F2E1B
15151751C9BFA9639ACD66382B211B19296F627A9ABC9C5020263B5E644F392F4A9E8096
A34F4DBBA97E6F5B191B1A20242027292A434B7855351917839DB29BC37A5B2C13111010
13133DB397B14F22483D2B3D261E2A1F282526363C62631615367E8FCABB725454699CA2
6C5051514B362E566D7660A47C4C3B33323488D18C5351769D937B49493F4733373950B7
9A6EA686738FBA977B8C8579828A8E919CB8D2DCE5D5CA9080D49556CADFB59B6A351C17
17191618151917193278A2C2D5B99FCA906A47383832373E556567636A433D45321B1A1B
201C1D326BA0A4B56F89782025273A91473A59545B3854B5533E3B3E
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A69138292922
549A4DB988919A837E89B5C4B7AC92636A9198C9DF906A96D7DBC98A54301B1815181816
1A191518191A1D58C19AC8C7854B417FC4D3C26F5DA2968F84846F56285A38221D231D1C
1511175F6D9AC17463899A35181B171B3F537397DBC9454A1715151B2C3F5DA4AB554EA4
8979874A65869C845B201A1C1D1D2122221F24466A372F61B3AE4022628A616A53311B11
1C3F595EC2C65E3A447F7D5B1A151223222425292F42624F1731D2CABB79463F4A8EAA8A
514E4B4B567BA882764C914A393043494367A9A29470614D58819F8D964329272C3849C3
8C8E8D896BA9D3C9A59BA58E73667D7C77727CACCFD082B2CC9F657BDBE4CD9331401618
17171515151716196093367AC4668BC78653352A2B2A2F2D364D5862566B4F4F783F3436
3844627275A8BDB78FAF4B20272E55994948615C443D46811F201F1F
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382352A2925
58D2CDC051456A7A87D0D4CD7A7085A1C3B8C0C1C0B59BB3826CB96E3A201C1819151E1D
1C1C1B1919192D72764BC6B88A5C5B7170C2CF9A8093A3B0CB902223273C422E1D1E1E1B
1F2165D3D2A5D2BA9F91A3B29BAB8C82857B6A7695C66C3A3115151515172DAF7671A2C3
ADC06F172B6FB2A2956B201B1C19171C202D3A83AC6D79B36C60361C2256705E52404D4F
64644853ABB1A16B4C7283864A1917151C241F2939554BA3849DA3817F8CAB86AFC5CF76
5D7C7F737382C6BD415F763B5A23212B378F823E407B836B47515F88D5844728242C55AE
82ACC7D7CEBEB78549455F6A502C3E4B517AA4A37263A5A4C8AC5AB3E2D0D5C669481615
1715171515191E36AF622059A94E4E6D3A3A414B463C2C2C303D44526D60709DC6C19B7E
7665667EAAA59F92B0893B44333A74954C5096734F32466E1C1C1C1C
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E41485F66
6B93D1BEA5635A837CBCCEC5928498947F79795966B0C252433472405B2D1E1E191B3D48
4B484C51677EB89548A9DDD38B47384F7AB25320352C2C32438C562320413F4C39354843
619BAAC6B09C76808FAAABC8C27E6068593E3D40437B8951311B13141516524225244877
5F5E7417194F9DD9B6B6684E4C4444474E5456634673AB756FA44F1B191C486C5D7E5956
6E8B8AB5A585856C56754F3945492E1611245E627784779EBFA479797A847772BBB9CCC7
704144496387C8C88B622C30453D1B2576835842457582865C383B39B2BC8F6C3E2C7E8D
5E8CDACDABBAB48363494A4C5B69586D8EA061424680D9D19EB4E0CBCBA0B9A8AC915025
171515161E4E9BD3A225366E83565868403332282A30353C3C2535496A9691B2B48E8DA0
ADB4A6B5906571AD816E5C43534A9A885E6F51613B364065201B1C1D
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82786A5646
41396EA9D3CFB19F6CB690876A43423D44638364332B405726405570737A67524C76664F
4439312D23204F77B1C777A6654B30305774251516191B1F1D2E6C5C2B63557F67495489
9770564486BD8576704E4DAAC19F3C3E4D231D1E2D4570664D381F15184241211D1D1D45
5541742B1751A9D1B27FC9896F65716A62756969A3B695687C919155261F1E437FA0AFA3
977D8B9CA27A4A2C3664542B212D403D2B356C60604B5F9CAD8E7A7D5F2E232F6C647594
31192637434C8EB4AF3D262D375D2C5676452A2529326369763F2A366F62A3B6ADA9BC87
95B7C77C638576848AA1AEA09A96AECDD24C202E39B9B097B0B6D9D8AC925674B47B9C98
8C412A37917B30666D1C446F77696E7841393F3928282720251F26486F7BA2C3B9B2839C
9AAACBBB5A55AE694563879DC2C89BBD882A223B4342366E2C18191D
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C8056554B2A
1F1C1E4E81C07DA0877A3640413B332E336DBC641513142A532D459C7A7F9D7342362D2D
2E2F31363869A1DAE19F273890552C2B3455190E131515151C1A2252875F80766991AD6A
49382A322C3D70875E4130758B924215372524211C2959706D5B332A433127191D1D1F36
5A4638956A3D4FB8E5D6D6CCA3999191909FB3D6D06B5C6054253DB1A75E69646AD1BD9B
8F715B5C623B19151A3F5F3B2C242A2D4C864C37252A4AACCF9E9C9F742B161F2535356A
74191B233883C8C66E3B24273758987A4E2327212320395A4E70542F1E4D4EBABEAA7C94
B3D974594A54502F1C1C28384B7093A3CB1F152680929439366ED3D657343D669A4B404D
73B2C8D3721E204B5929586E4A88656737432628201F1F1D1D2024486182B0708CCFA594
766583A953A1A238374472CC8C80A08C331D202857594282642F334D
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881403B3220
1D1A1A255C9295579998642A15151313111550AB251313111F5C80C6AAA078645A4F515E
5E5152899BCFCDDCD6C04E27935C3326314E1A2119111315171A1B207CA67B807EAA643D
322F2A191A1D26535D3E2E67664259402C361D2723212B5C49578E5926221C1C2226262E
5E50368143241D9EBFAFCBCC5C525659575E8092CA4F484A2D1F3156751A19654EAF8862
615A453A503D151615172C4C3125355373524B2F31417ACFC67C7F556E6E2D1815243547
AF613A362D337FA4947440292F40B76A2D1E1E1E1D1F224A556C966B7C9C9D828BA5C7D9
DFAE667857707D261C1B1A1B1B1B1C217A4C1774A97173201D31B4D02F282F4CAF4A221F
283E67C46D1919674C45693F2BBB99462A24261C1E1F1C1E1E2330517FBA8E779FB0B268
99C2CBD1DAD78B262E3167781E3A913D4A231E2366AA9BBCB48D8473
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E6536382B1D
211D171B4984AE9C686220131311100E1013126085201311102D9899BE96A8A4583E2B20
1B1B293B2E886F9D7FB3C077A593542C3B5B1517190E1013151D1A1D4C666064976E4848
35261B17151517274D4C32696C39395C64521C191D252A45664B7D5D371D1D1D1E262E25
5359406A311D1D58686DAAD67F6C554B454F5D4BC3912F1517242A3A7F42334B4D483E3F
42342821284919181515151C31292929746954667F9CCBE4CC7E4B2A273B7F33162F272B
79AE627E9DB29A8EB59E7D654665B259221F2022291B162C654886A44338533C304090C1
DF84879598A8A03B1B1B1D1B1D191E1F3183869AABB86B1F1D26A1CE7C3A3C87CF71232A
2C2127569B4C1F9235574C2882BCCB8A291A1E21231E1D1E1C2E628AA99198985853AC82
3D468DDDD8C2C486403163461C4E8322455B2C386E8596B98373747F
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B844949192668834329908934362B24
242F353627578DA0C2531514110D13101110101796711711101F8480AF57604B17131314
15151716171E353C695490CEE1C5664D497C19170E0E111315171A334487A2A290584140
211615151515152230365166623E303765A54D37353F59638D90A176604C3C343936454E
7960486A2F1C4247263462D19A7A6B66616A8B7FA7AE43141317354664BFAF776F61371B
1C211C17194332171717151C353F506385B39D987EABB095AA6E241C1E192C1F1929212A
6E391515216BA0CAE5E0BAA6A9C37FAB727F7367601F171940478B5F391D3E472B29478F
CF8C6D4842718F5C1E191F1F1C1C1C1C2658C56777D48A231B48994347694F665163552B
2731363565B398B84C4B59947982BBA5886A301C1C271E1F35798F909B997A4533335389
6849BDC98B727DB0AE887E532B86A42C216098854A5DAA5D342C3347
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E9030373025
46433A261D499C69B9892B13100E131011110E112BA14A131125698C84783B3F13111015
12141513101729395E6E5466B8D890ABC2BC4F2A170E1414111334533295738F6F4A4B24
15151514151515152523335B694045333F8F7E4946537791A8C4C89B663B495966748594
A378476A2C3E6742242A3DAE232D29243D65421A666781271314617EAFC0655375AD691B
223426291B2C7A2C1C16151836507D867DB87B8FA57A5077AF8C2F151C1C161B18292C2B
701C151517226E5DA0834D423B7152AA5331281F1D1E1F1F2B499C4D431D39633D414978
C7A13F3B33435E8B501C182020231D23325BA8598B6D5B6C768571354E6D77362D334657
4126354559A5E1E0D4B28A5B4B92933954809583562F3F557891A69D757E3B2233592924
77CBA0675661456985A8C297B0D4C3A49D9C926C95A39B2C212B4A70
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581344F7342
3E37231D3E57587A8B76612515111313100E0F11133AAB3C14406FBC61793D4018101114
15191F22242A31536E9084727EDEE4D0C49B6F68623A2E1C1615418B6AB15AAD91554217
1313151013131515191B1C4FAD614B8495B17446473E4A73809BA9BA9A452B3037414244
475D8BB5817C50372B2F6E89191E466660291F31457963851F1845716E74A7876A4A6536
40474428312057731F1A1D37535560516AC29C8A66524C2D4D576F191B1B1C1C171C3434
73171515151F913E3F6D4948446F5F7B341E181A1B1A1E1B215F814343325B683D2B3291
D69D442E34344B89A1331919323639424764986AA12725327188AB98B3522454483B3A4D
4B51343160B9E2DC917641414DBEAA2E23293B669AAE8871B7B78B6599532224351E1C1D
7DCE944E4F57613845727EC9CE8235374F6775A2B3C38D3444625E7C
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A84726C6B5055
3626234C42171B686057585721151113110E101013174D984C819B9B3532748672383537
3D3D3F4245484649515A718AC0DDB9BAC5AF976D594C4E535757518698B9C4D1BE9C2415
141413131313151315192B9C8CB47D9898A758383343524E6582A59D7E96843E1E202127
3660B4C2A39683958475B4A957334A4F1E24232D2F7549609161455E7BB4DDCF5B2C3060
43303E4F2B2431B0A389947780A19B6E92D4CE612A18191B1A2E63581E191C1C1D1A3F46
91171515151D672C3C643C433A7473604940362D2C2D21233E97684B7C56486D414EA6D1
D5C2692E2C2E404770BA83608584676C638FBC8A301F244E9F8A71824B17161E566A3840
4C4762465AA8CDBD9E544C6270927757432F1F223B78C4C5B0846393934328231D1A1D44
AD9FCBA6968B56484A576787A93F2822297E598D8BB191857867693C
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587AF554435
292C5634161430731F3F454B521F13151312140E1312115995A6A367222E889C6C574231
281D1B253E251D356537244AC3D3AA85954B54C2C06D48424B51657EA4C58B7FD09E1C11
15111311151B1919155DB7C2A26060ACCED19E7E5B554C476BC29A72746A699C6649476F
7480B6C5CA947D887E8A39305C8D4C1713111019195238257E521F57A0B7CFB3AA3D2A24
58422B394023269ACB90874B609E79869F94A97B17141717171B336A4F1A1C1A1D215E6C
B21310151517372E2C6238352C79803828272C2F2F353C4558A097806943363691A07C97
9DB1C5982F28342937CE9A3D343B6099D1A8B5551D275081A57A205422171515174E7B2E
383C6EA7B9C6C1CD85497EA5632C1F3C6144383D5B8BA6B7B86B5E3B504B2A1C191B4179
55904B313543499471503B7C5A52636B8D6548A4AA443C5A71502A1A
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E917B6F54
5671331A1729778B1D173A434952211311130E0E100E1155CBA9A1471E364A4A2B1A1513
1313151719191B1B2E6B572CB3A6707361604296865F585A5A5A6E696D799CADB18A5337
3D423F36393D38352F355FAEAE44269EC6C5C78F706C695D3E31544539467B7AA0899E92
B5BDCFC1BDA08A93B64B4E67463D5B60461D1314132C633793855B7B6E83968A6676552B
275F41331D2A1D7F442E345B5B809A97822929494F22151516161D3C66401921252C4CCA
CA482019382C2E24274C3F25338BA05B6367675D5A71889CBCCE7E45412C2229A38C6737
409CAAB57729201B42C04817171522579784A43E276E7A3B34661F322315151515174085
403B3DABD5D8CEDBB5BFCD64231C1C1F2A4669849E8FA6B391421E192931381B1E356D5E
795D1D29283B65A6973E314C39425274B47D707D6BA3909493919281
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74AD644F53
6E713B4E5B594F645222132A454C5919121011110E0E43B5D5C4B5913D662C2B14131010
11141A1B1A171715191F4899C75E2E3E7D8E963331181A212E3A64679FA89EC955277D32
1E191615151515151515153F4A624256C592791F1B181515151118986A58549DB0BF948E
9FAEBBCB815B7A506F2C203C61301B1C273F44271326A597ACA658625E65364359445460
3C257047304E6A945C5653919B624453301315182466642A1515192542743B39375AA4D6
A45F945B784029222446AC84B7CBCF796E615B5250535D6C80B3AC43292924879859221B
32BFBFBAC2B083364197421B2A3A403D3A66B68172531D151E482B1D321515151515164A
8D443279D0C2AB91D0CD661D151B1B1D222E40799E53608A692C19161C1B374231507B68
92272C3240507F92974C316A37384D71AB8A6421278EA24C36323360
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187A6736991
B5379E6134221C182344371824473F52170F0E1325539F927677AAA2994C42191513110F
101715151718161719191A50CA5B2A345D6E55712A16161F2A365472BED0B36C7B334C14
1511151315141415151515161F388264A6643E15151515151411275B332B3493698D585A
86A8938E7A4E4B3A395618235E3421191D1B1B2E436E9FA5ACB85A5142261A1C2839444B
55444CA35862A97653819F72301735551713131515226D80311D191D3F69A38A83B3BD76
83665B709E9C7F573F85DFC67D9CD949373934312A2E33343B7C977A3432899755171517
795169A0B4978DC5B0BB8A4135313A407A90ADD69B2219161A54471A4017151515151315
3FA85874BBA796C9B7A97E441B1A1B2342695B5197683773572C1C1719172255558B6CB1
2C35684D5774553A455668903F314377A192361C266F31191719236D
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767EB2644F44
5C5783301C1917131112244232264B505E2B374C5243404A2958A192A5957A1F14151213
0E1315151516161518151671663A1617274758AD8D5E4D62655A56775051ADA06EB79219
151315131315151515151511111A69AAA9983A151513131511154F361D244A793D824125
2F4C715777725D4D3D612B43241A39332623211D329C64617FCF896A6E5852524F575551
524B50A4A6A290C9AE6B3C1D1C17392E131310131419305B7E3B1C1F505B94D2CDC5842D
1F5CA47793849EC0D6DFC95E509FC4AF5042392C272B272D3461A05D9DAE8F562C1C174C
433428589AB673B7C5BA9A6349597686CADDD29AA6B092848CC69F31402A151515151213
157DC2B5D5DCC4B476404163713526646D3F2C2945834E664F331B19191C214B877AAE64
27538B835E3B322E314396BB644A72AD855C3D1C3163191415162174
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82C658392E
30A898301C16151511110E153A58686F845F2C25262C2B22166B87AB9971934F1F151515
151615151415151315151D7446371915172040B2A0735F6851372432702D379B7DCDC35A
1D15151215151515151313152F4EA9C3A6A23D1613131312133567201E1D2F6F3F91532B
29344A7F79A978405A53412612131B35292220202C8E755B7C7F3A6A2715151418283B33
46567CA6D3D6CAC94F2419151D2C42171515151312111B304E893D1B5168BEE1D67F4431
4B3C6DB7A19586A6D4DEB546683A2C70BC733F3B3D39343C588D9AA9CBB94B272027474C
302F26256ACDC29CA3A9B2AEC1A6405DD2AC905A415B829397C5CE7D6439161315151315
1852E1E2E0E1C9773D262C2E5185AD7A3224271F2E39938644341B191B35467097BB8032
6C9BB3672E2E2B2E2E3689C4C2C1A2B6455A6B236040161517191A5E
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C72643F3B
928A66543C1713151413131319838D8B76B47A3C2C2D1B285ABDCDCA7D3C638C4F321915
121515151515141315153E673C2B181413173A665676301F1C1A161B3F53274777B8BC78
5218151511151B1E1A2544708684A2D1BFBA8B311E1715151B763D1C211D3D704F47484C
37466094929A873E2A386517101013162D38353D628F946A883A5B441414131113151D28
202A212ED8C7A35D1F16151A2C4F3C15131715151515131E275D933B7DC2D6CAD566545F
797B83697274ADC276BFC05D221C1B1F2FA1AC6539343C51ADA3B9B496885D1B225F5236
312B241D51AE867F6F665A5CA2BAA2D28E4B33496A4D4B76929C7D68768A491D202D374C
39C6DACFE3E5BA4D181B25292E4AA73F2A23201C1F225E833B3716161B3B6E94ABBA97A1
8F5D354D6E4325282A5FABAE3A437BAB4654B786AC2F151615151A4C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F885B4C5BB1
9A5F5F30393B251815151313165F6C5494A794BC9C857F879BCCBDB7B653325B6D241D16
151515151515151515155961372C1513102665393A47261C1A191C1C192D281F4997A18B
6C561D151B252F40545855422D1B3BA4B8C78E7F5A6442255B5327212D2C5D4F351C1526
5A7388ADB0826D6A6069B3743D42343143685F425974AEABA04E6317111515141313131B
2D22272BB7785B69351B151B295731141717151615111219202D83D2BA928D64B6906682
91845D69A0AFAC97B8CACD2B15181A4D53498EC9BB6F526AB2C3939C5A53704771654036
2C2C21254C925F6C5143403B5ECDC76933282C3543698484533139576B71BE925B443E6E
C2AA94BEC4DCB1A82115245345417777462F1D1C1D1B25775E3D16171F4377BBC18FC5C4
492220253A53442B4C788E752C2932635E4FA2D4CD551C1515151634
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C9998B9D3B5
8C776F3C2E2F352B150E0F1F3225191C48808E91A7B0705B5D8489C6C19C6022868C5A4C
392F271C1713141515215B4E3321181515475F25293D2B1716172F1F151311151B807694
83829660604E3E3320181615151B366DB29C9B859785769CAA554639363A421D1915152B
3E708B9AB78972BE97A3AA71615F5A756D8097AAA99BAEBEC59531151511151311101115
2344272B9E7A5BB2A970523F666C2A1515181517151315161D2872C35C535142ABDDD4BD
A4B28E7D5E4F432E99BDC53E1B1B212B333F5682B4943267B66B88685B7296C9A59AA6A3
B7A1756389A091361E1C2B3435AB732D29262C322E4F7A422324416D718885A5C79690C8
A577917AC3CCB79C81251524416FA7A5702B1C1B181C1E50623B171A2E4B85BC97866C8F
1E1D1D211D2A2E435F5892592C2A34457259BED5CCC77A2513151B28
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B77513983804CBCA565
6D726B4D3E2C2532505236261C171515185FB7A4A5ABA07963ADCA7F9E848783686B5954
4B4C50564E3A2512114B503D2C25181526663E1F1D4627191D4421151511141517845186
9F56B0A22615141515151313173967872E2D45587682B2CECBAF8B505B4B20292019263A
323B7B727F8DB0B799755A4E4D4A364F56697796C9B8A190A5C11B141515150E0E111313
15465F2FA78E69C06F778494BEAF2B1515151515151415161D256094454C3D3F98C59D92
8E321E1B191E3D546CA2C0A9333C281F23242A3D6692607F727C9D4E4A95D3E1EAEAE6EC
F5F0F0E69E8D91221C1B213135A442272529272D3355304E615B7C554A46698FB1DCDB90
607098A179946DB18C8625171F273F8646211D1C191C1F68835224275157AAB25373476A
1E1D1C1E1D223B59436BA0532E2E3342649CAE9D5C6686864D1B151F
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA0876F94534B
4C472D23334242343980551C1713152F5B52634846456DCEC197D28D55A8A2AC9B502B33
3B46504947425E5C558E4623262A181C6A59241C1D72301715141415151115142FB46158
A06B71991D17151517192136739C8F2115151B2B4275C6806A86A1B37F435149292B3840
605B5E8184ADBEC18C322D3D536D504C599295909D8E90CC768622151313141011101311
1551D09CD7C294B0372B3A6EB7984A2919141515151415181D2C7869404F4B5E9FA63C6B
6B1B171C161A1A585F68B49194382023293228222F5398C84B466C5A5F98CDDFFFF5F5EA
EAF2CCAF857F6D1E161B1D2C429D35242B28292D53231E2689C8AD81747F68A2BFC6D38F
6D416054313C7176B2819335171F285D6E2D262B253959A99C636B7E5B8FBE6355644562
2D1D1D1D1F4A4F313C94BE5B413442549DABB8604A4B4A537375331C
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186A664534F
52302B262826223864958A4D1F274C594D4D322A2621238E2E152894BC7498A9A29A2D23
1F2229374B4A48448EB4745B546850647E342F4051864616151012101310155399626A56
AFC79ABE8E707777798C9DBCCFDC811917111756838CB89D4F455BAB878891592C355358
3B1C151788B6C19875555054523F362F222326286AAF909F78536B13141513100E101115
355C3F7BD4D2C4CC86415698C7A7454537322A1D151515152133715C5161807BAA9E6C3B
151A1D17161723575043A07483963523305259423B383583392B488E8A88C4D4C9C5C0CF
CFD38F7F48857623171A243859903C2A292E2C4E2B1D1E224D98503F3E5A2B766AAAB733
20476B40252959809A9D5F9B511A2135826B7B927F68A398A26B85A7A7A79C326869415F
561C1B1F484D3E45866F9382536CB4C7C0CABE766D5262663A4B788B
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72A24B4557
5C3025261F1C20306874A594997A564134362926271E286B1313131949BCA3889F8A9A3B
1F1C1F222D32373AAF7B596476A2B6C6A6815C32221D1D1614141513151C5D63291E534F
8FD5B27E6C5954656B637AAFC6D2C666221415223C87D1E3AB63959347546AA890552215
1315151563568C7397704A3F332F2D29241F234D73A791595D4D85441511131511131A49
4D285CB492B9D6C3A2BBD0C1966E543A363D2D34433B2614215281625C889262C1597023
1515141316171B4357478F744F81A53E574125171716174068454C8688B69CC996778B9F
8D8495AC74B9B34B271D212A7E5D453324263E4F1C1E1D214E7A3631312C245540736C1C
23653424222330678D81725CAD7E2D369FAF89718B8A3E2D50AC96BCD7D367367053325A
672D204C4D3A4594602F87BB608778BFCDBABD3021253C5F644F4B67
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677CAA0908E
61463A3C3B301F1B345F4198A53C26283F3A2B291B164E3C10111515165092B18E9F98A6
673D302D2D29329BA268827494B67E5B7D94AE9786663C351C1515152E6D61241615209D
A6B5B2A29D837C7878789BC6BF7B8EAF88491D1C2354B0E3E7D3C0A85F5B41436D261415
15151522734070444B2723262A2A303B3243655A5B7051585572689A2D19151011364539
2345955552BAD5C4AC97CA75301B1F394B44291C1B212B3964B2A97E9A947965A4635015
14140E1113181C225F4C9CAB4E4071B12F151313151515367F31295F92B297C89175935B
443D59ADCAD1AB8398532B3288352D24213285361E1D1B235B79372D1A1834722D744322
3F43221F21252737947996774AA3BF9C87BDA9A1662C212A3C54AED5E1CC3E3A92482B47
5D535E4B355B875987936786A07589AED4B9BF4139231F2581A7A5BC
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63D2D0AF87
5F534F412C29312F3D79878E7A484642563E3D3D1E2169231111151313363B5EA0A4A2BC
D9B6A097A3B9D6D7D7B6889FB79FA49D7642383B5173999F82583A606F24241515172F98
AE968C6B6C49312A292E345AB27B60545F6F6F514D9DCFDAE4DA7C5368849486865C4C48
484B4D8CB2636F454A1519171515172879855B353C2C171A443B6BA6A45B443143352825
428D4C4F4EADC6AEB0B6BD681B17191C1E344D4D3B201D3062A8ADCFB5816094A44A1A12
131513151011171D7449CDB99B928A83412B231F212D51A0BD693D63467B65A990473B3D
5B8EC7CBA097424C6FBCB5A4962C1F1C2F75A2531E1F1D2B626A321F3266898779763B17
432221212324212C568F64A7A66B9CCEC2B2AE73644545483E4255D1DFCC93ABADB36F45
55AD9183A6D58E85502F1C2F92A0ADAE9EA4574B50435272939DCAD3
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA838A7B98C5
86564D57616540304F7492A4874536263632302B2B30501A1317171315323D253FAECCDA
C194807A90B4D4D6DFD9CD9D594B76A08339292124293A4D3A5699C73B1D16151418425C
474B80786B6044392E2B252C76956D574946484F4B94D6D3C283B5724A4D606078523F38
362A35468DACAFA3781B15151415131740342F3A31151517276535799372A2693D353660
99545651838280736AB3A68E472117191C1C1F355247585399C7BCC5C84C90CEC8612017
1115150E14110E1E6E7EA367765F57788A81777073726552A7C0BE904D4A4B9183495485
C0B688743D696F33406C9CD8A4383B566234294979381E2B5C8D5177654436347EC64F15
17211D2424272B423030869FC49CA3BED3DC95706964677E7F8FA6B7DBC3AF77578AC4C8
C6B59694B14429222332353971AC977D99C496747D6B7A77ACBC8C76
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC0937B6F476D
6C7E785450618A877587A6D8C293474153443F35377C251A12182A28223350341D50D2D3
CBB47940373436A0DEDBAF6D4A4E559E863C2E242436525040412E4C6A6E745646586B45
3764712F263C3F59331F211C278F7B663A35292A2376C5C9995E80988846483E5264362F
2E3B43668BC38E9675451D151515151B4135403617151516273A2862915A95D0C8CCCCDA
B1604D6EA324174A50AB6E48857940221A1C1C1D252D568869CBC9D7D5CE846A708A7D6F
3F25191213101113378A644A3E5161402F303534343941459D8FCDCCB053712788AB989B
7C6B5A5742448C65374156B5A6CE8537181A1C1E3891735BB7AC8659352621294EAABC30
1921232223274B411D1C5AB8B5AC9282BCC55D1E191D2033579CBB88C88362E0D8C9BBC3
CAC2B7B74021325582A99C618DAAB0C6C7B79259686F94A473382D38
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398AE7E5D5F
5E394F79647D80A2DAB5918DC06D747E824D45498094233433334F38303F743A36747F88
C58E2112191B1B3F9EBF644B6D7F87C4D1AB76656DAB452E296A5F4D56536283B5DE9731
317647251B171C263F411F1517477B6D5B4E3F28209BC2BB4121435BB668729EB09B6253
504A473024858F686F5542382F292931303738161515151528351735A9878C97B9AAB4C1
AC929E93941915265A766A1F254075764127201C1B2239AFC4D95476A3AE231F1F2C2833
385A5C6052413330467B3944262138806A4434272D313446887B88A5CBC76E54918D7854
6D596A5F4F4E5B9747414AA55AB725191517221C1E3477AC8967A5906D625C6DA3CEA698
51372A1E22332C1C1B1E447A395693C3C694821D16191C2123438754B5B4A5876F8DAFBE
D5D9CF8A6552606568827386847CD2D5B7A46C1F35375357352C3035
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882766E7072
748358437581A29DB4923222398D4F6F58635F627B935D62614B41473324395C797E4A3B
9041161C140E0D0E1566351F1E215FAF5C251915174A3022214B16171F21273153BD942C
3E552B1B17131215181F3A3B2B2549728D6E7B9490C18878541C2570C7C08A6B66773C20
1C1919191C24655D7EC393786D6A708D8F915B16191615172230173B58255E6C5AA5D79C
815B352E792A151E6A5E571E211D1F3B7E7C3F211C2EA97E7A95914DA5AF201C1C222D29
1A1523292F3A619CC4971B22262023469A823C353137616875738276ABB7CBAA6C313862
9CCCE1DADAC192AB926A81A03E71261515171940574F79A16FBFBFA5626F839D929E9A54
7677291F27251A1B1D24574F262B3CA4C6A69246181A191B1C4F6C8AD2CD6217181A2D55
81A8A79095886757474540445A82B48244426C17181C1C5763533839
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC6984E494C4E
4644688BB7A56D63728948231E4167567141424C9A7A5737271C1D2C1C111E4D8D7F4637
813A152F3213100D1049501A1B171E743F29151515193334362617151519171A206DA131
552C151111111516161515235B54695F504337293F85526578202C6488392C292B471716
151515161515334C73AFA481594C5A785C262F54271615171B25185034182E304359BD93
564B33264861253D42594E1E19181A1B2241927E5E9AB3563A3778A4C39629261D1F252B
231A1717181D376BC3AB401F2B2223356148262927536E6CA57552633666CD4323232C21
AAB2B2BEBFBCC0C7D3D0C6B7428A301515151839509B9FB1AECDCC8B758757291D22836B
5351652F1E1C1A1B1B2D632D20282F7F498CB0903C1C244168AFA8B2848C4A171B171C2F
687FAF975C3229211C2124395FB98D4D3F365C3419171F292C47754D
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B4333452F
2D27294C8272AB5F56576A2D1F134847804F425BAB54221A101716130D101F5B714D5832
8336131533150E0D0D279C491C171B55622A1514141A1515161515111619191C1D448140
5821131114111411111115151018255D452A3223175A3C4C927B736C5D1A202A2D301615
151513151515194843716B4D507CB27F39211E2F5D5D26171B291A511D17211F2041A26C
27324B5541724E722F335A291B1B1B1A1C1C2573D9BD421C26273186D3A1502C231F242E
2D201A191E29446ECEB94E2D6A31293362171421537D6F85799AAB6E25389C24252F4153
4737363638415985A5524658519B4A191517244B7588A9B8BED2BFA459271D1F1F1C6F9E
773A454A1C19161A1F49631F1D282C5C352F91D6B55E60746E8F718E6C5171341D191A1F
9A8665561C1A1B191A1D21316CB6604339384D65151B292B25294150
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E3C303A26
1F1C19304A475D8555466C3C2815187197A48DBED35A1F1515150D0E0D11445E25193935
84361113120F100D0F1C9189231B1933913D111011111314141314132021161C1D506451
481D150E1110141515111611100D11414F321D1E155540265ACFC65E241E1E2A342A1515
15151515151515453A6B84764C60BF56452821222E487465314429421B161F241E2C8964
241D1A2042766A382C274E591D1C1D1D1F1D1D36CB881919273036AB945C535B394C5B4C
5D4A3D2226303970DFE08536315736538A566A6643266A78456743937C68A644467A5731
171E1D1D1D212F467753343666A3AB571D365B52486395BA8CB7B86034221E253D3DA258
5963343A231B171928563A1C1E25393C252657D5761F1B222F69678E534F70504D3E222F
774A4C5F201615151B1D253EB68C4A333033426E1A202D2221242951
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA59836333725
1F1A1924503E353694427C6F2C2324BBC8D3C2D7AC9585575E3F2F281E2C622715131B2C
823D1B1812140E0E111966AA3B171A60CA6A2111101311111314151519381A1A1C6E8C77
331715101311101515151511100E101C59391D1A1A5542302F9A8A1D191B202B30291516
151515151515153F3E51332D333D6F3327212327242A44648F9C7F3217151D2D1D21838C
2E181C1C1E3452472F1F2DA95B20181B221F1F418F6E1D1525344B884D9A3E2D445A98A6
9DC5922B252B3D9EDCE2CF7E2E617E5E747A361717186F4D5A7B24256CBEAF594041211B
1A1C1D2327282F45BFD0998185D1E2B69C6B494A586E60BA8F598E9D7D49445F809CBE67
54748E52543A2A2D2D64212123347B40372D7B992E1A1B1B446C7E593D3658642D3C6AA7
613B3A764D212B3A5D86AAD4D7B33D2A3A3337783123261E1D1F2B73
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA09737403123
1D1A172A3078532CC5CAC4C1837160C8CEC6D4BC4272495963716C8F8CBB7D171415152E
84481C191B3B170F151E56B7473E91CEDFD8B5805F311C13151413131739371F2A90AC73
2B1713111013151515161110101010155C45251B1B57542B38A8771C1C1C1D23342C1515
1515151515151C45494F3B291B1B3A5B2A29363435323F64577EB9461A17353B202389CA
7D25181A1B272F4D48212480CC8A411F1D1F236D707A43192133714D34723B34322C3770
A2C09F50404AA6CCC494A6CBAE6F907C5F9C3929212D944A8E52452C26A4BB94352F1B19
1B1D2634564D7088BFC6614EA3E4C7C3B77B8265614472CB461771D3C0B09365403C3C4F
7596C0B8B6C4A5ACB29E2426458091545357975C15191B324F7C7927272940784D2A3B53
68512B90DAC0CACEC4C9AEB5A5793F433F3F4365611D1D1B1F3652B1
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E42482D22
1F1C1B403F62A8CBD695A4A699B6D5D9B3D5DF93234F301D1D1A1925194FA75A1815151B
8B4F1B1515181B131C1D71B5CDC7CED2D4D2C2BDC0BA9D7E694E3332468FA64F4CA48458
211315101313141515150F0F0F0E110D3A6E232017696B4BA0D47C4E3B191C1D2F311514
151515151315176B94742E331E161C788059544B4C596992A4BAC67A4D4E839A2F61B3A0
A377361C171E1E34592C1F705346808F47322F696067511A20547F482E5D1515264D3F3F
506B9F998BBC8151AF939A9EA3D1B38E8F56708588B2C15EBC39231C428F9D5359651A17
1B1A1D474F45405C8E95BAC7A2AFC9C3CAD9CC925F9177AC291D845B32302C436A6D5C47
69B29B69565C888F57996C408A582A45518DA1451B172C494972581F1C1F354E973D4944
583344B7D6B6A7A99D8483AA4F75683D1E2C41528D2C2E3948527499
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F5F7A3F2C
221F1B2F212737CAD3B774312F3DCEAEB2B8AAC5333D3C201E1C243F1E1753A26017152F
BF6E1A1717152B60192CABE0CBC2916D44393B4E5C617079898D999E9FB0BBC0D7CB7C66
3011100E0E150E1515120E10120E10112AA72E211C79857FACDFBE543550402D34401513
13151515151F5DC1C59C53312B191979523639424E616BA5A393C8B96137396E99A94824
4D85665B1F1C1D3038652C703A1E69CAC8CBB2A68A85B09494D87F343150151815194AB4
A9503BA3C65733465CAE83B8B3CC8EA44324252E324CCBC2E091452C53789D3E36451B17
1A171C28263055496BC9D0754647D2DAD7CFD1DDC5451D9E3F6A5E331D191817172248B7
B5A0946753617EAD8E90C3AC4E1F1F2560B47D352F254C324F70311C1C1C1F348C863D40
4B3B92C2A45C4D5A3F2B243F5558774C252C3268B57E51526D6A4333
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D5A824F2A
241D232E261D756F41748F94609EB53D212C60959B375841322D3C28221F3A7AAB33194F
D5AC2A18171515525CA5B279C6D19454392820201F1F2836393B4F596A7A857FC7D6DA91
761B1211121111132A15100F12110F112CC697585CAEB8C8C6EAD4865F2D366181811E15
15181B2F519389A7C4B693524A251B5F29151719191A1E3F98B0A2C7CA86397BC26F221D
1E2D7E4F643B1D35494F838DA17061382846C18C98AFDBC6CCD2843A2D53151615152380
54423D8DA6504C46499AC8B38BA5A0585E3729303B4DB6D3B46D5964514E983D3A271B16
161B2729435B4FA1B0A0C5A3A9C3DDD6D3C6CDCDBC1C1C8F756F2B271B18171715162F96
BC939C8B8C354D618595C1942F1D1D2A959A4B3F505C29296682251C1B191A1E51947A34
5884C1994F30291E1E1F2122545E6E834F5C83A78676665438232023
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A2564968C658A3B
241C3227355C4F284628183020695E361E16194C88AAC4C6957F8E803B26505091AE92C7
C9B0B05F27192060B7A7555E7DBD9C4442423C3F371F1A17151215151F304F252A67B3C2
CD99774E39353044A15B54101012121245658F8596D9D59ACBAE92B466694E2572CD9076
7A838B87634D7A579D9B7384604144701C1515151517263E986496B8A5D0C9AA93A6321A
171A2C6A475C725F9E49ADAD7D8D7C796D9BCB6141728D2F3B53755946681D1515153143
1D1A28907229374B9AB5C97053509F513980874F539BD5A47A2137936D70C05147281815
1B1C21505D67AB7D6A7038465D6FC0CCD6DED998B0514E61942D242315161617183E649E
7A4E53A3913F6187A5C0BDA8964B3385B67A1D339F4C2A3FA8A32F1B1617151B29458DA1
A5AFA86B3E2D1F1B21201D23295D4469AEAEAEA48952231F1D1E252F
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E944F6D548C
4B1F4556764C2D432317151C1B152E39221716154D87C9E5E9F5F5E3A87E7A5D8CD5C67D
4448428EC1A3C2DCB38C82453244B44C1D202222281E1E171313111517196EA3784DBFC3
B4896E59646CA1CBD666591F2535506699AAA5C8D2E6E4DDB94B3E5EA86E6295B4BEA685
5A4C4B475A7CAE439B8A405985868E7A24151517171B374391646A4C53A3D49957A17F2E
1C191C216E7984B8B1A5AEBD86A588725046A6C57E8C2F161D26617066907F2B171A4D34
1A152BB773312F3A8D6C4A5C5C3F63914232A5DBD8DCCF958C4C9F7F64B9E48F56472B32
54436E67838362765A1E22222739A5B2A4AE8478B4C87943B72E1F1E1616161948606C60
353D6340487A4D555473AEA3BBD8D5D3C98C1F1B5C3C6A9E8A9286351A1819182B2C4397
C79C86301D1D222E1F1D1D1E2034624C78B680A87A1F1C1C20212852
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D69869D80705B
9181B2A95855512915151528201F58A16C3E3324164FA1DAEEF5E7CFC3A4948183BEAC2C
1917233141D2E1E0D2CF822D2217758F271A1917151C1B1515171517262C313A7CD5C5AB
C0B5AB83797991A3AD9960695C4B3F366399AD95C4BDDBDB9A69353059A88090D24B2535
3F46473A2D406968C46636314E67B7822F1F171A1F293E4E618A71261936A6A12E3D9E7D
2C251E21247DADA5B7DAD694694E3C30343C50C1CF981D1F4959469A8FC5857B78A38726
171520AC382255732D19171D364C4A6F7F334CC9DC90548C57B6A45777D5B3B4BEAC9098
AACE757F825579491E1C1F20263378D6897047B2A9A6B7828F6B422B14151F4B5A535138
4C4320171F5B966598B8C7C6AAB1C6B497BB68306488A961292E68726E251A1A21303F75
A595301E1D1D1F372F1E1D1D1E266B5D668B7B46821B1C1C2228438C
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557AB2A29A83
88CD968D8C6A662815151D53424F57463B58665F41319BD8DDDFC97E503225323D42975A
1515151739D1E1D7C8A99D721B135BCCA87B7C71746B655531201719241B1B192AC2CB95
D4D8CFA27051494D68798043211C1C2F42469C95A4BED6CEAD4E73756970BB677E5C1C1C
1C1D1F1E25365DA6D99881776486C97E6124263637485F6E5B80542B1A1941AA6D2E55C2
A7574C5B5E74848E86D1D3C48D5F5855484D5B85A5B46A3C4A647CA68AA566364272A23A
15162C69386F5129161815161A22458261902D648A2D26405D947066C4A55148553A2F4D
83BED9AE5175581C1C1D21273169C9B0AB60999E6ABDD8512E3B576B56395F5154584549
231C161519264B3BC7AEBBB87A3744755666C0B49B82421F1D1E2B5367786747486587A0
B4831F1C1C1E1D273A1D1D1D1D245B8D889A59255C381C1D23327D79
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A894A98AF78
BBBD84C6B29DA77B483E32403C452E25252522334D7ED4C9DFCAB4271B1C17212B254676
1F15131227C9B8C4B4906C55100D3051372C3D3C3E2D2D2D2E2F272D3332282F76BDA75C
D6DF88595A585B47354D71ACA56335323F60546CC8A28C988887398E645A80AD5661241D
1D1D1C1F2263B8C5AEAA8384B5CFE290967869B1917C7983784C523C1F1B3A9E9F4D356E
CEB2A57468686885D3D1A2AD96828889513C2B32A583954C4F5063B3A96B866970685460
46256F9F6E2D1E17171515151617173B858D94374C2521215FA081B5AF594B4131262943
4446ADAD63431C1F22292C37879E32195A8A64CAD4B6C741211E23264DB262454E5F3819
15161515171E37347B5184C3D17562B39AA2C3DA6E52232622232E4C947B656F776E8EA6
D4C0431E1F1F1D1C33301E1F272881C9BF882F2E317F242233588B2F
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D67372963834B7496A9
CBCC9275C1BFBD7957472E2B19201D191D1D1C1D264DBFB7CFCEC4705361421C1B2F2549
4817171841CA8FB6CDBA7020111441140E111513151012131211121217171B2B5DAC5366
C2B23627283D4E4C44405D96D4BF675A4D3F75A1461A3B61AAA89A3524161754A5744E21
1E1D1B2264B5B46A5C5A877F8078A2B8C0C794C68A686C98A84A4285592F3758A7A45959
CD76383D463B265ABEC7ADB6AA8D5245231C2E4B8C968382271C1A3190836F7061423F41
4D9BB47D3A1B151515151515151514172F9BA39C594151303FB3D3C66173899385724E52
A19E746C4F1C1D222A2D40A16A1C1516187376AACCB4D99E543E424C5FBC754B60231915
151817191621488F597784B2B6787CCDCAC7C9C8B74F272A37565C3F2E31465980B1BCD4
CFBB9D2A1E1D1D23244328212D55A9C8C6A0533733645B2456A44828
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F482667905959717E
BCB98D80C4BDA0816244402A2228272D2219171D207B8CB6C0D5C86262798C5218193850
9E6B5D7188C196C5C6B9996A517A3B0E0E111315140E11110E0E0D0E0E0F0E1011572342
9C83120E111015191D130F256086B1B9A39872271211131B33A97B6A471E151966AB8E4C
2734539DCCC4553D4146668C7D6A8488ADA09DC1A16646384B7C8D917B73617F7AD48095
A959533B211A1A84C04A6BBD7A6E8E7959544F333553495C7726211E5447926A2F282B68
AAB7C2665E1E15151515151515151515274999BABFD6E9D2D2E1D1D398664338363D68AE
DABA44224334222826459E4F171515151630D3D1D1CEB75A626B716F7D8EB59D30151516
19171A15193065777D7A749E55456D749BCAAAA8926E27476F532F2627272F5288AAD8D8
D9A99B6D1D1E20232448685687B5A6A5D2C69F97959AC489A399275F
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F223565713822518042373B3D
7A94578CBCB2BBCF894E452B2225272F33373E466CC5A5BCB3BC7B364360604F3B2B5697
61291C232A9A8DB8C5C76A1B1D2A541D0E101011110E1014100D0E0F0F0E0E1025431943
9173130F0E0E0E10130E0D0E136E9DADD890151114101013203C5D18486E2D164464BF8E
42719EB392935F4E4A3C201D3450726C818FD6C9BE6E34312B5CAD5C33414E8D9EC4BC7A
948863221E263EA4A17F4180572F4191D6961E24301E6B5D585F31244B343E9A844F75B0
D4BF9965601B15151514151517151515194FA1D6E4E5D7E2E9E2DAD86A31171514151841
AC9233202B5F372939A55017151715151727BBC6B8BE4F494F3E474F5C639983571D1515
1517151516255D6983808E834242384F5B94828497987E7B423933415055716F6DCFD8D6
B9AF85B55C23273255574F99ADA9B19EB354556E869DD4B9D17E6D82
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88372D2941
688E2D265C666691412012100E2011111111111431A04C5978756D1D1731231F2C335E64
41392F2F2D9CAE6ECBBC4D2319141F37120E0D10130D0F0E100E100F0E0E0D0E1F401B40
8F7B180E0E13111010100D0E0E397C4CA35411100E110E0E19275C17152D754E384460D7
D8BC9A4844545C1E191B17153B6C70B2BCB7D2CD9B664628263E64685337277D6FA4C6B8
8874766041333F7E4B649C6D5A232130B35F171715182C79737C543B725937BAC66E67AC
CBBFAA444345151515151315151515174385BFCDD4B04861E0DEE7AC5E4F4B3622151738
645F3B25284B7E418E551615151515151738B1ADCB997549528D755835293080693D1513
15151515152048667F7884634339223A509361C2AEA8C2646265859F72513133AEBFB0AC
7DA4B4B2D2A49DB9BF95947AACD8BBCA7A2B2630385DB799BAC76C51
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D352A2678
CCCA6221404C49632D170D0A0D180E0D0E0E110E175F343A5D2E60170E0E0E1010134E28
1D282C2B3490B86DC9C0B6934E2D192321110D0E0F0E0E0E0E0E0E110D0D0E1010482A47
9C7415100E10100E110E0D110E2B6A276F56130E11110E0E12263C2813152285B17EA2DE
E289514B381D28361F181C2E39333250AAA19FB3A63F4E583D565651464168ADA1A2A5A0
8D7B7B331D1C1D5648476EAB7B2C28265F76191515181D1D437F89505F79B6A08345395D
94C6AA5B344839151515141511132A51415E97CCD5C06390C2B4DDC7513B352F38424C96
5F4C572F27375F9980131515151515151A598EA8C0B2BA64729C33252321254972683F15
1515151417243D4B6769773733492B356A85A4E1D6BD7A35758E6941231C3AADA9695A82
968FA6B3D2D2CDBDB2966778B5DCD4D46A454060A3B5DEE1E5E1C3BF
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D312A3249
AACDCE7F3E5A4A6120150D0D0D0D0D0A0E0E0E0E114D363B912F2915100E0E0D0E1F2415
11111410112DABD8B8828E6C736E572D2C180D0E0E0D0E0E100E0F110E0E0E0F0E304278
CFC64C100E0E0D0F0E0D0D100E1F6526435F1011110E0D10132224430E10111CB2DFE7DB
AABE481F1718181B2E191B322526262D603B655A9073354358704C465A767A5C79B5C78D
815E513D17151757473B477D8D2F272D3B752A19231D191D1C3592BA969F995E3647509E
A165608961404B261515151627413C204F9075B3B345385BCFC7BAC76F586E7679725B88
B17E56462F375EBF3A1013131315161F3B8A7EB2957F6D1B1B5D3823231F252659645E52
271514151D42494C4F6338348B6A5E80A9CBB8AEABC3BB7653261C1B1C34A4894D293182
7266AEB8D8D6D1DCE2D0B7CCD1DFDBA9729D95B7BD7C84E3D2D87771
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A4155351848833B3F4764
846A6594B7806F7236110D0D0D0C0D110F11141F316589AAB1AA7D401D110E1021311615
130F10111431879FBDAEA2625254575440382B100D0E12192124201A15110D11103E8E98
877E7C573D130E0E100E0E0E0D1F5222305C10100E0D0E0D10191B55171310138CE2EAD8
C2A82615151515171C36204025272A3262284C908E9E5951667E7B7E6C533B394595CA66
4A6D79562F17174D46343861B399725F67875A333224231D1E2140BDD5A8756662869BD9
891E305D73705156211B3547432927778E748763677C3B5CB0B5B98A1515151924354E8C
B0BCAD8F4F71B68B771E16151F2D394591B3A2B7A97A44171B328340242424242C6E5545
534E31234B504841485949816035312F3C744B6D809DDFBC6E3B2B212BAC773B2920265B
376DA6B7BBD2CED0CFDCC7BFC9B88D8C549572487CB8CCB9CABF9657
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189493C3427
22554F496098BC9F2A110D0C0D0D135A5E4B3E3E406D8F6444586D75766D636570191310
10110E111B644528A7BA7D927B53595D54514A3F220E151B1D2029293B412D2B637D7B59
735A5447586023100E10100E123340212558130E10100E0E10191D4733151647B9DBE7BC
AD6F6F2115131515172B463B1B242B3263416B5858697E49524985988E918B87906A774E
51535B6B4F3D1944753B386B793A3F58778D907C7F635C6C6E648AC9E1D8C8C08E775287
A757213B58556973A05D3A2E25388978687E44253362A0B9515B6B781715151515151865
4F7380AFCEAA361F703D35494A5C7988B4CED7848387501B243191BC723F2D24264D7E4A
474B629295543641659979491F1B1B1C205A4C7E9DBDBDADC1B3849CB97A352C221F3536
2C78BD97ABCDC6D4CDD5C67E856D3D3E59397E7F6DBFC8A9AA4A4562
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A2526789138302C25
1F1F4A9580708D922D130D060A130F1C2632353D6BB4785C595A663E2F303E7E8C491313
0E10111453381D15615317254E8B7C4A59514B363F49321D19191919203C788061525A59
69B37035212B4E51341610101B4F2C1C1E4A180E0E120E0E102A4E459679735BA7B4BDCC
B26E51703C14141514233844191517358155462F1F4355162352685C59617BB0B8731D13
1A445F7976516B77BF9482BB49282E3987A49C8E696B5A44404561C2DA9B814B2620232A
69AF7B4854636752938827345A719270723834353D4CA1BF2E3E65521514131515151F86
5B4546486C79282C435D76767F443A4FBDA67F8557BDAC6D7D8577728B9C9D765E61A383
6F7B867DB0764F70946B7F271B1A1B1C2D726FAEC19C8280737287A3CB3429221D21452D
5B73AEA5ADC8C3C8B7BE8C221F356A53627470594293B1B97531344C
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A322C2625
201C4BCAC586AFAB7B3F2D18412C1B2D383F50615A5F8F81706868302429484635843712
10141547492117153A45110E0E18527A5147485B54515D5B412219296B7E6C655C333C76
599B73543D2837323E5258434F7726171B432B0E0E0E0F0E122D2D99AE5F477E77A6ACCF
8C6C865D675A382D1D3B2D241D151E74BB9B776B6C87683B336D374831383D5786291515
13173A556AAF9672417B805E89908E98A2AD9E8B6D6E6E7B8176A7AA95956C37221D352C
258DC19872574E7C7A748C9461758C5C41545B645862B5A43C2B6B641915171729383F46
806C5A563F5E251B2570A692867792C1D26B6995469750424B574E4F4046556A86975472
97C7CBB7C8C79F8D70808A643A2123244BA98B98A06CB36E38394352A8532A1C1C49334A
586BA894BCBD6959526E7A241E3BC39B6FADC09E56BE9FB03B323B36
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98342A2527
38595E4265A69465606C8C646A2A1825312F241D1E333445789B8B59312F5B422C389447
15133D622B17151527541110120E0E23676946673048686C6E768E9271725653527376A0
5C7D5A6253454B55413331353F944C19153939100E0D0D0F19291E7F854E8B6E5370BB87
596C4E675E6676707BB554372C3788884D756C63753B25335873584E4C3B32227F7C3B14
111521438BA15E3E1A182B86AABD996768776F5C3129283A7A55684E4A75673D27204532
293781CB8C80769D784D8CAE778F645042221715151A4E71702F4A571F1B2C39301D2122
2E525C4334534D171D90919E9C5147457A9F80BA7966201D201E1E202527272973837D7A
6E809AA7BCB5D7C46D4D494C6169605A98C2C3D09DA4888B623F354081893A30564E2D2E
404CA6ADA8B1957E5A58882F4492635E6C82AEB3C6C4B97C2D312C28
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C2242764330659533344865
5A3637464E61848376A3B2779F3E2B1B151513151515171724646F5547293E4132244DAB
5252823B1D1617171953121010130E0E0F4980BF77586C85ACCAD4C59D85654E403E558B
6E32192D5D65573F3A525F4F1E5069341D376E17192432383951838C5188916A63609542
1F2F534943667AA2A29E94738B837146564D625E2F332A1D2041727A6C492C5897495360
4C231536B4A8884B343E3953BEB5904159534963502F1D1C216F7431315A7E753E36342C
292E39739AA39592883EA098AF5D2A171415151415172C5A7B433A604732232022212326
262D3643453D68306F757273842D343F4E98C0DACA421C1D1A19181C1E2B4468483C4C79
9E94A0BCC5A1829B4C515C6B7A9FA6B4B3BBD5D7AC496462838E73555DAA959FAA462F2F
376BBFAF92D0E0B66365A6A26642353A47736BA5CECCD67B2F282D47
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E15548361745B3E
3D40362519183A483787BC9BB93019191517151418182938486844495550584E3B392753
D2CB4C24171115151550190E0D0D100E0D154ACE7E3533456DC4867C541B151510255F2E
254D241928365A66462E2229272A44667A9BCE74625A4D4C4950759289664B475C5B7D3A
2C1E1C3B5451677C99BACEBD9B934E344385652C26252D17162E6177746B804E38443432
476D7FA286967D8445312645A1829268374C524C31312F1D1C4C87222C70B5C3A161503F
45422F192F69A78FCDBDAC9158171515151515151516215C5D5E5476552221252A262019
171719473D3338B3AC7EA7989F3F44484D9CB8BC6978592417191B23445F4A2A2A23242B
3895CCBF8BD299D08F9F9389725B5695965B90C3A98D5582A1B9C6B6ACD2CEA4A38F878C
938B5D6868C07E8EA1A7C88E564A40464C614EBADADBDAB66445517C
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C906B4C4A3A
291D1C1A1715151D6997A4827979433131504E393D4D676556654F2529465D72593F362F
C1CD4619151110131A584D130E0E0F130F173AB9927E777FA7717887751F121523662F0E
0E21401B1C171325576743292F4147C7AAA0C276535852372B265E84A087583F2D2C6C18
171D2027386A5543447AC1C2B1674B4F593E4347242328301B1740688C8C4F1C18333B3C
323265C6797993A16C643E778C808386554E6B301F1D2533315F75213A759EBFC493A387
948F5D60746F424158B0A156331515151314151515151C513F4D466FA2513C33322D241F
1E191519334839AB7161AEB7BF6F6C5D7F97BF8E4C4F49635A302A655E2E1D26301F1E1D
2275C1A070D7D2D79D4A2F3844545A7F5D242A635BC9B6A48E7C7D8296B0BD9A856D717F
C8594F59916242375A98C6BD885E644B4D649FD9DAC5B7C6C09CAA5B
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C75483229
241B1917151513103299A09789733D302F2C261D18192E291E1A2B3D2B1B295B6A71708C
C8DCA6633B29282D42697F5D48331F101429674B15233C72A872604B4D59265D6F280E0D
0D0D3C491514130E0D1C44788078B3A28AAB544B523E494C479259557F826D3B1C28891D
1514152B1D255E6B5195C1C583676C5F2513102E52311C294037287A8F69532A15161924
3D438BB1A83CA0DBD7AB84A1958D856E717E5B38332F2E3640958855705C738E9C454541
3846403F38394756357BA0532E1513131315151515151B5B6455304A9ABB718F81604A33
2D2626191C5B84B87D7CD1ECD56F5A475DA27F716E514F4B5897C283201C1F292B1E2125
375BA08595C66EB8613A484B4F697C433F221B31669154594F46525E7C67818D884F4161
A3735D74955C503A406F9A7C97B8B2ABA8B7BFBEBDC4C4C5D6D88E27
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94893D362B
271D1C15161513131B909B82515348131010110E0E121518181818283C2F1E29424884C6
DADBB2876C6D7360564C2D263C454D4A56808E13100E16678754A4946CA79EBB730F0E0D
0D0D2D902D1713111015152588C0C17FAA8099A4C08929151370271E3C674E532544654D
4E31233029191C93CAAEC6CEAB7F4526211D180E19474A23394E5E4147685A4F271C1F1C
3157C7A4AE818FB05A5872CBAB7F60657842795F5B5D677F96D1C9847349635C9E46512F
1C171B212123243B4E90AA844B21291515131719213B547266504870A650232F3E618285
817047473C87AE868FA6D8E4E27E7E6C6D362E577F5769628598947E1B1B1D1D232E464F
36646241A3B37CBB778A7C4A3434502D31352022717F4B45464049626D4B6C556F7D6C81
898B4E97614051666D856F5A3F53B4CAC8A4877D9351767693C09560
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A491464141
341F1D1915151313308A99A968584B300F0E100E13151515151515152041321C3A5DBCC8
CF9E6048373F4F58716F5B573F342E5369B85B3D3A384B45826239323291D6C28C271510
0D0A0F5BA97A301B15111F3F7EADCFDBAF3B261A304E0E0D0E532B1D1D6060545E851714
1F3A647A716C6884404AA5B89C342F392A201E1C13102C829AB030193676A58C8B655953
5C7BC4A8CBD0C6BFB19A8D96902421226F9FBB98AF8479666D90C4AF80664F5BCB7E401E
1F1D1B1C1C1B1E2946B88EA0654D45181B30373A3526202572949AA4B526151517161719
2D4E8BAFA0A8CBC4CAA591D1D0BC31231D1E3457533C5B905B4B5165561D151719192B3A
3B6E466C9F4E4489453644201D213A282D362D22677D653742555A6653859B77515B884C
3D82996F4E3741588999726A4446557BC16C6D7E4C42454A72A75E7E
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B938E633D39
373528221815131E42459D9C6B6B58442B110E0E151615151518151516183D3584D1BA8F
C1A8956B574C5C5C656A5B51556471C1D4B53832201C4B3D994B331C2E93AC88B0B59058
3118111DD0BE8B70567298A8C7C4D8DEC233121318400F0E1078834E4F77A8A6C9A93B16
1615213C2D3678633B74B3AA831412193531282A37384E7696B8311F2963C7B88C392D2B
203398B5BF7C80B8904238335C522461ACD2B165493A3B4645667FBAB77E5D5E6A3F704D
20201F232B1F1F2F68CAABBD8A7E5238261A1B1C1818171A2FA0AFADC22B181116161311
1315152B7ACED0A7892F2D5C71DA723F2B1F306F6D8D71464E3D3E3B455F241515151938
7FA686B55F2830635A25422C1D1F28342D3241475F90693951719FABACAA6C637A577350
4C9289514339384D567670573C466262BDA788332C2D2B2E539C415C
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C59957A8A433B
322D292823191E3D2E3F374F5D5F624B47150D0E141513101014193B40434C63CBB8593D
83D1C3624C5B4435333944618AB1CAD7D8C02F15152B5992D4BC602D4D7C352128566D6D
6B62586CD2BD928582837E7B7275A27EAB9D3D151B3E163150777F8C89A0C2A0846D6362
4F33233E353A63B9685E92A9B038324149595A5E4C35221D3390807968A48A6C7B1A1815
151C56B9B1A0A8C26D231715194D8E888589AF6A352F2C42363A4A8DBDB08194521E1244
6F27161C1C1E284688D3CAA05A5E452017191D19171A1A1A1B74B3ABC02E1F1515151515
1516151943A68D7C461C1D3149C8737F8F88819F6A594B222343492C2B2C5C2917285871
6B7EC6CF4028294C57242E3D1E1E1F4A2E3746867ED0C07F949A8F807E59443947758C6C
A4716132282B3139465A6C3F3759678979956A302D292B2B3D7E3165
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495758F5235
2C2724252A495546381A121D424263664E3F120E0D0E1419191E2934312D7FC2A2462938
68B99091916139201C1D254B5251616FACC7BC8378857D7E86BA9C9BA8803C291D1E3451
432C2573A538243239393A3D4B94A1633871B7895C64555B34353636475C658A69652C24
2D476C716D544EA57B4C4C80DCAD6F463942423D352E1E1B256C5869B9B08A82891C1717
1C2973B5A8ADCD77385B4426171B7A44643C93AD4A413628252A354085A7A6C9972B1213
19625D202B263B79A8A5D5CF93746B4D4034231A1B1C18192F5F898FC646292618151113
151517202B9C96B75F201C275C6C1F212956857F2C6B50211B2146522626336D57615883
B6BAACCD5C212B405F28213F351C205354426CA0B3CFC76E7A8D7A8787382830363CAFBE
9C4D775A3531333A3E4F7B345D548D84543B573B3D403F3739764170
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C66996483B96B
413A2E355B7950411711110E16423175695F321311141917151E1F252550A49378693B6B
6668151728607C724023212F35333F3855C7D89A5D4C3A3E495BA183A589706B5955454E
3F37309C453B4442484744434772AD5F4F2752A3DBA07B1F181F2F1410275A817A7D8357
565B635D639A868CB096B3C3D683814D3E3C3F546A572A1D346E597382B593B6B1231D24
586E9593ADA796551D2B49371E1F605B4E3283944A505C655A66543A62AACDBFC0774521
1217438F3A2D7E9C7598D5C05B3A34576E78766D5534201A3B6840B5D4BB682B3E23151F
1F2C334C94DFCD542E4B2B216A2B1C1C2437796B46536428231B25758B808DB28F80A078
4E4055B67737293876261C27462A2E69908C8CA0B6BED69E859EACBEC65825272D3CA9A3
6D9D8A8DC0A181797EA0B05F516C9E592C2C835E4341454662944E73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 320},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001@2000`400?l00000o`00003ooooooooo
oooooh;ooooo0000aP2[Zj/0GUiN05iNGP1kNg/0QHF50;Zj^P1^KVh0>CTi05aLG01nOWh0QXJ60;Ng
]`16ATH0<30`059BDP1YJFT0IVIV0;6a/@1^KVh0:b/[04i>CP23Ph<0FUYJ0:JVYP3<c<`0CTi>02XZ
:P1VIVH0[Zj^08f=S@2[Zj/0QHF503<c<`1IFET0HF5Q0:n_[`1JFUX0P82003dm?@0e=CD0IfMW08>3
P`1EEED0K6a/07moO`0I6AT0BDU905eMG@1/K6`0@D5106=SH`1cLg<092@T051@D01YJFT0HF5Q03/k
>`1nOWh0ADE505mOG`1^KVh0V9RH03<c<`17AdL0FEUI02h^;P1JFUX0I6AT04=3@`0b<S80JVYZ03De
=@1BDU80IVIV08B4Q00h>3P0?3`l059BDP13@d<0=3@d08f=S@2VYZH0<c<c03lo?`1kNg/0@T9202h^
;P1eMGD0_kno04=3@`0_;bl0B4Q804e=C@1ADE40SXj>08J6QP0_;bl0@d=305QHF01FEUH0IVIV09jN
WP1TI6@0:b/[05IFEP1GEeL0M7Ad06UYJ@2IVIT0?clo03De=@1ADE40IVIV06ATI02_[jl0EEEE02LW
9`1CDe<0KFe]05EEE@1/K6`0Y:BT03lo?`0Q8B40ADE508J6QP1DE5@0ZZZZ0;Ng]`0e=CD0@D5104i>
CP1WIfL0EUIF0:RXZ033`l<0>CTi04=3@`1KFe/0JVYZ05MGE`2[Zj/0Ogmo03Hf=P1>CTh0JVYZ07Ee
M@1TI6@0cLg=05IFEP15ADD0HF5Q0:JVYP1jNWX0QhN70=GEe@1TI6@0>SXj07UiN@1bLW80X:2P0<O7
a`0_;bl0D51@06][J`2LW9`0UiNG0:FUY@2ATI40;Bd]05iNGP1aLG40`L7108B4Q039bLT0<S8b0492
@P1gMgL0SXj>09^KV`1LG5`0TI6A038b<P1:BTX0IVIV09FEU@1gMgL0G5aL0;Fe]@1DE5@0D51@07Ee
M@2PX:00DE5A07emO@2=SHd0A4A405QHF080HF5Q08<0<C4a07MgM`18B4P0Cdm?05ADE01dM7@0ATI6
03Hf=P1CDe<0=SHf04m?C`1bLW80N7Qh04U9B@1gMgL0FUYJ04Y:BP2:RXX0/k>c04U9B@15ADD0Hf=S
03lo?`1nOWh0`l?306a/K013@d<0LG5a04e=C@1ZJVX0^k^k09>CT`0k>c/0N7Qh06MWI`28R8P0/[:b
0;bl_01DE5@0FUYJ08J6QP1ADE40XZ:R079bLP0Z:RX0EeMG06][J`1DE5@0HV9R0;Jf]P1<C4`0<C4a
07alO02:RXX0E5AD0;:b/P2e]KD0BDU904Y:BP2EUID0LG5a07IfMP39bLT0K6a/0492@P1@D500N7Qh
07AdM01aLG40Z:RX04U9B@11@D40DU9B065QH@1bLW80ZZZZ08j>SP0a<C40>c/k04e=C@1]KFd0VYZJ
0<?3``1YJFT0<C4a04E5A@1bLW80P82009JFUP3Fe]H0JVYZ03Xj>P0o?cl0NWYj07AdM01QHF40`/;2
04M7A`0n?Sh0JVYZ06m_K`1VIVH0YZJV0<c<c01?Cdl0:RXZ06e]K@2UYJD0MgMg09VIV@3Cdm<0FEUI
01`L701SHf<0VIVI059BDP1ADE40][Jf06=SH`19BDT0I6AT09>CT`2YZJT0`<3008R8R01;Bd/0JFUY
05mOG`1EEED0MWIf055AD@0205=CD`1A05]KF`1nOWh0Hf=S075aL@1/K6`0_;bl0:6QX@21PH40IVIV
05UIF@0`<300B4Q803Hf=P1;Bd/0>3Ph05IFEP0[:b/0Cdm?03Ph>01FEUH0GemO05iNGP0m?Cd0=CDe
04A4A00o?cl0EeMG05IFEP18B4P0?Cdm04e=C@10@400>CTi02h^;P1;Bd/0De=C04m?C`0o?cl0EUIF
051@D01[Jf/0Cdm?03<c<`0];Bd0C4a<04=3@`1@D500CDe=051@D011@D40EeMG09>CT`1?Cdl0CDe=
0410@01FEUH0DE5A05QHF00`<300BTY:04i>CP1iNGT0F5QH06EUI@2GUiL0BDU904I6AP1PH600EEEE
06][J`1RHV80DE5A06YZJP1XJ6P0TI6A07MgM`17AdL0JFUY08F5Q@24Q8@0QhN70080DE5A00T0CDe=
075aL@1`L700KFe]075aL@1=CDd0H61P07YjNP1UIFD00P1dM7@03P23Ph<0MgMg059BDP1?Cdl0MWIf
07YjNP24Q8@0JFUY07]kN`1eMGD0RXZ:06QXJ02KVi/0J6QX0P26QXH0W`2PX:00Ng]k0:BTY01`L700
NWYj0:>SX`1TI6@0SHf=09>CT`23Ph<0[jn_05MGE`1fMWH0GemO06=SH`1LG5`0JVYZ069RHP21PH40
@T9209ZJVP1dM7@0Ogmo0;^k^`17AdL0][Jf0<K6aP0a<C40Ng]k0861P@0f=SH0C4a<04];B`1LG5`0
C4a<04m?C`16ATH0@T9205ADE01GEeL0Ogmo04m?C`1:BTX0B4Q806i^KP1gMgL0?clo069RHP1>CTh0
FUYJ05]KF`10@400HF5Q069RHP1MGEd0H61P01lO7`1WIfL0I6AT06=SH`1bLW80?Shn055AD@1?Cdl0
OWin079bLP28R8P0[:b/02<S8`0[:b/0BDU906][J`1:BTX0JFUY04A4A01NGUh0DU9B04a<C019BDT0
Cdm?069RHP0Z:RX0LW9b05UIF@1HF5P0IVIV034a<@16ATH0EeMG03Lg=`1?Cdl0HV9R05=CD`27QhL0
IVIV0861P@1jNWX0:b/[04U9B@1NGUh0Bd];055AD@0o?cl0QhN7059BDP22PX80ATI60:FUY@28R8P0
@41006m_K`1SHf<0FUYJ08B4Q01kNg/0>CTi05aLG01@D500HF5Q06YZJP1EEED0J6QX04I6AP1mOGd0
AdM7051@D01LG5`0LG5a07AdM02RXZ80FUYJ09bLW02j^[X0J6QX0;2`/020P800U9BD075aL@2?Shl0
XJ6Q06e]K@2JVYX0I6AT075aL@1iNGT0NWYj09FEU@20P800E5AD065QH@1gMgL0MWIf07alO01mOGd0
SXj>05eMG@1aLG40RXZ:07QhN00208B4Q00R059BDP1kNg/0JVYZ09NGU`1iNGT0`<3007IfMP1_Kfl0
JFUY0:NWY`2NWYh0;2`/06MWI`1bLW80<c<c0:RXZ02SXj<0@T9205QHF015ADD0HF5Q08N7Q`29RHT0
WinO08>3P`1hN7P0Q8B405IFEP1dM7@0K6a/0:FUY@2=SHd0[Zj^0:n_[`;ooooo0000=`1kNg/0PX:2
07IfMP1OGel0CDe=08B4Q020P800BDU907IfMP0n?Sh0ADE5065QH@1`L700IFEU07IfMP0Z:RX09BDU
092@T02PX:00A4A405=CD`19BDT07QhN03`l?02EUID0J6QX02l_;`1ADE40=cLg05UIF@1YJFT0RXZ:
055AD@0g=cL0P82004];B`1BDU80/k>c06EUI@0W9bL0@T9206m_K`0b<S80NWYj0;Vi^@0];Bd08b<S
071`L02CTi<0EEEE08n?S`2b/[80:b/[02l_;`1eMGD00P1RHV802P3@d=00OGem020P800m?Cd0Ogmo
055AD@1`L700RHV902/[:`0n?Sh2061PH03o05MGE`2a/K40;bl_03@d=01RHV80J6QX04m?C`1jNWX0
PH61024Q8@1:BTX0@41008F5Q@1lO7`0P8200;Rh^00T92@0?Shn04e=C@1fMWH0Q8B407moO`2TY:@0
<30`03Hf=P1OGel0Ng]k055AD@1aLG40XZ:R01LG5`12@T80A4A405UIF@1@D500^[Zj08>3P`0R8R80
E5AD07IfMP1bLW80GUiN0:6QX@0W9bL0>SXj07UiN@2?Shl0Bd];05ADE01JFUX0:2PX03lo?`1aLG40
Zj^[05mOG`1cLg<0@41003Hf=P1ADE40V9RH07emO@1WIfL0M7Ad03dm?@0f=SH0EUIF0::RXP1jNWX0
GUiN08N7Q`10@400?Shn08^;R`2VYZH0E5AD05]KF`1`L700Bd];04E5A@2YZJT0d=3@04e=C@1WIfL0
Jf][0492@P0n?Sh0Shn?0:j^[P0j>SX0Rh^;04M7A`13@d<0UIFE07EeM@19BDT0E5AD034a<@1ADE40
HV9R09ZJVP1QHF40De=C05YJFP0`<300N7Qh0:2PX01mOGd0>c/k05QHF02=SHd0@T92061PH03;bl/0
Shn?034a<@1TI6@0OWin069RHP1dM7@0g=cL06MWI`0j>SX0K6a/07QhN01/K6`0a/K60>GUi@0h>3P0
=CDe07AdM01]KFd0EUIF0<[:bP2XZ:P0<30`06IVIP1^KVh0Kfm_08Z:RP3>c/h0@d=304M7A`1/K6`0
T92@08b<S03?cll0WYjN02LW9`1@D500WYjN06UYJ@2d];@0]kNg034a<@0f=SH0SHf=0;fm_@2VYZH0
]kNg05]KF`0c<c<0CDe=0;^k^`24Q8@0_[jn05iNGP0e=CD0K6a/0:FUY@2:RXX0WIfM06QXJ014A4@0
GEeM07moO`1;Bd/0[jn_0:6QX@10@400AdM70861P@2BTY80Jf][07EeM@0[:b/0@T9206IVIP2HV9P0
R8R80<?3``2l_;`0FUYJ04e=C@2FUYH0_kno0820P02h^;P0Kfm_03hn?P1?Cdl0OGem07moO`28R8P0
[Zj^038b<P1DE5@0F5QH09^KV`1/K6`0PH610<71`@0k>c/0AdM70;Rh^02d];@0I6AT09ZJVP2SXj<0
CDe=055AD@2OWil0Zj^[051@D01[Jf/0=SHf0492@P1;Bd/0[Jf]0:>SX`16ATH0MgMg0451@@1ADE40
EEEE09:BTP21PH40=cLg055AD@1?Cdl0<C4a04e=C@2HV9P0[:b/051@D019BDT0JFUY03dm?@1[Jf/0
L71`05eMG@1>CTh0EeMG0<_;b`3AdM40cLg=003K0;:b/P1DE5@0MGEe08R8R01[Jf/0MWIf05mOG`1e
MGD0M7Ad06ATI01iNGT0J6QX07YjNP1bLW80PX:206EUI@1JFUX0Cdm?05aLG013@d<0DE5A051@D01V
IVH0AdM706=SH`1:BTX0HV9R04a<C01XJ6P0K6a/07moO`1;Bd/0>c/k06QXJ00h>3P0GemO05MGE`1W
IfL0=SHf06][J`1;Bd/0<C4a04=3@`1QHF40IFEU04a<C015ADD0M7Ad02LW9`1LG5`0GUiN07IfMP0_
;bl0IFEU069RHP0Z:RX0CDe=07YjNP1fMWH0H61P05=CD`16ATH0D51@04=3@`1LG5`0DU9B05iNGP19
BDT0@d=3069RHP1PH600M7Ad096AT@2g]kL0Fe]K05UIF@2XZ:P0][Jf08>3P`28R8P0PX:205eMG@19
BDT0]KFe0:ZZZP1WIfL0UiNG0;:b/P2`/;00XZ:R06YZJP1cLg<0G5aL08V9R@24Q8@0?Cdm065QH@0d
=3@0Fe]K069RHP10@400?clo06ATI01XJ6P0Cdm?030`<01<C4`0FUYJ04=3@`1ADE40CTi>05iNGP17
AdL0De=C051@D01VIVH0?Cdm05UIF@22PX80H61P05=CD`1EEED0?clo07AdM01nOWh0LG5a0:2PX01a
LG40Ogmo0:6QX@2?Shl0X:2P07AdM028R8P0Rh^;08>3P`1CDe<0Kfm_04M7A`1TI6@0Kfm_09ZJVP2e
]KD0HV9R05eMG@1JFUX0B4Q8075aL@25QHD0QhN70;6a/@1WIfL0FUYJ075aL@1JFUX0DU9B05EEE@1A
DE40@d=304a<C01=CDd0ADE503/k>`1WIfL0SXj>02h^;P1JFUX0C4a<069RHP0o?cl0ATI6051@D00D
51@0Jf][079bLP0Q8B40PX:207moO`12@T80FUYJ03dm?@1ZJVX0=cLg055AD@1>CTh0Bd];06MWI`0O
7al0>SXj06m_K`1bLW80A4A407QhN01UIFD0PX:2065QH@1GEeL0H61P03hn?P1FEUH0<S8b0;:b/P1`
L700EEEE06m_K`1HF5P0GemO08F5Q@1ADE40HV9R06m_K`1bLW80V9RH04Q8B02?Shl0RXZ:04e=C@1b
LW80LG5a0080MWIf0300AdM707IfMP1cLg<0[Zj^04Q8B02_[jl0IfMW034a<@1cLg<0IFEU04E5A@1>
CTh0EEEE038b<P1GEeL0GUiN069RHP1UIFD0J6QX07EeM@1LG5`0NWYj05aLG01OGel0K6a/06UYJ@1>
CTh0GemO05EEE@3Hf=P0^KVi07EeM@1XJ6P0YjNW0<G5a@1bLW80S8b<0:n_[`2ATI40WYjN05YJFP1h
N7P0MGEe0;:b/P2QXJ40Ph>3069RHP29RHT20:n_[`0[06EUI@16ATH0GemO05=CD`1hN7P0Ti>C08R8
R01GEeL0M7Ad06=SH`2ZZZX0G5aL08^;R`1oOgl0UYJF07moO`3EeMD0LW9b05=CD`1cLg<0>3Ph0:j^
[P2FUYH0A4A40;jn_P2m_Kd0De=C07emO@15ADD0@T9206UYJ@1nOWh0Rh^;05eMG@1mOGd0GemO04E5
A@1=CDd0Ng]k09RHV01/K6`0RXZ:0:^[Z`02ooooo`0003<0MWIf079bLP2PX:00NGUi03dm?@1JFUX0
Ogmo08^;R`21PH40A4A402`/;01=CDd0IFEU07QhN02TY:@0?clo01dM7@0^;Rh0Lg=c07alO01dM7@0
D51@01/K6`0X:2P0De=C07EeM@2HV9P0YZJV04m?C`0n?Sh0JVYZ07alO01nOWh0WinO0;Jf]P0i>CT0
>c/k06ATI02QXJ40DU9B0:FUY@1OGel0;Bd]03`l?01bLW80NGUi05IFEP2GUiL0JFUY024Q8@1=CDd0
0P1eMGD0:@1/K6`0QhN703De=@0Q8B40F5QH09FEU@1FEUH0J6QX04A4A00L71`0;bl_06m_K`1SHf<0
AdM7061PH00K6a/09RHV05=CD`21PH40B4Q804Y:BP1OGel08R8R059BDP21PH40B4Q802`/;01ADE40
CTi>04E5A@1FEUH0U9BD03Xj>P0];Bd0Jf][059BDP0e=CD0De=C09:BTP1IFET0:b/[0080EUIF04P0
K6a/08N7Q`2RXZ80EeMG04E5A@1`L700>SXj05MGE`2CTi<0Q8B4030`<014A4@0GUiN04m?C`1`L700
YJFU05YJFP0[:b/0OGem07]kN`1EEED0PX:20:JVYP0c<c<0=CDe05iNGP1gMgL0HV9R09BDU01eMGD0
:BTY04U9B@12@T80Q8B407UiN@2o_kl0AdM703/k>`17AdL0N7Qh06ATI01mOGd0^;Rh05YJFP0N7Qh0
FUYJ09jNWP1_Kfl0MWIf09NGU`0f=SH0:b/[06m_K`2f][H0Ng]k08R8R02<S8`0<30`05UIF@1JFUX0
Ti>C06e]K@2XZ:P0DU9B06e]K@24Q8@0JFUY09fMW@2a/K40;Bd]03Xj>P1WIfL206][J`3n092@T02Q
XJ40:b/[059BDP1VIVH0ZJVY08>3P`28R8P0Y:BT03lo?`1BDU80MWIf0<?3``1hN7P0`<3008J6QP16
ATH0CDe=09fMW@3MgMd0Lg=c09fMW@11@D40GemO07IfMP32`/80b<S806IVIP2ATI40@d=306i^KP1N
GUh0UIFE06YZJP1mOGd0Ph>3030`<01GEeL0Y:BT08N7Q`1dM7@0P820030`<01@D500Zj^[0<G5a@1`
L700SXj>09RHV00h>3P0CTi>09bLW01]KFd0GUiN07moO`0f=SH0HV9R08f=S@2FUYH0CTi>07YjNP0o
?cl0I6AT0<g=c@2OWil0CTi>09:BTP1NGUh0EeMG09jNWP31`L40EeMG07EeM@1hN7P0Bd];06i^KP2o
_kl0Cdm?03dm?@1[Jf/0AdM708N7Q`37alL0LG5a03Ph>02CTi<0HV9R03@d=01aLG40a<C409RHV01/
K6`0L71`06IVIP1IFET0Q8B40;Vi^@1TI6@0HF5Q07alO011@D40Ng]k0=;BdP1WIfL0ADE506YZJP1^
KVh0GemO08b<S03@d=00FUYJ03/k>`23Ph<0NGUi07AdM02DU9@0d];B05iNGP0i>CT0MgMg09BDU020
P800cLg=06UYJ@0Y:BT0BDU9075aL@2QXJ40IfMW0<G5a@1bLW80@410055AD@1bLW80Zj^[06e]K@2U
YJD0JFUY024Q8@0k>c/0Fe]K08n?S`2FUYH0TI6A07]kN`0K6a/0;Bd]04U9B@1CDe<0D51@05eMG@24
Q8@0KFe]07=cL`2LW9`0MgMg07EeM@1WIfL0@T92071`L01[Jf/0M7Ad061PH01GEeL0QhN707YjNP1f
MWH0IfMW06IVIP1bLW80OWin05iNGP19BDT0>3Ph069RHP1;Bd/0@T9203Ti>@1/K6`0DE5A03Lg=`0^
;Rh0K6a/08j>SP1DE5@0>c/k04Y:BP2EUID0Fe]K05mOG`1VIVH0HV9R04M7A`1PH600Bd];03Ti>@0h
>3P0IVIV07=cL`1?Cdl0C4a<06IVIP13@d<0NGUi06QXJ01hN7P0:BTY092@T02CTi<0BTY:06i^KP2G
UiL0O7al09bLW01JFUX0LG5a08J6QP1:BTX0R8R804i>CP1GEeL0Bd];04Y:BP17AdL0Kfm_0820P02J
VYX0Zj^[03`l?00m?Cd0QhN70<?3``1kNg/0C4a<04];B`1@D500JFUY0:FUY@1eMGD0@T9205mOG`1m
OGd0^;Rh07UiN@0o?cl0EeMG05=CD`1?Cdl0DU9B04Y:BP1<C4`0>SXj04M7A`1EEED205IFEP2f07If
MP1UIFD0GUiN03Ph>01DE5@0Hf=S051@D01NGUh0EeMG07EeM@1:BTX0Jf][06IVIP1dM7@0EEEE07If
MP2YZJT0YJFU05EEE@1jNWX0@D51079bLP1lO7`0AdM706a/K01^KVh0PH61071`L01?Cdl0J6QX05eM
G@1;Bd/0@41005]KF`1@D500TY:B03Ph>02>SXh0MWIf07QhN02i^KT0>3Ph079bLP29RHT0>CTi069R
HP2@T900GEeM06UYJ@1HF5P0Cdm?06m_K`1iNGT0F5QH08j>SP1NGUh0R8R805ADE01^KVh0FEUI0451
@@1fMWH0XZ:R0451@@1YJFT0De=C05MGE`0n?Sh0Jf][06a/K00i>CT0IVIV06i^KP1EEED0bLW90<;2
`P1RHV80G5aL04];B`1UIFD08R8R06UYJ@1/K6`0G5aL092@T00J6QX08b<S03dm?@1@D500?Cdm065Q
H@10@400SXj>07alO012@T80BTY:05QHF01_Kfl07AdM065QH@19BDT0N7Qh0:BTY016ATH0@D51051@
D00d=3@0PH61096AT@1PH600OWin05IFEP1[Jf/0Lg=c05YJFP1:BTX0D51@06IVIP1_Kfl0EEEE079b
LP1ADE40QHF507AdM039bLT0PH6104a<C02=SHd0Kfm_03lo?`1KFe/0Hf=S04A4A01_Kfl0DU9B05IF
EP24Q8@0IFEU06i^KP1PH600UIFE05UIF@1OGel0Kfm_075aL@1KFe/0HF5Q06EUI@2=SHd0Ogmo04Y:
BP1/K6`0RHV90820P02?Shl0WYjN0:^[Z`1JFUX0MWIf03De=@1VIVH0JVYZ06m_K`1hN7P0SXj>08n?
S`2DU9@0FUYJ06i^KP1<C4`0R8R808j>SP0n?Sh0NWYj09RHV01ZJVX0U9BD092@T02;Rh/0WIfM0:f]
[@2/[:`206e]K@0L07AdM02XZ:P0PX:206=SH`1WIfL0EEEE07IfMP1cLg<0B4Q80;6a/@2?Shl0B4Q8
06a/K01TI6@0@T9206m_K`1[Jf/0QXJ606a/K02SXj<0Shn?04M7A`1lO7`0W9bL0;Zj^P1gMgL0XJ6Q
0<S8b0;ooooo0000Y02YZJT0HF5Q08f=S@2][Jd0GEeM0:2PX01iNGT0?3`l0:2PX02c/k<0OWin071`
L00Q8B40EEEE06EUI@1kNg/0@T9207alO016ATH0@d=306m_K`2LW9`0@41008:2PP24Q8@0;Bd]02l_
;`2WYjL0[Jf]03Ph>01RHV80KFe]04Y:BP1gMgL0^[Zj096AT@0n?Sh0Fe]K05IFEP0d=3@0O7al08F5
Q@0Y:BT0;Rh^05EEE@1>CTh0@d=309FEU@2:RXX08b<S03@d=01NGUh0Bd];05QHF02g]kL0H61P034a
<@11@D40DU9B06IVIP2TY:@0Vi^K02@T900i>CT0B4Q80451@@23Ph<0YjNW03De=@0_;bl0BDU9051@
D01PH600UIFE08b<S00S8b<0ADE505UIF@1JFUX0DU9B0:2PX01TI6@07AdM059BDP1`L700NWYj055A
D@31`L40]kNg02<S8`0[:b/0?clo07=cL`1nOWh0][Jf061PH00O7al0Bd];05aLG01]KFd0P82009VI
V@0m?Cd07AdM04];B`1aLG40AdM707UiN@2RXZ80<S8b04I6AP1VIVH0T92@05iNGP37alL0EEEE04=3
@`1=CDd0MWIf09:BTP1ZJVX0MWIf030`<01_Kfl0Fe]K07]kN`1JFUX0Jf][07QhN00^;Rh0E5AD06QX
J02OWil0CTi>079bLP2<S8`0<c<c05]KF`1YJFT0NWYj05UIF@1hN7P0MWIf04M7A`1?Cdl0P82007Ad
M01:BTX0O7al04U9B@1DE5@0KVi^0820P01LG5`0JFUY07QhN00/;2`0GUiN0820P01SHf<0Bd];08R8
R00k>c/0B4Q80P2LW9`0/@1@D500IVIV07]kN`0^;Rh0H61P08R8R01nOWh0C4a<08j>SP1OGel0EUIF
07QhN039bLT0Ogmo0410@02<S8`0FEUI03Ti>@2LW9`0];Bd04Q8B010@400IFEU055AD@1LG5`0b/[:
08R8R00m?Cd0EEEE06e]K@1hN7P0TY:B0=cLg01[Jf/0?3`l075aL@1MGEd0HF5Q0;Bd]03=cLd0=cLg
02XZ:P1bLW80GUiN08J6QP32`/80CDe=02`/;01>CTh0VIVI07YjNP35aLD0c/k>03Ti>@1kNg/0Z:RX
06i^KP2;Rh/0hN7Q05aLG00Z:RX0R8R807MgM`1mOGd0]KFe04Q8B014A4@0L71`0:^[Z`1[Jf/0bLW9
05=CD`16ATH0E5AD0<K6aP1gMgL0WIfM07alO01<C4`0F5QH08R8R02[Zj/0QXJ60;Bd]00f=SH0AdM7
08>3P`2MWId0CTi>0;>c/`1hN7P0=cLg0451@@2b/[80PX:209VIV@2WYjL0=SHf05MGE`21PH40Y:BT
08b<S02?Shl0/K6a03/k>`13@d<0YJFU08Z:RP1kNg/0^k^k08F5Q@19BDT0MgMg08f=S@2OWil0IVIV
09jNWP1@D500AdM706MWI`2HV9P0UYJF079bLP2RXZ80EUIF0451@@2:RXX0S8b<03dm?@19BDT0LG5a
04e=C@0k>c/0GEeM0:NWY`1GEeL0IFEU06ATI00_;bl0GemO07=cL`1dM7@0ADE5065QH@1]KFd0?3`l
03/k>`2ATI40];Bd03dm?@0];Bd0H61P04A4A01?Cdl0F5QH0:NWY`2f][H0_;bl09nOW`19BDT0EeMG
06EUI@1@D500H61P071`L01QHF40DE5A05EEE@1]KFd0AdM705UIF@1bLW80S8b<07inOP1BDU80=SHf
04e=C@0203Lg=`2j03Ph>019BDT0@d=305YJFP0a<C40>c/k0410@01BDU80A4A405]KF`0f=SH0?clo
04A4A012@T80BDU905ADE011@D40>c/k04=3@`18B4P0?Cdm02XZ:P15ADD0Bd];05IFEP18B4P0DU9B
04E5A@28R8P0Lg=c05eMG@0W9bL0BTY:05]KF`1DE5@0EeMG04e=C@1DE5@0P82006UYJ@1FEUH0MWIf
055AD@1VIVH0DU9B05IFEP1DE5@0?Cdm04e=C@1MGEd0NGUi07alO02<S8`0EUIF055AD@1QHF40Kfm_
09BDU02RXZ80OWin05MGE`1ADE40Vi^K0:j^[P23Ph<0UIFE08B4Q02DU9@0RHV905mOG`1<C4`0FUYJ
06EUI@1YJFT0EEEE071`L01:BTX0EUIF06a/K01PH600GEeM05iNGP1TI6@0Hf=S0451@@0c<c<0AdM7
05IFEP1aLG40Cdm?05]KF`1JFUX0H61P03lo?`1YJFT0L71`06QXJ01HF5P0HF5Q06a/K01jNWX0@410
03Lg=`1KFe/0MWIf0:2PX01]KFd0PH6108R8R01aLG40MWIf06IVIP1GEeL0AdM7059BDP1:BTX0Ti>C
03dm?@2ATI40GemO07IfMP2CTi<0?3`l0:f][@2o_kl0F5QH06IVIP1kNg/0KVi^08J6QP1HF5P0De=C
05eMG@1>CTh0DU9B092@T024Q8@0OGem05EEE@1OGel0KVi^065QH@2=SHd0WIfM06MWI`1cLg<0F5QH
069RHP19BDT09BDU05IFEP1>CTh0IfMW08:2PP1DE5@0H61P051@D01DE5@0F5QH07MgM`2?Shl0@D51
07QhN01dM7@0NGUi08R8R00a<C40=3@d04=3@`1_Kfl0DE5A06YZJP1EEED0LW9b069RHP1CDe<0BDU9
034a<@1?Cdl07alO0:f][@1MGEd0Bd];051@D01DE5@0AdM70P1FEUH0:@1LG5`0QXJ607emO@2o_kl0
MGEe06YZJP2:RXX0Cdm?05]KF`1[Jf/0IFEU09FEU@1cLg<0Vi^K07YjNP27QhL0Ogmo0<30`02IVIT0
FEUI05]KF`1SHf<0Jf][0:FUY@2DU9@0Cdm?05QHF01GEeL0IfMW05mOG`1^KVh0L71`06EUI@1lO7`0
CDe=065QH@1OGel0IVIV07AdM02BTY80Ng]k0080[jn_03h0SHf=08:2PP2OWil0Xj>S05UIF@2MWId0
QhN7069RHP1eMGD0>SXj08J6QP1LG5`0MgMg06i^KP1`L700F5QH06a/K01OGel0M7Ad06=SH`1=CDd0
G5aL065QH@1kNg/0MWIf075aL@23Ph<0RXZ:05YJFP1bLW80GUiN09RHV01>CTh0Ti>C09jNWP2_[jl0
HV9R051@D01]KFd0DE5A07=cL`2[Zj/0VYZJ0:2PX02IVIT0E5AD06e]K@1XJ6P0GEeM0::RXP2@T900
OGem05UIF@1ADE40Cdm?04U9B@1OGel0P82008:2PP21PH40Xj>S09NGU`;ooooo0000o`2LW9`0MGEe
05eMG@29RHT0J6QX0:b/[02;Rh/0;Rh^04a<C01HF5P0RHV909BDU00c<c<0<C4a05]KF`1CDe<0D51@
0<;2`P1hN7P06a/K055AD@20P800ATI608j>SP2^[Zh0@T9201`L701RHV80_[jn08V9R@2g]kL0TI6A
03dm?@24Q8@0Y:BT09NGU`1_Kfl0b<S804];B`0W9bL0BTY:09^KV`1]KFd0Q8B408F5Q@0Y:BT0>c/k
04U9B@2GUiL0IFEU08V9R@2CTi<0:2PX03Lg=`1<C4`0U9BD06m_K`2FUYH0=cLg04Y:BP1?Cdl0OWin
06e]K@24Q8@0Cdm?034a<@11@D40IFEU059BDP1LG5`0PX:203<c<`0m?Cd0ATI608>3P`1YJFT0EEEE
08j>SP0M7Ad0=CDe06MWI`2ATI40ADE50410@01kNg/061PH02l_;`1ZJVX0TY:B08J6QP1VIVH0TY:B
01PH600U9BD0SHf=0:>SX`15ADD0FEUI069RHP0R8R80<S8b07MgM`2;Rh/0?3`l06UYJ@1>CTh0:BTY
05EEE@2[Zj/0FEUI059BDP1KFe/0<30`03Hf=P1YJFT0SHf=03@d=01DE5@0B4Q803<c<`1bLW80QhN7
051@D019BDT0QXJ6065QH@0^;Rh0QhN70<?3``1?Cdl0@D5107IfMP1eMGD0?Shn092@T02LW9`0@D51
04U9B@1YJFT0GEeM055AD@2=SHd0WIfM03Ti>@1CDe<0FUYJ065QH@1dM7@0T92@06=SH`0k>c/0HF5Q
079bLP1ADE40QhN70=7Ad@1EEED0>SXj07YjNP1/K6`0XZ:R0<g=c@1BDU80?Cdm06EUI@1/K6`0KFe]
0;^k^`2PX:00>SXj0410@01iNGT0VYZJ07EeM@2m_Kd0OWin04=3@`1cLg<0YZJV0=GEe@2>SXh0f][J
0451@@15ADD0JFUY08j>SP2b/[80YjNW0<S8b00l?3`0DE5A0:b/[02LW9`0GEeM0:>SX`2OWil0<C4a
04A4A02[Zj/0X:2P06EUI@2i^KT0D51@03<c<`16ATH0^KVi0:2PX023Ph<0KFe]03Ti>@1?Cdl0I6AT
0:^[Z`1gMgL0LG5a07alO00`<300H61P0;jn_P2KVi/0L71`0:VYZ@1PH600ATI608V9R@2o_kl0I6AT
09bLW016ATH0E5AD09bLW026QXH0DU9B07IfMP1BDU80H61P09^KV`22PX80EEEE07UiN@1SHf<0Fe]K
08>3P`2NWYh0>3Ph075aL@1PH600@D5105]KF`3<c<`0NGUi03Ti>@1OGel0CTi>04A4A000``2IVIT0
W9bL03lo?`12@T80O7al05YJFP1bLW80X:2P08>3P`11@D40IVIV09VIV@1<C4`0Ph>30<?3``1lO7`0
@T92071`L01OGel0DU9B08N7Q`2SXj<0@T9204U9B@2EUID0CDe=07IfMP3>c/h0S8b<034a<@18B4P0
G5aL06m_K`2=SHd0aLG507QhN00`<300HF5Q09VIV@1=CDd0Ng]k0;jn_P10@400?clo04Y:BP1nOWh0
FEUI0:RXZ03>c/h0AdM702d];@1]KFd0/[:b04A4A02LW9`0[Zj^03lo?`0O7al0<c<c09JFUP1NGUh0
KVi^0;Vi^@17AdL0C4a<06IVIP3Cdm<0bl_;0=cLg02i^KT0FEUI071`L02<S8`0E5AD08V9R@1SHf<0
Q8B4065QH@1DE5@0Vi^K05mOG`29RHT0PH6109>CT`2a/K40Q8B406=SH`1KFe/08b<S04i>CP0g=cL0
C4a<03Ph>01VIVH092@T02LW9`0S8b<0GEeM06MWI`1bLW80<c<c04Q8B02@T900HV9R04m?C`1WIfL0
M7Ad03`l?01_Kfl0Bd];02`/;00i>CT0FEUI05YJFP1;Bd/0?clo05eMG@11@D40BTY:055AD@1KFe/0
:RXZ05YJFP1ADE40=3@d04a<C01TI6@0E5AD05mOG`1LG5`0@D51055AD@0g=cL0ADE504];B`1EEED0
?clo04I6AP1RHV80De=C06a/K024Q8@0S8b<06IVIP1bLW80Ti>C09jNWP1IFET0BDU904Y:BP1CDe<0
A4A40<g=c@2k^k/0@D5104];B`1PH600]kNg07emO@1FEUH0CTi>0492@P1IFET0IFEU03`l?010@400
?clo06=SH`1:BTX0?clo04E5A@1/K6`0CTi>03dm?@0l?3`0CDe=051@D00g=cL0@410051@D01EEED0
?Cdm04a<C01?Cdl0BTY:03Ti>@1@D500S8b<07EeM@18B4P0CDe=0492@P1/K6`0HV9R04e=C@0205aL
G00405QHF01;Bd/0Ogmo06m_K`80De=C09<0MgMg06e]K@19BDT0K6a/03/k>`1dM7@0BTY:07moO`2h
^;P0?clo06=SH`1WIfL0>c/k051@D01>CTh0IVIV08^;R`15ADD0>c/k04E5A@1ZJVX0G5aL04a<C01>
CTh0OWin04a<C01aLG40Bd];06QXJ02LW9`0YZJV06UYJ@1NGUh0KVi^079bLP1QHF40=cLg05=CD`14
A4@0N7Qh07YjNP1JFUX0PH6107emO@1TI6@0EEEE06YZJP1GEeL0D51@06i^KP2?Shl0GemO06][J`10
@400?3`l03lo?`1TI6@0KFe]0:ZZZP2LW9`0Vi^K07MgM`1bLW80IFEU04];B`1GEeL0>SXj05aLG01=
CDd0JVYZ075aL@1OGel0IfMW07YjNP1HF5P0Lg=c07IfMP1<C4`0GUiN059BDP2UYJD0JFUY04I6AP2c
/k<0S8b<06UYJ@1`L700JFUY09FEU@1OGel0SHf=08R8R01@D500B4Q805ADE01_Kfl0JVYZ059BDP1E
EED0G5aL04M7A`1DE5@0MGEe0820P01iNGT0LG5a08V9R@1ZJVX0QHF506a/K01YJFT0J6QX075aL@1g
MgL0JVYZ071`L02SXj<0LG5a05YJFP2a/K40Kfm_09JFUP15ADD0Q8B408Z:RP1fMWH0SHf=05UIF@2=
SHd0JVYZ06][J`2OWil0X:2P061PH01lO7`0Shn?08F5Q@1EEED0C4a<079bLP1dM7@0Lg=c07inOP1b
LW80HV9R08j>SP1FEUH00P2@T9007`31`L40UIFE0;Bd]028R8P0^KVi07=cL`24Q8@0S8b<04i>CP1j
NWX0TI6A059BDP2;Rh/0Xj>S051@D01bLW80N7Qh05EEE@1LG5`0Ogmo08f=S@1OGel0SHf=05mOG`1@
D500EEEE08R8R02BTY80FUYJ07YjNP2EUID00_ooool0000;06e]K@2MWId0W9bL06EUI@16ATH0EEEE
07=cL`1DE5@0T92@02h^;P0d=3@00P1XJ6P0o`1;Bd/0N7Qh02l_;`0S8b<0Fe]K092@T01:BTX0KVi^
05QHF00I6AT0:b/[092@T02DU9@0GemO05eMG@0R8R80De=C06=SH`1`L700BTY:03@d=01KFe/0>c/k
06m_K`1aLG40DE5A03De=@0l?3`0CTi>02d];@1oOgl0/[:b04e=C@0^;Rh0@d=304I6AP0o?cl0QXJ6
0<W9b@1;Bd/0?Shn06m_K`1BDU80JVYZ09JFUP1WIfL0820P04];B`1NGUh0<c<c08n?S`2e]KD0=3@d
03De=@1MGEd0?clo05eMG@1kNg/0BTY:02<S8`1NGUh0HV9R051@D01GEeL0Vi^K05mOG`0E5AD0CDe=
08:2PP1cLg<0PX:20;Rh^00P8200:RXZ0410@01XJ6P0KFe]09nOW`3Ng]h08B4Q02@T901EEED0IVIV
051@D02MWId0`L7102DU9@10@400C4a<07AdM01RHV80cLg=08J6QP0N7Qh0BTY:07]kN`1CDe<0KVi^
06YZJP0X:2P092@T04];B`2<S8`0HV9R09bLW01hN7P09RHV02`/;01hN7P0Rh^;06UYJ@2GUiL0HF5Q
04m?C`1ADE40GEeM07IfMP1XJ6P0X:2P06IVIP0i>CT0OGem0:JVYP1BDU80HV9R0::RXP1?Cdl0EeMG
05IFEP2MWId0IfMW09>CT`2SXj<0>c/k05ADE01mOGd0MgMg05aLG02CTi<0UIFE03Lg=`12@T80]KFe
0;Ng]`1NGUh0UIFE05IFEP1EEED0YZJV09>CT`1LG5`0J6QX0451@@1<C4`0HF5Q09ZJVP1PH600HF5Q
061PH00Q8B40ADE507IfMP2PX:00I6AT08B4Q02DU9@0;Bd]05eMG@2j^[X0PX:204e=C@1nOWh0Ng]k
03Xj>P1_Kfl0d=3@06YZJP0n?Sh0LW9b06IVIP14A4@0UiNG0=;BdP1WIfL0C4a<07AdM019BDT0@410
09jNWP2[Zj/0ATI605mOG`1CDe<0EEEE09NGU`2ATI40De=C069RHP20P800IVIV05MGE`2XZ:P0WinO
03Ti>@12@T80Ng]k09ZJVP2DU9@0Xj>S065QH@1@D500Kfm_08R8R02>SXh0cLg=05YJFP12@T80Ogmo
09fMW@1/K6`0]KFe05ADE00n?Sh0U9BD0:JVYP2FUYH0Z:RX06a/K00i>CT0EUIF0:BTY01gMgL0_[jn
0:BTY00Y:BT0>c/k08j>SP2CTi<0KVi^09:BTP0U9BD0=3@d069RHP2[Zj/0Shn?0:ZZZP2LW9`0:2PX
04U9B@1MGEd0OGem08V9R@2n_[h0Ng]k03lo?`00B@1KFe/0R8R80:BTY02DU9@0/;2`02l_;`0h>3P0
FUYJ06QXJ02ATI40T92@0<o?c`0j>SX0=3@d04m?C`2WYjL0EEEE08J6QP1gMgL0?Shn055AD@2j^[X0
XZ:R055AD@2>SXh0GemO03Ph>019BDT0d];B0:NWY`1TI6@0NWYj04M7A`12@T80EUIF0;no_`2MWId0
HF5Q0861P@1>CTh0:BTY04A4A02CTi<0[Zj^05=CD`1WIfL0FEUI02PX:00m?Cd0O7al07inOP1:BTX0
H61P0::RXP2<S8`0W9bL0:BTY01OGel0I6AT08N7Q`1^KVh0M7Ad06YZJP1hN7P0PX:2061PH01]KFd0
H61P08>3P`2@T900V9RH08B4Q01eMGD00P1WIfL0L@14A4@0F5QH03lo?`1ADE40@410051@D00f=SH0
CTi>0410@01QHF40FUYJ06IVIP10@400ATI60820P01[Jf/0FUYJ06EUI@1iNGT0Bd];07QhN00h>3P0
<30`02`/;01KFe/0GEeM06QXJ017AdL0G5aL01dM7@1^KVh0MWIf08:2PP0K6a/0N7Qh09VIV@18B4P0
HV9R08N7Q`1QHF40QHF505EEE@1WIfL0PH6103`l?01kNg/0BDU904Q8B01<C4`0@T9204=3@`15ADD0
GUiN07emO@30`<00DE5A05UIF@2FUYH0[Zj^08F5Q@1iNGT0Lg=c08>3P`1@D500VYZJ0<G5a@1<C4`0
KVi^09JFUP2f][H0];Bd05QHF01NGUh0ADE506YZJP1_Kfl0Bd];065QH@0W9bL0B4Q8065QH@1CDe<0
ADE504A4A01HF5P0DE5A038b<P0[:b/0@T9204e=C@1RHV80F5QH05UIF@1FEUH0IVIV05IFEP1ZJVX0
Cdm?05IFEP0n?Sh0EUIF051@D01RHV80GEeM061PH01MGEd0CDe=06MWI`0o?cl0<C4a03`l?01;Bd/0
DE5A0080EUIF0;@0?3`l055AD@1TI6@0Ogmo03lo?`1kNg/0B4Q8061PH02=SHd0BTY:09VIV@2ATI40
<c<c04=3@`1BDU80BTY:05mOG`0n?Sh0?clo0451@@1ADE40Cdm?04I6AP1bLW80@d=305UIF@1=CDd0
E5AD05IFEP1OGel0KVi^05aLG02=SHd0D51@06IVIP1FEUH0De=C06YZJP0h>3P08b<S0492@P10@400
];Bd0:FUY@1EEED0PX:203lo?`1hN7P0CDe=08>3P`1nOWh0G5aL071`L01UIFD0B4Q803dm?@1aLG40
LW9b05IFEP1RHV80M7Ad06=SH`1?Cdl0H61P06UYJ@1WIfL0FEUI0861P@1IFET0GEeM0861P@1ZJVX0
?clo04I6AP1EEED0N7Qh08R8R02:RXX0S8b<09FEU@2YZJT0Vi^K055AD@1lO7`0UYJF07inOP2LW9`0
GemO08R8R02CTi<0aLG509:BTP1oOgl0B4Q8061PH02@T900Shn?051@D01OGel0MGEe06QXJ01YJFT0
HF5Q07MgM`22PX80NWYj06][J`1YJFT0L71`04i>CP1hN7P0Ng]k071`L01HF5P0IFEU06][J`2d];@0
MWIf0451@@1OGel0MgMg0:BTY01UIFD0bLW90:ZZZP2BTY80PH6105IFEP1TI6@0V9RH09JFUP21PH40
Jf][08B4Q02>SXh0XZ:R0;fm_@1_Kfl0CTi>079bLP21PH40SXj>092@T01[Jf/0G5aL09JFUP1VIVH0
QhN7075aL@2i^KT0JFUY061PH02:RXX0a<C408j>SP2DU9@0XJ6Q06UYJ@2EUID0_kno09BDU039bLT0
[Jf]05]KF`1fMWH0Bd];04m?C`1cLg<0KVi^06a/K01:BTX0EUIF05=CD`13@d<0KFe]0:BTY02HV9P0
OGem08n?S`2CTi<2ooooo`0003L0RHV906IVIP1cLg<0UiNG04i>CP1YJFT0Fe]K04i>CP2KVi/0F5QH
02l_;`19BDT0CTi>05eMG@2MWId0@D5102DU9@0];Bd0H61P04U9B@26QXH0T92@02TY:@11@D40DE5A
08^;R`26QXH0bl_;04e=C@0W9bL0IFEU06IVIP1aLG40[:b/0:^[Z`0Y:BT0=3@d07QhN01]KFd0Fe]K
09JFUP1bLW80;Rh^034a<@1EEED0KFe]06=SH`2f][H0DE5A03/k>`1;Bd/0MgMg08j>SP22PX80]kNg
0080<c<c0:00GUiN0861P@12@T80Ogmo07=cL`0I6AT0@D5109FEU@1CDe<0Hf=S06][J`0F5QH0>CTi
055AD@1>CTh0A4A406UYJ@1ZJVX051@D03lo?`19BDT0OWin0492@P22PX80TY:B02PX:00o?cl0Zj^[
05mOG`10@400SHf=07MgM`0^;Rh0?3`l0;no_`2SXj<0AdM709BDU00d=3@0=SHf0410@02GUiL0CDe=
03Ti>@1ZJVX0=3@d03`l?01fMWH0WinO061PH01BDU80FUYJ03`l?018B4P0NWYj05iNGP1JFUX0MWIf
03Hf=P0n?Sh0IVIV07]kN`1:BTX0CTi>06a/K010@400B4Q807alO01^KVh0=cLg04a<C01RHV80<C4a
03hn?P21PH40`/;205UIF@1oOgl0RXZ:04U9B@1MGEd0NGUi05=CD`14A4@0GUiN051@D01MGEd0K6a/
0:n_[`1FEUH0?Cdm06a/K01ADE40B4Q80:JVYP2UYJD0?Cdm0451@@1lO7`0J6QX06][J`2f][H0CDe=
04I6AP1BDU80I6AT07moO`22PX80=3@d03Hf=P10@400SXj>07UiN@2ATI40_[jn02/[:`0j>SX0De=C
08N7Q`1YJFT0_[jn0=kNgP17AdL0BDU9061PH02?Shl0Q8B40=WIf@2HV9P0>3Ph07emO@2`/;00TI6A
07AdM02ZZZX0Bd];030`<026QXH0[jn_07emO@2GUiL0^KVi03Lg=`11@D40O7al08R8R021PH40^[Zj
08f=S@0W9bL0@T920:VYZ@27QhL0Ogmo0:JVYP1>CTh0@41004a<C03?cll0Rh^;0P2BTY80:P0/;2`0
HF5Q09>CT`2ATI40LW9b09BDU011@D40BTY:08F5Q@2PX:00H61P0::RXP10@400Fe]K08j>SP2CTi<0
LG5a0:6QX@19BDT0ATI60:FUY@2f][H0JFUY0:6QX@1iNGT0<C4a07EeM@2YZJT0DU9B08f=S@2WYjL0
@D5106m_K`2[Zj/0Jf][06ATI025QHD0De=C04E5A@1PH600d];B07=cL`80MGEe03/0CTi>04U9B@2;
Rh/0cLg=05]KF`2;Rh/0K6a/04Y:BP1]KFd0WinO06m_K`0e=CD0I6AT05=CD`1KFe/0OGem0<S8b01k
Ng/0A4A4079bLP1^KVh0LW9b0<?3``2g]kL0C4a<05ADE01RHV80RHV905eMG@2e]KD0^KVi03/k>`0a
<C40P82005YJFP20P800eMGE06m_K`0j>SX0@d=3092@T01kNg/0IFEU0:>SX`2h^;P0<S8b0410@01Q
HF40GUiN07inOP2UYJD0SXj>028R8P0Y:BT0?3`l069RHP1MGEd0EEEE0;Zj^P0209JFUP0Q07QhN01U
IFD0LG5a051@D013@d<0E5AD06ATI01WIfL0EEEE04];B`1[Jf/0LW9b06m_K`1EEED0?clo03dm?@1I
FET0GEeM0410@00f=SH0CDe=04a<C00n?Sh0=cLg05UIF@1ADE40=SHf03Lg=`1ADE40GEeM055AD@0j
>SX0@4100080GemO04h0GUiN06UYJ@1YJFT0C4a<05MGE`0a<C40=CDe03Hf=P1UIFD0IfMW05IFEP1?
Cdl0IFEU03Ti>@1/K6`0Hf=S069RHP0N7Qh0K6a/071`L014A4@0ATI605aLG01QHF40Jf][04i>CP0i
>CT0OGem0492@P23Ph<0De=C04a<C01@D500Bd];04a<C01?Cdl0Fe]K0820P02k^k/0De=C05iNGP25
QHD0][Jf09BDU01fMWH0EeMG05mOG`1MGEd0@41008N7Q`1@D500Hf=S092@T035aLD0`/;2065QH@1g
MgL0De=C096AT@28R8P0CDe=07moO`1<C4`0KFe]07IfMP1GEeL0GUiN0861P@1fMWH0H61P03@d=01<
C4`0J6QX05=CD`1bLW80E5AD06e]K@1=CDd205UIF@0C07emO@1HF5P0GEeM06YZJP23Ph<0F5QH07Yj
NP1@D500F5QH0861P@1ADE40J6QX05MGE`1RHV80NWYj04];B`1FEUH0@41006EUI@02059BDP1M04E5
A@1fMWH0BDU908N7Q`1_Kfl0Z:RX0;Bd]01CDe<0b<S80<?3``0];Bd0EeMG05QHF01?Cdl0LG5a02l_
;`0i>CT0=CDe04m?C`1NGUh0ADE505mOG`18B4P0NGUi0492@P1:BTX0C4a<07]kN`1]KFd0?clo04a<
C01DE5@0LW9b038b<P0Y:BT0Bd];01dM7@0h>3P0Bd];02DU9@1SHf<0Fe]K05eMG@1JFUX0Cdm?08:2
PP17AdL0Ng]k065QH@1=CDd0JFUY014A4@10@400I6AT07EeM@0o?cl0K6a/07UiN@1[Jf/0LW9b05]K
F`1?Cdl0D51@07emO@12@T80Q8B406=SH`1mOGd0Z:RX07UiN@1:BTX0CDe=061PH01oOgl0S8b<05eM
G@23Ph<0NGUi0:2PX01gMgL0AdM7079bLP2:RXX0WinO096AT@1MGEd0VYZJ05MGE`1SHf<0GUiN05eM
G@1ADE40ADE50080CTi>02H0ADE50:>SX`20P800CDe=06IVIP1CDe<0LG5a06e]K@1SHf<0J6QX05AD
E01^KVh0Cdm?055AD@18B4P0De=C05ADE01NGUh0EeMG08R8R01VIVH0B4Q80:^[Z`1`L700PX:205MG
E`29RHT0Ng]k05YJFP1PH600OWin08Z:RP1_Kfl0H61P08>3P`1mOGd0NGUi06MWI`80HF5Q02/0IVIV
07EeM@2@T900EEEE0:JVYP2o_kl0@T9208>3P`2XZ:P0XJ6Q09JFUP25QHD0PH6105=CD`1nOWh0GEeM
06UYJ@1FEUH0RXZ:08V9R@1^KVh0YJFU09ZJVP1JFUX0VYZJ06m_K`0f=SH0EEEE03Lg=`0o?cl0KVi^
09FEU@2HV9P0EeMG06][J`1UIFD0GemO05iNGP1iNGT0PX:20861P@1ZJVX0PH6100;ooooo0000W`34
a<@0G5aL075aL@29RHT0L71`0:VYZ@1<C4`0BDU9051@D01hN7P0G5aL07QhN00V9RH0B4Q804m?C`1m
OGd0HV9R07QhN010@400=cLg04i>CP1EEED0A4A4055AD@1bLW80<C4a055AD@2DU9@0_Kfm065QH@1e
MGD0Fe]K03hn?P1GEeL0[Zj^0:n_[`10@400IfMW04Q8B00`<300DU9B09RHV01;Bd/0@D51069RHP0d
=3@0:2PX06QXJ01aLG40<S8b075aL@0h>3P0;bl_0451@@2GUiL0RXZ:03De=@1MGEd0GUiN04U9B@1k
Ng/0U9BD05QHF00n?Sh0F5QH04I6AP1aLG40TI6A03<c<`0Z:RX0BTY:04U9B@1;Bd/0OGem0;Zj^P1Q
HF4092@T04U9B@1>CTh0<30`08:2PP2;Rh/0=SHf02DU9@1>CTh0E5AD03lo?`2QXJ40TY:B03Ph>00Z
:RX0ADE50861P@1YJFT0c/k>06IVIP0i>CT0@D5105ADE01gMgL0IfMW0;Fe]@0m?Cd0=3@d03lo?`1_
Kfl0CTi>08V9R@2IVIT08B4Q04I6AP1@D500JFUY07YjNP2a/K40<C4a03De=@1PH600HV9R04e=C@1l
O7`0_Kfm04e=C@15ADD0Q8B408^;R`16ATH0Vi^K0:j^[P0e=CD0;Bd]05QHF01mOGd0GUiN096AT@2l
_;`0?3`l04M7A`1]KFd0SHf=08^;R`2WYjL0I6AT0492@P1WIfL0GemO0861P@1HF5P0_[jn05YJFP0_
;bl0KVi^0;jn_P2=SHd0P82008n?S`16ATH0BTY:061PH00208f=S@0I08J6QP0L71`0Fe]K08V9R@27
QhL0FUYJ07emO@1[Jf/0=cLg04m?C`2VYZH0Y:BT051@D02EUID0GEeM03<c<`1>CTh0UiNG0:RXZ01T
I6@0WIfM02`/;013@d<0Zj^[0;2`/00207MgM`2;0;Zj^P14A4@0EEEE0<S8b02WYjL0FEUI06YZJP22
PX80@41004m?C`3:b/X0[:b/04i>CP1LG5`0HF5Q04Y:BP1PH600_[jn05QHF00f=SH0G5aL04a<C01Q
HF40WYjN08R8R013@d<0GUiN05aLG01NGUh0^[Zj0=7Ad@10@400G5aL071`L01FEUH0Ng]k0;jn_P1L
G5`0Bd];07UiN@1VIVH0MGEe0<c<c02:RXX0>c/k08J6QP1nOWh0QhN70=KFeP1WIfL0=3@d061PH02G
UiL0KVi^0<30`02FUYH0;Rh^05UIF@1KFe/0CTi>09NGU`3EeMD0M7Ad06IVIP1?Cdl0AdM708B4Q02l
_;`0DE5A03`l?01PH600LG5a07inOP2VYZH0][Jf0492@P1FEUH0J6QX0:ZZZP1UIFD0eMGE09JFUP0n
?Sh0EUIF075aL@2QXJ40OGem0;bl_01WIfL0@d=3069RHP2BTY80^KVi09VIV@38b<P0/[:b03@d=01i
NGT0dm?C08j>SP1kNg/0];Bd061PH01BDU80De=C0;>c/`2DU9@0Hf=S0<o?c`1IFET0>SXj05YJFP2R
XZ80Kfm_08J6QP2DU9@0:RXZ04a<C01YJFT0HF5Q05mOG`1`L700`/;205YJFP0M7Ad0Lg=c0;^k^`1?
Cdl0BTY:05iNGP1@D500MGEe05EEE@2g]kL0aLG50=OGe`2UYJD0D51@05=CD`0206UYJ@0O069RHP1>
CTh0GUiN07UiN@1RHV80IFEU051@D01NGUh0V9RH08b<S01TI6@0Bd];04Q8B01VIVH0I6AT051@D01F
EUH0JFUY061PH01GEeL0<c<c05IFEP1NGUh0DU9B04a<C01MGEd0GUiN04a<C017AdL0Fe]K05MGE`02
05QHF01a03Ti>@1LG5`0?Cdm03Hf=P0h>3P0@D5104E5A@1=CDd0B4Q804Y:BP0m?Cd0GUiN05YJFP1B
DU80>CTi06i^KP1fMWH0ATI6055AD@1FEUH0BDU906a/K01CDe<0D51@06IVIP18B4P0CDe=04Y:BP1<
C4`0F5QH03dm?@1<C4`0D51@06ATI01DE5@0KVi^05QHF01IFET0G5aL08:2PP26QXH0K6a/0861P@2g
]kL0[Jf]03lo?`2;Rh/0DU9B05]KF`1jNWX0GUiN071`L01IFET0CDe=05=CD`1_Kfl0Jf][05]KF`1d
M7@0Cdm?07=cL`1FEUH0F5QH051@D01lO7`0KVi^05YJFP10@400DE5A05ADE01BDU80Hf=S05MGE`1L
G5`0ATI604i>CP1<C4`0GUiN05IFEP1LG5`0Ng]k08V9R@2;Rh/0Xj>S079bLP1YJFT0Kfm_051@D01T
I6@0B4Q806m_K`27QhL0I6AT07AdM01UIFD0MgMg05IFEP1KFe/0BDU908:2PP0/;2`0KVi^05IFEP27
QhL0b/[:04Q8B02<S8`0Ng]k059BDP1NGUh0FUYJ071`L02FUYH00P1EEED0X@23Ph<0F5QH03/k>`13
@d<0CDe=04a<C00i>CT0@D5104=3@`0h>3P0>SXj04A4A00Y:BT0FUYJ03Ti>@1?Cdl0=3@d03Ti>@1?
Cdl0<30`03dm?@1CDe<0=cLg07QhN01fMWH0@d=303`l?015ADD0Hf=S04i>CP1lO7`0Fe]K07MgM`27
QhL03Ph>02DU9@0m?Cd0DU9B04];B`1dM7@0CDe=061PH01MGEd0FUYJ065QH@1NGUh0HV9R04e=C@2_
[jl0Ogmo06YZJP1MGEd0A4A4071`L021PH40DU9B04=3@`1KFe/0Lg=c09jNWP1?Cdl0EEEE059BDP0a
<C40RHV907AdM01LG5`0NWYj06=SH`20P800KVi^0;>c/`1WIfL0Lg=c03<c<`15ADD0QHF506ATI00l
?3`0D51@05UIF@16ATH0HV9R06=SH`1ZJVX0EeMG05ADE01]KFd0C4a<05MGE`1JFUX0De=C071`L01R
HV80NGUi08J6QP1bLW80c/k>08f=S@1>CTh0HV9R09:BTP30`<00QHF50:FUY@27QhL0M7Ad09FEU@1/
K6`0KVi^065QH@2@T900`L7107emO@1HF5P0Rh^;09FEU@2GUiL0AdM704I6AP19BDT0DE5A08>3P`2S
Xj<0L71`09JFUP1iNGT0MWIf06YZJP0k>c/0LG5a07EeM@1lO7`0NGUi0:NWY`0j>SX0BDU9065QH@14
A4@0Ti>C08F5Q@1ADE40Zj^[07IfMP1KFe/0N7Qh04=3@`0h>3P0DE5A05IFEP1`L700IVIV06][J`1n
OWh0@T9206][J`1hN7P0Xj>S06EUI@2CTi<0^k^k00;ooooo0000bP2BTY80QhN707inOP1nOWh0De=C
07=cL`26QXH0>3Ph069RHP15ADD0BDU906m_K`1?Cdl0:b/[05EEE@16ATH0DE5A08F5Q@1gMgL0820P
03Hf=P1JFUX0E5AD06MWI`1oOgl0=cLg01`L701UIFD0VIVI07MgM`2[Zj/0S8b<0492@P0g=cL0GEeM
09nOW`24Q8@0[:b/03dm?@0Z:RX0;2`/06ATI02RXZ80PH610<O7a`0g=cL0<S8b03Ph>01>CTh0Cdm?
0<k>cP2PX:005ADE0492@P1DE5@0GemO08>3P`3:b/X0EeMG020P801:BTX0LW9b055AD@2b/[80AdM7
020P801:BTX0GEeM05IFEP1^KVh0/;2`02h^;P0W9bL0EUIF07=cL`2NWYh0KVi^0<G5a@0^;Rh08B4Q
030`<01iNGT0MWIf08B4Q02b/[8092@T02/[:`0k>c/0T92@09bLW01oOgl0ZZZZ028R8P0b<S80Cdm?
07UiN@1YJFT0MgMg08F5Q@0W9bL0D51@05ADE01]KFd0De=C065QH@0^;Rh0>3Ph07AdM028R8P0GemO
05IFEP1cLg<06ATI04a<C02WYjL0/k>c04m?C`1VIVH0I6AT02<S8`1LG5`0Ti>C07inOP1ZJVX0LG5a
05aLG00l?3`0FEUI0:JVYP1PH600?3`l06QXJ00m?Cd0DE5A07=cL`2LW9`0DE5A04Q8B01TI6@0ATI6
08R8R02`/;00S8b<03Xj>P1IFET0P82005ADE01]KFd0d];B0:f][@10@400@D5106UYJ@1<C4`0LG5a
0<W9b@1DE5@0@D5106YZJP1WIfL0UiNG0=[JfP1UIFD0=SHf065QH@1[Jf/0IVIV08R8R02PX:00?clo
038b<P1MGEd0IFEU05UIF@2^[Zh0PH6103Ti>@14A4@0CTi>06YZJP2;Rh/0bl_;05=CD`0n?Sh0ATI6
09^KV`1OGel0[Zj^0>?Sh`1=CDd0A4A404M7A`2[Zj/0Jf][0:b/[02c/k<0?clo05mOG`1RHV80TY:B
08R8R02d];@204M7A`3o06a/K02<S8`0P82008j>SP1dM7@0;Rh^03De=@1MGEd0ZJVY09ZJVP3<c<`0
RHV903hn?P1FEUH0S8b<07moO`3=cLd0/[:b04Y:BP1VIVH0RHV907moO`28R8P0UiNG04];B`17AdL0
UYJF0>OWi`2@T900Z:RX06UYJ@10@400Shn?0<_;b`1[Jf/0K6a/07QhN00n?Sh0CDe=09:BTP1KFe/0
YJFU05QHF00d=3@0CTi>08j>SP2=SHd0CTi>08Z:RP0_;bl0BDU909FEU@2;Rh/0GemO071`L01ADE40
Cdm?09fMW@2e]KD0UYJF05aLG02JVYX0B4Q804E5A@20P800[Jf]05=CD`1PH600Rh^;03Ti>@1?Cdl0
I6AT07]kN`0e=CD0H61P05MGE`1BDU80A4A405mOG`2KVi/0EEEE04];B`1EEED0MGEe07inOP2JVYX0
OWin03Lg=`10@400Cdm?06][J`1HF5P0b/[:06QXJ00i>CT0DE5A0451@@1bLW80[:b/0=kNgP1fMWH0
;bl_05IFEP1IFET0=cLg06=SH`3=cLd0QHF502XZ:P0l?3`0KFe]05IFEP1QHF40Lg=c03lo?`1hN7P0
G5aL08>3P`1bLW80YjNW0::RXP1BDU80FUYJ05MGE`0g=cL0IfMW055AD@1gMgL0G5aL05MGE`1_Kfl0
IfMW0820P01TI6@0A4A4069RHP1HF5P0EeMG061PH016ATH0E5AD0451@@15ADD0?clo055AD@0k>c/0
@D5104e=C@1?Cdl0DU9B0492@P0W9bL0?3`l05eMG@1/K6`0QhN7096AT@1`L700@d=306][J`1PH600
>SXj04i>CP2:RXX0MgMg04e=C@1:BTX0De=C04M7A`1<C4`0Cdm?04a<C00k>c/0FUYJ06][J`0a<C40
AdM7069RHP1lO7`0KVi^03Ph>01IFET0LG5a04e=C@1KFe/0ADE50492@P1FEUH0BDU904=3@`0o?cl0
MWIf07alO02IVIT0A4A404];B`2RXZ80`/;208J6QP12@T80LG5a0=CDe02`/;00Ogmo06i^KP0a<C40
CDe=08J6QP32`/80TI6A04];B`1DE5@0AdM705mOG`1QHF40>SXj04Q8B016ATH0Fe]K04e=C@1<C4`0
@d=3069RHP1HF5P0De=C03Hf=P0g=cL0ATI603dm?@1;Bd/0@d=3055AD@12@T80Bd];03dm?@1ADE40
@D51055AD@1gMgL0Ng]k05IFEP1JFUX0EEEE05=CD`1VIVH0DE5A05mOG`16ATH0MGEe06][J`2DU9@0
TI6A05IFEP1WIfL0NWYj000H07IfMP1EEED0OWin03/k>`1dM7@0LW9b08^;R`3<c<`0>3Ph0;Zj^P2>
SXh0>3Ph069RHP2MWId0LG5a065QH@1_Kfl0EeMG07AdM01gMgL0E5AD05=CD`1?Cdl0H61P0P1ADE40
H01LG5`0AdM7069RHP1QHF40=CDe0:>SX`1>CTh0KFe]03Xj>P1=CDd0IFEU01DE5@1@D500GEeM024Q
8@1[Jf/0OWin03@d=01@D500?Cdm07YjNP0/;2`0C4a<03lo?`1DE5@0GEeM04=3@`1FEUH0F5QH061P
H01=CDd0L71`05IFEP1UIFD0DU9B06][J`1TI6@0A4A404a<C00o?cl0Fe]K05IFEP1LG5`0L71`05UI
F@16ATH0B4Q803Lg=`1nOWh0TI6A07inOP2;Rh/0EEEE08n?S`2@T900ATI605=CD`1JFUX0KFe]07Qh
N01LG5`0MWIf04a<C01TI6@0OWin0861P@0n?Sh0@41004Y:BP1;Bd/0@T9205mOG`1KFe/0F5QH06YZ
JP1?Cdl0HV9R06IVIP1OGel0JFUY05iNGP1_Kfl0BTY:06ATI01UIFD0G5aL05MGE`1UIFD0JFUY06e]
K@1TI6@0CDe=071`L020P800FEUI04i>CP80Ph>300d0?Cdm05eMG@14A4@0N7Qh06a/K01kNg/0N7Qh
06a/K020P800LW9b05mOG`1YJFT0MGEe0080Rh^;02P0EEEE05mOG`1TI6@0;2`/08F5Q@27QhL0DU9B
05IFEP1PH600Vi^K05]KF`1cLg<0PH6109nOW`1IFET0GUiN059BDP12@T80GemO08^;R`1_Kfl0Ti>C
05MGE`14A4@0GemO0492@P0j>SX0LW9b08J6QP2?Shl0GemO09JFUP1FEUH0B4Q807MgM`2QXJ40^KVi
07moO`2_[jl0`l?30_ooool0002@07MgM`24Q8@0R8R80:BTY01@D500C4a<08F5Q@2GUiL0/;2`03lo
?`0n?Sh0GEeM06e]K@1_Kfl0Xj>S03De=@10@400FUYJ079bLP1ADE40QHF504i>CP0^;Rh0@T9207Mg
M`27QhL0Fe]K07AdM00_;bl0@41005aLG02FUYH0LG5a07UiN@1IFET0:2PX06YZJP27QhL0NWYj04I6
AP1]KFd0@D51038b<P1LG5`0OWin08V9R@18B4P0MgMg03hn?P0[:b/0F5QH08R8R01GEeL0GUiN07mo
O`0h>3P0=SHf07YjNP2PX:00@d=308N7Q`0a<C4092@T04m?C`24Q8@0ADE503Lg=`18B4P0=CDe03Ph
>01RHV80CDe=02PX:012@T80Fe]K04=3@`0l?3`0HV9R0820P00e=CD0Kfm_04E5A@12@T80AdM707mo
O`1PH6009BDU04m?C`0k>c/0HV9R061PH01oOgl0ADE502TY:@14A4@0>CTi05EEE@2CTi<0SHf=02XZ
:P0a<C40De=C04Y:BP2EUID0alO705MGE`0M7Ad0>SXj079bLP1VIVH0QHF508V9R@0R8R80<S8b04A4
A01fMWH0JFUY09JFUP1XJ6P0;bl_04E5A@1FEUH0NGUi08Z:RP2`/;00EeMG02l_;`1;Bd/0GUiN07]k
N`1iNGT0h>3P07MgM`0R8R80GEeM0:6QX@1cLg<0XZ:R0<G5a@19BDT0:b/[08R8R02h^;P0GEeM0P2V
YZH0J01@D500=cLg08:2PP3AdM40QhN70;Bd]02LW9`0CDe=03`l?02;Rh/0Y:BT07inOP2l_;`0@410
06m_K`20P800TY:B0:JVYP2WYjL0AdM70492@P1GEeL0QhN7079bLP1`L700XZ:R055AD@0o?cl0Lg=c
0<[:bP2ATI40V9RH0820P010@400E5AD0820P01jNWX0GemO08N7Q`1[Jf/0@D5105eMG@2/[:`0YZJV
07EeM@2QXJ40?Shn055AD@1nOWh0QXJ607alO01BDU80QHF502PX:01=CDd0/;2`09jNWP1;Bd/0B4Q8
07EeM@0b<S80MgMg0:6QX@1?Cdl0A4A406UYJ@0k>c/0EEEE09NGU`2e]KD0CTi>09bLW01JFUX0A4A4
05mOG`2k^k/0PX:207EeM@2:RXX0@D5107YjNP2e]KD0EEEE03Ti>@1eMGD0Kfm_06ATI03:b/X0RXZ:
04E5A@1MGEd0Kfm_07EeM@2UYJD0P82004Q8B017AdL0PH610451@@2n_[h0Y:BT03Lg=`1>CTh0OWin
0P1iNGT0o`33`l<0=cLg04E5A@20P800Ph>308f=S@2KVi/0T92@03Lg=`16ATH0RXZ:06e]K@23Ph<0
[jn_03De=@0c<c<0CDe=08Z:RP1iNGT0UYJF0;jn_P0Y:BT0?clo0861P@28R8P0C4a<0:FUY@2f][H0
:b/[04=3@`1RHV80MWIf07alO02b/[80_[jn02@T9014A4@0Lg=c06m_K`1SHf<0[Jf]08B4Q00J6QX0
EUIF0;:b/P2^[Zh0I6AT09jNWP1_Kfl08b<S04Q8B03?cll0emOG05YJFP1gMgL0?clo03Lg=`0l?3`0
EUIF0:>SX`1UIFD0OGem06i^KP0];Bd0De=C04e=C@1YJFT0Cdm?06EUI@3IfMT0h>3P0=kNgP37alL0
Ti>C08b<S02ATI40H61P07emO@1TI6@0EEEE04e=C@1>CTh0LG5a05IFEP1VIVH0Q8B406i^KP2<S8`0
Ng]k06YZJP1WIfL0ADE504];B`1RHV80BTY:04m?C`1jNWX0F5QH051@D01/K6`0MGEe06YZJP1YJFT0
ATI606ATI01^KVh0NWYj065QH@1[Jf/0KVi^04=3@`1^KVh0CTi>02l_;`0f=SH0D51@05eMG@15ADD0
AdM707UiN@1?Cdl0De=C05aLG01lO7`0?Shn06UYJ@1gMgL0>c/k04I6AP18B4P0<C4a04M7A`0k>c/0
FEUI069RHP1HF5P0HF5Q04e=C@10@400BTY:051@D011@D40B4Q803Ti>@0g=cL0Hf=S04I6AP14A4@0
FUYJ05aLG01XJ6P0E5AD05MGE`0c<c<0=SHf034a<@0Y:BT0<c<c05MGE`25QHD0/k>c0:>SX`1?Cdl0
H61P06IVIP1DE5@0GUiN06YZJP1TI6@0ADE5059BDP1CDe<0HV9R059BDP1ZJVX0LW9b07=cL`0o?cl0
BDU903hn?P1>CTh0IVIV04E5A@17AdL0?Shn0492@P0e=CD0D51@07=cL`1SHf<0HV9R07UiN@29RHT0
Vi^K06][J`1HF5P0I6AT05eMG@1_Kfl0@d=304i>CP1OGel0MGEe05ADE019BDT0E5AD06e]K@1eMGD0
?Shn06MWI`0b<S80Q8B406QXJ01MGEd0Ogmo04I6AP2[Zj/0UYJF04Q8B01<C4`0HF5Q08:2PP2YZJT0
>SXj03hn?P1=CDd0I6AT05ADE00l?3`0FUYJ03<c<`1:BTX0ATI605QHF01NGUh0L71`04];B`14A4@0
E5AD05UIF@1UIFD0CDe=05MGE`1eMGD0;bl_04a<C01OGel0ADE509NGU`2h^;P0Cdm?05=CD`1aLG40
QhN7061PH000@`1jNWX0N7Qh065QH@1VIVH0>3Ph03dm?@0S8b<0>c/k04M7A`1FEUH0Hf=S092@T01c
Lg<0F5QH04];B`12@T80IVIV0492@P1hN7P0FEUI06][J`1^KVh0CTi>04U9B@1:BTX0ATI604E5A@1L
G5`0I6AT07]kN`1<C4`0@4100492@P1=CDd0YjNW06IVIP1GEeL0J6QX05eMG@2SXj<0FEUI08N7Q`1o
Ogl0TI6A08:2PP13@d<0H61P05]KF`1TI6@0PX:207inOP1<C4`0F5QH04m?C`1OGel0CTi>05QHF01b
LW80EeMG069RHP1:BTX0EEEE05=CD`1EEED0GemO06EUI@24Q8@00P2OWil0?P1RHV80OGem08n?S`2G
UiL0I6AT0861P@1SHf<0@T9207alO01<C4`0O7al06i^KP1SHf<0JFUY06=SH`1OGel0QHF507QhN01n
OWh0H61P04Q8B01HF5P0Bd];07QhN01ZJVX0CDe=09ZJVP20P800DU9B06MWI`1GEeL0Ng]k0861P@1/
K6`0NGUi0:b/[029RHT0JVYZ08:2PP1WIfL0RHV90;>c/`25QHD0Z:RX05IFEP1:BTX0GUiN03/k>`1R
HV80M7Ad08B4Q01nOWh0@T9204i>CP1<C4`0CTi>08F5Q@2:RXX0H61P06m_K`2PX:00UIFE0_ooool0
003<0:>SX`1ADE40JFUY0861P@2DU9@0VYZJ03De=@1<C4`0NGUi075aL@18B4P0FUYJ03dm?@0];Bd0
Cdm?06IVIP0V9RH0@41003Ti>@0Q8B40@T9206MWI`0P82008b<S03hn?P10@400De=C08n?S`19BDT0
;2`/038b<P18B4P0CDe=06YZJP2<S8`0;bl_02XZ:P1@D500LG5a04Q8B022PX80TI6A02@T9016ATH0
BTY:07alO01LG5`0[jn_07emO@0/;2`0B4Q804e=C@1?Cdl0Q8B40=WIf@1<C4`0:2PX03lo?`1WIfL0
D51@0<c<c027QhL0:2PX05MGE`1NGUh0EEEE07IfMP2EUID08R8R02HV9P1CDe<0Fe]K04I6AP2FUYH0
^KVi024Q8@0i>CT0Lg=c06IVIP1dM7@0hN7Q09BDU00d=3@0=cLg05UIF@1oOgl0HF5Q0;Jf]P28R8P0
>SXj04I6AP1SHf<0ZJVY08:2PP2g]kL0LW9b01/K6`1LG5`0]kNg07]kN`1LG5`0VYZJ02d];@0o?cl0
MGEe0:6QX@19BDT0OWin06MWI`0L71`0IfMW08>3P`1XJ6P0I6AT08^;R`14A4@0:b/[05eMG@28R8P0
?clo05YJFP1mOGd08b<S03Hf=P23Ph<0Shn?04E5A@1iNGT0GemO02`/;00j>SX0O7al0:JVYP1MGEd0
Ng]k08j>SP13@d<0BTY:09JFUP2XZ:P0Bd];075aL@1bLW80=cLg069RHP2n_[h0QHF504=3@`1GEeL0
AdM703De=@1RHV80^KVi06e]K@1FEUH0GemO055AD@1?Cdl0XZ:R06QXJ01<C4`0M7Ad06IVIP1?Cdl0
Ph>305iNGP0c<c<0B4Q8071`L01GEeL0OGem08V9R@0n?Sh0?clo07AdM01YJFT0DU9B092@T02^[Zh0
@41004I6AP1_Kfl0JVYZ07EeM@2_[jl0WIfM03Ti>@1MGEd0SXj>09:BTP2o_kl0e]KF08f=S@0_;bl0
JVYZ09ZJVP2:RXX0V9RH0=7Ad@1@D500:b/[05EEE@1`L700S8b<0P2PX:003`0[:b/0CDe=08b<S01V
IVH0SXj>0;Rh^00m?Cd0:BTY06a/K02k^k/0HF5Q0=gMg@2HV9P0<S8b05UIF@020::RXP1h0;Fe]@3<
c<`0GUiN065QH@2SXj<0YjNW07QhN02][Jd0EUIF03dm?@2RXZ80YZJV06ATI02WYjL0LW9b0451@@1d
M7@0/;2`09:BTP2PX:00OWin03lo?`1lO7`0XJ6Q05YJFP27QhL0PH6103Ph>011@D40NWYj07alO01E
EED0Ogmo02d];@0o?cl0QXJ6079bLP1QHF40Kfm_07YjNP12@T80DU9B0:JVYP2m_Kd0Hf=S09ZJVP29
RHT0EUIF08^;R`39bLT0Y:BT04Q8B01hN7P0EEEE04Q8B01`L700g=cL0;Bd]015ADD0Y:BT04i>CP0b
<S80Kfm_0<C4a02JVYX0F5QH08^;R`1PH600EUIF07moO`3EeMD0HF5Q03Xj>P1jNWX0R8R807EeM@2Y
ZJT0RXZ:02HV9P0/;2`0GemO08B4Q01WIfL0/k>c075aL@0R8R80?clo06UYJ@1RHV80I6AT071`L01h
N7P0;Bd]030`<01^KVh0MGEe04e=C@1WIfL0gmoO0??cl`2OWil0P82006UYJ@1FEUH0LW9b07AdM02<
S8`0EEEE07QhN01VIVH0DE5A08J6QP1ZJVX0RHV90::RXP2?Shl0W9bL06MWI`1EEED0De=C0P19BDT0
1`16ATH0F5QH05ADE01FEUH0?3`l055AD@1;Bd/00P1<C4`03@1@D500De=C04Y:BP1@D500H61P092@
T02HV9P0J6QX03Xj>P1KFe/0FUYJ0492@P19BDT00P1kNg/0FP1KFe/0De=C06QXJ00i>CT0?3`l04e=
C@1VIVH0I6AT07emO@1[Jf/0<c<c0492@P1=CDd0B4Q8069RHP1?Cdl0GUiN065QH@18B4P0H61P05QH
F017AdL0I6AT0410@01<C4`0De=C065QH@1bLW80]kNg05YJFP1UIFD0XZ:R0;Fe]@2GUiL0FUYJ04e=
C@1JFUX0B4Q806ATI01LG5`0>c/k04m?C`1iNGT0UYJF09nOW`1ADE40I6AT05QHF01VIVH0Jf][04=3
@`1NGUh0=3@d061PH01LG5`0B4Q80451@@1dM7@0IVIV05EEE@0h>3P0Hf=S06IVIP0e=CD0ADE504I6
AP1IFET0>3Ph04a<C00l?3`0E5AD04A4A01KFe/0J6QX07YjNP1CDe<0Cdm?04Q8B01eMGD0Lg=c04e=
C@1SHf<0B4Q807EeM@1JFUX09RHV06MWI`0a<C40>3Ph030`<080C4a<01l0H61P0410@01QHF40HF5Q
08Z:RP2d];@0BDU905mOG`1;Bd/0=CDe04M7A`15ADD0B4Q804e=C@0i>CT0>SXj03/k>`0n?Sh0AdM7
059BDP25QHD0?clo05ADE00l?3`0GEeM03Lg=`1VIVH0Z:RX051@D01jNWX0FEUI0080LG5a0900=SHf
055AD@1eMGD0N7Qh08>3P`1UIFD0CTi>05YJFP1CDe<0G5aL061PH01YJFT0BTY:07alO01mOGd0?3`l
06QXJ00=3@d09BDU03hn?P1MGEd0?clo05mOG`1LG5`0I6AT05eMG@1KFe/0EeMG03Xj>P1?Cdl08b<S
09bLW01=CDd0De=C071`L01@D500H61P079bLP1gMgL0HV9R06EUI@1gMgL0U9BD059BDP1^KVh0GUiN
04i>CP1CDe<0Cdm?09BDU01ZJVX0JFUY0;Zj^P2:RXX0U9BD08j>SP2HV9P0G5aL03dm?@1RHV80LG5a
07YjNP2h^;P0T92@05YJFP1PH600MGEe07QhN01eMGD0NGUi06i^KP1ZJVX0SHf=05QHF01ADE40;Rh^
075aL@29RHT0MWIf08>3P`2PX:00RXZ:05UIF@2NWYh0Ti>C09ZJVP2BTY80W9bL07emO@1XJ6P0NGUi
07moO`2DU9@0MWIf09nOW`2ATI40R8R806MWI`24Q8@0TY:B0:>SX`11@D40ADE505]KF`0c<c<0WIfM
08R8R00^;Rh0QhN709VIV@1HF5P0QXJ605MGE`1mOGd0O7al08^;R`21PH40/;2`04M7A`1aLG40UYJF
069RHP2@T900SXj>05]KF`2DU9@0EEEE04];B`1?Cdl0;2`/04I6AP1[Jf/0OWin08>3P`22PX80VIVI
065QH@1ADE40MWIf0:b/[02BTY80JFUY08>3P`20P802ooooo`0005D0_Kfm09FEU@1IFET0JFUY07Yj
NP3IfMT0Lg=c030`<014A4@0J6QX075aL@2KVi/0;Rh^034a<@0k>c/0FUYJ04M7A`2FUYH0M7Ad01@D
5018B4P0EUIF04E5A@1gMgL0UYJF03@d=00h>3P0NWYj09ZJVP1`L700Y:BT05ADE00i>CT0C4a<07in
OP2>SXh0GUiN06YZJP0Z:RX0>3Ph03lo?`1fMWH0GemO0:>SX`2TY:@07AdM0451@@1@D500XJ6Q05eM
G@1XJ6P0Bd];02/[:`0k>c/0NWYj09^KV`1KFe/0H61P01lO7`0c<c<0DU9B09JFUP1>CTh0C4a<03lo
?`0[:b/0=CDe075aL@1QHF40@41003lo?`0^;Rh0;2`/04Y:BP2`/;00XJ6Q03hn?P22PX80:BTY034a
<@1kNg/0ZJVY06ATI016ATH0M7Ad0080<c<c01T0NWYj0:^[Z`0o?cl0;Rh^06YZJP0`<300>SXj0:BT
Y02CTi<0<c<c03Lg=`1NGUh0JFUY05iNGP2FUYH0?Cdm03De=@15ADD0I6AT04i>CP1gMgL0[:b/03Hf
=P10@400JVYZ0080FUYJ0340ZJVY08R8R00X:2P0@T9205UIF@10@400XJ6Q0;Vi^@0^;Rh0:RXZ04a<
C01fMWH0D51@0<;2`P37alL0=3@d03dm?@1NGUh0LG5a05IFEP2FUYH0cLg=03Ph>00n?Sh0De=C08j>
SP1NGUh0YZJV08B4Q00k>c/0@d=306=SH`2DU9@0LW9b0;no_`1`L700@T9204m?C`23Ph<0aLG50;Fe
]@2c/k<0;bl_05iNGP1cLg<0WinO0;Bd]02NWYh0>CTi0080IfMW05d0R8R808B4Q01jNWX0UIFE02PX
:01DE5@0P8200861P@1JFUX0f][J04a<C01;Bd/0Jf][06e]K@1fMWH0IFEU0;Zj^P0X:2P0?Shn0861
P@2a/K40Ng]k0::RXP2j^[X0?Shn06MWI`2BTY80aLG509RHV02WYjL0XJ6Q04A4A01jNWX0RXZ:08^;
R`1/K6`0SXj>03De=@16ATH0QhN70:ZZZP1jNWX0AdM708R8R00a<C40@T9209fMW@2>SXh0F5QH05MG
E`1KFe/0@T9208^;R`3AdM40Fe]K07UiN@1dM7@0>3Ph05=CD`2SXj<0R8R804=3@`2EUID0IVIV04E5
A@21PH40X:2P0410@02ATI40RHV907EeM@2_[jl0ZJVY03Lg=`1?Cdl0G5aL04];B`2YZJT0^;Rh03/k
>`17AdL0N7Qh05=CD`26QXH0]kNg03lo?`19BDT0BTY:0451@@2=SHd0c/k>059BDP0V9RH00P1KFe/0
B01LG5`0Shn?0<30`01DE5@0>c/k07inOP25QHD0MGEe0:FUY@2WYjL0BTY:04a<C02FUYH0/;2`08B4
Q02b/[80G5aL03dm?@1=CDd0OGem0=?Cd`2^[Zh0hn?S07QhN015ADD0@T9206ATI027QhL0MgMg0:b/
[01BDU80AdM704m?C`23Ph<0U9BD096AT@2n_[h0?clo03Lg=`1SHf<0ZZZZ05ADE01hN7P0^;Rh03lo
?`0h>3P0KVi^08^;R`1BDU80Rh^;0;Bd]01=CDd0?3`l05YJFP1bLW80H61P06QXJ01PH600?3`l0451
@@1OGel0FEUI0;6a/@3Vi^H0[Jf]059BDP1VIVH0GUiN03Xj>P1MGEd0LG5a061PH080@T920240J6QX
07alO01iNGT0Kfm_05aLG01dM7@0LW9b04M7A`15ADD0;Bd]04Y:BP0g=cL0?3`l03Ph>01dM7@0=CDe
03lo?`0j>SX0J6QX075aL@1@D500>c/k04m?C`25QHD0GemO05ADE01PH600O7al06=SH`1hN7P0H61P
0451@@12@T800P1kNg/0F@1CDe<0CDe=06UYJ@0k>c/0IFEU06QXJ01SHf<0?Shn05aLG01VIVH0ADE5
05ADE01VIVH0GUiN07moO`0n?Sh0AdM707=cL`1>CTh0De=C04e=C@16ATH0GEeM04U9B@0m?Cd0B4Q8
04m?C`1VIVH0WIfM02h^;P0e=CD0Rh^;0;Ng]`24Q8@0L71`07QhN023Ph<0;bl_0451@@1BDU80KVi^
07EeM@24Q8@0dM7A0:JVYP1CDe<0GUiN06QXJ01GEeL0IfMW05UIF@1NGUh0BTY:04e=C@1WIfL0DE5A
05IFEP1;Bd/0GEeM06UYJ@1:BTX0>c/k04a<C01EEED0KFe]04Y:BP1CDe<0@d=304M7A`0o?cl0@T92
05EEE@1HF5P0N7Qh08:2PP1NGUh0IFEU05EEE@1FEUH0QXJ606a/K01oOgl0CTi>04M7A`1JFUX0DU9B
05aLG015ADD0IfMW0080De=C0;80@d=30820P00Q8B40SHf=06e]K@1fMWH0/k>c0451@@39bLT0MGEe
02l_;`1/K6`0Kfm_04a<C01BDU80EeMG05mOG`17AdL0E5AD03/k>`1@D500ADE504i>CP0R8R80BTY:
0:2PX01YJFT0ATI606UYJ@1LG5`0YZJV059BDP1TI6@0IVIV05iNGP2;Rh/0B4Q803hn?P1BDU80IVIV
0;Bd]02][Jd0Hf=S061PH01<C4`0VYZJ04Q8B02;Rh/0MGEe06a/K025QHD0:2PX02/[:`11@D40GemO
05UIF@2>SXh0FUYJ08B4Q01SHf<0HV9R08:2PP1XJ6P0GemO04E5A@1KFe/0CTi>05]KF`1gMgL0HF5Q
06=SH`1]KFd0ATI6075aL@1SHf<0CDe=07inOP1VIVH0M7Ad0451@@1DE5@0UYJF07alO02=SHd0JFUY
05iNGP2;Rh/0N7Qh0;:b/P1YJFT0cLg=04M7A`0i>CT0IFEU06m_K`1DE5@0IfMW05mOG`1<C4`0KVi^
06QXJ01[Jf/0QXJ606UYJ@1_Kfl0JVYZ071`L01EEED0?clo03hn?P1PH600L71`07UiN@1UIFD0[Zj^
07YjNP1lO7`0`L7109VIV@2SXj<0KFe]09VIV@22PX80Hf=S075aL@1KFe/0NGUi06MWI`1hN7P0Shn?
05=CD`1PH600HV9R06EUI@1iNGT0GEeM05IFEP1DE5@0EUIF075aL@1RHV80=cLg08B4Q01gMgL0MGEe
06a/K01IFET0Lg=c051@D02BTY80UIFE0;^k^`1fMWH0LW9b06a/K01LG5`0Zj^[06i^KP1cLg<0c<c<
06QXJ01MGEd0GUiN04a<C01CDe<0EUIF05iNGP1LG5`0FUYJ05EEE@1BDU80AdM706a/K01MGEd0AdM7
05YJFP2FUYH0Y:BT0_ooool0003N071`L02UYJD0S8b<07moO`18B4P0QHF50<;2`P1KFe/0QhN702d]
;@0d=3@0Lg=c09JFUP0o?cl0I6AT03Hf=P0V9RH0E5AD0:RXZ01XJ6P0Fe]K04e=C@0N7Qh0>SXj08B4
Q01BDU80@41005]KF`0i>CT0DU9B0861P@2@T900;Bd]0451@@1OGel0E5AD051@D02BTY80OWin020P
8016ATH0GEeM05UIF@22PX80_[jn04=3@`0b<S80<C4a05ADE01BDU80Shn?0;6a/@0S8b<0@41004e=
C@1KFe/0I6AT0;>c/`1`L7009BDU05EEE@1fMWH0F5QH07AdM02OWil08B4Q0451@@1UIFD0B4Q8059B
DP21PH40:BTY018B4P0i>CT0DU9B08>3P`1nOWh0fMWI02h^;P0Q8B40>CTi069RHP27QhL0J6QX0<30
`00_;bl05aLG03/k>`2VYZH0VYZJ07inOP2TY:@0:BTY02@T900Z:RX0UiNG07]kN`23Ph<0PH6101hN
7P1>CTh0H61P04Q8B01QHF40J6QX04A4A00W9bL0De=C08J6QP1[Jf/0KFe]06i^KP0c<c<0@T9205EE
E@2<S8`0EeMG07YjNP1lO7`0<c<c0410@02BTY80EEEE05ADE02;Rh/0@d=303De=@1TI6@0[Jf]08n?
S`1bLW80Zj^[03<c<`0a<C40GemO0861P@1TI6@0F5QH0:6QX@13@d<0CDe=05iNGP2=SHd0KVi^05mO
G`1nOWh0;Rh^04M7A`1OGel0V9RH03dm?@1[Jf/0GEeM04=3@`2CTi<0TY:B05MGE`14A4@0S8b<03/k
>`1cLg<0QHF506m_K`0o?cl0OWin03`l?01WIfL0QXJ609JFUP18B4P0=SHf07MgM`0o?cl0DU9B0861
P@20P800<30`059BDP1/K6`0E5AD079bLP3<c<`0KVi^030`<01OGel0L71`05EEE@1lO7`0h>3P05EE
E@16ATH0Hf=S079bLP1_Kfl0N7Qh0=3@d00g=cL0ADE508j>SP1GEeL0Ti>C0;no_`1WIfL0:2PX04A4
A01fMWH0L71`09JFUP2LW9`0=CDe03dm?@1JFUX0HF5Q08:2PP3EeMD0TY:B02h^;P1aLG40YZJV069R
HP32`/80[Zj^0P11@D401022PX80RXZ:0820P039bLT2069RHP2h0:RXZ030`<00HF5Q0<;2`P1aLG40
?clo09>CT`2m_Kd0IFEU07]kN`1XJ6P0?Shn05MGE`2UYJD0KFe]07YjNP1aLG40=3@d05eMG@2[Zj/0
RHV9092@T01RHV80<c<c03`l?01^KVh0^k^k069RHP1eMGD0=SHf04Q8B01IFET0QXJ609NGU`2JVYX0
a/K603lo?`1EEED0JFUY096AT@2EUID0JVYZ09^KV`0j>SX0EeMG06MWI`1bLW80E5AD07alO01XJ6P0
<30`06QXJ01WIfL0Ti>C051@D01aLG40Kfm_03lo?`1XJ6P0PX:209fMW@1OGel0KFe]05IFEP0Y:BT0
EUIF0=;BdP2RXZ80@d=307AdM019BDT0>3Ph04Q8B02XZ:P0T92@04M7A`1WIfL0ATI603Ph>01?Cdl0
QHF509>CT`0g=cL0De=C06EUI@0b<S80Jf][07QhN01GEeL0?Shn06][J`2BTY80H61P09fMW@36a/H0
Fe]K05EEE@1ZJVX0ADE506MWI`1<C4`0E5AD04Q8B01DE5@0RHV906=SH`2@T900/k>c09NGU`2[Zj/0
KFe]05UIF@1GEeL0:RXZ05UIF@17AdL0BDU903/k>`1UIFD0AdM703dm?@18B4P0CDe=04U9B@1KFe/0
?Shn0492@P1ZJVX0DE5A06ATI01XJ6P0K6a/04I6AP1/K6`0DE5A04=3@`0g=cL0HF5Q06=SH`1HF5P0
DU9B05IFEP0N7Qh0BTY:069RHP1HF5P0?Shn05aLG01SHf<0=3@d04Q8B01=CDd0?Cdm05mOG`1eMGD0
Kfm_08N7Q`1BDU80K6a/06YZJP1?Cdl0KVi^04i>CP1DE5@0G5aL065QH@1`L700UiNG05ADE01FEUH0
UIFE09^KV`2WYjL0Rh^;05iNGP1fMWH0QhN705aLG00m?Cd0?3`l051@D01bLW80WinO0;2`/080EEEE
00X0EUIF06MWI`1cLg<0IVIV07UiN@1=CDd0F5QH07QhN01WIfL0FEUI0P1[Jf/01`1ZJVX0@41004a<
C01MGEd0D51@05ADE01<C4`00P1LG5`0<01CDe<0B4Q806QXJ01[Jf/0P82005aLG024Q8@0Lg=c07Ee
M@1[Jf/0K6a/08N7Q`1ZJVX0SHf=04Q8B01NGUh0K6a/0820P01YJFT0KFe]07QhN01QHF40D51@04=3
@`1lO7`0;Rh^0::RXP2:RXX0QXJ60:b/[01TI6@0SXj>07inOP0`<300GEeM04E5A@1/K6`0Y:BT04U9
B@0h>3P0DU9B05mOG`15ADD0MgMg06IVIP1FEUH0<S8b04U9B@80B4Q806L0AdM70:FUY@1@D500IFEU
04M7A`1KFe/0@D5103Lg=`1MGEd0?Cdm05eMG@1ZJVX0GemO09JFUP21PH40A4A405=CD`1MGEd0KVi^
0492@P1QHF40AdM70410@01@D500:BTY02XZ:P0g=cL0BTY:04Q8B01SHf<0F5QH07inOP1QHF40CDe=
05UIF@1BDU80JVYZ04i>CP1jNWX0EeMG069RHP1/K6`0GEeM04];B`1>CTh0CDe=08V9R@1oOgl0JFUY
0;no_`1FEUH0MGEe061PH00/;2`0IFEU04=3@`1HF5P0DU9B055AD@24Q8@0F5QH08:2PP1NGUh0MgMg
06=SH`10@400BTY:04i>CP1bLW80ZJVY07UiN@19BDT0EEEE05UIF@1cLg<0GUiN05]KF`1jNWX0F5QH
05EEE@1IFET0E5AD051@D01KFe/0Hf=S06e]K@1SHf<0[Zj^07emO@2=SHd0[Zj^08B4Q02SXj<0LW9b
09fMW@1TI6@0F5QH059BDP1oOgl0SHf=06=SH`1LG5`0QHF50080HF5Q00<0Jf][0:6QX@2MWId00P1@
D500:@1<C4`0K6a/0:b/[025QHD0DE5A08>3P`1fMWH0RXZ:08^;R`1JFUX0JFUY07YjNP1fMWH0GUiN
0861P@1FEUH0IVIV05ADE016ATH0W9bL07moO`1YJFT0V9RH05EEE@16ATH0Cdm?0492@P10@400JVYZ
0861P@2?Shl0JFUY05aLG01gMgL0GemO08f=S@1nOWh0Q8B408:2PP1eMGD0Ogmo00;ooooo0000g`1S
Hf<0Ogmo09NGU`2=SHd0BDU904e=C@2EUID0HV9R09bLW01EEED0:BTY03Lg=`27QhL0Cdm?09JFUP1B
DU80;2`/04=3@`1NGUh0H61P09fMW@2OWil05aLG04I6AP1IFET0K6a/06e]K@2d];@0>CTi02TY:@1S
Hf<0VIVI07QhN01DE5@0V9RH01/K6`14A4@0Bd];08F5Q@1HF5P0GemO04e=C@0T92@0?Shn03dm?@1@
D500K6a/07emO@17AdL0;Bd]03lo?`1^KVh0HF5Q07IfMP2b/[80=3@d02LW9`1ADE40XZ:R04U9B@27
QhL0O7al02/[:`0`<300DU9B06QXJ01OGel0Ph>301hN7P0[:b/0PH6107]kN`0];Bd0EeMG07UiN@0U
9BD0<C4a08j>SP25QHD0@41007inOP12@T80<c<c05eMG@2>SXh0QhN703lo?`1iNGT0CDe=0451@@1Z
JVX0UYJF06=SH`0_;bl0GemO038b<P1GEeL0MWIf0:^[Z`15ADD09RHV06IVIP1@D500KFe]08J6QP1;
Bd/0<c<c04];B`17AdL0Bd];08J6QP2EUID0=3@d04A4A01UIFD0HV9R05MGE`2MWId0TI6A0410@017
AdL0GUiN05YJFP1SHf<0Zj^[04Y:BP0`<300ATI605=CD`1LG5`0Ng]k0;Ng]`1ADE408b<S061PH026
QXH0EeMG075aL@3Bd]80Q8B402/[:`2ATI40Ng]k06=SH`2=SHd0h^;R061PH00g=cL0GEeM06QXJ01B
DU80XZ:R0;jn_P10@400BTY:06e]K@1oOgl0Ng]k0=kNgP1;Bd/0G5aL07alO02BTY80QXJ609fMW@0e
=CD0@41007QhN02UYJD0ZZZZ06QXJ02HV9P0>3Ph05EEE@1^KVh0^[Zj09RHV02b/[80R8R8034a<@19
BDT0Fe]K0:VYZ@1dM7@0VYZJ08N7Q`12@T80BTY:08:2PP20P800HV9R0:n_[`18B4P0EUIF05UIF@1m
OGd0Kfm_055AD@2ZZZX0?Shn03Lg=`29RHT0/[:b07YjNP2h^;P0I6AT02XZ:P1FEUH0aLG508>3P`1X
J6P0OWin02d];@0U9BD0Hf=S0<G5a@1NGUh0QhN706IVIP10@400HF5Q0<S8b02JVYX00P1eMGD09@0k
>c/0ATI608R8R02UYJD0D51@0;Vi^@21PH40CTi>0<o?c`2h^;P0GemO09fMW@26QXH0BDU907UiN@2/
[:`0Bd];04a<C01RHV80KFe]07UiN@2;Rh/0<c<c04=3@`1KFe/0L71`09JFUP2TY:@0>CTi04I6AP1A
DE40OGem06][J`2:RXX0FUYJ02PX:01ADE400P1RHV80101/K6`0c<c<09>CT`0m?Cd206][J`0W07Yj
NP1gMgL0alO703Xj>P0e=CD0Kfm_069RHP1CDe<0T92@0;Bd]00W9bL0@T920::RXP2@T900I6AT096A
T@2[Zj/0<c<c03Lg=`2XZ:P0][Jf06i^KP2a/K40OGem02HV9P0^;Rh0N7Qh0;6a/@1kNg/0a<C407Mg
M`0e=CD0F5QH05mOG`20P800RXZ:0<?3``2IVIT0:2PX0080EEEE02h0FEUI05QHF028R8P0/[:b01lO
7`0_;bl0Kfm_06QXJ00n?Sh0FEUI0<71`@2o_kl0HV9R0;jn_P1CDe<0FEUI08B4Q01[Jf/0MGEe05eM
G@1WIfL0IFEU06][J`1kNg/0HF5Q08Z:RP2i^KT0VYZJ07emO@1]KFd0GemO065QH@13@d<0H61P055A
D@1DE5@0AdM7079bLP0j>SX0E5AD04];B`1SHf<0GemO06a/K01LG5`0BTY:0P27QhL0;@1iNGT0J6QX
0861P@1?Cdl0W9bL051@D00m?Cd0BTY:05mOG`1]KFd0GemO05iNGP1XJ6P09RHV05QHF01[Jf/0P820
03lo?`1DE5@0OWin02XZ:P1JFUX0KVi^04Y:BP1YJFT0BDU904I6AP1KFe/0=SHf03lo?`1BDU80FUYJ
05IFEP12@T80De=C05YJFP1CDe<0GemO09NGU`15ADD0Bd];07YjNP2;Rh/0IfMW055AD@0205mOG`1=
04Y:BP1^KVh0EEEE07MgM`23Ph<0O7al0<K6aP2CTi<0C4a<05IFEP1:BTX0GEeM07AdM01EEED0HF5Q
04];B`1gMgL0HF5Q059BDP1YJFT0PX:206EUI@1JFUX0GUiN07]kN`1fMWH0Fe]K069RHP1PH600L71`
05MGE`1VIVH0Fe]K065QH@13@d<0IVIV08^;R`2GUiL0GEeM06=SH`1RHV80Z:RX09>CT`1DE5@0KFe]
07moO`2FUYH0KFe]03/k>`1IFET0E5AD08Z:RP2OWil0Shn?06UYJ@1VIVH0BTY:05eMG@1/K6`0W9bL
0=CDe015ADD0RHV907emO@1JFUX0/;2`06=SH`1>CTh0MGEe03Xj>P1hN7P0EEEE0820P01ZJVX0@T92
06MWI`11@D400P1OGel0CP1CDe<0@41006a/K02>SXh0CDe=05]KF`1ADE40K6a/04M7A`0e=CD0CDe=
05MGE`13@d<0F5QH06=SH`39bLT0TY:B05YJFP1UIFD0Bd];06UYJ@1=CDd0QHF506][J`1;Bd/0AdM7
02LW9`0Z:RX0?Shn04M7A`1EEED0RHV905UIF@1WIfL0GemO06MWI`20P800E5AD06i^KP1ADE40Zj^[
05mOG`1=CDd0FEUI07AdM01mOGd0UIFE04a<C01NGUh0CDe=04=3@`1JFUX0CTi>07UiN@1GEeL0EEEE
09FEU@1IFET0GemO05aLG01UIFD0X:2P071`L01oOgl0ADE507moO`1]KFd0?clo07MgM`1XJ6P0=3@d
03hn?P16ATH0>3Ph05]KF`1_Kfl0Lg=c06UYJ@80Jf][00H0FUYJ05IFEP1ADE40E5AD03<c<`1DE5@2
079bLP1105IFEP2DU9@0I6AT04M7A`1LG5`0Q8B407IfMP1HF5P0Vi^K08V9R@1hN7P0PX:206ATI01?
Cdl0HF5Q06EUI@20P800E5AD05EEE@1DE5@0@T9205iNGP1>CTh0Bd];059BDP17AdL0?3`l04Q8B01<
C4`0X:2P07emO@1XJ6P0GUiN06i^KP26QXH0JVYZ07MgM`1aLG40U9BD07QhN026QXH0K6a/05aLG01n
OWh0H61P04M7A`1OGel0E5AD05UIF@1]KFd0IfMW07UiN@1eMGD0EeMG075aL@1jNWX0J6QX05EEE@0h
>3P0JFUY0:^[Z`2][Jd0GUiN09NGU`2WYjL00_ooool0001l0;Vi^@1HF5P0FEUI09^KV`2;Rh/0a/K6
05EEE@1:BTX0KFe]0:BTY01?Cdl0F5QH03Lg=`0d=3@0GemO06UYJ@1GEeL0Rh^;06MWI`0d=3@0C4a<
06YZJP0m?Cd0<C4a05]KF`0g=cL0Lg=c0;fm_@1nOWh0<c<c05EEE@19BDT0KVi^08>3P`2m_Kd0AdM7
02/[:`19BDT0B4Q804=3@`2NWYh0OWin03Xj>P16ATH0EEEE03/k>`1;Bd/0YJFU0:JVYP0];Bd0A4A4
04Q8B00c<c<0P8200>c/k025QHD08b<S03Xj>P1ZJVX0ATI609BDU02h^;P0<c<c0410@016ATH0FEUI
06YZJP2k^k/0Cdm?01@D500k>c/0Kfm_04Q8B01MGEd0OGem02`/;00Q8B40AdM707AdM01:BTX0ZZZZ
08b<S00L71`0:BTY05]KF`2g]kL0KVi^0:FUY@2;Rh/0=cLg05QHF01jNWX0ZZZZ05ADE02YZJT0=CDe
04I6AP1cLg<0/[:b08Z:RP18B4P0P82002l_;`1OGel0RHV9092@T01@D500WinO03lo?`11@D40CTi>
08^;R`1LG5`0KFe]09jNWP0f=SH0<c<c04M7A`22PX80Ph>307alO01nOWh0:BTY05]KF`80ZZZZ03l0
Cdm?0861P@1aLG40:BTY05UIF@1hN7P0^k^k05IFEP2WYjL0TI6A034a<@1>CTh0P82009RHV01PH600
d];B07alO00m?Cd0CTi>07emO@2MWId0LG5a0<S8b00h>3P0@41005=CD`2[Zj/0V9RH07QhN01nOWh0
=cLg04a<C01YJFT0OWin09fMW@1HF5P0>SXj04M7A`24Q8@0U9BD038b<P1SHf<0J6QX03hn?P1;Bd/0
MWIf05=CD`1]KFd0Q8B403Xj>P19BDT0KFe]09fMW@1GEeL0@T9208>3P`0m?Cd0JVYZ09VIV@2h^;P0
ATI605aLG02BTY800P1PH600c03De=@0Lg=c03Lg=`1PH600Jf][061PH022PX80ZJVY059BDP0a<C40
EeMG065QH@1TI6@0/k>c08F5Q@0];Bd0CTi>0861P@2HV9P0Z:RX0=WIf@1MGEd0;2`/04E5A@2ATI40
QHF50<W9b@2g]kL0?3`l0451@@1iNGT0[Jf]09nOW`3Lg=`0EeMG03De=@1IFET0Y:BT08R8R030`<00
FUYJ03Ph>01EEED0O7al079bLP2c/k<0Q8B403lo?`1;Bd/0R8R805mOG`1oOgl0OGem028R8P11@D40
LW9b05eMG@2SXj<0R8R803Lg=`1QHF40EeMG06IVIP2VYZH0YJFU03lo?`0i>CT0Ng]k0::RXP1GEeL0
Vi^K0861P@1=CDd0Hf=S0:FUY@3GemL0JFUY09fMW@22PX80@d=305YJFP2MWId0];Bd06EUI@23Ph<0
LG5a04U9B@1PH600RXZ:07YjNP1DE5@0RXZ:05=CD`12@T80J6QX096AT@1EEED0Bd];05QHF00k>c/0
ADE5059BDP2?Shl0AdM704=3@`1IFET0AdM705EEE@1/K6`0Shn?03Hf=P1:BTX0HF5Q03Xj>P1@D500
H61P09bLW00h>3P0;bl_06UYJ@16ATH0:b/[04m?C`2_[jl0G5aL03dm?@1PH600>c/k04U9B@1RHV80
EeMG06ATI01gMgL0Fe]K05eMG@1hN7P0De=C03Lg=`16ATH0O7al06EUI@10@400AdM707UiN@1nOWh0
LW9b06IVIP1XJ6P0OWin05eMG@1DE5@0>CTi030`<01FEUH0ATI603Hf=P0c<c<0Jf][04m?C`11@D40
?Cdm069RHP1WIfL0FUYJ0451@@12@T80PH61079bLP26QXH0Rh^;07alO01?Cdl0U9BD061PH015ADD0
Hf=S08B4Q022PX80GEeM06MWI`1YJFT0G5aL07=cL`1dM7@0Q8B405aLG01CDe<0S8b<03<c<`1FEUH0
NWYj065QH@22PX80D51@04Q8B02DU9@0IFEU05aLG01[Jf/0AdM7061PH00c<c<0F5QH071`L080G5aL
0<00`L7104a<C01;Bd/0O7al08n?S`2/[:`0RXZ:06m_K`1iNGT0NWYj08F5Q@1IFET0AdM705aLG02R
XZ80clo?0;Ng]`1JFUX0G5aL04a<C021PH40P82004e=C@1]KFd0@d=305UIF@25QHD0AdM707IfMP1Z
JVX0M7Ad05MGE`1LG5`0>c/k055AD@1<C4`0EEEE04e=C@1WIfL0A4A405MGE`15ADD0B4Q8055AD@1H
F5P0EEEE069RHP1;Bd/0D51@065QH@19BDT0J6QX05EEE@1VIVH0<c<c05=CD`1=CDd0DE5A05UIF@21
PH40Q8B4055AD@1>CTh0Hf=S08V9R@1:BTX0KVi^06ATI01SHf<0XZ:R05UIF@2KVi/0>SXj02h^;P1I
FET0Lg=c07inOP2>SXh0>CTi059BDP0d=3@0I6AT07MgM`1FEUH0QHF503Xj>P1>CTh0?Cdm07=cL`14
A4@0?clo06i^KP0d=3@0Ng]k03De=@1[Jf/0Bd];06UYJ@28R8P0>SXj06i^KP1]KFd0;bl_07inOP1b
LW80:RXZ04e=C@1ADE40V9RH03Ti>@1mOGd0G5aL0492@P1kNg/09bLW038b<P1JFUX0HV9R03Hf=P1?
Cdl0ADE507MgM`1CDe<0@d=305]KF`1JFUX0IfMW04i>CP1FEUH0@D5105iNGP1/K6`0E5AD04Q8B01B
DU80=SHf07]kN`1cLg<0@T9209FEU@1:BTX0RXZ:03Hf=P17AdL0ATI605ADE02>SXh0DU9B038b<P1K
Fe/0Lg=c0<K6aP20P800QhN704M7A`1CDe<0H61P04i>CP1OGel0TI6A08b<S01/K6`0Ph>306m_K`1/
K6`0L71`061PH01eMGD0DU9B05mOG`14A4@0IFEU08n?S`1FEUH0ATI60410@012@T80]KFe07emO@26
QXH0_Kfm065QH@2CTi<0EeMG05mOG`1IFET0A4A405aLG01ZJVX0LG5a07emO@1YJFT2069RHP0Y07If
MP1VIVH0LG5a08V9R@1[Jf/0Ogmo08^;R`1[Jf/0RXZ:06UYJ@1LG5`0HF5Q05iNGP1YJFT0Kfm_059B
DP1gMgL0IfMW08Z:RP2HV9P0W9bL03<c<`0i>CT0ATI605ADE02EUID0Q8B4071`L02SXj<0De=C03dm
?@1LG5`0?clo04U9B@1SHf<0I6AT08J6QP2=SHd0QHF505iNGP1EEED00P2ATI40102EUID0T92@09jN
WP2PX:02ooooo`000?l0T92@0861P@1ADE40KFe]05QHF023Ph<0Ng]k03Lg=`1<C4`0Fe]K08j>SP1l
O7`0=3@d01lO7`12@T80ADE503Hf=P2TY:@0Rh^;024Q8@13@d<0R8R805iNGP1eMGD0R8R803De=@10
@400MgMg0<71`@1gMgL0QHF506YZJP0`<300L71`0:2PX02/[:`0GEeM08b<S00g=cL0?clo05UIF@2Q
XJ40FEUI0:NWY`2RXZ807AdM0451@@15ADD0Shn?079bLP25QHD0DE5A030`<00n?Sh0DU9B09RHV01X
J6P0Xj>S03Ph>00e=CD0HF5Q08V9R@1iNGT0IFEU051@D00J6QX0G5aL09bLW035aLD0F5QH07=cL`0I
6AT08b<S04i>CP1WIfL0EeMG04U9B@2?Shl092@T02d];@21PH40QhN7055AD@1iNGT0XJ6Q02`/;01F
EUH0F5QH06ATI00h>3P0K6a/09FEU@0V9RH0AdM707IfMP1TI6@0;Bd]075aL@0n?Sh0A4A406UYJ@27
QhL0>SXj0410@01TI6@0=3@d03Ph>01VIVH0NWYj034a<@1?Cdl0FUYJ04M7A`1@D500U9BD0::RXP16
ATH0IVIV06QXJ00i>CT0UiNG0;bl_00l?3`0<30`05mOG`1bLW80FEUI09jNWP2k^k/0>3Ph04Y:BP1Z
JVX0GEeM05=CD`2b/[80eMGE03Hf=P0h>3P0GUiN05EEE@1:BTX0d=3@0;fm_@0a<C40ADE504a<C01a
LG40QHF50=WIf@21PH40<S8b06ATI01aLG40NGUi0;Bd]02j^[X0@41004Y:BP1HF5P0MWIf0<S8b02]
[Jd0;2`/05EEE@1JFUX0Ph>306QXJ02>SXh0X:2P02DU9@1NGUh0MWIf06UYJ@2:RXX0`/;205=CD`0m
?Cd0DU9B09nOW`24Q8@0W9bL0<;2`P0g=cL092@T08N7Q`3=cLd0PX:20<[:bP3Lg=`0DE5A04U9B@2O
Wil0jn_[08j>SP30`<00WYjN03Hf=P1?Cdl0Y:BT0;Fe]@1KFe/0/;2`03Xj>P12@T80EUIF09FEU@1X
J6P0WYjN08f=S@15ADD0LW9b05UIF@32`/80E5AD0<W9b@1=CDd0?clo08b<S02a/K40K6a/07emO@1a
LG40:BTY05MGE`2IVIT0`l?305EEE@2/[:`0>SXj04m?C`37alL0^KVi06ATI02OWil0@T9204a<C022
PX80h^;R07=cL`2FUYH0NGUi05QHF01oOgl0^[Zj05IFEP1EEED0BDU904I6AP1`L700[Jf]05=CD`1G
EeL0?Cdm04U9B@1[Jf/007h0Y:BT09jNWP0n?Sh0CDe=05=CD`1UIFD0HV9R09VIV@1`L700a<C40=GE
e@2i^KT0QhN708n?S`2/[:`0?clo04a<C01gMgL0IFEU05ADE02IVIT0TY:B03Hf=P1=CDd0K6a/05UI
F@1YJFT0e]KF08>3P`0^;Rh0@T9206i^KP1TI6@0QHF50<W9b@1NGUh09bLW06ATI01RHV80DU9B06YZ
JP3;bl/0EEEE03hn?P1XJ6P0RXZ:04m?C`2CTi<0^k^k03Xj>P11@D40HV9R065QH@1jNWX0IfMW0;6a
/@1:BTX0<c<c04A4A01PH600HV9R07inOP2`/;00CTi>03hn?P1GEeL0ADE506a/K03dm?@0UiNG03Ph
>00j>SX0Fe]K04a<C01IFET0B4Q804U9B@17AdL0D51@061PH015ADD0?Shn092@T02?Shl0OGem06a/
K01EEED0F5QH03hn?P0d=3@0:BTY03Xj>P0d=3@0ADE503<c<`13@d<0=3@d02@T900`<300DE5A04Q8
B00i>CT0O7al04i>CP1CDe<0DU9B07=cL`1`L700Kfm_04m?C`13@d<0?Shn03Xj>P1?Cdl0GEeM05UI
F@1CDe<08B4Q075aL@1QHF40FEUI065QH@1MGEd0F5QH04=3@`16ATH203dm?@0`05MGE`1;Bd/0BDU9
08F5Q@0m?Cd0>SXj04=3@`14A4@0IfMW04i>CP1PH600JFUY07emO@1nOWh0]kNg04i>CP1=CDd0P820
09JFUP2RXZ80[jn_08V9R@2:RXX0@D5108J6QP0a<C40JVYZ06QXJ027QhL0QHF509JFUP1CDe<0Hf=S
055AD@1`L700PX:2059BDP1]KFd0DU9B06a/K024Q8@0DU9B07]kN`21PH40U9BD08>3P`1?Cdl0B4Q8
0P1KFe/0Z@1dM7@0Cdm?079bLP18B4P0E5AD05EEE@1[Jf/0CTi>06][J`1RHV80SHf=05IFEP1]KFd0
K6a/05eMG@1OGel0DU9B06a/K00m?Cd0IFEU06QXJ01;Bd/0FUYJ06EUI@20P800FEUI05mOG`15ADD0
Lg=c01`L701_Kfl0NWYj0:>SX`2o_kl0CDe=0<K6aP1`L700EeMG08b<S01oOgl0QhN70:>SX`22PX80
MWIf04];B`1SHf<0CTi>05ADE017AdL0=cLg06MWI`0o?cl0B4Q803@d=01dM7@0QXJ604];B`1UIFD0
KVi^09FEU@13@d<0?3`l04A4A00i>CT0GEeM06=SH`15ADD0RHV908B4Q01]KFd0QXJ604I6AP1GEeL0
=CDe07UiN@1XJ6P0@d=308n?S`0>3Ph09RHV03hn?P1CDe<0B4Q80:2PX01FEUH0SHf=06e]K@1WIfL0
JFUY04Y:BP1SHf<0?3`l08n?S`1NGUh0J6QX07emO@11@D40BDU905MGE`0f=SH0P82006m_K`1TI6@0
_kno05ADE01IFET07AdM02/[:`1@D500A4A4059BDP17AdL0J6QX08^;R`0n?Sh0K6a/0410@033`l<0
FUYJ03Hf=P1FEUH0B4Q805=CD`1kNg/0L71`03De=@1=CDd0Hf=S06YZJP1LG5`0EUIF07moO`13@d<0
Bd];059BDP1ADE40Ogmo0451@@2<S8`0PX:204U9B@2;Rh/0MGEe06EUI@1mOGd0PH610=gMg@1?Cdl0
MWIf07alO024Q8@0PX:2092@T029RHT0GEeM06ATI024Q8@0GEeM059BDP1dM7@0YJFU08f=S@1=CDd0
Jf][07EeM@1cLg<0`l?307=cL`0h>3P00P1OGel08P1FEUH0JFUY03dm?@2MWId0QhN70:n_[`1VIVH0
MWIf04Y:BP1FEUH0FUYJ02TY:@1WIfL0Ph>30:b/[02<S8`0?clo05YJFP1oOgl0AdM704];B`1aLG40
Vi^K0:2PX01MGEd0FUYJ06YZJP1OGel0De=C08F5Q@1jNWX0CTi>08B4Q02EUID2ooooo`0001`0SXj>
0;bl_025QHD0IVIV051@D01jNWX0b/[:06][J`2MWId0=CDe05IFEP1`L700IfMW04M7A`1[Jf/0?Cdm
038b<P0Z:RX0FUYJ055AD@1dM7@0ADE502DU9@1FEUH0F5QH0410@00m?Cd0Kfm_0P0o?cl0eP26QXH0
H61P04M7A`1NGUh0O7al02PX:01=CDd0Hf=S055AD@0V9RH0JVYZ04A4A017AdL0FUYJ09ZJVP0b<S80
;bl_04e=C@1<C4`0@d=309:BTP2^[Zh0:2PX03`l?012@T80BTY:05MGE`2a/K40Ti>C02LW9`1UIFD0
GemO04E5A@1lO7`0XZ:R02h^;P0b<S80CTi>06i^KP1HF5P0UIFE03De=@0L71`0<S8b075aL@2<S8`0
GemO0;^k^`1TI6@092@T03Ti>@23Ph<0Fe]K07inOP3Hf=P07AdM03De=@23Ph<0QhN705=CD`2GUiL0
dm?C03/k>`0i>CT0De=C09VIV@1IFET0cLg=07UiN@0P8200>SXj08j>SP1MGEd0]kNg09nOW`0^;Rh0
?Shn04E5A@1kNg/0KVi^07inOP21PH409bLW055AD@1PH600Ti>C06MWI`2JVYX0SHf=02PX:01SHf<0
^k^k092@T01YJFT0SXj>04E5A@0i>CT0Kfm_0:FUY@21PH40GemO071`L00_;bl0CDe=08J6QP2UYJD0
L71`06a/K02PX:00CDe=04E5A@2BTY80YJFU08F5Q@2?Shl0P82003/k>`1DE5@0UiNG0:RXZ01JFUX0
Vi^K05MGE`1>CTh0Fe]K0:^[Z`2<S8`0Ogmo075aL@0o?cl0MgMg0:VYZ@1bLW80OGem06m_K`0`<300
BDU904m?C`2JVYX0H61P06i^KP1ADE40<C4a04Q8B01TI6@0VIVI04U9B@29RHT0SHf=02l_;`1SHf<0
e]KF09FEU@0i>CT0OWin06QXJ00i>CT0Jf][0;Zj^P22PX80Bd];065QH@1?Cdl0EeMG09NGU`3Hf=P0
Hf=S04Y:BP1aLG40BDU904m?C`2/[:`0UYJF03`l?01PH600Cdm?04M7A`2ATI40a<C40451@@0m?Cd0
HV9R06e]K@1nOWh0`l?30;Zj^P0b<S80EeMG09>CT`26QXH0alO70:VYZ@0b<S80=CDe07QhN02l_;`0
NWYj0=KFeP1YJFT0>3Ph05UIF@2CTi<0LW9b0=gMg@0k>c/0@T9207UiN@25QHD0QhN70<;2`P24Q8@0
?Cdm09>CT`31`L4207moO`2904m?C`0n?Sh0I6AT0:^[Z`2;Rh/0^;Rh07MgM`0S8b<0CDe=06YZJP2k
^k/0ZJVY09NGU`1:BTX0;Rh^06QXJ01PH600>SXj05QHF02>SXh0QhN704Y:BP1mOGd0O7al08j>SP1M
GEd0ZZZZ02HV9P0k>c/0@d=30:2PX01ZJVX0Ogmo08F5Q@0b<S80B4Q804m?C`24Q8@0E5AD075aL@20
P800?Cdm04E5A@2>SXh0][Jf07EeM@2:RXX0Hf=S04a<C01HF5P0KFe]09BDU01;Bd/0J6QX04Q8B00b
<S80CDe=0820P01_Kfl0G5aL0:VYZ@1XJ6P0?Cdm0451@@1PH600RHV903dm?@2<S8`0D51@03Hf=P1=
CDd0IVIV07]kN`18B4P0G5aL06ATI01fMWH0lo?c0=[JfP1JFUX0HF5Q07YjNP1fMWH0FUYJ06EUI@1^
KVh0P820079bLP1_Kfl0GEeM05EEE@25QHD0LG5a03Xj>P0e=CD0=cLg05QHF00k>c/0?clo02TY:@19
BDT0@41004m?C`0l?3`0AdM704i>CP1DE5@0C4a<06][J`1?Cdl0>SXj06YZJP1JFUX0Jf][07EeM@17
AdL09BDU04U9B@1>CTh0<C4a03dm?@1UIFD0MWIf03Ti>@0h>3P0GUiN03Ti>@0V9RH0=SHf04A4A017
AdL0=CDe03/k>`0[:b/0?clo04Q8B014A4@00P1BDU807@15ADD0GUiN04a<C014A4@0EEEE059BDP18
B4P0>CTi05MGE`1MGEd0CTi>04U9B@1QHF40D51@05aLG01OGel0JFUY05=CD`1DE5@0HV9R06MWI`1T
I6@0P82003/k>`0o?cl0Hf=S08J6QP2EUID0Fe]K0080AdM701l0?clo05EEE@1]KFd0DU9B05eMG@13
@d<0G5aL03/k>`12@T80D51@07MgM`1NGUh0EeMG04Y:BP1NGUh0Fe]K0410@01<C4`0CTi>05QHF00k
>c/0>3Ph05=CD`1PH600B4Q805UIF@1fMWH0Ogmo05eMG@17AdL0DU9B0080L71`00<0AdM705QHF00^
;Rh00P1dM7@0S`1cLg<0N7Qh06ATI02=SHd0I6AT06UYJ@1?Cdl0OGem05ADE01lO7`0NWYj0;6a/@2f
][H0Cdm?05YJFP1<C4`0F5QH08f=S@1MGEd0Ph>30;^k^`1YJFT0OGem0;2`/027QhL0Ng]k07UiN@1N
GUh0IfMW061PH016ATH0BDU904e=C@1NGUh0PX:204m?C`1IFET0AdM7065QH@13@d<0HF5Q05aLG00c
<c<0F5QH061PH01eMGD0RXZ:06m_K`0c<c<0DU9B05MGE`27QhL0I6AT0:NWY`1aLG40IVIV08>3P`0V
9RH0AdM7071`L01^KVh0A4A4065QH@1MGEd0VYZJ06QXJ018B4P0EUIF0410@01]KFd09bLW06UYJ@17
AdL0HV9R08^;R`1GEeL0Ph>309RHV01SHf<0]KFe0;2`/01EEED0KFe]04Q8B02GUiL0?3`l059BDP1F
EUH0E5AD092@T01HF5P0Bd];07MgM`21PH40e=CD069RHP2PX:00B4Q804e=C@2/[:`0LG5a06EUI@1N
GUh0Ph>3071`L02UYJD0BTY:061PH02;Rh/0FEUI06QXJ01OGel0EeMG04e=C@1]KFd0OWin069RHP1P
H600FUYJ06QXJ02XZ:P0Rh^;05iNGP1dM7@0Jf][065QH@1YJFT0IVIV07alO01:BTX0BDU904e=C@1W
IfL0YJFU0861P@2LW9`0QXJ60820P01UIFD0L71`06i^KP17AdL0@d=30080FEUI02L0MGEe04m?C`0a
<C40[jn_07AdM01IFET0Ng]k04Q8B02WYjL0VYZJ0:NWY`2<S8`0/k>c05QHF02EUID0T92@069RHP2Y
ZJT0Ph>307QhN01kNg/0Bd];08F5Q@1UIFD0=cLg04=3@`16ATH0Cdm?06i^KP1SHf<0IFEU05]KF`19
BDT0R8R807UiN@2NWYh0P82009bLW02h^;P00_ooool0000507moO`1TI6@0TI6A09fMW@1GEeL00P1I
FET0o`1MGEd0][Jf08N7Q`0a<C40DU9B05MGE`15ADD0XJ6Q0861P@0U9BD0EUIF04U9B@0b<S80UYJF
0;2`/00S8b<0<c<c06i^KP1HF5P0G5aL0;>c/`1QHF408B4Q03Xj>P1`L700BDU908N7Q`3YjNT0EEEE
02<S8`1^KVh0RHV904i>CP2m_Kd0K6a/03/k>`1BDU80PH6106=SH`1gMgL0VYZJ0410@00X:2P0KVi^
09FEU@1ZJVX0Rh^;08f=S@0U9BD0>SXj04E5A@2=SHd0E5AD0;jn_P1eMGD0<30`05=CD`1PH600JVYZ
06ATI02<S8`07QhN03<c<`1<C4`0De=C038b<P23Ph<0O7al02DU9@0f=SH0A4A406a/K01:BTX0EEEE
05YJFP0O7al09BDU04e=C@0g=cL0BDU907IfMP16ATH0=CDe055AD@1NGUh0DE5A03@d=01eMGD0BDU9
030`<01_Kfl0T92@02XZ:P1WIfL0C4a<03Hf=P1RHV80X:2P08F5Q@0/;2`0Q8B404i>CP0l?3`0CDe=
075aL@1?Cdl0@41005aLG00m?Cd0<S8b05MGE`2VYZH0Cdm?03<c<`1OGel0CTi>07MgM`2XZ:P0FEUI
02l_;`17AdL0FEUI05eMG@2_[jl0][Jf065QH@0g=cL0CDe=08>3P`22PX80Q8B409bLW016ATH0>SXj
071`L02MWId0Kfm_09NGU`2XZ:P0@d=303hn?P1nOWh0/[:b069RHP3IfMT0GemO03Ph>015ADD0W9bL
061PH02OWil0/;2`03Hf=P1[Jf/0Y:BT065QH@2VYZH0`l?304Y:BP0a<C40NWYj09nOW`1]KFd0^[Zj
08R8R00_;bl0?clo05eMG@2@T900G5aL0:FUY@2DU9@0=SHf03lo?`25QHD0Xj>S08f=S@2l_;`0Ogmo
02LW9`1GEeL0];Bd09fMW@37alL0gmoO06i^KP0n?Sh0GEeM0:f][@2`/;00[:b/0=_Kf`18B4P0E5AD
07QhN032`/80T92@0<30`01=CDd0?3`l075aL@2<S8`0XZ:R07UiN@2f][H0;Bd]04e=C@2:RXX0c<c<
08B4Q02g]kL0O7al03@d=02@T900emOG09FEU@22PX80PH6104e=C@10@400MGEe0;Bd]01]KFd0_;bl
02l_;`12@T80dm?C0:ZZZP1=CDd0Y:BT06ATI00l?3`0LW9b0<k>cP1hN7P0VYZJ08R8R012@T80UYJF
08j>SP12@T80L71`08B4Q01QHF40SXj>0:2PX01BDU80EEEE06m_K`1>CTh0DE5A06][J`2`/;00ATI6
0451@@00501jNWX0;2`/03Xj>P1IFET0WIfM08B4Q02ATI40[:b/08>3P`25QHD0a/K608R8R00f=SH0
Hf=S061PH013@d<0QHF50<S8b01;Bd/0;2`/0P1`L700801aLG40Xj>S0:n_[`0o?cl0>3Ph05EEE@2<
S8`0MWIf0:j^[P1UIFD0;Rh^04Q8B01gMgL0Ng]k06=SH`2l_;`0De=C02d];@0h>3P0IVIV07AdM01@
D500c<c<08>3P`0`<300?clo05=CD`2FUYH0C4a<0:RXZ02IVIT09bLW0P1<C4`0:023Ph<0C4a<04e=
C@1LG5`0De=C08f=S@2d];@0NGUi08:2PP1BDU80>CTi03Ph>01cLg<0FUYJ0410@00i>CT0IfMW07Mg
M`1DE5@0FUYJ04a<C01TI6@0CDe=04Y:BP0i>CT09bLW04m?C`0n?Sh0?3`l04=3@`1HF5P0<c<c04i>
CP14A4@0De=C06EUI@19BDT0?clo04M7A`1cLg<207emO@0908j>SP1bLW80C4a<05aLG01@D500=cLg
0410@01<C4`0Hf=S0080ATI604H0EeMG0410@01BDU80AdM704A4A01CDe<0GUiN06m_K`0[:b/0DE5A
06i^KP1EEED0IfMW04];B`0n?Sh0NGUi05MGE`1FEUH0@d=303<c<`1BDU80EEEE0492@P0c<c<0AdM7
05YJFP2EUID0=cLg03/k>`1^KVh0V9RH07YjNP1KFe/0A4A404=3@`1JFUX0Kfm_04U9B@14A4@0EeMG
09ZJVP3GemL0VIVI03dm?@1=CDd0AdM703dm?@0j>SX0B4Q804m?C`0V9RH0;Rh^03dm?@17AdL0=CDe
03`l?015ADD0DE5A03Ph>00P8200<C4a04A4A01;Bd/0:BTY03@d=012@T80>3Ph02d];@0`<300?3`l
0P0j>SX0?01<C4`0@d=304i>CP13@d<0@T9206a/K026QXH0IFEU02h^;P0o?cl0=CDe03Lg=`0m?Cd0
E5AD06QXJ01YJFT0HV9R05eMG@1TI6@06a/K05mOG`1@D500OWin09>CT`1OGel0S8b<02d];@1>CTh0
KFe]06IVIP1RHV80J6QX06=SH`2EUID0OWin08B4Q01cLg<0NWYj06QXJ029RHT0M7Ad06EUI@1?Cdl0
G5aL08B4Q02CTi<0FEUI09nOW`1JFUX0I6AT04I6AP1XJ6P0NWYj0492@P1CDe<0DU9B05mOG`3=cLd0
U9BD04=3@`80J6QX01`0QhN704E5A@1QHF40M7Ad05iNGP1dM7@0<30`04I6AP10@400E5AD05eMG@1h
N7P0G5aL08N7Q`1dM7@0Hf=S04a<C013@d<0De=C02<S8`26QXH0N7Qh05mOG`1DE5@0EUIF04a<C01B
DU80G5aL0P1TI6@06@1LG5`0UIFE05UIF@1TI6@0MWIf069RHP1BDU80HF5Q061PH01dM7@0J6QX07Qh
N01bLW80PH6108n?S`2RXZ80>c/k04i>CP1=CDd0EUIF04I6AP1OGel0Lg=c05]KF`1RHV800P1EEED0
7@1;Bd/0GEeM05]KF`0m?Cd0DU9B03hn?P0o?cl0=CDe04Y:BP1_Kfl0KVi^03Ph>01iNGT0H61P05]K
F`2EUID0FEUI0::RXP1DE5@0Ti>C08V9R@1NGUh0PX:205ADE01gMgL0HV9R07UiN@1nOWh0A4A40080
E5AD02d0J6QX09nOW`1=CDd0DU9B06m_K`1OGel0W9bL05]KF`0e=CD0Hf=S05EEE@1GEeL0LG5a07Qh
N02>SXh0IFEU08>3P`2n_[h0bl_;079bLP1MGEd0GUiN069RHP1cLg<0PX:20;jn_P28R8P07AdM059B
DP1RHV80=3@d04Y:BP1nOWh0RHV908n?S`1`L700J6QX06e]K@1ADE40Shn?071`L02CTi<0Rh^;0:f]
[@2a/K400_ooool0003o0:^[Z`1/K6`0KVi^0;Vi^@21PH40[jn_0492@P1FEUH0RHV90<K6aP1NGUh0
[Jf]02/[:`19BDT0IFEU0:FUY@1aLG40emOG06a/K00m?Cd0ATI606e]K@1NGUh0JFUY08j>SP0/;2`0
De=C09FEU@2@T900De=C08:2PP1WIfL08b<S05QHF02WYjL0[Zj^065QH@2TY:@06a/K0410@01<C4`0
L71`04E5A@1RHV80K6a/02LW9`1@D500Ph>305eMG@0k>c/0FEUI04];B`1:BTX0Ng]k0:ZZZP1/K6`0
<c<c06ATI00e=CD0CDe=08f=S@2SXj<0@d=303Hf=P1FEUH0GemO05YJFP2JVYX0Jf][020P8015ADD0
?Cdm04A4A01fMWH0S8b<02d];@0U9BD0?Shn059BDP13@d<0MgMg09fMW@0f=SH0=3@d04i>CP15ADD0
HF5Q0;^k^`1WIfL08b<S03hn?P1aLG40MWIf079bLP2:RXX0@T9202d];@10@400IFEU04I6AP2NWYh0
Ph>303Hf=P0e=CD0DE5A08j>SP1ADE40b<S808B4Q00i>CT0<S8b069RHP1UIFD0Rh^;0:NWY`19BDT0
<S8b04i>CP1hN7P0IFEU06ATI02CTi<0:b/[03Ph>01nOWh0]KFe07AdM02WYjL0SHf=04I6AP1YJFT0
XZ:R08R8R01ZJVX0c<c<08j>SP0j>SX0EUIF08N7Q`23Ph<0De=C09>CT`1TI6@0BTY:05eMG@2>SXh0
U9BD07MgM`1cLg<0>CTi03dm?@1gMgL0c<c<07inOP2:RXX0S8b<04e=C@10@400TY:B08J6QP2RXZ80
?Cdm05EEE@1DE5@0UiNG0:6QX@1NGUh0X:2P06EUI@1JFUX0IVIV09jNWP1[Jf/0K6a/09JFUP0a<C40
:BTY07IfMP1oOgl0Kfm_07EeM@2MWId0<C4a03Hf=P2g]kL0^;Rh05iNGP29RHT0a<C40492@P0n?Sh0
XZ:R0;no_`1FEUH0IFEU05UIF@13@d<0C4a<0:^[Z`1[Jf/0@T9205MGE`1EEED0HV9R07alO02@T900
;2`/04i>CP1nOWh0EUIF07=cL`33`l<0S8b<02l_;`1MGEd0U9BD08^;R`3>c/h0YZJV03De=@1?Cdl0
KVi^06QXJ01iNGT0/;2`03`l?01:BTX0K6a/06i^KP1cLg<0iNGU05IFEP0[:b/0QXJ609BDU01eMGD0
e]KF06MWI`0o?cl0CDe=092@T01dM7@0`<300:NWY`0/;2`0NWYj07]kN`1UIFD0SHf=09FEU@0i>CT0
?3`l08>3P`1_Kfl0Shn?000_08b<S00g=cL0@41004m?C`2@T900F5QH075aL@36a/H0nOWi0>c/k03N
g]h0kno_0>;RhP3/k>`0WinO03lo?`1]KFd0L71`0=KFeP1dM7@0^KVi05YJFP16ATH0FUYJ06MWI`2:
RXX0HV9R0:>SX`1>CTh0=SHf05MGE`25QHD0I6AT07IfMP2RXZ80<30`0410@01RHV80UiNG069RHP2F
UYH0UIFE0451@@1ADE40YjNW0;jn_P12@T800P1SHf<0G`1CDe<0@D5108:2PP2_[jl0IFEU04Y:BP22
PX80@41003hn?P1=CDd0OWin0410@012@T80FEUI03hn?P19BDT0DU9B09>CT`1PH600`/;20:ZZZP12
@T80EUIF06e]K@14A4@0DE5A04a<C018B4P0BDU904];B`1QHF40Cdm?03dm?@1SHf<0KFe]069RHP1K
Fe/0BTY:04m?C`0c<c<0ADE502/[:`0c<c<0<S8b05ADE00h>3P0<c<c034a<@1BDU80HV9R05]KF`0n
?Sh0;Bd]06EUI@1PH600E5AD05MGE`1HF5P0E5AD06][J`1KFe/0CTi>04M7A`0n?Sh0De=C05eMG@1K
Fe/0GemO01lO7`1XJ6P0GUiN055AD@0b<S80;bl_03Hf=P18B4P0AdM702h^;P0j>SX0AdM704m?C`1D
E5@0Fe]K04i>CP1BDU80B4Q803/k>`1=CDd0Bd];03lo?`17AdL0PX:206][J`20P800B4Q80080@T92
02D0JVYZ07YjNP1bLW80H61P06EUI@0l?3`0S8b<05YJFP1[Jf/0HV9R07emO@1hN7P0Q8B4051@D01F
EUH0I6AT05aLG01ADE40CDe=05MGE`0i>CT0ADE504Y:BP1JFUX0B4Q806ATI01;Bd/0IFEU0492@P19
BDT0>c/k04E5A@1@D500C4a<04M7A`0n?Sh0ATI60080AdM703d0Bd];04m?C`1JFUX0LG5a05aLG01S
Hf<0FEUI05ADE01TI6@0DE5A04Q8B00h>3P0E5AD03dm?@1mOGd0De=C03De=@1HF5P0EEEE04A4A00Q
8B40?Shn01<C4`1`L700DE5A09FEU@20P800E5AD092@T00U9BD0?Cdm06ATI01IFET0UiNG0<S8b016
ATH0ADE50492@P0o?cl09BDU075aL@22PX80Ph>306EUI@18B4P0QXJ605mOG`1_Kfl0HV9R05QHF02Z
ZZX0FEUI06UYJ@15ADD0@T9205=CD`1:BTX0M7Ad06UYJ@14A4@0NWYj0080D51@01L0HV9R065QH@2b
/[80CDe=07emO@1]KFd0BTY:09>CT`1hN7P0?clo051@D01RHV80A4A407AdM01fMWH0QXJ608R8R01M
GEd0Hf=S07IfMP2=SHd0KVi^07]kN`0207YjNP1^06YZJP1]KFd0C4a<05MGE`18B4P0Lg=c05mOG`1?
Cdl0[Zj^06IVIP1gMgL0@d=304M7A`1DE5@0H61P079bLP23Ph<0H61P07emO@24Q8@0WinO08V9R@2S
Xj<09RHV04m?C`1GEeL0G5aL07QhN029RHT0U9BD04A4A01@D500ATI606QXJ01hN7P0HV9R07EeM@1U
IFD0CTi>04I6AP1HF5P0HV9R0410@01gMgL0MGEe04I6AP2EUID0NWYj0410@01]KFd0De=C092@T013
@d<0DU9B05ADE01YJFT0MGEe059BDP28R8P0RXZ:07UiN@2PX:00Cdm?079bLP1CDe<0Ph>308R8R01F
EUH0GUiN08J6QP2NWYh0g]kN06m_K`0R8R80KVi^04e=C@1CDe<0Jf][03dm?@1_Kfl0GUiN07MgM`19
BDT0MgMg05MGE`2GUiL0P82004M7A`1nOWh0M7Ad079bLP1IFET0:BTY05iNGP2BTY80C4a<04];B`1k
Ng/0QHF509BDU01aLG40OGem06MWI`1@D500Ti>C092@T01gMgL0LW9b08^;R`24Q8@2ooooo`0001D0
N7Qh0:BTY01/K6`0K6a/06QXJ02l_;`0Kfm_03hn?P2JVYX0C4a<05IFEP1`L700R8R803De=@1WIfL0
=SHf02PX:01^KVh0RXZ:038b<P0h>3P00P1=CDd0:`1nOWh0UYJF0410@00Z:RX0FUYJ07MgM`1JFUX0
[:b/09nOW`0Y:BT09RHV06=SH`2FUYH0OGem0>;RhP1CDe<09RHV065QH@1aLG40Cdm?0:6QX@2CTi<0
:2PX02XZ:P1UIFD0HV9R06e]K@2k^k/0E5AD030`<019BDT0QXJ607inOP1`L700ZJVY0451@@0`<300
K6a/09>CT`1YJFT0KVi^05eMG@0X:2P00P1CDe<0`@1jNWX0IFEU0:>SX`0h>3P092@T04a<C01NGUh0
Fe]K061PH02^[Zh0>CTi024Q8@1LG5`0UIFE07alO02CTi<0Z:RX028R8P0o?cl0LW9b096AT@1VIVH0
/;2`08V9R@0V9RH0ADE50:2PX020P800D51@0;:b/P1fMWH0820P04E5A@2GUiL0TI6A069RHP1mOGd0
9bLW03dm?@1@D500Ti>C05iNGP1OGel0KFe]02l_;`12@T80UYJF0:>SX`1;Bd/0SHf=04i>CP0g=cL0
@41008>3P`1GEeL0>3Ph04m?C`11@D40E5AD06m_K`2`/;00D51@03dm?@1^KVh0I6AT04m?C`2OWil0
/K6a0410@019BDT0KFe]03lo?`1UIFD0d=3@0<30`00l?3`0LG5a08^;R`0o?cl0KFe]0=3@d01^KVh0
>c/k07]kN`1TI6@0GUiN08V9R@35aLD0Fe]K04I6AP1>CTh0KVi^0<g=c@20P800<30`04U9B@1QHF40
EUIF05aLG02QXJ40O7al02l_;`1bLW80Lg=c07AdM01iNGT0^k^k03<c<`0O7al0Hf=S07=cL`1dM7@0
UiNG0>_[j`18B4P09bLW07UiN@30`<00Z:RX0:JVYP3dm?@0CDe=05=CD`1DE5@0YJFU0:6QX@2_[jl0
Q8B403@d=01KFe/0Jf][07EeM@2<S8`0ZJVY05=CD`19BDT0U9BD08B4Q01jNWX0]kNg0;Fe]@0R8R80
Bd];08B4Q038b<P0MgMg0<_;b`1RHV80=cLg08J6QP2_[jl0MgMg09JFUP2^[Zh0<c<c03lo?`2TY:@0
P82006QXJ02GUiL0>SXj03/k>`33`l<0aLG5092@T02VYZH0BTY:03Xj>P2a/K40alO7061PH020P800
CDe=03Xj>P1^KVh0]KFe07emO@1hN7P0FUYJ03lo?`1eMGD0UYJF06ATI01PH600GUiN01lO7`1IFET0
PH6107]kN`0h>3P0O7al04I6AP19BDT00P15ADD0A@18B4P0LW9b071`L01KFe/0SXj>0;Zj^P2GUiL0
CTi>05IFEP1gMgL0BTY:05IFEP2JVYX0Ng]k03Lg=`1GEeL0Jf][05EEE@1fMWH0YZJV09FEU@0Z:RX0
IFEU05eMG@1<C4`0O7al0<[:bP1RHV80:2PX061PH01BDU80@T9207UiN@3?cll0O7al02h^;P1JFUX0
R8R806QXJ01fMWH0NGUi03De=@0d=3@0Cdm?07inOP2NWYh0UIFE0;>c/`0n?Sh0>CTi055AD@1LG5`0
Hf=S07EeM@2NWYh0@T9205eMG@1?Cdl0XJ6Q092@T02IVIT0K6a/05QHF01gMgL0Ng]k04E5A@0c<c<0
I6AT06e]K@0205MGE`1J07EeM@1VIVH0C4a<08b<S02@T900RHV906i^KP1<C4`0EEEE02h^;P19BDT0
>SXj0492@P13@d<0Hf=S03De=@0n?Sh0@d=306UYJ@1ADE40Hf=S04=3@`0c<c<0CTi>05YJFP1KFe/0
IFEU05QHF00c<c<0De=C03lo?`0/;2`0<S8b05iNGP1ZJVX0AdM703Xj>P1NGUh07QhN03`l?01:BTX0
IfMW04i>CP1NGUh0KFe]02l_;`11@D40CTi>0410@015ADD0C4a<0451@@1>CTh0;bl_04=3@`1EEED0
F5QH055AD@10@400F5QH04];B`1BDU80=CDe05mOG`1@D500DU9B065QH@1`L700LG5a061PH01ZJVX0
E5AD04A4A01YJFT0DU9B04];B`1[Jf/0WYjN08b<S01SHf<0Fe]K05UIF@15ADD0De=C05eMG@0g=cL0
@d=303Hf=P1GEeL0?3`l0P0i>CT0?@1gMgL0AdM704I6AP19BDT0JVYZ05YJFP0i>CT0E5AD04U9B@1I
FET0>CTi04];B`14A4@0AdM703`l?013@d<0IVIV06][J`16ATH0=SHf04];B`24Q8@0N7Qh06e]K@1K
Fe/0?3`l08B4Q00h>3P0>CTi0410@01FEUH0H61P06e]K@1WIfL0@T9204U9B@0H61P0SHf=07IfMP3:
b/X0N7Qh05]KF`1aLG40:2PX03hn?P27QhL0Bd];05aLG02;Rh/0Cdm?05iNGP19BDT0IfMW0410@015
ADD0@d=304E5A@2IVIT0HF5Q061PH01HF5P00P2=SHd0:P1CDe<0L71`05=CD`26QXH0EeMG05YJFP1F
EUH0ATI604Q8B01<C4`0@d=307inOP1^KVh0EeMG06=SH`1LG5`0@D5104A4A01cLg<0SHf=071`L025
QHD0CTi>055AD@1CDe<0IVIV04A4A01dM7@0G5aL07moO`1fMWH0B4Q805IFEP1MGEd0SXj>05mOG`1m
OGd0K6a/06ATI01dM7@0JFUY055AD@80O7al06T0NWYj06e]K@1BDU80QhN705=CD`1iNGT0G5aL05QH
F02>SXh0HF5Q07UiN@17AdL0Fe]K0861P@1/K6`0Ti>C05EEE@2CTi<0IVIV05aLG01`L700HV9R05mO
G`1WIfL0L71`05EEE@1LG5`0IFEU071`L01jNWX0FUYJ0820P01XJ6P0AdM705MGE`1NGUh0JFUY04i>
CP2>SXh0I6AT05UIF@2RXZ80G5aL04Y:BP1mOGd0IVIV08j>SP0U9BD0EEEE06ATI01JFUX0M7Ad07Ui
N@1/K6`0J6QX069RHP1eMGD0C4a<069RHP1PH600KFe]09bLW01GEeL0Ph>308:2PP1RHV80JFUY03dm
?@0i>CT0PH6106ATI01kNg/0OWin04a<C02CTi<0YJFU0:NWY`24Q8@0ZZZZ06=SH`1iNGT0QHF504A4
A020P800V9RH09ZJVP1mOGd0BDU905UIF@1ZJVX0HF5Q0820P01/K6`0M7Ad07IfMP1>CTh0D51@04e=
C@1`L700LG5a06a/K01cLg<0QHF50;2`/02ZZZX00_ooool0001A05iNGP2VYZH0]kNg0820P01:BTX0
I6AT0::RXP1lO7`0_Kfm04A4A012@T80IfMW0:>SX`1/K6`0aLG5034a<@1?Cdl0CTi>06a/K01JFUX0
QHF505UIF@0C4a<0>CTi09NGU`1SHf<0O7al092@T01<C4`0<c<c05UIF@2m_Kd0MgMg06i^KP1oOgl0
@D5104U9B@2PX:00];Bd05mOG`1bLW80?3`l0451@@1cLg<0/[:b05aLG01GEeL0Kfm_02l_;`17AdL0
U9BD0;>c/`14A4@0Jf][08b<S014A4@0AdM709FEU@1nOWh0DU9B07QhN01TI6@0A4A408b<S02o_kl0
H61P03/k>`1QHF4092@T03<c<`1kNg/0Bd];028R8P1>CTh0A4A4059BDP1YJFT0ZJVY04Y:BP0T92@0
<c<c0080Hf=S04T0Rh^;0=KFeP0b<S80>3Ph061PH01QHF40Hf=S09JFUP27QhL0:b/[02`/;01BDU80
IVIV05iNGP2;Rh/0RHV9028R8P0];Bd0BTY:05iNGP2CTi<0YjNW04I6AP0Q8B40<S8b05eMG@1XJ6P0
NGUi0:JVYP0i>CT0>SXj04U9B@22PX80OGem0;Ng]`1eMGD0:BTY055AD@1PH600F5QH05aLG02MWId0
BTY:02<S8`1HF5P0H61P06UYJ@1/K6`0Ph>303Ti>@0a<C40PH610:n_[`1TI6@0S8b<0;Vi^@17AdL0
=3@d06i^KP31`L40GemO09^KV`2g]kL0EeMG06=SH`2@T900f][J07EeM@37alL0BDU90492@P1iNGT0
Q8B40080P82004l0Rh^;03@d=023Ph<0/k>c05QHF01oOgl0IVIV055AD@19BDT0PX:20:VYZ@1>CTh0
Kfm_061PH014A4@0HF5Q0::RXP2k^k/0EUIF08N7Q`1bLW80=CDe05=CD`1NGUh0QXJ605IFEP2<S8`0
CDe=03Xj>P1SHf<0TY:B0=[JfP2GUiL0][Jf079bLP0n?Sh0T92@0=CDe01RHV80RHV908:2PP0f=SH0
P8200;bl_02c/k<0Bd];0820P01SHf<0<C4a096AT@39bLT0M7Ad04];B`1HF5P0Bd];03`l?02n_[h0
Y:BT03@d=01DE5@0K6a/06QXJ02;Rh/0`/;206EUI@11@D40_Kfm05YJFP1lO7`0bLW906ATI00m?Cd0
J6QX08Z:RP2<S8`0][Jf051@D00`<300NGUi0080Ng]k0<h0b/[:08^;R`0f=SH0C4a<0861P@1SHf<0
/K6a0:2PX00K6a/0=SHf06a/K029RHT0[Zj^08^;R`0/;2`0?Cdm06MWI`2UYJD0FEUI09nOW`2<S8`0
?3`l034a<@0i>CT0?Cdm02/[:`1?Cdl0QHF507alO02/[:`0^[Zj06e]K@32`/80alO703hn?P11@D40
Ti>C08>3P`1<C4`0S8b<08Z:RP0Q8B40=CDe07]kN`2JVYX0Bd];0:VYZ@1IFET0?Cdm03`l?02;Rh/0
/k>c05ADE02ATI40?clo02TY:@1=CDd0P8200:RXZ01/K6`0V9RH04a<C016ATH0FUYJ06IVIP22PX80
?Shn06UYJ@2:RXX08b<S061PH02LW9`0Ng]k04i>CP1lO7`0LG5a03<c<`1GEeL0MGEe079bLP1[Jf/0
C4a<0:FUY@1ZJVX0ATI608n?S`1XJ6P0MgMg0820P01ZJVX0?Cdm06i^KP1PH600E5AD04E5A@1JFUX0
IFEU04A4A01?Cdl0C4a<05UIF@1TI6@0HF5Q059BDP0h>3P0DU9B03`l?01GEeL0ATI606YZJP0o?cl0
De=C03dm?@1cLg<0Ng]k06ATI016ATH0@d=305IFEP1JFUX0KVi^075aL@1`L700CTi>07MgM`12@T80
?clo04i>CP1_Kfl0Fe]K051@D01KFe/0L71`02TY:@1/K6`0M7Ad092@T01ADE40L71`08:2PP0c<c<0
G5aL07moO`1?Cdl0GemO05=CD`16ATH0NWYj03dm?@1MGEd0F5QH04=3@`1>CTh0A4A404];B`0m?Cd0
BDU905QHF02DU9@0?clo0492@P1gMgL0SXj>09FEU@1LG5`0Cdm?05=CD`1HF5P0S8b<05EEE@18B4P0
IfMW0:ZZZP3AdM40ZJVY04e=C@1RHV80Cdm?051@D01MGEd0C4a<061PH00a<C40@T9204];B`0k>c/0
B4Q804U9B@14A4@0DU9B04A4A00X:2P0?Cdm03`l?01:BTX0=3@d04a<C00a<C40@T9203hn?P0d=3@0
@d=304a<C01RHV80Fe]K0410@080BTY:06/0IfMW06i^KP1lO7`0ADE504Y:BP1cLg<0820P04Y:BP1=
CDd0FUYJ061PH00k>c/0ATI604m?C`1OGel06a/K04U9B@0m?Cd0W9bL09>CT`1SHf<0HF5Q02d];@1D
E5@0_;bl03Xj>P1lO7`0S8b<03`l?028R8P0?Shn04a<C00];Bd0I6AT092@T00g=cL0@4100451@@1Y
JFT0CDe=06MWI`1NGUh0Hf=S096AT@1=CDd0DE5A04e=C@26QXH0NWYj02`/;01GEeL0CDe=04Y:BP3<
c<`0T92@03Ti>@0l?3`0A4A407moO`16ATH0NGUi06i^KP1kNg/0MGEe02PX:00i>CT0DU9B07EeM@2K
Vi/0XJ6Q092@T01oOgl0Ng]k08Z:RP21PH40H61P07AdM00a<C40RXZ:079bLP1_Kfl0MgMg08^;R`26
QXH0QHF5061PH02VYZH0MGEe04A4A02?Shl0D51@08b<S01gMgL0I6AT07UiN@1[Jf/0P82006=SH`1W
IfL0RHV90:2PX038b<P0CTi>08:2PP1OGel0Lg=c07alO00204Q8B01B06=SH`1EEED0EeMG06UYJ@1A
DE40G5aL07EeM@1DE5@0H61P07EeM@1JFUX0BDU908N7Q`2LW9`0HF5Q05]KF`1>CTh0HV9R092@T01N
GUh0G5aL0:6QX@1<C4`0FUYJ03`l?01TI6@0Lg=c06i^KP1]KFd0E5AD065QH@1mOGd0MGEe07]kN`1O
Gel0Lg=c06EUI@2WYjL0TI6A071`L01gMgL0QXJ609NGU`2;Rh/0DU9B04I6AP25QHD0GEeM09:BTP2<
S8`0DU9B06m_K`1`L700S8b<07QhN02g]kL0NGUi07QhN02l_;`0OGem0;:b/P2f][H0/[:b09RHV01C
De<0LW9b06UYJ@0`<300ATI605]KF`20P800JVYZ06IVIP1ZJVX0EUIF0410@01TI6@0Y:BT06e]K@1X
J6P0/[:b09>CT`;ooooo0000102WYjL0EeMG07EeM@2i^KT208N7Q`2A04M7A`1>CTh0QXJ6096AT@17
AdL0OWin0451@@12@T80KVi^08B4Q00j>SX0C4a<04U9B@12@T80KVi^06m_K`0S8b<0;bl_05]KF`1>
CTh0J6QX0;2`/00h>3P08R8R03dm?@1OGel0KVi^08Z:RP20P800<30`03Ti>@1?Cdl0MWIf075aL@2L
W9`0De=C024Q8@0m?Cd0MWIf0492@P1nOWh0[Jf]02h^;P0m?Cd0ADE50820P01ZJVX0Q8B40:>SX`0W
9bL0FUYJ08F5Q@2<S8`0LW9b0;Rh^01[Jf/07AdM03Xj>P1lO7`0TI6A0:NWY`2FUYH09BDU03Hf=P1P
H600Lg=c05mOG`2<S8`0F5QH03@d=00o?cl0OGem08V9R@1QHF40[Jf]07AdM00T92@0DE5A0;:b/P2;
Rh/0HF5Q0:n_[`16ATH0820P08:2PP2j^[X0IVIV05eMG@2a/K40;Bd]0410@01UIFD0YjNW05ADE01Y
JFT0Q8B402HV9P13@d<0J6QX0<S8b01DE5@0MWIf0410@00Z:RX0Jf][06i^KP2BTY80EEEE09NGU`0_
;bl0<c<c09BDU02c/k<0Fe]K051@D01jNWX0:b/[05EEE@2_[jl0UiNG03hn?P1PH600Jf][04e=C@1m
OGd0XJ6Q05QHF00e=CD0EeMG05]KF`1=CDd0IFEU06QXJ01UIFD0CTi>06IVIP1MGEd0EUIF08F5Q@2]
[Jd0EeMG04M7A`1SHf<0B4Q806YZJP0209VIV@0M04m?C`1^KVh0Ph>305iNGP2][Jd0WIfM055AD@1Q
HF40EeMG03hn?P2DU9@0Z:RX03lo?`16ATH0PX:207emO@15ADD0[:b/08j>SP0`<300D51@06YZJP2>
SXh0DU9B09bLW02k^k/0;Bd]04a<C01mOGd00P1NGUh0U036a/H0S8b<02d];@1CDe<0H61P09fMW@2H
V9P0bl_;09jNWP19BDT0N7Qh09VIV@1eMGD0cLg=0;Ng]`0e=CD0<30`07QhN02PX:00NWYj0<c<c01U
IFD0?Cdm05ADE02TY:@0[:b/09fMW@35aLD0ATI603lo?`1@D500[Zj^08b<S02VYZH0Ng]k02@T901A
DE40S8b<0:>SX`1lO7`0_;bl05UIF@0j>SX0NGUi09ZJVP2BTY80WIfM02d];@1DE5@0Shn?08F5Q@2N
WYh0WinO04e=C@0W9bL0G5aL0<g=c@1SHf<0/K6a055AD@17AdL0IfMW09NGU`1=CDd0GUiN07YjNP0R
8R80EUIF0;jn_P1nOWh0I6AT0820P00n?Sh0ATI604m?C`1VIVH0@T9207AdM021PH40Z:RX0:b/[02a
/K40Ph>30:JVYP3;bl/0MWIf03/k>`1@D500RHV906IVIP1BDU80P82003Xj>P0a<C40N7Qh0;Rh^01H
F5P0A4A4051@D01FEUH0@T9208R8R01kNg/0<S8b0451@@1RHV80>c/k05eMG@2i^KT0Hf=S02LW9`0`
<300KVi^05mOG`1VIVH0/k>c08B4Q00Y:BT0CTi>05EEE@1@D500<c<c09JFUP38b<P0;2`/01`L701U
IFD0L71`05YJFP2EUID0PX:202<S8`0];Bd0Bd];079bLP1LG5`0@41007MgM`1TI6@0CTi>07moO`2<
S8`0XZ:R051@D00a<C40:RXZ04i>CP19BDT204a<C005069RHP1`L700=3@d05ADE01YJFT00P24Q8@0
901TI6@0GemO03`l?01>CTh0?clo03hn?P0e=CD0CTi>03hn?P0k>c/0=3@d05]KF`16ATH0G5aL0451
@@19BDT0GemO04m?C`1>CTh0AdM7061PH01BDU80Fe]K0492@P10@400=SHf06][J`1_Kfl0EUIF05iN
GP1_Kfl0<c<c0820P01ZJVX0MgMg06=SH`80KVi^00h0=3@d04e=C@1^KVh0OGem08F5Q@1FEUH0Bd];
08b<S01CDe<0L71`05QHF014A4@0GEeM04Q8B080FUYJ03/0IVIV05MGE`2c/k<0D51@04];B`1cLg<0
MgMg07moO`1^KVh0KFe]07EeM@0j>SX0VIVI06YZJP18B4P0GUiN09ZJVP3Fe]H0][Jf05eMG@1eMGD0
FUYJ079bLP1`L700EEEE07=cL`15ADD0GUiN07IfMP1DE5@0FEUI06][J`1cLg<0H61P069RHP18B4P0
BTY:055AD@1CDe<0A4A406=SH`12@T80DE5A04];B`1CDe<0CDe=04m?C`1OGel0Kfm_04U9B@1EEED0
De=C06a/K01nOWh0L71`0492@P0j>SX0IFEU01dM7@0204Y:BP2004U9B@1UIFD0EeMG04A4A00e=CD0
C4a<02HV9P1_Kfl0Hf=S08V9R@23Ph<0MWIf07inOP0[:b/0ADE506][J`1XJ6P0SHf=0:ZZZP19BDT0
Jf][01/K6`1;Bd/0AdM703Lg=`13@d<0<30`04a<C00d=3@0IVIV03Xj>P23Ph<0HV9R04M7A`1MGEd0
?Shn055AD@0[:b/0AdM70410@00U9BD0GUiN055AD@0h>3P0KFe]059BDP0k>c/0CTi>04A4A01mOGd0
=3@d06EUI@0k>c/0D51@07IfMP0d=3@0>CTi04];B`1FEUH0ADE504];B`1YJFT0VYZJ08F5Q@1@D500
HF5Q06YZJP1oOgl0C4a<04U9B@1<C4`0Lg=c07EeM@1BDU80@d=304Y:BP0k>c/0AdM705EEE@18B4P0
];Bd04a<C01CDe<0EEEE0451@@1BDU80D51@07alO01ADE40DU9B06ATI01CDe<0FUYJ05QHF02XZ:P0
DU9B04M7A`1FEUH0AdM7061PH02FUYH0Jf][03lo?`11@D40D51@05eMG@1BDU80De=C06a/K01<C4`0
A4A404m?C`1<C4`0BTY:051@D01lO7`0EEEE02`/;01mOGd0DE5A05=CD`1_Kfl0E5AD07moO`1ZJVX0
Vi^K08:2PP1<C4`205]KF`0J069RHP1KFe/0N7Qh09FEU@1>CTh0EeMG05]KF`2BTY80O7al059BDP1E
EED0IfMW0:j^[P3Shn<0GemO03Hf=P1kNg/0C4a<06m_K`1fMWH0PX:209^KV`1mOGd0Ogmo08B4Q03P
h>0208R8R00H07alO01JFUX0O7al0:BTY03MgMd0TY:B03/k>`13@d<0LG5a05YJFP1^KVh0JFUY06QX
J01_Kfl0MGEe07MgM`1?Cdl0BTY:06a/K01CDe<0GUiN08:2PP1XJ6P0Ng]k0_ooool0000=09jNWP1m
OGd0EeMG06MWI`2KVi/0[:b/06YZJP18B4P0F5QH051@D01kNg/0_Kfm04=3@`0203lo?`80Hf=S0?T0
_Kfm07IfMP0d=3@0De=C06ATI01jNWX0JFUY07inOP0I6AT0<30`09JFUP37alL0NGUi0:f][@2?Shl0
9BDU04m?C`2SXj<0Q8B409RHV02c/k<07AdM05MGE`1bLW80OGem06UYJ@2;Rh/0MgMg02DU9@1FEUH0
Rh^;08N7Q`1FEUH0Ogmo0410@00N7Qh0C4a<05EEE@1>CTh0A4A407UiN@0_;bl0BTY:07]kN`2TY:@0
Cdm?05EEE@14A4@0<c<c055AD@1VIVH0N7Qh03@d=01OGel09bLW02d];@1jNWX0G5aL02d];@13@d<0
LW9b04A4A010@400/K6a08F5Q@0e=CD0>3Ph05QHF00c<c<0Fe]K0;Fe]@1OGel09bLW04U9B@1GEeL0
IVIV06QXJ03?cll0GEeM03Lg=`1>CTh0FUYJ04Y:BP1NGUh0UIFE03lo?`0^;Rh0AdM705MGE`2>SXh0
]kNg069RHP0N7Qh0=SHf0861P@1ADE40L71`0<W9b@1WIfL061PH03/k>`27QhL0HF5Q08Z:RP2XZ:P0
<C4a03hn?P1MGEd0Ph>306IVIP2ZZZX0PH6103@d=018B4P0M7Ad09BDU01oOgl0[Jf]071`L00n?Sh0
NWYj08f=S@1]KFd0Ogmo0:NWY`1lO7`0;Rh^05UIF@2i^KT0Shn?09VIV@2YZJT0<30`04=3@`1`L700
]kNg08:2PP2i^KT0U9BD0410@01FEUH0T92@08f=S@2e]KD0GemO03dm?@1IFET0NGUi0:ZZZP1kNg/0
a/K604E5A@0o?cl0PH610;Fe]@1jNWX0OGem08:2PP0T92@0@D5105=CD`2HV9P0JFUY06][J`2:RXX0
9BDU05=CD`1IFET0VYZJ04I6AP24Q8@0RHV902TY:@1WIfL0H61P092@T01WIfL0QHF507]kN`0S8b<0
QHF50>CTi02WYjL0IFEU08N7Q`19BDT0=cLg0820P031`L40H61P07EeM@20P800=CDe04i>CP1`L700
XJ6Q059BDP26QXH0@T9204];B`2k^k/0YZJV03`l?01HF5P0Rh^;04U9B@1UIFD0clo?07emO@14A4@0
T92@06EUI@1VIVH0^[Zj06i^KP13@d<0W9bL05eMG@27QhL0^KVi05YJFP0d=3@0DE5A08:2PP1JFUX0
_[jn08^;R`0U9BD0IfMW06ATI011@D40Q8B40;jn_P0c<c<0:b/[07inOP1HF5P0Ogmo0;Vi^@0e=CD0
F5QH0;6a/@2DU9@0ADE50820P02k^k/0W9bL09NGU`2h^;P00P2LW9`09@3IfMT0Rh^;03Xj>P1QHF40
J6QX04e=C@1NGUh0^k^k061PH00S8b<0BDU909nOW`1@D500HF5Q06a/K00_;bl0>SXj069RHP2^[Zh0
JVYZ08b<S020P800?Cdm03lo?`1LG5`0P82006m_K`22PX80QXJ604];B`11@D40MgMg09^KV`1>CTh0
PH6108:2PP0];Bd00P0c<c<01@2?Shl0QhN707EeM@2QXJ40>3Ph0080?clo04<0JVYZ05YJFP1XJ6P0
OWin02l_;`17AdL0ATI60861P@1>CTh0>SXj05aLG01>CTh0FEUI07YjNP1[Jf/08R8R055AD@1OGel0
KVi^06QXJ01hN7P0GEeM03De=@1PH600Ng]k06YZJP1DE5@0ADE505mOG`0m?Cd0De=C04A4A00o?cl0
@D51069RHP0/;2`0@41003hn?P1iNGT0E5AD07EeM@1@D500C4a<05EEE@1SHf<0HF5Q05MGE`1YJFT0
:b/[059BDP0m?Cd0?3`l03Lg=`1@D500Fe]K04a<C014A4@0EeMG02TY:@1@D500F5QH061PH01ZJVX0
KVi^05MGE`0f=SH0?clo0080ATI60380BDU905QHF01IFET0EUIF04Q8B01CDe<0BTY:0410@01LG5`0
GemO04a<C01:BTX0MgMg06MWI`25QHD0EEEE05QHF01aLG40S8b<079bLP15ADD0IFEU06a/K01VIVH0
VYZJ07inOP1_Kfl0OGem09:BTP2LW9`0QhN706IVIP1HF5P0AdM705]KF`1QHF40Bd];05ADE00g=cL0
G5aL03hn?P0k>c/0@d=307=cL`1<C4`0?Shn04E5A@1BDU80B4Q80410@080AdM705D0EUIF04=3@`10
@400Cdm?04i>CP14A4@0?Shn069RHP1_Kfl0G5aL05UIF@1<C4`0Ogmo07inOP1oOgl0EEEE05YJFP1/
K6`0<c<c04a<C01KFe/0De=C08F5Q@1MGEd0EEEE0492@P1UIFD0:BTY08b<S015ADD0M7Ad0:RXZ02Q
XJ40]kNg03<c<`1[Jf/0X:2P08f=S@2JVYX0Zj^[06i^KP1OGel06ATI069RHP1mOGd0B4Q805]KF`0P
8200K6a/02TY:@1;Bd/0<S8b07MgM`1OGel0@41005]KF`1GEeL0Jf][03dm?@1ADE40B4Q801TI6@1Z
JVX0FEUI02PX:027QhL0J6QX0451@@1UIFD0>3Ph03hn?P0i>CT0N7Qh04Y:BP1CDe<0D51@01`L700Q
8B40AdM705QHF00i>CT0LW9b04e=C@1GEeL0DE5A0080DU9B0200>c/k05aLG00h>3P0WYjN07UiN@17
AdL0G5aL0451@@1PH600KVi^03hn?P1MGEd0EeMG04M7A`29RHT0F5QH06i^KP1dM7@0J6QX0;Rh^01F
EUH0KFe]03De=@1RHV80R8R806IVIP1jNWX0>3Ph06YZJP1OGel0CTi>05iNGP80>3Ph0580Bd];04a<
C00n?Sh0De=C075aL@1SHf<0JVYZ04a<C01fMWH0EEEE03dm?@1PH600DU9B06ATI013@d<0Rh^;069R
HP16ATH0Rh^;05aLG017AdL0IVIV0410@02ZZZX0Jf][05QHF01=CDd0Hf=S06m_K`2>SXh0OGem075a
L@1VIVH0VYZJ059BDP1TI6@0DU9B07MgM`2b/[80Kfm_079bLP2KVi/0Kfm_05]KF`14A4@0B4Q807]k
N`1HF5P0RHV906=SH`0k>c/0Jf][07YjNP1`L700Bd];0:2PX02ATI40];Bd09JFUP1IFET0MWIf08Z:
RP26QXH0S8b<05ADE01QHF40GEeM03Ti>@1ADE40JFUY09VIV@1iNGT0ATI605=CD`1HF5P0IFEU0820
P02BTY80UiNG0820P02JVYX0UIFE0_ooool0000f075aL@2YZJT0Y:BT08N7Q`1EEED0NGUi08n?S`2>
SXh0^;Rh03Xj>P14A4@0QHF506i^KP1MGEd0Ogmo02DU9@0d=3@0Hf=S0:>SX`1OGel0JFUY03dm?@1:
BTX0Rh^;09>CT`1HF5P0?Cdm04];B`0n?Sh0;Rh^07EeM@2RXZ80@41003De=@0o?cl0ATI60:>SX`2U
YJD0A4A403De=@1LG5`0?Shn030`<02HV9P0aLG503Ph>00g=cL0J6QX051@D01PH600f=SH0:^[Z`0M
7Ad0=CDe0P1FEUH0SP1dM7@0bl_;05MGE`0K6a/0DU9B09ZJVP1hN7P0U9BD05IFEP0a<C40@T9205eM
G@1hN7P0Fe]K0<71`@16ATH04A4A061PH02>SXh0QXJ609FEU@2m_Kd0ADE501/K6`1UIFD0X:2P075a
L@2;Rh/0Y:BT03lo?`0_;bl0Q8B40:BTY01/K6`0Zj^[07MgM`0g=cL0@d=3069RHP1[Jf/0PH610;jn
_P1[Jf/0<30`0410@01lO7`0QHF504e=C@2JVYX0B4Q802d];@1[Jf/0Q8B405]KF`1FEUH0WinO04=3
@`0[:b/0Kfm_0:f][@1QHF40QXJ607AdM016ATH0BDU90:FUY@1aLG40CDe=09fMW@14A4@0:BTY08B4
Q02VYZH0CDe=05]KF`1bLW80=cLg06MWI`2@T900YjNW04I6AP1EEED0K6a/04M7A`1JFUX0/;2`0;Vi
^@2>SXh0Kfm_07EeM@0l?3`0HV9R0<k>cP2NWYh0@T9208B4Q01NGUh0@T9209^KV`2RXZ80GUiN04M7
A`1[Jf/0F5QH09BDU025QHD0>c/k04a<C01RHV80FEUI08B4Q030`<00XZ:R04=3@`12@T80KFe]06MW
I`2=SHd0a<C404Y:BP0[:b/0IfMW04Y:BP0m?Cd0VYZJ0;Fe]@0j>SX0<C4a07=cL`1hN7P0HF5Q09^K
V`3?cll0AdM703Xj>P27QhL0Lg=c069RHP2YZJT0]kNg02HV9P0o?cl20:FUY@0T09>CT`2f][H0A4A4
03Ti>@1<C4`0VIVI06IVIP2UYJD0RXZ:028R8P16ATH0EEEE07alO01hN7P0d];B06i^KP0/;2`0MWIf
0:^[Z`1QHF40NWYj0:b/[00/;2`0ADE509nOW`31`L40L71`0;fm_@1;Bd/0FUYJ06UYJ@2b/[80O7al
0<c<c00g=cL0A4A40P3;bl/0H`1/K6`0a/K607moO`1ADE40Cdm?09bLW01DE5@0Y:BT05eMG@0n?Sh0
O7al0:VYZ@1iNGT0HV9R075aL@0[:b/0=cLg08V9R@26QXH0I6AT0<S8b01;Bd/0?Cdm02PX:00j>SX0
FEUI06m_K`1GEeL0HV9R08^;R`27QhL0RHV903/k>`1XJ6P0QhN702h^;P1dM7@0QhN707MgM`13@d<0
O7al09^KV`17AdL0HF5Q0;Bd]01UIFD0=cLg05QHF019BDT0Cdm?0820P033`l<0H61P03`l?01JFUX0
@41004M7A`1]KFd0ZJVY08f=S@13@d<0DE5A04Y:BP19BDT0EEEE07moO`0_;bl08b<S04Q8B01?Cdl0
DE5A051@D02QXJ40J6QX02h^;P1OGel0EeMG05IFEP1RHV80Vi^K04i>CP19BDT0@T920820P01NGUh0
E5AD06m_K`1eMGD0QHF506IVIP13@d<07QhN04U9B@1>CTh0D51@04=3@`1FEUH0E5AD03Xj>P0205mO
G`3o07AdM01UIFD0De=C05YJFP0f=SH0BDU90451@@1CDe<0ADE505]KF`0^;Rh0De=C03/k>`1TI6@0
GEeM05YJFP19BDT0De=C05]KF`1gMgL0QHF507UiN@1YJFT0;Rh^05iNGP1;Bd/0<c<c04M7A`1TI6@0
MWIf059BDP1EEED0O7al03Lg=`1]KFd0EeMG06ATI018B4P0C4a<05EEE@0W9bL0?clo05EEE@1RHV80
KVi^04e=C@0e=CD0J6QX05=CD`1JFUX0DU9B03lo?`1CDe<0DE5A05ADE01=CDd0Cdm?05MGE`2;Rh/0
?Cdm03/k>`2CTi<0];Bd0:NWY`1[Jf/0DE5A05mOG`1TI6@0MgMg06YZJP0m?Cd0K6a/0:f][@3De=@0
[:b/04U9B@1YJFT0EeMG05eMG@1IFET0EEEE061PH00j>SX0FUYJ04Q8B00j>SX0>c/k05=CD`1<C4`0
B4Q80492@P0g=cL0BDU903/k>`1EEED0@T9204a<C00`<300?Shn04E5A@0e=CD0BTY:03hn?P1OGel0
HF5Q03/k>`1BDU80CDe=055AD@1OGel0Kfm_05IFEP1NGUh0P82003<c<`1RHV80FUYJ04i>CP1fMWH0
MGEe05aLG012@T80EUIF02TY:@1lO7`0EeMG06MWI`2BTY80Ng]k07inOP0S8b<0CDe=0:RXZ01TI6@0
UIFE0<C4a01MGEd0RHV905aLG01SHf<0C4a<055AD@1PH600@D51059BDP0m?Cd0EUIF04Y:BP26QXH0
NGUi04a<C01MGEd0CTi>05iNGP10@400C4a<055AD@0i>CT0Jf][075aL@1JFUX0SXj>06i^KP1;Bd/0
@D5105IFEP1jNWX0De=C08N7Q`1@D500De=C05]KF`0i>CT0ATI6065QH@1MGEd0JFUY0:2PX01iNGT0
RXZ:06=SH`1XJ6P0NGUi0492@P1ADE40:b/[04e=C@1FEUH0F5QH06QXJ01IFET0?Cdm04U9B@11@D40
V9RH051@D00X:2P0RHV905=CD`2;Rh/0NGUi05ADE01IFET0F5QH08>3P`0f=SH0ADE5061PH01mOGd0
]kNg05]KF`1dM7@0CDe=06=SH`2:RXX0ADE504=3@`1PH600Fe]K05UIF@1ZJVX0ADE506MWI`29RHT0
G5aL06m_K`1YJFT0C4a<06IVIP1QHF40IfMW05ADE01eMGD0IfMW05EEE@2QXJ40HF5Q04];B`1_Kfl0
GEeM08>3P`1GEeL0MgMg06e]K@20P800QhN705ADE01QHF40LG5a06=SH`1nOWh0Fe]K09FEU@1bLW80
N7Qh000O0:NWY`2LW9`0WinO0;Bd]02SXj<0^KVi04m?C`0`<300SXj>051@D01OGel0IFEU04m?C`1d
M7@0Ti>C07inOP1TI6@0YJFU06a/K029RHT0];Bd069RHP2CTi<0WIfM0<30`02?Shl0@d=3075aL@1Z
JVX0@d=305=CD`02069RHP80MGEe00T0GUiN04Q8B014A4@0Lg=c09NGU`2a/K40TI6A0:JVYP2=SHd0
0_ooool0003D06i^KP1OGel0MgMg0:FUY@1=CDd0FUYJ04];B`1CDe<0[jn_04Y:BP0m?Cd0EeMG069R
HP2KVi/0eMGE05=CD`0/;2`0C4a<07=cL`1_Kfl0ZZZZ03Lg=`0Z:RX0@T9209jNWP23Ph<0Fe]K07If
MP0a<C40AdM703lo?`2[Zj/0X:2P0;:b/P25QHD05QHF04I6AP1UIFD0MWIf06YZJP2PX:00>3Ph03Lg
=`0d=3@0Lg=c05mOG`1^KVh0MWIf020P800e=CD0B4Q8092@T01MGEd0IFEU05eMG@0N7Qh0BTY:07Ad
M01hN7P0K6a/08F5Q@0j>SX0<30`05EEE@2:RXX0EUIF05YJFP1dM7@0?3`l03Ti>@1YJFT0XJ6Q04M7
A`1/K6`0GemO02PX:01>CTh0Cdm?07emO@0o?cl0J6QX05aLG00T92@0EeMG0:6QX@1IFET0ADE505eM
G@15ADD0<c<c06e]K@2UYJD0@D51051@D01UIFD0;2`/03/k>`1YJFT0[Zj^04E5A@13@d<0FEUI05=C
D`1MGEd0L71`09:BTP0j>SX0@T9207AdM014A4@0DU9B09VIV@1WIfL0@41005=CD`1^KVh0AdM707Mg
M`25QHD0=CDe03/k>`1NGUh0@D51061PH02YZJT0HV9R02/[:`1@D500OGem04Y:BP2JVYX0Ti>C03Xj
>P0n?Sh0C4a<096AT@1VIVH0PX:20:6QX@0l?3`0@D5105UIF@2:RXX0ZJVY0;:b/P2d];@0>c/k03Ph
>01hN7P0WIfM07moO`3:b/X0Kfm_03`l?01HF5P0UYJF07emO@2BTY80^k^k03De=@2?Shl0[Zj^06a/
K02i^KT0XJ6Q04U9B@1CDe<0RHV90=CDe01UIFD0VYZJ07QhN013@d<0M7Ad0;Vi^@2SXj<0EEEE0=?C
d`1]KFd0:2PX061PH035aLD0Rh^;06QXJ02^[Zh0KFe]0492@P26QXH0a/K60<30`01YJFT0c/k>04e=
C@1GEeL0OGem0=7Ad@1oOgl0OWin08:2PP12@T80Ti>C0<O7a`2j^[X0Hf=S07UiN@1@D500Bd];09BD
U03=cLd0MgMg059BDP2][Jd204a<C03a0;bl_02^[Zh0F5QH07inOP1hN7P0D51@08n?S`38b<P0QHF5
05]KF`1`L700@d=304i>CP2RXZ80O7al04Q8B01iNGT0DU9B07IfMP38b<P0RXZ:03/k>`1eMGD0D51@
06IVIP2i^KT0Ti>C04E5A@1hN7P0JFUY04m?C`36a/H0][Jf02/[:`1CDe<0ZJVY06][J`27QhL0UYJF
02<S8`0a<C40GUiN04m?C`1TI6@0[Zj^06YZJP0M7Ad07alO02<S8`0e=CD0<c<c03Ti>@0n?Sh0<C4a
06i^KP2KVi/0J6QX08R8R02n_[h0?3`l04E5A@2HV9P0];Bd05ADE02TY:@0aLG505MGE`1>CTh0OGem
07UiN@1GEeL0S8b<03Ti>@1;Bd/0D51@08N7Q`23Ph<0IFEU0;Zj^P17AdL0;Rh^05aLG01=CDd0NWYj
05aLG02`/;00ATI602TY:@1EEED0Kfm_065QH@1DE5@0T92@06m_K`0S8b<0?clo051@D01WIfL0E5AD
07QhN01NGUh09bLW04m?C`2LW9`0NGUi04I6AP15ADD0OGem059BDP1OGel0MWIf04i>CP1CDe<0Jf][
055AD@0/;2`0Kfm_06UYJ@1JFUX0C4a<07YjNP28R8P0LG5a05YJFP1VIVH0QhN707MgM`1HF5P0Lg=c
05=CD`1LG5`0FEUI04a<C01ADE40NWYj051@D010@400?clo0451@@1:BTX0FEUI04Q8B01>CTh0GemO
07AdM01]KFd0EEEE079bLP0X:2P0GEeM03<c<`0X:2P0>CTi04];B`1?Cdl0Bd];04m?C`1GEeL09BDU
06i^KP1UIFD0Vi^K05ADE01NGUh0Ti>C02/[:`19BDT0MWIf0492@P1HF5P0BTY:03`l?01JFUX0@d=3
05]KF`1BDU80>SXj05UIF@1WIfL0CDe=04I6AP23Ph<0RHV90;Vi^@1EEED0BTY:06QXJ01lO7`0ZJVY
07MgM`27QhL0OGem05UIF@1RHV80Jf][08V9R@1lO7`0WinO0?Cdm02XZ:P0C4a<07MgM`1dM7@0KFe]
06UYJ@1FEUH0M7Ad03Ti>@1OGel0Jf][059BDP1>CTh0L71`075aL@1GEeL0FUYJ03Lg=`1=CDd0EEEE
079bLP1=CDd0Fe]K04e=C@1EEED0@d=303Ph>01BDU80AdM7061PH01YJFT0De=C06EUI@1?Cdl0Hf=S
07IfMP1jNWX0Fe]K04a<C01mOGd0>3Ph0451@@0204a<C00L06MWI`16ATH0CDe=04U9B@1PH6005ADE
07EeM@14A4@0De=C06][J`1gMgL0UiNG04m?C`1LG5`0XZ:R04];B`1gMgL0Lg=c075aL@2@T900JFUY
092@T01HF5P0J6QX07EeM@0^;Rh0EUIF05MGE`80FEUI05h0V9RH0820P01hN7P0UIFE06e]K@1_Kfl0
IfMW09jNWP21PH40Bd];09FEU@20P800>SXj0;6a/@2EUID0<c<c05EEE@0g=cL0PX:205ADE01oOgl0
FUYJ05]KF`1WIfL0G5aL03lo?`11@D40Cdm?04M7A`0o?cl0IVIV0:RXZ020P800?Cdm05IFEP1LG5`0
PH6104i>CP25QHD0OGem07inOP1iNGT0De=C04M7A`1?Cdl0=CDe04m?C`1DE5@0=3@d08J6QP15ADD0
Jf][075aL@0c<c<0EUIF04m?C`1jNWX0BDU906EUI@1JFUX0GEeM07emO@15ADD0SHf=03<c<`18B4P0
DE5A04e=C@0n?Sh0L71`06=SH`1LG5`0J6QX05ADE01YJFT0LW9b06e]K@1ZJVX0MWIf06IVIP1MGEd0
PX:20:2PX01TI6@0R8R805iNGP1PH600RHV905IFEP1?Cdl0Q8B406a/K02SXj<0IFEU0P2@T900=`1P
H600IfMW09>CT`1dM7@0G5aL06YZJP29RHT0FUYJ075aL@1LG5`0TY:B09fMW@1OGel0GUiN08f=S@2Q
XJ40`L7103hn?P0a<C40X:2P0410@01VIVH0H61P075aL@2KVi/0P82008Z:RP2@T900b<S809>CT`2b
/[80TY:B065QH@2VYZH0VIVI0<71`@2c/k<0CTi>05iNGP21PH40BDU905eMG@1hN7P0SXj>0861P@1c
Lg<0QXJ605mOG`1@D500T92@0;Ng]`2:RXX0TY:B0<O7a`2KVi/00_ooool0000@0<[:bP1WIfL0Hf=S
0;Ng]`24Q8@0WinO04];B`1@D500M7Ad08Z:RP2HV9P0[Zj^03Hf=P0c<c<0KVi^0:b/[080SHf=03L0
CTi>0451@@14A4@0MWIf03De=@1QHF40I6AT04];B`0a<C40NWYj06QXJ00i>CT0KFe]038b<P0n?Sh0
Fe]K09RHV01<C4`0=3@d055AD@11@D40Cdm?09:BTP2;Rh/0<c<c05iNGP15ADD0B4Q8069RHP2FUYH0
E5AD03@d=01NGUh0Bd];05]KF`28R8P0_;bl03dm?@0/;2`0O7al06][J`1SHf<0];Bd07UiN@0a<C40
>SXj051@D01NGUh0NGUi07EeM@0/;2`0>CTi0451@@1hN7P0FEUI0080OGem00L0:2PX03@d=00c<c<0
R8R809^KV`2[Zj/0TI6A0080>CTi06T0C4a<069RHP22PX80UYJF03lo?`0U9BD0BTY:05aLG01HF5P0
PH610<o?c`0`<300<S8b0410@01RHV80H61P0:JVYP2?Shl092@T04e=C@19BDT0Q8B407=cL`2DU9@0
QhN702HV9P1@D500LW9b05MGE`1;Bd/0QXJ603Hf=P0a<C40Hf=S08b<S01SHf<0PX:207inOP1;Bd/0
@T9207MgM`2_[jl0Hf=S0:>SX`1gMgL0<C4a0451@@1mOGd0M7Ad05EEE@1nOWh0Ogmo04=3@`1BDU80
Hf=S079bLP1MGEd0PX:204M7A`12@T80FEUI08V9R@21PH40Jf][0:6QX@18B4P0@D510:RXZ03=cLd0
I6AT071`L02KVi/0Bd];05EEE@31`L40T92@07EeM@1LG5`0BDU905aLG02DU9@0Hf=S05MGE`1oOgl0
D51@05UIF@1WIfL0OWin0492@P1QHF40KFe]04];B`1:BTX0`L710:6QX@0j>SX0@41006IVIP13@d<0
LW9b0:FUY@1VIVH08b<S04Y:BP1EEED00P1IFET0P02k^k/0Kfm_0410@01CDe<0J6QX07alO02WYjL0
]kNg03lo?`0a<C40O7al08^;R`2SXj<0bl_;07]kN`0Y:BT0>CTi08V9R@1ZJVX0S8b<0>GUi@22PX80
;Bd]04a<C02LW9`0I6AT0=SHf02LW9`0:RXZ06i^KP1lO7`0LW9b09VIV@3Ng]h0F5QH02TY:@1jNWX0
^[Zj08J6QP2MWId0?clo03dm?@2=SHd0YZJV07UiN@2WYjL0@D51055AD@1]KFd0`L7108F5Q@2LW9`0
Jf][02`/;01QHF40][Jf071`L02HV9P0UIFE030`<012@T80[Jf]08n?S`1OGel0T92@02/[:`0m?Cd0
I6AT08N7Q`1=CDd0IfMW09VIV@3]kNd0d];B0:n_[`1IFET0IFEU0:6QX@1IFET0?Shn05mOG`1ZJVX0
CTi>05ADE02XZ:P0Hf=S04A4A01MGEd0L71`05mOG`1BDU80]KFe03lo?`0f=SH0JVYZ06e]K@0l?3`0
H61P09BDU01LG5`0CTi>06UYJ@1RHV80<c<c04e=C@21PH40B4Q8059BDP2EUID0_;bl03Xj>P1DE5@0
F5QH03lo?`18B4P0QhN70:j^[P1DE5@0?3`l08N7Q`0j>SX0CTi>06][J`1VIVH0>3Ph04Q8B01jNWX0
EUIF0P15ADD0o`2/[:`0LG5a05UIF@1iNGT0EeMG05iNGP26QXH0P82005QHF01;Bd/0Fe]K05QHF018
B4P0J6QX051@D00n?Sh0GemO071`L01/K6`0L71`07QhN01RHV80?Shn05EEE@1ADE40@T9204M7A`1^
KVh0?Cdm03Xj>P0_;bl0LW9b051@D01ZJVX0BDU906UYJ@1PH600Lg=c05eMG@1DE5@0Hf=S03dm?@1<
C4`0<S8b02`/;00^;Rh0D51@05YJFP13@d<0<C4a05UIF@0X:2P0A4A405EEE@1TI6@0EEEE05MGE`1[
Jf/0ATI605QHF01LG5`0BTY:05eMG@1HF5P0DE5A05=CD`14A4@0Fe]K069RHP1NGUh0Kfm_05YJFP20
P800EUIF05MGE`1JFUX0QXJ6061PH01HF5P0Ogmo0:2PX01mOGd0F5QH06UYJ@1iNGT0IVIV08F5Q@1m
OGd0?Shn05QHF01^KVh0XZ:R07inOP1[Jf/0Fe]K051@D01XJ6P0IfMW051@D01BDU80>SXj06YZJP0h
>3P0@T9203hn?P1oOgl0Cdm?03/k>`0o?cl0EEEE05MGE`0m?Cd0EUIF059BDP1EEED0>CTi04=3@`1B
DU80BDU903/k>`1?Cdl0PX:206ATI00k>c/0BDU904M7A`1OGel0Hf=S05eMG@1QHF40:b/[0;2`/019
BDT0J6QX069RHP0l?3`0JFUY05mOG`1>CTh0ADE505mOG`0];Bd0Ti>C04=3@`21PH40M7Ad04m?C`2[
Zj/071`L04E5A@1fMWH0BDU906m_K`26QXH0@d=305MGE`1<C4`0IFEU05IFEP2@T900TY:B05eMG@1:
BTX0CTi>07UiN@1EEED0ZZZZ06YZJP1ADE40K6a/06EUI@1SHf<0@D5104=3@`1;Bd/0;Bd]07]kN`1O
Gel0?clo08>3P`1aLG40EEEE06m_K`1FEUH0W9bL03Lg=`2:RXX0IfMW03Ph>01UIFD0A4A402HV9P1:
BTX0GemO04I6AP1VIVH0JFUY07MgM`1TI6@0Bd];04m?C`0n?Sh0Hf=S04=3@`1lO7`0HV9R04Y:BP1V
IVH0@41006EUI@1ZJVX09BDU092@T01BDU80?3`l07emO@1CDe<0P82008^;R`1OGel0Q8B404i>CP1R
HV80>c/k07UiN@1jNWX0LG5a08J6QP1<C4`0NGUi04Y:BP1=CDd0I6AT04I6AP1RHV80Ph>307MgM`1C
De<0GemO055AD@1_Kfl0OWin05UIF@1^KVh0Jf][065QH@1LG5`0FUYJ06UYJ@1BDU80SHf=03Ph>00e
=CD0VIVI03Lg=`00?P1;Bd/0RXZ:04Y:BP2SXj<0IVIV0861P@1RHV80HF5Q06e]K@1CDe<0JFUY07Ad
M01hN7P0XJ6Q06EUI@28R8P0Hf=S06YZJP1oOgl0JFUY07AdM02[Zj/0fm_K0>o_k`1FEUH0:RXZ0:6Q
X@1KFe/0Kfm_06][J`19BDT0LG5a08N7Q`1lO7`0U9BD0=WIf@23Ph<0Q8B408n?S`1]KFd0UIFE0:6Q
X@2i^KT0]kNg05IFEP1SHf<0H61P06ATI01gMgL0G5aL09BDU01nOWh0Fe]K05=CD`1aLG40IFEU05iN
GP1mOGd0MWIf08R8R02HV9P0XJ6Q0_ooool0003o0861P@2EUID0EeMG05EEE@1?Cdl0XZ:R07QhN017
AdL0Cdm?04Q8B01=CDd0SXj>04Y:BP0];Bd0AdM703Ph>01@D500S8b<07IfMP0b<S80AdM704A4A01Z
JVX0RHV90:^[Z`0h>3P0ADE503lo?`1TI6@0M7Ad0<71`@1QHF40:b/[03Lg=`1UIFD0MWIf0:>SX`2U
YJD07alO05IFEP1PH600J6QX06=SH`2a/K40SHf=020P801JFUX0J6QX05eMG@1/K6`0][Jf02XZ:P14
A4@0BTY:06YZJP1nOWh0RHV90820P00V9RH0<c<c0492@P24Q8@0PH6109NGU`0Z:RX07alO04e=C@1D
E5@0M7Ad07EeM@35aLD05aLG02PX:01ZJVX0PX:206e]K@1hN7P0[Jf]01dM7@1=CDd0KFe]08V9R@22
PX80OWin09VIV@0Z:RX0HF5Q0:VYZ@2;Rh/0F5QH06UYJ@1gMgL0;Bd]04=3@`2i^KT0VYZJ06=SH`1Z
JVX0>CTi038b<P1IFET0]KFe079bLP0b<S80KVi^03/k>`0n?Sh0FEUI08N7Q`15ADD0>SXj065QH@10
@400FEUI06MWI`1QHF40;2`/04=3@`18B4P0>SXj06UYJ@2>SXh0B4Q8030`<01:BTX0@d=305eMG@1^
KVh0Shn?03Ph>00m?Cd0D51@04Q8B01EEED0[Zj^0:^[Z`0a<C40CDe=04a<C01PH600I6AT0<C4a02K
Vi/0;Bd]04];B`1RHV80Kfm_08J6QP3=cLd0E5AD0492@P1=CDd0RHV907moO`2IVIT0^;Rh0451@@0m
?Cd0LG5a0:2PX03:b/X0Shn?034a<@1LG5`0R8R806MWI`1dM7@0emOG07emO@0`<300T92@0:ZZZP1<
C4`0NGUi08f=S@0f=SH0:b/[07moO`3<c<`0PX:209JFUP25QHD0<S8b030`<02CTi<0hN7Q06][J`2M
WId0QXJ603hn?P1@D500Ph>30:n_[`2FUYH0[Jf]04i>CP0g=cL0MgMg0<c<c02FUYH0IfMW08Z:RP0i
>CT0@D5108b<S03IfMT0LG5a07]kN`1[Jf/0C4a<05QHF02>SXh0][Jf06][J`26QXH0D51@04M7A`2j
^[X0b/[:06UYJ@2RXZ80KFe]03Lg=`1TI6@0d=3@0>3Ph01eMGD0P82002l_;`1MGEd0VYZJ07YjNP12
@T80N7Qh05YJFP1bLW80bLW905iNGP12@T80QXJ604Y:BP1`L700[Jf]09RHV011@D40BTY:05UIF@10
@400KVi^0;Vi^@1<C4`0?3`l069RHP1DE5@0TI6A000a0:JVYP0];Bd0>c/k05iNGP1QHF40DE5A0:6Q
X@2/[:`0[jn_0>SXj03YjNT0^KVi09ZJVP2[Zj/0DE5A03Xj>P1ZJVX0QhN7051@D026QXH0^k^k07If
MP1=CDd0J6QX08j>SP1UIFD0P8200>7Qh@1[Jf/0:RXZ05]KF`2?Shl0A4A408F5Q@22PX80?clo0492
@P1cLg<0JVYZ055AD@20P800a/K604];B`0c<c<0QXJ60;Bd]01WIfL0ZJVY07UiN@0202h^;P1305IF
EP1KFe/0GUiN0861P@3MgMd0E5AD03Hf=P20P800QHF504=3@`1/K6`0NWYj051@D01>CTh0H61P06EU
I@19BDT0?Cdm06MWI`1PH600K6a/08J6QP1@D5009BDU05aLG01NGUh0JVYZ065QH@1lO7`0QhN705AD
E01=CDd0CTi>061PH01WIfL0CDe=04a<C00e=CD0Cdm?0492@P1FEUH0CTi>06][J`13@d<0DE5A03lo
?`1XJ6P0H61P06EUI@1<C4`0J6QX079bLP27QhL0O7al05eMG@1eMGD0<S8b05UIF@0d=3@0:b/[0492
@P1QHF40IVIV04e=C@1ADE40LW9b03Hf=P0205YJFP0Z08^;R`1RHV80IfMW06a/K00U9BD0@T9206YZ
JP13@d<0IFEU05ADE00m?Cd0HV9R03Xj>P1KFe/0@d=3034a<@1CDe<0E5AD05UIF@17AdL0BDU906AT
I01iNGT0DU9B04I6AP1NGUh0PH610;Rh^01WIfL0K6a/07emO@1aLG40T92@08F5Q@17AdL0P8200:JV
YP37alL0Ti>C04A4A01BDU80Bd];0P1?Cdl0201<C4`0DE5A02d];@18B4P0@D5104I6AP0f=SH0BDU9
0P1?Cdl0I@13@d<0<S8b0492@P13@d<0GUiN04I6AP1<C4`0>c/k03dm?@0o?cl0=SHf04Y:BP0l?3`0
E5AD05IFEP0o?cl0Cdm?04a<C01aLG40GEeM06YZJP1SHf<08b<S09NGU`0h>3P0@d=305YJFP0_;bl0
GUiN07MgM`1JFUX0?Shn0410@00Q8B40MgMg03dm?@2NWYh0NWYj04a<C02c/k<0:BTY04m?C`2LW9`0
CDe=08B4Q01mOGd0JFUY08V9R@0o?cl0LW9b06][J`11@D40Fe]K03Ti>@1DE5@0=CDe04a<C011@D40
RHV904i>CP1KFe/0Ogmo05mOG`1]KFd0A4A405UIF@1BDU80;2`/07alO01[Jf/0BDU908N7Q`1_Kfl0
<C4a051@D00k>c/0E5AD065QH@2OWil0JFUY05UIF@2IVIT0=cLg02TY:@1:BTX0EUIF03Ti>@2NWYh0
MGEe08N7Q`1GEeL0C4a<05IFEP0d=3@0Ogmo02LW9`2VYZH0L71`08:2PP2>SXh0@d=30080C4a<06X0
?3`l05EEE@0Z:RX0:BTY06YZJP1ADE40Rh^;075aL@19BDT0FEUI04e=C@1[Jf/0=SHf04a<C01SHf<0
LG5a07IfMP1:BTX0IfMW0492@P1YJFT0Shn?05EEE@0k>c/0Ogmo04e=C@1>CTh0I6AT06QXJ01bLW80
UiNG08F5Q@2QXJ40MGEe06e]K@1eMGD0Q8B409ZJVP1aLG40][Jf0410@016ATH0XJ6Q03`l?01YJFT0
PH6105ADE02DU9@0B4Q806a/K01aLG40L71`08V9R@1]KFd0Q8B40861P@23Ph<0SXj>07QhN02ZZZX0
IVIV07=cL`2/[:`0N7Qh06m_K`29RHT0S8b<0:FUY@1<C4`0CTi>0:2PX02BTY80/;2`08B4Q01UIFD0
SHf=0:FUY@2CTi<0QHF50<g=c@2ATI40RHV90<30`01fMWH0UYJF09RHV034a<@0b<S805UIF@2@T900
JVYZ03lo?`1>CTh0@d=3051@D01QHF40Kfm_071`L011@D40?Shn06i^KP2NWYh0O7al07AdM03Jf]X0
ZJVY0_ooool0000E06UYJ@2QXJ40[Zj^06][J`1:BTX0EEEE07EeM@2ATI40SHf=02@T9012@T80D51@
05YJFP21PH40Xj>S01dM7@0o?cl0AdM708n?S`23Ph<0Rh^;0080?3`l02H0IFEU0:NWY`2HV9P0Bd];
05mOG`0F5QH0?Shn05]KF`2/[:`0HV9R04M7A`1ADE40<S8b05ADE01ZJVX0GEeM055AD@1PH600:2PX
04E5A@1XJ6P0VIVI03Hf=P0g=cL0CDe=0492@P19BDT0YZJV0:BTY00j>SX0EeMG05aLG00f=SH0EUIF
09^KV`1MGEd0:2PX04Y:BP80CTi>0>@0T92@09FEU@0Z:RX0<30`04A4A00b<S80H61P0:n_[`1<C4`0
61PH04];B`1eMGD0O7al07QhN035aLD0@d=301`L701KFe/0O7al071`L029RHT0`L7102h^;P0J6QX0
BTY:08f=S@1/K6`0XZ:R08B4Q00b<S80?Cdm05ADE01`L700UiNG0;:b/P16ATH0?Cdm05MGE`1]KFd0
P82006=SH`34a<@0TI6A02HV9P1JFUX0E5AD05UIF@24Q8@0_;bl02h^;P0l?3`0QXJ609NGU`1FEUH0
XJ6Q08F5Q@0^;Rh0B4Q80820P02IVIT0Q8B40<_;b`1<C4`0>3Ph065QH@2@T900K6a/07YjNP21PH40
ADE504=3@`1BDU80[jn_05EEE@2MWId0RXZ:03dm?@1KFe/0MWIf0;>c/`1_Kfl0Ti>C08F5Q@16ATH0
D51@07YjNP2_[jl0MgMg09FEU@10@400CDe=04U9B@2NWYh0T92@05mOG`1aLG40Bd];06UYJ@2i^KT0
OGem08f=S@2QXJ40BDU90410@01EEED0c/k>08Z:RP1aLG40P82003Ti>@1@D500Xj>S07emO@1FEUH0
N7Qh07MgM`1@D500JVYZ0<71`@1JFUX0BDU905ADE01LG5`0Cdm?09FEU@3Hf=P0HF5Q04U9B@1QHF40
OWin07AdM02`/;00X:2P02d];@1DE5@0Hf=S07AdM01bLW80_;bl06m_K`0a<C40CDe=07]kN`1fMWH0
T92@09RHV00Y:BT0>CTi08N7Q`1_Kfl0MGEe0<S8b027QhL092@T069RHP2e]KD0Fe]K0;Ng]`2[Zj/0
:RXZ02h^;P1RHV80Q8B407IfMP2YZJT0:BTY03lo?`1cLg<0OWin07QhN02UYJD0?Shn04I6AP2RXZ80
P820055AD@3>c/h0De=C0492@P1mOGd0^[Zj05IFEP21PH40Hf=S02l_;`1IFET0VIVI09BDU01oOgl0
QhN70492@P1@D500KVi^069RHP1aLG40VYZJ02PX:014A4@0@d=304m?C`0o?cl0H61P06ATI01?Cdl0
L71`09FEU@2_[jl0EUIF065QH@1jNWX0@d=305=CD`1bLW80O7al09VIV@2VYZH0Shn?05EEE@1ZJVX0
Rh^;09nOW`1<C4`0Hf=S04Q8B017AdL0F5QH08j>SP21PH4206][J`0o030`<00h>3P0BTY:08:2PP27
QhL0?Cdm06UYJ@18B4P0;bl_06QXJ01]KFd0ATI603Ti>@15ADD0Kfm_02l_;`0l?3`0Xj>S09RHV011
@D40EeMG06QXJ00b<S80ATI60:>SX`1UIFD0DE5A05iNGP23Ph<0GUiN04];B`1iNGT0EEEE05]KF`2A
TI40I6AT030`<01DE5@0Cdm?05=CD`15ADD0OWin07IfMP1bLW80M7Ad059BDP1YJFT0Hf=S04U9B@1?
Cdl0?clo05IFEP0h>3P0ATI604M7A`1XJ6P0?clo03hn?P0o?cl0G5aL06ATI01ZJVX0BDU90080FEUI
00X0Fe]K04e=C@1@D500EeMG04E5A@1DE5@0?3`l038b<P0`<300BDU90P1>CTh0F@1BDU80Hf=S02DU
9@1QHF40JVYZ06a/K017AdL0De=C07=cL`0j>SX0DU9B061PH018B4P0FEUI05=CD`17AdL0L71`0410
@01]KFd0FEUI03lo?`1XJ6P0DE5A07UiN@1HF5P0HV9R06=SH`2c/k<0Cdm?04];B`1hN7P0RHV90:j^
[P25QHD0K6a/09RHV018B4P0IVIV07emO@18B4P0NGUi0:BTY03Ng]h0_Kfm05UIF@1fMWH0De=C0820
P01^KVh0CTi>06a/K016ATH0JFUY075aL@1>CTh0CDe=07UiN@1^KVh0De=C05]KF`18B4P0E5AD051@
D01ZJVX0CDe=065QH@18B4P0F5QH059BDP11@D40C4a<03lo?`1_Kfl0LG5a0492@P1ADE40CDe=06IV
IP1XJ6P0JFUY059BDP0G5aL0I6AT03Lg=`17AdL0G5aL05=CD`1`L700CTi>0080EUIF06L0Cdm?02PX
:01fMWH0<30`09RHV01^KVh0<30`0;Vi^@0e=CD0@d=307moO`0j>SX0Shn?07YjNP1KFe/0FEUI03<c
<`18B4P0BTY:05QHF028R8P0>3Ph05ADE011@D40L71`03dm?@1jNWX0?Shn0451@@1LG5`0FEUI06QX
J01BDU80LW9b07AdM01;Bd/0Q8B407=cL`1NGUh0b/[:09NGU`19BDT0EeMG05iNGP22PX80Cdm?06UY
J@1<C4`0I6AT071`L01HF5P0D51@069RHP1EEED0?Shn05]KF`1LG5`0UIFE07UiN@1QHF40KVi^04m?
C`2>SXh0BTY:07EeM@1ZJVX0EEEE05ADE00i>CT0N7Qh06e]K@0W9bL0IfMW02@T900e=CD0QHF504A4
A01UIFD0EEEE03Lg=`1DE5@0FEUI09FEU@1;Bd/0IFEU05ADE01`L700ZZZZ06ATI02?Shl08R8R0451
@@1CDe<0A4A404];B`1ZJVX0E5AD06a/K01WIfL0F5QH079bLP2VYZH0PX:20080UIFE04P0CDe=05IF
EP1OGel0J6QX069RHP1jNWX0DE5A075aL@2j^[X0AdM704e=C@1fMWH0I6AT0;Fe]@1JFUX0OGem06EU
I@1@D500L71`08f=S@1iNGT0F5QH07EeM@2@T900F5QH06EUI@1/K6`0YjNW09jNWP2HV9P0Vi^K09jN
WP2WYjL0d=3@06EUI@1IFET0WinO07moO`1QHF40GEeM0861P@2HV9P0QhN708V9R@32`/80n?Sh0;no
_`3=cLd0d=3@08n?S`2i^KT0/K6a0;Jf]P1eMGD0?3`l04e=C@1FEUH0De=C06e]K@1EEED0SHf=06][
J`1RHV80M7Ad03Ti>@1<C4`0MgMg0861P@1VIVH0RHV909fMW@2UYJD2ooooo`0003d0YZJV05=CD`2R
XZ80[:b/06=SH`20P800BDU905MGE`2][Jd0Jf][0451@@1NGUh0;2`/03Hf=P1aLG40FUYJ03@d=01:
BTX0<30`04];B`1OGel0IfMW02<S8`12@T80Hf=S04=3@`1iNGT0`L7103De=@0`<300C4a<06e]K@1/
K6`0RHV906e]K@0^;Rh0B4Q8059BDP1;Bd/0UIFE0<O7a`0[:b/0;bl_07EeM@2WYjL0CDe=07UiN@2C
Ti<0?clo04=3@`1EEED0HF5Q07]kN`2_[jl0TY:B01`L7013@d<0E5AD07UiN@26QXH0W9bL0080=CDe
05/0Bd];079bLP2<S8`0MgMg07UiN@0E5AD0@d=307UiN@2ATI40DE5A09BDU01IFET09BDU04I6AP29
RHT0WIfM05MGE`3?cll0@d=303/k>`1CDe<0W9bL08b<S01GEeL0Kfm_02HV9P0k>c/0LG5a08N7Q`1K
Fe/0BTY:04=3@`0[:b/0F5QH08:2PP1[Jf/0<S8b05QHF01KFe/09RHV04I6AP1FEUH0PX:203`l?01E
EED0LG5a02h^;P1bLW80eMGE0:VYZ@1?Cdl0GEeM04e=C@0Y:BT0B4Q807QhN01;Bd/0F5QH04I6AP0j
>SX0BDU9092@T01RHV80;bl_0410@00o?cl0ATI606UYJ@2BTY80AdM702d];@1?Cdl0EUIF05eMG@26
QXH0]kNg05IFEP0i>CT0HF5Q05YJFP1FEUH0TI6A0;Fe]@1?Cdl0AdM705mOG`1aLG40Ng]k09fMW@2N
WYh0>CTi0080GemO09D0LW9b0;^k^`2a/K40B4Q805MGE`1?Cdl0?3`l0:6QX@3:b/X0BTY:04a<C01A
DE40MgMg0::RXP2j^[X0];Bd04Q8B01ADE40H61P06YZJP1RHV80alO707MgM`0k>c/0BDU907AdM01g
MgL0NWYj0<S8b028R8P0B4Q804E5A@2=SHd0TY:B0:n_[`2e]KD0ADE505eMG@1UIFD0YZJV07=cL`2a
/K40RHV904M7A`20P800Ti>C0;Vi^@21PH40WYjN06m_K`11@D40KFe]0<30`035aLD0Q8B40<_;b`1U
IFD0ADE506=SH`2i^KT0Fe]K09FEU@22PX80ADE504M7A`2:RXX0FUYJ071`L01kNg/0>c/k04];B`2/
[:`0MgMg05EEE@2o_kl0BTY:04A4A02SXj<0UiNG06a/K022PX80>c/k04];B`1lO7`0WIfM05MGE`1a
LG40AdM7059BDP2][Jd0W9bL03Hf=P1IFET0MgMg03/k>`1XJ6P0WIfM03Hf=P1QHF40KFe]04U9B@1K
Fe/0Z:RX03<c<`0S8b<0>c/k04U9B@0P8200>c/k059BDP0e=CD0EeMG05ADE01mOGd0Ng]k09nOW`2Y
ZJT0:RXZ04];B`1VIVH0IFEU055AD@2>SXh0/;2`02XZ:P14A4@0FUYJ08Z:RP1XJ6P0Y:BT06QXJ00[
:b/0D51@06IVIP29RHT0PH610;Bd]01EEED08R8R04i>CP1VIVH0^KVi071`L02YZJT0Ng]k03dm?@17
AdL0IfMW06UYJ@0207EeM@0B04e=C@0e=CD0;bl_055AD@2EUID0GemO08:2PP1FEUH0>c/k04I6AP1G
EeL0NWYj05=CD`1iNGT0VYZJ06e]K@1GEeL0Ogmo0P1LG5`0P`2;Rh/0Hf=S03lo?`1>CTh0EEEE07Ui
N@1XJ6P0UiNG08f=S@1MGEd0Ng]k06m_K`1kNg/0N7Qh055AD@1]KFd0AdM7051@D01=CDd0ADE504m?
C`1MGEd0BTY:04Q8B01ADE40LG5a05YJFP1QHF40C4a<07=cL`1[Jf/0LW9b06i^KP1GEeL0H61P03Hf
=P1:BTX0<30`024Q8@0/;2`0CTi>05ADE013@d<0@41005eMG@0Y:BT0Bd];05]KF`1gMgL0CTi>055A
D@1cLg<0<c<c04A4A01LG5`0@d=3055AD@1GEeL0BTY:04e=C@0l?3`0EeMG05YJFP1LG5`0GemO059B
DP1^KVh0IVIV07emO@21PH40Ti>C05aLG01BDU80De=C05eMG@1iNGT0Fe]K05iNGP2MWId0F5QH06a/
K02<S8`0Kfm_09JFUP2@T900]kNg08n?S`1aLG40Fe]K04Y:BP1UIFD0Hf=S04];B`1OGel0>c/k061P
H00n?Sh0C4a<04Y:BP21PH40Bd];04E5A@1?Cdl0CTi>05EEE@13@d<0EEEE04Q8B01HF5P0@T9204A4
A01CDe<0@D51055AD@0k>c/0Lg=c06EUI@1BDU80F5QH04a<C01lO7`0J6QX05=CD`19BDT0;bl_07Yj
NP0n?Sh0ATI605MGE`0l?3`0CTi>0080DU9B08L0?clo059BDP0^;Rh0UYJF04I6AP31`L40N7Qh01XJ
6P2QXJ40=CDe055AD@2GUiL0>3Ph08N7Q`2>SXh0H61P06EUI@19BDT0GUiN07=cL`0o?cl0EUIF03dm
?@1TI6@0:2PX04e=C@0c<c<0Xj>S02PX:00g=cL0DU9B071`L01^KVh0?Shn06MWI`1KFe/092@T0;jn
_P2@T900AdM707inOP1hN7P0@T92061PH01?Cdl0TI6A04a<C01/K6`0Hf=S04A4A01RHV80Bd];02h^
;P16ATH0Cdm?05=CD`2ATI40I6AT05MGE`1MGEd0DU9B06][J`0e=CD0J6QX03Hf=P22PX80JFUY04a<
C01NGUh0?Cdm04U9B@1ADE40A4A40:BTY00i>CT0?3`l07MgM`19BDT0LG5a06ATI01LG5`0QHF504e=
C@1ADE40;2`/07alO01GEeL0AdM706YZJP14A4@0IfMW03Lg=`1?Cdl0HF5Q03De=@0o?cl0CDe=03`l
?00n?Sh0DE5A06MWI`1MGEd0P8200:BTY02c/k<0J6QX04E5A@1OGel0DE5A05]KF`1lO7`0Zj^[059B
DP1PH600MgMg04Y:BP23Ph<0W9bL05mOG`21PH40HV9R0:f][@1_Kfl0C4a<06EUI@1^KVh0S8b<061P
H01lO7`0Vi^K059BDP1WIfL0HF5Q05aLG01cLg<00P1GEeL0:@1oOgl0/k>c0<o?c`1<C4`0GUiN0:6Q
X@1jNWX0SHf=07QhN01<C4`0J6QX07alO020P800RHV90;Rh^02QXJ40Z:RX07alO028R8P0Zj^[08f=
S@2/[:`0^[Zj05=CD`1NGUh0HV9R04Q8B01OGel0LG5a0:b/[02FUYH0QHF508B4Q01IFET0F5QH07Qh
N02VYZH0Q8B406m_K`2GUiL0Xj>S00;ooooo00006@2a/K40NWYj05eMG@2DU9@0L71`0<G5a@16ATH0
>c/k06i^KP22PX80KFe]08J6QP0f=SH09RHV05ADE01dM7@0NGUi07QhN00/;2`0;Rh^05aLG02WYjL0
Ogmo0;2`/02SXj<00P1CDe<0N`1KFe/0NWYj06UYJ@2GUiL0?Shn0492@P1>CTh0SHf=04M7A`1XJ6P0
OWin02HV9P1IFET0KVi^08N7Q`0Z:RX0IVIV07moO`0f=SH0>SXj06IVIP0o?cl0<C4a06i^KP0e=CD0
7AdM05eMG@2ZZZX0EEEE03lo?`1`L700>c/k02/[:`1aLG40Ti>C04M7A`0o?cl0>c/k038b<P16ATH0
Q8B404E5A@0X:2P0EUIF05ADE00o?cl0U9BD08j>SP0[:b/0;Bd]05EEE@10@400>3Ph08>3P`1cLg<0
9BDU0451@@1BDU80E5AD061PH02VYZH0=SHf01`L7011@D40NWYj03dm?@1VIVH0WIfM024Q8@0d=3@0
Ng]k0861P@1=CDd0UYJF0861P@0N7Qh0DU9B09VIV@2KVi/0H61P09jNWP1eMGD0=SHf034a<@1OGel0
RXZ:05ADE02LW9`0CTi>02LW9`1CDe<0Fe]K06UYJ@23Ph<0Z:RX02h^;P0d=3@0Ph>30;Bd]01PH600
/[:b08F5Q@0`<300FUYJ06e]K@1jNWX0Ng]k09VIV@1XJ6P0ADE5055AD@2GUiL0UIFE07=cL`2TY:@0
?Cdm03lo?`1MGEd0RXZ:08b<S021PH40UYJF020P800206QXJ02J09NGU`1YJFT0Xj>S0861P@0[:b/0
F5QH08B4Q01kNg/0]KFe05ADE00d=3@0LG5a08^;R`2GUiL0Hf=S09ZJVP0c<c<0=cLg08^;R`2f][H0
QXJ606=SH`2[Zj/0<C4a02`/;01]KFd0_Kfm06QXJ01WIfL0LW9b02d];@0n?Sh0NGUi09ZJVP15ADD0
GemO061PH00];Bd0LG5a0;Bd]01ZJVX0BTY:075aL@1ADE40>c/k075aL@2e]KD0FUYJ03lo?`1iNGT0
KFe]05UIF@1jNWX0Xj>S03<c<`11@D40FUYJ05mOG`2@T900bLW9075aL@11@D40UiNG06i^KP1@D500
^k^k0;bl_00c<c<0E5AD06EUI@1HF5P0Shn?0;Zj^P0n?Sh0=CDe06e]K@1aLG40GUiN0=WIf@1`L700
?Shn07AdM01nOWh0SHf=0<k>cP1:BTX0BDU906IVIP2@T900R8R80;Bd]01QHF40=SHf06=SH`2SXj<0
H61P0:n_[`2HV9P0@41004e=C@2<S8`0Ng]k0:^[Z`2ATI40>c/k06=SH`1nOWh0Ogmo05IFEP1kNg/0
Hf=S04A4A01EEED0EUIF04Q8B01DE5@0`<3005MGE`0h>3P0FUYJ07]kN`1UIFD0R8R80;fm_@0h>3P0
?Cdm05]KF`23Ph<0IfMW07=cL`2VYZH0ADE505eMG@1[Jf/0YjNW06YZJP1[Jf/0LW9b03Xj>P18B4P0
H61P0:BTY01?Cdl0GEeM0861P@1CDe<0FEUI061PH02CTi<0?clo06UYJ@1[Jf/0;Rh^04a<C080HV9R
09H0@41005ADE01SHf<0;bl_03Ph>01HF5P0Jf][020P8013@d<0EeMG03Ph>01ADE40IVIV079bLP1V
IVH0DE5A07QhN01HF5P0FUYJ0:FUY@1DE5@0>c/k04e=C@1FEUH0M7Ad04U9B@1TI6@0L71`05=CD`1J
FUX0AdM705QHF01fMWH0JVYZ05IFEP0[:b/0DE5A03<c<`1?Cdl0?clo06QXJ00j>SX0=cLg0451@@1d
M7@0OGem07UiN@12@T80JFUY069RHP27QhL0OGem06MWI`1dM7@0ATI605eMG@0h>3P09bLW03<c<`1]
KFd0H61P04Y:BP1BDU80Kfm_02l_;`1IFET0Jf][07inOP1<C4`0EUIF07MgM`0a<C40BTY:05MGE`14
A4@0FUYJ04M7A`0n?Sh0KVi^0492@P1VIVH0DU9B04E5A@1HF5P0C4a<069RHP1ADE40EEEE06][J`2T
Y:@0CDe=04U9B@1fMWH0FUYJ0861P@1BDU80F5QH09^KV`2BTY80Ogmo08V9R@15ADD0OGem09nOW`3J
f]X0XJ6Q055AD@1SHf<0BTY:06=SH`1WIfL0BTY:05mOG`0m?Cd0De=C04A4A016ATH0?Shn05YJFP1@
D500Cdm?055AD@0h>3P0EEEE0410@01LG5`0>CTi04i>CP17AdL0?Cdm0492@P0b<S80A4A403@d=01]
KFd0IFEU03`l?01@D500Cdm?06=SH`1GEeL0IfMW06IVIP18B4P0RHV904m?C`1GEeL0IVIV04];B`17
AdL2069RHP1T04Y:BP18B4P0=CDe092@T010@400_;bl07moO`0Q8B40XJ6Q04e=C@1JFUX0Y:BT03/k
>`2;Rh/0PX:206e]K@1gMgL0A4A405QHF01<C4`0BDU907UiN@0`<300BTY:030`<01DE5@0ATI607If
MP0W9bL0CTi>05=CD`17AdL0F5QH04=3@`1ADE40GUiN02h^;P1NGUh0GemO051@D02MWId0KVi^05QH
F01fMWH0Cdm?096AT@1RHV80UIFE07IfMP1FEUH0MGEe08F5Q@10@400C4a<065QH@1DE5@0GemO071`
L01IFET0LG5a06UYJ@1GEeL0>SXj06e]K@1:BTX0UIFE07=cL`1NGUh0OWin05]KF`1=CDd0D51@03Ph
>01hN7P0<C4a04=3@`1fMWH0E5AD08f=S@1KFe/0?Cdm055AD@1GEeL0KVi^034a<@1YJFT0GemO06m_
K`2PX:00C4a<06EUI@0];Bd0Hf=S07MgM`0o?cl0?Shn055AD@0k>c/0GUiN06EUI@80H61P04`0R8R8
0;Bd]02g]kL0Shn?05IFEP1LG5`0Ph>30861P@1ZJVX0LW9b03Hf=P1?Cdl0RXZ:03De=@1=CDd0J6QX
05ADE01kNg/0De=C07emO@1jNWX0Q8B409:BTP1eMGD0QXJ606a/K020P800];Bd05iNGP26QXH0IVIV
07AdM02=SHd0I6AT061PH01`L700WIfM0<o?c`2JVYX0Ng]k09JFUP28R8P0QhN708R8R01CDe<0T92@
0;2`/031`L40`l?30<k>cP2KVi/0Z:RX0:>SX`25QHD0XZ:R0;Rh^03IfMT0/k>c05MGE`23Ph<0MWIf
04m?C`1GEeL0C4a<06=SH`1/K6`0Lg=c07MgM`0h>3P0BDU905eMG@2DU9@0L71`092@T02>SXh0^KVi
0_ooool0001F07YjNP2RXZ80MWIf07MgM`1?Cdl0Ng]k08B4Q01/K6`0Jf][03@d=01@D500Fe]K05EE
E@1HF5P0Kfm_02TY:@1JFUX0UiNG05EEE@0`<300AdM704I6AP11@D40Lg=c0:f][@0o?cl0:BTY069R
HP0m?Cd0IfMW0;Jf]P2LW9`0<30`03dm?@1HF5P0>SXj07emO@2a/K408R8R03lo?`1DE5@0CTi>034a
<@2PX:00]kNg02TY:@0l?3`0AdM705aLG01RHV80[Jf]06IVIP0];Bd0ATI606m_K`1eMGD0LG5a08:2
PP0[:b/0B4Q805=CD`1`L700Jf][06UYJ@1>CTh05aLG05eMG@1oOgl0O7al04Q8B02=SHd0;2`/024Q
8@1LG5`0^[Zj0:VYZ@1VIVH0R8R8024Q8@13@d<0HF5Q09NGU`1]KFd0S8b<0:2PX00T92@204Y:BP3o
07]kN`14A4@0SHf=06EUI@1=CDd0Bd];05eMG@1KFe/0GUiN07emO@0];Bd0Cdm?055AD@2ATI40GemO
07IfMP1^KVh0<30`04Y:BP1OGel0S8b<04e=C@1RHV80EEEE02`/;015ADD0Ti>C09BDU00k>c/0?Cdm
04U9B@0g=cL0D51@071`L01?Cdl0?Shn04M7A`0`<300ATI605=CD`1_Kfl0?Shn04A4A01RHV80:BTY
02l_;`2@T900UYJF03/k>`15ADD0BDU904Y:BP1=CDd0Xj>S09JFUP0_;bl0A4A4059BDP1SHf<0GEeM
0<o?c`1VIVH0=CDe06=SH`1KFe/0KFe]08R8R02n_[h0D51@03Ti>@1_Kfl0Fe]K0;Jf]P2c/k<0<c<c
03lo?`1kNg/0LG5a07IfMP3?cll0QHF502LW9`1@D500WYjN06][J`1bLW80d=3@03Ti>@0d=3@0ATI6
08b<S01IFET0Vi^K0;bl_00R8R80ATI6065QH@25QHD0JVYZ0<O7a`2VYZH08B4Q03lo?`1TI6@0NGUi
05mOG`2d];@0IfMW03Xj>P1QHF40Ph>306YZJP27QhL0XJ6Q055AD@19BDT0LW9b08N7Q`1mOGd0Shn?
08>3P`0R8R80J6QX0:>SX`2RXZ80NWYj0:f][@22PX80:b/[07=cL`3Ogml0LG5a09nOW`1?Cdl0=3@d
05]KF`3EeMD0UiNG07AdM01aLG40:BTY0451@@1oOgl0a<C406a/K02ZZZX0>3Ph06][J`27QhL0T92@
079bLP2`/;00Cdm?05ADE02][Jd0UIFE051@D01RHV80GUiN0451@@1jNWX0a/K606ATI01MGEd0@D51
04];B`1QHF40S8b<05=CD`14A4@0M7Ad03/k>`1VIVH0S8b<0:2PX01DE5@0Jf][08:2PP1NGUh0B4Q8
0;:b/P2JVYX0=CDe06=SH`1^KVh0CDe=06EUI@2SXj<0LW9b03Hf=P1YJFT0C4a<05UIF@25QHD0Z:RX
05UIF@0d=3@0CTi>05=CD`19BDT0TI6A0<30`017AdL0<30`03`l?01TI6@0C4a<06][J`2YZJT0<C4a
03Lg=`1HF5P0Lg=c05=CD`23Ph<0RHV9028R8P0e=CD0DE5A07]kN`1BDU80Ogmo0:j^[P0_;bl0;Bd]
04a<C01kNg/0Cdm?0820P01kNg/0>SXj04M7A`1QHF40PX:206UYJ@1TI6@0QhN705YJFP1MGEd0XZ:R
05=CD`0o?cl0H61P04m?C`1/K6`0CTi>08B4Q01gMgL0XJ6Q06MWI`1?Cdl0LW9b07EeM@1?Cdl0DE5A
000G03Xj>P1?Cdl0<30`03lo?`0n?Sh0Hf=S04a<C00f=SH0A4A405YJFP1;Bd/0Hf=S03hn?P1MGEd0
CDe=06UYJ@1EEED0EeMG061PH011@D40DE5A03Xj>P19BDT00`1ADE40=@1SHf<0GEeM05aLG00o?cl0
FUYJ07QhN01^KVh0ATI604E5A@1KFe/092@T04Q8B01WIfL0@41005eMG@1CDe<0CDe=06=SH`1@D500
LW9b04Y:BP13@d<0K6a/05ADE01]KFd0EEEE061PH01fMWH0]KFe059BDP1:BTX0WinO065QH@1kNg/0
H61P06e]K@29RHT0EEEE05iNGP24Q8@0JVYZ09BDU02g]kL0h^;R0<71`@1IFET0L71`06=SH`1?Cdl0
Kfm_069RHP1hN7P0=SHf00<0H61P02<0DU9B071`L01/K6`0EUIF06QXJ01@D500KFe]061PH01VIVH0
CTi>061PH01DE5@0H61P051@D00e=CD0EEEE0492@P1fMWH0Hf=S04I6AP1KFe/0D51@06IVIP1FEUH0
JFUY08n?S`1XJ6P0MGEe05IFEP18B4P0DU9B05]KF`1@D500BTY:05YJFP02059BDP1R03<c<`2:RXX0
>SXj0<;2`P2GUiL092@T08B4Q020P800IFEU09^KV`1XJ6P0/[:b08j>SP1PH600FUYJ04E5A@1BDU80
ATI60410@01XJ6P0:BTY051@D00V9RH0F5QH0451@@2QXJ407alO0492@P1DE5@0FEUI06][J`13@d<0
BTY:05MGE`0`<300UIFE07AdM01CDe<0`L7108:2PP0c<c<0FEUI0410@02CTi<0?Cdm05EEE@1HF5P0
CTi>08N7Q`1cLg<0@d=3079bLP1XJ6P0>3Ph079bLP1ZJVX0/;2`0;^k^`27QhL0EUIF03<c<`29RHT0
@410092@T01NGUh0?3`l05UIF@0n?Sh0C4a<05EEE@0k>c/0SHf=055AD@10@400M7Ad04=3@`1IFET0
EUIF04E5A@1<C4`0D51@08:2PP15ADD0MGEe05YJFP1:BTX0IVIV06QXJ01TI6@07alO04M7A`1HF5P0
;bl_03<c<`1RHV80;2`/0492@P17AdL205UIF@1<07emO@1ZJVX0Q8B4061PH00m?Cd0D51@04a<C01?
Cdl0HF5Q06m_K`0d=3@0OWin0;jn_P14A4@0FEUI0820P01FEUH0R8R805mOG`1TI6@0GemO059BDP1O
Gel0Cdm?06e]K@1/K6`0KFe]09JFUP24Q8@0RHV905eMG@1YJFT0Lg=c08R8R02>SXh0PX:208^;R`2d
];@0Q8B40;fm_@33`l<0OGem06i^KP1VIVH0K6a/0:6QX@2MWId0d=3@0<;2`P3Fe]H0QXJ608j>SP2d
];@0dM7A0=OGe`2>SXh0UiNG0:^[Z`1>CTh0F5QH04Y:BP1ADE40JFUY04Y:BP26QXH0LW9b08R8R01n
OWh0?clo05ADE01QHF40];Bd07YjNP2@T900Shn?0;Vi^@;ooooo00006@2=SHd0NGUi08F5Q@2=SHd0
B4Q805EEE@1iNGT0O7al09bLW00Y:BT0BDU905MGE`1NGUh0MWIf0;>c/`0m?Cd08B4Q07=cL`2RXZ80
J6QX0::RXP1JFUX0ADE503Hf=P26QXH00P2>SXh0?02n_[h0>SXj02/[:`0X:2P0TY:B08F5Q@2PX:00
L71`02l_;`0h>3P0GEeM05MGE`1_Kfl0Y:BT02l_;`0I6AT0;Rh^08F5Q@1VIVH0DU9B079bLP0N7Qh0
<S8b0410@01YJFT0C4a<06m_K`1nOWh07AdM051@D02PX:00J6QX02l_;`1bLW80CTi>02HV9P1@D500
S8b<04Q8B00^;Rh0CTi>03Ti>@19BDT0GUiN03Ph>00X:2P0?Cdm05IFEP0n?Sh0IFEU07=cL`1:BTX0
;bl_07EeM@1NGUh0;bl_08V9R@3Ng]h0J6QX030`<080I6AT00/0GEeM09FEU@2[Zj/0;bl_03`l?01S
Hf<0E5AD06UYJ@2UYJD0CDe=02d];@02059BDP2i05QHF02JVYX0bl_;038b<P0f=SH0KVi^071`L01D
E5@0VIVI0;2`/00b<S807QhN055AD@2@T900RHV907UiN@1NGUh09bLW04E5A@1JFUX0Hf=S07IfMP2L
W9`0<c<c0492@P1LG5`0EEEE04e=C@1dM7@0Zj^[02l_;`0j>SX0Fe]K06a/K01?Cdl0R8R80861P@0c
<c<0Bd];059BDP26QXH0P82009JFUP1_Kfl0>c/k04Q8B02`/;00VYZJ06][J`2TY:@0CDe=03`l?01S
Hf<0MgMg0;Vi^@26QXH0VIVI03Ph>01YJFT0Shn?09JFUP1aLG40PH6102`/;01HF5P0L71`0:n_[`1_
Kfl0I6AT07MgM`1<C4`0FUYJ079bLP2CTi<0D51@07inOP11@D40?Shn055AD@2KVi/0Fe]K05IFEP1c
Lg<0?Shn0410@01WIfL0Y:BT05eMG@1WIfL0S8b<03lo?`19BDT0O7al0;Bd]011@D40>c/k06e]K@15
ADD0EEEE0:BTY02IVIT0=cLg04m?C`1IFET0>CTi08N7Q`3;bl/0IfMW06EUI@2QXJ40H61P06QXJ02d
];@0V9RH034a<@1LG5`0W9bL09BDU02VYZH0ZZZZ03Lg=`16ATH0L71`07moO`2OWil0V9RH03@d=018
B4P0MGEe06QXJ01dM7@0fm_K05eMG@10@400UIFE06EUI@1]KFd0e=CD06a/K00m?Cd0EeMG07QhN01@
D500UYJF06=SH`0l?3`0H61P08^;R`1fMWH0ZZZZ05mOG`0/;2`0FEUI0820P01TI6@0TI6A0:VYZ@0S
8b<0?Cdm06YZJP2DU9@0F5QH08b<S01XJ6P0<c<c0451@@1cLg<0Y:BT051@D02ZZZX0GEeM03Ph>01C
De<0QHF50:2PX019BDT0W9bL06MWI`0];Bd0D51@092@T02TY:@0EEEE08Z:RP1RHV800P15ADD0>@23
Ph<0Q8B405ADE01OGel09bLW03`l?019BDT0Ph>307AdM01EEED0K6a/03Hf=P12@T80IFEU08n?S`1Q
HF40@41009:BTP10@400@D5106EUI@1oOgl0L71`05IFEP1oOgl0>SXj02DU9@1ZJVX0TI6A061PH013
@d<0I6AT071`L01OGel0K6a/06ATI01QHF40Jf][08j>SP1;Bd/0;2`/04a<C019BDT0MgMg06a/K022
PX80IFEU08F5Q@1dM7@0J6QX07moO`1lO7`0HF5Q05mOG`0[:b/0BDU902`/;00203`l?03Y06=SH`1=
CDd0?3`l05YJFP1mOGd0Fe]K07EeM@14A4@0N7Qh06QXJ02CTi<0Kfm_05eMG@1eMGD0?Cdm05MGE`0W
9bL092@T02/[:`1HF5P0FEUI04e=C@0o?cl0EeMG02<S8`13@d<0HV9R08Z:RP1ADE40EUIF096AT@0o
?cl0BDU90820P010@400I6AT04U9B@0o?cl0LG5a03/k>`1^KVh0De=C04i>CP1MGEd0ADE507=cL`1X
J6P0OGem05eMG@2LW9`0FUYJ05aLG02EUID0IfMW07EeM@1<C4`0GUiN0:ZZZP1aLG40JVYZ07MgM`10
@400M7Ad09bLW03MgMd0X:2P06EUI@1SHf<0De=C08B4Q01kNg/0Cdm?069RHP1HF5P0O7al04U9B@1?
Cdl0@d=308R8R017AdL0CTi>05]KF`1GEeL0JVYZ04a<C01EEED0BTY:05iNGP1@D500CTi>05aLG017
AdL0CDe=03dm?@2EUID0LG5a059BDP1QHF40DE5A071`L01UIFD0Q8B406m_K`1GEeL0MWIf03De=@1<
C4`0L71`04i>CP1KFe/0NWYj06QXJ01@D500JFUY03hn?P2@T900=CDe0;jn_P2EUID0<c<c08J6QP2O
Wil0KVi^09jNWP1HF5P0[jn_08N7Q`1QHF40F5QH04M7A`1OGel0E5AD03dm?@1YJFT0Cdm?06a/K016
ATH0EEEE065QH@2o_kl0@d=304];B`1DE5@0IFEU059BDP13@d<0Kfm_06IVIP0Q8B40FEUI05MGE`0o
?cl0^[Zj08F5Q@0l?3`0KVi^04A4A01YJFT0=cLg09>CT`1]KFd0CTi>0861P@1FEUH0;Bd]03dm?@15
ADD0<c<c06ATI019BDT0KFe]09:BTP1VIVH0AdM702HV9P1[Jf/0?Cdm0;2`/01^KVh0Cdm?07=cL`1:
BTX0GUiN06EUI@13@d<0RXZ:04M7A`0m?Cd0LW9b05IFEP1oOgl0EEEE051@D01UIFD0De=C06=SH`19
BDT0LW9b069RHP1NGUh0NGUi06=SH`1fMWH0<S8b051@D01NGUh0?Shn04i>CP1jNWX0?clo04M7A`16
ATH0OGem06MWI`1TI6@0BDU907emO@1YJFT0Cdm?051@D01QHF40JFUY07]kN`1XJ6P0DE5A08j>SP2i
^KT0C4a<05EEE@1hN7P0IfMW07UiN@1<C4`00P1kNg/0;@1DE5@0PX:206a/K02CTi<0MWIf09NGU`2_
[jl0Jf][08N7Q`2?Shl0Y:BT07alO01JFUX0GemO06ATI01/K6`0[jn_07]kN`1aLG40Shn?0861P@1k
Ng/0GemO05eMG@2GUiL0YZJV0:>SX`2NWYh0dM7A09BDU02JVYX0Zj^[08j>SP2g]kL0UIFE09BDU02f
][H0GEeM06MWI`1;Bd/0EUIF05YJFP1?Cdl0R8R806MWI`0205EEE@0804U9B@1LG5`0FEUI07emO@21
PH40RXZ:07inOP2PX:02ooooo`0001l0`L7104i>CP1cLg<0UIFE07alO02@T900?clo05QHF01XJ6P0
I6AT0451@@19BDT0:b/[05=CD`1]KFd0Ph>305ADE00m?Cd08b<S04I6AP1UIFD0VIVI05QHF01ADE40
HF5Q03<c<`15ADD0Q8B40:RXZ00o?cl0Fe]K0080=SHf0:80SXj>0:b/[00d=3@0@D5103/k>`17AdL0
GEeM0:BTY01YJFT071`L0492@P0j>SX0GUiN06UYJ@33`l<0>3Ph02TY:@1BDU80Cdm?038b<P2GUiL0
`<3003<c<`0M7Ad0OWin07UiN@19BDT0SHf=04I6AP0K6a/0<c<c07AdM00m?Cd0QhN707QhN00G5aL0
:RXZ05QHF01:BTX0E5AD08N7Q`2JVYX0>c/k0451@@1EEED0HF5Q04=3@`2a/K40QhN703/k>`13@d<0
Fe]K08N7Q`1nOWh0`l?303<c<`0j>SX0De=C09bLW01SHf<0MGEe0:6QX@0a<C40?3`l06=SH`2PX:00
IFEU0;Vi^@0/;2`0@D5104Q8B029RHT0YJFU04Q8B02YZJT0IfMW03Lg=`1<C4`0Ti>C08B4Q01@D500
MWIf04];B`0/;2`0L71`0:NWY`13@d<0EUIF05eMG@0f=SH0BTY:07=cL`1WIfL0?clo07=cL`1dM7@0
:b/[06IVIP31`L40YJFU04i>CP2>SXh0HV9R02l_;`1jNWX0`L7107emO@1HF5P0Shn?05iNGP1>CTh0
Shn?0<;2`P1DE5@0CTi>096AT@1VIVH0?Shn09:BTP2`/;00>3Ph06=SH`1NGUh0CTi>07MgM`2YZJT0
Bd];06ATI025QHD0=cLg08j>SP3<c<`0FUYJ03Ph>01_Kfl0M7Ad051@D01iNGT0`l?305ADE00h>3P0
Ogmo05IFEP1mOGd0i>CT09:BTP0W9bL0EeMG0861P@1IFET0O7al0=;BdP1IFET0:b/[07EeM@2=SHd0
LG5a09VIV@3?cll0E5AD04i>CP1XJ6P208B4Q01F09nOW`2RXZ80>3Ph065QH@1KFe/0]KFe09>CT`2L
W9`0De=C03Lg=`1@D500M7Ad07IfMP2QXJ40cLg=02<S8`1JFUX0TI6A0;jn_P1BDU80^;Rh08n?S`0f
=SH0UIFE0<;2`P1iNGT0LG5a07YjNP0`<300OWin0:b/[02PX:00NWYj0:FUY@0g=cL0?3`l07alO02=
SHd0JFUY08^;R`0d=3@0>CTi05EEE@2XZ:P0Fe]K07QhN01?Cdl0<C4a05aLG01jNWX0BTY:08Z:RP1h
N7P0=3@d06a/K02:RXX0=3@d04e=C@1FEUH0;bl_05ADE032`/80MWIf04M7A`1SHf<0J6QX03De=@27
QhL0Xj>S059BDP18B4P0IVIV04=3@`1]KFd0UYJF09>CT`0g=cL0@D5106ATI01;Bd/0FEUI0:FUY@2i
^KT0>3Ph0410@01WIfL205IFEP0^09^KV`2XZ:P0B4Q804E5A@2>SXh0HF5Q07AdM02EUID0IfMW02l_
;`1MGEd0Jf][06QXJ01HF5P0TI6A06m_K`0S8b<0BTY:07AdM01RHV80EeMG0:JVYP2EUID0820P03/k
>`2@T900J6QX04M7A`2^[Zh0FUYJ02PX:00i>CT0FEUI05MGE`10@400IfMW07EeM@1[Jf/0MWIf06IV
IP1<C4`0CTi>06UYJ@1MGEd0<C4a04m?C`80CTi>01/0?Shn03`l?01GEeL0MWIf06][J`1oOgl0JVYZ
05eMG@1BDU80H61P04Y:BP1BDU80:b/[04];B`18B4P0EEEE02/[:`0o?cl0DE5A05aLG01QHF40De=C
04];B`1SHf<0HF5Q06EUI@1cLg<00P1hN7P0BP15ADD0Fe]K03De=@0Y:BT0>CTi08B4Q01`L700CDe=
059BDP1jNWX0=3@d05aLG01eMGD0XJ6Q05=CD`1BDU80XZ:R02/[:`1DE5@0MWIf03Ti>@1UIFD0CDe=
04M7A`1gMgL0?Cdm07YjNP1ADE40?Cdm069RHP13@d<0HV9R05YJFP1SHf<0I6AT09jNWP1<C4`0Cdm?
09bLW01/K6`0MgMg06IVIP1QHF40WIfM0:2PX02:RXX0Ph>304Q8B022PX80U9BD0<o?c`2i^KT0MgMg
06i^KP1CDe<0I6AT0861P@1?Cdl0I6AT0492@P1EEED0=SHf05ADE019BDT0MWIf04A4A01QHF40D51@
0492@P1GEeL0AdM7055AD@19BDT0ADE50P19BDT0:01OGel0=3@d05EEE@0g=cL0J6QX05EEE@11@D40
EEEE04m?C`2;Rh/0@T9205iNGP18B4P0AdM706i^KP10@400DE5A07EeM@1BDU80EUIF059BDP1UIFD0
FEUI069RHP1]KFd0Vi^K05]KF`3:b/X0X:2P03@d=01nOWh0d=3@07inOP2XZ:P0E5AD0<[:bP2MWId0
J6QX06m_K`19BDT204m?C`0a059BDP1dM7@0>c/k05IFEP0m?Cd0EUIF05EEE@2UYJD0ADE506MWI`1e
MGD0IFEU061PH016ATH0BDU904m?C`0R8R80Hf=S06a/K012@T80Vi^K07]kN`0o?cl0F5QH05iNGP1L
G5`0ADE508J6QP1RHV80G5aL0:FUY@1^KVh0=3@d06ATI01LG5`0<30`0820P018B4P0PH610<71`@1/
K6`0HF5Q02`/;01iNGT0=3@d05mOG`11@D40J6QX08F5Q@0204A4A01[04U9B@0_;bl0LW9b04e=C@0d
=3@0L71`04a<C01NGUh0EeMG04e=C@1XJ6P0GUiN08^;R`0h>3P0Lg=c06EUI@1cLg<0QhN7065QH@1i
NGT0<30`06MWI`1[Jf/0?Cdm03Ph>01IFET0:b/[05eMG@1HF5P0H61P05]KF`1jNWX0MGEe05YJFP1U
IFD0EEEE05aLG01ZJVX0LW9b071`L01YJFT0CDe=08F5Q@2i^KT0F5QH08:2PP27QhL0Bd];06YZJP1D
E5@0Jf][06UYJ@1GEeL0J6QX05=CD`1bLW80KFe]0820P02FUYH0FUYJ07emO@1ADE40EeMG05UIF@1T
I6@0J6QX05]KF`1TI6@0[Jf]08V9R@1dM7@0[:b/08V9R@1cLg<0HV9R05=CD`1jNWX0RHV909:BTP2U
YJD0d];B0:NWY`2a/K40`L710:2PX034a<@0QhN70<[:bP31`L40IFEU07QhN01CDe<0GemO05iNGP15
ADD0MgMg05mOG`1XJ6P0IVIV04Q8B01HF5P0I6AT06QXJ01MGEd0RHV905iNGP2WYjL00_ooool0000T
08V9R@1hN7P0HV9R07emO@1/K6`0UYJF0492@P0i>CT0Lg=c096AT@1UIFD0K6a/02l_;`0^;Rh0@T92
05EEE@24Q8@0Z:RX03lo?`0N7Qh0@d=304a<C01hN7P0^;Rh0<O7a`0W9bL0CDe=04a<C01[Jf/0O7al
0<W9b@1OGel0=SHf07QhN021PH40CDe=0P2=SHd03@0A4A40@T9204a<C01VIVH0AdM70;6a/@1fMWH0
8B4Q04e=C@1]KFd0JFUY05ADE01nOWh00P0b<S80o`1BDU80KVi^09JFUP1@D500N7Qh02XZ:P15ADD0
NWYj09:BTP1KFe/0GemO03hn?P0N7Qh0H61P0;Ng]`23Ph<0EeMG06m_K`0Q8B40:BTY07EeM@1fMWH0
[:b/06e]K@2_[jl0;Bd]05=CD`1ADE40K6a/04A4A01[Jf/0K6a/03Xj>P1MGEd0Hf=S06e]K@0c<c<0
NWYj03hn?P0k>c/0A4A409bLW01LG5`0ATI605YJFP0a<C40OGem0<30`01FEUH0<c<c05EEE@1^KVh0
C4a<051@D031`L40WYjN03<c<`0`<300B4Q803Ti>@1fMWH0PH6106QXJ00a<C40@d=3065QH@1WIfL0
MgMg08R8R00a<C40@41004];B`1bLW80IVIV0;:b/P2GUiL0?clo04a<C01TI6@0N7Qh05IFEP3>c/h0
Rh^;03Ti>@19BDT0IfMW08^;R`24Q8@0^k^k05=CD`1<C4`0GemO08V9R@24Q8@0G5aL0:RXZ00e=CD0
EeMG05iNGP1gMgL0OWin09bLW01bLW80<c<c06a/K01ZJVX0N7Qh09^KV`2:RXX0Fe]K05ADE02DU9@0
Xj>S07moO`32`/80CTi>03De=@1RHV80MGEe0:FUY@1kNg/0bLW904Q8B00k>c/0IVIV0:>SX`1FEUH0
N7Qh075aL@10@400>3Ph07UiN@2ZZZX0H61P08F5Q@1/K6`0>c/k05mOG`1`L700TI6A051@D031`L40
BDU903Lg=`1dM7@0X:2P07]kN`1_Kfl0RHV904Q8B01LG5`0L71`0;Bd]01SHf<0HF5Q08n?S`12@T80
IFEU0<k>cP2QXJ40HF5Q09^KV`27QhL0ADE508f=S@3Cdm<0E5AD05EEE@1FEUH0H61P0::RXP2QXJ40
?3`l05eMG@1^KVh0QhN70:^[Z`38b<P0De=C0410@01]KFd0CDe=07alO03AdM40L71`03/k>`1WIfL0
M7Ad05mOG`2^[Zh0UiNG02/[:`1CDe<0I6AT05mOG`2a/K40TY:B03De=@1KFe/0Z:RX06=SH`25QHD0
W9bL02d];@0i>CT0RXZ:08F5Q@1WIfL0Kfm_05eMG@0g=cL0FEUI08j>SP2=SHd0IFEU09nOW`1?Cdl0
=CDe061PH02h^;P0EUIF05YJFP2b/[80>SXj02TY:@1/K6`0^KVi065QH@1`L700e=CD04i>CP1QHF40
LW9b096AT@1_Kfl0TY:B0;>c/`10@400Fe]K096AT@2CTi<0AdM70:b/[02XZ:P0Fe]K04];B`1PH600
RHV904M7A`1QHF40?Cdm02h^;P16ATH0Bd];0861P@00301DE5@0Hf=S06YZJP0_;bl0ADE505EEE@22
PX80:RXZ03lo?`1]KFd0A4A403hn?P80J6QX01X0Cdm?03Xj>P1MGEd0DU9B05QHF01WIfL0ATI604M7
A`1=CDd0BDU905EEE@13@d<0EUIF05aLG01eMGD0Lg=c05mOG`1ZJVX0KVi^05MGE`1;Bd/092@T04m?
C`0`<300:RXZ03<c<`80D51@0100@T92069RHP1^KVh0H61P06IVIP0m?Cd0Jf][05ADE01hN7P0HV9R
04e=C@1JFUX0?Shn04m?C`0^;Rh09RHV0P0o?cl08@14A4@0?Cdm04Q8B01PH600=3@d04];B`1dM7@0
PX:206QXJ01jNWX0UIFE03Ti>@19BDT0LG5a05aLG01hN7P0BTY:04I6AP1mOGd0@d=307=cL`1BDU80
BDU9061PH013@d<0IfMW06YZJP1gMgL0Lg=c0;2`/01ADE40CTi>09nOW`0209JFUP0P06a/K01KFe/0
Lg=c07YjNP1nOWh0Fe]K04];B`1]KFd0O7al0>3Ph02[Zj/0EUIF06ATI01LG5`0PH6108V9R@1LG5`0
NWYj04E5A@1_Kfl0MGEe06=SH`0k>c/0LW9b06a/K01RHV80HF5Q05ADE01PH600E5AD065QH@15ADD2
059BDP0h04Y:BP1NGUh0@41005]KF`0k>c/0NGUi05]KF`18B4P0H61P05QHF01UIFD0AdM706][J`1P
H600Hf=S07]kN`0/;2`0@41004i>CP1VIVH0H61P05QHF01LG5`0H61P06IVIP1HF5P0I6AT04i>CP3A
dM40Ogmo03De=@2FUYH0`<3007IfMP2][Jd0EeMG08Z:RP27QhL0KVi^07alO00a<C40EEEE06UYJ@1B
DU80IfMW03Xj>P1<C4`0=3@d05UIF@1HF5P0[Zj^04U9B@1<C4`0Jf][079bLP1`L70204Y:BP1^06=S
H`0m?Cd0Y:BT08Z:RP1JFUX0^KVi09nOW`1WIfL0IFEU04I6AP2KVi/0@T92092@T01oOgl0CDe=075a
L@1LG5`0=3@d03lo?`19BDT0?Cdm07QhN01?Cdl0Fe]K08F5Q@1@D500Fe]K02TY:@1gMgL0<c<c08n?
S`1@D500De=C06UYJ@0g=cL0GUiN069RHP0T92@0MWIf06MWI`1>CTh0MGEe065QH@1jNWX0GUiN05UI
F@1cLg<0E5AD05mOG`0V9RH0QHF504M7A`1cLg<0LW9b04E5A@1HF5P08b<S06MWI`1EEED09bLW05aL
G022PX80<C4a04Y:BP1;Bd/0EUIF05MGE`1^KVh0G5aL05UIF@1FEUH0>3Ph055AD@1MGEd0H61P065Q
H@1SHf<0HV9R06m_K`2LW9`0DE5A051@D01TI6@0IVIV08J6QP1NGUh0F5QH06QXJ00o?cl0EUIF04U9
B@1aLG40MgMg06YZJP2BTY80JVYZ08j>SP1CDe<0IfMW05EEE@1`L700NWYj05iNGP1;Bd/0YjNW07If
MP1eMGD0XJ6Q08J6QP2;Rh/2071`L00O08J6QP2=SHd0YjNW0::RXP3Kfm/0QhN707MgM`2;Rh/0ZJVY
0<;2`P1eMGD0^KVi0<K6aP1cLg<0Hf=S04M7A`0d=3@0C4a<05iNGP2BTY80HV9R05YJFP1EEED0E5AD
055AD@1_Kfl0N7Qh06e]K@1^KVh0IVIV0:VYZ@02ooooo`000?l0PX:209fMW@2a/K40EeMG04m?C`1[
Jf/0M7Ad06UYJ@2LW9`0;bl_04E5A@1WIfL0AdM704Q8B01aLG40<S8b020P801NGUh0SHf=059BDP1g
MgL0?Cdm030`<00j>SX0NWYj06EUI@0n?Sh0I6AT02@T901ADE40G5aL08Z:RP0k>c/0DU9B05YJFP1;
Bd/0EeMG08f=S@10@400=3@d075aL@0b<S80@d=30861P@2SXj<0>c/k038b<P1SHf<0GemO04E5A@2T
Y:@0HF5Q02LW9`1@D500KVi^03Ph>01eMGD0b<S805QHF00Q8B40FEUI06QXJ01DE5@0[Zj^05QHF00D
51@0820P05MGE`1WIfL0Jf][0;Fe]@0];Bd0820P02/[:`19BDT0NGUi079bLP3De=@0:b/[03/k>`1Z
JVX0NWYj075aL@2TY:@0_[jn02@T900l?3`0UiNG07AdM01>CTh0`l?306YZJP0P8200EEEE07moO`1a
LG40S8b<0:n_[`0m?Cd0=cLg06i^KP2l_;`0OGem09JFUP2KVi/0Bd];03Ph>01]KFd0_Kfm08^;R`1a
LG40LW9b01/K6`12@T80Ph>3071`L01OGel0QXJ607UiN@0K6a/0G5aL09:BTP1FEUH0Fe]K06a/K00]
;Bd0@41007MgM`2UYJD0F5QH04Q8B01NGUh09bLW03dm?@1>CTh0Shn?04U9B@1OGel0M7Ad03@d=01@
D500LG5a08F5Q@18B4P0PX:20861P@0/;2`0Lg=c08^;R`1cLg<0?Cdm0820P016ATH0<S8b0:2PX02n
_[h0@41004M7A`1`L700?clo0:ZZZP2CTi<0>c/k059BDP1FEUH0EeMG079bLP36a/H0LW9b02h^;P1C
De<0H61P055AD@1PH600RXZ:05aLG00m?Cd0EeMG05eMG@1[Jf/0WIfM09VIV@0h>3P0=SHf051@D01d
M7@0GUiN0:ZZZP2XZ:P09bLW03Ph>015ADD0TI6A07EeM@3Bd]80MGEe03<c<`13@d<0F5QH06m_K`2N
WYh0b/[:07=cL`0l?3`0BDU90:2PX02ATI40X:2P0:JVYP14A4@0FUYJ05eMG@2OWil0WIfM0<K6aP1[
Jf/0A4A406YZJP28R8P0Kfm_0=CDe02:RXX0:BTY0410@02:RXX0RHV90:ZZZP2BTY808R8R04];B`1o
Ogl0K6a/08b<S035aLD0CTi>02/[:`2;Rh/0^[Zj07MgM`36a/H0DU9B03dm?@1<C4`0^KVi08f=S@2C
Ti<0JFUY03De=@23Ph<0a<C407MgM`2?Shl0GEeM04e=C@1CDe<000H0PH6106YZJP1mOGd0PX:203dm
?@1GEeL20:NWY`1l03dm?@1/K6`0O7al05mOG`1LG5`0Y:BT09fMW@1=CDd0KFe]04];B`1HF5P0GUiN
0<30`01eMGD0>c/k065QH@1HF5P0?3`l06a/K02FUYH0OWin03@d=01JFUX0E5AD0451@@1ADE40alO7
09:BTP0a<C40E5AD061PH01=CDd0KFe]09nOW`1IFET0>c/k04e=C@1[Jf/0FEUI07moO`2=SHd0;Rh^
03/k>`1EEED0C4a<05ADE02CTi<0/[:b03Ti>@0];Bd0A4A405mOG`0_;bl0K6a/09JFUP1ADE40AdM7
05EEE@1cLg<0GemO05UIF@1JFUX0GUiN06=SH`20P800BDU903Lg=`1NGUh0De=C05iNGP1JFUX0IfMW
051@D01TI6@0LG5a06ATI01LG5`0Fe]K051@D01?Cdl0?Cdm04m?C`0_;bl0@D5103Lg=`1EEED0CTi>
04E5A@1:BTX0GEeM06=SH`1MGEd0B4Q805eMG@1FEUH0K6a/069RHP1WIfL0K6a/04M7A`15ADD0?Cdm
03<c<`13@d<0Lg=c05mOG`19BDT0CTi>08:2PP0T92@0>3Ph069RHP2?Shl0BTY:03/k>`1GEeL0@D51
04Q8B01DE5@0;2`/04A4A013@d<0@D5106a/K080IVIV0?T0AdM704A4A01WIfL0JVYZ05aLG01HF5P0
QXJ606YZJP1BDU80C4a<055AD@1BDU80?Cdm06EUI@1YJFT0GUiN07AdM011@D40DE5A065QH@19BDT0
M7Ad061PH02>SXh0P82005aLG01DE5@0@D5106EUI@1JFUX0ATI605mOG`19BDT0EUIF059BDP1[Jf/0
AdM706UYJ@10@400<30`0451@@1LG5`0B4Q803Ph>00m?Cd0ADE504];B`1KFe/0ATI605MGE`1DE5@0
GUiN02d];@1[Jf/0J6QX065QH@1mOGd0AdM7071`L00o?cl0V9RH059BDP0k>c/0EUIF04i>CP1SHf<0
I6AT061PH01RHV80EEEE06a/K01>CTh0IVIV05MGE`1QHF408b<S09bLW01bLW80=cLg07AdM02][Jd0
LG5a0:j^[P1LG5`0_[jn0820P01SHf<0EEEE04I6AP1SHf<0Ph>3059BDP1MGEd0ATI605MGE`0j>SX0
?Cdm04E5A@2JVYX0@41004a<C01@D500Lg=c061PH00n?Sh0Cdm?059BDP0j>SX0PH61075aL@1[Jf/0
_kno09JFUP27QhL0Ph>307MgM`2RXZ80HV9R08N7Q`26QXH0E5AD09VIV@24Q8@0@D5104e=C@1OGel0
?Cdm06=SH`1WIfL0BTY:069RHP1;Bd/0J6QX02d];@20P800@D5106i^KP1?Cdl0E5AD07EeM@0n?Sh0
CTi>051@D01;Bd/0VIVI07inOP18B4P0I6AT04E5A@1UIFD0K6a/051@D01<C4`0Jf][09:BTP0a<C40
I6AT04];B`1OGel0JFUY065QH@1oOgl0=3@d05YJFP1WIfL0:RXZ04a<C01>CTh0>c/k04e=C@15ADD0
L71`05]KF`1`L700H61P06][J`1]KFd0FEUI06IVIP1ZJVX0Lg=c08R8R02@T900O7al06m_K`2b/[80
BTY:08V9R@22PX80EEEE075aL@15ADD0MWIf06i^KP10@400Hf=S05UIF@1jNWX0JFUY07UiN@2DU9@0
GUiN08j>SP1_Kfl0YZJV07EeM@1QHF40IFEU05MGE`13@d<0Zj^[071`L025QHD0ZJVY07AdM02DU9@0
L71`059BDP2OWil0[:b/0;2`/02CTi<0bl_;092@T02>SXh0TI6A08j>SP2FUYH0@d=307AdM02/[:`0
TI6A08n?S`1YJFT0BTY:05IFEP1SHf<0Q8B406EUI@1aLG40GEeM04I6AP1GEeL0KFe]08B4Q01<C4`0
L71`06QXJ02`/;000_ooool0000D09:BTP1_Kfl0PH6109RHV01@D500IFEU06UYJ@1NGUh0XJ6Q0410
@011@D40DE5A04Q8B01EEED0Vi^K030`<00N7Qh0<30`04Q8B010@40209>CT`0E02d];@14A4@0De=C
06EUI@2<S8`0/k>c02PX:00Y:BT0@D5108b<S01KFe/0`<3007alO00P8200AdM7055AD@1<C4`0NGUi
0<71`@0m?Cd0;Bd]0080IFEU0?l0I6AT08>3P`2j^[X0>CTi03@d=01XJ6P0Ogmo04E5A@1nOWh0QhN7
02HV9P0^;Rh0NGUi08^;R`1MGEd0QhN7034a<@0M7Ad0JFUY0:RXZ01<C4`0FUYJ04i>CP0X:2P0:b/[
03`l?01TI6@0@T920:n_[`15ADD05QHF02h^;P1EEED0PX:204a<C01MGEd0@T9203@d=01gMgL0RXZ:
05YJFP1>CTh0KVi^03/k>`0Y:BT0EEEE08b<S00d=3@0GemO07AdM00X:2P0;2`/07]kN`1_Kfl0?Cdm
05iNGP0X:2P0;Bd]04=3@`1NGUh0D51@02l_;`1GEeL0CDe=03dm?@2<S8`0/;2`04Q8B00d=3@0H61P
04];B`0d=3@0S8b<08V9R@0_;bl0;Bd]055AD@1MGEd0IFEU0;Jf]P16ATH0:2PX03hn?P1fMWH0GemO
07QhN02f][H0@d=303Ph>01UIFD0J6QX051@D02BTY80`<3004i>CP12@T80Ng]k075aL@1IFET0Vi^K
0=KFeP0e=CD0CTi>09fMW@25QHD0MWIf0<O7a`1YJFT09BDU061PH02d];@0Q8B407emO@2DU9@0>3Ph
05YJFP3?cll0NWYj09nOW`2EUID08R8R06IVIP2SXj<0_[jn07=cL`3:b/X0YjNW03`l?01VIVH0Jf][
09^KV`1CDe<0a<C406EUI@0a<C40NWYj06i^KP1SHf<0J6QX0;Rh^00];Bd0?Shn07EeM@2][Jd0Ph>3
07inOP2?Shl0>3Ph051@D02;Rh/0_Kfm05IFEP1dM7@0HV9R038b<P1UIFD0U9BD0<;2`P1SHf<0]kNg
04A4A01:BTX0J6QX0;2`/01eMGD0O7al0820P00[:b/0KVi^09bLW02ZZZX0De=C0:f][@1XJ6P0AdM7
092@T03Bd]80I6AT059BDP1FEUH0@410075aL@2l_;`0KFe]04=3@`1]KFd0?Shn06i^KP3AdM40PH61
03Lg=`1CDe<0F5QH05MGE`25QHD0QhN703hn?P19BDT0CTi>075aL@31`L40W9bL02XZ:P1IFET0JVYZ
06e]K@2_[jl0/K6a03/k>`1GEeL0S8b<065QH@1kNg/0aLG5079bLP0V9RH0E5AD0:NWY`1HF5P0Ph>3
09ZJVP0h>3P0?Cdm05]KF`2BTY80MgMg0;6a/@1JFUX0<S8b04M7A`1RHV80O7al079bLP2n_[h0TI6A
0410@00e=CD0GEeM09^KV`1mOGd0YZJV06i^KP0m?Cd0?clo0;Fe]@39bLT0U9BD0;fm_@0o?cl0<30`
04];B`2WYjL0/K6a07EeM@2GUiL002L0F5QH024Q8@0i>CT0QHF508:2PP1jNWX0/k>c05UIF@0a<C40
=SHf05]KF`1lO7`0B4Q807moO`0l?3`0<30`02l_;`11@D40GEeM04a<C015ADD0MGEe06YZJP1TI6@0
M7Ad061PH01]KFd0RHV905MGE`19BDT0FUYJ04];B`1ADE40@41006YZJP1mOGd0S8b<07inOP1]KFd0
0P1fMWH0C01_Kfl0I6AT03Ti>@1FEUH08b<S04Y:BP13@d<0GUiN03<c<`1=CDd0IfMW06][J`1SHf<0
JVYZ05QHF01iNGT0FEUI08j>SP1dM7@0GemO07alO016ATH0D51@03Ti>@0c<c<0@41006e]K@1RHV80
BTY:04A4A01NGUh0=CDe03Lg=`1ADE40HF5Q059BDP1KFe/0P820028R8P10@400GUiN03hn?P1IFET0
DE5A04e=C@1OGel0ADE506MWI`19BDT0FUYJ05IFEP14A4@0KFe]06UYJ@1jNWX0LW9b08V9R@15ADD0
CDe=08Z:RP1cLg<0OGem05IFEP1LG5`0MGEe071`L022PX80TY:B06MWI`25QHD0MgMg0>3Ph02TY:@0
F5QH06EUI@1?Cdl205iNGP0X04Y:BP1QHF40D51@06][J`18B4P0HF5Q04A4A01dM7@0>3Ph03/k>`1?
Cdl0KFe]05MGE`0i>CT0EEEE04Q8B00m?Cd0AdM704Y:BP1HF5P0?Shn04e=C@1?Cdl0TI6A05IFEP1;
Bd/0D51@05EEE@1_Kfl0BTY:03Ti>@1@D500CDe=07=cL`1OGel0EEEE06i^KP17AdL0F5QH07alO080
EUIF08/0?3`l06][J`1TI6@08B4Q0:6QX@1@D500:BTY0;Zj^P37alL0MgMg092@T01=CDd0]kNg07If
MP1LG5`0EEEE0451@@1GEeL0MGEe06a/K01WIfL0=SHf04a<C00f=SH0DE5A03Ti>@2UYJD0>c/k06=S
H`1`L700KFe]04i>CP1?Cdl0MgMg075aL@0l?3`0IfMW051@D01QHF40g=cL09bLW013@d<0F5QH04E5
A@2=SHd0BDU90:j^[P2][Jd0@T9208f=S@1NGUh0=SHf051@D01eMGD0GemO07emO@2DU9@0IFEU075a
L@1:BTX0Hf=S02XZ:P1[Jf/0<C4a07IfMP1:BTX0JVYZ0:6QX@17AdL0BTY:04i>CP0d=3@0JFUY07Ui
N@13@d<0Jf][03lo?`1bLW80FUYJ03De=@1DE5@0GEeM069RHP1>CTh0KVi^04a<C01YJFT0EeMG06e]
K@2/[:`0A4A406][J`1PH600DU9B04i>CP1KFe/0GemO08F5Q@1KFe/0Cdm?06ATI025QHD0E5AD04];
B`1NGUh0?Cdm04i>CP1SHf<0JFUY05iNGP1WIfL0CDe=079bLP2][Jd0AdM7065QH@1UIFD0GemO08B4
Q00k>c/0Cdm?04e=C@1BDU80IfMW04i>CP1PH600PX:207=cL`2BTY80Hf=S09BDU01WIfL0De=C04E5
A@1EEED0G5aL04I6AP1DE5@0VYZJ0080JFUY02@0Ph>306EUI@1HF5P0M7Ad05mOG`1RHV80MGEe08:2
PP2g]kL0dM7A09ZJVP2h^;P0Zj^[09:BTP2RXZ80MgMg09JFUP2HV9P0K6a/06UYJ@1MGEd0CTi>05MG
E`1?Cdl0MgMg07QhN02TY:@0TI6A05=CD`1OGel0K6a/08b<S01:BTX0Ogmo08j>SP2^[Zh2ooooo`00
0>D0][Jf05mOG`1^KVh0Q8B409^KV`2l_;`0ATI606EUI@2ZZZX0N7Qh08n?S`2IVIT09RHV04i>CP26
QXH0MgMg07QhN02EUID0BTY:02d];@1VIVH0WinO06=SH`2>SXh0XZ:R02h^;P13@d<0I6AT07QhN01D
E5@0Ogmo03Xj>P0/;2`0G5aL09RHV013@d<0>CTi06m_K`0U9BD0:b/[08b<S02VYZH0<S8b04e=C@0n
?Sh0820P04Q8B02?Shl0RXZ:03dm?@1NGUh0?3`l02`/;01UIFD0Shn?03<c<`12@T80D51@03Ti>@1H
F5P0YjNW0:2PX00Q8B40>CTi06m_K`1KFe/0L71`07QhN00a<C40=cLg03`l?00a<C40Bd];0<?3``25
QHD07AdM02d];@16ATH0CDe=05]KF`2SXj<0MgMg01hN7P0m?Cd0EEEE04A4A01bLW80d];B05ADE00a
<C40BDU904m?C`1DE5@0UYJF0=cLg00k>c/0?3`l04Y:BP1LG5`0QHF50<G5a@1nOWh0;Bd]05ADE01<
C4`0GEeM06][J`2MWId0TI6A028R8P13@d<0L71`06ATI01HF5P0U9BD05iNGP0^;Rh0@D5106=SH`1K
Fe/0Ti>C075aL@0Z:RX0?Shn06EUI@2<S8`0Cdm?08^;R`1aLG40=3@d04=3@`0o?cl0GUiN05=CD`2@
T900H61P03<c<`12@T80FUYJ07]kN`1DE5@0^k^k05]KF`0c<c<0@D51096AT@23Ph<0EEEE07inOP0[
:b/0B4Q8079bLP25QHD0ATI607alO01IFET0<C4a061PH01kNg/0De=C06IVIP1KFe/0ATI606YZJP26
QXH0@D510492@P2EUID0@41005QHF025QHD0Vi^K04e=C@12@T80NWYj04e=C@1YJFT0T92@07emO@0^
;Rh0DE5A071`L01ADE40LG5a0:n_[`1ZJVX092@T0410@01_Kfl0LW9b07=cL`2c/k<0IFEU02LW9`1C
De<0UYJF0861P@2RXZ80TI6A02l_;`1<C4`0IVIV07=cL`1eMGD0[jn_08b<S010@400G5aL09^KV`1U
IFD0QhN70:n_[`0V9RH0EEEE09FEU@1nOWh0N7Qh0<k>cP1KFe/0<S8b06i^KP2VYZH0X:2P0:ZZZP1_
Kfl0;2`/06YZJP2ATI40Kfm_0080ZJVY05`08B4Q0451@@23Ph<0TI6A08F5Q@2LW9`0B4Q804];B`2<
S8`0c/k>06m_K`2_[jl0FUYJ02DU9@2CTi<0c<c<05YJFP2PX:00Fe]K038b<P1MGEd0ZZZZ09NGU`1o
Ogl0Ng]k038b<P1GEeL0RHV90<g=c@2BTY80WIfM075aL@12@T80FEUI07inOP25QHD0GEeM0:BTY00g
=cL0<C4a08>3P`2@T900AdM7059BDP2JVYX0FEUI03@d=01MGEd0[Jf]04a<C01?Cdl0G5aL04U9B@0o
?cl0LG5a0::RXP1:BTX0?Shn07emO@1MGEd0DU9B096AT@1fMWH0>3Ph05=CD`1?Cdl0D51@05ADE024
Q8@0LW9b034a<@17AdL0FEUI030`<01ZJVX0_Kfm0:>SX`1=CDd0FUYJ04m?C`16ATH0>3Ph09VIV@2W
YjL09BDU03/k>`1MGEd0J6QX04m?C`1JFUX0MWIf065QH@80EEEE00d0HF5Q079bLP1/K6`0ADE5034a
<@1OGel0Bd];04i>CP1:BTX0H61P04U9B@1:BTX0F5QH0080DU9B0?l0GemO05YJFP0i>CT0;Bd]06QX
J00`<300<c<c03/k>`1gMgL0=3@d03`l?01<C4`0IfMW07emO@1YJFT0B4Q806IVIP2:RXX0N7Qh06YZ
JP1MGEd0LW9b06EUI@1OGel0BTY:04A4A01OGel0IFEU06MWI`1@D500DE5A06MWI`0h>3P0?Cdm069R
HP2:RXX0DE5A04a<C023Ph<0;bl_04U9B@1UIFD0C4a<061PH01?Cdl0?clo07MgM`1=CDd0RHV904M7
A`13@d<0EUIF04E5A@1MGEd0EUIF071`L01cLg<0/K6a04];B`1ADE40d];B0:ZZZP2OWil0IFEU051@
D022PX80ADE505IFEP1NGUh0?3`l069RHP1^KVh0c/k>0;Zj^P1HF5P0Jf][05aLG023Ph<0M7Ad05UI
F@1]KFd0?Cdm05aLG01SHf<0FUYJ03/k>`1KFe/0@T9205MGE`19BDT0AdM705iNGP1:BTX0Hf=S04e=
C@1HF5P0GEeM04a<C01GEeL0HV9R061PH00i>CT0JFUY051@D01EEED0Lg=c04U9B@1oOgl0@d=305iN
GP1GEeL0F5QH07emO@0e=CD0Bd];06=SH`1IFET0H61P0820P01OGel0Cdm?04Q8B014A4@0GEeM05AD
E02][Jd0J6QX02XZ:P1GEeL0TY:B07]kN`2IVIT0De=C07=cL`1RHV80Ng]k08^;R`1FEUH0DU9B04a<
C01OGel0LG5a03Ph>014A4@0=SHf05IFEP0h>3P0Shn?04M7A`1?Cdl0FUYJ07YjNP1GEeL0=CDe04M7
A`15ADD08B4Q08N7Q`1FEUH0=CDe06e]K@0o?cl0=SHf05YJFP1ADE40RHV902@T901bLW80IVIV03De
=@1YJFT0GemO0451@@1UIFD0JFUY03dm?@1VIVH0I6AT07QhN024Q8@0E5AD06YZJP1>CTh0TI6A03De
=@20P800Cdm?05MGE`1XJ6P0?Shn04a<C01CDe<0=SHf06m_K`1lO7`0H61P08j>SP1MGEd0QhN706EU
I@17AdL0GUiN04m?C`1TI6@07alO06IVIP0Z:RX0DU9B03hn?P1FEUH0U9BD02d];@1ZJVX0GUiN01dM
7@1GEeL0GUiN01HF5P1GEeL0?3`l04m?C`1<C4`0Ng]k03lo?`1;Bd/0HV9R03`l?016ATH0FEUI05mO
G`1VIVH0MGEe05ADE02?Shl0]kNg03Xj>P1[Jf/0Hf=S055AD@26QXH0?3`l05EEE@12@T80@D5105IF
EP1HF5P0IFEU08n?S`1HF5P0SXj>06i^KP2KVi/0ATI606ATI01@D50002/0Lg=c07UiN@28R8P0Kfm_
09ZJVP2?Shl0PX:20;>c/`2SXj<0[Zj^08:2PP25QHD0RHV907AdM02RXZ80bLW90>SXj02DU9@0Kfm_
09BDU02KVi/0b<S8096AT@2HV9P0][Jf05aLG01WIfL0IVIV06QXJ01[Jf/0IVIV07AdM01EEED0O7al
05mOG`1;Bd/0DE5A06EUI@2HV9P0Bd];079bLP1`L700Ph>300;ooooo00001`2IVIT0OGem092@T01B
DU80GEeM09VIV@1KFe/00P1^KVh04P0o?cl0H61P08f=S@1=CDd0>SXj05IFEP0e=CD0>CTi092@T01E
EED0;2`/0492@P1OGel0@T9207MgM`2o_kl0F5QH03hn?P80JFUY08/0SHf=0<K6aP1^KVh08R8R03Lg
=`26QXH0EeMG09ZJVP35aLD09BDU03`l?01ADE40Ng]k06UYJ@31`L40T92@024Q8@17AdL0De=C05MG
E`1VIVH0_Kfm05=CD`0a<C40EUIF055AD@1fMWH0WinO08:2PP0J6QX0?clo04Y:BP1WIfL0Fe]K0:6Q
X@1<C4`0820P03Lg=`15ADD0G5aL06ATI01kNg/0:b/[01lO7`1CDe<0Y:BT05iNGP1fMWH0Ng]k02DU
9@0^;Rh0CTi>08V9R@1JFUX0MWIf06YZJP0Q8B40CDe=09FEU@2JVYX0BTY:075aL@13@d<0:RXZ04Q8
B02FUYH0QXJ603Ti>@1VIVH07AdM05MGE`2;Rh/0PX:205]KF`1HF5P0NWYj03De=@0_;bl0JFUY0::R
XP1VIVH0@41004e=C@0d=3@0ATI605ADE02ATI40@d=306a/K012@T809BDU07]kN`2KVi/0@d=303De
=@1>CTh0BDU90410@02<S8`0/k>c05IFEP11@D40Hf=S0492@P0o?cl0PX:20:6QX@0[:b/0CDe=07If
MP1LG5`0LW9b0;6a/@2OWil0ADE505IFEP1MGEd0Q8B40:n_[`3Bd]80BDU903`l?01EEED0KFe]04Q8
B02i^KT0Z:RX03<c<`15ADD0EUIF06][J`2l_;`0QHF503Ph>01IFET0J6QX07=cL`27QhL0eMGE0080
@D510:h0LG5a09jNWP2WYjL0XZ:R0<G5a@0c<c<0?Shn071`L02][Jd0FUYJ096AT@1nOWh0>SXj06QX
J02ATI40/;2`07EeM@2CTi<0EeMG03dm?@1]KFd0GemO0;Rh^02CTi<0VIVI03dm?@1`L700U9BD09fM
W@1HF5P0GEeM07YjNP1:BTX0C4a<07moO`2h^;P0Ph>307AdM02<S8`0A4A409bLW02;Rh/0MgMg0820
P036a/H0HF5Q03Lg=`2WYjL0a<C404];B`1aLG40M7Ad06MWI`2>SXh0[Jf]059BDP1NGUh0LW9b04M7
A`1MGEd0b<S807IfMP15ADD0EUIF04M7A`1CDe<0/;2`06m_K`1:BTX0JVYZ06m_K`1eMGD0W9bL09fM
W@0b<S80IVIV08f=S@1@D500SHf=09RHV00/;2`0>3Ph07inOP1fMWH0RHV909JFUP0n?Sh0EUIF06QX
J01eMGD0H61P0;Vi^@2UYJD0@41004];B`1HF5P0NWYj05iNGP2_[jl0Lg=c03De=@1:BTX0OGem055A
D@1MGEd0/;2`0410@00`<300>3Ph06QXJ01PH600PX:20;fm_@1=CDd0AdM7059BDP1lO7`0L71`07]k
N`2/[:`0@41003dm?@1nOWh0QhN70451@@29RHT0NWYj02LW9`1=CDd0Ng]k08:2PP1mOGd0MGEe05IF
EP0/;2`0?3`l059BDP21PH40GEeM07]kN`1hN7P0:b/[02HV9P18B4P0Q8B404E5A@17AdL0UiNG04I6
AP1cLg<0EeMG07UiN@1YJFT0E5AD08>3P`1JFUX0F5QH092@T018B4P0C4a<05mOG`14A4@0LG5a06QX
J01hN7P0EeMG075aL@25QHD0CDe=07]kN`1`L700ADE504Y:BP0a<C4204i>CP0@04I6AP0n?Sh0E5AD
04];B`0k>c/0GUiN061PH019BDT0EeMG0492@P1PH600@D5105eMG@1>CTh0DE5A06MWI`80>CTi00D0
:2PX03Hf=P0l?3`0C4a<05]KF`0205ADE00A05EEE@0h>3P0>CTi055AD@1DE5@0Bd];04Y:BP1@D500
>3Ph04i>CP1<C4`0@D5104a<C01YJFT0FUYJ05IFEP17AdL00P1WIfL0n01eMGD0F5QH0451@@1^KVh0
OGem092@T01XJ6P0Zj^[07IfMP1_Kfl0LG5a08F5Q@2;Rh/0Q8B4069RHP1SHf<0A4A405UIF@25QHD0
Rh^;07YjNP19BDT0_Kfm09nOW`1lO7`0GUiN05QHF028R8P0MWIf04U9B@1MGEd0@d=3071`L01:BTX0
EeMG03De=@1RHV809BDU04I6AP1@D500EEEE05QHF01BDU80Kfm_04Q8B01?Cdl0HV9R03Ti>@1:BTX0
CDe=05EEE@0m?Cd0MGEe04I6AP1NGUh0Lg=c04E5A@1^KVh0ADE5075aL@18B4P0?clo07QhN00n?Sh0
AdM705mOG`1eMGD0MgMg051@D01DE5@0FEUI061PH01ADE40Hf=S04E5A@1kNg/0Cdm?03Xj>P29RHT0
P820069RHP2ATI40JVYZ09ZJVP29RHT0MgMg06UYJ@0e=CD0FUYJ06m_K`1BDU80K6a/0451@@1LG5`0
>3Ph051@D00J6QX0NWYj04Y:BP1SHf<0JVYZ071`L01:BTX0@D5106IVIP1@D5005ADE06i^KP1<C4`0
BTY:0<[:bP1nOWh0@d=306a/K018B4P0?3`l02LW9`26QXH0Lg=c0492@P2EUID0CTi>030`<01;Bd/0
B4Q8034a<@1WIfL0EeMG06EUI@1MGEd0<30`05IFEP0i>CT0M7Ad06=SH`28R8P0F5QH06IVIP1mOGd0
?Cdm04m?C`1BDU80?Shn075aL@1VIVH0De=C07YjNP1EEED0MgMg05UIF@1JFUX0P82005iNGP1RHV80
:RXZ075aL@0m?Cd0IVIV04m?C`1JFUX0Q8B402h^;P1/K6`0FUYJ02DU9@18B4P0CTi>01dM7@1FEUH0
Cdm?07=cL`1@D500KFe]05QHF01XJ6P0GemO0410@01EEED0I6AT06MWI`22PX80UIFE04M7A`1/K6`0
QXJ60410@01nOWh0IVIV04];B`1^KVh0?Cdm05ADE017AdL0B4Q805]KF`1GEeL0CDe=07AdM02JVYX0
Zj^[06ATI02?Shl0MGEe08N7Q`1lO7`0DU9B05MGE`12@T80MGEe0<W9b@1[Jf/0IfMW07AdM01GEeL0
FUYJ04a<C01@D500KVi^0;Ng]`2EUID0VIVI0;Fe]@2YZJT0b<S80:j^[P1fMWH0WIfM07UiN@3Ph>00
bl_;059BDP1UIFD0?Shn04Y:BP16ATH0CDe=06a/K00j>SX0P820061PH011@D40DE5A06][J`1kNg/0
CDe=05IFEP2<S8`0RHV90_ooool0000B06YZJP1cLg<0`/;205aLG01CDe<0Lg=c06=SH`25QHD0alO7
034a<@16ATH0VYZJ08j>SP2;Rh/0W9bL02XZ:P0f=SH0BTY:0P1lO7`0l02HV9P0=3@d0410@011@D40
A4A406i^KP24Q8@0Y:BT03<c<`0/;2`0EEEE09VIV@1cLg<0JVYZ04M7A`0d=3@0BDU9059BDP1>CTh0
@41006][J`0a<C40820P096AT@2HV9P0=SHf03dm?@1`L700<30`02HV9P1`L700VYZJ03Xj>P1[Jf/0
CDe=03De=@16ATH0Vi^K04e=C@0c<c<0Cdm?02`/;010@400LG5a06EUI@0Y:BT0>SXj03dm?@0d=3@0
K6a/08j>SP0a<C406QXJ03/k>`0h>3P0>SXj09FEU@3AdM40=3@d028R8P1EEED0AdM704I6AP2XZ:P0
alO7024Q8@0I6AT0FEUI08>3P`1UIFD0KVi^05]KF`0Y:BT0?Cdm06YZJP1hN7P0PH610:^[Z`0a<C40
;Bd]03lo?`1`L700G5aL0:JVYP2_[jl0CTi>02PX:012@T80NWYj06][J`2RXZ80PX:2020P8014A4@0
Cdm?09RHV01UIFD0_;bl07=cL`0S8b<0=3@d05]KF`1XJ6P0CTi>06i^KP0^;Rh0CTi>04I6AP1bLW80
SXj>09bLW032`/80=cLg04i>CP1`L700W9bL069RHP2KVi/0b/[:0410@01;Bd/0Jf][0:VYZ@1gMgL0
VYZJ0861P@0o?cl0Kfm_0;bl_02e]KD0JFUY0<S8b01]KFd0BDU904=3@`2BTY80SXj>07YjNP1_Kfl0
>CTi06ATI02QXJ40GEeM05mOG`2?Shl0>3Ph04i>CP1LG5`0Rh^;05=CD`30`<00OWin03`l?01SHf<0
`/;206IVIP13@d<0J6QX05UIF@0j>SX0K6a/0:>SX`0];Bd0=cLg079bLP1ADE40BDU909^KV`2b/[80
;Rh^03dm?@1]KFd0EEEE059BDP2MWId0Shn?03<c<`1OGel0PH6106e]K@2g]kL0W9bL038b<P0m?Cd0
B4Q807MgM`1VIVH0]KFe0;Jf]P16ATH0Bd];07QhN01_Kfl0O7al0;Fe]@1OGel0;2`/055AD@1UIFD0
Hf=S0;Zj^P2FUYH0<C4a06e]K@2RXZ80Fe]K0;Bd]02SXj<0=cLg04Y:BP1gMgL0KVi^09:BTP23Ph<0
:RXZ04U9B@20P800W9bL071`L030`<00DU9B03Lg=`1OGel0]kNg05=CD`2/[:`0JFUY04U9B@2QXJ40
`<3007UiN@1aLG40EeMG03dm?@1LG5`0PX:205ADE02>SXh0W9bL030`<080C4a<0780VYZJ06ATI02E
UID0[Jf]034a<@1;Bd/0Kfm_08n?S`1GEeL0P82005YJFP0^;Rh0>CTi07emO@2PX:00BTY:07QhN01/
K6`09BDU04Q8B01mOGd0SXj>03dm?@1[Jf/0@41003Lg=`1EEED0SXj>0:ZZZP15ADD0G5aL04];B`1A
DE40Jf][09:BTP1;Bd/0=3@d06UYJ@0k>c/0D51@071`L01nOWh0;Rh^02XZ:P1LG5`0GemO05iNGP21
PH40Vi^K0492@P0Q8B40@d=306i^KP1DE5@0C4a<08^;R`2ATI40G5aL04M7A`2BTY80O7al06m_K`1b
LW80De=C05aLG01^KVh0K6a/04Y:BP1JFUX0EEEE05aLG014A4@0GUiN07=cL`1dM7@0MGEe07=cL`2@
T900M7Ad04Y:BP1MGEd0?Shn059BDP0o?cl0G5aL04U9B@1MGEd0=3@d04e=C@1RHV80LW9b06QXJ01e
MGD0EEEE07moO`1HF5P0S8b<06=SH`1EEED0TI6A04Y:BP13@d<09BDU02PX:01BDU80Fe]K065QH@1M
GEd0@T9207]kN`0c<c<0@T9205EEE@24Q8@204U9B@1Q08N7Q`0T92@0@41006UYJ@14A4@0EUIF03Ti
>@0U9BD0E5AD03hn?P1cLg<0<C4a02PX:014A4@0>c/k04=3@`0c<c<0EEEE05MGE`1QHF40<30`038b
<P1IFET0L71`08B4Q00m?Cd0=cLg07YjNP1<C4`0HF5Q04m?C`0U9BD0D51@06EUI@35aLD0M7Ad0451
@@1>CTh0ADE504U9B@1<C4`0Bd];04U9B@0a<C40ATI604A4A01:BTX0<c<c06IVIP0[:b/0D51@04U9
B@1^KVh0GemO04A4A01WIfL0H61P051@D01]KFd0<c<c061PH018B4P0G5aL03Ti>@1gMgL0>SXj051@
D01`L700CTi>07alO010@400J6QX04Q8B01:BTX0Q8B403@d=01EEED0LG5a05YJFP1cLg<0P82005aL
G01>CTh0=SHf03hn?P0f=SH09RHV0:BTY01/K6`0?clo07inOP2NWYh0K6a/09jNWP1;Bd/0Z:RX0;no
_`0207YjNP1e05mOG`1UIFD0FUYJ06=SH`1[Jf/0>3Ph05ADE019BDT0Hf=S02@T902=SHd0G5aL061P
H01HF5P0FUYJ05=CD`0k>c/0AdM704];B`0Y:BT0WYjN06IVIP1NGUh0d];B08J6QP0f=SH0IVIV06][
J`21PH40>CTi09>CT`1iNGT0ATI6059BDP0i>CT0=cLg05=CD`1?Cdl0BTY:07EeM@16ATH0Ogmo061P
H00l?3`0DU9B02DU9@1aLG40B4Q808R8R01=CDd0Fe]K06QXJ00f=SH0HV9R05iNGP16ATH0MGEe07Mg
M`1@D500LW9b04Y:BP1hN7P0KFe]04E5A@1=CDd0D51@06UYJ@0/;2`0DU9B03lo?`1KFe/0O7al07If
MP2?Shl0Bd];06i^KP1OGel0=SHf04Y:BP1@D500;Rh^051@D00o?cl0Bd];051@D01WIfL0A4A404e=
C@1GEeL0?Cdm04E5A@1OGel0F5QH05aLG01HF5P0>SXj06IVIP27QhL0@d=3069RHP1VIVH0E5AD07Qh
N016ATH0M7Ad059BDP0i>CT0Fe]K069RHP1PH600KFe]065QH@1NGUh0DE5A079bLP1HF5P0FUYJ0080
Cdm?02X0Fe]K06=SH`1KFe/0Ph>305eMG@1NGUh0Ogmo06=SH`2ATI40K6a/05=CD`1LG5`0E5AD05QH
F02<S8`0Z:RX06EUI@1@D500IFEU05QHF01kNg/0@D5107alO02][Jd0CTi>06YZJP13@d<0C4a<05AD
E01@D500LG5a0410@02<S8`0I6AT0410@01ADE40LW9b09ZJVP1PH600EUIF08F5Q@1mOGd2ooooo`00
05X0WYjN05QHF01KFe/0XJ6Q06][J`1eMGD0@T9204E5A@28R8P0W9bL07EeM@1EEED0:BTY05aLG027
QhL0IFEU03hn?P1XJ6P0D51@03/k>`25QHD0/;2`03/k>`0n?Sh0@d=304Y:BP1GEeL0WYjN065QH@0_
;bl0Cdm?061PH01XJ6P0cLg=09VIV@0X:2P0<30`051@D00g=cL0MWIf0<_;b`1WIfL051@D03lo?`22
PX80A4A407UiN@3>c/h0?Shn02/[:`1FEUH0Y:BT04M7A`2h^;P0Shn?02h^;P0l?3`0K6a/061PH02?
Shl0Q8B403Hf=P0R8R80J6QX065QH@0f=SH0UYJF079bLP0C4a<0=CDe05mOG`1VIVH0E5AD09jNWP14
A4@09BDU03De=@1/K6`0OGem04Y:BP1hN7P0BDU901lO7`1?Cdl0UiNG065QH@1<C4`0UIFE038b<P0[
:b/206i^KP0k03lo?`1PH600Y:BT03/k>`1FEUH0T92@08:2PP1FEUH0PX:2051@D00i>CT0A4A406UY
J@1TI6@0Bd];09FEU@15ADD0?clo03/k>`1`L700@d=303lo?`1_Kfl0?Shn03De=@1@D500Lg=c03De
=@12@T80CDe=030`<01cLg<0YjNW04m?C`0X:2P0IfMW06][J`0T92@0Cdm?09ZJVP15ADD0>SXj05MG
E`1;Bd/0A4A405QHF02VYZH0EeMG03dm?@1UIFD0CDe=051@D02VYZH0^k^k04Q8B014A4@0FUYJ06UY
J@1WIfL00P2OWil05P0l?3`0F5QH04A4A011@D40UiNG0:^[Z`0c<c<0EUIF07EeM@1DE5@0Y:BT0<c<
c018B4P0D51@071`L02CTi<0K6a/0:j^[P2LW9`0<c<c04i>CP1OGel2096AT@0J0:VYZ@1:BTX0ADE5
055AD@1ZJVX0GUiN06m_K`2^[Zh0>c/k04U9B@1MGEd0MgMg07QhN028R8P0W9bL03lo?`1GEeL0JFUY
09RHV01UIFD0/[:b0:>SX`13@d<0De=C09RHV026QXH208>3P`1204e=C@0l?3`0H61P09RHV01iNGT0
GUiN07]kN`0J6QX0AdM70:NWY`2@T900De=C0;jn_P0i>CT0>3Ph05IFEP2PX:00JVYZ08j>SP1FEUH0
@41006YZJP3:b/X0S8b<055AD@22PX80;Rh^06ATI02m_Kd0VIVI04Q8B01iNGT0>c/k05=CD`2LW9`0
S8b<03Lg=`1OGel0B4Q805MGE`2?Shl0MgMg03Ti>@1VIVH0UYJF04Y:BP2QXJ40WYjN04M7A`1IFET0
HF5Q04];B`1VIVH0/K6a05QHF019BDT0NGUi0::RXP1_Kfl0TI6A0<o?c`17AdL0B4Q806EUI@1DE5@0
Fe]K0P2HV9P0EP0_;bl0@D5105IFEP1QHF40FUYJ08b<S02;Rh/0:RXZ04M7A`1aLG40RHV90:2PX035
aLD0H61P03Xj>P1QHF40FUYJ05mOG`28R8P0_kno03Ti>@1@D500Q8B409jNWP1eMGD0N7Qh0<S8b00g
=cL0?Cdm05=CD`23Ph<0E5AD07UiN@2g]kL0E5AD03Ph>01KFe/0N7Qh05=CD`1HF5P0SHf=07IfMP0M
7Ad0;Bd]03`l?01aLG40A4A404Q8B01kNg/0De=C05IFEP28R8P0C4a<05MGE`2IVIT0BDU906EUI@1X
J6P0DU9B06EUI@16ATH0HF5Q05IFEP1RHV80GemO04E5A@1MGEd0KVi^05=CD`14A4@0<30`05EEE@16
ATH0>SXj03dm?@1SHf<0BTY:03Xj>P1QHF40Hf=S0861P@1PH600?Shn05eMG@1VIVH0IfMW0P1_Kfl0
M01kNg/0ADE505QHF012@T80:2PX04Q8B01XJ6P0Ng]k04a<C014A4@0De=C03lo?`1EEED0NGUi06a/
K01=CDd0DE5A07emO@0n?Sh0AdM7061PH01>CTh0GUiN0451@@0b<S80H61P05ADE01^KVh0?clo04M7
A`1KFe/0A4A407=cL`1JFUX0J6QX05aLG02QXJ40ADE504m?C`1gMgL0I6AT0:FUY@1LG5`0ATI605UI
F@10@400Fe]K061PH011@D40GemO07YjNP3Fe]H0UIFE051@D01[Jf/0F5QH06EUI@1YJFT0GemO06][
J`13@d<0IVIV07QhN01^KVh0=SHf06ATI00^;Rh0MgMg05IFEP15ADD0DE5A04Y:BP1MGEd0@41004a<
C01ADE40?Cdm05mOG`1FEUH0HF5Q02`/;00n?Sh0?3`l07IfMP1kNg/0H61P07]kN`1JFUX0N7Qh05IF
EP1IFET0SXj>03Lg=`14A4@0Fe]K06EUI@1NGUh0IVIV061PH01LG5`0@T9204Q8B01@D500;2`/0:VY
Z@1eMGD071`L06QXJ01VIVH0L71`0:NWY`1]KFd0_[jn09ZJVP25QHD0V9RH0P1EEED0101HF5P0Lg=c
096AT@0n?Sh203Hf=P1C05QHF00[:b/0MGEe04];B`1CDe<0IFEU06a/K01dM7@0DE5A05eMG@1HF5P0
AdM70861P@2CTi<0NGUi0?Win@2e]KD0BTY:06EUI@1@D500V9RH0492@P1lO7`0MgMg05iNGP1PH600
MGEe05QHF01EEED0EUIF04=3@`1?Cdl0D51@0::RXP1kNg/0DE5A05MGE`0^;Rh0GUiN034a<@3Bd]80
EUIF05=CD`1VIVH0>SXj03lo?`1IFET0KVi^07EeM@1GEeL0MWIf0:JVYP1RHV80Ogmo06m_K`1@D500
G5aL06QXJ01QHF40BDU904];B`13@d<0GEeM07AdM01VIVH0T92@03Ph>02JVYX0JFUY01/K6`1?Cdl0
DE5A01hN7P1:BTX0B4Q805=CD`18B4P0KVi^04U9B@17AdL0IVIV04a<C01BDU800P1ZJVX00`1[Jf/0
OGem06i^KP0209BDU00l04a<C01UIFD0HF5Q06QXJ02GUiL0<S8b08n?S`1JFUX0HV9R06i^KP1IFET0
DE5A07MgM`1lO7`0WIfM06m_K`2ATI40ADE505MGE`1:BTX0Cdm?05YJFP1LG5`0IfMW09bLW010@400
IVIV08J6QP1UIFD0UIFE07MgM`1DE5@0N7Qh07alO02KVi/0R8R80<;2`P1gMgL0OGem06EUI@1MGEd0
O7al06i^KP2TY:@0TI6A03Xj>P1iNGT0ATI604Y:BP1BDU80E5AD06][J`0Z:RX0PX:2055AD@15ADD0
IFEU07QhN020P800CDe=0P1gMgL1092@T07ooooo0Oooool0000B0;Rh^01EEED0G5aL07YjNP1kNg/0
_[jn04E5A@19BDT0De=C06a/K034a<@0ZJVY03Ph>00m?Cd0@d=307IfMP27QhL0YZJV0P0n?Sh0K@1C
De<0WinO08:2PP3?cll0QhN703@d=01ADE40Fe]K0;6a/@1WIfL0ZZZZ03dm?@0n?Sh0GEeM09jNWP1j
NWX0J6QX0:f][@0P8200<30`07QhN02b/[80CTi>06=SH`1dM7@09BDU02h^;P1mOGd0SHf=03`l?01X
J6P0=cLg01`L7013@d<0SHf=06][J`1TI6@0RXZ:024Q8@1FEUH0ZZZZ09jNWP1>CTh0MGEe03hn?P0l
?3`0Fe]K09BDU015ADD0@T9204Q8B00m?Cd0=SHf06UYJ@25QHD0;Rh^05MGE`13@d<0C4a<03lo?`2H
V9P0GUiN03Lg=`1MGEd0FEUI04U9B@17AdL0^KVi08>3P`0a<C40BTY:04M7A`0e=CD0LG5a0:b/[00^
;Rh0<S8b06EUI@1EEED0GEeM092@T02VYZH0;Bd]03dm?@1>CTh0Fe]K06IVIP2d];@0T92@03@d=017
AdL0CTi>04a<C01YJFT0/k>c04M7A`0e=CD0Fe]K06=SH`19BDT0MgMg06QXJ00M7Ad0:b/[07AdM01j
NWX0D51@0;:b/P2KVi/00P0X:2P0A@1;Bd/0E5AD065QH@2i^KT0NWYj038b<P1PH600QHF509BDU01k
Ng/0/;2`06][J`14A4@0GEeM08^;R`1gMgL0HV9R09>CT`0/;2`0@d=307emO@1aLG40I6AT09nOW`1d
M7@0?3`l055AD@2c/k<0Ogmo0:BTY01DE5@0@D5105=CD`2@T900Ti>C05aLG027QhL0=cLg05mOG`1^
KVh0W9bL07moO`27QhL0S8b<02`/;00k>c/0[Jf]0:^[Z`18B4P0J6QX06ATI00`<300Cdm?0::RXP21
PH40<C4a06=SH`0l?3`0A4A4069RHP2^[Zh0QXJ603dm?@24Q8@0CDe=03Xj>P1/K6`0V9RH03`l?002
04a<C01A03<c<`2=SHd0_;bl04=3@`0Y:BT0KFe]07emO@12@T80Ti>C0<c<c018B4P0;bl_07]kN`27
QhL0GEeM0<O7a`27QhL08b<S069RHP27QhL0Lg=c09jNWP1mOGd0;2`/03hn?P1SHf<0K6a/09VIV@3?
cll0;bl_038b<P1MGEd0U9BD09ZJVP39bLT0@D5102l_;`1HF5P0Rh^;06m_K`2k^k/0QXJ60451@@1V
IVH0NGUi051@D02IVIT0^KVi038b<P0c<c<0O7al079bLP2QXJ40NWYj030`<01EEED0IfMW0:RXZ01S
Hf<0Y:BT071`L00n?Sh0LW9b07MgM`21PH40LG5a0<k>cP18B4P0ATI609>CT`2k^k/0EEEE065QH@2c
/k<0@41004Q8B01PH600Z:RX08:2PP1aLG40`l?30080?3`l06T0Ti>C0:>SX`1<C4`0SXj>0:VYZ@0o
?cl0?Cdm06IVIP1bLW80<30`05UIF@1nOWh0B4Q806ATI02OWil0RHV903Xj>P1SHf<0N7Qh04M7A`0m
?Cd0T92@0:BTY00l?3`0F5QH06][J`12@T80C4a<07IfMP33`l<0BTY:04m?C`26QXH0E5AD04=3@`19
BDT0O7al05mOG`1nOWh0MGEe04a<C01@D500Q8B404a<C01DE5@0HF5Q05EEE@1XJ6P0EUIF07MgM`1R
HV80JVYZ09:BTP1/K6`0MWIf065QH@1<C4`0DE5A02PX:01>CTh0;Rh^03dm?@0Y:BT0B4Q801`L7011
@D40C4a<05UIF@1HF5P0NWYj04e=C@1iNGT0BTY:07MgM`1HF5P0DE5A06a/K01<C4`0FUYJ03/k>`0n
?Sh0Cdm?04I6AP1DE5@0DE5A05MGE`1UIFD0@41003hn?P19BDT0Kfm_0492@P0g=cL0D51@03lo?`1=
CDd0E5AD03/k>`1GEeL0EUIF03<c<`1UIFD0AdM707UiN@16ATH00`1=CDd0601LG5`0DU9B092@T01h
N7P0[jn_03lo?`19BDT0QXJ608B4Q02FUYH0Kfm_06IVIP1SHf<0=CDe05=CD`1iNGT0EEEE05eMG@1G
EeL0XJ6Q08J6QP1GEeL0EUIF059BDP80KFe]0100>CTi05EEE@0j>SX0IFEU04e=C@1OGel0ADE5079b
LP15ADD0A4A404];B`1<C4`0D51@04a<C01CDe<0EeMG0P1OGel0AP13@d<0JVYZ04E5A@1BDU80@T92
07inOP1NGUh0CTi>06=SH`1BDU80MWIf06ATI02:RXX0E5AD05iNGP1/K6`0=3@d04];B`1KFe/0NGUi
07IfMP1[Jf/0LW9b08f=S@1bLW80SXj>069RHP13@d<0S8b<075aL@0d=3@0AdM705IFEP1TI6@0Shn?
055AD@2<S8`0K6a/05EEE@1^KVh0?Cdm05MGE`1cLg<0De=C05UIF@11@D40DU9B038b<P1CDe<061PH
08j>SP1>CTh0F5QH08>3P`2FUYH0NGUi04Q8B017AdL0HF5Q055AD@2g]kL0OGem08F5Q@3Fe]H0Xj>S
055AD@1YJFT0CDe=09VIV@14A4@207emO@210492@P1_Kfl0Cdm?03Hf=P1>CTh0D51@04U9B@22PX80
CTi>08B4Q01JFUX0=3@d03`l?013@d<0Q8B403dm?@1WIfL0?3`l061PH01bLW80De=C059BDP1MGEd0
Bd];06EUI@1<C4`0F5QH06MWI`10@400H61P06=SH`1GEeL0NGUi069RHP1gMgL0A4A4069RHP1FEUH0
OGem06m_K`1[Jf/0V9RH04Q8B01JFUX0D51@04M7A`1iNGT0KFe]05=CD`1dM7@0H61P059BDP1GEeL0
IVIV06=SH`1;Bd/0GEeM03`l?01=CDd0DU9B05QHF01`L700Lg=c04U9B@1QHF40KFe]03/k>`1/K6`0
GUiN04e=C@1nOWh0E5AD08V9R@1@D500DE5A04I6AP1CDe<0EeMG07MgM`1DE5@0SHf=061PH02DU9@0
C4a<055AD@0K6a/0BTY:06=SH`1NGUh0IVIV092@T01IFET0O7al09RHV029RHT0TI6A07EeM@1CDe<0
O7al08f=S@23Ph<0PH610;^k^`1eMGD0QHF504i>CP1`L700W9bL05YJFP2/[:`0WYjN051@D02NWYh0
G5aL04M7A`1@D500Jf][096AT@1NGUh0LG5a05mOG`1EEED0Cdm?061PH023Ph<0GUiN06m_K`2ATI40
QHF500;ooooo0000=P2IVIT0Rh^;0:^[Z`1>CTh0H61P07alO01XJ6P0BDU90820P00Z:RX0HV9R0:j^
[P22PX80FUYJ08:2PP0/;2`0<30`09BDU02b/[80EEEE0820P01@D500BTY:06MWI`2YZJT0DU9B03Ti
>@1dM7@0>SXj02l_;`1jNWX0Zj^[02/[:`0o?cl0MWIf065QH@1KFe/0WinO03/k>`0O7al0>SXj07If
MP1WIfL0UIFE07moO`0a<C40:b/[04m?C`1YJFT0CTi>09VIV@1aLG408R8R02d];@80FEUI0<l0Hf=S
0;2`/00Y:BT07AdM02h^;P1bLW80IfMW08j>SP0i>CT09BDU04a<C01VIVH0>3Ph07EeM@2QXJ40820P
038b<P15ADD0J6QX04a<C02MWId0WYjN01hN7P1<C4`0F5QH06e]K@1<C4`0X:2P07EeM@0/;2`0>SXj
04E5A@1jNWX0D51@0:VYZ@1MGEd0<C4a02LW9`1dM7@0SHf=04i>CP1nOWh0<c<c03Ti>@1IFET0Ti>C
09:BTP23Ph<0UiNG034a<@0j>SX0AdM708^;R`1^KVh0HF5Q05eMG@0T92@0B4Q804e=C@1nOWh0EeMG
08>3P`1UIFD0;bl_06ATI02ATI40ADE506ATI01WIfL0<S8b03dm?@1WIfL0ZZZZ04];B`0Z:RX04A4A
01XJ6P0e=CD0GemO09JFUP0k>c/0IfMW05UIF@1>CTh0G5aL092@T02VYZH0B4Q806ATI02;Rh/0F5QH
07inOP3IfMT0WinO03De=@1/K6`0IfMW03`l?024Q8@0VYZJ03Ti>@10@400EUIF06QXJ02EUID0I6AT
02/[:`1MGEd0MWIf0820P01]KFd0VIVI05YJFP0k>c/0XZ:R09NGU`1VIVH0[Zj^0<30`00c<c<0?Shn
065QH@2JVYX0F5QH0:2PX02=SHd0<c<c05IFEP2FUYH0S8b<05eMG@2YZJT0>c/k04M7A`12@T80P820
0:6QX@1YJFT0_[jn03dm?@0c<c<0IFEU09VIV@1kNg/0Ogmo079bLP0o?cl0Cdm?08B4Q02=SHd0DU9B
0;Vi^@1VIVH0<30`04];B`2RXZ80TI6A06UYJ@28R8P0AdM70410@026QXH0_[jn06m_K`1XJ6P0DU9B
03Lg=`1VIVH0WinO06EUI@1TI6@0PH6103Hf=P1:BTX0^KVi096AT@1CDe<0BTY:02PX:01IFET0Ph>3
08V9R@1PH600VIVI059BDP0`<300MWIf09>CT`11@D40KVi^04E5A@0c<c<0J6QX0;>c/`1EEED0G5aL
04];B`0b<S80UYJF0<30`01EEED0BDU905YJFP1=CDd0EeMG0:j^[P2ZZZX00P0o?cl0D01WIfL0A4A4
065QH@2/[:`0GEeM02d];@1?Cdl0L71`075aL@1iNGT0_[jn05iNGP0i>CT0EEEE055AD@1YJFT0IVIV
0=;BdP1IFET09RHV05MGE`1/K6`0BTY:0:>SX`3Fe]H0@d=303@d=01HF5P0IFEU071`L02PX:00T92@
030`<00/;2`0Hf=S08>3P`1ZJVX0SHf=09bLW016ATH0?3`l04A4A026QXH0N7Qh07]kN`2QXJ40:BTY
0410@02DU9@0TY:B06QXJ023Ph<0[Jf]05EEE@14A4@0IFEU08:2PP1ZJVX0L71`06QXJ01;Bd/0C4a<
071`L01[Jf/0GUiN092@T01kNg/0FUYJ0492@P1MGEd0VYZJ06][J`1KFe/0AdM7061PH01EEED0CDe=
05aLG01:BTX0IVIV0P1FEUH0E01ADE40E5AD02TY:@0n?Sh0Cdm?055AD@1JFUX0GEeM0410@01JFUX0
Cdm?07]kN`20P800Kfm_08j>SP0n?Sh0Cdm?03@d=00V9RH0B4Q804];B`1LG5`0BTY:04I6AP2>SXh0
C4a<05=CD`1LG5`0S8b<03Xj>P1<C4`0TI6A03`l?00o?cl0H61P05IFEP1IFET0EEEE0410@01DE5@0
Bd];06IVIP0j>SX0F5QH04m?C`14A4@0JFUY061PH01SHf<0D51@079bLP1CDe<0?clo05UIF@1OGel0
K6a/061PH01?Cdl0Q8B404=3@`1KFe/0H61P04I6AP1OGel0KFe]0;Zj^P25QHD0FEUI05YJFP1CDe<0
Fe]K06ATI019BDT0EeMG03Xj>P1CDe<0EUIF05EEE@0Q8B40KFe]03De=@1MGEd0B4Q804U9B@80Bd];
0<d0De=C04m?C`0^;Rh0DE5A02d];@1=CDd0AdM705mOG`18B4P0SHf=04M7A`1JFUX0L71`05]KF`2I
VIT0E5AD06][J`1GEeL0De=C06a/K00l?3`0J6QX06IVIP0l?3`0K6a/09ZJVP1_Kfl0I6AT08B4Q023
Ph<0Q8B405iNGP2IVIT0PX:20492@P1KFe/0Rh^;06e]K@2?Shl0ATI60<S8b02JVYX0G5aL05EEE@1Q
HF40ATI60492@P1FEUH0GemO03De=@0o?cl0>SXj05]KF`0`<300HV9R06EUI@1NGUh0IfMW04Y:BP1D
E5@0De=C07=cL`1RHV80?clo07moO`22PX80MGEe0=?Cd`2:RXX0Fe]K0861P@19BDT0Jf][03lo?`2V
YZH0JVYZ03lo?`1eMGD0CDe=034a<@1CDe<0ADE5034a<@1QHF40Bd];07QhN01;Bd/0@T9204=3@`0O
7al0EUIF03/k>`2?Shl0DU9B05iNGP1ZJVX0<S8b07AdM01_Kfl0Fe]K06m_K`0/;2`0@d=306IVIP0l
?3`0Lg=c06IVIP0c<c<0DE5A04I6AP1GEeL0BDU90861P@1MGEd0JFUY06EUI@1SHf<0OGem05eMG@2Q
XJ40MGEe02h^;P1DE5@0A4A402/[:`1ADE40Cdm?06a/K01GEeL0L71`05QHF01:BTX0Fe]K05IFEP1=
CDd0GUiN05EEE@1IFET0Ti>C04i>CP1ZJVX0Jf][01dM7@1GEeL0EEEE051@D01jNWX0G5aL09jNWP1L
G5`0EEEE05eMG@1KFe/0>c/k05EEE@1lO7`0QXJ606UYJ@2<S8`0FUYJ05QHF00n?Sh0E5AD05]KF`0c
<c<0HV9R07emO@13@d<0M7Ad09RHV01NGUh0UiNG08R8R01BDU80F5QH07YjNP2[Zj/0YZJV0;2`/01H
F5P0P82007emO@2<S8`0/K6a07emO@2[Zj/0OWin04E5A@1`L700EeMG06ATI01UIFD0H61P05iNGP18
B4P0QXJ605ADE013@d<0ATI6071`L01UIFD0I6AT07QhN01YJFT0S8b<00;ooooo0000P022PX80QHF5
0:ZZZP26QXH0ADE508V9R@1lO7`0YjNW09BDU00f=SH0<30`06ATI01eMGD0QhN70<[:bP0a<C40@d=3
05MGE`1nOWh0HV9R0<?3``25QHD071`L065QH@2PX:00OGem075aL@35aLD0=CDe04e=C@1HF5P0ZZZZ
08V9R@1ZJVX0Jf][03De=@1LG5`0EUIF07inOP1lO7`0TI6A05EEE@0];Bd0MgMg07=cL`19BDT0GemO
08B4Q00`<300;bl_06=SH`1RHV80DU9B08:2PP1LG5`08b<S0451@@2RXZ80S8b<06EUI@1VIVH06ATI
03dm?@1HF5P0E5AD04i>CP1UIFD0Jf][01dM7@18B4P0Ogmo07=cL`1QHF40NGUi04Q8B00f=SH0E5AD
0:^[Z`1BDU80=CDe05YJFP0i>CT0:2PX06a/K02h^;P0@T920410@015ADD0;Bd]03@d=01/K6`0VIVI
030`<00j>SX0AdM7069RHP1bLW80RXZ:04U9B@0^;Rh0@T9204U9B@1ZJVX0Ogmo09JFUP15ADD0<S8b
04e=C@17AdL0I6AT09fMW@2;Rh/0:RXZ04];B`1IFET0Cdm?061PH02j^[X0RXZ:02`/;012@T80HV9R
0410@01aLG40^KVi03dm?@0a<C40Cdm?0P1aLG40Q@0j>SX071`L00l?3`0[:b/0DE5A065QH@1VIVH0
XJ6Q0:2PX00d=3@0JVYZ07YjNP1eMGD0MWIf0:>SX`2j^[X0=CDe05=CD`2CTi<0_Kfm06YZJP2h^;P0
JVYZ03Ph>01>CTh0]KFe096AT@26QXH0OGem03Ph>01/K6`0XJ6Q07IfMP2=SHd0Y:BT03lo?`1PH600
GUiN08j>SP1VIVH0];Bd09JFUP10@400@T9208V9R@25QHD0Jf][0;Bd]01kNg/0?clo04U9B@2FUYH0
F5QH0492@P2HV9P0D51@04M7A`1dM7@0Vi^K04U9B@1HF5P0GUiN03/k>`18B4P0Ti>C07UiN@0d=3@0
F5QH05YJFP11@D40V9RH07UiN@0o?cl0De=C07inOP1=CDd0CTi>08^;R`2PX:00BTY:05QHF01QHF40
Jf][06YZJP2VYZH0DE5A02`/;01@D500I6AT07QhN02MWId0Jf][03@d=01<C4`0Fe]K06][J`2:RXX0
^[Zj04a<C00[:b/0GEeM05]KF`1gMgL0SHf=0492@P0n?Sh0FEUI07]kN`2;Rh/0alO705iNGP0o?cl0
Cdm?08B4Q01YJFT0a/K607]kN`0I6AT0FEUI09jNWP1eMGD0UiNG07moO`1?Cdl0ATI609>CT`2:RXX0
Ogmo09fMW@0o?cl0<30`096AT@2XZ:P00P2IVIT0X`2SXj<0<c<c05ADE02?Shl0Ogmo04a<C020P800
De=C02`/;017AdL0TI6A09NGU`28R8P0^;Rh09bLW00Y:BT0@D510;Bd]02k^k/0HV9R09JFUP1HF5P0
?clo04a<C01bLW80UiNG04I6AP1dM7@0?3`l02LW9`1<C4`0N7Qh05ADE01;Bd/0FEUI03Ph>00S8b<0
=3@d07QhN01@D500CDe=06MWI`0h>3P0>c/k07]kN`2<S8`0KFe]034a<@17AdL0C4a<028R8P10@400
^[Zj07]kN`11@D40LG5a09jNWP1aLG40EUIF07QhN01[Jf/0JFUY07UiN@14A4@0@d=304];B`1ADE40
De=C0410@01EEED0BDU904Y:BP1@D500Cdm?079bLP21PH40KFe]04U9B@0e=CD0Kfm_0451@@0k>c/0
>CTi08B4Q00M7Ad0ADE506ATI01gMgL0Ph>306YZJP12@T80MWIf05iNGP1]KFd0CTi>03`l?01IFET0
IFEU07alO018B4P0=SHf04E5A@1EEED0IVIV04m?C`1:BTX0HF5Q055AD@1@D500JVYZ08>3P`1QHF40
JVYZ08j>SP0m?Cd0A4A4069RHP1TI6@0JVYZ05ADE00`<300JFUY04m?C`2ATI40@4100492@P1IFET0
D51@06YZJP1EEED0I6AT05]KF`2a/K40?Cdm0492@P29RHT0NWYj0:FUY@1PH600CTi>06][J`14A4@0
L71`065QH@18B4P0LG5a08Z:RP31`L40UiNG05=CD`1XJ6P0HF5Q06QXJ01iNGT0B4Q8065QH@0i>CT0
Lg=c08B4Q01aLG40=CDe08Z:RP0m?Cd00P1LG5`0H`17AdL0DE5A06=SH`1TI6@0GemO03Ph>01[Jf/0
>SXj05=CD`12@T80M7Ad04];B`1dM7@0C4a<05mOG`1bLW80EUIF08f=S@1UIFD0NWYj06][J`24Q8@0
Rh^;02l_;`17AdL0JFUY04];B`1GEeL0IfMW08>3P`1/K6`0Ng]k08:2PP2RXZ80EUIF0:BTY01oOgl0
;Rh^07moO`2FUYH0Kfm_0:2PX01_Kfl0UIFE09ZJVP1dM7@0IfMW0451@@14A4@0@d=305IFEP1RHV80
=3@d04M7A`0`<300C4a<014A4@23Ph<0DE5A06EUI@1kNg/0GemO05EEE@0i>CT0?Shn04e=C@0a<C40
SXj>06ATI01kNg/0gMgM08^;R`0l?3`0H61P03dm?@2ATI40820P04];B`0j>SX0GUiN096AT@1LG5`0
CDe=06][J`1ADE40=3@d07MgM`0h>3P0VIVI05eMG@1ADE40Fe]K02<S8`1EEED0:RXZ09ZJVP0j>SX0
IFEU07YjNP0204];B`0d059BDP1ZJVX0MWIf03/k>`1SHf<0SHf=04Q8B01QHF40Kfm_07IfMP25QHD0
E5AD08B4Q00Q8B40GemO04a<C02ATI40GUiN07=cL`23Ph<0>c/k04];B`11@D40;bl_092@T01FEUH0
6QXJ07MgM`1<C4`0EUIF059BDP1YJFT0BDU904E5A@1LG5`0>3Ph03lo?`1YJFT0IVIV04E5A@2@T900
DE5A09nOW`1oOgl0;bl_06YZJP1OGel0MgMg09VIV@10@400LG5a03`l?080K6a/00X0LW9b06YZJP1V
IVH0NWYj069RHP1ADE40JVYZ04a<C01JFUX0@D510P1BDU80:@0j>SX0Hf=S06m_K`0n?Sh0Hf=S07=c
L`1=CDd0Q8B405EEE@1WIfL0Ng]k08n?S`2YZJT0Zj^[0<;2`P1DE5@0Rh^;065QH@23Ph<0Y:BT05YJ
FP3Lg=`0clo?06m_K`2?Shl0ADE50451@@1?Cdl0MGEe09>CT`10@400L71`05IFEP1HF5P0CDe=06a/
K01fMWH0Hf=S04E5A@1mOGd0IVIV00;ooooo0000o`3@d=00FUYJ06YZJP2ZZZX0Lg=c09fMW@1;Bd/0
ATI60:ZZZP2@T900Kfm_06EUI@11@D40=SHf06EUI@2e]KD0?Shn08j>SP17AdL0>CTi04E5A@2MWId0
EeMG05]KF`1XJ6P0;bl_03lo?`1eMGD0KFe]04M7A`2BTY80>CTi05EEE@1TI6@0KFe]03/k>`1JFUX0
Q8B401lO7`10@400SXj>09JFUP0c<c<0A4A405iNGP0f=SH0FUYJ09bLW01>CTh09RHV04E5A@1`L700
@41009RHV02][Jd0;2`/028R8P1>CTh0GEeM09NGU`2CTi<0=3@d02DU9@1VIVH0EEEE059BDP2MWId0
MgMg01dM7@0O7al0DU9B05EEE@1MGEd0UYJF05EEE@0];Bd0;Rh^06YZJP1VIVH0Lg=c0::RXP18B4P0
>CTi0492@P1FEUH0KFe]07]kN`2NWYh09bLW04a<C01:BTX0WYjN07MgM`1nOWh0S8b<038b<P13@d<0
F5QH08:2PP1CDe<0Z:RX04];B`0T92@0AdM707QhN02SXj<0F5QH09bLW00k>c/071`L05=CD`2CTi<0
FUYJ07IfMP24Q8@0@D5103Ph>01`L700_kno06a/K01bLW80BTY:02/[:`0h>3P0EeMG0820P011@D40
_kno05IFEP0];Bd0;Rh^04M7A`1OGel0A4A4069RHP1cLg<0<S8b07MgM`2YZJT0Fe]K03Lg=`1jNWX0
GEeM05MGE`1mOGd0/;2`06a/K00n?Sh0GEeM03<c<`1CDe<0SXj>07emO@0h>3P0AdM705MGE`1FEUH0
MGEe09RHV00n?Sh0HF5Q03De=@1ZJVX0RXZ:0:RXZ01YJFT0>SXj059BDP1KFe/0IfMW0:>SX`2/[:`0
<S8b04a<C00j>SX0GUiN06MWI`2j^[X0QHF503dm?@1FEUH0De=C07inOP1MGEd0cLg=04I6AP0l?3`0
EUIF05EEE@1eMGD0`l?30;jn_P0l?3`0DE5A065QH@1HF5P0IFEU0;bl_02SXj<0:2PX04];B`2EUID0
Cdm?09NGU`33`l<0B4Q804I6AP1OGel0[:b/08j>SP2c/k<0VIVI02h^;P1CDe<0Lg=c09jNWP1QHF40
YZJV04e=C@10@400OWin0;bl_01[Jf/0]kNg04M7A`11@D40J6QX0:2PX037alL0J6QX09fMW@0^;Rh0
GemO0;Zj^P20P800KVi^06IVIP0h>3P0N7Qh0:RXZ02[Zj/0Jf][0;bl_00m?Cd0BDU90:JVYP33`l<0
CDe=08F5Q@1bLW80E5AD07AdM02][Jd0KVi^05mOG`00;P2=SHd0DE5A05aLG02`/;00QHF504i>CP1l
O7`0Xj>S059BDP1OGel0a<C407emO@1?Cdl0Ng]k059BDP0l?3`0MGEe08>3P`0f=SH0@D5105eMG@17
AdL0@41007YjNP2HV9P0:RXZ034a<@1ZJVX0MWIf04i>CP1oOgl0VYZJ038b<P1HF5P0JVYZ0861P@2:
RXX0Xj>S05iNGP0h>3P0De=C065QH@1CDe<0P8200:>SX`0f=SH203Lg=`10059BDP1CDe<0EEEE07em
O@1@D500820P03De=@1YJFT0SXj>05IFEP2?Shl0@T9203Lg=`0^;Rh0KFe]09^KV`0j>SX0JVYZ05QH
F018B4P0E5AD06UYJ@13@d<0AdM708R8R013@d<0C4a<06MWI`1VIVH0CDe=04I6AP1/K6`0KFe]06m_
K`1OGel0IfMW05YJFP14A4@0?3`l0492@P0_;bl0D51@03Ph>011@D40>3Ph04a<C00W9bL0<c<c04M7
A`13@d<0?3`l04m?C`0i>CT0EeMG03`l?01@D500Cdm?04a<C01ZJVX0@41004e=C@0b<S80ATI604M7
A`80D51@01D0FUYJ07EeM@1]KFd0<30`04E5A@1mOGd0HF5Q04];B`16ATH0H61P04U9B@1PH600Fe]K
03Lg=`1CDe<0IFEU04];B`1LG5`0CDe=061PH011@D400P1IFET0b018B4P0DU9B05mOG`2ATI40Q8B4
0;Vi^@14A4@0AdM708>3P`25QHD0X:2P07]kN`1RHV80QXJ603Ph>01YJFT0LW9b04e=C@24Q8@0LG5a
09:BTP1nOWh0E5AD05=CD`1IFET0QXJ606e]K@1DE5@0HV9R0492@P1^KVh0MWIf06EUI@0/;2`0VIVI
04e=C@1TI6@0CDe=04Y:BP1@D500JFUY05aLG01BDU80CDe=05]KF`0j>SX0D51@0492@P1KFe/0BDU9
08Z:RP1^KVh0RHV907UiN@1NGUh0Y:BT06m_K`2>SXh0L71`07IfMP2ATI40BTY:04m?C`28R8P0EUIF
07inOP25QHD0UYJF06UYJ@1MGEd0Shn?0=;BdP1dM7@0^k^k08f=S@0g=cL0IfMW07=cL`1JFUX0SXj>
03hn?P2FUYH0Rh^;05UIF@1TI6@0HF5Q04Q8B01GEeL0UIFE08f=S@12@T80Bd];04Q8B01PH600=CDe
08>3P`1_Kfl0E5AD07emO@1]KFd0@41003`l?01>CTh0D51@03<c<`2EUID0JFUY05eMG@2`/;00Hf=S
03lo?`1KFe/0BDU905aLG00];Bd0GemO05ADE01:BTX0IVIV05]KF`0k>c/0Bd];03@d=00n?Sh0Ng]k
05IFEP1IFET0Bd];03/k>`14A4@0=CDe07EeM@0k>c/0QHF505IFEP1]KFd0J6QX03/k>`1>CTh0C4a<
04m?C`1FEUH0<30`061PH01gMgL0?Shn05UIF@1LG5`0EUIF06][J`1ADE40@T9203dm?@1[Jf/0AdM7
05EEE@1>CTh0AdM704m?C`0b<S80FEUI04Y:BP0I6AT0CTi>03@d=00C4a<0BTY:03lo?`1HF5P0ATI6
05=CD`1OGel0C4a<05=CD`17AdL0@d=304Y:BP19BDT0Hf=S07moO`1BDU80EeMG04e=C@14A4@0S8b<
05ADE01<C4`0HF5Q04];B`1[Jf/0FEUI051@D01;Bd/0LW9b08F5Q@2IVIT0M7Ad09:BTP1oOgl0R8R8
0P1fMWH0801XJ6P0EUIF06UYJ@1KFe/0Ng]k07YjNP0Z:RX0PX:20:JVYP25QHD0[jn_0861P@27QhL0
LG5a0:BTY01gMgL0UIFE0;Jf]P1nOWh0/K6a08b<S01kNg/0SHf=07emO@2PX:00IVIV04I6AP2QXJ40
DU9B04Q8B017AdL0GUiN0P1PH6002P2<S8`0E5AD04=3@`1>CTh0Q8B407EeM@1JFUX0De=C065QH@1j
NWX2ooooo`0000<0/[:b061PH01ZJVX00P1PH600402`/;00FUYJ03/k>`1<C4`0Jf][09FEU@2LW9`0
>c/k034a<@13@d<0KFe]04Q8B02b/[80EeMG0451@@1FEUH205]KF`1n09JFUP2BTY80;2`/04Q8B01C
De<0HF5Q06i^KP3:b/X0G5aL02h^;P0m?Cd0JFUY04M7A`2TY:@0b<S802XZ:P11@D40DU9B061PH01J
FUX0Zj^[0:f][@0K6a/0?Cdm06i^KP2DU9@0K6a/092@T01aLG40<C4a03hn?P1fMWH0PX:208B4Q02?
Shl0<C4a02h^;P25QHD0Ti>C06=SH`1oOgl0AdM702@T901=CDd0Rh^;05UIF@1?Cdl0H61P028R8P0X
:2P0Bd];07=cL`18B4P0NGUi079bLP0C4a<0?3`l06e]K@1FEUH0;2`/05iNGP1VIVH0<30`0861P@2A
TI40HF5Q03Xj>P1FEUH0=CDe055AD@1OGel0TY:B05eMG@0^;Rh0CDe=03Ti>@18B4P0Ng]k0:f][@1:
BTX0B4Q80:n_[`1hN7P0I6AT0;Jf]P2:RXX0<C4a03Ph>01GEeL0CTi>07alO02e]KD0ATI603De=@16
ATH0KFe]05UIF@20P800RXZ:02XZ:P0m?Cd0ATI6051@D01;Bd/0`/;206i^KP0V9RH0@D51059BDP1U
IFD0GemO0;Jf]P1eMGD0@41004a<C01XJ6P0Kfm_05UIF@3;bl/0SHf=03@d=01]KFd0R8R806QXJ025
QHD0dM7A0P0l?3`0I@2@T900[jn_06EUI@2JVYX0Ng]k04M7A`1[Jf/0X:2P07=cL`2c/k<0NGUi02PX
:01lO7`0QHF50:b/[022PX80WIfM02@T9014A4@0X:2P0;Ng]`28R8P0ZZZZ065QH@0n?Sh0B4Q809jN
WP2c/k<0LG5a08R8R01MGEd07alO04i>CP2][Jd0Ph>305QHF02a/K40HF5Q03Ti>@1CDe<0`l?30:ZZ
ZP1CDe<0QXJ604=3@`0o?cl0FEUI0:^[Z`2ATI40N7Qh05]KF`0[:b/0Bd];06UYJ@1_Kfl0De=C08R8
R00l?3`0BTY:0:2PX02m_Kd0I6AT04a<C026QXH0>CTi04I6AP2i^KT0[Zj^03/k>`1HF5P0@T9205iN
GP29RHT0OWin04];B`1>CTh0Lg=c04i>CP2ATI40k>c/08B4Q00g=cL0GEeM06e]K@1bLW80Ogmo038b
<P0i>CT0NWYj061PH01XJ6P0iNGU079bLP0S8b<0Jf][0:RXZ01@D500T92@06QXJ00[:b/0A4A40080
KFe]09X0WYjN0;Zj^P19BDT0>SXj05QHF02FUYH0KFe]0<W9b@3:b/X0BDU904E5A@1SHf<0HF5Q09JF
UP3=cLd0BDU904I6AP1NGUh0MGEe05MGE`2JVYX0XZ:R0410@00j>SX0CTi>05QHF01ZJVX0LG5a0;Fe
]@0k>c/0?Cdm05YJFP2KVi/0Jf][09^KV`2HV9P0;Rh^05UIF@1aLG40MWIf07QhN02TY:@0XJ6Q04A4
A011@D40DU9B06][J`13@d<0HF5Q06=SH`0c<c<0@d=305=CD`1oOgl0>3Ph03Ti>@17AdL0=cLg05YJ
FP1dM7@0VIVI03@d=014A4@0Jf][04i>CP11@D40L71`08^;R`1PH600Fe]K09JFUP1MGEd0FUYJ09bL
W01@D500Cdm?06][J`1PH600JVYZ05UIF@1MGEd0K6a/071`L01aLG40MGEe07AdM01cLg<0EUIF05=C
D`0V9RH0F5QH034a<@1=CDd0>c/k06ATI00K6a/0C4a<06m_K`2<S8`0MWIf065QH@11@D40J6QX04e=
C@1hN7P0JFUY051@D029RHT0E5AD059BDP0R8R80;bl_0451@@0i>CT0D51@04=3@`0j>SX0JVYZ04A4
A01<C4`0Cdm?06EUI@0`<300Cdm?06YZJP0a<C40@d=306ATI01<C4`0EEEE05MGE`0m?Cd0DE5A0451
@@1HF5P0BTY:07YjNP1GEeL0B4Q805]KF`1FEUH0Cdm?04U9B@1WIfL0KVi^05iNGP1SHf<0JVYZ05MG
E`13@d<0BDU904M7A`0n?Sh0I6AT0P1GEeL0i01VIVH0Ogmo0:^[Z`1jNWX0FUYJ05QHF01;Bd/0EeMG
065QH@11@D40Bd];05UIF@1UIFD0F5QH059BDP1MGEd0QhN704a<C012@T80EUIF05aLG01GEeL0DE5A
05ADE01TI6@0Bd];05QHF01<C4`0FUYJ05UIF@1/K6`0M7Ad09:BTP17AdL0CTi>079bLP2ATI40/;2`
07alO02@T900UIFE09ZJVP26QXH0G5aL06QXJ02EUID0Ng]k08F5Q@22PX80P82007AdM020P800ZZZZ
0:>SX`1:BTX0KFe]07]kN`14A4@0UiNG0820P01mOGd0YjNW07YjNP35aLD0YJFU08f=S@2BTY80E5AD
06=SH`1UIFD0FUYJ06MWI`0o?cl0EUIF03hn?P1>CTh07QhN08j>SP1[Jf/0GUiN08F5Q@1^KVh0LG5a
04m?C`1ADE40HF5Q04A4A02EUID0IVIV08B4Q03<c<`0OWin04e=C@29RHT0Cdm?09jNWP15ADD0KVi^
08R8R01IFET0Shn?05UIF@12@T80CTi>05EEE@1MGEd0QhN704Q8B022PX80DE5A05=CD`1ADE40;Bd]
04e=C@0a<C40RXZ:034a<@1IFET0I6AT03dm?@2=SHd0Lg=c069RHP1^KVh0EUIF06=SH`1oOgl0@D51
05aLG01VIVH0Cdm?08J6QP1ZJVX0Hf=S03De=@1]KFd0DE5A06MWI`0n?Sh0JVYZ06MWI`0h>3P0FUYJ
059BDP0R8R80GUiN03Lg=`0K6a/0C4a<04Y:BP1^KVh0DE5A05QHF01IFET0DU9B055AD@1@D500ATI6
06ATI019BDT0DU9B07AdM019BDT0GemO06UYJ@0i>CT0N7Qh05QHF01EEED0Jf][05]KF`26QXH0ADE5
05EEE@1HF5P0Ph>303Xj>P16ATH0HF5Q06QXJ02;Rh/0P82004a<C01CDe<0Cdm?07moO`1kNg/0BDU9
061PH01]KFd0B4Q807emO@2<S8`0MGEe0:FUY@1HF5P0Jf][07AdM02YZJT0OGem09jNWP3Bd]80NGUi
0;Ng]`2SXj<0`L710;bl_01KFe/0WIfM07IfMP11@D40Jf][05eMG@1bLW80G5aL05=CD`1TI6@0?clo
061PH012@T80BTY:07QhN022PX80N7Qh04Y:BP1DE5@0Jf][07EeM@;ooooo0000o`2=SHd0RHV90;>c
/`1UIFD0D51@096AT@2c/k<0PH6108f=S@0h>3P0FEUI08n?S`2a/K40NGUi0;Bd]00d=3@0@41007=c
L`2][Jd0IFEU0;6a/@0n?Sh0@T920820P01/K6`0Hf=S07emO@2@T900;bl_05IFEP1lO7`0UIFE04=3
@`1EEED0Bd];03Lg=`1QHF40OGem065QH@0g=cL0EUIF03dm?@0l?3`0IfMW08B4Q01KFe/0>3Ph04I6
AP0Q8B40@4100;jn_P2[Zj/0<C4a03Xj>P13@d<0<c<c06e]K@3;bl/0H61P03Lg=`18B4P0<c<c03Lg
=`1fMWH0Kfm_028R8P0c<c<0D51@03dm?@29RHT0_Kfm02DU9@0];Bd0ADE505IFEP12@T80Vi^K0;Ng
]`0O7al0:BTY06IVIP1UIFD0?Cdm08Z:RP2DU9@09RHV02PX:025QHD0Shn?06IVIP2i^KT0Lg=c02d]
;@0d=3@0QhN70;6a/@26QXH0WYjN030`<01:BTX0EUIF08J6QP20P800RXZ:0<O7a`0j>SX0EUIF059B
DP2MWId0G5aL07alO01mOGd08B4Q05IFEP25QHD0Shn?06IVIP2KVi/0B4Q804=3@`1GEeL0Hf=S05AD
E01UIFD0L71`02h^;P1=CDd0Bd];07YjNP1LG5`0P82007alO00_;bl0?Shn059BDP2;Rh/0@d=307=c
L`1^KVh0<C4a04];B`1lO7`0_Kfm08b<S026QXH0TI6A04=3@`1RHV80Zj^[0;6a/@1IFET0QHF504E5
A@0j>SX0N7Qh0;6a/@1:BTX0HV9R07EeM@10@400G5aL09NGU`19BDT0D51@08F5Q@0h>3P0TI6A0:n_
[`1nOWh0B4Q806ATI01QHF40Cdm?0;Ng]`2DU9@0;Rh^03Lg=`2@T900FEUI04Y:BP2GUiL0Rh^;024Q
8@17AdL0LG5a07EeM@1FEUH0_[jn07]kN`0Q8B40A4A4065QH@1?Cdl0G5aL0;no_`0m?Cd0:2PX05eM
G@1XJ6P0EeMG0;Fe]@2g]kL09BDU04Q8B01kNg/0GEeM06e]K@3>c/h0MgMg01TI6@1NGUh0[jn_07Ui
N@1/K6`0`/;203Lg=`0f=SH0QHF50;Ng]`1UIFD0QHF504i>CP0c<c<0C4a<06m_K`1aLG40TI6A07em
O@0h>3P0Cdm?09nOW`2EUID0Hf=S09ZJVP0k>c/0DE5A09^KV`1oOgl0EeMG07YjNP1KFe/0BTY:06=S
H`2`/;00P8200;:b/P1_Kfl0ATI608:2PP28R8P0DE5A06ATI01<C4`0?Shn05mOG`020:6QX@0Z06UY
J@22PX80;bl_0410@01>CTh0TY:B08B4Q01kNg/0WIfM03De=@11@D40ZJVY0;6a/@1GEeL0KVi^05=C
D`0`<300A4A409jNWP22PX80>3Ph06UYJ@1bLW80ATI604Q8B02PX:00Ph>302`/;01XJ6P0BDU903Lg
=`1mOGd0^k^k05QHF00i>CT0QHF505EEE@1FEUH0UYJF0<o?c`1IFET0@4100P1PH600I015ADD0OGem
0;Zj^P11@D40>3Ph065QH@1WIfL0CDe=08V9R@37alL0>3Ph0492@P1CDe<0Lg=c05IFEP1aLG40clo?
059BDP19BDT0LW9b08n?S`20P800QXJ607QhN01CDe<0G5aL06ATI019BDT0CDe=06a/K01eMGD0DU9B
04E5A@1[Jf/0R8R807MgM`1[Jf/0EEEE069RHP1^KVh0EEEE04a<C00X:2P0Hf=S03lo?`1YJFT0CDe=
075aL@0U9BD0@T9205UIF@1aLG40M7Ad04m?C`0m?Cd0D51@04U9B@1@D500H61P06EUI@21PH40C4a<
05iNGP19BDT0?3`l04M7A`1=CDd0Kfm_059BDP15ADD0KFe]04M7A`1:BTX0IfMW06=SH`0k>c/0IfMW
07]kN`0f=SH0CDe=06][J`1DE5@0Hf=S05iNGP12@T80M7Ad04];B`1jNWX0>c/k05iNGP1:BTX0Bd];
055AD@1JFUX0FEUI05EEE@2SXj<0@D5104A4A01fMWH208R8R00d04];B`19BDT0@D5104E5A@1_Kfl0
EEEE04E5A@1mOGd0RHV90;6a/@2;Rh/0FEUI06=SH`1ADE40Ng]k08b<S012@T80JVYZ04e=C@1NGUh0
LW9b06=SH`1GEeL0Ogmo0451@@17AdL0GUiN03lo?`1EEED0EUIF07=cL`1dM7@0Cdm?06IVIP1MGEd0
HV9R04I6AP1jNWX0EEEE075aL@1ADE40E5AD07AdM01IFET0KVi^05aLG01HF5P0Jf][08b<S01iNGT0
DE5A04U9B@80M7Ad0;D0T92@0:VYZ@1^KVh0E5AD05QHF02DU9@0UYJF05=CD`35aLD0RHV903@d=01M
GEd0Jf][069RHP2<S8`0Bd];071`L01VIVH0CDe=05iNGP19BDT0CTi>04e=C@1`L700Q8B405ADE01U
IFD0D51@069RHP0d=3@0PH6106IVIP21PH40Rh^;06a/K01oOgl0HF5Q08F5Q@1`L700EEEE092@T02O
Wil0/K6a0;Vi^@1eMGD0GemO07UiN@1NGUh0VIVI05UIF@2IVIT0PX:205eMG@28R8P0GemO03lo?`1C
De<0?Cdm0492@P2>SXh0GEeM07EeM@1NGUh0IfMW071`L00b<S80EEEE055AD@2c/k<0DU9B06MWI`1U
IFD0ADE504Y:BP1OGel0JFUY07MgM`1;Bd/0I6AT08N7Q`17AdL0I6AT055AD@0l?3`0Q8B4065QH@1j
NWX0F5QH06YZJP1WIfL0OGem04Q8B01]KFd0EUIF055AD@2;Rh/0LG5a04U9B@1SHf<0DE5A01dM7@1H
F5P0EEEE06MWI`1BDU80LW9b06i^KP1UIFD0Kfm_06UYJ@1:BTX0IfMW051@D01RHV80K6a/051@D02M
WId0OWin0492@P1PH600C4a<065QH@1ZJVX0@410061PH00j>SX0D51@055AD@1WIfL0Hf=S07UiN@2G
UiL0S8b<05MGE`1=CDd0CTi>06i^KP11@D40<C4a03Xj>P0];Bd0W9bL09>CT`1<C4`0PH6108:2PP17
AdL0O7al06m_K`1mOGd0RHV908^;R`1ZJVX0[Zj^0;>c/`1[Jf/0Zj^[08b<S01jNWX0SXj>04];B`30
`<00WinO07MgM`1dM7@0BTY:04a<C01MGEd0N7Qh08:2PP1WIfL0KFe]06EUI@1cLg<0Jf][07inOP1i
NGT0H61P05mOG`1WIfL0NGUi00;ooooo0000L@20P800F5QH06EUI@25QHD0C4a<05YJFP1ADE40Bd];
08F5Q@0h>3P0=cLg04A4A01RHV80MgMg09:BTP10@400;Bd]03lo?`1CDe<0PH61092@T01JFUX06a/K
04Q8B01DE5@0>SXj0:f][@35aLD0;Rh^020P801RHV80OGem075aL@2LW9`0S8b<01PH601FEUH0MGEe
06IVIP24Q8@0_[jn079bLP0I6AT0LG5a09fMW@24Q8@0TY:B0;6a/@0g=cL08b<S05IFEP3=cLd0De=C
07moO`1[Jf/07alO0410@02EUID0alO7065QH@20P8005ADE02/[:`14A4@0L71`05EEE@1LG5`0Jf][
02l_;`0d=3@0KVi^08B4Q00m?Cd0P82004A4A00];Bd0ATI607]kN`1eMGD0A4A407alO00f=SH092@T
03De=@1_Kfl0HV9R06YZJP20P800?3`l04I6AP1?Cdl0Kfm_04];B`1dM7@0K6a/02l_;`1eMGD0XZ:R
09>CT`0j>SX0J6QX04Y:BP10@400GemO0:FUY@20P800ADE505EEE@11@D40BTY:06EUI@2`/;00N7Qh
0080AdM70;L0ATI6079bLP2<S8`0Ng]k02d];@1<C4`0Cdm?05ADE01gMgL0_[jn05=CD`0_;bl0EeMG
05=CD`15ADD0SHf=096AT@1;Bd/09RHV05YJFP1gMgL0JFUY08^;R`2b/[80A4A402XZ:P1ZJVX0MGEe
06=SH`2FUYH0alO703dm?@0f=SH0OGem08Z:RP1]KFd0b/[:04Y:BP0W9bL0=SHf09ZJVP1_Kfl0VIVI
08N7Q`0f=SH0Bd];07YjNP1_Kfl0OWin0<C4a00m?Cd0D51@07inOP23Ph<0Vi^K0<o?c`2MWId07AdM
075aL@2l_;`0Ng]k0820P03_knl0Jf][02l_;`1dM7@0[:b/05=CD`1eMGD0TY:B03De=@18B4P0Ng]k
0=KFeP26QXH0Kfm_09^KV`0l?3`0DU9B07]kN`2FUYH0CDe=09RHV01jNWX08B4Q04m?C`2][Jd0HF5Q
05eMG@1_Kfl0;Bd]04M7A`1dM7@0XZ:R04E5A@1?Cdl0IVIV03Ti>@1[Jf/0XZ:R07]kN`0n?Sh0QHF5
05UIF@14A4@0ZJVY0:^[Z`1<C4`0Q8B407UiN@0^;Rh0NGUi0<W9b@1TI6@0CDe=06e]K@1SHf<0KVi^
0<_;b`1JFUX0>c/k04M7A`1LG5`0RHV90<o?c`2>SXh0CTi>07MgM`0e=CD0Cdm?0<_;b`2`/;00;Bd]
06QXJ02;Rh/0L71`07UiN@1fMWH0:BTY0492@P1cLg<0EUIF071`L03Jf]X0BTY:03De=@1<C4`0HF5Q
06EUI@2IVIT0ZZZZ03@d=019BDT0NGUi09:BTP1UIFD0alO708V9R@0h>3P0ATI606=SH`2IVIT0GemO
09FEU@2RXZ80?Shn061PH01nOWh0Ogmo05mOG`2l_;`0Ph>3030`<01<C4`0X:2P08V9R@1TI6@0YjNW
04=3@`1LG5`0Shn?096AT@28R8P00P1fMWH0;P0W9bL0Fe]K05eMG@1HF5P0M7Ad04e=C@1YJFT0@D51
03/k>`1UIFD0Lg=c06IVIP0m?Cd0L71`03Lg=`0Y:BT0B4Q807]kN`2EUID0CTi>06IVIP1bLW80DU9B
055AD@1?Cdl0De=C05MGE`1WIfL0CDe=04U9B@1:BTX0B4Q805IFEP1IFET0BTY:04m?C`1DE5@0SXj>
09BDU01IFET0H61P05IFEP1;Bd/0=cLg05EEE@0k>c/204A4A00Z06EUI@0d=3@0Cdm?05mOG`1IFET0
HF5Q04m?C`17AdL0B4Q8059BDP0m?Cd0BDU904m?C`1=CDd0EUIF04E5A@0e=CD0<S8b02@T900b<S80
BTY:04m?C`1:BTX0Jf][04e=C@1QHF40Shn?079bLP0l?3`0@T9206YZJP0c<c<0A4A4055AD@0o?cl0
AdM704E5A@11@D40Hf=S05MGE`1NGUh0<C4a0P1HF5P0D`1IFET0D51@05eMG@1dM7@0I6AT08F5Q@17
AdL0BTY:07UiN@1aLG40P82004e=C@1FEUH0Bd];03/k>`1UIFD0C4a<04i>CP1=CDd0KFe]0:>SX`1g
MgL0D51@04a<C01>CTh0Hf=S05iNGP1=CDd0EUIF04U9B@1BDU80I6AT06UYJ@1FEUH0QXJ604Y:BP1B
DU80BDU904A4A01EEED0Hf=S069RHP1hN7P0Ng]k06m_K`1;Bd/0IfMW07YjNP1VIVH0EUIF09:BTP1b
LW80OWin07EeM@1XJ6P0T92@09>CT`2NWYh0VIVI07=cL`23Ph<0Bd];04Y:BP1OGel0RXZ:06m_K`1E
EED0LW9b08F5Q@1IFET0Q8B409JFUP13@d<0Q8B407=cL`14A4@0QhN70;Bd]01nOWh0WIfM08Z:RP2j
^[X0Vi^K0080Hf=S0100AdM706YZJP1OGel0D51@07inOP1NGUh0Fe]K03De=@1CDe<06QXJ0:RXZ018
B4P0C4a<05aLG02IVIT0NWYj0P1=CDd0S`17AdL0@D510=3@d02?Shl0VIVI0=_Kf`28R8P0ATI606a/
K01@D500V9RH02DU9@1VIVH0E5AD055AD@29RHT0?3`l04Y:BP1IFET0=3@d03Ti>@25QHD0=SHf07mo
O`14A4@0?clo05iNGP18B4P0IfMW03`l?01dM7@0;Rh^05EEE@1SHf<0DE5A04a<C01NGUh0JVYZ08j>
SP0[:b/0DU9B07EeM@1JFUX0SHf=05QHF00n?Sh0L71`04Y:BP21PH40<c<c06e]K@1dM7@0Q8B405IF
EP1fMWH0D51@03De=@1BDU80DE5A03Lg=`1XJ6P0?3`l03/k>`1fMWH0IVIV06UYJ@1VIVH0Jf][05YJ
FP1WIfL0HV9R04E5A@0o?cl0IVIV05QHF01QHF40Ph>303lo?`1PH600EeMG028R8P1jNWX0C4a<059B
DP1VIVH0GEeM07AdM01GEeL0Cdm?05MGE`26QXH0IfMW061PH01gMgL0IFEU075aL@1NGUh0FUYJ07Ad
M01EEED0FEUI06=SH`1FEUH0IFEU05EEE@0g=cL0QHF507inOP1@D500W9bL07YjNP1lO7`0IVIV09bL
W02JVYX0[Zj^0;6a/@1WIfL0S8b<075aL@3IfMT0]kNg09^KV`3De=@0U9BD04];B`2XZ:P0F5QH07Mg
M`1PH600Fe]K0861P@1ZJVX0IVIV051@D01>CTh0BTY:08f=S@1lO7`0Hf=S07EeM@1YJFT0SHf=00;o
oooo0000D`2a/K40E5AD05IFEP2IVIT0O7al0:^[Z`1=CDd0FEUI069RHP1bLW80TI6A08Z:RP0W9bL0
BDU907MgM`20P800MGEe0;Fe]@0^;Rh0>SXj07QhN02>SXh0IVIV07inOP29RHT08B4Q04E5A@2=SHd0
MgMg051@D01gMgL0:BTY04Y:BP1]KFd0HF5Q03Hf=P1ADE40IfMW01LG5`0N7Qh0H61P0820P00];Bd0
Bd];06][J`0^;Rh0>SXj05aLG01/K6`09bLW05EEE@13@d<0C4a<04m?C`1kNg/0<S8b03/k>`12@T80
<C4a071`L02>SXh0AdM7024Q8@15ADD0@41002`/;01jNWX0U9BD02`/;00_;bl0?3`l03Xj>P0c<c<0
T92@06a/K00Q8B40@41004U9B@1EEED0Bd];0:f][@1iNGT08b<S0080@T920=L0EEEE07emO@2`/;00
MWIf020P801ADE40IFEU04a<C022PX80`L7103/k>`0V9RH0EUIF09:BTP1KFe/0Xj>S07AdM00[:b/0
?clo08>3P`2RXZ80Xj>S0:VYZ@0h>3P0=3@d05YJFP2@T900PX:209VIV@2_[jl092@T04i>CP2LW9`0
/K6a061PH02VYZH0Rh^;028R8P1;Bd/0[Zj^09^KV`1KFe/0YJFU03dm?@0j>SX0GUiN09bLW037alL0
I6AT08J6QP2k^k/0@d=306ATI01VIVH0P82005aLG03@d=00CTi>04A4A01KFe/0QhN708>3P`1dM7@0
JFUY02PX:01LG5`0ZJVY0:6QX@1VIVH0QhN704e=C@0h>3P0IVIV09jNWP1MGEd0IfMW04=3@`15ADD0
EeMG0:BTY027QhL0G5aL07inOP0/;2`0Fe]K0::RXP3De=@0IFEU04a<C01JFUX0BDU905MGE`3Cdm<0
YjNW04E5A@1HF5P0MGEe04E5A@1`L700alO703`l?00d=3@0GemO069RHP0k>c/0VYZJ0=cLg01BDU80
;bl_06][J`1WIfL0>CTi09FEU@3:b/X0?3`l02XZ:P20P800EEEE0861P@3AdM40<30`038b<P14A4@0
Jf][05QHF02VYZH0hn?S02XZ:P0^;Rh0QHF509>CT`1TI6@0gmoO05MGE`1@D500DE5A092@T01PH600
/;2`07inOP0o?cl0GEeM07YjNP1eMGD0SHf=0;no_`0d=3@0FEUI0:NWY`1iNGT0Shn?07emO@0f=SH0
@d=309FEU@2>SXh0HV9R0:6QX@0g=cL0?clo05UIF@2g]kL0FUYJ08F5Q@1SHf<0>SXj06][J`2DU9@0
K6a/04i>CP1cLg<0C4a<03lo?`1GEeL0SHf=04i>CP2?Shl0S8b<02LW9`13@d<0S8b<059BDP1@D500
N7Qh0410@011@D40JFUY07moO`1=CDd0EEEE09NGU`14A4@0ADE505]KF`2>SXh0FUYJ05QHF02BTY80
=SHf03@d=02PX:00^;Rh055AD@1]KFd0PH6105IFEP1<C4`0Shn?069RHP0h>3P0Jf][06e]K@1KFe/0
Lg=c09nOW`0203Xj>P0G051@D01LG5`0IfMW06e]K@2NWYh0T92@02HV9P0f=SH0KFe]05aLG01QHF40
X:2P04m?C`0T92@0:2PX05IFEP2>SXh0?Shn06=SH`27QhL0OWin08b<S025QHD00P1;Bd/0;`1MGEd0
BDU905]KF`1HF5P0FUYJ04m?C`17AdL0H61P08J6QP1XJ6P0D51@04=3@`1>CTh0E5AD04Y:BP1DE5@0
@d=305YJFP1HF5P0CTi>04e=C@1KFe/0BTY:0492@P1[Jf/0D51@05UIF@1:BTX0>3Ph04Q8B013@d<0
FEUI05iNGP1bLW80JVYZ03lo?`0m?Cd0<30`02LW9`0N7Qh0=cLg05IFEP13@d<0@T92055AD@0m?Cd0
>CTi0080Bd];00D0;bl_06i^KP1GEeL0A4A404e=C@0204Q8B00805=CD`1FEUH0E5AD05eMG@19BDT0
FEUI051@D01[Jf/204];B`0F05QHF01VIVH0FEUI05QHF01WIfL0EEEE05iNGP1jNWX0Ph>307inOP1M
GEd0EEEE05UIF@1KFe/0De=C05eMG@1WIfL0IVIV06UYJ@2;Rh/0EeMG06ATI080Bd];0500FUYJ06MW
I`0o?cl0Fe]K034a<@1<C4`0?clo05IFEP10@400IVIV0451@@1@D500Bd];03Ti>@1@D500EUIF05YJ
FP1=CDd0ADE504m?C`0d=3@0?3`l02h^;P1JFUX0OGem0:6QX@1GEeL0C4a<05MGE`1LG5`0FEUI03`l
?01OGel0CTi>05aLG01GEeL0@D5106QXJ027QhL0L71`09JFUP2TY:@0R8R804i>CP1lO7`0^;Rh0;fm
_@1/K6`0V9RH071`L01CDe<0H61P08F5Q@1hN7P0RXZ:08J6QP28R8P0ZJVY06m_K`1>CTh0Lg=c051@
D00g=cL0GEeM05mOG`0l?3`0EEEE04E5A@12@T807AdM079bLP10@400D51@0492@P1=CDd0BTY:04a<
C01LG5`0?3`l03Ph>080IVIV0440L71`09NGU`1UIFD0T92@08^;R`1<C4`0FEUI04U9B@2QXJ40EUIF
04U9B@1MGEd0>c/k061PH01jNWX0Cdm?06IVIP24Q8@0Cdm?09JFUP1:BTX0D51@05=CD`0d=3@0DU9B
06ATI02n_[h0DU9B06i^KP1NGUh0:RXZ04e=C@1FEUH0FUYJ06i^KP1@D500Jf][07YjNP1BDU80Ph>3
05eMG@1KFe/0M7Ad04m?C`1]KFd0:b/[08R8R01CDe<0KFe]02h^;P1MGEd0Bd];04=3@`1QHF40BTY:
04U9B@26QXH0FEUI01HF5P1OGel0BDU9071`L01<C4`0IVIV05]KF`0205YJFP18059BDP1>CTh0LW9b
06UYJ@1VIVH0Ph>304];B`1eMGD0HV9R04M7A`25QHD0KFe]06UYJ@1?Cdl0Jf][06a/K01KFe/0DE5A
071`L01WIfL0G5aL06UYJ@2[Zj/0IFEU04a<C01TI6@0Jf][06IVIP1;Bd/0?Shn04I6AP1HF5P0U9BD
07EeM@0j>SX0OWin06MWI`1=CDd0^[Zj05aLG01IFET0@d=306YZJP1PH600U9BD0:^[Z`0n?Sh0[Zj^
09RHV02OWil0Y:BT07=cL`32`/80Lg=c05IFEP23Ph<0<30`04M7A`0k>c/0OGem08j>SP1IFET0QXJ6
04a<C01cLg<0FEUI07inOP1oOgl0LG5a05]KF`1_Kfl0HV9R0_ooool0001j0:VYZ@1^KVh0N7Qh06=S
H`1BDU80OGem07MgM`1WIfL0MgMg03hn?P19BDT0NGUi04m?C`0n?Sh0QHF504a<C019BDT0PH6108N7
Q`0n?Sh0KVi^05=CD`0j>SX0PX:20:n_[`11@D40?Cdm05MGE`16ATH0PH610:2PX00h>3P07alO034a
<@1WIfL0@41008b<S02/[:`08B4Q01dM7@0l?3`0KFe]08>3P`1jNWX0Vi^K01lO7`11@D40BDU906QX
J01IFET0]KFe07alO00I6AT0F5QH075aL@14A4@0JFUY08j>SP0g=cL08b<S061PH01_Kfl0GEeM08J6
QP0a<C40>3Ph03lo?`25QHD0HF5Q08B4Q02MWId0?Cdm02LW9`1SHf<0ZZZZ05eMG@25QHD0PX:202/[
:`0j>SX0LG5a0:RXZ01LG5`0FEUI05IFEP0S8b<0@d=307QhN02WYjL0B4Q807alO012@T80;Bd]04Y:
BP1kNg/0YjNW055AD@2DU9@0>SXj03lo?`1IFET0SHf=06i^KP1ADE40SHf=03<c<`0o?cl0MgMg06AT
I00`<300H61P059BDP0h>3P0D51@07]kN`1?Cdl0:2PX05QHF019BDT0>SXj06IVIP2SXj<203<c<`07
04a<C01?Cdl0E5AD08B4Q01VIVH09bLW03dm?@0204E5A@0B05aLG01ZJVX0T92@02TY:@0k>c/0De=C
04E5A@1QHF40/[:b08F5Q@0U9BD0Hf=S06][J`1UIFD0QXJ60:j^[P1FEUH0=cLg0P1QHF40o`1^KVh0
XJ6Q06IVIP0];Bd0@41006a/K020P800]kNg0492@P0m?Cd0FUYJ092@T01dM7@0Ogmo0<30`00j>SX0
?Cdm08V9R@2d];@0OWin0;Vi^@23Ph<0=CDe04e=C@2IVIT0`/;206][J`2XZ:P0G5aL04M7A`1MGEd0
Ph>309jNWP1NGUh0/k>c03lo?`0l?3`0A4A40;fm_@2MWId0HV9R08N7Q`0e=CD0<S8b06QXJ03Hf=P0
_kno08:2PP1oOgl0CDe=05QHF01`L700NWYj06i^KP2YZJT0BTY:03Ti>@1?Cdl0XJ6Q09fMW@1PH600
IVIV03`l?014A4@0Y:BT0<_;b`1PH600Ng]k03Ph>017AdL0OGem0<[:bP1VIVH0MWIf06m_K`12@T80
D51@07inOP1hN7P0C4a<06e]K@1GEeL0KFe]07alO013@d<0=3@d04i>CP1DE5@0M7Ad0;Rh^01RHV80
9bLW05EEE@1eMGD0IVIV0;Fe]@2BTY80;2`/03@d=010@400MGEe08>3P`2VYZH0KFe]03`l?01GEeL0
NWYj05QHF02OWil0_Kfm04i>CP0n?Sh0KFe]0451@@1GEeL0[:b/05mOG`0P8200=cLg06IVIP1IFET0
I6AT0;Jf]P14A4@06a/K04E5A@1dM7@0Lg=c07UiN@3Kfm/0EeMG03Ph>01EEED0XJ6Q08J6QP2<S8`0
XJ6Q0451@@12@T80E5AD08:2PP1MGEd0V9RH08>3P`0d=3@0GUiN07]kN`1[Jf/0?3`l04];B`14A4@0
9bLW0492@P1`L700Shn?05aLG019BDT0H61P02DU9@13@d<0HF5Q09ZJVP1<C4`0FUYJ075aL@13@d<0
?Cdm08N7Q`1mOGd0AdM703/k>`1DE5@0BTY:05=CD`1NGUh0>SXj05]KF`1]KFd0IFEU069RHP1NGUh0
L71`07emO@1cLg<0Jf][05YJFP1XJ6P0KVi^055AD@18B4P0;Rh^05EEE@1ADE40=SHf04e=C@1ZJVX0
?Cdm03Xj>P1YJFT0M7Ad07moO`1QHF40>c/k05mOG`1JFUX0Fe]K03dm?@0g=cL0De=C04Q8B01CDe<0
=SHf030`<00b<S80@d=306EUI@16ATH0>c/k05=CD`17AdL0B4Q806=SH`1<C4`0?clo03Lg=`1;Bd/0
>3Ph04I6AP1BDU80GEeM061PH019BDT0:b/[04a<C01=CDd0BDU902TY:@1FEUH0Kfm_061PH00k>c/0
C4a<05ADE01ZJVX0N7Qh03`l?00n?Sh0Ng]k0:f][@21PH40LW9b04E5A@0m?Cd0:BTY0492@P00iP18
B4P0@d=304];B`2XZ:P0dM7A05eMG@12@T80ATI603dm?@0o?cl0B4Q804M7A`14A4@08b<S03dm?@0h
>3P0@T9203`l?01;Bd/0>c/k05eMG@0l?3`0@D5104U9B@1[Jf/0BDU9051@D01;Bd/0AdM7028R8P0k
>c/0=cLg04U9B@16ATH0C4a<03Xj>P1`L700DU9B05YJFP1cLg<0DE5A09JFUP1XJ6P0NWYj07EeM@0n
?Sh0?clo05mOG`1HF5P0IVIV05EEE@1UIFD0Bd];061PH01RHV80Vi^K04e=C@2PX:00RHV905UIF@1m
OGd0K6a/06m_K`2ZZZX0Q8B40:JVYP2NWYh0Ph>308b<S01PH600>c/k05MGE`2LW9`0OGem03hn?P1W
IfL0IFEU05MGE`0_;bl0X:2P05EEE@1[Jf/0IFEU05mOG`1TI6@0GUiN08^;R`1KFe/0=CDe07UiN@1Q
HF40Rh^;0=gMg@1WIfL0?Shn04m?C`0d=3@0JVYZ03Ti>@1]KFd0IfMW04e=C@1RHV80?Cdm04I6AP19
BDT0>c/k04U9B@1RHV80EEEE0;Ng]`1_Kfl0O7al06ATI016ATH0C4a<05=CD`1`L700<c<c05EEE@1H
F5P0>c/k06e]K@1cLg<0X:2P09^KV`17AdL0BTY:05aLG01RHV80RHV907YjNP1ADE40D51@04e=C@1o
Ogl0=cLg06a/K01ZJVX0WYjN05eMG@1bLW80BTY:05EEE@2<S8`0IFEU0410@01CDe<0BDU903hn?P1m
OGd0@T9204E5A@1NGUh0LW9b05IFEP1NGUh0H61P03dm?@19BDT0UiNG07inOP1DE5@0IFEU07MgM`3P
h>00S8b<04Q8B01`L700LG5a0:NWY`1VIVH0De=C06QXJ01PH600Hf=S04i>CP1WIfL0F5QH07inOP1a
LG40Fe]K07MgM`1WIfL0HF5Q09RHV01SHf<0RHV905iNGP0n?Sh0AdM704a<C00i>CT0Vi^K07]kN`1D
E5@0Jf][06MWI`2EUID0EUIF07EeM@1HF5P0Xj>S09VIV@0S8b<0L71`06=SH`2e]KD0XZ:R06MWI`2A
TI40@D5106ATI022PX80?3`l04a<C00j>SX0BDU905]KF`1@D500EEEE04I6AP13@d<0DU9B09RHV01c
Lg<0FUYJ07MgM`2CTi<0OWin0_ooool0000F0820P01aLG40ZJVY04i>CP1OGel0I6AT06=SH`22PX80
WIfM03hn?P13@d<0GUiN05eMG@1oOgl0Ti>C03Ph>01IFET0L71`08R8R01KFe/0b/[:069RHP80<S8b
0?l0O7al05mOG`1iNGT0O7al0410@00Y:BT0Ng]k08J6QP1@D500LG5a05MGE`11@D40?Shn08F5Q@2?
Shl0E5AD07]kN`1GEeL08B4Q05mOG`25QHD0CDe=04U9B@1QHF40:BTY02`/;01SHf<0XJ6Q04i>CP1F
EUH0CDe=03Hf=P0j>SX0MGEe069RHP1ADE40EUIF02PX:00U9BD0O7al05EEE@0[:b/0CTi>055AD@0N
7Qh0=cLg07EeM@19BDT08B4Q03Hf=P1:BTX0:BTY04e=C@2GUiL0;2`/028R8P0o?cl0CTi>04Y:BP2M
WId0[Jf]02PX:00b<S80@T92079bLP1@D500PX:206e]K@0Y:BT0ADE503Lg=`1cLg<0QXJ60:6QX@1M
GEd0=CDe04A4A00m?Cd0GemO07=cL`2f][H0>SXj03De=@1OGel0IVIV05UIF@2SXj<0UIFE02HV9P18
B4P0Ph>308V9R@1PH600WIfM04I6AP0Q8B40CTi>09bLW022PX80IfMW092@T00f=SH0:b/[06ATI02J
VYX0IfMW08J6QP2^[Zh0:b/[02l_;`1IFET0QHF506EUI@1oOgl0RHV9034a<@0i>CT0Y:BT0:f][@17
AdL0Vi^K08>3P`0S8b<0IFEU08V9R@1gMgL0KFe]09NGU`0g=cL0:BTY06EUI@2KVi/0OWin05eMG@1h
N7P0>CTi06MWI`2RXZ80DU9B08V9R@1FEUH0@D5104i>CP1lO7`0JFUY04E5A@2MWId0QHF50451@@1[
Jf/0XJ6Q05IFEP19BDT0U9BD05IFEP14A4@0IFEU092@T00c<c<0Hf=S09jNWP0k>c/0Fe]K0:BTY01W
IfL0<30`05eMG@2RXZ80CTi>06e]K@2/[:`0De=C02TY:@1DE5@0Fe]K04U9B@1SHf<0YjNW055AD@12
@T80FEUI05YJFP1NGUh0[Jf]09jNWP0W9bL0ATI608J6QP1bLW80MGEe0;Bd]01OGel06a/K05QHF021
PH40TY:B0;bl_00h>3P0<C4a04e=C@1oOgl0H61P0;>c/`2;Rh/08R8R05QHF02>SXh0OGem08N7Q`36
a/H0AdM705IFEP23Ph<0I6AT0820P02^[Zh0@d=305MGE`2ZZZX0/K6a04e=C@1fMWH0@T9204U9B@1O
Gel0^;Rh092@T02:RXX0CDe=02d];@1bLW80Vi^K0:n_[`1gMgL0W9bL02`/;00c<c<0P8200<[:bP2:
RXX0LW9b07inOP0e=CD0=3@d06i^KP2i^KT0I6AT06m_K`1;Bd/0>c/k05QHF01eMGD0O7al03lo?`1n
OWh002@0F5QH03`l?01ADE40UYJF07moO`0j>SX0E5AD02l_;`19BDT0FUYJ0:6QX@1NGUh0?clo065Q
H@0l?3`0Jf][07MgM`2=SHd0De=C02`/;01ADE40HF5Q06=SH`26QXH0P82002LW9`0V9RH0?3`l04Y:
BP1hN7P0NWYj09jNWP0[:b/09bLW04I6AP22PX8207emO@0309bLW00m?Cd0@4100080EEEE00l0Fe]K
059BDP1HF5P0GEeM05YJFP1[Jf/0@d=304E5A@1=CDd0>c/k05aLG01GEeL0MGEe09nOW`2?Shl00P1/
K6`06P1GEeL0LG5a07EeM@1=CDd0:BTY07alO00g=cL0?Shn03`l?02:RXX0H61P03hn?P1GEeL0KFe]
07AdM01IFET0@T9204Q8B01eMGD0EeMG059BDP1NGUh0EEEE05MGE`16ATH0=CDe0P1CDe<0V00l?3`0
ADE504Q8B01EEED0NGUi03Lg=`1NGUh0WIfM08b<S010@400BDU9075aL@1:BTX0EeMG05ADE00_;bl0
?3`l04M7A`15ADD0B4Q804A4A01;Bd/0=3@d06IVIP0b<S80ADE505ADE01EEED0IfMW04Y:BP1NGUh0
BTY:05ADE00o?cl0EEEE05YJFP1ADE40H61P030`<00d=3@0IfMW07=cL`1CDe<0Bd];05=CD`1=CDd0
?Cdm04M7A`0^;Rh0>c/k04];B`14A4@0:b/[03`l?00i>CT0ATI603hn?P17AdL0C4a<05EEE@0h>3P0
?Shn03/k>`0h>3P0B4Q804i>CP1ADE40Cdm?04e=C@1ADE40CDe=04=3@`12@T80AdM7051@D01bLW80
CDe=05QHF01=CDd0@d=304e=C@1VIVH0O7al059BDP0n?Sh0Bd];05aLG01gMgL0Ng]k09BDU02:RXX0
QHF507moO`1hN7P0PH6108Z:RP2RXZ80JVYZ09RHV01eMGD0Bd];07QhN01JFUX0Cdm?05mOG`1FEUH0
XZ:R09RHV018B4P0GemO06m_K`1JFUX0@41005MGE`1lO7`0@410061PH01ZJVX0KVi^04i>CP2NWYh0
MWIf07EeM@2DU9@0Jf][06ATI01FEUH0CTi>08n?S`2GUiL0Ogmo0861P@2LW9`0TI6A06QXJ01BDU80
I6AT07alO02ATI40EeMG09:BTP2;Rh/0MgMg06m_K`24Q8@0CDe=04m?C`1QHF40CTi>08:2PP1<C4`0
DE5A0P18B4P0201;Bd/0N7Qh05]KF`1BDU80UYJF05YJFP2?Shl0Ogmo0P14A4@02P1=CDd0E5AD05iN
GP0g=cL0E5AD06a/K01LG5`0Hf=S04I6AP0e=CD205UIF@1O06IVIP1KFe/0KVi^05eMG@1bLW80EeMG
07=cL`0e=CD0ADE505EEE@1>CTh0<c<c05aLG00e=CD08B4Q05=CD`12@T80DU9B04];B`1WIfL0EUIF
05mOG`1WIfL0>c/k04a<C035aLD0TI6A06QXJ01aLG40?Shn069RHP1?Cdl0C4a<06m_K`1GEeL0GUiN
05mOG`1YJFT0L71`04=3@`1CDe<0EUIF07moO`1:BTX0G5aL07QhN01HF5P0C4a<04=3@`1NGUh0JVYZ
03Hf=P0o?cl0GemO04a<C01JFUX0F5QH04M7A`1eMGD0CDe=06][J`2HV9P0MWIf05MGE`2FUYH0dM7A
06a/K02GUiL0Ogmo05eMG@1dM7@0I6AT09>CT`2DU9@0MWIf0=WIf@1UIFD0FEUI06YZJP1MGEd0Q8B4
03<c<`1@D500IfMW07moO`26QXH0BTY:04e=C@1FEUH0XZ:R07IfMP1HF5P0JFUY07UiN@1]KFd00_oo
ool0001;0;6a/@1EEED0SHf=09:BTP1WIfL0QhN70451@@1GEeL0]KFe079bLP1VIVH0FEUI03Hf=P0m
?Cd0Lg=c05=CD`0n?Sh0QHF503`l?01?Cdl0P8200:b/[019BDT0G5aL075aL@0`<300Cdm?09JFUP1Q
HF40B4Q805UIF@1GEeL0CTi>0;>c/`1XJ6P0:BTY02XZ:P13@d<0@T9204I6AP1ZJVX0EEEE01dM7@0`
<300N7Qh05iNGP1[Jf/0TI6A02h^;P0Z:RX0@D5104I6AP1/K6`0/[:b09bLW00W9bL0>c/k051@D01C
De<0EEEE0;6a/@15ADD0:b/[02`/;022PX80EUIF08^;R`2ATI408b<S02d];@0l?3`0RHV905EEE@2K
Vi/0IfMW0080:RXZ08@0H61P079bLP1QHF40];Bd06][J`0N7Qh0?clo05YJFP1HF5P0LG5a07inOP0g
=cL0>c/k055AD@21PH40L71`08F5Q@2OWil08b<S03lo?`1EEED0Zj^[05QHF02@T900=cLg02TY:@1@
D500TI6A07YjNP15ADD0R8R803Lg=`0i>CT0IfMW08V9R@1LG5`0H61P07YjNP0j>SX0EeMG07inOP20
P800@D5105QHF011@D40ATI605YJFP1oOgl0Fe]K03Ph>01OGel0=3@d04Y:BP1RHV80^KVi08f=S@0d
=3@0Ng]k06][J`0c<c<0EUIF07YjNP1BDU80@D5108N7Q`1YJFT0BDU906YZJP2SXj<0Cdm?04U9B@1h
N7P0>CTi06YZJP2RXZ80JFUY02/[:`1JFUX0EEEE03Xj>P1TI6@0TI6A03`l?01TI6@0IFEU04i>CP39
bLT0][Jf02l_;`1;Bd/0J6QX071`L01ZJVX0cLg=0;6a/@0j>SX0FEUI05=CD`23Ph<0OWin0;Zj^P1N
GUh0@41008^;R`2UYJD0KVi^0820P03@d=00DE5A02TY:@1`L700J6QX06ATI02EUID0hn?S03hn?P0e
=CD0QXJ606m_K`26QXH0f=SH06=SH`0X:2P0@D5109^KV`2SXj<0I6AT08f=S@0b<S80D51@05IFEP2N
WYh206IVIP23096AT@0T92@0DE5A05YJFP1lO7`0FEUI07alO01<C4`0@d=308j>SP2;Rh/0?Cdm05EE
E@1XJ6P0;Rh^075aL@3@d=00XJ6Q06EUI@1VIVH0=CDe05IFEP2i^KT0NWYj04a<C01FEUH0=CDe04U9
B@2MWId0SHf=03Xj>P1CDe<0Bd];05]KF`1lO7`0IVIV03De=@15ADD0B4Q805=CD`1TI6@0PH6103Hf
=P0d=3@0MgMg04I6AP1nOWh0dM7A0492@P0S8b<0CDe=07inOP1IFET0QHF50<71`@0k>c/0<c<c0410
@01WIfL0Kfm_0:2PX02_[jl0;bl_04e=C@2=SHd0Ng]k05ADE02VYZH0UYJF030`<019BDT0IVIV08R8
R02<S8`0^k^k05MGE`0g=cL0CDe=07UiN@1kNg/0Vi^K0:^[Z`0b<S80DU9B06i^KP2][Jd0X:2P07]k
N`2HV9P0?clo04E5A@1YJFT0WYjN07UiN@1NGUh0OWin0451@@0l?3`0F5QH0:ZZZP26QXH0>CTi059B
DP0P8200<C4a06MWI`2j^[X0SXj>03hn?P1gMgL0TI6A06m_K`1IFET0L71`04E5A@1:BTX0KFe]04I6
AP19BDT0F5QH05EEE@1>CTh0B4Q806=SH`1EEED0H61P05iNGP1;Bd/0GUiN07UiN@1HF5P00P10@400
3017AdL0BDU904=3@`0i>CT0A4A403hn?P0m?Cd0F5QH06a/K01LG5`0De=C0451@@80D51@04d0EUIF
05QHF01QHF40QhN704Y:BP1?Cdl0<30`03De=@0h>3P0A4A4059BDP14A4@0DU9B051@D014A4@0?3`l
02`/;01GEeL0?clo04e=C@1IFET0?Shn04Q8B016ATH0D51@065QH@1SHf<0H61P06IVIP19BDT0EEEE
04Q8B01^KVh0BTY:03lo?`1IFET0IfMW05=CD`1EEED0J6QX06i^KP1SHf<0L71`096AT@2RXZ80C4a<
05MGE`0b<S80=cLg05EEE@1bLW80QhN706YZJP2g]kL0RXZ:04a<C01VIVH0AdM703Xj>P1DE5@0BDU9
03<c<`0_;bl0@T9205EEE@0c<c<0=CDe06QXJ01^KVh0<C4a04U9B@1<C4`0Ng]k04A4A00g=cL0GEeM
06][J`02038b<P0f04];B`17AdL0;bl_04A4A01iNGT0RXZ:0410@00j>SX0?3`l06=SH`1XJ6P0@T92
04Q8B01ADE40Ogmo06MWI`12@T808b<S0410@011@D40EeMG08N7Q`1JFUX0Cdm?059BDP2;Rh/0_kno
05IFEP2LW9`0DU9B03Hf=P1ZJVX0K6a/05]KF`1RHV80<30`07=cL`1/K6`0MGEe07MgM`2OWil0SHf=
0861P@1]KFd0IfMW051@D022PX80H61P06=SH`0o?cl0XZ:R07EeM@1aLG40IFEU0P2FUYH0101TI6@0
TI6A07MgM`1eMGD20:6QX@0=0<k>cP3<c<`0ZZZZ061PH01EEED0HF5Q05iNGP1>CTh0QXJ608V9R@2^
[Zh0YjNW075aL@02051@D00a04i>CP22PX80UYJF05YJFP22PX80HV9R05UIF@1LG5`0C4a<051@D01U
IFD0Ti>C03De=@1LG5`0F5QH04U9B@1:BTX0DU9B069RHP2;Rh/0S8b<08:2PP1kNg/0H61P07moO`1^
KVh0BDU904i>CP16ATH0IVIV03<c<`1iNGT0M7Ad06][J`1NGUh0S8b<055AD@1<C4`0FUYJ04Q8B011
@D40K6a/0410@00e=CD0E5AD04I6AP1cLg<0EEEE05aLG002061PH00U065QH@1ADE40AdM705aLG020
P800W9bL0:NWY`0g=cL0MgMg07inOP1HF5P0XZ:R08:2PP1WIfL0A4A404i>CP1<C4`0:2PX04e=C@0l
?3`0I6AT07YjNP1HF5P0EeMG03Ti>@1@D500DU9B0:VYZ@2JVYX0E5AD055AD@1BDU80IfMW096AT@1V
IVH09RHV07emO@0203@d=00R05iNGP18B4P0HV9R04M7A`1GEeL0Bd];0:NWY`26QXH0LG5a09^KV`1^
KVh0SXj>08J6QP1gMgL0Xj>S061PH02BTY80PH6104U9B@1=CDd0FUYJ08N7Q`1eMGD0Jf][065QH@0k
>c/0MWIf04m?C`2:RXX0MGEe07emO@2ATI40[Jf]08^;R`;ooooo0000U`2l_;`0IFEU05iNGP26QXH0
NGUi08n?S`12@T80Bd];05aLG01FEUH0UiNG07YjNP0i>CT0>3Ph08n?S`1[Jf/0Ogmo0<g=c@14A4@0
=3@d069RHP2KVi/0LW9b0861P@2m_Kd0>c/k03<c<`2?Shl0`/;208F5Q@2h^;P0<C4a04A4A01>CTh0
X:2P06UYJ@2<S8`0TI6A01LG5`1IFET0Ph>306EUI@1:BTX0OGem0;2`/00[:b/0DE5A0::RXP2=SHd0
D51@0:FUY@1VIVH0:2PX04A4A02][Jd0JVYZ04e=C@1QHF40:b/[02d];@1QHF40U9BD04Q8B01_Kfl0
;2`/02l_;`0o?cl0KFe]061PH01OGel0Q8B4030`<00o?cl0R8R80:BTY01>CTh0GUiN06YZJP0`<300
EUIF08F5Q@2WYjL0Bd];04E5A@1QHF40;bl_04Y:BP2CTi<0LG5a02/[:`0k>c/0=cLg04E5A@1ADE40
UYJF07EeM@0[:b/0GUiN04E5A@16ATH0XZ:R09fMW@0Z:RX0@T9206a/K01RHV80Bd];08j>SP1MGEd0
;Rh^04U9B@1gMgL0I6AT07QhN02k^k/0<30`02l_;`18B4P0M7Ad04Y:BP2?Shl0M7Ad02l_;`0m?Cd0
Fe]K079bLP1DE5@0[jn_07=cL`0Z:RX0;bl_05mOG`22PX80Fe]K0=GEe@2NWYh0>3Ph03@d=021PH40
SHf=06UYJ@39bLT0LW9b034a<@1OGel0YZJV07MgM`29RHT0W9bL02l_;`0l?3`00P1UIFD0:P1<C4`0
OGem06EUI@12@T80E5AD09fMW@1SHf<0KFe]05iNGP17AdL0OGem0=?Cd`2OWil0OGem08^;R`0i>CT0
BDU90820P03=cLd0Lg=c0820P01NGUh0>SXj05]KF`2LW9`0SHf=04M7A`1_Kfl0EeMG02`/;01QHF40
RHV909NGU`1CDe<0ZJVY05UIF@0];Bd0DU9B0;2`/02:RXX0BTY:06][J`80=3@d04D0GemO08^;R`0o
?cl0A4A405eMG@0e=CD0MWIf08j>SP0l?3`0;2`/04Q8B01ADE40?Cdm07MgM`3>c/h0@D5103De=@1b
LW80FUYJ06UYJ@3De=@0Xj>S02d];@1ADE40OGem06MWI`2QXJ40IfMW02`/;00j>SX0P82009RHV02h
^;P0[Jf]02XZ:P0^;Rh0H61P07YjNP2e]KD0Xj>S02PX:011@D40Cdm?09>CT`2FUYH0/;2`04A4A00Y
:BT0FUYJ07moO`1ZJVX0V9RH05QHF00X:2P0H61P06i^KP1KFe/0HV9R08B4Q00o?cl0B4Q806][J`2W
YjL0De=C0<C4a01_Kfl0ATI605]KF`1iNGT00P1WIfL0Y@2DU9@0@D5104M7A`1OGel0UiNG06=SH`1G
EeL0XZ:R034a<@0k>c/0C4a<07emO@18B4P0GEeM07moO`11@D40:b/[05aLG025QHD0=CDe059BDP1^
KVh0<S8b04i>CP1_Kfl0J6QX02`/;01IFET0IfMW04Q8B01?Cdl0JFUY05QHF00];Bd0ATI6059BDP11
@D40HV9R07]kN`1JFUX08b<S038b<P1GEeL0D51@04Q8B020P800CDe=02<S8`1bLW80EeMG04];B`10
@400TY:B08B4Q01IFET0CTi>05mOG`1=CDd0EUIF06IVIP0o?cl0FUYJ04M7A`1BDU80FUYJ05mOG`1n
OWh0IfMW08J6QP1nOWh0Fe]K079bLP1EEED0A4A40410@00k>c/0NWYj04m?C`19BDT0CTi>079bLP1L
G5`0>CTi04];B`1/K6`0NWYj05UIF@17AdL0D51@069RHP1JFUX0DE5A05]KF`1YJFT0Hf=S05MGE`0`
<300B4Q805mOG`1EEED0HF5Q04M7A`16ATH0MgMg03Ph>01JFUX0KVi^07]kN`1?Cdl0H61P07QhN011
@D40C4a<04M7A`1BDU80FUYJ03dm?@0e=CD0HV9R04e=C@1VIVH0=CDe07=cL`1:BTX0D51@04U9B@1f
MWH0F5QH05YJFP2CTi<0@d=306ATI01dM7@0Vi^K0;2`/01HF5P0EeMG02h^;P0k>c/0M7Ad05ADE01U
IFD0SHf=0<[:bP2FUYH0HF5Q04];B`15ADD0Cdm?04M7A`1SHf<0=cLg055AD@0i>CT0C4a<03hn?P14
A4@0=3@d03hn?P0g=cL0AdM702TY:@0d=3@0=CDe04i>CP0203hn?P1n04=3@`0o?cl0=SHf04I6AP12
@T80DE5A05]KF`1HF5P0<S8b04e=C@14A4@0DU9B065QH@16ATH0FEUI04Q8B00g=cL0@T9203hn?P11
@D40F5QH08F5Q@1VIVH0Ng]k06=SH`1EEED0BTY:071`L024Q8@0I6AT0;>c/`1HF5P0<C4a061PH01m
OGd0TI6A0:j^[P1MGEd0P820079bLP1CDe<0Jf][04i>CP14A4@0CTi>09FEU@1lO7`0;Bd]03Ph>01E
EED0CDe=02l_;`24Q8@0CDe=07QhN01OGel0De=C04a<C00n?Sh0?clo04E5A@18B4P0Q8B407UiN@3=
cLd0kno_09bLW023Ph<0R8R805UIF@1fMWH0DU9B0:2PX01;Bd/0D51@05mOG`0R8R80D51@05UIF@1;
Bd/0F5QH06a/K01GEeL0P820059BDP1[Jf/0N7Qh03hn?P0Z:RX0MGEe0:^[Z`1:BTX0J6QX05EEE@1<
C4`0Lg=c06IVIP1TI6@0IFEU03De=@0n?Sh0J6QX06YZJP2<S8`0J6QX05mOG`2=SHd0LG5a08j>SP1P
H600UYJF0:^[Z`2VYZH0Hf=S07AdM01ADE40EeMG05UIF@1:BTX0ATI604Q8B00m?Cd0>3Ph05=CD`1>
CTh0F5QH0`1RHV80701KFe/0I6AT05iNGP1YJFT0[Zj^0:NWY`1XJ6P0C4a<05mOG`2[Zj/0Shn?05mO
G`1IFET0EeMG07AdM00o?cl0Fe]K05UIF@0g=cL0GUiN04U9B@1ZJVX0LG5a065QH@1ZJVX0GUiN06QX
J010@40205IFEP0/0451@@1_Kfl0@D5104=3@`1OGel0=CDe02LW9`2WYjL0@d=304A4A01QHF40BDU9
08n?S`12@T80Ng]k03Ti>@2e]KD0QXJ604Q8B01kNg/0UiNG0=WIf@27QhL0LG5a0<O7a`1^KVh0[jn_
096AT@1kNg/0U9BD03Lg=`1CDe<0DU9B08^;R`1FEUH0@D5104A4A01RHV80[:b/07YjNP1_Kfl0RXZ:
07inOP1]KFd2ooooo`0001T0[jn_0:ZZZP2j^[X0DE5A05aLG027QhL0Shn?08J6QP1=CDd0C4a<06MW
I`22PX80MWIf07moO`1SHf<0E5AD04Y:BP2DU9@0N7Qh0492@P1lO7`0@D5103hn?P1KFe/0Rh^;0080
Cdm?06T0De=C034a<@1?Cdl0IFEU04E5A@0Z:RX0ATI604e=C@0Y:BT0TI6A0<g=c@1UIFD0;2`/04i>
CP0j>SX06a/K06QXJ02g]kL0C4a<05IFEP1dM7@0HF5Q03Xj>P25QHD0PX:201lO7`0h>3P0H61P059B
DP2?Shl0YZJV038b<P0W9bL0@41006YZJP1DE5@0Z:RX069RHP0N7Qh0IfMW06=SH`10@400MGEe0<C4
a00m?Cd051@D034a<@1[Jf/0CTi>09FEU@2LW9`09RHV02<S8`1dM7@0]kNg06UYJ@2<S8`0YjNW028R
8P0`<300Kfm_09RHV01KFe/0Ti>C07]kN`0Q8B40?Cdm055AD@2EUID0FEUI0:6QX@1]KFd0ADE50451
@@2ATI40Fe]K0::RXP2IVIT0;bl_05EEE@1GEeL0RXZ:07MgM`3>c/h0MGEe024Q8@1@D500Kfm_06UY
J@1OGel0[:b/051@D00`<300Hf=S09>CT`1KFe/0JFUY092@T00n?Sh0>CTi07MgM`2XZ:P0GEeM08V9
R@1hN7P00P0n?Sh0>P1XJ6P0[jn_06i^KP1`L700Lg=c03lo?`0k>c/0MWIf0;Ng]`1DE5@0IVIV04m?
C`0n?Sh0CDe=09^KV`2JVYX0EUIF09FEU@14A4@0?3`l08Z:RP1mOGd0;bl_0451@@1aLG40GEeM0::R
XP1BDU80?3`l04E5A@1`L700Cdm?065QH@2m_Kd0ATI603lo?`1?Cdl0Ph>307=cL`20P800Shn?030`
<00k>c/0MGEe08>3P`1RHV80];Bd09ZJVP0J6QX0>3Ph06EUI@1TI6@0D51@0<W9b@2SXj<0:2PX0451
@@1DE5@205aLG02n0;Rh^01DE5@0:b/[05EEE@1MGEd0FUYJ09JFUP2[Zj/09bLW03/k>`1EEED0EUIF
059BDP1dM7@0HV9R02/[:`1]KFd0XJ6Q08F5Q@1fMWH0Zj^[03Ti>@0f=SH0Shn?0=WIf@1_Kfl0NWYj
02l_;`0c<c<0DU9B09NGU`1cLg<0L71`06a/K00_;bl0MWIf0:BTY01JFUX0IFEU05YJFP11@D40EeMG
08f=S@1NGUh0PH610820P00m?Cd0DE5A07]kN`24Q8@0BTY:07EeM@1KFe/0@T9209>CT`2^[Zh0AdM7
05IFEP1PH600CDe=07=cL`2WYjL0DU9B030`<01^KVh0E5AD03Ti>@2OWil0clo?05mOG`14A4@0MWIf
05eMG@1<C4`0VIVI05aLG00_;bl0?Shn05aLG01TI6@0HV9R0:FUY@1XJ6P09BDU0410@00o?cl0Fe]K
06e]K@2/[:`0M7Ad02l_;`1ADE40Cdm?06=SH`2@T900b<S803dm?@1:BTX0NGUi06QXJ01TI6@0^;Rh
0<?3``13@d<0C4a<06EUI@1_Kfl0D51@09:BTP2PX:00;2`/03`l?01EEED0P820059BDP21PH40][Jf
03dm?@1DE5@0Kfm_08n?S`18B4P0Shn?079bLP0f=SH0A4A4079bLP1lO7`0FEUI04a<C01cLg<0Bd];
055AD@2DU9@0Bd];06YZJP1KFe/0FEUI0451@@1;Bd/0Hf=S06a/K01cLg<0OWin079bLP22PX80Lg=c
05MGE`1:BTX09RHV04];B`1?Cdl0@D5105EEE@1JFUX0E5AD034a<@1JFUX0K6a/069RHP1EEED0?3`l
06QXJ018B4P0I6AT059BDP1=CDd0J6QX04M7A`1ADE40AdM703`l?013@d<0CDe=055AD@1IFET0H61P
05EEE@0f=SH0FUYJ08J6QP1[Jf/0B4Q804e=C@1/K6`0EUIF069RHP1DE5@0?Shn04];B`80Lg=c0;80
LG5a05UIF@1OGel0Fe]K09JFUP1DE5@0De=C05QHF01lO7`0JFUY05aLG02;Rh/0Bd];05QHF01[Jf/0
QhN709nOW`2;Rh/0HF5Q03dm?@0];Bd0F5QH07emO@2ATI40WIfM09RHV02RXZ80RHV906QXJ01>CTh0
DE5A06=SH`1NGUh0@41005ADE017AdL0GUiN03dm?@1DE5@0G5aL071`L017AdL0GEeM04M7A`1=CDd0
J6QX05]KF`1IFET0Kfm_04Y:BP1CDe<0C4a<051@D018B4P0De=C05IFEP1cLg<0FUYJ05=CD`17AdL0
FEUI071`L015ADD0JVYZ05YJFP1DE5@0HV9R04M7A`1=CDd0GUiN0451@@14A4@0DU9B06ATI02>SXh0
>CTi05ADE01nOWh0F5QH0=kNgP26QXH0>c/k06ATI01?Cdl0ADE5069RHP0n?Sh0O7al09RHV01aLG40
JVYZ06EUI@1nOWh0FUYJ051@D01TI6@0D51@04m?C`16ATH0ADE5024Q8@3@d=00=cLg04];B`1GEeL0
SHf=06EUI@13@d<0A4A403dm?@0e=CD0FEUI04A4A01bLW80Ogmo04Y:BP16ATH0CDe=08B4Q01kNg/0
DE5A04];B`12@T80Ng]k08>3P`1<C4`0NWYj07]kN`1NGUh0JFUY08Z:RP1XJ6P0WYjN08F5Q@1GEeL0
M7Ad04i>CP1]KFd0De=C06a/K01?Cdl0O7al07UiN@1IFET0>c/k06QXJ029RHT0NGUi034a<@1oOgl0
O7al06a/K026QXH0GUiN04];B`1IFET0DU9B08B4Q01ZJVX0Ogmo04];B`1VIVH0Ng]k08j>SP1DE5@0
EUIF05eMG@10@400?3`l06QXJ013@d<0>CTi065QH@1;Bd/0IFEU05ADE01:BTX0FEUI0P1=CDd0B01A
DE40C4a<059BDP21PH40JFUY069RHP0^;Rh0HF5Q04e=C@0b<S80NGUi04i>CP1GEeL0>SXj05=CD`16
ATH0>3Ph05MGE`1XJ6P0PH61051@D01BDU80JVYZ04I6AP18B4P0=SHf05mOG`1KFe/0ADE5055AD@0m
?Cd0F5QH07=cL`0f=SH08b<S059BDP0];Bd0EUIF08j>SP16ATH0C4a<03lo?`2@T900EEEE08f=S@1P
H600IFEU08V9R@1[Jf/0KVi^06e]K@1kNg/0lO7a06ATI02RXZ80JFUY0410@01HF5P0?Cdm071`L01]
KFd0QHF507UiN@21PH40Ti>C06a/K01lO7`0NGUi07emO@1KFe/0LW9b08V9R@;ooooo00007P2:RXX0
IFEU08R8R01`L700DE5A06YZJP1OGel0WIfM06][J`0U9BD0B4Q805IFEP0l?3`0TI6A0:RXZ00W9bL0
@D5105ADE013@d<0EEEE0;Ng]`25QHD0:b/[06EUI@1lO7`0E5AD075aL@2SXj<0@41002l_;`80DU9B
0240MGEe0:FUY@1jNWX061PH03lo?`1NGUh0N7Qh05EEE@28R8P0>3Ph02LW9`0e=CD0QXJ608N7Q`1L
G5`0c/k>04Y:BP0j>SX0D51@06UYJ@1:BTX0Jf][09nOW`0k>c/0@41007alO01hN7P0JFUY07inOP0_
;bl0;Bd]03Ph>01lO7`00P1@D500a@1NGUh06a/K02`/;01?Cdl0Rh^;04A4A01IFET0DE5A02PX:00n
?Sh0N7Qh05mOG`0Z:RX0D51@04];B`0f=SH0BTY:09NGU`1JFUX0?clo05=CD`0j>SX0EEEE06][J`2L
W9`0=SHf03Lg=`1DE5@0Cdm?04M7A`2@T900Xj>S02l_;`12@T80EEEE0492@P1]KFd0[:b/0410@012
@T80M7Ad04U9B@1?Cdl0XJ6Q0<k>cP1DE5@0A4A405QHF018B4P0EUIF0:n_[`1dM7@0=CDe03dm?@1/
K6`0BDU9096AT@33`l<0E5AD03De=@1GEeL0IFEU04];B`2ATI40_[jn04e=C@0U9BD0@T92071`L01E
EED0TI6A0<K6aP1=CDd0B4Q8069RHP2NWYh0Lg=c0;Zj^P2@T900=CDe05YJFP1YJFT0GemO07QhN03@
d=00N7Qh03hn?P1KFe/0^[Zj08N7Q`20P800T92@04=3@`2FUYH0^k^k05]KF`2CTi<0OWin03/k>`14
A4@0XJ6Q0<71`@1QHF40XJ6Q08J6QP0m?Cd0Ph>30861P@18B4P0GemO09JFUP0e=CD0A4A40861P@2i
^KT0KVi^07YjNP22PX80BDU903hn?P1PH600dm?C07AdM02FUYH0U9BD04I6AP1ADE40UiNG0<g=c@1T
I6@0N7Qh06IVIP0b<S80GemO0<W9b@2MWId0IFEU07inOP0a<C40?Cdm096AT@2b/[80DE5A05ADE021
PH40BDU904e=C@2RXZ80KFe]03Lg=`1LG5`0E5AD07moO`33`l<0I6AT02d];@1KFe/0I6AT04e=C@27
QhL0ZJVY03@d=013@d<0IfMW079bLP2LW9`0[:b/04I6AP1<C4`0SXj>05UIF@2o_kl0^;Rh04e=C@0k
>c/0ATI606EUI@1iNGT0a<C407]kN`0[:b/0Kfm_08R8R01hN7P0Zj^[09NGU`0N7Qh0BDU90;6a/@2J
VYX0H61P0;Rh^014A4@0CTi>055AD@2TY:@0NWYj0080SXj>0280:b/[05]KF`29RHT0N7Qh04M7A`2/
[:`0L71`01dM7@16ATH0SXj>09>CT`1=CDd0Ti>C07MgM`0];Bd0F5QH0820P023Ph<0EUIF09RHV00g
=cL0;Bd]06UYJ@2BTY80S8b<061PH01mOGd0ADE503Lg=`17AdL0RHV907emO@1?Cdl0QHF50P0m?Cd0
F@0g=cL0QXJ606MWI`0f=SH0K6a/0492@P0^;Rh0:RXZ061PH020P800=3@d065QH@0Y:BT0;2`/06i^
KP2@T900Fe]K0492@P2CTi<0UIFE06MWI`1HF5P0Kfm_05ADE01CDe<0G5aL0410@01BDU80MgMg059B
DP12@T80DE5A08R8R02CTi<0R8R805eMG@18B4P0De=C05eMG@1EEED0CDe=03Lg=`1EEED0Bd];04E5
A@12@T80Hf=S069RHP0b<S80HF5Q0861P@1]KFd0F5QH055AD@1JFUX0FEUI07EeM@1`L700I6AT08j>
SP1>CTh0DE5A028R8P0l?3`0FEUI04=3@`1ADE40E5AD04A4A021PH40A4A4069RHP1WIfL0Ng]k059B
DP1OGel0MGEe03De=@1=CDd0DU9B03lo?`1RHV80CTi>03<c<`1HF5P0B4Q805mOG`18B4P0IfMW0080
?clo02d0ATI606MWI`1@D500C4a<075aL@1YJFT0KFe]05iNGP1cLg<0NGUi06a/K01GEeL0?Cdm05iN
GP1QHF40?Cdm04i>CP2FUYH0f][J09NGU`1MGEd0Bd];03`l?00j>SX0=CDe04Q8B00h>3P0ATI603hn
?P1HF5P0>c/k04E5A@1@D500C4a<03hn?P14A4@0=3@d04a<C00m?Cd0BDU9055AD@1XJ6P0>c/k04E5
A@1:BTX00P0m?Cd04@1?Cdl0L71`07alO00o?cl0D51@05ADE01kNg/0Jf][04M7A`1LG5`0Bd];06EU
I@1FEUH0@T9205IFEP1kNg/0K6a/0080KVi^06/0FEUI06=SH`15ADD0I6AT08R8R01=CDd0WIfM07=c
L`0j>SX0Ogmo04i>CP28R8P0WYjN03@d=02@T900Shn?09JFUP28R8P0LW9b08Z:RP1nOWh0HV9R04a<
C016ATH0IVIV05IFEP12@T80@d=3071`L01CDe<0GUiN05=CD`1;Bd/0EeMG04U9B@1SHf<0>c/k03Ti
>@1fMWH0DE5A09bLW02a/K40E5AD07UiN@1kNg/0ATI604m?C`0g=cL0JVYZ03De=@1DE5@0FEUI02LW
9`13@d<0?Cdm038b<P1mOGd0Ng]k05eMG@27QhL0;bl_04a<C01dM7@0NWYj05]KF`1aLG40PH6104E5
A@1>CTh0@d=303Lg=`1DE5@0ATI60492@P1DE5@0=3@d04e=C@19BDT0E5AD06QXJ012@T80?Shn07in
OP1:BTX0EUIF03Lg=`2DU9@0EEEE06QXJ00o?cl0HF5Q05EEE@19BDT0C4a<061PH01KFe/0EeMG04E5
A@0f=SH0BDU903Xj>P1GEeL0@T92055AD@1RHV80EeMG05iNGP0205YJFP1604Y:BP1MGEd0KVi^06i^
KP18B4P0N7Qh03hn?P0/;2`0FEUI04Q8B01oOgl0I6AT07=cL`1KFe/0E5AD071`L01DE5@0De=C06EU
I@1LG5`0F5QH03dm?@1RHV80?Shn0820P01]KFd0;Rh^04m?C`0i>CT0HV9R096AT@15ADD0<S8b07Ad
M00d=3@0@41006MWI`1GEeL0SHf=05YJFP1^KVh0BTY:0=CDe01mOGd0GemO0;>c/`1HF5P0^k^k08>3
P`1ZJVX0W9bL05YJFP2KVi/0JFUY03Xj>P1BDU80Bd];08^;R`1bLW80IFEU05EEE@1CDe<0@T9204i>
CP2QXJ40Shn?06MWI`1LG5`0PH6108>3P`;ooooo0000:P34a<@0EUIF07YjNP2[Zj/0Q8B407YjNP11
@D40EEEE0:6QX@1NGUh0MWIf079bLP0j>SX0;bl_07UiN@1LG5`0NGUi0:>SX`0m?Cd0@d=306IVIP2Z
ZZX0F5QH08j>SP1hN7P0;2`/04A4A01oOgl0LG5a05IFEP20P800=SHf02<S8`1SHf<0RHV903lo?`0n
?Sh0>c/k04U9B@15ADD0Q8B40861P@80:2PX07L0@T9204U9B@1;Bd/0LW9b05]KF`0O7al0E5AD04A4
A00a<C40IfMW0;Zj^P12@T80:2PX05mOG`14A4@0HF5Q0;bl_01`L7007AdM03lo?`12@T80BTY:08J6
QP2GUiL0:2PX02TY:@1@D500Lg=c04U9B@1mOGd0R8R801TI6@0U9BD0EUIF07QhN01CDe<0T92@06IV
IP0[:b/0EEEE06UYJ@1TI6@0K6a/0<?3``0i>CT0;bl_05UIF@2=SHd0HV9R07=cL`2i^KT0<c<c0410
@01TI6@0[jn_07EeM@1bLW80>SXj02LW9`18B4P0Shn?0:ZZZP2GUiL0bLW903lo?`0O7al0Fe]K09fM
W@1cLg<0ZZZZ079bLP0];Bd0=cLg05aLG02GUiL0J6QX08:2PP1BDU809BDU03hn?P29RHT0TY:B055A
D@25QHD0@41002/[:`0i>CT0IfMW09JFUP1@D500RHV905aLG00e=CD0B4Q808>3P`27QhL0De=C07Ad
M00m?Cd0E5AD06e]K@2LW9`0FUYJ05]KF`1SHf<0?Shn03Xj>P1dM7@0O7al0451@@1fMWH0?Shn03Xj
>P17AdL0UYJF04];B`1BDU80>CTi0492@P0207moO`3o04=3@`0j>SX0QHF50451@@25QHD0X:2P09nO
W`0h>3P0D51@07QhN01>CTh0UIFE0<71`@1LG5`09BDU05IFEP2IVIT0GemO09bLW038b<P0?clo03Ph
>017AdL0LG5a09:BTP2ZZZX0gMgM04e=C@0o?cl0Ti>C0;Rh^01iNGT0/K6a07alO00X:2P0B4Q80:j^
[P1mOGd0Vi^K0<71`@0Z:RX0<C4a05mOG`2n_[h0R8R80:RXZ02^[Zh0:BTY05]KF`2<S8`0QhN7071`
L02l_;`0FUYJ03dm?@2BTY80WYjN05iNGP2CTi<0J6QX03Lg=`16ATH0Z:RX09bLW01jNWX0Ogmo03Ti
>@1oOgl0/;2`07]kN`29RHT0IVIV03/k>`1QHF40[Zj^0:BTY01LG5`0I6AT02/[:`17AdL0aLG50<_;
b`1UIFD0Q8B40861P@15ADD0D51@0<G5a@1]KFd0PX:208n?S`15ADD0CTi>06=SH`1lO7`0=CDe079b
LP1_Kfl0@D5106QXJ02c/k<0GEeM03Lg=`1TI6@0IVIV051@D02NWYh0/K6a03<c<`0V9RH0J6QX07mo
O`1=CDd0MWIf0:VYZ@0k>c/0:b/[06UYJ@1XJ6P0CDe=0:6QX@1RHV807QhN03Ti>@1MGEd0De=C07If
MP2l_;`0D51@02h^;P17AdL0E5AD05]KF`1OGel0Y:BT06YZJP0m?Cd0Jf][061PH01OGel0IFEU0:BT
Y028R8P0<30`04=3@`1CDe<0Ng]k07IfMP2[Zj/0>c/k01XJ6P0[:b/0Shn?0861P@1:BTX0UiNG08:2
PP1GEeL0BDU906i^KP1SHf<0LW9b07MgM`11@D40C4a<04];B`0k>c/0?clo055AD@1/K6`0EEEE05AD
E01QHF40G5aL0820P01/K6`0CTi>04=3@`0f=SH0De=C04E5A@1XJ6P0DE5A05IFEP1CDe<0@T9205]K
F`1MGEd0M7Ad05=CD`0j>SX0De=C069RHP1XJ6P0D51@05MGE`1LG5`0Cdm?075aL@11@D40@d=3069R
HP19BDT0LG5a05eMG@1IFET0T92@04Q8B01UIFD0Ph>306UYJ@1;Bd/0IVIV06e]K@1EEED0FUYJ065Q
H@1YJFT0Lg=c06QXJ01=CDd0JVYZ05ADE02FUYH0De=C09ZJVP0o?cl0De=C04Y:BP1lO7`0EeMG04U9
B@1gMgL0B4Q806EUI@1aLG40TI6A08n?S`10@400DU9B02@T900c<c<0IVIV05eMG@2FUYH0Shn?0:JV
YP2BTY80JFUY05IFEP1<C4`0DE5A04m?C`1]KFd0>CTi003J05IFEP0e=CD0IFEU03Hf=P1<C4`0AdM7
07AdM01<C4`0G5aL03`l?00m?Cd0CTi>04];B`1ZJVX0GUiN04=3@`19BDT0A4A403lo?`0g=cL0C4a<
03`l?026QXH0B4Q804];B`1?Cdl0EUIF06ATI018B4P0K6a/07]kN`1CDe<0BDU90410@018B4P0KVi^
08N7Q`1aLG40P820071`L02>SXh0EUIF06m_K`2BTY80Cdm?0;Vi^@20P800@d=306m_K`1HF5P0G5aL
07QhN01CDe<0[jn_07=cL`1FEUH0HV9R05iNGP1FEUH0BTY:061PH01IFET0<S8b03dm?@1MGEd0Hf=S
038b<P34a<@0:2PX05UIF@0l?3`0Kfm_051@D013@d<0H61P06EUI@1;Bd/0Ogmo05UIF@2[Zj/0bl_;
03Ph>013@d<0<S8b05ADE01UIFD0ATI609JFUP1YJFT0Jf][092@T00m?Cd0L71`061PH01<C4`0EUIF
04Y:BP0n?Sh0M7Ad03Hf=P1IFET0EUIF03hn?P0[:b/0KVi^0:b/[013@d<0JFUY04e=C@1:BTX0@d=3
0410@029RHT0Ph>303Ph>01PH600F5QH08:2PP2NWYh0FEUI05ADE01eMGD0C4a<05QHF00o?cl0G5aL
06][J`2FUYH0E5AD06i^KP0];Bd0IfMW06][J`14A4@0Bd];04Q8B00o?cl0:2PX07emO@10@400>SXj
05QHF01PH600B4Q804e=C@1GEeL0B4Q803hn?P13@d<0@410075aL@2i^KT0C4a<0:JVYP1JFUX0B4Q8
061PH01CDe<0B4Q8030`<01RHV80AdM702`/;00o?cl0DU9B07inOP1=CDd0AdM706e]K@1`L700PH61
05QHF02b/[80O7al03Ti>@17AdL0>c/k05iNGP1TI6@0CTi>04U9B@30`<00HV9R06=SH`1hN7P0Cdm?
04];B`1PH600U9BD06e]K@23Ph<0GUiN04i>CP1nOWh0SHf=0>_[j`2EUID0Hf=S0;bl_01BDU80OGem
04i>CP14A4@0De=C04Q8B01SHf<0NGUi07emO@1UIFD0A4A405=CD`1eMGD0[jn_07=cL`1dM7@0QHF5
07UiN@2:RXX2ooooo`0009L0UiNG06][J`1oOgl0D51@06i^KP2BTY80C4a<05EEE@1?Cdl0?clo07Ui
N@2KVi/0=SHf03Ti>@1CDe<0EUIF06IVIP2SXj<0>SXj020P800o?cl0GUiN08^;R`2a/K40UYJF02XZ
:P0/;2`0EEEE0820P01GEeL0/K6a038b<P0[:b/0@D5107YjNP1DE5@0TI6A07UiN@0/;2`0>CTi05=C
D`1oOgl0GUiN07IfMP2n_[h0<c<c02`/;01lO7`0V9RH03lo?`2TY:@0IFEU03De=@11@D40WinO08F5
Q@1LG5`0ZZZZ03<c<`0R8R80@T920;Ng]`1XJ6P0RXZ:03@d=00c<c<0@d=307UiN@2LW9`0EeMG08J6
QP0m?Cd0<C4a0492@P1XJ6P0ATI606EUI@2ATI409bLW04E5A@1RHV80K6a/03Lg=`1EEED0SXj>02HV
9P0a<C40M7Ad08V9R@0c<c<0EeMG06e]K@0d=3@0@d=3071`L01VIVH0<c<c07MgM`0g=cL0?clo04M7
A`1WIfL0=CDe06IVIP1bLW80De=C055AD@23Ph<0De=C02HV9P19BDT0E5AD03De=@2>SXh0^[Zj02d]
;@0Z:RX0?3`l059BDP0o?cl0RXZ:08N7Q`0M7Ad0=cLg05=CD`1GEeL0De=C0:n_[`1kNg/09BDU03dm
?@15ADD0GemO06QXJ038b<P0QhN702<S8`17AdL0G5aL06IVIP1UIFD0cLg=06EUI@0U9BD0G5aL09fM
W@1_Kfl0U9BD09RHV00/;2`0@4100080Ng]k01@0LG5a0;Jf]P20P80092@T0451@@1UIFD0JVYZ09nO
W`0l?3`0=SHf05aLG02LW9`0cLg=06IVIP39bLT0;Rh^04U9B@2ATI40U9BD07inOP80QhN704008R8R
04i>CP2PX:00Shn?05=CD`2?Shl0C4a<02TY:@1<C4`0[Zj^0:6QX@1CDe<0NWYj030`<01BDU80FEUI
0;:b/P2MWId0Fe]K06m_K`0`<300DE5A05UIF@2f][H0IVIV06][J`1TI6@0?Cdm03lo?`2BTY80LW9b
03/k>`14A4@0De=C03Ph>01[Jf/0];Bd05ADE00b<S80NGUi05IFEP19BDT0clo?0;Rh^00g=cL0ATI6
0410@00n?Sh0GemO08n?S`0d=3@0=cLg04e=C@1GEeL0YJFU0:f][@0`<300A4A408B4Q01dM7@0b<S8
09nOW`0Z:RX0=3@d0P1]KFd0LP2KVi/0];Bd03hn?P0a<C40Hf=S09VIV@29RHT0Y:BT08>3P`0l?3`0
GEeM0820P01bLW80^k^k0;jn_P0`<300@41007alO029RHT0EeMG0:RXZ02FUYH0?clo05MGE`1QHF40
Vi^K06][J`2c/k<0GEeM03Hf=P1PH600RXZ:0;>c/`1jNWX0XZ:R069RHP0l?3`0CTi>07alO021PH40
J6QX0;Bd]01=CDd0Bd];04i>CP1aLG40CTi>07alO01/K6`0?clo055AD@1dM7@0^[Zj05EEE@2<S8`0
QHF503/k>`11@D40N7Qh0:6QX@19BDT0MgMg07alO00];Bd0=CDe061PH02LW9`0E5AD05EEE@21PH40
<S8b02/[:`2ATI40[:b/030`<01PH600;2`/03lo?`1;Bd/0EUIF061PH01BDU80Bd];04e=C@0m?Cd0
B4Q808N7Q`1CDe<0K6a/055AD@1HF5P0EEEE05=CD`1NGUh0JVYZ07MgM`2;Rh/0NWYj07EeM@1dM7@0
IFEU04];B`0f=SH0LG5a04a<C00f=SH0AdM7079bLP1NGUh0>3Ph04a<C010@400=cLg051@D080AdM7
01X0<C4a05]KF`1@D500GUiN06=SH`1LG5`0Cdm?03<c<`1:BTX0DU9B05EEE@2<S8`0IVIV06e]K@1H
F5P0ATI605iNGP2ATI40NWYj04e=C@1DE5@0K6a/04U9B@1HF5P0CDe=03lo?`80Cdm?00L0Bd];06QX
J01ZJVX0QXJ608N7Q`2XZ:P0DU9B0080GUiN0:80PX:206i^KP1RHV80MGEe07AdM01gMgL0E5AD075a
L@2EUID0GEeM06UYJ@0_;bl0>c/k059BDP0m?Cd0K6a/04e=C@19BDT0ZZZZ06QXJ01RHV80@d=304e=
C@1KFe/0HF5Q04Y:BP1ADE40De=C079bLP16ATH0C4a<05]KF`1RHV80D51@065QH@0d=3@0C4a<059B
DP1OGel0Ti>C07=cL`1;Bd/0DE5A04M7A`1>CTh0?clo04i>CP1=CDd0UIFE05UIF@1BDU80EUIF079b
LP20P800De=C096AT@1gMgL0FUYJ04e=C@0l?3`0B4Q808R8R01gMgL0NGUi06QXJ01HF5P0Hf=S04Q8
B01TI6@0VYZJ08:2PP2][Jd0PH6106i^KP2GUiL0PX:206YZJP2?Shl0EEEE09FEU@2GUiL0QhN706i^
KP1SHf<0SXj>0820P01TI6@0De=C04m?C`1DE5@0DE5A0492@P0a<C40X:2P02`/;01BDU80<c<c071`
L01JFUX0B4Q805QHF01=CDd0LG5a0<S8b01DE5@0V9RH0;>c/`1NGUh0D51@059BDP1SHf<0MWIf04m?
C`1TI6@0@D5107=cL`2BTY80Fe]K06a/K01^KVh0ATI605]KF`1QHF40KVi^0;^k^`1/K6`0De=C06AT
I026QXH0Cdm?05UIF@1VIVH0Bd];079bLP1aLG40A4A403lo?`0j>SX0D51@04Q8B00Q8B40Jf][05mO
G`1ADE40CTi>04a<C017AdL0D51@06MWI`2=SHd0IfMW07QhN01IFET0KVi^05eMG@23Ph<0;Rh^03lo
?`0j>SX0=3@d04=3@`1CDe<203lo?`1@04Y:BP17AdL0@d=304U9B@17AdL0De=C04i>CP1@D500ATI6
04U9B@1cLg<0>SXj04E5A@1MGEd0IfMW05=CD`16ATH0ADE506UYJ@0d=3@0DE5A03<c<`1RHV80E5AD
0492@P1?Cdl0Hf=S09^KV`1DE5@0KFe]07inOP1WIfL0BTY:05EEE@1dM7@0IfMW07AdM01nOWh0G5aL
05MGE`1LG5`0;bl_03Lg=`1oOgl0De=C05iNGP20P800Cdm?04a<C01NGUh0Shn?06ATI02i^KT0CTi>
04a<C01YJFT0D51@06e]K@21PH40MgMg0=GEe@1IFET0V9RH09BDU029RHT0PH6106ATI01RHV80RXZ:
09nOW`1ZJVX0DU9B07=cL`1aLG40WinO07emO@28R8P0RXZ:08V9R@27QhL2ooooo`000?l0LG5a0861
P@35aLD0De=C05QHF02@T900MgMg0:NWY`2NWYh0<C4a05iNGP2KVi/0PH6107UiN@22PX80>CTi04a<
C01eMGD0PH6108Z:RP2BTY80FEUI07IfMP1RHV80XZ:R06UYJ@1RHV80MWIf028R8P0e=CD0IFEU0:NW
Y`0o?cl0P82006EUI@0S8b<0@D5107inOP1aLG40@41007moO`1@D5007QhN04i>CP1YJFT0HF5Q03Lg
=`1gMgL0B4Q803Ti>@24Q8@0RHV902XZ:P1CDe<0B4Q804E5A@1GEeL0QXJ605IFEP0P8200>c/k03Ti
>@13@d<0U9BD05aLG00M7Ad0A4A404i>CP1LG5`0?Cdm08n?S`1/K6`07AdM05]KF`1LG5`0=cLg06AT
I02i^KT0ATI601HF5P1BDU80O7al04i>CP1bLW80`l?302l_;`0/;2`0>c/k07EeM@1EEED0P82009^K
V`0`<300Bd];05QHF01[Jf/0Bd];0<S8b01QHF40<30`05YJFP1BDU80DE5A09ZJVP2MWId08B4Q02h^
;P1UIFD0LG5a059BDP1`L700LG5a03Hf=P1@D500GUiN075aL@1KFe/0OGem03Ph>01ADE40GUiN06m_
K`16ATH0BTY:07YjNP0^;Rh0<c<c069RHP2>SXh0ATI6061PH01OGel0:b/[038b<P1QHF40R8R804Q8
B01QHF40Lg=c03/k>`17AdL0P8200<S8b01DE5@0Hf=S04Q8B00e=CD0CDe=0820P01dM7@0B4Q806UY
J@0V9RH0ATI607YjNP22PX80FUYJ071`L021PH40@T9207]kN`1gMgL0;2`/05MGE`1BDU80A4A405QH
F02b/[80EEEE02DU9@1LG5`0LW9b05ADE01[Jf/0[jn_02h^;P0_;bl0KFe]05QHF00m?Cd0U9BD09>C
T`0N7Qh0<c<c05QHF028R8P0IVIV0:ZZZP1YJFT0;bl_04m?C`1BDU80RXZ:071`L02m_Kd0=CDe04=3
@`1?Cdl0Ng]k06UYJ@2OWil0XJ6Q02l_;`1GEeL0G5aL08n?S`1PH600];Bd07inOP0g=cL0Ogmo09JF
UP2d];@0QhN70<K6aP1ADE40=3@d096AT@2h^;P0RHV90<?3``0n?Sh0<C4a05MGE`2l_;`0SHf=09ZJ
VP1cLg<09bLW04m?C`28R8P0T92@08:2PP1QHF40@41007EeM@2SXj<0R8R807IfMP2JVYX0<S8b05QH
F02YZJT0NGUi04i>CP1WIfL0FUYJ03<c<`25QHD0[Jf]07moO`25QHD0E5AD034a<@1@D50001l0[jn_
0:6QX@1ADE40K6a/0451@@1PH600Kfm_0:>SX`1ZJVX0Fe]K07IfMP0a<C40BDU909ZJVP2g]kL0ADE5
06UYJ@1]KFd0<c<c04e=C@1oOgl0WinO03Ti>@1@D500@T920451@@1YJFT0U9BD09fMW@15ADD0I6AT
0080@d=302D0SHf=0;Vi^@15ADD0C4a<05mOG`1jNWX0K6a/09ZJVP2LW9`0ATI602`/;014A4@0Lg=c
04Q8B01nOWh0]KFe03`l?00W9bL0=CDe07moO`1IFET0JVYZ0;6a/@0l?3`0=3@d04e=C@1PH600Cdm?
0;Fe]@2WYjL0?Cdm04e=C@1XJ6P0R8R806a/K01QHF40JVYZ0080CDe=00<0A4A403De=@17AdL00P1;
Bd/08P0c<c<0<S8b04i>CP1LG5`0E5AD02@T900[:b/0?clo04I6AP0j>SX0@d=303Lg=`0h>3P0ATI6
065QH@19BDT0A4A404i>CP10@400G5aL0451@@13@d<0A4A40410@01;Bd/0AdM704e=C@1@D500GemO
06UYJ@12@T80DU9B02LW9`13@d<20492@P0<07=cL`1HF5P0E5AD06YZJP1>CTh0EUIF06i^KP2BTY80
FUYJ05iNGP2CTi<0Bd];0P1XJ6P0ZP1;Bd/0GUiN04E5A@10@400CTi>04m?C`1WIfL0EeMG07]kN`0i
>CT0@T9204E5A@1UIFD0Cdm?04a<C01bLW80B4Q805YJFP1TI6@0Q8B408n?S`1;Bd/0LW9b05IFEP1c
Lg<0JVYZ04Q8B019BDT0Jf][04e=C@2e]KD0Jf][04a<C01;Bd/0Cdm?04Q8B01ADE40@d=305=CD`0n
?Sh0DE5A030`<013@d<0>SXj03hn?P0`<300BDU904E5A@1EEED0BDU904I6AP1PH600QXJ605IFEP1D
E5@0Bd];04Q8B017AdL0EEEE06YZJP25QHD0ATI605=CD`1?Cdl0M7Ad07IfMP1XJ6P0OGem06=SH`1R
HV80@D5104=3@`1YJFT0QXJ607emO@2BTY80T92@05]KF`1LG5`0RHV908R8R035aLD0^;Rh0;Ng]`1o
Ogl0C4a<07UiN@15ADD0O7al0:ZZZP0^;Rh0UYJF08J6QP2LW9`0X:2P05IFEP1MGEd0Fe]K05mOG`11
@D40;bl_05IFEP1KFe/0E5AD05EEE@2?Shl0Hf=S04a<C00S8b<0Jf][04i>CP17AdL0ZZZZ020P8018
B4P0Jf][06ATI02e]KD0c/k>05eMG@1gMgL0KVi^059BDP1ADE40?Cdm09^KV`0_;bl0I6AT07EeM@0a
<C40DU9B051@D00W9bL0L71`06i^KP0e=CD0EeMG02h^;P13@d<0F5QH06=SH`1JFUX0Jf][071`L011
@D40ADE503Ph>00k>c/0D51@02l_;`1IFET0EEEE02TY:@1YJFT0G5aL05mOG`1]KFd0?Cdm055AD@1V
IVH0?clo05]KF`1@D500Shn?05YJFP1ZJVX0ADE507EeM@1DE5@0ATI60P1>CTh0<01=CDd0DE5A03/k
>`0S8b<0DE5A03De=@15ADD0?3`l04A4A01DE5@0AdM7055AD@0o?cl0@41004i>CP0k>c/0NWYj07in
OP0];Bd0Hf=S02l_;`0c<c<0JFUY03hn?P19BDT0:b/[05eMG@16ATH0BTY:061PH027QhL0^;Rh061P
H01cLg<0QHF507AdM01OGel0IfMW0:BTY025QHD0A4A403Lg=`1DE5@0G5aL05iNGP1LG5`0Ogmo0;Jf
]P80EEEE0280Lg=c04Y:BP2ATI40FUYJ09FEU@1GEeL0^KVi08n?S`1GEeL0Kfm_07YjNP2/[:`0MGEe
09BDU03UiND0Ph>309JFUP22PX80DE5A06i^KP1EEED0L71`09bLW02;Rh/0HV9R05UIF@1RHV80M7Ad
09ZJVP1cLg<0G5aL07=cL`1mOGd0Lg=c0_ooool000090:JVYP1OGel0Lg=c0=SHf02BTY80OGem05EE
E@1^KVh0Ph>30080EEEE0?l0IFEU02h^;P1dM7@0/K6a02h^;P0j>SX0F5QH03`l?01FEUH0IFEU04];
B`0_;bl0ADE505=CD`1GEeL0]KFe0;Bd]00e=CD0<S8b05EEE@1BDU80C4a<0;:b/P1lO7`08b<S02/[
:`0i>CT0Cdm?05MGE`2PX:00A4A4020P800l?3`0De=C071`L01aLG40d=3@07MgM`0Y:BT0C4a<08f=
S@1HF5P0`L7109FEU@0L71`0;2`/05IFEP1mOGd0ADE508Z:RP0_;bl06ATI03hn?P2@T900ATI609ZJ
VP1^KVh0;Bd]01`L7015ADD0QHF504A4A01hN7P0E5AD01DE5@0^;Rh0H61P08:2PP1PH600Lg=c04e=
C@0U9BD0A4A406a/K01iNGT0DU9B05IFEP0b<S80;2`/0451@@1RHV80De=C04m?C`1RHV80:RXZ02/[
:`1=CDd0OGem04A4A01KFe/0EeMG01lO7`1?Cdl0Ph>305IFEP12@T80IVIV03Hf=P0^;Rh0NGUi08J6
QP0];Bd0ATI605iNGP0g=cL0AdM708J6QP1WIfL0820P04];B`1TI6@0GEeM06IVIP2CTi<0CDe=034a
<@1ADE40Fe]K05YJFP1XJ6P0Shn?03De=@0W9bL0ADE5065QH@1TI6@0P8200:BTY01;Bd/0?Cdm05]K
F`27QhL0MgMg0::RXP1^KVh0;Bd]05MGE`1JFUX0DU9B05eMG@2f][H0IFEU01lO7`1DE5@0R8R8061P
H02KVi/0`/;203Lg=`1VIVH0ZJVY04U9B@2DU9@0SXj>02TY:@1BDU80UYJF0<71`@1LG5`0/[:b07=c
L`1?Cdl0De=C07AdM01YJFT0H61P075aL@0R8R80@T9205IFEP1CDe<0BTY:06UYJ@1kNg/0=SHf03/k
>`25QHD0ZZZZ05IFEP1oOgl0LW9b04E5A@1dM7@0U9BD092@T01?Cdl0HF5Q05IFEP0h>3P0J6QX0:j^
[P1mOGd0E5AD07alO010@400=SHf05iNGP2QXJ40Fe]K06a/K01jNWX0<C4a04e=C@1_Kfl0OWin05QH
F02;Rh/0>c/k04E5A@2SXj<0TY:B02h^;P13@d<0?Cdm04];B`1kNg/0/K6a04];B`1:BTX0HF5Q05]K
F`2i^KT0Rh^;03/k>`1FEUH0Lg=c03lo?`27QhL0e=CD04e=C@0o?cl0N7Qh08R8R01aLG40`l?309FE
U@0U9BD0@41007]kN`1cLg<0]KFe07YjNP0T92@0DE5A07]kN`1`L700N7Qh0<O7a`17AdL0=SHf05aL
G02ATI40OGem08R8R03:b/X00600?Cdm01`L701IFET0[:b/05EEE@2DU9@0QhN702XZ:P0Y:BT0DE5A
0:^[Z`1VIVH0ZZZZ08Z:RP0U9BD0D51@05iNGP23Ph<0LW9b0:VYZ@1FEUH0:BTY059BDP2JVYX0J6QX
06m_K`26QXH0>3Ph04E5A@1iNGT0SXj>07UiN@1HF5P0MGEe04Q8B00/;2`0@D5105eMG@1]KFd0EEEE
07MgM`1PH600<c<c03dm?@1WIfL0NWYj04i>CP2HV9P0=SHf02PX:01YJFT0U9BD069RHP1=CDd0IVIV
06=SH`11@D40ADE506e]K@19BDT0DE5A07YjNP12@T80IVIV06i^KP1=CDd0@D5105aLG01[Jf/0Lg=c
07QhN01SHf<0CDe=06ATI01<C4`0ATI6038b<P0_;bl0Bd];03Ph>00V9RH0@D5104];B`0j>SX07AdM
04A4A01ADE40B4Q804I6AP0a<C40F5QH04I6AP1KFe/0BTY:03/k>`1>CTh204I6AP1:02DU9@12@T80
?3`l03De=@1=CDd0@T9204e=C@1>CTh0>CTi05UIF@1UIFD0GEeM05=CD`1EEED0MGEe04Q8B01[Jf/0
E5AD02DU9@1XJ6P0ATI603Ph>01PH600L71`07emO@1BDU80S8b<051@D01MGEd0BTY:08J6QP1ZJVX0
IFEU09JFUP17AdL0IVIV07QhN02JVYX0U9BD05YJFP1BDU80=cLg04Y:BP1IFET0BTY:059BDP1LG5`0
IfMW071`L00k>c/0Bd];03lo?`12@T80A4A404Y:BP1;Bd/0DU9B04A4A01@D500=cLg04];B`16ATH0
E5AD04m?C`1SHf<0BDU903@d=01:BTX0HF5Q04U9B@1>CTh0Cdm?05IFEP13@d<203lo?`1804U9B@1C
De<0F5QH03Xj>P1BDU80Cdm?09RHV01IFET0EeMG08:2PP1NGUh0IVIV0492@P0o?cl0@D5106][J`1e
MGD0Lg=c08J6QP1dM7@0EeMG03lo?`13@d<0XJ6Q07emO@2TY:@0FUYJ05mOG`1nOWh0GEeM05mOG`2:
RXX0H61P0<g=c@1YJFT0GEeM06i^KP1kNg/0Jf][07YjNP1]KFd0Jf][04E5A@1IFET0F5QH05mOG`1D
E5@0alO704Y:BP1^KVh0Bd];08n?S`1QHF40JVYZ079bLP1:BTX0HF5Q09FEU@21PH40hN7Q0=?Cd`0m
?Cd0De=C04Q8B01OGel0JVYZ05EEE@1iNGT0=CDe06=SH`1ZJVX0EeMG0P2<S8`0L00b<S80IFEU06YZ
JP0l?3`0Ng]k02/[:`1@D500De=C04=3@`0T92@0IfMW07]kN`0[:b/0MWIf04e=C@11@D40B4Q80451
@@1EEED0GUiN04a<C01]KFd0Jf][05ADE01OGel0C4a<038b<P1GEeL0>SXj05]KF`1QHF40Q8B408Z:
RP2][Jd0GEeM07MgM`0d=3@0GemO079bLP0a<C40<c<c04m?C`0_;bl071`L05eMG@0Y:BT0BTY:04A4
A01<C4`0EUIF04m?C`1EEED0BDU90492@P1WIfL07alO061PH01ADE40<S8b08f=S@0`<300<C4a05iN
GP0m?Cd0IfMW02l_;`1UIFD0C4a<03dm?@14A4@0N7Qh08V9R@1DE5@0JVYZ07MgM`1XJ6P0MGEe04m?
C`20P800K6a/06QXJ01VIVH0E5AD06ATI01WIfL0=CDe05ADE01LG5`0FUYJ05eMG@1KFe/0CDe=04Y:
BP1PH600QHF509BDU03De=@0TY:B08n?S`2^[Zh0JVYZ09fMW@2`/;00Z:RX0=kNgP2CTi<0/k>c06IV
IP12@T80EeMG04Q8B01aLG4207MgM`0:079bLP1<C4`0D51@05QHF02;Rh/0JFUY079bLP1DE5@0Ph>3
09FEU@;ooooo0000k`37alL0EEEE07]kN`2f][H0Vi^K0:b/[00g=cL0FEUI065QH@1aLG40Q8B409ZJ
VP0Y:BT0BTY:08N7Q`1YJFT0Rh^;06MWI`0c<c<0:b/[04];B`25QHD0IFEU09:BTP2IVIT06ATI05UI
F@2i^KT0Hf=S05ADE02NWYh0=cLg01/K6`1QHF40Shn?04];B`1VIVH0HF5Q02<S8`0a<C40JFUY0;jn
_P19BDT0MWIf08B4Q00T92@0:b/[075aL@2:RXX0ADE505QHF00i>CT0=CDe04m?C`1`L700EeMG04E5
A@21PH40@D5105IFEP2OWil0Shn?03Ph>01CDe<0CTi>03Ti>@23Ph<0Rh^;04U9B@0[:b/0ATI604Q8
B00e=CD0QHF508b<S00W9bL0:RXZ0451@@1KFe/0?3`l08R8R01YJFT092@T02d];@1ADE40HF5Q069R
HP2^[Zh0K6a/02DU9@0b<S80EUIF06=SH`1bLW80/K6a04A4A00`<300>c/k05mOG`1>CTh0MGEe08n?
S`0Z:RX0<S8b05MGE`1oOgl0Kfm_08^;R`1CDe<0=SHf03dm?@1PH600EEEE08Z:RP2KVi/092@T03<c
<`0m?Cd0F5QH05UIF@22PX80K6a/02LW9`0_;bl0Cdm?06m_K`1TI6@0Y:BT06e]K@0a<C40BDU905YJ
FP1NGUh0H61P0:BTY01JFUX0;bl_059BDP1GEeL0PH6106IVIP2f][H0<c<c0410@01kNg/0VIVI04e=
C@1ZJVX0HV9R03/k>`10@400O7al09^KV`1EEED0NWYj04a<C00Y:BT0F5QH0:^[Z`1TI6@0F5QH04Y:
BP17AdL0KFe]08V9R@1IFET0D51@079bLP0m?Cd0@d=308Z:RP2PX:00;bl_04Q8B015ADD0>3Ph07al
O030`<00DU9B02HV9P1NGUh0Fe]K04I6AP2BTY80[Jf]03De=@0K6a/0?Shn06=SH`18B4P0VYZJ0820
P00/;2`0A4A408>3P`2<S8`0LW9b09jNWP1gMgL0<30`03De=@1YJFT0Ng]k0861P@37alL0Bd];034a
<@19BDT0EEEE06][J`3De=@0_Kfm02/[:`1EEED0SHf=065QH@1EEED0hn?S05EEE@0W9bL0L71`0::R
XP1MGEd0Rh^;03lo?`13@d<0IfMW0;Fe]@1gMgL0G5aL06EUI@0O7al0HF5Q0;Zj^P26QXH0QhN706e]
K@18B4P0CDe=0080Shn?06<0Ng]k06i^KP0n?Sh0C4a<05aLG02g]kL0L71`09^KV`1`L700?Cdm06a/
K02c/k<0J6QX06IVIP1hN7P0A4A404];B`1dM7@0^k^k04i>CP1FEUH0BDU9030`<01=CDd0Ogmo07em
O@1:BTX0IFEU03Ph>00m?Cd0VYZJ0;Jf]P1MGEd0<c<c065QH@1ADE40>SXj07QhN033`l<0FUYJ04A4
A01_Kfl0AdM704i>CP2<S8`0[Jf]05MGE`18B4P0De=C04e=C@1^KVh0PX:203`l?00`<300BDU906EU
I@0m?Cd0P8200;Jf]P1XJ6P07alO03Ti>@1LG5`0@d=304e=C@2e]KD0`l?3034a<@0_;bl0AdM704E5
A@1PH600XZ:R08N7Q`0Q8B40>CTi05MGE`1KFe/0B4Q8069RHP2;Rh/0DU9B04Y:BP1SHf<0Cdm?05]K
F`1UIFD0A4A40410@00m?Cd0?clo04M7A`1CDe<0C4a<04I6AP1;Bd/0Jf][05=CD`1EEED00P1GEeL0
5P19BDT0:RXZ05UIF@17AdL0@T9204U9B@1[Jf/0FEUI03Xj>P18B4P0CDe=05=CD`1@D500?clo051@
D017AdL0Hf=S05QHF01CDe<0HV9R05UIF@1CDe<204];B`0[06EUI@1DE5@0Kfm_055AD@1PH600PX:2
04i>CP1TI6@0LW9b07IfMP1?Cdl0>c/k05aLG01NGUh0H61P04i>CP0b<S80DU9B03hn?P0f=SH0CDe=
059BDP1TI6@0AdM705=CD`0`<300CDe=03lo?`1KFe/0C4a<04i>CP1dM7@0ADE505]KF`1BDU80J6QX
07MgM`1RHV80MgMg03Hf=P0n?Sh0JFUY05eMG@0206YZJP0W08n?S`1^KVh0@41005YJFP18B4P0CDe=
0451@@1BDU80>SXj051@D00m?Cd0EeMG04m?C`17AdL0C4a<05EEE@13@d<0AdM703/k>`13@d<0Bd];
0410@01DE5@0GemO04E5A@1DE5@0@d=305aLG01>CTh0De=C06IVIP1nOWh0IFEU06YZJP1CDe<0@410
05YJFP29RHT0UiNG0080C4a<01h0DU9B05ADE01JFUX0HF5Q06m_K`1bLW80P82006][J`2GUiL0HF5Q
06e]K@2g]kL0YJFU0<[:bP23Ph<0Hf=S0:6QX@1bLW80IFEU06a/K00o?cl0SXj>06i^KP1UIFD0Lg=c
07QhN023Ph<0Ng]k06=SH`1_Kfl204I6AP1f06IVIP1DE5@0IFEU0=kNgP14A4@0Jf][03lo?`23Ph<0
>CTi03`l?026QXH0;Bd]06m_K`2[Zj/0DE5A09NGU`2_[jl0DU9B05MGE`1VIVH0K6a/06e]K@11@D40
TI6A04U9B@1RHV80QhN705YJFP1>CTh0A4A4034a<@1^KVh0L71`03hn?P2c/k<0>c/k06MWI`1SHf<0
NGUi04I6AP1ZJVX0KVi^03hn?P1jNWX0Fe]K04I6AP17AdL0ADE507emO@19BDT0:2PX05iNGP1PH600
LW9b08b<S01FEUH0B4Q804Y:BP14A4@0J6QX06a/K02=SHd0?Cdm05aLG00n?Sh0HF5Q05aLG018B4P0
>c/k04M7A`0k>c/0DU9B03@d=00g=cL0@d=303hn?P1>CTh0@d=30451@@1?Cdl0BTY:051@D00k>c/0
F5QH055AD@0a<C40NWYj059BDP1HF5P0Ti>C02`/;00h>3P0FEUI02XZ:P11@D40Cdm?065QH@17AdL0
@d=304E5A@1TI6@0H61P055AD@1EEED0PX:206e]K@1EEED0CTi>06m_K`1]KFd0?3`l03dm?@1>CTh0
G5aL069RHP1QHF40K6a/096AT@80Cdm?01l0IFEU0410@01ADE40GEeM08j>SP1TI6@0WIfM06][J`1C
De<0IfMW09jNWP2`/;00V9RH0<K6aP2ZZZX0PH6109NGU`2ATI40D51@05]KF`1>CTh0Kfm_092@T01^
KVh0Hf=S03Ti>@1FEUH0Lg=c09nOW`1VIVH0Ng]k0080Jf][0@2JVYX1ooooo`7ooooo00006`2KVi/0
MWIf08^;R`1<C4`0IFEU0:>SX`1dM7@0H61P05aLG00d=3@0F5QH09NGU`1DE5@0HF5Q05IFEP0`<300
GEeM09JFUP14A4@0=cLg0451@@14A4@0?3`l07AdM02SXj<0ADE503Ph>00206ATI01f069RHP2EUID0
FUYJ024Q8@0k>c/0IFEU051@D01ZJVX0N7Qh028R8P0^;Rh0=SHf06ATI012@T80[:b/0;Fe]@0U9BD0
<C4a04=3@`1:BTX0GemO09jNWP1[Jf/0:b/[05aLG01dM7@0F5QH0820P02/[:`092@T04E5A@1MGEd0
JFUY06=SH`26QXH0IVIV024Q8@0e=CD0NWYj092@T01OGel0cLg=0410@00k>c/0A4A407=cL`1LG5`0
S8b<07emO@0i>CT0AdM703`l?01iNGT0DU9B08j>SP2SXj<0820P0410@019BDT0TY:B05MGE`25QHD0
UiNG02/[:`18B4P0HV9R07inOP1:BTX0PH6102`/;00`<300D51@08B4Q01RHV80GEeM05YJFP0R8R80
BDU905IFEP1ZJVX0ATI605QHF00n?Sh0>SXj05=CD`1bLW80E5AD03De=@1KFe/0>c/k03<c<`2JVYX0
[jn_05ADE00^;Rh0@D5102h^;P0f=SH0U9BD0:b/[00j>SX0?Shn05iNGP0l?3`0AdM709VIV@2[Zj/0
;Rh^04=3@`1MGEd0CDe=06a/K02k^k/0^[Zj03dm?@1HF5P0I6AT05ADE080V9RH0=l0>SXj03/k>`1^
KVh0OWin05EEE@2g]kL0J6QX02h^;P0g=cL0R8R807YjNP2[Zj/0HF5Q02d];@24Q8@0R8R807alO01i
NGT0c/k>03Ph>010@400Kfm_0:>SX`2BTY80WIfM05UIF@11@D40>3Ph0:ZZZP2VYZH0FUYJ07moO`1K
Fe/0>SXj034a<@2WYjL0Vi^K06EUI@1iNGT0L71`03De=@1>CTh0RHV907IfMP1UIFD0LG5a03De=@1?
Cdl0IfMW0:>SX`1YJFT0JVYZ05]KF`0S8b<0DU9B071`L02>SXh0CDe=07MgM`1>CTh0:2PX05aLG02U
YJD0GemO04m?C`1gMgL0>CTi04=3@`24Q8@0YJFU05EEE@1YJFT0BTY:02TY:@1QHF40QXJ603De=@14
A4@0K6a/05=CD`2BTY80Zj^[04];B`0j>SX0GUiN04I6AP2BTY80ZZZZ02l_;`0g=cL0I6AT04m?C`1o
Ogl0_Kfm05eMG@0[:b/0GEeM06MWI`1cLg<0YJFU0<30`01:BTX0C4a<05eMG@1GEeL0^;Rh0:JVYP0c
<c<0=CDe04M7A`25QHD0Hf=S0;Zj^P2f][H0=3@d0492@P26QXH0S8b<061PH03?cll0R8R802TY:@1E
EED0Xj>S09RHV01fMWH0YJFU07YjNP0n?Sh0CDe=08^;R`2JVYX0P8200<g=c@1=CDd0Bd];06a/K02^
[Zh0cLg=0:ZZZP1`L70092@T04i>CP1`L700MgMg04a<C020P800Vi^K02`/;00h>3P0OGem09fMW@1@
D500I6AT061PH00e=CD0<C4a04m?C`2@T900NGUi06UYJ@2;Rh/0;Bd]03De=@1QHF40VIVI04e=C@2:
RXX0JVYZ03/k>`11@D40A4A4059BDP1=CDd0Fe]K04=3@`0^;Rh0?Cdm05ADE01>CTh0Cdm?059BDP1;
Bd/0@T9203De=@16ATH0De=C04E5A@11@D40?Shn04A4A00];Bd0:BTY04a<C00f=SH0G5aL03Ti>@0o
?cl0<30`0492@P1;Bd/0C4a<04i>CP0k>c/0<c<c04A4A01>CTh0BTY:038b<P1;Bd/0EEEE05mOG`1J
FUX0?Shn0492@P0Q8B408b<S03Xj>P11@D40DU9B03`l?00j>SX0BDU90080C4a<01X0@D5105YJFP1>
CTh0C4a<07AdM00k>c/0?3`l04];B`1>CTh0K6a/04I6AP14A4@0De=C05MGE`1kNg/0Fe]K06QXJ01;
Bd/0Hf=S04M7A`1XJ6P0GemO05eMG@25QHD0JVYZ06MWI`80K6a/0280FUYJ06i^KP1ZJVX0=CDe04=3
@`1OGel0HV9R06e]K@2BTY80TI6A0451@@0f=SH0EeMG03dm?@0d=3@0?clo03dm?@18B4P0?3`l03Ph
>01FEUH0;2`/05=CD`1GEeL0L71`05QHF01PH600=cLg03dm?@1GEeL0HV9R06IVIP1eMGD0CDe=0P1>
CTh01P1:BTX0ADE505QHF01kNg/0O7al03Lg=`80C4a<0200KFe]04];B`0k>c/0GUiN04E5A@0o?cl0
@41003@d=01@D500DE5A05]KF`1mOGd0WIfM04U9B@1ADE40Cdm?07UiN@3;bl/0OGem09fMW@1?Cdl0
CDe=08n?S`1LG5`0S8b<08Z:RP1;Bd/0YjNW08^;R`1/K6`0H61P08R8R080E5AD0680MWIf04i>CP1J
FUX0H61P05UIF@1RHV80KFe]07YjNP1JFUX0M7Ad05UIF@1lO7`0GemO04i>CP1oOgl0D51@06IVIP22
PX80MGEe0=3@d036a/H0EeMG08j>SP1SHf<0CTi>05=CD`14A4@0X:2P04e=C@2BTY80Ti>C04Y:BP1H
F5P0EeMG04U9B@1dM7@0O7al07AdM01KFe/0?clo05]KF`1?Cdl0FUYJ04m?C`1_Kfl0K6a/04=3@`1W
IfL0CTi>04=3@`17AdL0>3Ph06i^KP1PH600>3Ph05aLG00m?Cd0Cdm?05=CD`1:BTX0De=C075aL@1H
F5P0HV9R06QXJ02`/;00IFEU08b<S015ADD0GUiN04A4A01mOGd0O7al03Xj>P1JFUX0Lg=c0492@P0l
?3`0BTY:03dm?@1?Cdl0CDe=04M7A`1PH600FUYJ065QH@17AdL0C4a<06=SH`0j>SX0Rh^;05mOG`16
ATH0QXJ60410@00g=cL0D51@03De=@80E5AD03X0K6a/055AD@0h>3P0ADE5065QH@2<S8`0BTY:06QX
J028R8P0DU9B05]KF`1TI6@0JFUY05ADE014A4@0ATI604U9B@1KFe/0IVIV02TY:@1LG5`0RXZ:04=3
@`1EEED0J6QX03De=@1BDU80=CDe08f=S@0m?Cd0_kno04=3@`1ZJVX0NGUi05IFEP1^KVh0MWIf09bL
W030`<00IfMW0;:b/P28R8P0ATI607UiN@12@T80KFe]08N7Q`2HV9P0I6AT04M7A`1NGUh0J6QX07Yj
NP1cLg<0VIVI069RHP27QhL0WIfM0_ooool0001/07=cL`22PX80W9bL05EEE@1?Cdl0M7Ad08F5Q@1l
O7`0S8b<034a<@13@d<0Ti>C08b<S02=SHd0S8b<03Xj>P1?Cdl0JFUY07emO@1gMgL0Hf=S01`L7016
ATH0MgMg0:FUY@1JFUX0Ph>308Z:RP0W9bL0BTY:08:2PP2PX:00D51@09nOW`1ADE40=3@d04];B`1f
MWH0G5aL04E5A@1iNGT0<c<c028R8P1GEeL0Shn?075aL@15ADD0XJ6Q04E5A@0T92@0L71`0:JVYP0n
?Sh0BDU905UIF@0`<300?clo0:f][@2BTY80<S8b04U9B@0j>SX092@T059BDP1dM7@0=3@d02/[:`0m
?Cd0:b/[03Ti>@2TY:@0QHF5024Q8@0g=cL0>CTi024Q8@1MGEd0Y:BT05UIF@0/;2`0AdM704Y:BP0c
<c<0DE5A09jNWP1:BTX08b<S03lo?`0k>c/0?Cdm05MGE`2DU9@0<c<c03dm?@10@400D51@079bLP2R
XZ80BDU902DU9@18B4P0EEEE05MGE`2GUiL0XJ6Q02l_;`16ATH0De=C0P1OGel0;P2YZJT0Jf][034a
<@1KFe/0M7Ad05iNGP1@D500WIfM03hn?P0/;2`0De=C05iNGP1mOGd0SHf=08N7Q`0g=cL0B4Q805]K
F`1^KVh0FEUI07]kN`2UYJD0AdM703De=@1:BTX0PH6107emO@2<S8`0XZ:R03`l?01OGel0Xj>S09FE
U@2UYJD0`l?309NGU`11@D40A4A408j>SP2@T900MgMg08b<S014A4@0@41005ADE02OWil207=cL`3h
07UiN@19BDT0GEeM0:ZZZP0o?cl0I6AT06m_K`0`<300De=C08V9R@2MWId0@T9208:2PP1ZJVX0BTY:
07alO01oOgl0>c/k0451@@1PH600>c/k05UIF@24Q8@0Kfm_020P800Y:BT0G5aL06ATI01_Kfl0RHV9
06m_K`0];Bd0CDe=055AD@1`L700YZJV09jNWP1<C4`0?clo05EEE@1oOgl0PH6109FEU@2>SXh0;bl_
02PX:01IFET0JFUY06YZJP2@T900Jf][02d];@0a<C40G5aL06MWI`1hN7P0^;Rh03Xj>P0V9RH0Fe]K
08F5Q@1iNGT0];Bd075aL@0[:b/0>CTi07IfMP1KFe/0WinO09:BTP0b<S80ADE508R8R023Ph<0Shn?
09jNWP1@D500?clo08B4Q02GUiL0T92@0;Ng]`13@d<0ADE505EEE@28R8P0KFe]0:BTY00a<C40?Shn
055AD@22PX80IVIV0:>SX`1NGUh0:RXZ03Xj>P29RHT0VYZJ061PH02MWId0CDe=0451@@1GEeL0[Zj^
09JFUP1IFET0LG5a03Ti>@0o?cl0IFEU08B4Q014A4@0LW9b05QHF00f=SH0<S8b06e]K@28R8P0?clo
05EEE@1?Cdl0;2`/04Y:BP20P800Kfm_03Xj>P1TI6@0EeMG04E5A@29RHT0e]KF06UYJ@0i>CT0G5aL
04];B`1DE5@0SHf=0:b/[01<C4`08B4Q04Q8B01IFET0BTY:06YZJP29RHT0:BTY030`<012@T80HV9R
051@D01fMWH0c<c<04U9B@0Q8B40=cLg05eMG@17AdL0R8R808V9R@0l?3`0EEEE06UYJ@1JFUX0?Cdm
03<c<`11@D40EEEE06ATI012@T807alO03lo?`1mOGd0@D5102PX:00h>3P0Jf][07inOP1NGUh0<S8b
02DU9@11@D40ADE503hn?P0`<300:2PX04Q8B00i>CT0Cdm?04e=C@1@D500:b/[01@D5012@T80BTY:
04e=C@15ADD0:BTY04A4A01:BTX0CDe=03Hf=P0_;bl0CTi>04Y:BP1>CTh09bLW03@d=016ATH0D51@
05iNGP13@d<0DE5A05=CD`1EEED0IVIV06MWI`1UIFD0FEUI055AD@1iNGT0@D51059BDP1OGel0De=C
05YJFP0X:2P0<c<c04a<C01OGel0Hf=S04M7A`1ADE40C4a<05ADE00n?Sh0GEeM06EUI@1WIfL0Kfm_
0451@@1EEED0MgMg08N7Q`1OGel0ADE506][J`1FEUH2079bLP0g03lo?`17AdL0HF5Q05]KF`14A4@0
9BDU04m?C`1:BTX0E5AD04];B`19BDT0?3`l04];B`0];Bd0@d=3028R8P0j>SX0AdM7051@D01>CTh0
C4a<02l_;`18B4P0ADE505MGE`18B4P0EUIF04];B`19BDT0=3@d0492@P15ADD0FEUI04e=C@1ADE40
?clo059BDP1IFET0IVIV04A4A01UIFD0MGEe04i>CP17AdL0DE5A0451@@1=CDd0HV9R07YjNP1?Cdl0
C4a<065QH@1/K6`0<C4a03Xj>P0206IVIP1l09NGU`1WIfL0IFEU08>3P`17AdL0Kfm_08:2PP19BDT0
[:b/06=SH`1:BTX0EEEE05aLG00o?cl0Fe]K05iNGP1]KFd0<S8b03`l?01^KVh0LG5a04m?C`2f][H0
Ng]k0:>SX`1eMGD0K6a/04e=C@1iNGT0^KVi079bLP1gMgL0Ph>3096AT@3]kNd0f=SH05ADE01PH600
EEEE06MWI`1QHF40De=C0:VYZ@0c<c<0L71`075aL@10@400N7Qh05QHF018B4P0NGUi06EUI@1ZJVX0
PX:204E5A@1IFET0Fe]K05UIF@0f=SH0Rh^;08>3P`0k>c/0NWYj05QHF01YJFT0LG5a06IVIP2LW9`0
GUiN04m?C`29RHT0DE5A05EEE@1JFUX0Bd];04a<C01KFe/0CDe=05iNGP14A4@0K6a/04A4A01TI6@0
D51@05aLG00k>c/0BTY:051@D012@T80?3`l04a<C013@d<0=CDe059BDP0j>SX0BDU905mOG`19BDT0
E5AD05mOG`1`L700?Shn04e=C@1ZJVX0:2PX065QH@15ADD0D51@0:NWY`0_;bl0GUiN06EUI@1ZJVX0
B4Q804A4A02?Shl0HF5Q059BDP1mOGd0KVi^079bLP1DE5@0D51@07EeM@80FUYJ00D0IfMW06YZJP1h
N7P0F5QH04e=C@0205YJFP0S06ATI015ADD0E5AD08b<S00Z:RX0BTY:06MWI`0d=3@0Cdm?04U9B@2Q
XJ40H61P0<30`017AdL0MGEe0:>SX`1fMWH0YJFU05ADE01^KVh0Xj>S05=CD`2[Zj/0QXJ603<c<`1[
Jf/0<30`05aLG01IFET0IVIV061PH01GEeL0De=C08j>SP2IVIT00P1RHV800`2YZJT0O7al06e]K@02
ooooo`0005X0XZ:R055AD@1RHV80SHf=08>3P`20P800A4A405YJFP2MWId0N7Qh059BDP1;Bd/0>c/k
05MGE`1bLW80>3Ph04a<C02;Rh/0?Shn051@D02MWId0O7al034a<@1CDe<0GEeM02LW9`19BDT0SHf=
04U9B@0^;Rh0CTi>04Y:BP0n?Sh0UiNG07inOP0k>c/0=SHf04Y:BP0_;bl0>SXj08F5Q@15ADD08b<S
03Hf=P0k>c/0>CTi05UIF@35aLD0JVYZ02<S8`0a<C40QhN704I6AP2SXj<0_Kfm02PX:00R8R80JVYZ
09^KV`1UIFD0[Zj^034a<@0K6a/0<30`09^KV`1`L700M7Ad07alO00I6AT07alO04=3@`2^[Zh0HF5Q
09NGU`1]KFd092@T020P800[:b/0Kfm_06ATI021PH40De=C03Hf=P14A4@0=CDe08>3P`1LG5`0NGUi
03De=@0X:2P204];B`0504U9B@1FEUH0R8R803Xj>P0c<c<00P2;Rh/0e`0g=cL0GUiN05EEE@0c<c<0
C4a<09FEU@1HF5P0?Shn07AdM00b<S80<30`05=CD`20P800DE5A04E5A@1UIFD09bLW04U9B@1fMWH0
Fe]K038b<P1EEED0IfMW024Q8@1IFET0[jn_07EeM@0/;2`0Hf=S04e=C@0];Bd0?Shn09JFUP1@D500
>3Ph06EUI@12@T80?Cdm09:BTP2YZJT0CDe=03lo?`1QHF40@T9204Y:BP2TY:@0a<C404e=C@12@T80
Cdm?04];B`1BDU80/k>c07]kN`0];Bd0Bd];04I6AP1JFUX0M7Ad0:^[Z`0`<300@D5105QHF01QHF40
Q8B408f=S@0U9BD0?Shn05YJFP1SHf<0H61P0;Bd]02?Shl092@T06=SH`2/[:`0GUiN08>3P`22PX80
<c<c02`/;01[Jf/0_;bl06EUI@1_Kfl0UYJF03lo?`0k>c/0MGEe0:FUY@1EEED0X:2P06YZJP10@400
H61P0:f][@3EeMD0Lg=c0<;2`P1?Cdl0G5aL07AdM02c/k<0T92@06UYJ@22PX80?Shn05IFEP2<S8`0
P82005IFEP23Ph<0Shn?01/K6`1SHf<0d];B0;2`/01BDU80LG5a03/k>`1>CTh0UiNG0<K6aP1MGEd0
IFEU03Xj>P0o?cl0J6QX0;Vi^@1aLG40CTi>04e=C@0^;Rh0G5aL0<71`@1oOgl0L71`05MGE`0o?cl0
De=C0:FUY@2;Rh/0CDe=06UYJ@0m?Cd0M7Ad0;Fe]@2ATI40?clo09jNWP1YJFT0G5aL0:VYZ@2OWil0
?Shn04M7A`1VIVH0JVYZ06=SH`32`/80TI6A03Xj>P17AdL0GUiN07IfMP2UYJD0b/[:03De=@0a<C40
HV9R05aLG015ADD0`l?30<[:bP0W9bL07alO06i^KP1iNGT0Cdm?0:^[Z`2WYjL0;bl_02/[:`22PX80
RHV906EUI@2e]KD0G5aL03@d=010@400RHV907UiN@1fMWH0JFUY02DU9@0^;Rh0EEEE09nOW`1iNGT0
I6AT07EeM@1<C4`0<30`04e=C@2BTY80SXj>04Y:BP2DU9@0EUIF01hN7P0h>3P0Ng]k07IfMP15ADD0
J6QX0080;bl_00l0CTi>08N7Q`1_Kfl0F5QH06IVIP1XJ6P0?Shn03lo?`19BDT0>CTi04I6AP1CDe<0
=CDe05EEE@13@d<00P0_;bl0101FEUH0DU9B04=3@`1FEUH305UIF@0_06EUI@1FEUH0=cLg03Ti>@1Y
JFT0>SXj03Lg=`1CDe<0RHV904];B`0i>CT0DU9B05IFEP1hN7P0EeMG03Lg=`1BDU80E5AD06IVIP1K
Fe/0C4a<05UIF@1ZJVX0EEEE02l_;`1QHF40FEUI04A4A01:BTX0C4a<05eMG@11@D40?3`l04Y:BP16
ATH0@D51038b<P0Y:BT0ATI605UIF@1@D500?Shn01lO7`0n?Sh0?3`l0492@P1DE5@00P1BDU80;P1?
Cdl0B4Q803`l?00o?cl0<c<c04Y:BP14A4@0ATI605mOG`23Ph<0KVi^03lo?`1LG5`0D51@04i>CP1=
CDd09BDU038b<P1>CTh0A4A404Q8B014A4@0>CTi03Xj>P0X:2P0A4A40451@@10@400DU9B04A4A00]
;Bd0A4A404U9B@1ADE40@d=304e=C@1IFET0D51@03/k>`15ADD0=CDe03Hf=P0n?Sh0?clo05ADE01[
Jf/205IFEP0Y04a<C01HF5P0C4a<04];B`1WIfL0RXZ:05=CD`1MGEd0E5AD06=SH`1]KFd0LG5a07al
O01ZJVX0LW9b06EUI@1=CDd0De=C05aLG012@T80HF5Q07emO@0o?cl0IVIV03Ph>01GEeL0Vi^K06e]
K@2j^[X0KFe]05aLG02KVi/0?3`l05aLG01KFe/0=CDe0;fm_@25QHD0HV9R06UYJ@1bLW800P1QHF40
GP1TI6@0K6a/065QH@18B4P0De=C04A4A01oOgl0^k^k04M7A`1TI6@0DE5A09jNWP1EEED0De=C07Mg
M`1IFET0UYJF0:^[Z`1iNGT0Rh^;08Z:RP1WIfL0EeMG04Y:BP1aLG40Jf][04M7A`1fMWH0Jf][0:JV
YP2ATI40AdM7079bLP19BDT06ATI05mOG`17AdL0?Shn05mOG`13@d<0WIfM07QhN01VIVH0De=C079b
LP25QHD0Hf=S0;>c/`1jNWX0ATI604Q8B01?Cdl0UIFE05]KF`0[:b/0FUYJ05]KF`1JFUX0Ng]k0410
@01KFe/0I6AT069RHP1jNWX0LG5a09:BTP1LG5`0Fe]K04];B`1aLG40EeMG04m?C`1CDe<0=CDe05MG
E`1XJ6P0=3@d02h^;P19BDT0>3Ph04a<C015ADD0BTY:06ATI01@D500CTi>04Q8B017AdL0ATI604=3
@`1eMGD0?Cdm05iNGP2][Jd205ADE00=05eMG@0/;2`0@d=30492@P1`L700CDe=04m?C`1SHf<0QhN7
07emO@1/K6`0EUIF06IVIP02069RHP0_04e=C@20P800MWIf0492@P1BDU80@D5105eMG@1UIFD0:RXZ
05]KF`1oOgl0ADE508R8R02;Rh/0MGEe07inOP1MGEd0LW9b06e]K@3Kfm/0MgMg06][J`1kNg/0IVIV
0;Bd]01GEeL0WYjN0:^[Z`1@D500UiNG08N7Q`1QHF40YjNW061PH02WYjL0X:2P0::RXP1WIfL0CTi>
055AD@1UIFD0LG5a07AdM022PX80Lg=c08:2PP24Q8@00_ooool0001<0<;2`P1DE5@0F5QH06a/K02:
RXX0[Zj^0410@017AdL0De=C08>3P`2GUiL0VIVI02XZ:P17AdL0HF5Q06=SH`1nOWh0V9RH03@d=01@
D500FEUI07]kN`1QHF40[jn_08b<S00V9RH0@T9206EUI@1^KVh0H61P09jNWP0W9bL0;Rh^03Ph>01/
K6`0>CTi06IVIP1aLG404Q8B03De=@1?Cdl0F5QH04U9B@2KVi/0/;2`01TI6@0i>CT0Cdm?08N7Q`1E
EED0De=C051@D00M7Ad0<C4a08N7Q`1UIFD0CDe=06YZJP0/;2`06ATI06MWI`2QXJ40?Cdm0492@P11
@D40>CTi04=3@`1fMWH0GemO03De=@18B4P0;2`/04E5A@1=CDd0LW9b02d];@80>SXj0780<C4a03De
=@17AdL0F5QH02/[:`0n?Sh0EEEE03<c<`1OGel0K6a/0410@00H61P0B4Q805]KF`0^;Rh0G5aL0:FU
Y@18B4P0820P04=3@`1VIVH0AdM706i^KP1UIFD0:RXZ03De=@1EEED0L71`06MWI`2MWId0;bl_02`/
;00j>SX0Ng]k071`L027QhL0[jn_02<S8`0U9BD0FEUI08N7Q`1HF5P0JVYZ0861P@0R8R80:RXZ06m_
K`2BTY80ADE50:b/[01JFUX09BDU03Lg=`1kNg/0Ti>C06EUI@2VYZH0CTi>02HV9P1DE5@0XJ6Q09BD
U01cLg<0NGUi030`<01:BTX0HV9R08b<S024Q8@0Ng]k0820P00Q8B40E5AD07inOP1jNWX0IVIV09fM
W@1;Bd/09bLW05eMG@1SHf<0KFe]08J6QP0U9BD0;Bd]07EeM@1YJFT0@d=304a<C025QHD0<S8b02h^
;P29RHT0]kNg05MGE`1DE5@0J6QX03Ti>@16ATH0Y:BT05]KF`0[:b/0E5AD05IFEP0X:2P0@d=309jN
WP1>CTh0:2PX06=SH`14A4@0<C4a06m_K`2[Zj/203Ph>01^04U9B@1FEUH0CTi>07AdM01mOGd0>CTi
05ADE01KFe/0>SXj09BDU02n_[h0@d=302TY:@1YJFT0RHV904m?C`2CTi<0a<C4034a<@0/;2`0PH61
08V9R@1`L700];Bd02DU9@0b<S80Ogmo0;Ng]`1NGUh0UIFE03dm?@0N7Qh0A4A409RHV025QHD0NWYj
05=CD`0O7al0BDU908V9R@21PH40UiNG07MgM`0Y:BT0Bd];0:JVYP2ATI40QhN7092@T00_;bl0BTY:
07alO02XZ:P0JFUY0<71`@1:BTX0AdM708R8R02KVi/0OGem08V9R@1iNGT0?clo0410@01`L700`l?3
096AT@2[Zj/0UYJF03`l?01MGEd0ZZZZ07moO`1?Cdl0MWIf04E5A@0];Bd0CTi>0:FUY@1^KVh0<C4a
08Z:RP1WIfL0?3`l04E5A@28R8P0DE5A04M7A`1kNg/0ADE504I6AP1]KFd0P82004E5A@1aLG40E5AD
03`l?01ZJVX0WIfM055AD@0e=CD0K6a/06=SH`1GEeL0?Shn08V9R@2:RXX09bLW02h^;P0f=SH205IF
EP3V08J6QP2OWil08B4Q02LW9`1QHF40OGem06EUI@2?Shl0MWIf01lO7`0l?3`0ATI6065QH@1NGUh0
C4a<06e]K@11@D40C4a<06a/K017AdL0De=C05mOG`19BDT0Fe]K04i>CP1BDU80ADE504m?C`1@D500
EUIF05iNGP1PH600HV9R05ADE011@D40?Shn04Y:BP0_;bl0DE5A03<c<`1:BTX0>c/k0451@@1=CDd0
@D5105]KF`1RHV80GemO04m?C`0m?Cd0GemO04E5A@1/K6`0De=C04Y:BP1ADE40AdM704];B`0M7Ad0
>3Ph04Q8B016ATH0GUiN0451@@1LG5`0L71`04m?C`1kNg/0O7al07inOP1TI6@0C4a<06IVIP0c<c<0
?3`l04E5A@1:BTX0H61P06UYJ@1XJ6P0De=C04A4A01IFET0Kfm_06ATI00n?Sh0Bd];06EUI@1eMGD0
AdM703lo?`19BDT0?Shn05eMG@1@D500GEeM05IFEP1UIFD0Q8B403Ti>@13@d<0Ng]k05eMG@1KFe/0
E5AD02XZ:P0];Bd0<C4a04e=C@0Y:BT0;bl_055AD@0j>SX0;2`/02d];@1DE5@0G5aL03<c<`10@400
KVi^05QHF00h>3P0A4A405UIF@1QHF40>SXj03Ph>01SHf<0IFEU03Lg=`15ADD0Cdm?03`l?00b<S80
ATI6092@T01eMGD0>c/k051@D01BDU80KFe]03@d=016ATH0LW9b04i>CP1gMgL0CDe=059BDP1YJFT0
FEUI06YZJP1mOGd0Shn?04Y:BP1oOgl0CDe=08F5Q@2g]kL0L71`08Z:RP1GEeL0@d=306][J`1UIFD0
RXZ:08B4Q01?Cdl0RHV905]KF`1RHV80J6QX09>CT`1YJFT0MWIf06QXJ00b<S80?Cdm04I6AP1IFET0
EeMG05YJFP1lO7`0CTi>08N7Q`1=CDd0IfMW04e=C@1UIFD0QHF503De=@13@d<0DE5A04I6AP3Xj>P0
Y:BT03dm?@1oOgl0G5aL08B4Q01jNWX0GEeM09>CT`18B4P0LW9b06YZJP1?Cdl0BTY:04E5A@1@D500
YZJV08V9R@2>SXh0IFEU04M7A`1]KFd0DE5A06UYJ@13@d<0Ogmo071`L01ADE40GUiN04e=C@1:BTX0
De=C04Q8B01NGUh0Hf=S04I6AP2<S8`204M7A`0I04U9B@1;Bd/0IFEU06QXJ00m?Cd0?clo051@D01d
M7@0HF5Q08B4Q01CDe<0Hf=S03dm?@1kNg/0OGem04M7A`1MGEd0EUIF04];B`0j>SX0@D5103Xj>P1A
DE40ADE504A4A00205ADE01905IFEP16ATH0Cdm?04e=C@1ADE40[:b/05QHF01fMWH0TI6A02<S8`1H
F5P0GEeM04Q8B01UIFD0KFe]07]kN`0e=CD0?clo05]KF`1GEeL0F5QH04U9B@1UIFD0KVi^04i>CP0o
?cl0EEEE08n?S`1iNGT0I6AT05IFEP1QHF40UiNG08>3P`1TI6@0KFe]08f=S@1IFET0M7Ad07YjNP12
@T80BDU906e]K@2@T900J6QX0;Rh^01KFe/0G5aL0820P022PX80]kNg0861P@25QHD0VIVI09RHV02h
^;P0O7al0861P@2MWId0K6a/06m_K`1EEED0E5AD06EUI@1PH600HF5Q06m_K`2GUiL0HF5Q05aLG01i
NGT0QhN7079bLP02ooooo`000280O7al08Z:RP2e]KD0Bd];07AdM02QXJ40QHF507alO01/K6`0;Bd]
07=cL`1nOWh0G5aL071`L01_Kfl0<c<c06ATI02YZJT0MgMg0410@01;Bd/0=cLg02l_;`1ZJVX0a/K6
07MgM`0m?Cd0FUYJ034a<@1EEED0QHF506EUI@0g=cL0DE5A0P17AdL0:P1NGUh0O7al03<c<`0];Bd0
MGEe03dm?@0d=3@0VYZJ08F5Q@18B4P0>c/k05QHF019BDT0K6a/07moO`1YJFT09bLW02/[:`0n?Sh0
Cdm?06QXJ02XZ:P0Bd];01/K6`0_;bl0EUIF06IVIP20P800FUYJ01lO7`1BDU80P82007EeM@1GEeL0
YZJV03hn?P0R8R80GemO06UYJ@15ADD0Ph>30;Rh^0808b<S01l0G5aL05=CD`14A4@0O7al0<30`00h
>3P09bLW051@D01NGUh0BDU909nOW`2][Jd0:2PX03Ti>@1QHF40S8b<05UIF@2@T900=3@d038b<P17
AdL0U9BD05UIF@1jNWX0O7al024Q8@1XJ6P0P8200861P@1QHF40KVi^0080B4Q80580D51@079bLP1I
FET0>c/k05mOG`0e=CD0?Shn04e=C@1KFe/0E5AD061PH01aLG40>SXj03hn?P1HF5P0P82003Xj>P1=
CDd0GEeM03Xj>P0l?3`0Ogmo08Z:RP0V9RH0GUiN06MWI`0n?Sh0Rh^;0;Bd]01ZJVX0:RXZ061PH01k
Ng/0AdM707UiN@36a/H0I6AT03dm?@1eMGD0I6AT04a<C028R8P0ZJVY03Hf=P0m?Cd0IFEU05mOG`2a
/K40VIVI02HV9P18B4P0Q8B405]KF`1[Jf/0`<3006=SH`0Y:BT0KFe]0:RXZ01_Kfl0N7Qh08R8R00b
<S80;Bd]08R8R02ATI40D51@096AT@1FEUH0=3@d051@D01nOWh0XJ6Q069RHP2JVYX0?clo055AD@24
Q8@0Z:RX075aL@1eMGD0QXJ60P0g=cL0BP25QHD0c/k>06YZJP2;Rh/0UYJF03Ph>00k>c/0Ng]k0:j^
[P1PH600N7Qh06MWI`1>CTh0Jf][07QhN01^KVh0HV9R07YjNP0i>CT0ATI60;Bd]02XZ:P0:b/[05AD
E00n?Sh0?clo05EEE@1eMGD0<C4a051@D01PH600>c/k09>CT`2WYjL0?clo04U9B@1PH600@T9206UY
J@2SXj<0BDU905MGE`1YJFT0B4Q806QXJ024Q8@0B4Q803De=@1[Jf/0@410059BDP2n_[h0QXJ602h^
;P16ATH0LG5a05ADE025QHD0^KVi03Ph>00Y:BT0AdM706IVIP1dM7@0Y:BT092@T00h>3P0Bd];07=c
L`0o?cl0E5AD0<C4a01]KFd0;Rh^0P1ADE40<P1]KFd0A4A408f=S@1jNWX0>CTi04=3@`1SHf<0MWIf
05eMG@2c/k<0IVIV03hn?P1PH600KFe]05=CD`2UYJD0OWin0410@01<C4`0Lg=c09ZJVP1@D500RHV9
06QXJ013@d<0@T9206IVIP24Q8@0CTi>069RHP1VIVH05aLG0410@01;Bd/0IVIV079bLP1^KVh0WIfM
03Hf=P1;Bd/0CTi>07MgM`1:BTX0IFEU04i>CP0/;2`0EeMG05IFEP1YJFT0De=C0P18B4P02@17AdL0
BTY:0492@P0Y:BT0EUIF04a<C00_;bl0<C4a04];B`0205eMG@1P05MGE`19BDT0DU9B061PH01EEED0
B4Q803De=@0U9BD0DU9B03/k>`1RHV80Bd];05EEE@16ATH0ADE505eMG@1TI6@0Ph>304a<C00m?Cd0
G5aL05=CD`1GEeL0EUIF04i>CP1EEED0De=C071`L00U9BD0B4Q8065QH@1>CTh0KVi^04U9B@1/K6`0
LW9b05ADE02:RXX0UYJF07]kN`1NGUh0GemO08Z:RP19BDT0IfMW04];B`1ADE40M7Ad02h^;P0k>c/0
CDe=04a<C01KFe/0GemO05QHF017AdL0ATI603lo?`1VIVH0EeMG051@D01GEeL0BTY:07]kN`1QHF40
Jf][07AdM01;Bd/0F5QH03@d=015ADD0FEUI0410@019BDT0CTi>03hn?P0S8b<0:b/[059BDP0k>c/0
ADE504e=C@1CDe<0?clo0451@@0k>c/0EEEE02h^;P10@400>CTi04M7A`15ADD0@D5102DU9@0k>c/0
?Shn0P1>CTh0U@1XJ6P0BTY:04e=C@1=CDd0C4a<04=3@`1CDe<0BDU903Hf=P0b<S80CTi>061PH029
RHT0;2`/05EEE@1NGUh0EeMG079bLP13@d<0<c<c04I6AP1OGel0QhN704e=C@1RHV80CTi>05]KF`16
ATH0De=C07IfMP1kNg/0f][J09BDU01aLG40O7al04M7A`2GUiL0QXJ604m?C`2DU9@0B4Q807AdM027
QhL0GEeM0410@01CDe<0PH6104Q8B017AdL0<C4a051@D01;Bd/0IFEU09^KV`0k>c/0AdM703Xj>P1[
Jf/0?Shn0:BTY03<c<`0>3Ph07IfMP1VIVH0Fe]K0:>SX`2IVIT0;2`/059BDP11@D40Ng]k05UIF@1^
KVh0Q8B402/[:`21PH40MGEe04e=C@1bLW80CDe=04M7A`1TI6@0GEeM09FEU@1OGel0@D51092@T01G
EeL0D51@04Q8B02`/;00YZJV06=SH`1gMgL0Hf=S075aL@1XJ6P0B4Q80:FUY@20P800=3@d05eMG@14
A4@0FUYJ06m_K`0`<300>SXj04Y:BP1<C4`0De=C06][J`2DU9@0Hf=S06ATI01:BTX0QHF5038b<P1<
C4`0Bd];03@d=01:BTX0EUIF03@d=011@D40Cdm?03lo?`19BDT0EeMG04e=C@1CDe<0F5QH06YZJP1>
CTh0Fe]K07AdM019BDT0IFEU03dm?@1MGEd0JVYZ03dm?@23Ph<0JVYZ05EEE@1NGUh0<C4a05]KF`10
@400EeMG0080Fe]K03D0Cdm?05IFEP1GEeL0Hf=S05iNGP1<C4`0KVi^09jNWP1^KVh0K6a/07=cL`1L
G5`0JFUY07MgM`12@T80KVi^065QH@0/;2`0Fe]K05iNGP17AdL0K6a/04i>CP1XJ6P0MGEe0;2`/00i
>CT0IfMW07alO02GUiL0clo?08b<S02FUYH0X:2P06IVIP2=SHd0GEeM04A4A01IFET0?clo069RHP1?
Cdl0MGEe0492@P0l?3`0De=C08>3P`2HV9P0MgMg07emO@2IVIT0Shn?07alO002ooooo`0008@0PX:2
05aLG01cLg<0FUYJ04m?C`1NGUh0IVIV08B4Q029RHT0>c/k05=CD`1jNWX0L71`07QhN02ATI40<S8b
03Lg=`1cLg<0RHV90::RXP2DU9@0=3@d04E5A@1KFe/0Jf][08^;R`2a/K40VIVI02l_;`13@d<0G5aL
08b<S01NGUh0X:2P055AD@0f=SH0H61P07inOP1TI6@0De=C0<W9b@1PH6007QhN03hn?P1aLG40E5AD
079bLP2IVIT0GemO02<S8`1YJFT0YZJV05iNGP2KVi/0V9RH02h^;P0o?cl0NWYj0;2`/01GEeL0P820
04U9B@0X:2P0Cdm?08n?S`1=CDd0A4A405=CD`0V9RH0?3`l065QH@22PX80D51@05YJFP1=CDd0;2`/
0451@@27QhL0HV9R03<c<`1JFUX0@D5102l_;`15ADD0LG5a07AdM00m?Cd0GUiN038b<P0l?3`0Lg=c
09jNWP1;Bd/0<30`05aLG00o?cl0@41006=SH`1]KFd08B4Q03Ti>@19BDT0C4a<06UYJ@2EUID0=SHf
02h^;P1CDe<0@T9204e=C@27QhL0Lg=c02PX:013@d<0GemO065QH@1UIFD0/k>c061PH00Q8B40GUiN
05UIF@19BDT0M7Ad0<G5a@13@d<0:RXZ03lo?`1hN7P0GemO08Z:RP39bLT203hn?P0<05IFEP1hN7P0
ADE509fMW@3:b/X0@T9203Xj>P1lO7`0`<30051@D02LW9`0TY:B0P18B4P0T`22PX80P82006YZJP2e
]KD0DE5A04m?C`1TI6@0RHV906e]K@1kNg/0NWYj03Lg=`1XJ6P0dm?C08n?S`2TY:@0NGUi03dm?@1B
DU80OWin0;Rh^01hN7P0UYJF06a/K00j>SX0BDU907UiN@1gMgL0@T9207IfMP0o?cl0D51@075aL@1i
NGT0=CDe051@D024Q8@0<30`04a<C02:RXX0Q8B402h^;P1BDU80O7al061PH01iNGT0c/k>08^;R`1A
DE40CTi>08N7Q`15ADD0V9RH0;Fe]@1CDe<0?clo04=3@`1>CTh0EeMG08Z:RP2?Shl0=cLg04m?C`24
Q8@0OWin08Z:RP2m_Kd0BTY:038b<P1OGel0Rh^;07moO`2i^KT0Hf=S038b<P1HF5P0MgMg05IFEP2N
WYh0YJFU030`<01:BTX0YJFU05eMG@2KVi/0FUYJ028R8P0i>CT0OGem06EUI@2CTi<0_;bl034a<@15
ADD0KFe]06=SH`1_Kfl0[:b/04I6AP0i>CT0S8b<0:b/[01eMGD0XJ6Q04Y:BP0`<300BTY:0:BTY02j
^[X0HV9R09nOW`0a<C409bLW07UiN@2PX:00EUIF07AdM02h^;P0AdM703Hf=P1/K6`0YJFU04Y:BP2Q
XJ40EeMG02l_;`17AdL0C4a<06UYJ@18B4P0MgMg05mOG`0H61P0=SHf0861P@1jNWX0>CTi07QhN01I
FET0?Cdm06i^KP38b<P0IVIV03Lg=`0l?3`0B4Q8038b<P0207]kN`3@03<c<`0h>3P0De=C05MGE`10
@400P82008V9R@1KFe/0>3Ph07IfMP10@400?clo05MGE`2@T900BTY:034a<@1DE5@0@T9205=CD`2P
X:00/k>c03dm?@1CDe<0IVIV07emO@11@D40>c/k061PH01BDU80GUiN055AD@0f=SH0EeMG04m?C`15
ADD0EEEE05YJFP1@D500EEEE05YJFP2;Rh/0KFe]05eMG@1VIVH0GemO0410@00a<C40GEeM03/k>`17
AdL0BTY:05=CD`10@400>3Ph05EEE@1JFUX0PX:205aLG00j>SX0G5aL06=SH`1PH600AdM703Xj>P1:
BTX0GUiN04E5A@0W9bL0DU9B051@D011@D40BDU905=CD`1WIfL0B4Q804E5A@1WIfL0[:b/06QXJ014
A4@0<S8b05UIF@14A4@0DU9B055AD@1PH600OWin055AD@1MGEd0HF5Q05mOG`1IFET0HV9R04m?C`15
ADD0@d=306EUI@1MGEd0CDe=04i>CP1XJ6P0CDe=07alO02<S8`0QXJ607YjNP19BDT0GemO03De=@1S
Hf<0H61P065QH@1VIVH0Bd];0492@P0b<S80Bd];04Q8B00j>SX0=CDe05IFEP1JFUX0@T9204m?C`1A
DE40JVYZ04Q8B01DE5@0Hf=S06IVIP1:BTX0GemO04I6AP1:BTX0De=C05IFEP1RHV80LG5a04Q8B01<
C4`0AdM70451@@0a<C40=3@d06ATI01?Cdl0>c/k05IFEP16ATH0Bd];02LW9`1YJFT0Q8B404];B`21
PH40Lg=c04A4A01?Cdl0Hf=S05QHF01DE5@0Ng]k03<c<`2HV9P0?3`l05mOG`2MWId0EeMG0=?Cd`1`
L700HF5Q07UiN@0a<C40Ph>306i^KP0n?Sh0[jn_06e]K@1KFe/0HF5Q08b<S020P800IVIV04I6AP14
A4@0LG5a04A4A01?Cdl0>3Ph05aLG01cLg<0<c<c06e]K@0h>3P0O7al03De=@12@T80MWIf04A4A02J
VYX0Lg=c04Y:BP37alL0Y:BT04];B`25QHD0De=C07inOP80DU9B08<0JFUY02XZ:P2][Jd0S8b<03lo
?`18B4P0:b/[030`<01jNWX0C4a<05iNGP0a<C40;Rh^05MGE`16ATH0T92@024Q8@1lO7`0MGEe03dm
?@26QXH0EEEE04Y:BP1IFET0@d=305MGE`1ADE40FUYJ05aLG019BDT0C4a<05=CD`0f=SH0N7Qh075a
L@12@T80=3@d04I6AP1OGel0Jf][075aL@16ATH0De=C02<S8`1@D500De=C01hN7P1PH600Lg=c03Xj
>P0d=3@0CTi>05YJFP1OGel0C4a<04=3@`1[Jf/0HF5Q04Y:BP0f=SH0ATI60410@014A4@0JVYZ03/k
>`21PH40/K6a04Q8B01<C4`0@T9202@T9018B4P0BDU907=cL`0d=3@0DU9B06EUI@2<S8`0FUYJ04i>
CP19BDT0IfMW04E5A@1GEeL0ATI606][J`1ADE40=cLg04e=C@1;Bd/0EUIF05aLG00/;2`0H61P08Z:
RP0l?3`0Fe]K0492@P11@D40FUYJ08b<S029RHT0Ng]k0:b/[00a<C40LW9b07UiN@1@D500K6a/06][
J`2k^k/0WIfM07QhN01mOGd0GEeM04A4A01_Kfl0?3`l05mOG`1ADE40CDe=051@D01IFET0EUIF06IV
IP1^KVh0NWYj071`L01WIfL0LG5a08V9R@02ooooo`000?l0[Zj^051@D01LG5`0MGEe09jNWP2DU9@0
>c/k055AD@1NGUh0G5aL0:n_[`1lO7`0=3@d04Q8B01UIFD0B4Q807]kN`1]KFd09BDU04m?C`1]KFd0
Jf][03<c<`1SHf<0>c/k02XZ:P1GEeL0Kfm_04m?C`0o?cl0KFe]04Q8B00n?Sh0HF5Q08:2PP0g=cL0
?Cdm051@D00W9bL08b<S07UiN@26QXH0;2`/0451@@1OGel06a/K02/[:`21PH40PX:203<c<`0m?Cd0
@T9203Ti>@1cLg<0NWYj03Ph>00d=3@0M7Ad051@D010@400W9bL075aL@0S8b<09RHV05iNGP1BDU80
K6a/08J6QP0W9bL0@41004U9B@1[Jf/0Cdm?096AT@1PH600=cLg03Ph>01SHf<0N7Qh051@D02VYZH0
TI6A01lO7`16ATH0MWIf061PH01HF5P0YjNW03hn?P0e=CD0F5QH08V9R@20P800IVIV0<c<c00o?cl0
@41004e=C@1nOWh0EeMG06m_K`1GEeL0=SHf04M7A`1gMgL0U9BD06QXJ026QXH0<c<c0492@P1CDe<0
O7al05ADE01SHf<0LW9b03Lg=`10@400GUiN08V9R@1DE5@0IFEU059BDP0W9bL0@d=307AdM01/K6`0
>3Ph069RHP0i>CT0:BTY04a<C01eMGD0Ng]k04];B`1jNWX0@D5102@T901;Bd/0R8R806=SH`1=CDd0
Ng]k0492@P0_;bl0Cdm?07alO01DE5@0GEeM05IFEP0l?3`0CTi>06YZJP28R8P0AdM7061PH01HF5P0
<C4a08F5Q@3<c<`0CTi>06QXJ01IFET0;2`/075aL@2JVYX0<c<c03Hf=P1>CTh0AdM70451@@2PX:00
/k>c034a<@17AdL0Fe]K061PH01oOgl0RHV905UIF@0[:b/0IVIV05mOG`1GEeL0YJFU0>;RhP0l?3`0
8b<S07YjNP2ZZZX0Bd];0:NWY`2DU9@0<S8b04=3@`2][Jd0]kNg09jNWP2c/k<0X:2P04M7A`11@D40
WinO096AT@2IVIT0e=CD04];B`11@D40JFUY09ZJVP1oOgl0UiNG0;fm_@0Q8B40IfMW0<S8b02i^KT0
VIVI09jNWP0a<C40?clo0:VYZ@39bLT0CDe=08>3P`1GEeL0=SHf051@D036a/H0Ogmo06UYJ@1hN7P0
ADE506a/K02EUID0E5AD07MgM`1SHf<0<30`04];B`2ATI40EeMG0410@01JFUX0<C4a05MGE`1hN7P0
Kfm_04Q8B01PH600D51@03Lg=`27QhL0V9RH034a<@0h>3P005/0C4a<05mOG`1WIfL0XJ6Q05ADE00Z
:RX0D51@05aLG01gMgL0UIFE0;fm_@1<C4`0:BTY04a<C01`L700@d=30;>c/`26QXH07QhN02d];@1d
M7@0IfMW05iNGP2QXJ40^KVi030`<00P8200N7Qh08R8R01UIFD0/K6a04];B`10@400CTi>09:BTP1d
M7@0NWYj08j>SP0_;bl0AdM704U9B@2=SHd0G5aL06ATI02ATI40NGUi01dM7@12@T80I6AT06][J`1X
J6P0_kno08F5Q@0P8200<C4a06e]K@1`L700IFEU08Z:RP1JFUX0=SHf0410@01UIFD0I6AT05aLG01=
CDd0KVi^04=3@`10@400F5QH03De=@1>CTh0Jf][04i>CP1MGEd0BDU903`l?00a<C40H61P04i>CP1<
C4`0NWYj05EEE@17AdL0?Shn03dm?@11@D40@T9203hn?P1RHV80ATI60080A4A401l0D51@04e=C@1:
BTX0G5aL05ADE01LG5`0DU9B04A4A01RHV80AdM706YZJP1hN7P0HF5Q05IFEP15ADD0D51@02HV9P0m
?Cd0EEEE0492@P1QHF40?3`l051@D01MGEd0B4Q805QHF01?Cdl0E5AD04];B`1>CTh0GUiN0080H61P
00h0>3Ph03De=@1DE5@0KVi^07AdM00m?Cd0;Rh^055AD@20P800I6AT03/k>`0o?cl0A4A404m?C`80
@d=300@0>SXj06EUI@1KFe/0>c/k0P1;Bd/0301]KFd0G5aL02/[:`0g=cL0Bd];02l_;`17AdL0A4A4
03/k>`0W9bL0<S8b0451@@80;Bd]07P0E5AD03dm?@0W9bL0=cLg05MGE`1JFUX0@41004U9B@1jNWX0
G5aL03<c<`0k>c/0HV9R05]KF`0a<C4092@T06QXJ01]KFd092@T03/k>`0l?3`0A4A403@d=00n?Sh0
Ng]k0861P@16ATH0ADE5055AD@1oOgl0B4Q804E5A@1WIfL0N7Qh09NGU`1_Kfl0DU9B05QHF01CDe<0
L71`06QXJ01_Kfl0>3Ph05QHF00_;bl0FUYJ09^KV`1CDe<0d];B08R8R01dM7@0Xj>S05EEE@2i^KT0
SHf=04a<C01]KFd0>c/k05MGE`1HF5P0?clo04m?C`1RHV80FUYJ03De=@1<C4`0A4A406e]K@0_;bl0
Jf][08j>SP0j>SX0Bd];03lo?`1nOWh0EEEE08f=S@2RXZ80DU9B09nOW`27QhL0IfMW0=OGe`2g]kL0
P82009RHV01[Jf/0LW9b04Q8B027QhL0XZ:R05QHF01VIVH0F5QH05=CD`1FEUH0EeMG04I6AP1kNg/0
NGUi08:2PP1;Bd/0B4Q80820P01IFET0FUYJ038b<P3Bd]80VYZJ04E5A@1mOGd0Bd];08:2PP27QhL0
IFEU06][J`1eMGD0L71`0:FUY@1BDU82051@D01S0410@00k>c/0De=C06a/K01jNWX0FUYJ069RHP1j
NWX0];Bd07UiN@1dM7@0FUYJ05iNGP1JFUX0ADE5055AD@19BDT0?3`l03Hf=P0l?3`0>SXj04=3@`1A
DE40>SXj059BDP1WIfL0H61P04U9B@1BDU80CDe=069RHP29RHT0=CDe065QH@1IFET09BDU07EeM@1_
Kfl0=3@d06][J`1MGEd0?Shn03De=@1=CDd0BTY:04];B`14A4@0FEUI04I6AP1FEUH0CTi>04e=C@1S
Hf<0WIfM055AD@1DE5@0LW9b04i>CP1gMgL0MWIf024Q8@1cLg<0Ogmo04I6AP2=SHd0IVIV06e]K@1[
Jf/0EeMG071`L02n_[h0YZJV03Ph>01fMWH0Fe]K08N7Q`2SXj<0Hf=S07UiN@1bLW80EEEE0:^[Z`1K
Fe/0@41006i^KP1dM7@0RXZ:05eMG@1EEED0B4Q804=3@`1JFUX0JVYZ0820P01LG5`0MWIf08f=S@1i
NGT0MWIf00;ooooo00007`2>SXh0IFEU07MgM`1@D500H61P0:NWY`1HF5P0De=C04i>CP14A4@0MgMg
096AT@0d=3@0BDU904Q8B01ADE40JVYZ09VIV@17AdL0;2`/05=CD`1JFUX0EeMG08:2PP2?Shl09BDU
0451@@1FEUH0CTi>06i^KP2;Rh/00`0j>SX0o`1JFUX0E5AD075aL@1`L70092@T01LG5`10@400HV9R
05=CD`2ATI40aLG501TI6@0/;2`0=CDe04m?C`1JFUX0[Jf]07=cL`0S8b<0>CTi05ADE01OGel0GUiN
0;Zj^P14A4@07AdM04i>CP1jNWX0G5aL069RHP1SHf<05aLG04Q8B01bLW80DE5A03@d=01SHf<06a/K
02l_;`19BDT0GUiN03De=@1BDU80IVIV028R8P0f=SH0Bd];07inOP1<C4`0CTi>075aL@0g=cL0ATI6
06=SH`1KFe/08R8R0451@@1IFET0;Rh^03Ph>01KFe/0BTY:02d];@1<C4`0:2PX0492@P1<C4`0Ph>3
03Ti>@15ADD0Bd];03Xj>P1=CDd0IFEU0451@@0c<c<0D51@04=3@`1DE5@0PH6107inOP0/;2`0>SXj
04];B`1?Cdl0LW9b08Z:RP1]KFd09bLW03Ti>@1SHf<0JVYZ075aL@2?Shl0Vi^K01dM7@0i>CT0?clo
05eMG@1cLg<0`<300820P00];Bd0Bd];05aLG01MGEd0OGem0>GUi@1MGEd0?clo08:2PP1nOWh0NWYj
0:n_[`2e]KD09bLW04=3@`1ZJVX0N7Qh05YJFP2h^;P0YJFU03Xj>P15ADD0U9BD08>3P`30`<00EEEE
02LW9`1FEUH0[:b/08b<S01gMgL0`/;204];B`0g=cL0JVYZ09VIV@2OWil0Ng]k07moO`0S8b<0?Cdm
07MgM`2MWId0GUiN0:b/[01TI6@08B4Q03<c<`2h^;P0UIFE0410@02>SXh0Cdm?03De=@0o?cl0VYZJ
05YJFP1@D500Kfm_04i>CP0g=cL0FEUI08^;R`1IFET0GUiN06QXJ00n?Sh0?clo0861P@2FUYH0<C4a
06ATI01@D500>c/k0492@P2LW9`0?clo02h^;P1OGel0CDe=09^KV`3?cll0EEEE02`/;01GEeL0TY:B
05EEE@2CTi<0QHF502/[:`19BDT0HV9R05UIF@2SXj<0YZJV02@T901=CDd0LW9b06EUI@2RXZ80UiNG
03De=@1;Bd/0NWYj079bLP1eMGD0SXj>038b<P19BDT0KFe]09FEU@1^KVh0Zj^[079bLP0k>c/0EEEE
09nOW`1nOWh0WinO0:RXZ00X:2P0B4Q80:NWY`1oOgl0Bd];0<71`@2<S8`0:BTY05YJFP2j^[X0Lg=c
05=CD`1^KVh0>3Ph03/k>`1dM7@0alO7069RHP19BDT0`<3004e=C@0_;bl0EUIF09fMW@1kNg/0CDe=
0:BTY01/K6`0AdM707EeM@2d];@0ADE506MWI`00G026QXH0?clo0492@P1hN7P0Lg=c04=3@`2=SHd0
YjNW0451@@0Z:RX0MGEe0;6a/@1?Cdl0CDe=06EUI@0_;bl0;Bd]09FEU@24Q8@0<C4a04i>CP1iNGT0
;bl_04];B`2SXj<0ZJVY034a<@12@T80H61P04e=C@1IFET0GUiN0820P01JFUX0Hf=S06UYJ@19BDT0
CTi>04U9B@0l?3`0Hf=S04U9B@0i>CT0?Cdm06=SH`1TI6@0EeMG08:2PP1=CDd0Cdm?04];B`17AdL0
BDU904A4A00_;bl0DE5A04E5A@1TI6@0Fe]K06ATI01?Cdl0IfMW07emO@1aLG40P82004m?C`1<C4`0
G5aL04M7A`1SHf<0Cdm?05mOG`1CDe<0D51@06=SH`0^;Rh0@T9205UIF@1<C4`0LW9b04I6AP1LG5`0
JFUY04m?C`1RHV80Ph>306IVIP10@400Kfm_06UYJ@0n?Sh0GemO0P1<C4`06P1nOWh0FUYJ06ATI01=
CDd0Bd];06QXJ01MGEd0MGEe04E5A@1fMWH0CDe=07YjNP1XJ6P0De=C05]KF`18B4P0E5AD04e=C@1L
G5`0A4A403lo?`1jNWX0FEUI07UiN@1bLW80ADE50P1EEED0:00l?3`0BDU904=3@`1LG5`0>c/k02PX
:01HF5P0?clo0492@P11@D40>c/k05=CD`16ATH0EEEE055AD@1KFe/0ATI6065QH@14A4@0@T9204];
B`18B4P0DE5A06IVIP0n?Sh0Bd];0451@@17AdL0BDU905QHF01IFET0Cdm?04=3@`1>CTh0EEEE07Ee
M@13@d<0AdM706IVIP1@D50206IVIP0A03/k>`11@D40KVi^08f=S@1aLG40Ng]k02XZ:P1QHF40CDe=
092@T034a<@0Y:BT0>OWi`2>SXh0IVIV0820P010@4000P1ZJVX01P1=CDd0UiNG0410@01NGUh0I6AT
05=CD`80DU9B02d0P82003hn?P1IFET0:BTY04Y:BP0e=CD0IVIV08B4Q00U9BD0EeMG04E5A@1lO7`0
@410059BDP1MGEd0H61P07MgM`1_Kfl0L71`0>[ZjP31`L40?clo04e=C@0b<S80O7al04i>CP21PH40
P82003Lg=`2ATI40Jf][05MGE`24Q8@09bLW02TY:@1MGEd0BDU905QHF01WIfL0>SXj04e=C@1LG5`0
WIfM05iNGP23Ph<00P1ZJVX0:02ATI40HV9R04M7A`1:BTX0CTi>06YZJP0k>c/0<c<c05=CD`0U9BD0
EEEE05aLG00V9RH0B4Q805]KF`1VIVH0GemO05IFEP1SHf<0>SXj06IVIP1OGel0UYJF06EUI@2OWil0
R8R804Q8B01DE5@0Fe]K04M7A`1:BTX0C4a<03Xj>P14A4@0Fe]K04];B`1DE5@0Fe]K05MGE`1:BTX2
05=CD`0U04a<C019BDT0;2`/06YZJP1RHV80<30`04];B`16ATH0H61P065QH@0j>SX0AdM702DU9@0f
=SH0@T9205]KF`1LG5`0E5AD05IFEP1GEeL0EUIF06IVIP1=CDd0GemO05aLG00a<C40DU9B05UIF@1E
EED0I6AT03`l?01jNWX0SHf=04];B`1RHV80DE5A04E5A@02061PH00408j>SP1fMWH0TI6A03/k>`80
N7Qh01@0KVi^08j>SP1aLG40Rh^;06m_K`1PH600TI6A06m_K`16ATH0FUYJ04E5A@1OGel0Cdm?05iN
GP0n?Sh0BDU9055AD@1fMWH0Xj>S061PH080RXZ:00<0LW9b0820P?ooool00Oooool0002_0861P@1_
Kfl0a/K605=CD`1IFET0R8R807QhN028R8P0L71`03`l?01FEUH0WYjN06QXJ02PX:00R8R8020P801=
CDd0Rh^;079bLP1iNGT0R8R802XZ:P16ATH0EUIF09JFUP1gMgL0NWYj09VIV@0U9BD0?Cdm05ADE024
Q8@0@T9205IFEP1?Cdl092@T059BDP1PH600D51@03Lg=`1YJFT0<30`01TI6@1;Bd/0TI6A07=cL`1<
C4`0HF5Q02`/;00I6AT0EUIF0:2PX00k>c/0CDe=069RHP0Y:BT0>SXj09^KV`1[Jf/0=CDe03Hf=P10
@400;bl_04i>CP1fMWH0;Rh^03Lg=`1BDU80>SXj05YJFP2`/;00EUIF01TI6@15ADD0J6QX04M7A`2<
S8`0[Jf]01lO7`0S8b<0=cLg05EEE@1HF5P0K6a/0:b/[00g=cL0;bl_04Q8B01dM7@0DE5A07UiN@2?
Shl09bLW02h^;P1JFUX0MGEe06][J`2DU9@0>SXj02PX:015ADD0Ogmo06UYJ@28R8P0RXZ:01/K6`0j
>SX0D51@079bLP1IFET0Q8B405ADE00Q8B40E5AD069RHP1WIfL0E5AD07]kN`0e=CD0;Bd]05mOG`1L
G5`0E5AD055AD@2>SXh06QXJ03De=@1JFUX0KFe]04Y:BP1IFET0Jf][02LW9`13@d<0EEEE08Z:RP16
ATH0MGEe08N7Q`0_;bl0EUIF07AdM023Ph<0<S8b08J6QP1VIVH0ADE506YZJP2EUID0Shn?04M7A`1O
Gel0;Rh^03/k>`19BDT0Ogmo04=3@`14A4@0EeMG03Ph>02FUYH0VIVI03Ti>@0m?Cd0BDU903`l?01@
D500HF5Q06YZJP0b<S80De=C04M7A`1SHf<0ZJVY0:6QX@0202XZ:P3o04e=C@0o?cl0Cdm?0;Vi^@2L
W9`0:RXZ03`l?01RHV80BDU905QHF02n_[h0Kfm_02d];@17AdL0EEEE05UIF@2GUiL0bLW905UIF@10
@400EeMG06MWI`1VIVH0XJ6Q0=GEe@14A4@0@d=305=CD`2ATI40OGem0;^k^`2:RXX0<30`07emO@2B
TY80LW9b08B4Q02f][H0=3@d034a<@2TY:@0S8b<069RHP2LW9`0@D5103Ph>01LG5`0`l?305aLG02T
Y:@0EUIF02h^;P14A4@0[Zj^05MGE`1eMGD0BTY:03<c<`1;Bd/0Ogmo06MWI`21PH40UYJF03@d=01P
H600O7al055AD@1?Cdl0Ogmo04U9B@1>CTh0N7Qh09VIV@1DE5@0RHV906UYJ@19BDT0OGem09RHV01P
H600CDe=09ZJVP16ATH0IVIV09ZJVP2EUID0?clo04i>CP2JVYX0JVYZ071`L01nOWh0AdM702l_;`14
A4@0E5AD06QXJ01RHV80Z:RX05YJFP0Z:RX0>c/k04m?C`1NGUh0CDe=0;fm_@1_Kfl0<30`05MGE`1=
CDd0JFUY0:6QX@31`L40EEEE0451@@1OGel0BDU903lo?`2DU9@0_[jn03hn?P0h>3P0CTi>08Z:RP1Q
HF40Shn?0:VYZ@0o?cl0:RXZ03hn?P20P800KVi^09fMW@33`l<0EeMG02HV9P0o?cl0UIFE05ADE01n
OWh0LG5a03Ph>01FEUH0O7al07QhN01:BTX0B4Q805aLG01PH600KFe]079bLP11@D40LG5a065QH@0i
>CT0ATI6055AD@0o?cl0ADE504m?C`1VIVH0FEUI05MGE`1MGEd0IFEU03Xj>P0Z:RX0Fe]K0492@P19
BDT0Cdm?05eMG@16ATH0?Cdm06IVIP1dM7@0XJ6Q05IFEP16ATH0IfMW05iNGP1/K6`0EUIF05ADE01@
D500FUYJ04Y:BP0W9bL0Cdm?05mOG`1GEeL0HF5Q04U9B@1:BTX0>SXj03@d=01FEUH0R8R807inOP1<
C4`0Bd];079bLP18B4P0DU9B069RHP1WIfL0HV9R05mOG`1bLW80HF5Q071`L01dM7@0HF5Q061PH00o
?cl0L71`04a<C01YJFT0MgMg06EUI@12@T80C4a<07AdM01GEeL0K6a/07IfMP1:BTX0Bd];02HV9P0k
>c/0FUYJ0492@P18B4P0ATI605iNGP0d=3@0?3`l04Q8B01BDU80?clo05]KF`1EEED0EUIF03hn?P1F
EUH0I6AT03<c<`1?Cdl0L71`06QXJ00k>c/0GUiN04M7A`1ADE40CTi>000`04Q8B01YJFT0QHF504a<
C018B4P0Bd];04=3@`1TI6@0?Cdm06ATI01mOGd0?Shn05QHF01@D500MWIf04M7A`1<C4`0H61P03Xj
>P26QXH0MgMg03lo?`1?Cdl0CTi>05YJFP10@400EEEE05aLG02LW9`0CDe=05=CD`1nOWh0GemO0:BT
Y023Ph<0NWYj08>3P`1@D500Ti>C07inOP1MGEd0XZ:R05iNGP1VIVH0QXJ606=SH`2>SXh0OWin0P1C
De<0OP20P800FUYJ05eMG@13@d<0MGEe07emO@1=CDd0N7Qh03Hf=P1mOGd0<C4a06YZJP1gMgL0J6QX
0;>c/`1UIFD0?Shn07]kN`1FEUH0=CDe08n?S`19BDT0PX:2030`<01lO7`0RXZ:01dM7@2OWil0GUiN
03<c<`1HF5P08b<S02LW9`1_Kfl0>3Ph05YJFP1EEED0=3@d06i^KP19BDT0EEEE0410@02@T900K6a/
04e=C@1hN7P0CDe=051@D01ADE40Cdm?06a/K00f=SH0Bd];08^;R`0/;2`0AdM705]KF`0W9bL0Fe]K
04A4A00h>3P0Cdm?06MWI`1iNGT0M7Ad07]kN`11@D40EEEE0451@@1LG5`0AdM70410@01eMGD0KFe]
03Lg=`0h>3P0Bd];04A4A00l?3`0Bd];04A4A01:BTX0DU9B04U9B@0`<300D51@0410@01=CDd0EeMG
02PX:02PX:00Y:BT055AD@1IFET0DE5A03@d=016ATH0?Shn07AdM00c<c<0B4Q806EUI@2ATI40BTY:
05MGE`1CDe<0EEEE04M7A`1<C4`0DE5A06e]K@1WIfL0H61P07UiN@1CDe<0EeMG05UIF@13@d<0LW9b
08:2PP13@d<0Hf=S04Y:BP0o?cl0CTi>07AdM080UiNG01`0Shn?01PH601EEED0FUYJ06a/K01iNGT0
D51@06MWI`1eMGD0ADE507MgM`1>CTh0=cLg05iNGP1=CDd0KVi^03De=@1YJFT0@41004a<C01IFET0
HF5Q059BDP1aLG40SXj>06YZJP21PH40QHF50_ooool0000H09:BTP1BDU80NGUi06ATI01PH600Kfm_
04Q8B01NGUh0Shn?059BDP1OGel0ADE504i>CP1XJ6P0SHf=03Xj>P0h>3P0G5aL05QHF01BDU80YJFU
05aLG00Y:BT0D51@0P0l?3`0o`2@T900Vi^K04E5A@0U9BD0=3@d06UYJ@1iNGT0Ti>C075aL@0M7Ad0
9BDU04E5A@1VIVH0IFEU0<g=c@1BDU806ATI024Q8@1NGUh0H61P07EeM@32`/80@41002DU9@0a<C40
De=C04Q8B02<S8`0YjNW01hN7P0R8R80?Cdm06QXJ01GEeL0NGUi05QHF00L71`0>SXj04Q8B01@D500
HV9R09BDU010@4009BDU04];B`1HF5P0?3`l07=cL`1TI6@0:RXZ03/k>`1/K6`0LW9b04=3@`23Ph<0
H61P01`L7018B4P0EUIF06UYJ@0e=CD0Hf=S038b<P0c<c<0A4A407=cL`0o?cl0D51@06][J`0d=3@0
Fe]K06=SH`1XJ6P0:b/[05ADE00d=3@0?3`l05mOG`1eMGD0Bd];03Lg=`1^KVh0;Bd]04a<C01YJFT0
Kfm_03De=@16ATH0IVIV04=3@`1TI6@0SHf=071`L00X:2P0DE5A05eMG@1ADE40L71`0=OGe`1KFe/0
8B4Q04Y:BP1FEUH0?clo08J6QP2n_[h0D51@038b<P1<C4`0IfMW05=CD`2MWId0`/;203Hf=P10@400
J6QX06a/K018B4P0];Bd0;2`/00b<S80HV9R07]kN`1YJFT0SHf=0:n_[`0c<c<0:RXZ05YJFP1oOgl0
D51@07QhN02:RXX0;Bd]07EeM@2][Jd0MgMg0:ZZZP2CTi<0=cLg04M7A`1/K6`0S8b<05IFEP2ATI40
Q8B403dm?@12@T80SHf=08B4Q01NGUh0PX:204A4A00l?3`0JVYZ0;Ng]`1YJFT0S8b<07alO00f=SH0
>SXj07QhN033`l<0D51@08Z:RP1KFe/0?Shn03`l?02:RXX0_[jn05]KF`2HV9P0GemO03<c<`10@400
RHV909nOW`1@D500UYJF03De=@0c<c<0CDe=08^;R`11@D40TI6A069RHP0k>c/0GemO08V9R@1dM7@0
KFe]07inOP13@d<0AdM70;^k^`2=SHd0<30`069RHP1/K6`0C4a<0;6a/@2OWil0<30`03`l?02>SXh0
RHV90<S8b02=SHd0<c<c051@D01GEeL0F5QH0:f][@3Jf]X0AdM703hn?P2<S8`0I6AT07]kN`2c/k<0
A4A403hn?P1ADE40Ph>305iNGP2k^k/0Ph>303Ti>@1LG5`0TY:B07alO02:RXX0h>3P03lo?`11@D40
Hf=S09VIV@1EEED0JFUY0;Zj^P0e=CD0HV9R0::RXP1oOgl0CTi>0:JVYP1]KFd0?Cdm05YJFP2EUID0
Ogmo05QHF02a/K40U9BD024Q8@00o`0l?3`0TY:B09RHV01KFe/0/k>c07alO00_;bl0EeMG09BDU01j
NWX0JVYZ09BDU00o?cl08B4Q0492@P1eMGD0Q8B404m?C`23Ph<09bLW03Lg=`11@D40S8b<07QhN01C
De<0I6AT02l_;`0c<c<0?3`l07YjNP1OGel0?3`l05eMG@0m?Cd0?3`l06ATI02:RXX0@D5106ATI01Y
JFT0J6QX04A4A019BDT0CTi>0410@01:BTX0DE5A03Ti>@1CDe<0>SXj04Q8B014A4@0FUYJ05IFEP1?
Cdl0Ng]k04Q8B01>CTh0AdM703<c<`12@T80@d=3038b<P19BDT0>CTi0492@P13@d<0D51@04E5A@18
B4P0De=C051@D01DE5@0CDe=04m?C`18B4P0AdM705=CD`1QHF40K6a/05QHF015ADD0D51@03Ph>011
@D40@d=30451@@1GEeL0A4A404E5A@18B4P0ADE505EEE@1`L700Lg=c04];B`1RHV80LW9b05YJFP1b
LW80CDe=04=3@`1NGUh0CTi>05]KF`17AdL0De=C07MgM`1YJFT0MGEe04A4A028R8P0EEEE07AdM01R
HV80De=C020P801?Cdl0JFUY0820P01nOWh0H61P06i^KP1UIFD0;2`/03@d=01?Cdl0AdM704m?C`10
@400CDe=03Hf=P10@400=SHf03@d=00O7al0DE5A03<c<`1>CTh0?Cdm051@D01>CTh0?Cdm04];B`1P
H600GEeM05UIF@1?Cdl0ADE504I6AP1=CDd0DE5A05YJFP1EEED0ADE5059BDP17AdL0CDe=04a<C019
BDT0Hf=S08R8R013@d<0Fe]K04U9B@1dM7@0FUYJ059BDP2OWil0De=C079bLP20P800IfMW07=cL`1V
IVH0Shn?05iNGP1iNGT0?clo05aLG016ATH0N7Qh0:JVYP29RHT0`<3009>CT`2ATI40[Zj^06EUI@2?
Shl0Kfm_06UYJ@2TY:@0HV9R06IVIP1_Kfl0SHf=05eMG@1[Jf/0EeMG0451@@1?Cdl0B4Q805iNGP0J
6QX0QHF508:2PP1BDU80Ogmo04E5A@2:RXX0<30`0:JVYP2`/;00?Shn05ADE01@D500GEeM0<K6aP2U
YJD0?Shn05YJFP14A4@0K6a/03hn?P23Ph<0P82004E5A@1<C4`0BTY:07=cL`2MWId0F5QH04];B`22
PX80?Cdm05iNGP1cLg<0<S8b06e]K@0g=cL0HV9R03De=@2/[:`0NWYj05iNGP2;Rh/0B4Q805]KF`1F
EUH0BTY:06][J`12@T80?clo04];B`00IP1=CDd0UiNG0:FUY@0n?Sh0IFEU05aLG01^KVh0GEeM04e=
C@1:BTX0ADE505eMG@1bLW80HF5Q028R8P1fMWH0L71`01/K6`1?Cdl0ADE502h^;P10@400<C4a05=C
D`16ATH0CDe=03Ph>01@D500Fe]K04Q8B00n?Sh0E5AD03/k>`19BDT0JVYZ020P801LG5`0EUIF01LG
5`1FEUH0?Cdm03Lg=`1:BTX0D51@05eMG@1BDU80DE5A051@D01RHV80G5aL05mOG`1HF5P0@T9204m?
C`1JFUX0FEUI07inOP1;Bd/0>c/k05mOG`1CDe<0FUYJ07MgM`10@400Fe]K06UYJ@0i>CT0RXZ:04a<
C01EEED0IFEU055AD@1bLW80X:2P09BDU00/;2`0Ph>306=SH`1JFUX0P82005ADE01ZJVX0MGEe03lo
?`1TI6@0D51@06=SH`1/K6`0Hf=S06a/K00e=CD0BTY:055AD@1QHF40JFUY07QhN027QhL0HF5Q06][
J`1kNg/0GEeM06a/K0;ooooo0000YP2a/K40EEEE07AdM024Q8@0TY:B09NGU`0h>3P0C4a<09JFUP1V
IVH0UIFE04i>CP0o?cl0GEeM0:JVYP1_Kfl0Jf][08Z:RP1:BTX0AdM705EEE@2NWYh0MGEe0:j^[P1T
I6@0;bl_04A4A01hN7P0Y:BT05iNGP2GUiL0ADE503lo?`1MGEd0O7al051@D01WIfL0A4A402h^;P0f
=SH0Hf=S09RHV00k>c/0Cdm?06QXJ00S8b<0<S8b06e]K@24Q8@0?clo061PH012@T80@41004U9B@1a
LG40F5QH04];B`1>CTh0=CDe04Y:BP2;Rh/0]kNg04Q8B01NGUh0D51@02`/;01>CTh0OGem09RHV00f
=SH0G5aL03`l?016ATH0JFUY096AT@1CDe<0?3`l05MGE`15ADD0D51@07QhN02<S8`0;2`/02LW9`1[
Jf/0LW9b05eMG@2VYZH0A4A403@d=00];Bd0J6QX04U9B@1dM7@0/k>c0492@P0[:b/0AdM709>CT`1A
DE40XZ:R06QXJ00T92@0=cLg06][J`1PH600IFEU09jNWP0_;bl092@T04];B`1kNg/0Fe]K079bLP2E
UID09RHV0451@@1KFe/0Ph>3065QH@21PH40IVIV02TY:@1?Cdl0Ng]k08b<S01EEED0[Zj^059BDP0Z
:RX0Bd];07alO02=SHd0HF5Q08B4Q00m?Cd0=3@d065QH@2/[:`0RXZ:061PH02g]kL0Bd];03Xj>P1<
C4`0TY:B065QH@1TI6@0OWin01dM7@1OGel0SXj>08R8R016ATH0DU9B06][J`0];Bd0D51@08>3P`1N
GUh0LW9b0410@00i>CT0TY:B0:>SX`1>CTh204e=C@06059BDP1GEeL0WIfM09JFUP1?Cdl0GEeM0P1U
IFD07`1XJ6P0XZ:R03`l?00O7al0BDU904m?C`1;Bd/0Shn?09JFUP0];Bd0=3@d055AD@1IFET0EeMG
08J6QP2WYjL0?Shn03lo?`1CDe<0KFe]05UIF@2IVIT0`<300492@P17AdL0Bd];07QhN01^KVh0dm?C
08B4Q00j>SX00P1`L7009019BDT0[:b/0:>SX`0I6AT0BTY:06e]K@1VIVH0Shn?0;jn_P0n?Sh0CDe=
07]kN`2d];@0I6AT0:6QX@1CDe<0:RXZ06e]K@34a<@0M7Ad0820P02FUYH08R8R05=CD`2/[:`0Ng]k
07alO01FEUH0=SHf05EEE@23Ph<0Kfm_07alO024Q8@0:2PX038b<P80R8R80<`0KFe]08f=S@0f=SH0
<30`06EUI@2n_[h0Jf][071`L02;Rh/0?Cdm04m?C`1mOGd0QHF50492@P1TI6@0GemO03Ph>01QHF40
^KVi05YJFP11@D40U9BD04m?C`0d=3@0RHV908>3P`0X:2P0>3Ph071`L00^;Rh0=SHf07YjNP32`/80
FEUI02@T901dM7@0GemO05ADE02KVi/0K6a/02/[:`1>CTh0NGUi061PH01YJFT0`<3008V9R@0U9BD0
@41005mOG`1XJ6P0K6a/0;^k^`1^KVh08B4Q03Lg=`1CDe<0GemO05EEE@2ATI40B4Q802PX:01<C4`0
GEeM05iNGP1LG5`0/K6a069RHP0V9RH0BTY:07=cL`18B4P0F5QH06MWI`1/K6`0EUIF04m?C`1JFUX0
BDU905ADE01NGUh0BTY:06UYJ@1DE5@0@d=303`l?01<C4`0GUiN069RHP1SHf<0DU9B05aLG01ZJVX0
IfMW05=CD`1=CDd0Bd];05iNGP15ADD0Bd];04e=C@1EEED0Cdm?059BDP1YJFT0KVi^08j>SP1<C4`0
ADE5071`L01HF5P0QhN704m?C`1XJ6P0H61P05=CD`1HF5P0<c<c0492@P1IFET0EUIF079bLP18B4P0
Fe]K05aLG018B4P0HF5Q05YJFP1DE5@0ADE506=SH`1NGUh0=cLg04E5A@1QHF40JFUY05eMG@0o?cl0
GemO04m?C`1MGEd0FUYJ055AD@1EEED0CTi>05mOG`0a<C40Kfm_0;Ng]`1^KVh09BDU03Ph>013@d<0
E5AD06a/K01MGEd0ADE507UiN@1ADE40L71`07AdM00d=3@0AdM706EUI@1iNGT0CDe=0492@P1:BTX0
FUYJ03De=@1IFET0;Rh^051@D00c<c<0CTi>03dm?@0Y:BT0?Shn04Q8B01RHV80CDe=04M7A`0h>3P0
C4a<03`l?01BDU80E5AD06ATI01CDe<0B4Q804a<C017AdL0B4Q803dm?@1IFET0NGUi06ATI023Ph<0
DE5A09BDU01DE5@0RHV906YZJP13@d<2079bLP0303dm?@1HF5P0De=C0080MgMg02<0[jn_05UIF@1_
Kfl0GUiN0820P02UYJD0Ng]k0:f][@1QHF40P8200:b/[01SHf<0UIFE071`L01JFUX0Xj>S03@d=024
Q8@0HV9R04e=C@1BDU80SHf=08^;R`17AdL0DU9B03<c<`2=SHd0CTi>096AT@23Ph<0>3Ph055AD@19
BDT0M7Ad02<S8`0205iNGP0^055AD@1kNg/0Bd];059BDP3Bd]80XJ6Q04E5A@1hN7P0F5QH0861P@1G
EeL0S8b<0:b/[01?Cdl0QXJ605]KF`0l?3`0FEUI03De=@0];Bd0HV9R03lo?`1bLW80SHf=04i>CP1F
EUH0A4A406][J`1;Bd/0^;Rh07inOP1TI6@0V9RH04Y:BP0o?cl0C4a<05aLG01BDU80F5QH04M7A`1H
F5P0;2`/05=CD`1MGEd0=3@d04U9B@80>3Ph0500BTY:06MWI`1:BTX0EUIF05QHF023Ph<0Ogmo03Hf
=P1MGEd0CTi>01DE5@1ADE40C4a<024Q8@1EEED0?Cdm04A4A00c<c<0CDe=04=3@`18B4P0F5QH05AD
E00m?Cd0IVIV0451@@0i>CT0De=C01/K6`1bLW80I6AT01lO7`1WIfL0F5QH06UYJ@1MGEd0L71`07em
O@1TI6@0EeMG04Q8B01SHf<0EeMG04e=C@14A4@0CDe=06e]K@1PH600JVYZ079bLP0m?Cd0@41006i^
KP1JFUX0SHf=08Z:RP0m?Cd0J6QX07moO`0];Bd0De=C05QHF01OGel0E5AD05QHF01dM7@0];Bd0:VY
Z@16ATH0F5QH06IVIP1[Jf/0KVi^075aL@2=SHd0NGUi04m?C`2FUYH0Cdm?04A4A080D51@00d0GUiN
03hn?P1NGUh0CDe=0451@@1MGEd0NGUi09jNWP1ZJVX0Lg=c06YZJP1cLg<0G5aL00;ooooo0000A@26
QXH0Hf=S09BDU01<C4`0CTi>08B4Q01SHf<0GemO04e=C@0a<C40Jf][07YjNP15ADD0Hf=S04m?C`0h
>3P0?3`l06MWI`1ADE40@T9205iNGP0d=3@0FEUI05]KF`1/K6`0<C4a03hn?P1OGel0=3@d03hn?P1Z
JVX0De=C02l_;`0a<C40?Shn03Lg=`1>CTh0MGEe02<S8`0N7Qh0BDU905aLG01@D500IfMW09NGU`0f
=SH07alO05ADE01IFET0E5AD07]kN`2FUYH09RHV04m?C`1dM7@0CTi>07IfMP2g]kL0=cLg01/K6`1K
Fe/0V9RH05]KF`2c/k<0KVi^02LW9`0O7al0IFEU0;:b/P0207=cL`1V04e=C@0W9bL0ATI6075aL@1m
OGd0QXJ60:NWY`0O7al0;Rh^04E5A@21PH40L71`06ATI02BTY80=3@d030`<016ATH0IFEU05=CD`1c
Lg<0FEUI02@T900k>c/0@41005eMG@1=CDd0Cdm?02DU9@0`<300G5aL08>3P`1@D500CDe=04];B`0V
9RH0B4Q806ATI024Q8@0>c/k055AD@0e=CD0?Cdm06m_K`1fMWH0B4Q803@d=01=CDd0@4100451@@1c
Lg<0RHV902TY:@0d=3@0A4A403Hf=P0b<S80PH6107alO00W9bL0;bl_03dm?@1HF5P0A4A40:NWY`1n
OWh0<30`03Ph>01CDe<0MWIf06a/K02RXZ80F5QH02l_;`19BDT0B4Q805YJFP2>SXh0/k>c03Xj>P0b
<S80HV9R06][J`1]KFd0P8200;^k^`0f=SH0ADE5071`L021PH40alO706a/K00T92@0C4a<06i^KP1N
GUh0Vi^K0:f][@0j>SX0GemO06IVIP2IVIT0PH610P2PX:00:00l?3`0A4A409jNWP1cLg<0GUiN09VI
V@1JFUX09BDU0492@P2_[jl0U9BD06EUI@2i^KT0GEeM03Lg=`1BDU80NGUi07alO01UIFD0TY:B03@d
=00a<C40BTY:08>3P`1kNg/0IVIV07MgM`1ADE40?Cdm04e=C@21PH40EUIF09ZJVP1ZJVX0=SHf08Z:
RP2/[:`0GUiN055AD@1hN7P203`l?0060:FUY@20P800>SXj06ATI01nOWh0@D510P1dM7@0K@0e=CD0
Bd];05aLG01OGel0OWin0:ZZZP0];Bd0=SHf061PH01HF5P0Shn?09fMW@0Z:RX0ADE507=cL`1GEeL0
M7Ad0:n_[`0g=cL07AdM069RHP1UIFD0N7Qh0=3@d01WIfL09bLW03Ph>01hN7P0KFe]08f=S@2CTi<0
<30`04U9B@1]KFd0RHV907AdM03Cdm<0VYZJ024Q8@1FEUH0W9bL05QHF01VIVH0clo?06EUI@0O7al0
BTY:09RHV01=CDd0Lg=c0<;2`P1>CTh0>3Ph04a<C02:RXX0MgMg04I6AP2XZ:P0B4Q804m?C`1cLg<0
SHf=0410@023Ph<0KVi^03Hf=P1>CTh0R8R80;no_`1:BTX0HV9R07moO`0^;Rh0AdM707QhN02HV9P0
ATI606MWI`1JFUX0:BTY04=3@`1CDe<0V9RH03Ph>01JFUX0DE5A034a<@10@400QHF508n?S`16ATH0
IVIV04A4A015ADD0DE5A06ATI01^KVh0A4A404U9B@1TI6@0JFUY05mOG`17AdL0=3@d04Y:BP12@T80
@d=303Ph>01UIFD00P1BDU804P21PH40Cdm?06=SH`1@D500>3Ph04M7A`0j>SX0:b/[03lo?`0j>SX0
?clo04E5A@1BDU80?clo04A4A01=CDd0A4A404e=C@80BDU900T0EeMG06MWI`1NGUh0EEEE05iNGP1E
EED0IVIV05]KF`0];Bd00P1BDU80;@1FEUH0IfMW06IVIP1XJ6P0EEEE04i>CP1WIfL0QXJ607emO@11
@D40Cdm?07emO@11@D40KFe]04U9B@14A4@0GUiN02`/;00o?cl0EUIF06][J`1jNWX0HV9R06=SH`10
@400S8b<03dm?@1bLW80NGUi07EeM@0m?Cd0@d=307]kN`1WIfL0V9RH06a/K01;Bd/0OGem0410@01<
C4`0Jf][069RHP1MGEd0D51@05YJFP0204e=C@80F5QH08l0=CDe06ATI01@D500EEEE04a<C00[:b/0
;Rh^03`l?00o?cl0<C4a04U9B@1RHV80ADE502TY:@0h>3P0Bd];05mOG`0l?3`0BDU905]KF`17AdL0
=SHf04i>CP1/K6`0@d=3055AD@1=CDd0?clo055AD@1:BTX0QHF5055AD@1PH600MGEe03dm?@1BDU80
CTi>06MWI`1gMgL0FEUI06i^KP1?Cdl0M7Ad0492@P1RHV80:RXZ08N7Q`2YZJT0IFEU096AT@1@D500
NWYj08V9R@0l?3`0MWIf05EEE@1dM7@0YZJV04m?C`1=CDd0EeMG06MWI`1UIFD0LG5a06=SH`19BDT0
Cdm?01lO7`1=CDd04a<C07alO01WIfL0>CTi06IVIP0m?Cd0P82002@T901QHF40IVIV04A4A023Ph<0
GEeM08R8R03Xj>P0Vi^K02d];@1eMGD0HF5Q08^;R`1OGel0T92@08J6QP11@D40RXZ:07IfMP1<C4`0
JFUY034a<@11@D40Fe]K04];B`1GEeL0Hf=S04I6AP1ADE40B4Q808N7Q`1EEED0PX:2075aL@1fMWH0
UIFE06=SH`1>CTh0GEeM05]KF`1XJ6P0CDe=04a<C01aLG40B4Q8079bLP1lO7`0:2PX04U9B@0c<c<0
>c/k04E5A@1aLG40Cdm?06QXJ01_Kfl0XJ6Q08f=S@0k>c/0JVYZ06=SH`0Z:RX0De=C05ADE00_;bl0
BDU903Lg=`0203dm?@0>051@D00/;2`0@D5105IFEP0o?cl0;bl_051@D01:BTX0@41006IVIP0X:2P0
/[:b08V9R@0N7Qh204e=C@0A04];B`1FEUH0EUIF05]KF`1fMWH0F5QH03Xj>P1=CDd0M7Ad06MWI`1G
EeL0H61P05MGE`1DE5@0EEEE04e=C@1ADE400P1gMgL0:P17AdL0>SXj04e=C@0b<S80GEeM07]kN`0X
:2P0J6QX04U9B@1;Bd/0IFEU04m?C`1iNGT0XZ:R07=cL`17AdL0IFEU05YJFP2MWId0XJ6Q04e=C@15
ADD0GemO06QXJ023Ph<0KVi^04U9B@1QHF40F5QH06IVIP0b<S80VIVI06][J`1<C4`0GEeM08Z:RP22
PX80GUiN08f=S@1hN7P0IVIV06MWI`;ooooo0000O@1bLW80Ng]k0<W9b@1EEED0EUIF069RHP1JFUX0
Kfm_07emO@0f=SH0GemO0820P01FEUH0Rh^;08n?S`0b<S80E5AD05iNGP1HF5P0Ogmo0;6a/@1<C4`0
=CDe0410@01eMGD0JVYZ07=cL`31`L40>CTi02@T901GEeL0YJFU05aLG024Q8@0EUIF02TY:@0e=CD0
E5AD06QXJ01OGel0W9bL0410@00h>3P0BDU906IVIP1YJFT0D51@079bLP0/;2`0<30`04A4A01OGel0
HF5Q051@D01EEED07AdM0451@@1UIFD0JFUY02DU9@0i>CT0?3`l02XZ:P1@D500JVYZ04U9B@0n?Sh0
ATI6024Q8@1<C4`0NGUi07alO00a<C40B4Q80451@@12@T80H61P09^KV`15ADD06a/K03dm?@13@d<0
@T9205YJFP2d];@0?Cdm02l_;`1?Cdl0@d=3069RHP1nOWh0RHV9024Q8@10@400D51@055AD@1VIVH0
SXj>04Y:BP0I6AT0=CDe05]KF`1DE5@0UYJF08j>SP0U9BD0;2`/04Y:BP1bLW80F5QH09ZJVP1gMgL0
<C4a03Ph>01mOGd0LW9b05YJFP2LW9`0=CDe02h^;P0f=SH0JFUY051@D026QXH0[:b/0080:BTY0?l0
De=C06e]K@1TI6@0Y:BT08N7Q`0d=3@0@D5105MGE`27QhL0D51@09JFUP23Ph<0>3Ph051@D028R8P0
/K6a061PH02i^KT0JVYZ03Xj>P1TI6@0YjNW0:6QX@1;Bd/0IfMW02/[:`0o?cl0Bd];09BDU01]KFd0
L71`05aLG00a<C40O7al08N7Q`1DE5@0YJFU08Z:RP0^;Rh0@d=308Z:RP1@D500=SHf079bLP0l?3`0
?Shn05UIF@1_Kfl0IfMW05mOG`1_Kfl0>3Ph02LW9`1eMGD0ZZZZ03Ph>01ADE40GUiN03`l?01MGEd0
OWin08F5Q@0h>3P0EUIF0492@P1`L700OGem0:JVYP1DE5@09bLW04M7A`1:BTX0MgMg0:VYZ@2PX:00
?Cdm03Ti>@1CDe<0@41005MGE`2m_Kd0T92@038b<P15ADD0Jf][08R8R034a<@0_kno03/k>`1:BTX0
KFe]06QXJ01iNGT0dM7A07UiN@11@D40FUYJ08>3P`1<C4`0YjNW06IVIP0Y:BT0MWIf0;:b/P1fMWH0
KFe]06i^KP19BDT0Bd];0:ZZZP1mOGd0UYJF08>3P`0e=CD0D51@08b<S01mOGd0K6a/06IVIP0i>CT0
D51@0:^[Z`2l_;`0JFUY07IfMP17AdL0;bl_06][J`2?Shl0IVIV05EEE@22PX80@d=304Y:BP1EEED0
^KVi07IfMP1=CDd0Rh^;05=CD`1;Bd/0SHf=09jNWP1FEUH0G5aL04Q8B00m?Cd0BTY:07=cL`1ZJVX0
:BTY04Q8B014A4@0ADE504Q8B02CTi<0Fe]K02d];@1CDe<0O7al059BDP2VYZH0YJFU04Y:BP0[:b/0
GEeM07IfMP1QHF40WinO08>3P`0b<S80=CDe051@D01PH600AdM709fMW@2a/K40;Bd]03Ti>@1;Bd/0
H61P059BDP2QXJ40[:b/02TY:@0];Bd0FUYJ0861P@1CDe<0WinO05ADE00j>SX0Fe]K075aL@1lO7`0
ATI604A4A01PH600?Cdm059BDP1<C4`0=3@d05ADE016ATH0@D5103dm?@1QHF40CTi>05=CD`2:RXX0
D51@071`L01UIFD0CTi>061PH00h>3P0<S8b04];B`14A4@0=CDe04A4A00h>3P0AdM704Q8B01nOWh0
EEEE07IfMP1GEeL0ATI6079bLP1HF5P0Jf][05ADE01`L700IFEU04i>CP1@D50092@T03<c<`1<C4`0
DU9B05eMG@0o?cl0ADE504Q8B010@400ADE504i>CP1KFe/0@41004Y:BP1HF5P0FEUI06MWI`17AdL0
0?l0ATI607alO01?Cdl0IFEU051@D01GEeL0Ng]k075aL@1UIFD0B4Q805IFEP12@T80D51@06ATI01G
EeL0C4a<065QH@2JVYX0X:2P0;>c/`1hN7P0NGUi06ATI00j>SX0BTY:05=CD`0Y:BT0A4A403Ti>@15
ADD0@d=3038b<P0c<c<0@41003Ti>@1PH600>SXj04i>CP1<C4`0HV9R05ADE012@T80Cdm?06MWI`1E
EED0ATI6051@D00i>CT0A4A404Q8B01LG5`0CDe=05QHF01EEED0FUYJ04M7A`1:BTX0EUIF04i>CP1I
FET0KFe]06YZJP1mOGd0BDU9071`L01PH600QHF507QhN00m?Cd0De=C061PH01:BTX0HV9R04U9B@1<
C4`0K6a/07inOP1DE5@0S8b<01TI6@1]KFd0Kfm_04U9B@2KVi/0Jf][0:2PX02OWil0B4Q807UiN@18
B4P0Jf][09JFUP0c<c<0F5QH04m?C`1kNg/0GEeM06UYJ@1RHV80ADE506=SH`0n?Sh0HV9R03Ti>@25
QHD0JVYZ061PH01iNGT0BDU905MGE`11@D40Jf][06EUI@1bLW80QhN704M7A`0k>c/0Q8B406EUI@0a
<C40LW9b055AD@29RHT0BTY:08J6QP1jNWX0@41009RHV01JFUX0>3Ph06a/K00n?Sh0CTi>09ZJVP0Z
:RX0JVYZ07EeM@15ADD0HV9R051@D01bLW80M7Ad09JFUP1FEUH0I6AT09ZJVP1HF5P0Bd];05aLG01D
E5@0I6AT01<C4`14A4@0IFEU01hN7P1lO7`0PX:203Ti>@1JFUX0BTY:059BDP1IFET0VYZJ08B4Q01c
Lg<0GUiN05mOG`1aLG40@d=306QXJ01OGel0:b/[05IFEP1@D500:RXZ04Y:BP0c<c<0>CTi02XZ:P1A
DE40@T9206IVIP1JFUX0ATI603hn?P1KFe/0DE5A03<c<`1:BTX0;Bd]06YZJP1UIFD0?Shn05=CD`15
ADD0FEUI04A4A00c<c<0Bd];08^;R`1MGEd0EUIF092@T01eMGD0EUIF061PH01aLG40EUIF059BDP0k
>c/0EUIF05=CD`0f=SH0GemO04e=C@1LG5`0Kfm_02h^;P1SHf<0LG5a04Y:BP1PH600Cdm?04Y:BP1C
De<0RHV909JFUP2QXJ40N7Qh02<S8`1@D500GemO09NGU`2DU9@0K6a/05eMG@1oOgl0BDU907AdM00n
?Sh0ADE505QHF01CDe<0FEUI04U9B@1hN7P0GUiN05aLG01@D500NGUi08F5Q@1XJ6P0Jf][071`L025
QHD00@2<S8`2ooooo`000?l0SHf=05EEE@24Q8@0WYjN0:2PX02RXZ80B4Q805IFEP1fMWH0O7al09JF
UP1[Jf/0ATI6055AD@1aLG40JFUY08J6QP2@T900;2`/03dm?@1FEUH0MWIf02d];@1:BTX0B4Q802DU
9@13@d<0K6a/06m_K`0R8R80E5AD061PH017AdL0EUIF06IVIP0S8b<0>c/k065QH@0T92@0@41009FE
U@1OGel07alO03Ph>01UIFD0>3Ph05aLG02c/k<0FEUI01`L7011@D40AdM704m?C`1lO7`0Shn?02/[
:`0M7Ad0EeMG06e]K@10@400HF5Q05mOG`0M7Ad0;bl_07inOP1HF5P0N7Qh09BDU00_;bl08R8R04I6
AP2FUYH0DU9B0:^[Z`1iNGT07alO02l_;`1oOgl0VIVI04Y:BP2<S8`0Jf][01/K6`0i>CT0QhN707Ad
M01PH600HV9R020P800W9bL0Kfm_09nOW`1>CTh0H61P06e]K@0];Bd0@41005QHF01gMgL0B4Q806][
J`0Y:BT0<c<c03dm?@1]KFd0Fe]K05MGE`1UIFD092@T034a<@1MGEd0[Jf]05=CD`1HF5P0J6QX02XZ
:P0^;Rh0Lg=c06i^KP0b<S80CTi>04M7A`0O7al0@41008R8R01<C4`0;Rh^065QH@0o?cl0<30`06EU
I@2b/[80GEeM03Ti>@1<C4`0>c/k04e=C@1hN7P0[Zj^0451@@17AdL0JFUY06ATI015ADD0NGUi09>C
T`10@400F5QH071`L01PH600TI6A0:b/[00l?3`0:b/[059BDP1bLW80@d=307emO@23Ph<0;2`/04e=
C@1oOgl0FUYJ0:n_[`2CTi<0>SXj03Hf=P1NGUh0LW9b04m?C`2f][H0Lg=c01/K6`1EEED0KVi^06][
J`1lO7`0^[Zj04];B`0h>3P0AdM708n?S`1]KFd0WinO08>3P`0Y:BT0IfMW0861P@1kNg/0IVIV09bL
W01>CTh08b<S069RHP23Ph<0IfMW05iNGP1mOGd0Cdm?01/K6`1_Kfl0X:2P07UiN@1VIVH0T92@0451
@@0a<C40N7Qh0<o?c`2>SXh0Zj^[07MgM`0Q8B40E5AD0;bl_027QhL0C4a<07=cL`0f=SH0;Rh^06QX
J02RXZ80HF5Q08b<S00];Bd0?Shn05iNGP29RHT0A4A407=cL`1]KFd0<c<c07QhN02MWId0?Shn04Y:
BP1>CTh0C4a<0861P@2b/[80>c/k04M7A`1JFUX0G5aL05EEE@2GUiL0@T9203<c<`1=CDd0HV9R08Z:
RP32`/80VYZJ03dm?@1CDe<00880RXZ:04a<C028R8P0cLg=06i^KP0i>CT0HV9R07EeM@20P800M7Ad
0;bl_017AdL0E5AD07=cL`1]KFd0NGUi0<?3``2OWil06ATI03De=@1<C4`0DE5A05EEE@2HV9P0TY:B
01`L7014A4@0Jf][05mOG`16ATH0S8b<05eMG@19BDT0CDe=09ZJVP22PX80D51@08J6QP15ADD0;bl_
06IVIP2a/K40QXJ6061PH02/[:`0HF5Q02/[:`1LG5`0/[:b07=cL`1YJFT0QXJ603lo?`0h>3P0EUIF
09FEU@2ATI40LG5a06a/K00^;Rh0@41006QXJ028R8P0C4a<05iNGP1jNWX0Shn?05QHF01@D500KVi^
04a<C01/K6`0F5QH04E5A@1BDU80C4a<04Q8B00b<S80CDe=059BDP1:BTX0GEeM051@D01EEED0DE5A
059BDP1TI6@0=CDe04A4A01HF5P0CDe=0451@@1>CTh0ADE5059BDP18B4P0QhN705]KF`22PX80FEUI
05EEE@1^KVh0G5aL06MWI`1iNGT0MGEe04m?C`1DE5@0D51@01hN7P15ADD0E5AD05YJFP1bLW80CDe=
06MWI`1HF5P0ATI606ATI01_Kfl0MWIf0451@@1<C4`0Jf][03De=@1HF5P0@4100451@@1LG5`0:2PX
0P0m?Cd0m01=CDd0C4a<03Lg=`1RHV80@T9206e]K@0f=SH0CTi>0861P@20P8009RHV03Ph>01NGUh0
LG5a071`L01/K6`0A4A40820P00e=CD0EUIF071`L018B4P0IFEU04U9B@11@D40De=C04I6AP14A4@0
BTY:03Hf=P1PH600:RXZ04Q8B00T92@0=cLg03De=@0c<c<0@410038b<P0n?Sh0EEEE02d];@0/;2`0
?clo0410@01HF5P0?Shn04m?C`1FEUH0ADE50492@P10@400De=C051@D02<S8`0LG5a05UIF@2IVIT0
@d=307moO`0o?cl0KVi^09BDU01NGUh0Kfm_061PH01<C4`0SXj>06m_K`1SHf<0LW9b07=cL`0n?Sh0
J6QX05IFEP2i^KT0PH6106i^KP2QXJ40MWIf07QhN01eMGD0ADE508^;R`1aLG40NGUi092@T01EEED0
Ogmo075aL@1BDU80>c/k05YJFP1ZJVX0?Shn04M7A`0b<S80SXj>04=3@`2BTY80E5AD051@D01dM7@0
?Shn06ATI00L71`0Ph>3096AT@1;Bd/0ADE505IFEP1oOgl0clo?0:JVYP1QHF40MgMg04A4A02GUiL0
A4A407QhN01FEUH0@41008B4Q01`L700GemO07AdM00f=SH0BTY:059BDP15ADD0IfMW07inOP1KFe/0
LW9b03`l?022PX80MWIf0;Vi^@26QXH0PH6109fMW@1MGEd0KVi^061PH01<C4`0HF5Q018B4P1jNWX0
VIVI02d];@1HF5P0IfMW03Hf=P1iNGT0K6a/05QHF00n?Sh0LW9b04E5A@1_Kfl0GUiN07EeM@1=CDd0
>3Ph05aLG01DE5@0?Cdm08^;R`1bLW809BDU0451@@0/;2`0FUYJ04U9B@1ADE40>c/k04Y:BP1?Cdl0
?3`l0451@@1CDe<0?Cdm05IFEP1MGEd092@T07MgM`20P8008b<S059BDP0_;bl0CDe=065QH@1XJ6P0
RHV906IVIP1:BTX0<C4a06i^KP1QHF40FUYJ059BDP1ADE40CTi>04];B`1ADE40HV9R05=CD`0g=cL0
Kfm_05=CD`1OGel0M7Ad04i>CP1VIVH0HF5Q03hn?P1hN7P0;bl_04A4A00n?Sh0N7Qh071`L02JVYX0
UYJF04=3@`1OGel0O7al0861P@1TI6@0BTY:06=SH`1[Jf/0=SHf06IVIP0e=CD0KFe]05UIF@1MGEd0
JFUY02d];@2QXJ40ADE503lo?`1CDe<206][J`0505=CD`2CTi<0XJ6Q06a/K02SXj<00_ooool0001c
0:VYZ@1JFUX0GEeM05EEE@1RHV80YZJV051@D017AdL0?Shn03lo?`1iNGT0Ph>302d];@1<C4`0FUYJ
04M7A`1^KVh0gmoO05QHF00T92@0GUiN08f=S@1fMWH0T92@079bLP0e=CD0?Shn05mOG`2PX:00G5aL
09RHV01iNGT0<30`03Hf=P1cLg<0FUYJ08f=S@2n_[h0>SXj02TY:@1JFUX0[jn_055AD@1GEeL0PH61
03<c<`0N7Qh0J6QX0:NWY`11@D40OWin07moO`0X:2P0HF5Q0:ZZZP2<S8`0GEeM07alO00T92@0D51@
05=CD`1XJ6P0DU9B06UYJ@12@T80820P03<c<`25QHD0XJ6Q05MGE`2DU9@0?Shn0492@P1CDe<0X:2P
06QXJ01TI6@0NGUi03Lg=`0k>c/0FEUI09:BTP0_;bl0@41005eMG@19BDT0DE5A069RHP0f=SH0:RXZ
03hn?P1?Cdl0B4Q806=SH`2ATI40=cLg02<S8`0b<S80ATI606ATI02TY:@0IVIV02DU9@0];Bd0?clo
04I6AP1/K6`0^KVi04i>CP0R8R80>CTi04m?C`12@T80S8b<0<O7a`02038b<P0E05EEE@1dM7@0FEUI
09nOW`2;Rh/08b<S034a<@1CDe<0HV9R06YZJP2e]KD0<30`03/k>`0m?Cd0Cdm?06m_K`2CTi<0YZJV
03/k>`0i>CT0>3Ph0080Ph>302d0M7Ad09RHV00j>SX0@D5105QHF01QHF40EEEE0:VYZ@2VYZH0?3`l
03/k>`1^KVh0O7al051@D02DU9@0Fe]K0451@@0o?cl0KFe]07YjNP26QXH09RHV03Ti>@1GEeL0U9BD
06EUI@1^KVh0NGUi02DU9@17AdL0FEUI0:RXZ01IFET0GEeM06=SH`0`<300D51@09VIV@2BTY80AdM7
07AdM015ADD0Bd];06UYJ@2PX:000P1>CTh0h01jNWX0ADE507MgM`2FUYH0`l?305IFEP0k>c/0NWYj
07emO@1SHf<0[:b/08B4Q00[:b/0<C4a07MgM`1BDU80Ng]k0:f][@1VIVH0;Rh^03/k>`1GEeL0NWYj
0:j^[P2i^KT0:2PX03lo?`1CDe<0FUYJ07inOP2g]kL0<S8b03hn?P1LG5`0PH6108:2PP3Ogml0B4Q8
02<S8`1WIfL0N7Qh04E5A@2XZ:P0ZZZZ024Q8@1GEeL0_[jn07YjNP1dM7@0IFEU02l_;`1NGUh0U9BD
096AT@2ZZZX0Zj^[03Ph>01BDU80R8R809JFUP1HF5P0TY:B03dm?@0Z:RX0Ph>30;6a/@28R8P0^;Rh
0;no_`18B4P0@d=30:6QX@2ZZZX0H61P07YjNP1KFe/0>c/k05ADE026QXH0HV9R04i>CP2FUYH0@410
03@d=027QhL0_kno04Q8B01=CDd0Lg=c03Xj>P0/;2`0KFe]0:n_[`1=CDd0=CDe05eMG@15ADD0FEUI
09NGU`1UIFD0;Bd]04a<C01RHV80BDU9065QH@2CTi<0GEeM02HV9P0n?Sh0HV9R03Ti>@1gMgL0bl_;
07emO@0W9bL0<30`05EEE@1FEUH0IfMW08b<S01LG5`0;Bd]03`l?01oOgl0LW9b09^KV`37alL0?Cdm
03<c<`12@T80I6AT05ADE01IFET0Lg=c05YJFP19BDT0ADE505=CD`1?Cdl0EEEE04a<C011@D40ADE5
06ATI012@T80>3Ph05]KF`1nOWh0FUYJ06IVIP16ATH0De=C05iNGP20P800IfMW0451@@0k>c/0@d=3
04A4A01EEED0H61P03Ti>@18B4P0DU9B05aLG01MGEd0R8R805=CD`10@400JVYZ08F5Q@1[Jf/0Bd];
06=SH`1FEUH0I6AT0410@00V9RH0BDU904e=C@17AdL0CDe=04];B`1EEED0ATI603dm?@1=CDd0Kfm_
069RHP15ADD0FEUI06a/K00m?Cd0E5AD04Y:BP1EEED0JVYZ03lo?`1CDe<0BDU905iNGP1RHV80DU9B
061PH01?Cdl0Jf][03hn?P0k>c/0Bd];06a/K00c<c<0AdM706YZJP23Ph<0S8b<09:BTP1ADE40RXZ:
0492@P1eMGD0O7al051@D01HF5P0BDU90P1FEUH02019BDT0EeMG05UIF@0h>3P0KVi^03/k>`1@D500
>c/k0P1=CDd01@13@d<0F5QH05UIF@1?Cdl0ATI60080@4100=00DE5A04];B`1VIVH0E5AD06YZJP1A
DE40@41005IFEP1IFET0Jf][05ADE01_Kfl0KVi^05=CD`1JFUX0@D5107MgM`1;Bd/0R8R805mOG`0j
>SX0EeMG059BDP1<C4`0HF5Q0820P01_Kfl0I6AT06][J`1=CDd0Ti>C02LW9`1cLg<0L71`05mOG`25
QHD0BDU908f=S@1mOGd0@T9206=SH`0h>3P0Kfm_0820P00h>3P0BDU9065QH@1]KFd0IFEU061PH01k
Ng/0ADE505]KF`1@D500N7Qh04Y:BP2FUYH0JFUY06IVIP1gMgL0GUiN05QHF00_;bl0IVIV05IFEP1Y
JFT0VIVI04m?C`27QhL0m?Cd0:>SX`1BDU80De=C05aLG02e]KD0EEEE069RHP1;Bd/0EUIF08:2PP1D
E5@0DU9B05IFEP0g=cL0JFUY096AT@18B4P0HF5Q051@D01KFe/0S8b<051@D01cLg<0N7Qh0<;2`P1i
NGT0LW9b08Z:RP1EEED0Rh^;06YZJP1KFe/0GemO03hn?P1/K6`0Q8B402`/;02EUID0NGUi02l_;`1B
DU80@D51051@D01DE5@0PX:208>3P`1aLG40Lg=c09^KV`1QHF40D51@06i^KP1GEeL0:RXZ04U9B@16
ATH0<30`04A4A00Y:BT0ATI606a/K01EEED0;bl_05ADE01GEeL0@d=304I6AP1DE5@0De=C05ADE01`
L700>3Ph07MgM`1nOWh0<S8b09FEU@1CDe<0JVYZ05YJFP1IFET0GemO04i>CP17AdL0:RXZ06ATI01D
E5@0D51@06=SH`1GEeL0DU9B04U9B@1_Kfl0RXZ:02l_;`0d=3@0M7Ad06=SH`1/K6`0N7Qh030`<01L
G5`0BDU903<c<`1OGel0>3Ph05QHF01MGEd0DU9B07=cL`2<S8`0Hf=S02l_;`1TI6@0J6QX0;Jf]P2Q
XJ40PX:20<W9b@1mOGd0DE5A09RHV00o?cl0CDe=03Lg=`17AdL0BTY:02l_;`1eMGD0DE5A04];B`1]
KFd0VIVI0;>c/`1ZJVX0UIFE07AdM01LG5`0VIVI0_ooool0002a06e]K@2EUID0b/[:05MGE`18B4P0
DE5A0820P02CTi<0HF5Q03Ti>@17AdL0Lg=c07IfMP2MWId0IVIV02`/;019BDT0RHV909RHV01hN7P0
I6AT03<c<`0n?Sh0Fe]K0861P@16ATH0J6QX07IfMP0Z:RX08B4Q05QHF02HV9P0A4A404Y:BP0a<C40
92@T04A4A019BDT0Fe]K0451@@18B4P0;bl_0410@01;Bd/0N7Qh04M7A`0d=3@0B4Q80451@@0];Bd0
JVYZ08F5Q@0^;Rh0?Cdm04];B`0i>CT0M7Ad0<C4a01>CTh06ATI04e=C@1OGel0De=C09JFUP1eMGD0
9BDU01PH601<C4`0GEeM06UYJ@2n_[h0ATI602/[:`0b<S80GEeM071`L02QXJ40/[:b01hN7P0`<300
EUIF06i^KP1YJFT0WinO0;no_`0V9RH0Bd];06e]K@1?Cdl0EUIF07UiN@1EEED0820P04a<C02BTY80
JVYZ065QH@1hN7P0=cLg034a<@27QhL0^k^k05eMG@1`L700HV9R024Q8@0a<C40IfMW0<O7a`1ADE40
Lg=c03Ph>00/;2`0>SXj06UYJ@24Q8@0CTi>06m_K`0];Bd0=cLg04U9B@1lO7`0BTY:05=CD`1cLg<0
:BTY03Ph>02j^[X0UYJF02l_;`10@400?Shn03Ti>@1CDe<0/K6a07MgM`0g=cL0De=C05QHF01<C4`0
K6a/0;bl_01QHF40<C4a06YZJP1IFET0>SXj08R8R039bLT0KVi^03Hf=P1NGUh0?clo05=CD`1gMgL0
XZ:R03lo?`1IFET0H61P04U9B@3:b/X0G5aL02l_;`1?Cdl0F5QH03Xj>P1kNg/0clo?0410@00W9bL0
IVIV07EeM@1bLW80Shn?0;Zj^P0Q8B4092@T0080IVIV05h0LG5a09nOW`1oOgl0:RXZ05YJFP1RHV80
OWin069RHP2`/;00=3@d03De=@25QHD0YjNW096AT@2BTY80/[:b03Hf=P17AdL0UIFE0=3@d01[Jf/0
QhN708f=S@0e=CD0:b/[07]kN`2=SHd0Hf=S07=cL`0e=CD0@D5106EUI@2FUYH0I6AT06i^KP2JVYX0
>3Ph03/k>`1lO7`0UYJF06EUI@2EUID0DU9B06UYJ@22PX80_;bl05aLG01TI6@0Bd];03lo?`1cLg<0
];Bd06IVIP1KFe/0GEeM04Q8B02FUYH0VYZJ04A4A01BDU80EeMG03Ti>@1]KFd0Xj>S04Y:BP0d=3@0
EeMG0410@01ZJVX0V9RH05YJFP0P8200F5QH05aLG01VIVH0PX:20<G5a@0h>3P0<c<c05iNGP1jNWX0
RXZ:0:NWY`1gMgL0:RXZ04e=C@1bLW80OWin07UiN@2[Zj/0?clo034a<@1@D500MWIf0P2=SHd0G@2^
[Zh0?clo03/k>`1;Bd/0NWYj09bLW01bLW80]kNg030`<00d=3@0HF5Q09bLW01IFET0OWin08Z:RP0`
<300@T920861P@2i^KT0C4a<079bLP2>SXh0?Shn02l_;`1DE5@0RXZ:05=CD`1iNGT0AdM7024Q8@10
@400DE5A07]kN`18B4P0Jf][07QhN00[:b/0<c<c06ATI01oOgl0>3Ph0861P@0`<300@D5105mOG`1h
N7P0OGem04M7A`13@d<0IFEU05MGE`1RHV80ATI603lo?`1?Cdl0Bd];04m?C`11@D40E5AD05UIF@1A
DE40MGEe05eMG@1YJFT0Bd];0451@@14A4@0;Bd]04=3@`1@D500?clo03@d=01>CTh0>CTi04m?C`1;
Bd/0Fe]K06IVIP28R8P0G5aL04A4A01GEeL0CTi>06IVIP1BDU80IfMW055AD@1;Bd/0BTY:02@T9016
ATH0C4a<04];B`0205eMG@0V05MGE`0m?Cd0@d=3059BDP1lO7`0I6AT02l_;`0l?3`0HF5Q0451@@1E
EED0?3`l03lo?`1QHF40BTY:059BDP0d=3@0?clo05QHF01QHF40EUIF03De=@1NGUh0IFEU065QH@1X
J6P0UYJF065QH@1TI6@0OWin05]KF`18B4P0BDU906][J`1OGel0@D5105ADE01<C4`205ADE02`0410
@00k>c/0DE5A05IFEP0h>3P0AdM705ADE01]KFd0=cLg04M7A`0j>SX0MgMg05EEE@10@400CTi>06YZ
JP18B4P0=3@d03/k>`1OGel0EEEE0410@01:BTX0NWYj05mOG`1BDU80B4Q8055AD@18B4P0G5aL04M7
A`2CTi<0KVi^071`L01iNGT0>3Ph06IVIP1FEUH0UIFE05iNGP1<C4`0OWin06UYJ@1>CTh0Ng]k06YZ
JP1jNWX0H61P069RHP0a<C40IVIV03hn?P2?Shl0R8R8092@T02m_Kd0GEeM0:n_[`2XZ:P0DE5A08:2
PP1>CTh0QHF508N7Q`1BDU80Q8B404m?C`1JFUX0AdM705IFEP1PH600>CTi04I6AP1BDU80MgMg03<c
<`2HV9P0Hf=S06a/K028R8P0Bd];065QH@0l?3`0LW9b069RHP1`L700Kfm_05]KF`1gMgL0YjNW09RH
V01<C4`0GemO04M7A`2;Rh/0EUIF07AdM01_Kfl0?Cdm08B4Q00j>SX0@T9206UYJ@0m?Cd0@D5106UY
J@0c<c<0DU9B03Ti>@1CDe<0Lg=c03Xj>P29RHT0E5AD0;:b/P2<S8`0Rh^;0<30`01]KFd0MgMg06QX
J018B4P0AdM702d];@1JFUX0IVIV04a<C01BDU80HF5Q04a<C01RHV80FUYJ06IVIP15ADD0QHF506AT
I01ZJVX0IVIV08N7Q`1HF5P0=CDe06e]K@1@D500B4Q805aLG01?Cdl0>CTi03/k>`0l?3`0HV9R075a
L@13@d<0ATI605YJFP1GEeL0>c/k061PH01;Bd/0?Shn04];B`1<C4`0:BTY0:f][@2JVYX0CTi>05YJ
FP1CDe<0@d=305ADE00`<300De=C04i>CP12@T80ADE505iNGP1SHf<205YJFP0b08R8R00d=3@0>CTi
06QXJ01QHF40<30`04Y:BP1bLW80K6a/0:>SX`1oOgl0>c/k079bLP1WIfL0H61P07alO00i>CT0@410
061PH01XJ6P0Ti>C0;Zj^P1ZJVX0@T9206e]K@1eMGD0V9RH071`L01SHf<0P82007EeM@1BDU80GEeM
05aLG01`L700GEeM04Q8B01ZJVX0@T920861P@19BDT0IFEU06m_K`2/[:`0]KFe07EeM@2EUID0SHf=
05MGE`1eMGD2ooooo`000;h0P82005EEE@26QXH0UiNG07alO01hN7P0?Cdm065QH@2HV9P0?clo065Q
H@1JFUX0>c/k08B4Q02_[jl0:b/[0410@01BDU80=cLg03`l?02KVi/0CDe=02l_;`0Z:RX0De=C05EE
E@1nOWh0WYjN03`l?00[:b/0>c/k07]kN`1`L700/k>c06UYJ@0B4Q80<30`04M7A`1FEUH0MWIf0:j^
[P1WIfL06ATI03dm?@1LG5`0@T9206MWI`2/[:`0EEEE024Q8@14A4@0GemO04a<C01WIfL0WYjN02/[
:`0O7al0DU9B08^;R`1=CDd0J6QX02/[:`0];Bd0BTY:071`L01_Kfl0Cdm?06a/K00P82007QhN05MG
E`2>SXh0@T9204i>CP0l?3`061PH04m?C`2XZ:P0KFe]03@d=022PX80?Shn02PX:015ADD0Rh^;04e=
C@0e=CD0Bd];02PX:00];Bd0HF5Q08J6QP0o?cl0:BTY04Y:BP0e=CD0LW9b0:2PX01;Bd/06QXJ030`
<01`L700CDe=08b<S02DU9@09bLW01hN7P0g=cL0E5AD05]KF`2][Jd0Fe]K01TI6@0f=SH0A4A405IF
EP1RHV80Vi^K04m?C`0I6AT0De=C05]KF`1>CTh0PX:207=cL`0l?3`0:RXZ05YJFP2=SHd0EUIF09>C
T`10@400;bl_04M7A`1GEeL0PX:205IFEP2BTY80E5AD03hn?P1MGEd0KVi^07emO@1fMWH0[Zj^06IV
IP0^;Rh0JVYZ0;Vi^@2o_kl0S8b<0:FUY@0h>3P0>c/k06EUI@2LW9`0GEeM08N7Q`2ATI40=SHf05iN
GP2CTi<0Cdm?09fMW@1kNg/0:RXZ04];B`2DU9@0SXj>079bLP1gMgL0?clo03Ti>@1IFET0Xj>S06m_
K`1JFUX0QXJ603<c<`1:BTX0KVi^096AT@1<C4`0IFEU07MgM`13@d<0Fe]K09ZJVP2GUiL0@4100P1R
HV80PP0g=cL0D51@0:j^[P2][Jd0>CTi04U9B@1CDe<0CTi>055AD@25QHD0GUiN02XZ:P1EEED0C4a<
06e]K@2i^KT0L71`034a<@1YJFT0Hf=S04a<C02=SHd0bl_;03lo?`10@400IFEU06YZJP1[Jf/0/k>c
07EeM@0b<S80Hf=S06][J`1ADE40];Bd096AT@0Q8B40GEeM092@T01oOgl0Vi^K06=SH`0N7Qh0ATI6
09>CT`1IFET0R8R809:BTP0];Bd0B4Q806a/K01aLG40NWYj09FEU@0Y:BT0@d=307UiN@2IVIT0CTi>
09:BTP1DE5@0:RXZ07AdM02n_[h0R8R807UiN@22PX80?3`l059BDP23Ph<0YjNW059BDP18B4P0Ti>C
03Lg=`1XJ6P0][Jf09NGU`12@T80Ng]k05MGE`0d=3@0Kfm_06UYJ@1dM7@0?Cdm06ATI012@T80A4A4
05UIF@2GUiL0J6QX03hn?P1_Kfl0@41005eMG@1XJ6P0Rh^;04I6AP0o?cl0EeMG03`l?00o?cl0Cdm?
08V9R@1=CDd0>CTi04M7A`0m?Cd0AdM709jNWP1nOWh0;Bd]04E5A@17AdL0De=C06][J`2?Shl0UiNG
04=3@`11@D40F5QH05UIF@1<C4`0[:b/04m?C`0a<C40G5aL055AD@1YJFT205eMG@2405YJFP15ADD0
I6AT05IFEP1<C4`0@D5105MGE`12@T80=CDe05YJFP1_Kfl0FEUI06i^KP1;Bd/0GEeM04a<C01@D500
Hf=S05ADE019BDT0>CTi03@d=010@400ADE503Ph>011@D40B4Q8061PH01cLg<0Ng]k06e]K@1UIFD0
N7Qh05MGE`1OGel0G5aL06a/K01FEUH0DU9B04I6AP0X:2P0BDU9065QH@1OGel0H61P0451@@1PH600
BDU904E5A@1?Cdl0BDU905IFEP0o?cl0AdM705ADE00k>c/0AdM7030`<015ADD0B4Q803@d=019BDT0
=CDe04i>CP1HF5P0CTi>065QH@10@400H61P03<c<`1;Bd/0Fe]K08:2PP0o?cl0@d=305MGE`1TI6@0
MWIf055AD@0l?3`0G5aL03Lg=`1EEED0?3`l03Xj>P1?Cdl0;Bd]03Xj>P13@d<0?Cdm03@d=01ADE40
CTi>04e=C@0X:2P0?Shn03<c<`13@d<0>3Ph03Lg=`18B4P0BDU903hn?P0e=CD0@T9203hn?P16ATH0
=cLg04e=C@1;Bd/0EUIF051@D013@d<0?3`l05=CD`1HF5P0Bd];09:BTP1MGEd0>3Ph05IFEP1hN7P0
SXj>03lo?`1HF5P0LW9b07MgM`2@T900MWIf079bLP1hN7P0JVYZ0P1/K6`0]025QHD0De=C07=cL`15
ADD0Zj^[06m_K`2>SXh0`l?305MGE`1HF5P0J6QX059BDP2JVYX0GemO0820P01NGUh0>3Ph03lo?`17
AdL0CTi>04Q8B022PX80QHF503Ph>012@T809BDU07emO@0f=SH0YjNW0410@01NGUh0IFEU04Q8B01P
H600:2PX08>3P`1mOGd0KVi^06e]K@1bLW80QXJ60>3Ph01lO7`0IFEU07YjNP1DE5@0VYZJ04Q8B023
Ph<0GemO04a<C027QhL0DE5A065QH@1DE5@06ATI04I6AP22PX80Bd];069RHP1:BTX0DE5A07=cL`12
@T80FUYJ06ATI03Ph>00Shn?05UIF@1DE5@0D51@04i>CP17AdL0>CTi06IVIP0W9bL0Fe]K0861P@1?
Cdl0Hf=S05]KF`1ADE40M7Ad04=3@`1;Bd/0BTY:07AdM00o?cl0RXZ:06m_K`2@T900EUIF04=3@`2g
]kL0MgMg02PX:01IFET0EEEE02HV9P0m?Cd071`L0;^k^`2:RXX0BDU902LW9`1>CTh0DE5A038b<P1:
BTX0>SXj03<c<`1UIFD0Hf=S02XZ:P1aLG40GUiN02`/;01WIfL0C4a<04Y:BP1YJFT0DE5A05eMG@14
A4@0De=C0410@01VIVH0M7Ad06YZJP1]KFd0M7Ad0492@P1NGUh0Jf][06ATI016ATH0>SXj05ADE01k
Ng/0RHV907IfMP1@D500EEEE04Q8B00_;bl0J6QX04m?C`1WIfL0J6QX07=cL`2PX:00h>3P0;>c/`1F
EUH0J6QX08F5Q@2=SHd0QXJ608^;R`2PX:00KVi^04];B`1SHf<0CTi>05UIF@1OGel0IfMW0861P@1N
GUh0Ph>305UIF@18B4P0EeMG0;bl_02UYJD0GUiN07alO02CTi<0R8R808>3P`;ooooo0000102a/K40
DU9B06IVIP1bLW820;>c/`0Y03/k>`1?Cdl0KVi^051@D02`/;00LW9b03<c<`0e=CD0Ph>305ADE028
R8P0YJFU03Ti>@0Z:RX0FUYJ08f=S@1nOWh0Ogmo06ATI00M7Ad0@410071`L021PH40C4a<0;Fe]@1f
MWH0;Bd]04E5A@29RHT0@T920410@01OGel0>SXj02l_;`27QhL0_[jn05YJFP1WIfL0K6a/02HV9P0a
<C400P1mOGd0FP0k>c/0Kfm_04a<C00[:b/0HV9R0;Zj^P1QHF40=SHf04Q8B01:BTX0=SHf07MgM`1a
LG408R8R03Lg=`0l?3`0GUiN06MWI`2JVYX0AdM702HV9P11@D40IVIV05MGE`1eMGD0Lg=c01`L700`
<300ATI607IfMP1@D500b/[:07EeM@0[:b/0E5AD06=SH`1ADE40IFEU07]kN`0P82006a/K04I6AP1]
KFd0FUYJ07EeM@2:RXX0;bl_02`/;01]KFd0WinO05MGE`1WIfL0:RXZ020P8012@T80UiNG08b<S01B
DU80Xj>S02l_;`0];Bd0EeMG0:BTY00j>SX0D51@06e]K@0Q8B40=CDe07EeM@1bLW80CTi>05ADE00l
?3`092@T04=3@`25QHD0CTi>03Ti>@1CDe<0;Bd]03Ti>@1KFe/0OGem05IFEP1;Bd/0HV9R03Lg=`1D
E5@0H61P07YjNP80>3Ph0:P0LW9b06=SH`1BDU80QhN70:FUY@12@T80ADE505=CD`0[:b/0EUIF0;Zj
^P1]KFd0:RXZ04I6AP10@400=3@d09NGU`2QXJ40=SHf055AD@16ATH0ADE50;Fe]@2NWYh09bLW02d]
;@1EEED0GemO08V9R@2YZJT0@T92034a<@1EEED0IfMW06a/K024Q8@0[jn_038b<P0`<300JVYZ06IV
IP1DE5@0WinO0<[:bP0f=SH0?clo08V9R@2PX:00Ogmo0;6a/@1cLg<0=cLg03hn?P1iNGT0Rh^;09fM
W@3:b/X0BDU903`l?010@400MWIf0:2PX01YJFT0c/k>059BDP19BDT0MWIf06e]K@1EEED0WIfM05MG
E`0i>CT0IFEU0<S8b02:RXX0Shn?07UiN@0g=cL0@d=306IVIP2k^k/0G5aL09BDU00^;Rh0BTY:065Q
H@20P800CTi>06MWI`1FEUH0:RXZ08b<S03UiND0Lg=c04m?C`1/K6`0D51@06IVIP2CTi<0@T9204i>
CP1SHf<0>c/k055AD@2XZ:P0ZZZZ04I6AP1[Jf/0ADE505UIF@2CTi<0Ph>303De=@1FEUH0P82003dm
?@29RHT0c<c<04e=C@11@D40FUYJ06=SH`1YJFT0PH610;^k^`0m?Cd0<S8b06e]K@1iNGT0JVYZ0:>S
X`2d];@0:2PX03Lg=`1@D500HF5Q06ATI02UYJD0TI6A028R8P0f=SH0IfMW06EUI@15ADD0Z:RX04i>
CP0[:b/0C4a<08n?S`1oOgl0OGem0;jn_P19BDT0;bl_05ADE02@T900JVYZ079bLP1mOGd0?Shn03/k
>`1VIVH0W9bL05=CD`1]KFd0Hf=S02`/;00Y:BT205EEE@0F05YJFP1VIVH0LW9b03Ph>00c<c<0Bd];
0:j^[P19BDT0EEEE05QHF01PH600A4A404E5A@1BDU80FUYJ05QHF015ADD0@d=304U9B@1:BTX0A4A4
03Lg=`80De=C01h0C4a<061PH01;Bd/0JFUY04a<C019BDT0EeMG02h^;P0f=SH0EUIF04m?C`15ADD0
EEEE0410@016ATH0B4Q805QHF01NGUh0M7Ad051@D019BDT0FUYJ069RHP1QHF40E5AD06YZJP1MGEd0
DU9B0451@@0T92@203hn?P0403Xj>P16ATH0CDe=04Q8B080=CDe01X0@T9205]KF`1FEUH0>c/k05=C
D`1VIVH0>c/k04M7A`0i>CT0IFEU05IFEP0l?3`0B4Q804Y:BP1KFe/0GUiN05aLG01=CDd0@41005eM
G@13@d<0EEEE05=CD`27QhL0;bl_0492@P80O7al00T0Rh^;02HV9P12@T80J6QX05MGE`1hN7P0?clo
03/k>`1:BTX00P11@D40?P1<C4`0A4A403Hf=P1DE5@0CDe=04m?C`0[:b/0C4a<01TI6@1@D500?Shn
04=3@`18B4P0EUIF03/k>`15ADD09bLW0451@@18B4P0=3@d04m?C`1PH600Fe]K079bLP16ATH0AdM7
06QXJ01oOgl0>SXj08R8R01DE5@0BTY:05]KF`0n?Sh0IVIV05=CD`20P800G5aL04E5A@1@D500Bd];
04Q8B01DE5@0L71`05aLG017AdL0EeMG04i>CP24Q8@0@41008R8R01KFe/0NGUi0;Vi^@1YJFT0TY:B
08f=S@27QhL0RHV908J6QP2_[jl0V9RH0P1FEUH0XP19BDT0NGUi07AdM01HF5P0GemO05ADE01gMgL0
9RHV05IFEP0a<C40YJFU04m?C`1/K6`0J6QX061PH01^KVh0ATI605eMG@1VIVH0Ng]k0:FUY@1CDe<0
FUYJ0:NWY`1dM7@0B4Q805EEE@14A4@0YjNW04A4A01_Kfl0@d=304];B`2ATI40EUIF04Y:BP1BDU80
6ATI06UYJ@2@T900?3`l055AD@0S8b<0D51@07YjNP1<C4`0I6AT03dm?@37alL0M7Ad075aL@1gMgL0
C4a<05=CD`18B4P0>c/k07emO@12@T80IVIV07QhN00[:b/0GUiN05aLG00Z:RX0EEEE03Hf=P1hN7P0
EeMG07YjNP1NGUh0BTY:079bLP2CTi<0F5QH0492@P0i>CT0Bd];03lo?`1EEED0@d=303Hf=P13@d<0
B4Q80>?Sh`2:RXX0CDe=04M7A`1>CTh0FEUI03dm?@1<C4`0EeMG0410@01<C4`0CDe=01hN7P2?Shl0
Jf][02LW9`1TI6@0CTi>07QhN01[Jf/0CDe=05IFEP1GEeL0De=C03dm?@1>CTh0EEEE05mOG`1RHV80
CTi>075aL@0m?Cd0AdM706EUI@0D51@0>c/k061PH01BDU80De=C06EUI@0M7Ad0SXj>08F5Q@1FEUH0
EeMG02d];@19BDT0GemO079bLP1OGel0LW9b07MgM`1OGel0HF5Q069RHP3Cdm<0c/k>08N7Q`2KVi/0
R8R806ATI02VYZH0RXZ:07inOP1BDU80>SXj05eMG@1YJFT0IFEU04m?C`19BDT0C4a<05iNGP1cLg<0
Ogmo06QXJ01VIVH0Q8B408f=S@;ooooo0000202BTY80M7Ad09nOW`1;Bd/0F5QH08Z:RP1aLG40FEUI
0P14A4@0/P1GEeL0IfMW034a<@1BDU80EUIF04i>CP1QHF40QXJ604];B`0S8b<0AdM704A4A015ADD0
MGEe08n?S`0W9bL0;Bd]04e=C@1lO7`0@T9209NGU`1bLW80<C4a02`/;01JFUX0G5aL05UIF@2FUYH0
=3@d02PX:018B4P0T92@05mOG`25QHD0alO702PX:00F5QH0De=C07moO`14A4@0YjNW08:2PP0G5aL0
=CDe08J6QP21PH40M7Ad09JFUP0U9BD0?3`l04A4A01;Bd/0EeMG06i^KP1UIFD05aLG04E5A@1GEeL0
R8R8071`L038b<P0;bl_02h^;P15ADD0F5QH051@D01WIfL0P820024Q8@0c<c<0Cdm?07UiN@1BDU80
Ogmo08n?S`0k>c/0@T9205iNGP0m?Cd0@41004Q8B00`<300=SHf04];B`27QhL0BDU903Xj>P19BDT0
=cLg04e=C@1iNGT0JFUY02@T900];Bd0?Shn07EeM@1GEeL0PH6104Y:BP0a<C40Hf=S05ADE01[Jf/0
JVYZ07EeM@0c<c<08R8R04Q8B01SHf<0F5QH0861P@1;Bd/09bLW04I6AP1<C4`0HF5Q07alO02/[:`0
;2`/02PX:01GEeL0Kfm_069RHP2?Shl0OGem02`/;013@d<0Ogmo08N7Q`1hN7P0Xj>S0:BTY015ADD0
CTi>05UIF@2>SXh0P8200;2`/02TY:@0;Rh^03De=@1=CDd0Lg=c069RHP2[Zj/0D51@01dM7@1:BTX0
XJ6Q08^;R`1iNGT0?Shn04=3@`1KFe/0W9bL05MGE`1YJFT0S8b<01`L700^;Rh0Shn?07inOP18B4P0
TI6A079bLP0[:b/0<C4a05eMG@29RHT0BDU909RHV013@d<0<30`0410@02a/K40S8b<05aLG01VIVH2
03Lg=`1J09:BTP2j^[X0Hf=S09^KV`20P800>3Ph03<c<`22PX80[jn_05IFEP12@T80B4Q803Xj>P0l
?3`0OWin09FEU@0j>SX0FEUI04Q8B019BDT0b<S807YjNP0Q8B40?Shn051@D011@D40JFUY0<_;b`1M
GEd0<C4a04I6AP1^KVh0TY:B0:^[Z`1KFe/07QhN05QHF01iNGT0G5aL0:b/[022PX808R8R03Hf=P1j
NWX0OWin08:2PP1TI6@07AdM05QHF02UYJD0GEeM08R8R01kNg/0;Bd]051@D01RHV80^k^k05IFEP21
PH409BDU03hn?P2GUiL0UYJF07QhN029RHT0YjNW04E5A@1:BTX0Ti>C08j>SP1]KFd0[:b/03hn?P11
@D40F5QH075aL@1RHV80GemO0:ZZZP0n?Sh0A4A4069RHP1cLg<0GemO07YjNP1hN7P0<C4a05]KF`1X
J6P0S8b<0P15ADD0:@1aLG40?Shn05EEE@1jNWX0NGUi04=3@`1WIfL0J6QX030`<00o?cl0V9RH09fM
W@0k>c/0?clo07alO00k>c/0EUIF08n?S`1:BTX0=CDe05QHF015ADD0ATI605IFEP1eMGD0ADE502h^
;P15ADD0C4a<05]KF`1WIfL0XZ:R04Y:BP0g=cL0EEEE05MGE`1NGUh0GemO04A4A01BDU80BDU90080
F5QH0640@D5106YZJP1<C4`0KFe]05aLG01DE5@0B4Q804I6AP1MGEd0EeMG05ADE01MGEd0LG5a06UY
J@1BDU80BDU904m?C`0b<S80>CTi03dm?@12@T80;2`/04];B`17AdL0BDU904i>CP2>SXh0GemO05AD
E01JFUX0AdM705YJFP1?Cdl0K6a/061PH01_Kfl0F5QH05ADE01;Bd/0:RXZ03Ph>00i>CT0@T92051@
D016ATH0DU9B03lo?`11@D40Bd];05EEE@1BDU80<S8b03Xj>P1>CTh0@T9203lo?`0Z:RX0@d=304e=
C@11@D40DE5A0410@018B4P0BTY:0451@@18B4P0@D5104a<C00o?cl0@41005MGE`1bLW80BDU903hn
?P1MGEd0C4a<04e=C@0e=CD0ADE506ATI00^;Rh0C4a<04A4A017AdL0FEUI02TY:@0g=cL0@d=304I6
AP0Z:RX0@T9205]KF`1?Cdl0;2`/03dm?@0L71`0Cdm?0080=cLg0=H0?clo05ADE00m?Cd0@T9201lO
7`0b<S80?clo03De=@1=CDd0GemO0492@P1;Bd/0@D5102DU9@1:BTX0CTi>05QHF02@T900IVIV06YZ
JP1/K6`0ATI606MWI`10@400Hf=S04=3@`0m?Cd0H61P05YJFP1]KFd0Lg=c061PH01SHf<0FEUI06a/
K010@400MWIf03Xj>P2@T900DE5A08J6QP30`<00NWYj0<?3``24Q8@0O7al07inOP1FEUH0UIFE06][
J`1?Cdl0Hf=S04i>CP0o?cl0ATI6065QH@1HF5P0BTY:06UYJ@0c<c<0Fe]K01hN7P2BTY80EUIF04I6
AP10@400BTY:055AD@0Z:RX0HV9R05mOG`1LG5`0QhN7051@D01kNg/0dm?C07YjNP15ADD0Jf][04E5
A@1PH600K6a/0:FUY@1QHF40@41006EUI@0_;bl0Lg=c08:2PP0e=CD0?Shn05]KF`1=CDd0GUiN03Ti
>@1FEUH0JVYZ05YJFP1mOGd0F5QH0<71`@1XJ6P0UiNG0<k>cP1?Cdl0FUYJ04m?C`0j>SX0EUIF0492
@P1KFe/0LW9b055AD@1fMWH0PH6104e=C@1>CTh0A4A404a<C01^KVh0QHF507EeM@1KFe/0F5QH08^;
R`1JFUX0AdM705MGE`1BDU80>CTi06IVIP10@400<30`04Y:BP22PX80b/[:04m?C`1EEED0DE5A05=C
D`1fMWH0B4Q804m?C`1EEED0CDe=04Y:BP17AdL0=CDe09VIV@20P800C4a<05aLG00b<S80?3`l055A
D@0a<C40CDe=03<c<`1IFET0@T9205eMG@1hN7P0HV9R0820P01QHF40B4Q804M7A`1IFET0DE5A03dm
?@1ZJVX0MgMg05IFEP1WIfL0G5aL05IFEP14A4@0FUYJ051@D01WIfL0Fe]K06=SH`1DE5@0HV9R06EU
I@2n_[h0Lg=c051@D023Ph<0PX:206][J`1gMgL0WIfM0:n_[`1kNg/0M7Ad08n?S`1LG5`0DE5A06=S
H`1jNWX0T92@05UIF@1]KFd0OWin08:2PP1[Jf/0SXj>08>3P`1DE5@0HV9R065QH@1`L700I6AT0_oo
ool0001N08:2PP1WIfL0b/[:055AD@1;Bd/0I6AT06][J`2`/;00IVIV03dm?@1DE5@0OGem065QH@2T
Y:@0R8R802TY:@1GEeL0JVYZ08>3P`1LG5`0Vi^K02XZ:P0j>SX0>c/k07AdM01fMWH0VYZJ0:>SX`0M
7Ad0A4A406a/K025QHD0C4a<07EeM@14A4@05QHF02l_;`1=CDd0GUiN03lo?`1;Bd/0<30`024Q8@0g
=cL0DE5A08V9R@1DE5@0RHV90410@00Q8B40AdM707YjNP0k>c/0C4a<0492@P0^;Rh0BDU906a/K01[
Jf/0<S8b04U9B@0_;bl0?clo04i>CP1/K6`0:2PX03<c<`14A4@0?Cdm04Q8B01gMgL0JFUY02DU9@16
ATH0C4a<03`l?01oOgl0ZJVY04=3@`0K6a/0ATI60492@P14A4@0R8R80<71`@0X:2P0>3Ph06ATI01H
F5P0Kfm_08f=S@1YJFT05aLG03Xj>P80Kfm_0?l0JFUY07QhN00j>SX0=3@d05]KF`2ATI40Kfm_08>3
P`1nOWh07AdM04Y:BP15ADD0KVi^06=SH`30`<00B4Q802PX:019BDT0=cLg05QHF01/K6`0WIfM02DU
9@0Z:RX0IFEU079bLP0b<S80NWYj03lo?`12@T80>3Ph0861P@1kNg/0?3`l04Q8B00m?Cd0=CDe04m?
C`2`/;00LG5a059BDP1iNGT0DE5A02l_;`1OGel0MWIf05QHF011@D40HF5Q03`l?013@d<0EUIF07Yj
NP1EEED0@410075aL@0j>SX0D51@06UYJ@1/K6`0=3@d04M7A`1=CDd0GemO08b<S010@400=CDe05EE
E@1QHF40IFEU07=cL`2JVYX0>CTi02LW9`1MGEd0CDe=03De=@2@T900Xj>S03`l?00];Bd0CTi>04A4
A01GEeL0Z:RX06YZJP0d=3@0CDe=059BDP27QhL0/[:b0<O7a`1@D500;Bd]05mOG`24Q8@0G5aL08^;
R`3:b/X0A4A402`/;01FEUH0UIFE07IfMP1^KVh0IFEU02h^;P1EEED0E5AD08j>SP1WIfL0V9RH04I6
AP0X:2P0KFe]09^KV`1?Cdl0PX:206MWI`0U9BD0BTY:05QHF01/K6`0GUiN075aL@0];Bd0<30`08^;
R`33`l<0GUiN07YjNP12@T80:RXZ06UYJ@2JVYX0<c<c061PH00k>c/0;Bd]07moO`2b/[80D51@05AD
E01VIVH0<C4a04Y:BP2BTY80Cdm?03lo?`1ZJVX0D51@05QHF02:RXX0IfMW02PX:01:BTX0CTi>04Q8
B02EUID0/K6a05aLG01>CTh0DE5A05YJFP1BDU80b<S809JFUP0^;Rh0EUIF061PH017AdL0JFUY0<W9
b@1JFUX0:RXZ05iNGP14A4@0DU9B0:FUY@2KVi/0B4Q802DU9@1WIfL0Lg=c04i>CP2ATI40clo?059B
DP0Z:RX0OWin09FEU@1ADE40PH6108V9R@0/;2`09bLW04E5A@2SXj<0Ogmo079bLP2=SHd0?Cdm05YJ
FP1ZJVX0Rh^;061PH01nOWh0A4A402<S8`1ADE40P82009:BTP21PH40Ph>304U9B@0h>3P0A4A409FE
U@20P800J6QX08b<S00c<c<0AdM705eMG@1LG5`0Ng]k04Y:BP1VIVH0JVYZ04m?C`1UIFD0D51@04U9
B@15ADD0EeMG04I6AP0g=cL0De=C05]KF`1FEUH0KVi^0451@@1FEUH0?Shn03dm?@1HF5P0@D5103De
=@0];Bd0B4Q803De=@1CDe<0<S8b05=CD`1TI6@003X0MgMg06i^KP1UIFD0GemO05iNGP1hN7P0EUIF
07inOP2:RXX0Ti>C06e]K@1OGel0ADE502LW9`1@D500CTi>05YJFP1EEED0=cLg059BDP0m?Cd0CDe=
0492@P0n?Sh0BTY:03hn?P1=CDd0Cdm?03`l?015ADD0<S8b04e=C@0o?cl0;bl_055AD@12@T80EUIF
05UIF@1DE5@0GEeM0451@@1XJ6P0>c/k02d];@1WIfL0NWYj034a<@14A4@0R8R806ATI01RHV80>SXj
06EUI@1LG5`0EUIF06EUI@0Y:BT0:b/[0P14A4@0601GEeL0B4Q803De=@0];Bd0C4a<03Hf=P0i>CT0
:b/[0451@@0L71`0:BTY03Lg=`13@d<0?3`l0410@00l?3`0CDe=03Ph>013@d<0Cdm?0410@01FEUH0
LG5a06][J`80F5QH07h0AdM7059BDP1WIfL0DU9B0;:b/P1<C4`0E5AD07AdM01BDU80L71`04m?C`1o
Ogl0MgMg04a<C01OGel0EEEE04Y:BP1?Cdl0F5QH05eMG@1`L700JVYZ03Lg=`1/K6`0KFe]0;Vi^@1H
F5P0Rh^;0::RXP1@D500QhN706MWI`1lO7`0YZJV06MWI`2f][H0EUIF03Ph>01^KVh0?3`l04i>CP1:
BTX0JFUY08f=S@1ADE40M7Ad06][J`2FUYH0M7Ad0:b/[01NGUh0NGUi065QH@1TI6@0EeMG05eMG@2M
WId0Kfm_05mOG`24Q8@0F5QH0820P03GemL0M7Ad0410@01<C4`0ATI608R8R01;Bd/0KVi^051@D01<
C4`0Ng]k03/k>`1@D500AdM7020P801=CDd0I6AT04];B`20P800@d=306=SH`1dM7@0A4A4069RHP1C
De<0e]KF07AdM01IFET0IVIV04U9B@1XJ6P0DE5A0492@P28R8P0EEEE09RHV02PX:00FUYJ051@D01I
FET0LG5a07UiN@0m?Cd0De=C03@d=01LG5`0EeMG09FEU@1]KFd0Ph>303lo?`0j>SX0Jf][05IFEP1O
Gel0L71`061PH00b<S80GUiN03Lg=`1KFe/0Hf=S051@D010@402065QH@190492@P1PH600ADE504e=
C@1BDU80Bd];02TY:@1dM7@0D51@02PX:01nOWh0?Cdm04i>CP1MGEd0HV9R07=cL`0n?Sh0@d=302PX
:018B4P0N7Qh079bLP1NGUh0Bd];04=3@`1EEED0RXZ:05]KF`1OGel0@410069RHP1SHf<0G5aL07Ad
M01eMGD0IVIV05QHF01CDe<0GemO03Xj>P1IFET0Bd];06a/K01lO7`0jn_[06i^KP0o?cl0L71`04Y:
BP3;bl/0Zj^[05YJFP1]KFd0Jf][05EEE@1ZJVX0EeMG05YJFP1EEED0BDU9069RHP1GEeL0B4Q803<c
<`10@400?Shn08f=S@2BTY80GemO07QhN01YJFT0J6QX07moO`02ooooo`000:H0SHf=04m?C`1oOgl0
Rh^;07emO@1lO7`0=cLg04=3@`21PH40CTi>06MWI`1<C4`0<30`04];B`25QHD0>CTi05QHF01FEUH0
:2PX04I6AP1RHV80Hf=S038b<P1FEUH0>c/k0410@01HF5P0SXj>06IVIP0a<C40IfMW04i>CP1NGUh0
VYZJ07UiN@0Y:BT0:RXZ05MGE`1^KVh0H61P07YjNP2<S8`092@T03/k>`1YJFT0IVIV05mOG`2ZZZX0
IVIV01dM7@11@D40FUYJ055AD@26QXH0/[:b02@T900V9RH0EUIF06YZJP1ADE40UiNG03Ph>00J6QX0
>c/k07MgM`1QHF40MgMg08V9R@0R8R80;Bd]06UYJ@1kNg/0KVi^08^;R`1`L7008b<S02h^;P29RHT0
UiNG04i>CP2LW9`0GEeM01lO7`1;Bd/0Q8B405aLG01YJFT0FUYJ01lO7`0o?cl0IFEU07=cL`0d=3@0
@d=3051@D00`<300A4A405=CD`13@d<08b<S04M7A`0V9RH0@D5105YJFP1eMGD0ADE503Ti>@1FEUH0
8B4Q03Ph>01mOGd0L71`02LW9`18B4P0HV9R01/K6`1<C4`0[Jf]06e]K@0O7al0BDU903lo?`1:BTX0
Lg=c051@D00T92@0;bl_05QHF01NGUh0GEeM07inOP0m?Cd0<c<c03lo?`1HF5P0Lg=c05MGE`2WYjL0
N7Qh02PX:019BDT0L71`06UYJ@1^KVh0_Kfm08b<S00[:b/0FEUI07alO025QHD0Lg=c0<O7a`1EEED0
>SXj079bLP1[Jf/0Bd];09:BTP28R8P0:b/[05=CD`1bLW80GUiN0<G5a@1PH600>CTi0P1lO7`03@2A
TI40KFe]0;>c/`1NGUh0<30`05UIF@1]KFd0PH61075aL@2YZJT0:2PX04I6AP1cLg<00P1RHV802@1j
NWX0DU9B03`l?01MGEd0I6AT09fMW@10@400K6a/06m_K`0203De=@0/06UYJ@1ZJVX0GEeM08N7Q`1>
CTh0?3`l05IFEP1NGUh0?Shn06=SH`26QXH0>c/k05EEE@1aLG40IVIV03Lg=`1QHF40Lg=c059BDP2O
Wil0VIVI04I6AP1ADE40PH6103Lg=`1eMGD0a/K6075aL@0g=cL0BTY:04i>CP1=CDd0bl_;09jNWP0X
:2P0@d=308b<S012@T80KVi^06][J`0U9BD0DE5A06][J`1XJ6P208f=S@1Y038b<P15ADD0GUiN06MW
I`1hN7P0_[jn03dm?@1>CTh0P82008n?S`1IFET0SXj>05iNGP0M7Ad0EUIF0:NWY`29RHT0RXZ:08^;
R`0m?Cd0@d=307QhN02`/;00CDe=07=cL`1ZJVX0@d=304];B`1ZJVX0LG5a04U9B@2EUID0Kfm_01hN
7P1UIFD0Ng]k06i^KP1CDe<0R8R807]kN`0[:b/0@41006e]K@2;Rh/0DE5A06][J`0c<c<0De=C06IV
IP2`/;00Jf][04i>CP1[Jf/0<30`04i>CP1ADE40RHV9069RHP10@400?3`l03De=@0n?Sh0U9BD09>C
T`0f=SH0AdM703hn?P10@400ADE508B4Q01TI6@0;Bd]03<c<`0l?3`0Fe]K06UYJ@2ATI40Cdm?034a
<@1JFUX0HV9R06UYJ@14A4@0CTi>05QHF01@D500LG5a04A4A01JFUX0C4a<05]KF`1:BTX0@41006AT
I01MGEd0Fe]K08>3P`1BDU80Ng]k04M7A`19BDT0Fe]K02/[:`0i>CT0?3`l0080?Cdm0?l0DE5A02h^
;P11@D40DU9B08>3P`1HF5P0De=C05eMG@1@D500NGUi05YJFP1VIVH0DU9B06i^KP1ADE40HF5Q04];
B`0i>CT0BDU903Hf=P0m?Cd0AdM703Xj>P1IFET0ADE504A4A012@T80Bd];04i>CP12@T80BTY:03/k
>`0^;Rh0=3@d03De=@1KFe/0>SXj038b<P15ADD0B4Q804];B`15ADD0BDU904m?C`1ADE40CTi>03@d
=00Y:BT0Vi^K06ATI00/;2`0@d=305]KF`1DE5@0EeMG02<S8`16ATH0DE5A02/[:`1ADE40:RXZ03Xj
>P1;Bd/08B4Q0410@00o?cl0?Cdm02h^;P0l?3`0A4A403De=@0`<300A4A401hN7P12@T80<S8b04E5
A@12@T80CDe=03@d=017AdL06a/K02h^;P0i>CT0Cdm?04i>CP1?Cdl0>SXj05EEE@0o?cl0@d=3059B
DP1QHF40C4a<06ATI016ATH0IVIV06m_K`1LG5`0R8R806][J`2?Shl0KFe]055AD@1_Kfl0EeMG07al
O01]KFd0GUiN05eMG@1GEeL0Cdm?04U9B@1TI6@0@41009BDU01OGel0UiNG096AT@1hN7P0^;Rh05iN
GP1FEUH0NGUi06e]K@2[Zj/0IVIV03Xj>P12@T80=cLg05mOG`1^KVh0Cdm?05QHF01BDU80EEEE03Hf
=P1EEED0@D510<S8b012@T80Hf=S03<c<`1YJFT0CTi>02/[:`1NGUh0Lg=c08B4Q02KVi/0HF5Q09BD
U03fm_H0NWYj03<c<`1dM7@0GUiN09nOW`1`L700TI6A04a<C01FEUH0Ph>303hn?P1MGEd0CDe=01LG
5`1LG5`0IfMW03@d=01?Cdl0=CDe04Y:BP1<C4`0F5QH06UYJ@0o?cl0RXZ:0820P026QXH0MWIf04=3
@`1;Bd/0I6AT07IfMP2YZJT0MWIf04i>CP1CDe<0BDU906=SH`1GEeL0=CDe04a<C00j>SX0Ng]k04];
B`2@T900DU9B05MGE`1CDe<0P82005QHF00n?Sh0OGem06MWI`0l?3`0ATI603lo?`0e=CD0C4a<03hn
?P0f=SH0DU9B05UIF@19BDT0ATI6061PH01DE5@0BTY:061PH01FEUH0F5QH05YJFP0^;Rh0OWin051@
D00];Bd0CDe=05QHF02BTY80IFEU0492@P0m?Cd0@41006IVIP1SHf<0GUiN051@D01CDe<0OWin065Q
H@1SHf<0>c/k04m?C`1;Bd/07AdM03/k>`1NGUh0G5aL06e]K@1RHV80BDU908R8R01KFe/00100@T92
05ADE00V9RH0D51@05QHF01SHf<0EEEE09NGU`1TI6@0F5QH06][J`19BDT0NGUi07QhN01cLg<0OWin
0P1WIfL04P1eMGD0<c<c05iNGP1;Bd/0FEUI04a<C01QHF40EeMG03lo?`1:BTX0F5QH06a/K01CDe<0
G5aL061PH01_Kfl0L71`061PH0;ooooo00006@2TY:@0CTi>05YJFP23Ph<0QXJ608Z:RP14A4@0=CDe
05iNGP1RHV80VIVI06][J`0k>c/0CTi>06ATI01NGUh0V9RH0;^k^`0[:b/0BDU907YjNP1dM7@0Jf][
08^;R`18B4P00P0a<C40o`1_Kfl0ZZZZ071`L028R8P0?Shn03Lg=`17AdL0MWIf07QhN01_Kfl0Ogmo
02@T900n?Sh0ADE505eMG@1cLg<0HF5Q08f=S@0];Bd0>c/k04i>CP1CDe<0FUYJ096AT@1aLG40:RXZ
05mOG`2DU9@0MGEe05aLG01jNWX0=SHf02HV9P1nOWh0VYZJ03`l?016ATH0?Cdm02XZ:P10@400RHV9
04i>CP12@T80E5AD02TY:@0f=SH0CDe=07]kN`0^;Rh0ATI604A4A013@d<0ATI606QXJ01[Jf/08B4Q
03Lg=`1`L700ADE505IFEP2@T900<S8b01XJ6P16ATH0HF5Q03dm?@1CDe<0TY:B030`<00m?Cd0G5aL
06a/K01FEUH0Y:BT04E5A@0T92@0BTY:0820P01YJFT0N7Qh0=;BdP0f=SH0:BTY05YJFP1bLW80B4Q8
07YjNP2KVi/0:BTY02`/;019BDT0G5aL0492@P2RXZ80;2`/02XZ:P1HF5P0IFEU05aLG01PH600[Jf]
02l_;`1=CDd0GEeM07UiN@1=CDd0EeMG03hn?P0c<c<0BTY:08:2PP2g]kL0HF5Q05iNGP1fMWH0CTi>
04=3@`24Q8@0`L7104i>CP1=CDd0FUYJ034a<@14A4@0NWYj09:BTP18B4P0Ng]k03Ph>00Z:RX0Hf=S
08n?S`1PH600N7Qh02l_;`14A4@0SHf=096AT@12@T80EEEE07inOP0`<300D51@08B4Q02LW9`0EeMG
05aLG01EEED08b<S05mOG`2GUiL0EUIF02l_;`1PH600ADE503/k>`2IVIT0ZZZZ03<c<`19BDT0J6QX
07AdM01CDe<0YJFU0<o?c`16ATH0BDU9059BDP1EEED0KVi^0;Rh^02`/;00>CTi03/k>`1KFe/0EUIF
09FEU@37alL0DU9B02d];@13@d<0IFEU04a<C02MWId0QhN702d];@1DE5@0Rh^;08:2PP2IVIT0`L71
03Ph>00a<C40IFEU069RHP1/K6`0X:2P04I6AP0_;bl0KFe]0:j^[P1BDU80NGUi06a/K00i>CT0@d=3
09JFUP1SHf<0[jn_05]KF`0W9bL0Lg=c09^KV`1GEeL0JVYZ06][J`0U9BD0<C4a07moO`2[Zj/0Fe]K
08j>SP13@d<0ATI606i^KP2JVYX0EEEE061PH01lO7`0>SXj06=SH`2f][H0Bd];03`l?01SHf<0C4a<
0492@P2>SXh0YjNW030`<012@T80NGUi04a<C01BDU80ZZZZ0;Ng]`1>CTh0>CTi07AdM01HF5P0HF5Q
0;Vi^@2SXj<0<c<c03Xj>P00o`1>CTh0@T9205mOG`34a<@0Ng]k034a<@1GEeL0Lg=c05aLG01bLW80
`<3007AdM00];Bd0Cdm?071`L01?Cdl0SXj>09JFUP0Q8B40?Cdm05QHF02c/k<0Jf][092@T01NGUh0
:2PX04a<C01?Cdl0W9bL06a/K01dM7@0Ng]k02XZ:P15ADD0IVIV09FEU@1ADE40EEEE051@D01IFET0
Bd];051@D01VIVH0JFUY071`L01;Bd/0LW9b05YJFP1NGUh0E5AD0451@@1cLg<0Ph>308:2PP25QHD0
Hf=S07alO01BDU80D51@05eMG@0[:b/0=cLg02@T900m?Cd0=CDe05mOG`18B4P0C4a<05=CD`2@T900
QhN707emO@1^KVh0DU9B07YjNP23Ph<0O7al05eMG@1dM7@0DE5A08Z:RP17AdL0;2`/051@D017AdL0
CTi>065QH@1ZJVX0Hf=S03hn?P1GEeL0D51@06QXJ01UIFD0BDU9059BDP1<C4`0=3@d04M7A`0i>CT0
BTY:04Q8B00g=cL0E5AD04M7A`1CDe<0EEEE05mOG`1KFe/0A4A4055AD@0];Bd0<30`05UIF@1LG5`0
?Shn04I6AP26QXH0Lg=c08B4Q015ADD0L71`06IVIP0f=SH0GEeM04Y:BP1EEED0IFEU02LW9`17AdL0
De=C04I6AP0b<S80BTY:03/k>`14A4@0=SHf04a<C00V9RH0@D5103dm?@1=CDd0@D5104m?C`0m?Cd0
DE5A02LW9`0f=SH0CDe=0410@015ADD0FEUI051@D01BDU80ATI603Lg=`1?Cdl0F5QH04A4A02DU9@0
C4a<05YJFP1GEeL0B4Q805iNGP1nOWh0SXj>059BDP0f=SH0?clo038b<P18B4P0Cdm?04a<C01ZJVX0
NWYj05UIF@1@D500GUiN08F5Q@3Jf]X0BDU909fMW@1hN7P0LG5a0<W9b@0n?Sh0FUYJ05ADE01ADE40
XZ:R05YJFP12@T80FEUI04Y:BP0];Bd0=cLg055AD@1NGUh0IFEU06IVIP1XJ6P0TY:B03<c<`1mOGd0
?Cdm08B4Q00b<S80DU9B04=3@`16ATH0Ti>C05EEE@2=SHd0YJFU08R8R023Ph<0U9BD071`L01RHV80
M7Ad05iNGP1KFe/0Kfm_0:BTY01cLg<0EEEE05aLG00W9bL0PX:206a/K00d=3@0Ph>307QhN01ADE40
K6a/03Xj>P1QHF40GUiN06][J`24Q8@0ATI60;Vi^@1fMWH0][Jf0:FUY@19BDT0EEEE04i>CP1PH600
MWIf04a<C01?Cdl0FEUI04M7A`00B`2KVi/0Ogmo04A4A01BDU80>CTi04m?C`0i>CT0E5AD07AdM01o
Ogl0MGEe06][J`18B4P0=SHf05eMG@18B4P0IfMW08F5Q@1@D500@T9207QhN00`<300J6QX03lo?`0f
=SH0>c/k0492@P1GEeL0:RXZ0451@@1:BTX0@d=304M7A`11@D40?Cdm0<S8b02@T900@41006EUI@0Z
:RX0C4a<04m?C`1lO7`0GUiN04Q8B017AdL0?clo04Y:BP11@D40BTY:05ADE013@d<0>c/k03dm?@1/
K6`0H61P03/k>`1WIfL0N7Qh0410@00l?3`0CTi>04U9B@1KFe/0C4a<04I6AP1HF5P0ATI604a<C015
ADD0Kfm_069RHP2m_Kd0OGem06=SH`0206EUI@0H08n?S`1]KFd0GEeM08B4Q01GEeL0HF5Q06UYJ@0g
=cL0P82004];B`1DE5@0EUIF04Y:BP1GEeL0BTY:05=CD`0l?3`0KVi^07=cL`1YJFT0LW9b07inOP1X
J6P0NGUi0_ooool0000>08j>SP2IVIT0][Jf04U9B@1<C4`0Lg=c07]kN`2DU9@0>CTi03De=@1<C4`0
NGUi05=CD`2EUID203Xj>P0d06][J`2<S8`0P82005]KF`1GEeL0AdM705QHF01OGel0Kfm_03Ph>00g
=cL0=SHf03dm?@1UIFD0N7Qh06ATI00Q8B40>CTi03Hf=P0/;2`0I6AT0:f][@0m?Cd0:BTY04A4A00l
?3`09RHV06a/K026QXH0FEUI02d];@1>CTh0@D5103lo?`2@T900[Jf]02LW9`0n?Sh0Lg=c05YJFP1^
KVh0/K6a0492@P0I6AT0Bd];08J6QP1WIfL0N7Qh04e=C@0V9RH0?clo04];B`80IFEU02<0YJFU01TI
6@0e=CD0D51@05mOG`16ATH0PH610:NWY`0L71`0ADE506ATI01MGEd0ADE505QHF02BTY80820P03lo
?`1]KFd0EEEE061PH02EUID0FEUI02TY:@16ATH0MWIf061PH01ADE40IVIV03<c<`0a<C40C4a<096A
T@0m?Cd0Fe]K06e]K@0203`l?02R05ADE01UIFD0EEEE06][J`0i>CT0=CDe03lo?`1?Cdl0AdM704Q8
B02<S8`0?Shn03Hf=P29RHT0IfMW02HV9P1ADE40AdM7038b<P1=CDd0TY:B05EEE@0[:b/0EEEE04A4
A01TI6@0N7Qh08Z:RP0m?Cd0?3`l05ADE01QHF40M7Ad08V9R@28R8P0=cLg02/[:`1MGEd0SXj>06i^
KP2HV9P0PX:203`l?00V9RH0JVYZ08f=S@1IFET0YJFU04a<C00U9BD0@410079bLP1XJ6P0`L7104E5
A@0X:2P0E5AD0:>SX`2:RXX0Y:BT0=;BdP0_;bl0=CDe05iNGP20P800JVYZ0=3@d02EUID07alO051@
D02;Rh/0KVi^06m_K`2OWil0FUYJ03`l?01GEeL0Z:RX06][J`1bLW80][Jf05EEE@0m?Cd0IVIV0;Ng
]`1gMgL0SXj>09BDU00_;bl0>CTi05YJFP2b/[80TY:B06e]K@1CDe<0=3@d04i>CP1YJFT0YZJV069R
HP1]KFd0:b/[03lo?`2=SHd0YZJV05EEE@1XJ6P0Cdm?030`<01oOgl0/;2`09fMW@1;Bd/0PX:203Lg
=`1GEeL0W9bL05UIF@0[:b/0I6AT05]KF`1@D500UiNG0:^[Z`0o?cl0@d=30451@@15ADD0[Zj^08J6
QP0N7Qh0=CDe065QH@1JFUX0Shn?0;:b/P0];Bd0:2PX05MGE`1mOGd0LG5a0:2PX01_Kfl0>3Ph04E5
A@1aLG40IfMW09>CT`2WYjL0@T9203Ti>@1[Jf/0MGEe0820P02YZJT0D51@03`l?010@400NWYj065Q
H@1^KVh0Z:RX0P14A4@0@@1@D500/k>c06MWI`2IVIT0IfMW03hn?P12@T80IVIV0;bl_01CDe<0UIFE
07emO@0i>CT0>SXj079bLP2l_;`0BDU905mOG`2BTY80@41003dm?@1OGel0WIfM05ADE01hN7P0VIVI
03Ph>015ADD0U9BD08Z:RP1DE5@0Jf][03<c<`0g=cL0E5AD075aL@0d=3@0?clo06IVIP13@d<0AdM7
055AD@1hN7P0?Shn03dm?@1SHf<0>SXj06=SH`1DE5@0DE5A06EUI@1<C4`0EEEE04a<C00k>c/0?clo
03Xj>P1FEUH0MWIf06e]K@15ADD0>CTi04i>CP16ATH0C4a<0080DU9B0?00F5QH04e=C@11@D40?Shn
030`<01<C4`0@d=30451@@0^;Rh0HV9R04E5A@17AdL0B4Q805=CD`1>CTh0GEeM05ADE013@d<0FEUI
04E5A@1KFe/0De=C06=SH`1:BTX0E5AD03@d=00^;Rh0?Shn03<c<`0m?Cd0A4A403@d=00o?cl0;2`/
04I6AP0g=cL0C4a<04E5A@19BDT0Cdm?04Q8B01NGUh0CDe=03@d=01;Bd/0DE5A069RHP1PH600E5AD
051@D011@D40BTY:04e=C@11@D40FEUI05iNGP0o?cl0Ph>3069RHP1?Cdl0O7al07inOP1SHf<0SXj>
051@D00n?Sh0F5QH03Xj>P1HF5P0?Cdm04i>CP1JFUX0=CDe02l_;`10@400EEEE03<c<`11@D40E5AD
0492@P0b<S80BTY:030`<01TI6@0?clo04e=C@10@400IVIV03Xj>P1CDe<0;bl_06=SH`12@T80ADE5
04=3@`1KFe/0@T9205ADE018B4P0L71`04a<C01WIfL0HF5Q0:b/[01;Bd/0Hf=S06MWI`0o?cl0M7Ad
05mOG`23Ph<0>3Ph03/k>`12@T80;Bd]05ADE01ZJVX0FUYJ07UiN@1RHV80FEUI03Ph>014A4@0B4Q8
08b<S01GEeL0][Jf071`L01CDe<0R8R804A4A027QhL0Q8B406m_K`2/[:`0O7al06a/K02<S8`09bLW
04m?C`0n?Sh0DE5A04m?C`0d=3@0?clo034a<@17AdL0=cLg092@T00/;2`0I6AT03Xj>P1QHF40@410
04];B`1nOWh0J6QX079bLP2FUYH0H61P09RHV03UiND0M7Ad05aLG01gMgL0@d=308j>SP1_Kfl0W9bL
04Q8B01GEeL0JVYZ01dM7@1RHV80B4Q8020P801?Cdl0C4a<0451@@1PH600>CTi06IVIP1JFUX0BDU9
059BDP1mOGd0gmoO0861P@1mOGd0OWin05ADE01FEUH0KVi^06IVIP20P800LW9b05YJFP1XJ6P0?3`l
04Y:BP1@D500EeMG07QhN016ATH0E5AD03Ph>01NGUh0C4a<07inOP1QHF40KFe]04Q8B01=CDd0KFe]
05IFEP0c<c<0>SXj04=3@`0n?Sh0BTY:030`<01CDe<0BDU9055AD@13@d<0Bd];06YZJP1;Bd/0D51@
05iNGP16ATH0Fe]K05YJFP0/;2`0JVYZ05]KF`0h>3P0Ogmo055AD@1>CTh204a<C00j04m?C`0f=SH0
DU9B03@d=01cLg<0BTY:04=3@`1UIFD0CTi>04U9B@1HF5P0L71`05QHF019BDT0>SXj05UIF@0m?Cd0
JVYZ065QH@10@400H61P05IFEP15ADD0G5aL04=3@`1XJ6P0?3`l05mOG`1ADE40b/[:06a/K02=SHd0
TY:B04M7A`2OWil0M7Ad07moO`31`L40BDU905QHF01NGUh09RHV05EEE@0m?Cd0K6a/065QH@1EEED0
CTi>02XZ:P0a<C40>3Ph09RHV01jNWX0Cdm?07YjNP2:RXX0IFEU07=cL`;ooooo0000c@1XJ6P0HV9R
0;Vi^@1JFUX0Cdm?05UIF@1DE5@0TY:B06i^KP0/;2`0BDU904Y:BP1UIFD0bl_;09jNWP0J6QX0>c/k
08:2PP1UIFD0UYJF08N7Q`0Z:RX0Bd];06UYJ@28R8P0I6AT09fMW@2SXj<0;Rh^04E5A@26QXH0JFUY
06ATI02ZZZX0Ogmo01HF5P1<C4`0G5aL07inOP1QHF40XZ:R0451@@0L71`092@T03<c<`1aLG40QXJ6
0::RXP0c<c<0:b/[04U9B@1lO7`0OWin07]kN`1bLW8071`L03/k>`1gMgL0PH6103dm?@1NGUh09RHV
02/[:`1PH600UIFE05MGE`1HF5P0DU9B01hN7P1ADE40F5QH06YZJP0[:b/0AdM704m?C`0X:2P0AdM7
09bLW01DE5@0<C4a069RHP0n?Sh0E5AD061PH02LW9`0G5aL051@D01;Bd/0?clo03/k>`1TI6@0IFEU
01lO7`0h>3P0D51@03hn?P23Ph<0SXj>03@d=00O7al09BDU05mOG`1ADE40QhN7092@T00N7Qh0@T92
059BDP0o?cl0L71`0<71`@0m?Cd09RHV04I6AP1MGEd0DU9B08f=S@2^[Zh0DE5A03/k>`1YJFT0O7al
05=CD`2CTi<0EeMG01hN7P0S8b<0Q8B406m_K`24Q8@0UYJF03De=@0c<c<0FUYJ0:b/[02FUYH0TI6A
0;Rh^01@D500@T9206i^KP3;bl/0UYJF071`L02HV9P0Cdm?03@d=01_Kfl0P82007UiN@1WIfL0VIVI
04a<C00b<S80GEeM07YjNP0g=cL0HF5Q07UiN@0l?3`0L71`08:2PP13@d<0LG5a04a<C00b<S80GUiN
079bLP1XJ6P0=3@d08:2PP0f=SH0;2`/06UYJ@2=SHd0<30`04E5A@2:RXX0>CTi03Ph>02@T900PH61
02XZ:P1<C4`0G5aL05=CD`14A4@0YZJV06][J`0h>3P0HV9R07EeM@1PH600LG5a09bLW013@d<0;bl_
06QXJ00o?cl0EUIF0:JVYP2=SHd0820P04i>CP1OGel00P1iNGT0c@2e]KD0E5AD01/K6`1FEUH0QhN7
07emO@2TY:@0HV9R01lO7`0o?cl0Rh^;0:RXZ01LG5`0YZJV038b<P0Z:RX0JVYZ096AT@1EEED0WinO
05QHF00X:2P0CTi>06a/K01NGUh0SXj>0410@00Q8B40GUiN09RHV01DE5@0Kfm_09>CT`0`<300A4A4
09VIV@2?Shl0L71`0;>c/`0`<300=cLg05aLG01[Jf/0E5AD07]kN`1JFUX07AdM06EUI@33`l<0Shn?
07alO02=SHd0@d=3059BDP2DU9@0TI6A05IFEP21PH40MGEe03Ti>@1CDe<0W9bL06QXJ00l?3`0EUIF
04I6AP1?Cdl0Kfm_08n?S`1BDU80>CTi04U9B@10@400AdM7061PH02BTY80@d=304Q8B01LG5`0Bd];
05YJFP1ZJVX0WinO04Y:BP0d=3@0BDU906MWI`1MGEd0OGem0;6a/@14A4@0>3Ph05YJFP1]KFd0G5aL
08n?S`1;Bd/06a/K04E5A@1`L700Lg=c06e]K@2RXZ80HF5Q02<S8`10@400SXj>069RHP1oOgl0]KFe
03hn?P0a<C40C4a<06ATI01`L700CDe=06IVIP1GEeL0ATI605mOG`16ATH0CTi>04=3@`0i>CT0BTY:
04A4A01HF5P0NWYj071`L01TI6@0GUiN05YJFP1IFET0ATI6055AD@0j>SX0=3@d02/[:`0h>3P08B4Q
04m?C`0g=cL0Bd];04m?C`22PX80QHF507alO01HF5P0C4a<06EUI@1GEeL0JVYZ05YJFP1eMGD0CTi>
06=SH`0c<c<0=CDe04a<C00l?3`0A4A4055AD@1DE5@0D51@02TY:@1=CDd0?clo06EUI@1@D500Bd];
051@D00m?Cd0;2`/034a<@0[:b/0AdM702@T900Y:BT0CTi>04I6AP1GEeL0Bd];05=CD`1NGUh0@410
04];B`0a<C4092@T07inOP1IFET0:b/[04A4A01mOGd0GEeM08B4Q015ADD0GemO06EUI@19BDT0HV9R
03Xj>P1UIFD0J6QX02DU9@0d=3@00P1>CTh0S00^;Rh0=CDe04m?C`1:BTX0<C4a04i>CP0^;Rh0AdM7
03<c<`19BDT0B4Q8051@D00_;bl0Cdm?02PX:00d=3@0<C4a03hn?P19BDT0OWin04Q8B01@D500A4A4
04a<C01FEUH0Fe]K059BDP1dM7@0Bd];05QHF01iNGT0HV9R08:2PP1IFET0OWin06UYJ@1eMGD0I6AT
03Xj>P1CDe<0C4a<06UYJ@1OGel0Jf][07MgM`1lO7`0JFUY07moO`36a/H0>CTi0>KViP1`L700De=C
08^;R`0_;bl0HF5Q05MGE`1HF5P0TY:B055AD@1@D500K6a/04U9B@1?Cdl0BTY:0410@011@D40FUYJ
05UIF@13@d<0HF5Q034a<@2HV9P06a/K06IVIP0c<c<0RXZ:03`l?00k>c/0OGem04A4A01lO7`0Q8B4
04M7A`28R8P0/k>c06][J`17AdL0GUiN06UYJ@23Ph<0H61P08j>SP1WIfL0Ng]k07moO`0h>3P0IfMW
04Q8B00e=CD0EeMG05=CD`1ADE40NGUi02XZ:P1JFUX0EEEE05IFEP1ADE40EUIF0:6QX@22PX80SHf=
06IVIP1XJ6P0YZJV055AD@1/K6`0T92@04m?C`1XJ6P0Ph>3051@D01>CTh0ADE5034a<@16ATH0<C4a
05YJFP0`<300Ng]k0451@@1NGUh0IfMW07YjNP1<C4`0=SHf03hn?P19BDT0@d=30P1;Bd/0DP0k>c/0
DE5A03<c<`1QHF40Bd];04U9B@1BDU80ATI606=SH`0Y:BT0A4A404M7A`13@d<0ADE5055AD@18B4P0
YZJV06m_K`12@T80DU9B0492@P1NGUh0H61P06ATI01RHV80:2PX04=3@`0`<300K6a/0451@@1;Bd/0
GUiN05YJFP1VIVH0DE5A06MWI`1?Cdl0;Rh^03Lg=`12@T80B4Q804E5A@19BDT0?Cdm061PH00h>3P0
>CTi034a<@0P8200C4a<04];B`29RHT0CTi>09BDU01NGUh0De=C05MGE`1ADE40VYZJ05MGE`1HF5P0
Lg=c04M7A`26QXH0Ti>C04M7A`1SHf<09bLW04e=C@0k>c/0Fe]K06][J`0m?Cd0A4A404m?C`1JFUX0
D51@05YJFP21PH40F5QH05eMG@1kNg/2ooooo`000?l0WIfM05MGE`1jNWX0Ng]k08n?S`1^KVh0?clo
05iNGP2<S8`0HV9R0:NWY`1@D500:2PX07IfMP34a<@0IfMW09NGU`1VIVH09RHV03Ph>01hN7P0De=C
04A4A01gMgL0>CTi02PX:012@T80Ogmo05eMG@1SHf<0PH6102`/;013@d<0E5AD06][J`15ADD0@410
08J6QP0I6AT0@4100:VYZ@2FUYH092@T04m?C`1EEED08b<S051@D02MWId0Lg=c01`L7011@D40ADE5
05EEE@1]KFd0[:b/03Ti>@0T92@0D51@07EeM@1bLW80Lg=c0410@00U9BD0C4a<05UIF@1=CDd0R8R8
0:f][@0S8b<0>CTi05aLG02:RXX0GEeM0;2`/025QHD06QXJ03Lg=`20P800Fe]K07MgM`2RXZ80B4Q8
020P8017AdL0Rh^;05YJFP2CTi<0Lg=c01lO7`0f=SH0B4Q8065QH@1BDU80];Bd05eMG@0e=CD0?Shn
05iNGP1bLW80IVIV07QhN00P8200=SHf04];B`1lO7`0H61P05aLG01IFET07AdM051@D01VIVH0MWIf
038b<P1[Jf/0@T9202XZ:P1>CTh0KFe]04a<C01=CDd0LG5a02/[:`0Z:RX0PX:209VIV@1;Bd/0>c/k
06YZJP0Y:BT0?clo08:2PP1lO7`0;Bd]03dm?@0d=3@0?3`l04Q8B01cLg<0FUYJ02HV9P0h>3P0G5aL
04m?C`1VIVH0RXZ:04i>CP0[:b/0@d=305aLG00o?cl0Jf][09fMW@1[Jf/0<C4a03hn?P1QHF40Fe]K
07]kN`2FUYH0<30`05aLG01jNWX0IVIV09JFUP19BDT0=CDe0410@01MGEd0M7Ad09JFUP3Ng]h0Bd];
02@T901[Jf/0Y:BT05EEE@2:RXX0aLG503Ti>@0d=3@0MGEe0;6a/@1RHV80TY:B071`L00X:2P0F5QH
096AT@2<S8`0JVYZ0<S8b02<S8`0=CDe06EUI@1?Cdl0MWIf05aLG02i^KT0FUYJ0451@@16ATH0UiNG
05mOG`1WIfL0PX:204I6AP0i>CT0G5aL09nOW`1ADE40SHf=065QH@17AdL0IVIV0:FUY@1^KVh0JFUY
07]kN`1ADE40AdM7096AT@1^KVh0Bd];04i>CP1?Cdl0AdM70<30`02ATI40>c/k069RHP1;Bd/0BTY:
08f=S@1_Kfl0<c<c05iNGP2?Shl0?3`l07inOP2FUYH0=SHf02d];@1;Bd/0<C4a04U9B@2c/k<0NGUi
038b<P1FEUH0?3`l05aLG02e]KD0[Jf]03@d=01@D50002/0P82006ATI02?Shl0b/[:03lo?`0j>SX0
GemO08b<S01eMGD0Zj^[092@T00W9bL0>SXj07inOP1aLG40NGUi0;2`/01gMgL08R8R04I6AP23Ph<0
HV9R071`L02`/;00R8R8024Q8@1FEUH0^k^k08j>SP1]KFd0dm?C04e=C@0^;Rh0D51@09nOW`2>SXh0
JFUY0:^[Z`0o?cl0=3@d06YZJP2`/;00IFEU0080Fe]K0300:2PX04];B`1aLG40YjNW06=SH`1lO7`0
>SXj02HV9P1:BTX0G5aL071`L017AdL0HV9R05aLG00O7al0=cLg08Z:RP1nOWh0?3`l04];B`1KFe/0
IfMW04a<C01NGUh0MWIf06m_K`1kNg/0@T9206YZJP1?Cdl0CTi>04U9B@0h>3P0Cdm?055AD@1GEeL0
Lg=c06a/K01HF5P0BTY:04i>CP19BDT0=CDe051@D01ADE40CTi>03lo?`1WIfL20410@02104I6AP1<
C4`0G5aL06=SH`18B4P0@D5106EUI@1ADE40De=C04];B`1NGUh0DU9B07MgM`0i>CT0<S8b04i>CP0b
<S80@D5104E5A@0d=3@0C4a<03dm?@10@400>3Ph04i>CP15ADD0=CDe04M7A`0m?Cd0ATI603<c<`0[
:b/0CTi>034a<@0o?cl0Cdm?0410@01:BTX0CTi>05iNGP1<C4`0B4Q805iNGP19BDT08B4Q07inOP1H
F5P0;Bd]04E5A@1ZJVX0GemO065QH@0h>3P0Cdm?05UIF@0k>c/0IFEU02l_;`0j>SX0EEEE02TY:@0g
=cL0ADE505EEE@0W9bL0;Rh^06QXJ016ATH0>c/k0492@P0i>CT0I6AT03Lg=`12@T80BTY:06][J`0h
>3P0A4A40410@01ADE40De=C04];B`11@D40KFe]04];B`1DE5@0Cdm?065QH@1LG5`0GemO05eMG@2Z
ZZX0FUYJ05QHF01VIVH0GEeM079bLP1NGUh0Lg=c038b<P18B4P0ATI603`l?01ADE40B4Q8065QH@19
BDT0JFUY04U9B@0g=cL0F5QH08R8R037alL0NGUi09jNWP1RHV80JFUY071`L02;Rh/0LG5a07AdM01_
Kfl0YjNW06][J`1WIfL0KVi^02@T9018B4P0Kfm_0080BTY:0400?3`l055AD@1>CTh0F5QH04m?C`28
R8P0>3Ph06QXJ00Y:BT0EEEE03lo?`19BDT0N7Qh03<c<`2][Jd0aLG503`l?01jNWX0[Jf]05mOG`13
@d<0FUYJ03`l?01ADE40B4Q8096AT@16ATH0D51@04E5A@0U9BD0Jf][059BDP0^;Rh0QHF506i^KP19
BDT0B4Q803hn?P1XJ6P0DE5A069RHP1OGel0A4A40;Jf]P1IFET0VIVI05mOG`19BDT0Bd];069RHP1d
M7@0RHV904Q8B00i>CT0D51@03/k>`2CTi<0Ph>30492@P17AdL0?Shn04Y:BP0c<c<0P8200P1IFET0
8`11@D40Hf=S05iNGP17AdL0DE5A0410@017AdL0JFUY03hn?P0O7al0Cdm?01dM7@1kNg/0ADE504i>
CP1PH600Fe]K06QXJ019BDT0H61P04Y:BP1FEUH0S8b<04m?C`0a<C40KVi^05eMG@0_;bl0KFe]030`
<00h>3P0@D510861P@1dM7@0>CTi0080CTi>02T0L71`04m?C`1;Bd/0Hf=S0492@P14A4@0;Bd]09>C
T`1cLg<0:BTY061PH01KFe/0?Cdm04e=C@1@D500>CTi07alO01>CTh0AdM704U9B@0o?cl0BDU903Hf
=P1KFe/0ADE50:VYZ@19BDT0QHF50820P01QHF40Xj>S07YjNP1eMGD0VIVI04M7A`1KFe/0HV9R0410
@01nOWh0BDU905MGE`0205QHF00;055AD@1PH600JFUY04A4A01kNg/0O7al08F5Q@1kNg/0R8R809VI
V@1_Kfl00_ooool0003B09^KV`1YJFT0Ogmo04];B`1KFe/0QXJ604Y:BP1EEED0>SXj04U9B@1dM7@0
Cdm?030`<00l?3`0ATI605=CD`1eMGD0N7Qh02/[:`0/;2`0Cdm?06MWI`1HF5P0Xj>S06][J`0Y:BT0
9BDU05eMG@1QHF40S8b<0<[:bP0e=CD09bLW03Hf=P1_Kfl0ADE507alO02n_[h09BDU01LG5`1@D500
QhN704m?C`2>SXh0TY:B01HF5P0`<300HF5Q07]kN`1QHF40PX:205QHF00P8200?Shn06m_K`1kNg/0
KVi^08^;R`13@d<0;Rh^06IVIP27QhL0ADE506m_K`11@D409bLW0410@01^KVh0MGEe05UIF@1TI6@0
;bl_02@T901NGUh0SXj>04Q8B010@400E5AD024Q8@0[:b/0Q8B4079bLP0];Bd0A4A403/k>`0S8b<0
De=C0:^[Z`1NGUh0?Cdm04];B`0/;2`0:RXZ07YjNP2UYJD09bLW03Ph>01FEUH0@T9205YJFP1aLG40
?Cdm02LW9`1:BTX0@D5103/k>`20P800YjNW02XZ:P0W9bL0K6a/07=cL`16ATH0TI6A075aL@0M7Ad0
;bl_06m_K`1FEUH0Kfm_0;no_`0];Bd0:2PX04I6AP1]KFd0N7Qh06EUI@2QXJ40;2`/02l_;`0o?cl0
LG5a05YJFP1cLg<0@d=301lO7`19BDT0H61P07UiN@1MGEd0/;2`0:>SX`0i>CT0EeMG06YZJP23Ph<0
QXJ60:JVYP1mOGd0<S8b04i>CP1kNg/0/K6a07emO@2c/k<0<30`0451@@1[Jf/0M7Ad06UYJ@2RXZ80
;2`/04m?C`2JVYX0NWYj04Q8B024Q8@0MgMg03@d=01>CTh0alO70:>SX`1YJFT0X:2P06i^KP0c<c<0
Fe]K0;>c/`1SHf<0ADE507YjNP18B4P0?Cdm079bLP34a<@0HV9R03Lg=`1jNWX0DU9B04I6AP2CTi<0
d=3@05MGE`1UIFD0GemO03/k>`1bLW80bl_;061PH00e=CD0O7al05EEE@17AdL0OGem0;Zj^P11@D40
>CTi055AD@1RHV80GemO0P29RHT0VP0[:b/0IVIV06MWI`1XJ6P0UiNG0<K6aP0k>c/0K6a/096AT@21
PH40Ogmo09RHV00S8b<06a/K06MWI`2;Rh/0KVi^0:RXZ01gMgL08R8R04M7A`2YZJT0Ogmo0:>SX`1f
MWH08R8R03Ti>@1iNGT0Jf][065QH@1lO7`09bLW03Xj>P1ADE40[Zj^079bLP2`/;00F5QH03De=@16
ATH0Ti>C06UYJ@2[Zj/0MgMg03Ph>013@d<0MGEe069RHP1ZJVX0MGEe04M7A`0d=3@0ADE508J6QP1=
CDd0HF5Q0:JVYP1JFUX0<30`06MWI`23Ph<0>c/k05IFEP1TI6@0=cLg03Xj>P1VIVH0YjNW04U9B@1B
DU80B4Q804a<C01TI6@0T92@0:VYZ@11@D40G5aL065QH@1;Bd/0BTY:08N7Q`2IVIT09BDU05EEE@1U
IFD0Hf=S08j>SP2ATI40@D5103@d=01CDe<0MgMg075aL@2KVi/0MgMg01TI6@0o?cl0MgMg06UYJ@1W
IfL0Ogmo09>CT`0a<C40:RXZ05eMG@2a/K40OWin055AD@1QHF40QHF507MgM`1iNGT0FUYJ04I6AP1Z
JVX0H61P06MWI`1RHV80IfMW069RHP1FEUH0GEeM06i^KP1:BTX0DE5A03De=@0a<C40?3`l04A4A01C
De<0?clo0410@00[:b/0AdM703dm?@1=CDd0B4Q805mOG`1^KVh0Jf][06i^KP1/K6`0EeMG06YZJP1m
OGd0DE5A06QXJ029RHT0P82004Y:BP1`L700;bl_03<c<`1CDe<205MGE`0704a<C00l?3`0CDe=04I6
AP1DE5@0?clo05EEE@0204=3@`2M05EEE@0i>CT0>3Ph03De=@0_;bl0Bd];03De=@17AdL0E5AD03hn
?P17AdL0@D5105UIF@1MGEd0@d=304i>CP19BDT0=cLg07]kN`1KFe/0?3`l04U9B@1_Kfl0HF5Q06][
J`13@d<0CDe=07QhN015ADD0L71`03dm?@18B4P0IFEU02l_;`0e=CD0AdM7051@D00Z:RX0=CDe05QH
F00e=CD0;Rh^03Xj>P0_;bl0C4a<02PX:015ADD0?Shn05ADE00h>3P0C4a<02d];@0j>SX0=cLg0451
@@12@T80NGUi04U9B@1?Cdl0@T9205MGE`1=CDd0EEEE05=CD`25QHD0@T92059BDP18B4P0Cdm?06e]
K@1EEED0OGem02@T902ATI40HF5Q03hn?P1NGUh0K6a/09JFUP1CDe<0MWIf051@D016ATH0DE5A08:2
PP34a<@0CTi>0<[:bP1NGUh0DE5A07EeM@1BDU80W9bL06EUI@1@D500RXZ:03dm?@1>CTh0KFe]04A4
A012@T80@41004M7A`1RHV80Bd];04U9B@1ADE40C4a<03dm?@25QHD071`L065QH@0I6AT0JVYZ02l_
;`1XJ6P0QhN703/k>`1BDU80FEUI04Q8B02IVIT0eMGE06QXJ023Ph<0UIFE05aLG01`L700GEeM09nO
W`1?Cdl0IVIV061PH00M7Ad0PH6105EEE@0S8b<0CTi>03De=@0k>c/0D51@03Lg=`1jNWX0ADE504i>
CP1JFUX0QXJ60>o_k`1OGel0TI6A06=SH`1HF5P0HF5Q03lo?`1BDU80KFe]03Lg=`0206UYJ@0I055A
D@1CDe<0EEEE06=SH`1hN7P0@d=30492@P0h>3P0IfMW04];B`1VIVH0CDe=05aLG01?Cdl0<S8b04a<
C00i>CT0=CDe03hn?P0i>CT0<S8b04Q8B00_;bl0EEEE0410@00203/k>`1204Q8B01RHV80:RXZ03`l
?013@d<0=3@d04a<C014A4@0AdM708b<S01RHV80EEEE06EUI@0n?Sh0BDU903Ph>01>CTh0ATI603`l
?01IFET0AdM705YJFP18B4P0F5QH05eMG@1GEeL0FUYJ06MWI`20P800GemO04i>CP11@D40HF5Q05MG
E`1nOWh0De=C030`<00n?Sh0=cLg04Q8B01CDe<0GemO07UiN@0f=SH0HV9R04m?C`2e]KD0BDU905AD
E014A4@0?3`l05mOG`1?Cdl0FEUI05iNGP1DE5@0T92@06a/K00e=CD0FEUI061PH02WYjL0FEUI06AT
I01:BTX0;bl_0P12@T801`25QHD0IFEU05]KF`1YJFT0Lg=c05mOG`23Ph<00_ooool0000Y08B4Q02H
V9P0f=SH04a<C017AdL0I6AT079bLP36a/H0BDU902d];@1YJFT0[jn_0861P@33`l<0@41003@d=014
A4@0L71`06IVIP2MWId0TI6A03@d=00`<300ADE507AdM01]KFd0NWYj0820P00n?Sh0E5AD06EUI@2S
Xj<0D51@09nOW`0n?Sh0<S8b05mOG`1^KVh0Cdm?04U9B@1ZJVX00P0`<300:P1EEED0S8b<04e=C@0]
;Bd0B4Q803`l?00g=cL0Q8B409:BTP0_;bl0<c<c03De=@0T92@0=CDe09:BTP1WIfL07QhN03Hf=P0k
>c/0=3@d079bLP23Ph<08b<S02HV9P0k>c/0A4A4069RHP2GUiL0BDU902LW9`1ADE40GemO06m_K`24
Q8@0YJFU028R8P0H61P0A4A408B4Q01PH600^KVi06i^KP806a/K0?l0?Shn069RHP2QXJ40[Jf]03@d
=00T92@0;Rh^06IVIP1DE5@0KFe]09fMW@0Z:RX0;Bd]04Y:BP1ZJVX0NGUi0;2`/01UIFD0;Rh^03Lg
=`1bLW80GEeM06MWI`1`L700@d=303<c<`1CDe<0N7Qh0451@@1WIfL0HF5Q03/k>`0m?Cd0U9BD07al
O01>CTh0LW9b04I6AP0T92@0CTi>05UIF@1]KFd0BDU907IfMP0f=SH0?3`l08Z:RP2LW9`0EeMG04E5
A@1hN7P0:2PX03dm?@1IFET0SHf=04I6AP10@400G5aL02@T901IFET0LG5a08V9R@1ADE40B4Q806QX
J01EEED0LG5a09bLW01EEED08b<S05YJFP1BDU80GEeM0;jn_P1IFET09bLW06EUI@1ZJVX0C4a<0:b/
[029RHT0=CDe038b<P1MGEd0DE5A06EUI@38b<P0[:b/02LW9`0i>CT0KVi^07=cL`1ZJVX0b<S804i>
CP0f=SH0CTi>0:NWY`2n_[h0R8R80;no_`19BDT0C4a<06i^KP2UYJD0OWin0<o?c`2JVYX09bLW04E5
A@2>SXh0WYjN05mOG`3De=@0LG5a04M7A`0l?3`0NGUi07moO`1ZJVX0MgMg024Q8@11@D40N7Qh0:^[
Z`1DE5@0WYjN071`L00c<c<0?3`l0<?3``2LW9`0Ng]k07alO00c<c<0EeMG0861P@1RHV80D51@075a
L@0j>SX0?Shn08:2PP2XZ:P0DU9B061PH00`<300AdM70:VYZ@2b/[80@d=304M7A`1aLG40@41005UI
F@2SXj<0G5aL05IFEP1gMgL0=cLg06a/K02^[Zh0L71`0451@@1EEED0@d=3059BDP2k^k/0[Zj^0451
@@1?Cdl0Fe]K06QXJ02NWYh0`l?307moO`0n?Sh0C4a<05YJFP1FEUH0UIFE0;Ng]`1SHf<0<30`04m?
C`1gMgL0BTY:0;6a/@38b<P0DE5A03Ph>01:BTX0GUiN04Y:BP20P800/;2`034a<@0l?3`0Lg=c07em
O@1@D500QXJ60;Rh^00m?Cd0@d=30820P02e]KD0KVi^09NGU`2>SXh0<30`06YZJP1OGel0FUYJ04U9
B@1kNg/0=CDe03hn?P1^KVh0I6AT04I6AP15ADD0R8R803lo?`13@d<0Jf][0861P@1LG5`0De=C075a
L@0k>c/0Cdm?051@D01LG5`0Cdm?02h^;P1;Bd/0CDe=04Y:BP1DE5@0?Shn04=3@`16ATH0BDU903lo
?`0/;2`0EEEE08b<S01nOWh0IFEU04Q8B01YJFT0GUiN05UIF@15ADD002408R8R03Hf=P0h>3P0:BTY
02h^;P1:BTX0>SXj02@T9012@T80BTY:05mOG`16ATH09bLW03/k>`17AdL0C4a<0492@P0g=cL0EEEE
05ADE019BDT07alO03De=@14A4@0<C4a038b<P0l?3`0;Rh^03Ti>@0K6a/0<30`03<c<`17AdL00P0k
>c/0hP1;Bd/0:RXZ0410@00c<c<0BTY:05aLG00`<300A4A405mOG`1ZJVX0DU9B04A4A01FEUH0GEeM
04U9B@1FEUH0FEUI03/k>`2WYjL0IfMW04Q8B01BDU80Ng]k05mOG`1bLW80@41004e=C@1UIFD0LG5a
08Z:RP14A4@0DE5A05=CD`0b<S80DU9B04=3@`1>CTh0=cLg03Xj>P1PH600?clo03Ti>@1>CTh0>CTi
051@D00^;Rh0D51@04e=C@1BDU80@T9205IFEP0b<S80@T9203Hf=P14A4@0CDe=075aL@15ADD0E5AD
04m?C`1eMGD0EEEE06MWI`1aLG40XJ6Q04];B`1@D500FEUI061PH01lO7`0Hf=S06e]K@1;Bd/0JFUY
06EUI@14A4@0Bd];04E5A@1aLG40ADE505=CD`1IFET0IFEU04A4A02>SXh0/;2`06e]K@3Cdm<0GUiN
055AD@1=CDd0?3`l06a/K013@d<0JFUY0;:b/P16ATH0GEeM06=SH`14A4@0DE5A05eMG@1GEeL0F5QH
06EUI@1QHF40E5AD0492@P1lO7`0X:2P04a<C018B4P0@d=307inOP18B4P0EEEE05eMG@12@T80M7Ad
08N7Q`10@400ZZZZ0=cLg01NGUh0BDU904a<C018B4P0H61P04Y:BP1VIVH0=CDe05iNGP1IFET0<S8b
09^KV`1LG5`07alO05aLG01BDU80>CTi055AD@0[:b/0@D5103Ph>01SHf<0H61P04E5A@1EEED0RXZ:
0=oOg`1/K6`0<30`03@d=00f=SH0Fe]K07MgM`15ADD0Lg=c07UiN@0m?Cd0DU9B055AD@13@d<0ATI6
03`l?01=CDd0>3Ph06i^KP1BDU80EUIF03dm?@1WIfL0B4Q805EEE@1fMWH0>3Ph03Lg=`16ATH0@T92
02TY:@0o?cl05QHF065QH@0n?Sh0ATI605=CD`1BDU80KFe]03Xj>P1:BTX0JVYZ03Xj>P1<C4`0@d=3
02DU9@1mOGd0ADE5034a<@1;Bd/08B4Q06YZJP15ADD0ATI6059BDP0I6AT0CDe=04I6AP1UIFD0Cdm?
05EEE@1RHV80Hf=S07MgM`1>CTh0GUiN05UIF@0X:2P0@T9204Q8B00g=cL0@4100492@P10@400Ph>3
0451@@14A4@202LW9`80EUIF01l0MWIf06IVIP3AdM40HV9R075aL@1IFET0ADE50:>SX`1SHf<0IVIV
07MgM`0b<S80GEeM051@D00i>CT0K6a/03dm?@1BDU80ADE505YJFP1QHF40ATI604Y:BP0j>SX0PH61
05eMG@1`L700Ng]k061PH01kNg/0QHF500;ooooo0000U01[Jf/0IVIV08:2PP1eMGD0Lg=c04U9B@15
ADD0IVIV08^;R`0i>CT0EeMG03dm?@0g=cL0OWin09RHV00a<C40DU9B04=3@`0];Bd0Bd];09BDU01=
CDd08b<S05EEE@1`L700=SHf05YJFP1kNg/0=cLg02XZ:P12@T80KVi^08F5Q@2>SXh0A4A401DE5@0m
?Cd0Hf=S08F5Q@22PX80^[Zj065QH@0K6a/0C4a<04i>CP1JFUX0EUIF08R8R010@400820P04M7A`1P
H600M7Ad075aL@25QHD08B4Q034a<@1@D500Ogmo05YJFP2GUiL0<C4a02d];@1HF5P0I6AT051@D01Y
JFT0KFe]01hN7P0e=CD0FEUI07inOP19BDT0a<C408:2PP0S8b<0@D5107EeM@1MGEd0@T92059BDP0S
8b<0<C4a06ATI02OWil0?3`l0492@P0h>3P09bLW04U9B@1kNg/0MgMg02`/;00n?Sh0@d=302h^;P12
@T80P82006QXJ00a<C40>CTi03<c<`1JFUX0QHF5069RHP0O7al0=3@d03Ti>@0b<S80D51@09NGU`18
B4P08B4Q034a<@1MGEd0>SXj08B4Q02FUYH0>SXj02LW9`1>CTh0H61P04];B`2CTi<0GUiN02/[:`0]
;Bd0JFUY07YjNP1]KFd0/k>c0410@00a<C40AdM706=SH`1NGUh0W9bL0:VYZ@0`<300ADE504];B`20
P800PH6109VIV@3>c/h0?Cdm04I6AP1^KVh208^;R`2n0:VYZ@2g]kL0;bl_06=SH`2GUiL0WinO06EU
I@2YZJT0Shn?03`l?02GUiL0Vi^K06a/K02UYJD0=3@d02/[:`1>CTh0[:b/07=cL`26QXH0J6QX03Hf
=P11@D40Hf=S0;bl_01_Kfl0PH6108F5Q@0U9BD0B4Q808b<S02[Zj/0A4A4075aL@1OGel0<30`06MW
I`2_[jl0KVi^04=3@`1eMGD0C4a<03De=@1YJFT0[Zj^05iNGP0n?Sh0J6QX03Ph>014A4@0T92@09BD
U00f=SH0X:2P07]kN`1TI6@0LW9b09:BTP15ADD0;Rh^05EEE@1>CTh0EUIF0;Jf]P2<S8`0;bl_04E5
A@1RHV80Lg=c08j>SP2k^k/0>3Ph03`l?01_Kfl0EUIF07YjNP35aLD0B4Q8024Q8@1NGUh0PX:207Mg
M`3<c<`0HV9R01dM7@1?Cdl0/;2`07moO`2?Shl0W9bL03`l?01:BTX0GemO06EUI@1hN7P0WIfM03@d
=00j>SX0SHf=08j>SP24Q8@0[Jf]055AD@14A4@0E5AD0:JVYP1aLG40OWin06e]K@0Q8B40?clo07Mg
M`2CTi<0Ng]k0:JVYP26QXH08B4Q04U9B@2i^KT0RXZ:05YJFP28R8P0DE5A02/[:`0f=SH0RHV908b<
S018B4P0GEeM055AD@11@D40@d=307inOP1^KVh0;Bd]06i^KP1UIFD0CDe=07=cL`2[Zj/0Hf=S03Ph
>01PH600M7Ad05]KF`26QXH0Xj>S04];B`13@d<0Bd];03lo?`1ZJVX0OGem05YJFP0W9bL0C4a<06i^
KP1:BTX0H61P0:^[Z`1UIFD0820P038b<P1/K6`0IFEU06i^KP2_[jl0>CTi034a<@1FEUH0J6QX06m_
K`16ATH0PX:205=CD`1>CTh0Jf][03hn?P1UIFD0C4a<05]KF`14A4@0?Cdm05EEE@1OGel0KFe]06AT
I01DE5@0NWYj04M7A`80ADE502X0<30`04i>CP0l?3`0@D5102XZ:P1ADE40D51@03lo?`15ADD0IVIV
05YJFP1YJFT0B4Q804E5A@1DE5@0HV9R061PH01IFET0JVYZ05UIF@1jNWX0ATI604U9B@1RHV80BDU9
04e=C@1>CTh0?clo059BDP0e=CD0Cdm?04Q8B01IFET0ADE503De=@1ADE40<30`0451@@0Z:RX09bLW
03Ti>@0];Bd203Xj>P3l03@d=00k>c/0>SXj051@D019BDT0?Cdm051@D01PH600A4A406MWI`1ADE40
?Shn0410@01`L700X:2P09:BTP15ADD0De=C03Ti>@0b<S80CTi>03Ph>00o?cl0CTi>01dM7@0b<S80
=3@d04];B`0O7al0;bl_05=CD`0^;Rh0@41003lo?`0j>SX0ATI603Hf=P0o?cl0Cdm?051@D01DE5@0
EUIF04U9B@18B4P0EEEE05]KF`1>CTh0LG5a05mOG`1XJ6P0BDU906a/K01lO7`0KFe]07emO@2PX:00
I6AT07emO@1cLg<0Fe]K07inOP27QhL0NWYj04I6AP1oOgl0GemO04Y:BP1RHV80De=C08V9R@1=CDd0
LW9b03Lg=`1DE5@0Hf=S0:ZZZP31`L40Shn?0=3@d01GEeL0PX:209FEU@1<C4`0N7Qh04E5A@1SHf<0
WIfM05ADE01PH600De=C04Y:BP1<C4`0HV9R05EEE@1CDe<0BTY:04E5A@1QHF40>3Ph07IfMP2i^KT0
?Cdm04Y:BP0I6AT0CTi>02h^;P1JFUX0NWYj0410@02QXJ40VYZJ038b<P25QHD0/k>c051@D01=CDd0
FEUI0451@@1VIVH0H61P0:FUY@0n?Sh0JFUY06EUI@12@T80IVIV055AD@12@T80Hf=S069RHP12@T80
K6a/02TY:@1NGUh0=CDe071`L01OGel0D51@0<G5a@1@D500GemO05QHF00d=3@0Bd];02`/;02HV9P0
][Jf04i>CP14A4@0D51@04Q8B01ZJVX0KFe]04I6AP14A4@0Hf=S06IVIP0d=3@0MGEe03Ti>@1CDe<0
>3Ph075aL@1ADE40=3@d03Xj>P16ATH0AdM704a<C00o?cl0<S8b055AD@0d=3@0G5aL03/k>`0d=3@0
?Cdm0451@@1ZJVX06a/K038b<P10@400:BTY04a<C017AdL0>CTi08^;R`1VIVH0>3Ph05EEE@0N7Qh0
?Cdm02PX:016ATH0Bd];01/K6`17AdL0=3@d04m?C`16ATH0DU9B07]kN`1JFUX0E5AD03Ti>@1MGEd0
F5QH0492@P2:RXX0KVi^03@d=01BDU80>3Ph03Hf=P1YJFT0<c<c05=CD`1<C4`0B4Q805IFEP0^;Rh0
F5QH05=CD`2=SHd0EeMG08F5Q@1BDU80BDU908n?S`1[Jf/0NWYj09jNWP1;Bd/0RHV906a/K00o?cl0
EEEE04e=C@1aLG40BTY:0451@@15ADD0?Shn05QHF00a<C40IfMW06ATI01WIfL0F5QH071`L01aLG40
MgMg0_ooool0000K0:6QX@1EEED0N7Qh06a/K02UYJD0EUIF04A4A01?Cdl0S8b<05IFEP2[Zj/0B4Q8
0410@00i>CT0Shn?05mOG`2DU9@0FUYJ03Xj>P1EEED0De=C0:2PX01eMGD0_Kfm07inOP0k>c/0>SXj
0080F5QH0?l0Ogmo0<_;b`0G5aL0=SHf04];B`1HF5P0@D5108:2PP1ADE409bLW04A4A01`L700JVYZ
02h^;P1ZJVX0LW9b01`L700n?Sh0EUIF07QhN00b<S80DU9B051@D00f=SH0IfMW061PH015ADD0:b/[
08>3P`0^;Rh0;Bd]08J6QP1RHV80820P03Hf=P1ADE40<c<c065QH@2KVi/0>CTi02`/;00c<c<0>CTi
03dm?@2:RXX0Kfm_028R8P0b<S80@D51079bLP1dM7@0Ti>C030`<00R8R80D51@07=cL`1UIFD0MWIf
05ADE00S8b<0>SXj07UiN@1hN7P0A4A408V9R@1^KVh04a<C03Ti>@1KFe/0GUiN06=SH`2>SXh071`L
03Lg=`1QHF40Ph>306=SH`2IVIT0GUiN02PX:00j>SX0JVYZ07inOP1YJFT0KVi^05=CD`0I6AT0Bd];
07alO01XJ6P0?Shn05mOG`0M7Ad0<c<c05eMG@2PX:00ATI605EEE@1BDU808B4Q03@d=01^KVh0XZ:R
04a<C01XJ6P0AdM7028R8P1@D500V9RH08B4Q01GEeL0PH61069RHP0];Bd0JVYZ06EUI@1WIfL0>CTi
05iNGP0g=cL0>3Ph05EEE@2RXZ80M7Ad03Ph>01FEUH0;2`/04Y:BP1MGEd0NWYj03De=@1@D500Cdm?
06UYJ@2LW9`0IVIV01lO7`0j>SX0IfMW06QXJ01gMgL0[Jf]030`<011@D40G5aL08^;R`1cLg<0W9bL
0=GEe@1PH600:RXZ06i^KP27QhL0MWIf0;Bd]025QHD0;Bd]04m?C`22PX80SHf=06a/K03:b/X0LW9b
038b<P13@d<0KVi^09:BTP2RXZ80g=cL03@d=00m?Cd0?Shn07]kN`1MGEd0`l?308F5Q@0Q8B40B4Q8
0861P@25QHD0GEeM07AdM00g=cL0?Cdm04M7A`20P800DU9B08>3P`1CDe<0:RXZ065QH@2<S8`0XJ6Q
07alO02@T9008b<S034a<@2c/k<0[Jf]05MGE`1VIVH0Hf=S0410@01dM7@0YZJV061PH01]KFd0@T92
04A4A01KFe/0QhN703Ti>@1=CDd0EeMG02@T901XJ6P0]kNg05QHF00n?Sh0Hf=S030`<011@D40Ng]k
04Q8B00/;2`0De=C05EEE@1SHf<0P82009BDU00j>SX0<S8b07EeM@1_Kfl0Lg=c09NGU`2/[:`092@T
038b<P1NGUh0JVYZ07emO@2^[Zh0Vi^K02d];@0h>3P0FEUI061PH023Ph<0ZJVY0:2PX00X:2P0AdM7
05iNGP1_Kfl000H0K6a/0;bl_01bLW80:b/[04Y:BP1GEeL209^KV`0E0;Jf]P1;Bd/0?Cdm04e=C@1`
L700EEEE08f=S@2FUYH0:BTY02d];@1aLG40RXZ:05ADE029RHT0Hf=S034a<@0/;2`0FUYJ0:6QX@1Q
HF40Jf][0080AdM702`0@d=308B4Q02a/K40H61P05aLG01UIFD0HF5Q04a<C020P800LG5a06i^KP1a
LG40Bd];07IfMP1JFUX0IVIV05EEE@1>CTh0K6a/09RHV02>SXh0Jf][055AD@1SHf<0G5aL05IFEP1U
IFD0=cLg0410@00b<S80AdM703Ph>01JFUX0BDU903hn?P18B4P0LW9b055AD@1SHf<0CDe=04];B`1A
DE40C4a<06=SH`80JFUY05X0@D5106][J`0f=SH0@41005IFEP16ATH0F5QH0451@@0X:2P0DE5A034a
<@1:BTX0;Bd]04e=C@12@T80?Cdm04U9B@0k>c/0Cdm?04=3@`0j>SX0Cdm?03hn?P19BDT0Hf=S0492
@P1=CDd0@D5105=CD`1GEeL0ATI606i^KP1aLG40KFe]08n?S`1JFUX0@D5104I6AP1^KVh0AdM705UI
F@14A4@0CDe=06=SH`0g=cL0O7al04];B`0o?cl0GEeM030`<00o?cl0@T9204];B`0Y:BT0<S8b05MG
E`0/;2`0=SHf03`l?00f=SH0?Shn02`/;012@T80AdM70410@00g=cL0?3`l038b<P14A4@0;2`/03hn
?P0d=3@0GemO02LW9`13@d<0=CDe05YJFP0o?cl0EEEE08J6QP2PX:00@D5104];B`1EEED0Hf=S071`
L01FEUH0IFEU05IFEP1fMWH204A4A00=04Y:BP0h>3P0L71`03Ph>01YJFT0?Cdm05QHF01GEeL0X:2P
0:BTY02?Shl0a/K603Lg=`0205aLG01904m?C`1XJ6P0@T9208V9R@2i^KT0A4A4055AD@1DE5@0IfMW
05=CD`1ADE40B4Q803Lg=`1;Bd/0BDU908J6QP1VIVH0Rh^;09RHV01IFET0JVYZ03dm?@1jNWX0=CDe
09nOW`2MWId0<30`07=cL`20P800ADE50;6a/@3?cll0GemO061PH01YJFT0DE5A05MGE`1OGel0KVi^
0492@P1MGEd0HF5Q03Xj>P20P800EeMG02/[:`1NGUh0EeMG06e]K@1oOgl0ADE506EUI@16ATH0HF5Q
06=SH`1bLW80];Bd05mOG`2BTY80GemO04M7A`1PH600=CDe06e]K@2;Rh/0<30`05ADE01@D500HF5Q
09>CT`1hN7P0A4A404E5A@020451@@0d038b<P1OGel0CTi>06QXJ00n?Sh0Bd];04e=C@1;Bd/0Cdm?
038b<P1DE5@0Fe]K03Hf=P0W9bL0=3@d028R8P1PH600EUIF04A4A010@400Bd];06m_K`0X:2P0>CTi
05EEE@0b<S80D51@04U9B@0^;Rh0NGUi03Hf=P11@D40Fe]K01/K6`1?Cdl08b<S04Q8B01@D500?3`l
04Y:BP0W9bL0AdM7051@D01:BTX0GUiN061PH01]KFd0@D5106UYJ@1>CTh0<30`03Xj>P80BDU902T0
I6AT04I6AP0e=CD0HF5Q0410@00n?Sh0:BTY02l_;`1:BTX0>3Ph05mOG`18B4P0U9BD04Y:BP1LG5`0
>c/k03hn?P2QXJ40DU9B05ADE01MGEd08B4Q06ATI01CDe<0<c<c05MGE`0o?cl0DE5A02h^;P13@d<0
B4Q803Xj>P1>CTh0BDU908>3P`1LG5`0N7Qh05MGE`1NGUh0Jf][07=cL`02ooooo`0000P0WIfM07Mg
M`2;Rh/0B4Q806EUI@1MGEd0@d=3061PH080?Cdm06L0IFEU05aLG00W9bL0F5QH03<c<`0a<C40F5QH
09ZJVP0l?3`0@D5104U9B@0d=3@0;Rh^069RHP2a/K40>c/k04Y:BP16ATH0>SXj05ADE01cLg<0G5aL
02DU9@0j>SX0<S8b06IVIP2XZ:P0HV9R01TI6@0Q8B40>c/k06UYJ@1DE5@0RXZ:0:j^[P0R8R805QHF
03lo?`1fMWH0EeMG08j>SP2JVYX07AdM04m?C`1TI6@0De=C06MWI`34a<@0B4Q801`L701KFe/0OGem
069RHP2DU9@0EUIF01lO7`0/;2`0C4a<06QXJ025QHD0WIfM02@T900];Bd0>SXj06ATI016ATH0G5aL
06ATI00U9BD0De=C05aLG017AdL0EUIF08N7Q`0l?3`0:RXZ03@d=019BDT0=3@d05IFEP1SHf<0;2`/
03<c<`0d=3@0MWIf04];B`0a<C40EEEE03@d=00Y:BT0G5aL0410@00X:2P0@D5103Ti>@0X:2P0DE5A
06QXJ00P8200;bl_03Xj>P18B4P0A4A40080UYJF02P08R8R03Hf=P1RHV80J6QX06=SH`28R8P0:2PX
01/K6`0_;bl0Lg=c05UIF@2CTi<0Ogmo02<S8`0U9BD0DE5A06a/K01PH600WinO06ATI00O7al0A4A4
04M7A`1PH600I6AT0:ZZZP2>SXh071`L05ADE01cLg<0I6AT07EeM@3:b/X0M7Ad038b<P16ATH0PX:2
09RHV01lO7`0YZJV0P0U9BD0h@2=SHd0TI6A07UiN@2o_kl0?Shn03Xj>P2:RXX0WIfM07EeM@2QXJ40
O7al04];B`1KFe/0Ng]k08f=S@1nOWh0WinO05UIF@0m?Cd0F5QH07EeM@2XZ:P0IfMW0;fm_@1EEED0
A4A405eMG@2QXJ40Fe]K07IfMP2FUYH0?clo0451@@1_Kfl0/;2`05QHF026QXH0O7al02TY:@1VIVH0
QhN707EeM@1>CTh0WinO03/k>`15ADD0OGem09fMW@0c<c<0@T9205iNGP0`<300NGUi0;^k^`1DE5@0
:RXZ061PH018B4P0@4100;6a/@2o_kl0@d=3030`<01PH600De=C0861P@2e]KD0:BTY02d];@1CDe<0
JFUY07IfMP2RXZ80GemO02/[:`1OGel0IFEU07AdM032`/80LW9b01PH601HF5P0QhN705ADE02ATI40
R8R802PX:00S8b<0H61P08N7Q`1iNGT0`/;203<c<`0j>SX0KFe]08V9R@1`L700/;2`07AdM00`<300
IfMW092@T02LW9`0P8200::RXP17AdL0BTY:07IfMP2j^[X0M7Ad09NGU`25QHD0=CDe04Q8B01HF5P0
LW9b06a/K01WIfL0/K6a034a<@10@400PH610820P01BDU80J6QX08R8R016ATH0;Rh^07EeM@34a<@0
DE5A05]KF`1GEeL09RHV059BDP27QhL0R8R803Hf=P1LG5`0CDe=0451@@1RHV80X:2P051@D00g=cL0
LW9b06MWI`1OGel0S8b<0861P@0^;Rh0<S8b04a<C01>CTh0J6QX0861P@1CDe<07alO02@T900o?cl0
CDe=05QHF01ADE40J6QX07=cL`1>CTh0N7Qh06i^KP1ZJVX0G5aL04A4A01<C4`0F5QH05YJFP0i>CT0
=CDe05mOG`1PH600LG5a06ATI01ADE40K6a/05IFEP1GEeL0CTi>02LW9`19BDT0@d=30410@00m?Cd0
I6AT04e=C@11@D40DE5A05mOG`1iNGT0JFUY04Y:BP1JFUX0G5aL06MWI`1EEED0I6AT061PH01GEeL0
Fe]K03<c<`13@d<0DE5A04i>CP1HF5P0ATI603Xj>P10@400>c/k04M7A`0d=3@0JFUY03dm?@1CDe<0
EeMG02l_;`1:BTX09bLW02`/;00203Ph>00M04];B`1IFET0BDU905IFEP17AdL0Cdm?05IFEP1EEED0
Cdm?07UiN@1NGUh0XZ:R06IVIP1<C4`0G5aL08j>SP1/K6`0NWYj04U9B@1GEeL0OGem05UIF@29RHT0
E5AD059BDP1KFe/0AdM704i>CP10@4000P1<C4`0401BDU80DE5A03/k>`17AdL0Bd];04A4A01<C4`0
>CTi05ADE01=CDd0C4a<04U9B@1=CDd0?Shn04Y:BP0i>CT205QHF00n06EUI@1?Cdl0Fe]K05EEE@1H
F5P0L71`07emO@1/K6`0PH6106MWI`1IFET0NWYj05ADE02:RXX0L71`08n?S`1aLG40EUIF065QH@1<
C4`0E5AD07QhN01_Kfl0@D5107YjNP1DE5@0HF5Q03@d=01oOgl0K6a/08b<S038b<P0>CTi07YjNP28
R8P0Hf=S07emO@12@T80RXZ:096AT@17AdL0Jf][03<c<`0m?Cd0=3@d04m?C`1dM7@0G5aL04U9B@0a
<C40De=C03<c<`1NGUh0MWIf0410@01CDe<0<S8b06YZJP0i>CT0N7Qh08j>SP0N7Qh208Z:RP1H02l_
;`2QXJ40`l?3059BDP1OGel0H61P051@D01^KVh0HV9R096AT@11@D40GUiN05ADE00`<300GUiN04E5
A@0a<C40FUYJ06UYJ@19BDT0Ph>303lo?`1GEeL0@D5106i^KP1EEED0GemO09NGU`1>CTh0Xj>S07If
MP10@400@d=3038b<P1dM7@0Lg=c02<S8`1GEeL0BTY:02XZ:P1KFe/0GEeM04i>CP1?Cdl0G5aL06YZ
JP15ADD0Jf][0451@@1NGUh0;bl_05ADE01:BTX0C4a<05]KF`0e=CD0>CTi04=3@`0b<S80<30`04A4
A00^;Rh0BDU90410@00o?cl0Cdm?055AD@1`L700>SXj03Ti>@1LG5`0?Shn04];B`19BDT0@d=3096A
T@1:BTX0>SXj04e=C@13@d<0FUYJ03@d=014A4@0De=C02h^;P12@T80<30`04M7A`80BTY:01d0Fe]K
04=3@`1=CDd0Bd];05aLG017AdL0@T9204];B`1?Cdl0@D5104m?C`14A4@0BDU907]kN`0Z:RX0?Shn
03Ph>00e=CD0A4A404=3@`22PX80G5aL0:n_[`1>CTh0[jn_06][J`12@T80OWin05]KF`0205=CD`0D
03Ph>01aLG40D51@05EEE@1WIfL0Cdm?05mOG`17AdL0DE5A06UYJ@15ADD0BTY:04E5A@1eMGD0E5AD
06=SH`1XJ6P0EUIF06a/K02;Rh/2ooooo`000680JFUY07MgM`2c/k<0EUIF06ATI01YJFT0Fe]K08N7
Q`10@400<S8b05]KF`27QhL0Kfm_0:n_[`14A4@0=SHf03dm?@1YJFT0FEUI07EeM@1jNWX07QhN03lo
?`0i>CT0Ogmo06a/K02ZZZX0RXZ:020P8013@d<0GemO07alO01TI6@0YZJV02TY:@0S8b<0GEeM07Ad
M01:BTX0JVYZ0:ZZZP0^;Rh09bLW04e=C@1EEED0FEUI05ADE01YJFT09BDU03<c<`1JFUX0Kfm_04Y:
BP14A4@0@d=301lO7`1/K6`0b<S809RHV00];Bd0D51@02LW9`0P8200FEUI08R8R017AdL0<C4a03@d
=00e=CD0BTY:069RHP16ATH08R8R04i>CP0l?3`0BTY:06EUI@2@T900:RXZ01lO7`1DE5@0@T9205UI
F@2PX:00QXJ602<S8`14A4@0>CTi05=CD`1cLg<0Vi^K04E5A@0^;Rh0<30`04I6AP1SHf<0MWIf09>C
T`809BDU02<0=SHf06UYJ@1[Jf/0XZ:R04i>CP0Q8B40AdM704i>CP0f=SH0MgMg059BDP0Q8B40820P
059BDP2VYZH0RXZ:07alO02BTY8092@T03hn?P1oOgl0KFe]05IFEP1TI6@08B4Q02`/;01HF5P0ZJVY
06][J`1WIfL0EUIF03De=@0a<C40Cdm?09JFUP020410@02I04i>CP0M7Ad0ATI6075aL@2<S8`0DE5A
04e=C@1TI6@0=SHf04e=C@1fMWH0[Zj^04=3@`10@400EeMG04I6AP0h>3P0MgMg08F5Q@0j>SX0Hf=S
069RHP0l?3`0VIVI04U9B@0j>SX0FUYJ03Xj>P18B4P0LG5a09VIV@0`<300@41003Xj>P13@d<0F5QH
0;>c/`2MWId0<S8b04I6AP1HF5P0E5AD07YjNP3=cLd0FUYJ03Lg=`1RHV80D51@04m?C`23Ph<0gMgM
07YjNP0W9bL0IFEU09^KV`1LG5`0Shn?0;^k^`0m?Cd0;Rh^07inOP2YZJT0J6QX0<G5a@1DE5@0>CTi
055AD@2QXJ40EUIF09>CT`2DU9@08b<S0492@P2ATI40NWYj09:BTP34a<@0KFe]02HV9P1dM7@0cLg=
0;2`/02YZJT0J6QX02LW9`1OGel0Ogmo05EEE@1MGEd0P82003Hf=P17AdL0PH6109bLW014A4@0Lg=c
02<S8`0_;bl0RXZ:0;Rh^01EEED0O7al0820P00[:b/0@D510:>SX`1UIFD0EeMG05QHF00`<300@D51
07]kN`1eMGD0@4100:6QX@0/;2`0BTY:0:>SX`1kNg/0=cLg04Y:BP1FEUH0BTY:05mOG`2ATI40EUIF
03hn?P1`L700BDU90451@@2PX:00[jn_02l_;`0Z:RX0C4a<055AD@0e=CD0NGUi0;no_`1GEeL07alO
059BDP2<S8`0De=C07alO02h^;P0?Cdm03<c<`1OGel0OWin05eMG@28R8P0Ti>C0080<C4a0?l0MWIf
0:RXZ016ATH0P82006=SH`0U9BD0@d=3096AT@21PH40G5aL0;bl_01IFET0<C4a04Y:BP2FUYH0PX:2
05mOG`2DU9@08R8R01dM7@1ADE40XZ:R059BDP1=CDd0H61P03dm?@0j>SX0EeMG06YZJP1NGUh0B4Q8
061PH01GEeL0De=C061PH00f=SH0J6QX059BDP1UIFD0ATI603`l?01]KFd0PH6109FEU@1iNGT0@d=3
08J6QP1EEED0FEUI05]KF`0K6a/0@D5102XZ:P0i>CT0:BTY04Q8B016ATH08R8R04=3@`1WIfL0DU9B
06=SH`15ADD0BTY:04];B`1?Cdl0EEEE04Y:BP1GEeL0CDe=065QH@0g=cL0AdM7055AD@10@400BDU9
04E5A@11@D40?Cdm02XZ:P0i>CT0>c/k05aLG00j>SX0?Cdm03@d=016ATH0EEEE028R8P1ADE40BDU9
03Xj>P1:BTX0@D510410@01?Cdl0DE5A06YZJP1>CTh0C4a<05=CD`1]KFd0JFUY09bLW01BDU80@D51
055AD@1eMGD0SXj>09ZJVP1QHF40JVYZ05MGE`0h>3P0HV9R038b<P0g=cL0EeMG02LW9`11@D40=SHf
04a<C00/;2`0A4A405]KF`10@400AdM703lo?`15ADD0HF5Q04U9B@1;Bd/0DU9B06EUI@1>CTh0Bd];
04I6AP17AdL0GEeM06EUI@16ATH0FEUI04];B`1MGEd0>CTi05ADE01jNWX0IVIV07moO`2UYJD0DU9B
06a/K019BDT0E5AD07IfMP1cLg<0^;Rh06QXJ01SHf<0P820061PH01UIFD0ADE506IVIP1[Jf/0R8R8
08V9R@2IVIT0TY:B0<[:bP2/[:`0_;bl0=KFeP1RHV80`L710:^[Z`1SHf<0HF5Q05MGE`2JVYX0Rh^;
03`l?01<C4`0<c<c06EUI@0f=SH0Cdm?055AD@0d=3@0FEUI03/k>`1jNWX0AdM708:2PP1oOgl0GUiN
07]kN`0j>SX0G5aL03Lg=`24Q8@0NWYj03/k>`1MGEd0Lg=c02l_;`31`L40fMWI06i^KP1>CTh0I6AT
06YZJP1jNWX0JFUY09ZJVP0n?Sh0QhN705IFEP0[:b/0GUiN05QHF00a<C40GemO059BDP1LG5`0SHf=
0451@@1SHf<0B4Q8069RHP1EEED0JFUY0;:b/P1IFET0S8b<07moO`15ADD0C4a<04I6AP2>SXh0Shn?
04m?C`1OGel0EeMG04Y:BP2<S8`0HV9R03lo?`12@T80CTi>05ADE015ADD0RHV904Q8B01GEeL00180
?Shn08B4Q01TI6@0ADE5051@D01ADE40Bd];04M7A`13@d<0>c/k04E5A@0j>SX0FEUI05=CD`1:BTX0
Cdm?04i>CP1gMgL202l_;`0J055AD@0i>CT0DU9B03Lg=`0i>CT0KVi^03<c<`0o?cl0@41002@T901>
CTh0=CDe04M7A`1EEED0;Rh^03Lg=`0i>CT0K6a/03Ti>@17AdL0I6AT04U9B@1BDU80>3Ph06MWI`1U
IFD204Q8B00E05iNGP15ADD0EeMG03Xj>P14A4@0G5aL03Hf=P12@T80?clo038b<P16ATH0;Rh^04a<
C01jNWX0UIFE05mOG`1GEeL0AdM706a/K02@T900MGEe0080V9RH00P0EEEE07AdM01=CDd0HV9R079b
LP1oOgl0N7Qh0492@P80Fe]K00X0Bd];05aLG01PH600S8b<05IFEP1QHF40De=C06m_K`1eMGD0L71`
0_ooool0001h09>CT`1SHf<0U9BD06e]K@2BTY80DE5A04e=C@1VIVH0Kfm_05EEE@2?Shl0@T9203@d
=01bLW80KVi^03`l?01FEUH0<c<c03@d=00o?cl0L71`061PH00W9bL0JFUY03lo?`1;Bd/0GEeM075a
L@0R8R80@T92065QH@1=CDd0HV9R08Z:RP1>CTh061PH03Hf=P1KFe/0<c<c08>3P`2e]KD0C4a<01HF
5P0k>c/0JVYZ05]KF`1IFET0WinO06IVIP0G5aL0@D5106UYJ@1UIFD0Ph>308F5Q@0T92@09RHV05QH
F02YZJT0De=C0:n_[`1=CDd09bLW04=3@`1PH600IVIV07MgM`1PH60061PH04i>CP1PH600EEEE04i>
CP2g]kL0KVi^02<S8`14A4@0LG5a05YJFP1YJFT0WYjN02d];@0i>CT0Fe]K08N7Q`1JFUX0Lg=c030`
<00U9BD0ATI607AdM02BTY80Fe]K06e]K@0n?Sh06ATI0492@P1lO7`0NGUi034a<@1aLG407AdM02LW
9`1SHf<0QHF5034a<@10@400?Cdm02<S8`1;Bd/0N7Qh06QXJ01ADE40K6a/05eMG@0O7al0G5aL0:6Q
X@0m?Cd0<c<c0P0n?Sh01@1MGEd0Ng]k04Y:BP0M7Ad0;bl_0080CDe=00L0KFe]0861P@0b<S80:b/[
03/k>`1XJ6P0GEeM0080U9BD02H092@T02<S8`1@D500IfMW05ADE029RHT0Y:BT02l_;`0`<300@d=3
08Z:RP1SHf<0RHV908j>SP0W9bL0BDU904];B`1VIVH0FUYJ0;Rh^01_Kfl0?clo069RHP24Q8@0OGem
0;Vi^@11@D40>3Ph079bLP2IVIT0H61P07=cL`1IFET0>c/k04A4A01fMWH0/;2`06UYJ@80T92@02D0
<c<c04=3@`1oOgl0/K6a04];B`26QXH0@T9203Xj>P1;Bd/0TY:B0=cLg01PH600Ti>C04A4A00f=SH0
ATI607MgM`2JVYX0MGEe096AT@0a<C40CTi>05=CD`1]KFd0>SXj07MgM`1RHV80@41006e]K@2g]kL0
QhN704i>CP1kNg/0@d=304];B`2SXj<0]kNg0080?clo0:@0Hf=S06EUI@28R8P0[:b/03<c<`0f=SH0
JFUY04i>CP1_Kfl0a/K608^;R`0`<300AdM706YZJP1jNWX0Y:BT05iNGP0[:b/0E5AD04U9B@1HF5P0
^[Zj08f=S@0[:b/0<C4a05iNGP1]KFd0UiNG0:n_[`0[:b/0BTY:075aL@1OGel0P8200<c<c01^KVh0
8B4Q071`L02^[Zh0Ng]k0:BTY029RHT0ATI605IFEP20P800SXj>07=cL`2;Rh/0D51@02h^;P0g=cL0
Zj^[09RHV01/K6`0Y:BT07UiN@0b<S80;Bd]08>3P`2?Shl0HF5Q06][J`1NGUh0:RXZ03lo?`2LW9`0
ZJVY04Q8B01fMWH0?3`l02PX:018B4P0QhN704Y:BP15ADD0JFUY0492@P0k>c/0Kfm_09^KV`1;Bd/0
G5aL04e=C@0f=SH0<C4a04m?C`25QHD0@d=304];B`1_Kfl0;Rh^06UYJ@2l_;`0O7al0492@P11@D40
?3`l05ADE01=CDd0WinO08N7Q`12@T80Jf][06m_K`1]KFd0?Cdm08n?S`1]KFd0IVIV07YjNP15ADD0
NGUi05IFEP1SHf<0AdM703/k>`1cLg<0Ng]k08Z:RP2DU9@0G5aL08R8R01DE5@0GUiN05eMG@0Y:BT0
Cdm?04I6AP18B4P0>c/k05=CD`1DE5@0:RXZ0451@@1oOgl0P82008F5Q@1?Cdl0H61P071`L01JFUX0
H61P04Y:BP1cLg<0FUYJ07inOP0Y:BT0BTY:05MGE`10@400FEUI04A4A00o?cl0BDU902HV9P1<C4`0
<S8b06ATI00m?Cd0>SXj038b<P0];Bd0BTY:02TY:@80=SHf06P0BTY:05QHF00k>c/0CTi>04U9B@14
A4@0EEEE04M7A`1QHF40ADE506i^KP1fMWH0YJFU03lo?`1<C4`0G5aL05QHF01<C4`0F5QH03De=@1;
Bd/0IVIV038b<P1nOWh0?clo04A4A01fMWH0<c<c04A4A00g=cL0CTi>02`/;00k>c/0E5AD03<c<`11
@D40;bl_04e=C@0b<S80=cLg03Ph>01?Cdl0<C4a0451@@0f=SH0@T9204E5A@0W9bL0C4a<03Ti>@1C
De<0:BTY04E5A@0^;Rh0De=C05IFEP19BDT0TI6A09JFUP1>CTh0GUiN03lo?`1^KVh0N7Qh06EUI@1j
NWX0LG5a08F5Q@1GEeL0?Cdm04Y:BP0`<300Cdm?03lo?`1mOGd0>3Ph06QXJ015ADD0hn?S08V9R@3<
c<`0`L7105IFEP2JVYX0P820071`L027QhL0@D5106YZJP1kNg/0M7Ad071`L00T92@0Bd];04M7A`0n
?Sh0FEUI04m?C`15ADD0<c<c05]KF`0j>SX0MWIf08R8R080AdM70300=3@d06MWI`0e=CD0T92@0861
P@0k>c/0Lg=c07MgM`1JFUX0O7al08^;R`1NGUh0K6a/06IVIP1GEeL0Hf=S06QXJ029RHT0>3Ph07Ee
M@1CDe<0@T9207=cL`1=CDd0EEEE08V9R@1CDe<0Fe]K08Z:RP1?Cdl0GemO03Lg=`1/K6`0EeMG07=c
L`2VYZH0ADE509BDU01cLg<0KVi^08n?S`0`<300I6AT05QHF01DE5@0T92@07MgM`1CDe<205IFEP0B
05eMG@1IFET0Cdm?04a<C00/;2`0IFEU04I6AP1LG5`09bLW04a<C011@D40ADE504i>CP0m?Cd0FEUI
05aLG00g=cL0;2`/0P0o?cl0<01[Jf/0CDe=03hn?P1PH600F5QH06i^KP12@T80BTY:051@D00k>c/0
Jf][04A4A00_;bl0J6QX02XZ:P1VIVH0F5QH02@T901>CTh06a/K065QH@1DE5@08b<S03/k>`0g=cL0
D51@04=3@`0o?cl0EeMG03De=@19BDT0>SXj07]kN`1MGEd0:RXZ04=3@`0e=CD0@D5106YZJP18B4P0
CDe=05UIF@0f=SH0OGem04Y:BP10@400?Shn034a<@80De=C00P0S8b<03Xj>P1bLW80Fe]K061PH02F
UYH0Bd];04Y:BP80C4a<01<0MWIf051@D019BDT0FEUI05YJFP1TI6@0HV9R06EUI@1YJFT0A4A404i>
CP1;Bd/0Jf][04Q8B01EEED0OWin055AD@1EEED0Vi^K00;ooooo0000=`2JVYX0Bd];05MGE`1BDU80
WinO05QHF00h>3P0BTY:05mOG`1SHf<0_[jn0410@00`<300>3Ph05IFEP1YJFT0Vi^K03/k>`0T92@0
?Cdm05EEE@1MGEd0K6a/0<G5a@17AdL0:RXZ07EeM@1^KVh0A4A40:b/[03QhN40<S8b0451@@1oOgl0
Jf][04i>CP2_[jl0EEEE01PH600e=CD0HV9R06UYJ@1]KFd0YZJV096AT@0I6AT0;bl_03dm?@1bLW80
EEEE06IVIP1EEED07alO0410@01HF5P00P0l?3`08P1XJ6P0;Bd]03Ph>01>CTh0HF5Q03Ph>01MGEd0
H61P02d];@1@D500UiNG05mOG`1KFe/0GUiN04i>CP0k>c/0N7Qh08j>SP0g=cL0?Shn04A4A00o?cl0
?Cdm08^;R`16ATH08R8R04E5A@0l?3`0@d=307alO01WIfL0820P02`/;01:BTX207YjNP3o07=cL`1H
F5P06QXJ02LW9`18B4P0K6a/04=3@`2YZJT09bLW01/K6`0a<C40JVYZ05IFEP1iNGT0Hf=S01TI6@0a
<C40B4Q80:2PX024Q8@0/[:b04E5A@0Y:BT0CDe=06=SH`1TI6@0MWIf08N7Q`0P8200?3`l06EUI@2>
SXh0CTi>06m_K`15ADD09BDU03/k>`22PX80ZJVY05IFEP1EEED0=cLg03<c<`1JFUX0GemO04M7A`0f
=SH0Lg=c03lo?`0R8R80Cdm?07alO021PH40Fe]K09FEU@1KFe/0@D5104Q8B01[Jf/0De=C03hn?P1=
CDd08R8R03De=@1KFe/0P820051@D01UIFD09BDU05eMG@1IFET0JFUY03Ph>01kNg/0FEUI04m?C`2P
X:00MGEe04M7A`1DE5@0IfMW04A4A01`L700Ogmo08f=S@0j>SX0=CDe05eMG@1cLg<0PX:209nOW`1S
Hf<0<30`03hn?P1@D500T92@08N7Q`2[Zj/0OGem034a<@1@D500E5AD061PH02WYjL0f=SH03`l?012
@T80OWin08^;R`1OGel0VYZJ08J6QP0M7Ad0D51@09bLW028R8P0[:b/0:VYZ@0o?cl0<S8b05YJFP2O
Wil0SXj>0<W9b@2DU9@0ATI605mOG`22PX80NWYj09fMW@2IVIT06ATI03Ph>01TI6@0OGem08F5Q@2K
Vi/0>c/k05=CD`2:RXX0QXJ605QHF02HV9P0@d=302<S8`1mOGd0a<C406e]K@1^KVh0IFEU02TY:@1:
BTX0WYjN08>3P`1QHF40JFUY028R8P0n?Sh0Lg=c0;Vi^@1YJFT0LW9b0451@@0a<C40HF5Q079bLP11
@D40DU9B08F5Q@0f=SH0Cdm?0:6QX@27QhL0<30`04M7A`0g=cL0GEeM04E5A@2EUID0YZJV05ADE018
B4P0>SXj04E5A@1>CTh0QHF50:NWY`0g=cL0;Bd]061PH01ZJVX0E5AD0;6a/@1NGUh092@T03Xj>P1i
NGT0IVIV07MgM`2m_Kd0@410034a<@0j>SX0Lg=c05QHF02SXj<0WYjN038b<P0i>CT0@d=3096AT@1P
H600NWYj08n?S`0N7Qh0@T9208:2PP1TI6@0ATI60:RXZ01WIfL0=3@d03<c<`1`L700_;bl06ATI01W
IfL0O7al07=cL`1MGEd0NWYj069RHP1SHf<0NGUi06m_K`1VIVH0G5aL05EEE@1_Kfl0Jf][07]kN`2@
T900K6a/08n?S`1SHf<0HV9R05MGE`1HF5P0Hf=S03Lg=`13@d<0<30`05=CD`0o?cl0IfMW001905=C
D`1bLW80JFUY05iNGP1jNWX0E5AD04M7A`1ADE40GEeM06=SH`1`L700MWIf06m_K`1GEeL0Fe]K02h^
;P1<C4`0CTi>05QHF01IFET0@41003hn?P0f=SH0@d=303hn?P0_;bl0HF5Q04Q8B01bLW80=CDe03<c
<`1DE5@08b<S04];B`1JFUX0>SXj04i>CP10@400CTi>04U9B@1RHV80JVYZ04M7A`1ZJVX0EeMG05QH
F01RHV80S8b<03dm?@16ATH0HF5Q05iNGP1GEeL0HF5Q03lo?`1IFET0=SHf03Ph>01gMgL0>CTi04=3
@`1LG5`09bLW04Y:BP0h>3P0E5AD03Ti>@1=CDd0J6QX03Ti>@13@d<0;bl_03Xj>P0202l_;`1>03Lg
=`1SHf<0=CDe04A4A00m?Cd0B4Q805EEE@0X:2P0H61P04M7A`1UIFD0>3Ph055AD@0f=SH0DU9B05eM
G@1QHF40Shn?08N7Q`1?Cdl0GemO03lo?`1GEeL0L71`07inOP2[Zj/0GEeM06MWI`1ZJVX0Cdm?055A
D@1>CTh0Fe]K03De=@1TI6@09RHV05YJFP0I6AT0S8b<069RHP39bLT0ZJVY04Y:BP2IVIT0Fe]K07Ee
M@25QHD0@T9206MWI`0_;bl0>3Ph05YJFP1=CDd0HV9R04I6AP0l?3`0G5aL0492@P18B4P0=3@d07in
OP0m?Cd0S8b<07alO01CDe<0EEEE03Xj>P1NGUh0=3@d0:RXZ02ATI404a<C065QH@1/K6`0>3Ph0<71
`@3:b/X0Bd];0P10@400I@1DE5@0FUYJ05mOG`1gMgL09bLW08f=S@1;Bd/0<c<c05UIF@0j>SX0=CDe
05aLG011@D40LW9b08:2PP1BDU80HV9R03/k>`1JFUX0>3Ph08Z:RP2YZJT0FEUI0:n_[`1eMGD0ADE5
04a<C00T92@0JFUY05MGE`0/;2`0De=C03hn?P0a<C40FUYJ03/k>`1<C4`0BDU905MGE`1>CTh0>SXj
07=cL`0e=CD0E5AD02PX:01_Kfl0CDe=04m?C`1MGEd0A4A404E5A@1VIVH0BTY:030`<00g=cL0>CTi
03hn?P1>CTh0=cLg04I6AP19BDT0HV9R02TY:@0];Bd0H61P038b<P16ATH0=3@d03/k>`1[Jf/0<c<c
04Q8B00_;bl0?Cdm04m?C`14A4@0DE5A04m?C`0_;bl0=CDe02l_;`1;Bd/0=SHf03`l?01TI6@0DU9B
05IFEP0o?cl0IVIV06][J`1?Cdl0@d=304Y:BP1jNWX0WinO06m_K`1PH600FEUI03Lg=`1BDU80;2`/
0080@d=301H0DU9B069RHP1DE5@0P8200410@02NWYh0MgMg05=CD`1[Jf/08R8R05eMG@14A4@0:BTY
05mOG`0c<c<0AdM704m?C`1;Bd/0G5aL03Xj>P1JFUX0?Shn0P15ADD02012@T80Ogmo04I6AP1IFET0
JVYZ051@D01LG5`0NGUi0_ooool0003o07EeM@1fMWH0JFUY051@D01>CTh0PH6105]KF`2=SHd0<S8b
04m?C`1]KFd0L71`04m?C`1RHV80=SHf02h^;P1RHV80ZJVY04Y:BP0m?Cd0?3`l02l_;`0o?cl0KVi^
08B4Q01:BTX0E5AD03Hf=P0E5AD0:b/[07inOP1lO7`0@D5105YJFP0];Bd08b<S05aLG021PH40:BTY
03@d=01>CTh0;Rh^03/k>`1CDe<0TI6A03lo?`0V9RH0De=C03`l?01LG5`0Xj>S06i^KP0H61P0;bl_
04E5A@0e=CD0F5QH09^KV`1JFUX0:RXZ04Y:BP0n?Sh0>3Ph09FEU@2@T900:RXZ03dm?@14A4@0EUIF
07emO@2][Jd09bLW03<c<`19BDT0EUIF05QHF02EUID0YJFU01lO7`0X:2P0E5AD06][J`1]KFd0c<c<
06ATI00T92@0FUYJ0=7Ad@1]KFd0P82009JFUP0P8200ATI604=3@`1MGEd0CTi>0820P01ZJVX061PH
04I6AP1VIVH0K6a/04=3@`1iNGT0<30`03De=@1?Cdl0EeMG02TY:@1<C4`0FEUI01XJ6P0n?Sh0JVYZ
06UYJ@0k>c/0FEUI05YJFP0j>SX0AdM7079bLP15ADD0<c<c04A4A00c<c<0BDU905=CD`1TI6@09RHV
02XZ:P0j>SX0?3`l061PH01kNg/0Jf][028R8P11@D40CDe=05mOG`1?Cdl0Vi^K08>3P`0S8b<0<C4a
05eMG@1?Cdl0G5aL07moO`2KVi/0>CTi06EUI@1[Jf/0D51@09RHV02<S8`0:RXZ02LW9`1eMGD0EeMG
08V9R@2GUiL0;bl_04Y:BP1EEED0I6AT05MGE`3Ogml0Zj^[024Q8@1JFUX0[Zj^08>3P`2YZJT0emOG
05QHF00_;bl0J6QX08R8R027QhL0P8200<S8b01PH600@d=308b<S02TY:@0IfMW09fMW@20P800<S8b
05IFEP2NWYh0/k>c06=SH`1[Jf/0J6QX03<c<`1EEED0Z:RX0:n_[`1HF5P0M7Ad02l_;`1;Bd/0Jf][
09VIV@17AdL0KVi^061PH00O7al0CTi>09NGU`1YJFT0BTY:06e]K@0k>c/0:RXZ06MWI`2IVIT0GEeM
05]KF`11@D40@T920861P@2GUiL0DU9B034a<@1>CTh0Bd];05ADE02][Jd0K6a/01hN7P1KFe/0IVIV
06m_K`2c/k<0OGem020P801GEeL0I6AT08f=S@2i^KT0TI6A02TY:@0U9BD0Hf=S06QXJ02g]kL0Zj^[
02`/;00Z:RX0E5AD08F5Q@1nOWh0cLg=001H07=cL`0a<C40Fe]K06i^KP1iNGT0Ng]k0;:b/P1DE5@0
?3`l05YJFP23Ph<0BTY:0:JVYP2@T9009bLW02HV9P17AdL0NGUi06=SH`2b/[80Q8B4020P800[:b/0
ADE5096AT@21PH40N7Qh07EeM@0X:2P0FEUI05aLG01UIFD0EEEE07QhN01cLg<0<c<c03/k>`1XJ6P0
Ogmo055AD@1/K6`0=SHf02l_;`14A4@0J6QX05]KF`1?Cdl0HF5Q030`<00o?cl0@D5107]kN`1VIVH0
>SXj07moO`0n?Sh0A4A404U9B@1]KFd0Cdm?024Q8@1=CDd0B4Q8065QH@1XJ6P0FUYJ04=3@`0i>CT0
C4a<051@D01EEED0E5AD03Xj>P1EEED0EeMG05=CD`0l?3`0=cLg05YJFP1MGEd0EeMG06QXJ018B4P0
CDe=04M7A`0o?cl0@T9202`/;080@T9201/0>c/k030`<01TI6@0De=C04M7A`1BDU80HV9R07=cL`1_
Kfl0@T92051@D01IFET0H61P04M7A`1<C4`0H61P05iNGP1WIfL0?Cdm04i>CP1ADE40>c/k05ADE013
@d<0?Cdm03Lg=`0[:b/00P0j>SX05P1ADE40<C4a03Ph>00l?3`0<c<c0492@P0F5QH0?Shn038b<P0h
>3P0>c/k03dm?@1bLW80BDU906a/K01IFET0<S8b03lo?`1VIVH0EUIF05QHF01iNGT20492@P0N04Q8
B01fMWH0Shn?06YZJP0e=CD0CDe=03<c<`1QHF40H61P0410@017AdL0>CTi034a<@13@d<0@41003lo
?`0g=cL0@D5105mOG`0g=cL0?clo03Ti>@1;Bd/0=CDe03/k>`0e=CD0EeMG03De=@0j>SX0;bl_0P1=
CDd0V014A4@0BDU905=CD`1KFe/0@41004Y:BP14A4@0Bd];05QHF01:BTX0XJ6Q071`L01SHf<0M7Ad
04Q8B01FEUH0HV9R08^;R`2JVYX0EeMG0820P01gMgL0DU9B05EEE@16ATH0FUYJ04=3@`1KFe/0>CTi
07IfMP1:BTX0[:b/06YZJP2`/;00P82004Y:BP3Fe]H0IFEU079bLP1VIVH0H61P09>CT`1BDU80BTY:
05aLG00G5aL0GemO051@D01dM7@0JFUY06IVIP1[Jf/0FEUI07=cL`1=CDd0QHF50861P@1OGel0F5QH
04Y:BP1EEED0ATI60861P@1OGel08B4Q07AdM025QHD0:b/[09jNWP2GUiL0?Cdm061PH00l?3`0DE5A
03Ph>01EEED0M7Ad02DU9@27QhL0Jf][04U9B@1PH600GEeM05]KF`1gMgL0BDU905QHF01GEeL0D51@
061PH018B4P0GemO04M7A`28R8P0[:b/05EEE@1dM7@0Jf][065QH@1MGEd0<30`092@T01GEeL0:b/[
051@D00m?Cd0>SXj08R8R014A4@0AdM704];B`14A4@0>CTi03<c<`1FEUH0@T9205QHF00`<300F5QH
03/k>`0j>SX0?clo034a<@0n?Sh0BTY:02`/;00e=CD0@d=303`l?016ATH0CTi>04I6AP1MGEd0F5QH
05eMG@1;Bd/0@d=305QHF014A4@0Fe]K03/k>`0o?cl0KFe]03@d=01KFe/0A4A403De=@0o?cl05ADE
069RHP1:BTX0820P0P0f=SH05P1SHf<0?3`l05eMG@1gMgL0?Cdm03hn?P17AdL0GEeM065QH@0k>c/0
D51@03`l?00g=cL0FUYJ03<c<`1FEUH0@D5103`l?01YJFT09BDU03De=@11@D4204M7A`0K05mOG`1l
O7`08b<S06][J`1SHf<0F5QH065QH@0T92@0]kNg05MGE`0^;Rh0GemO03<c<`1LG5`0GEeM04Y:BP1N
GUh0=SHf06ATI018B4P0@d=304i>CP1DE5@0Ng]k04Y:BP1FEUH0NGUi0080FEUI0@2=SHd1ooooo`7o
oooo0000E`1nOWh0M7Ad0;Rh^01GEeL0GemO04i>CP1CDe<0]KFe059BDP0f=SH0KVi^05QHF01EEED0
PH6103Xj>P0_;bl0Bd];06UYJ@1lO7`0K6a/06=SH`0J6QX0=cLg04m?C`17AdL0E5AD0<?3``20P800
71`L038b<P0i>CT0IfMW09VIV@2m_Kd0<30`038b<P1LG5`0IVIV05ADE023Ph<0XJ6Q01dM7@0T92@0
AdM705UIF@1aLG40NGUi0:>SX`0d=3@08B4Q04];B`2IVIT0?Cdm05mOG`1KFe/08B4Q04m?C`1JFUX0
NWYj04M7A`2DU9@0<30`020P801:BTX0WinO071`L01[Jf/0B4Q8020P800n?Sh0I6AT08J6QP0i>CT0
Jf][03`l?00N7Qh0<c<c08J6QP1DE5@0?clo05UIF@0N7Qh0<30`04m?C`27QhL0?clo05eMG@02038b
<P0H0410@01XJ6P0Fe]K01dM7@11@D408B4Q03lo?`2LW9`0[Jf]03`l?00/;2`0CDe=03/k>`1@D500
Y:BT04a<C00P8200>CTi0410@00a<C40JFUY0:>SX`0[:b/08B4Q0P1HF5P0o`15ADD0[Zj^0;jn_P0[
:b/0?Shn05aLG01@D500Jf][0:n_[`1MGEd08B4Q05]KF`1bLW80DE5A07EeM@2k^k/0AdM702<S8`1N
GUh0Vi^K04i>CP1iNGT0G5aL02LW9`0o?cl0H61P0;fm_@25QHD0M7Ad07IfMP0^;Rh0?3`l05QHF02>
SXh0U9BD09FEU@1iNGT0<30`061PH02DU9@0IfMW05IFEP2TY:@0CDe=05iNGP30`<00I6AT06i^KP1P
H600<c<c03Xj>P2LW9`0e]KF06IVIP1IFET0>CTi04M7A`1DE5@0VYZJ09^KV`1LG5`0IfMW04M7A`1:
BTX0HF5Q09>CT`25QHD0<c<c04Y:BP1IFET0CDe=07YjNP33`l<0E5AD034a<@1?Cdl0N7Qh06EUI@1j
NWX0Rh^;03Hf=P0j>SX0FEUI08R8R02>SXh0clo?03hn?P0O7al0DU9B079bLP1FEUH0PX:207=cL`0U
9BD0:2PX04E5A@1]KFd0HV9R09jNWP1CDe<0;bl_059BDP1ADE40GemO0;bl_022PX8061PH04M7A`21
PH40G5aL065QH@1kNg/0;Bd]03Lg=`1SHf<0Y:BT05iNGP2JVYX07alO03/k>`21PH40YZJV04U9B@2T
Y:@0BDU902XZ:P1XJ6P0X:2P07]kN`1bLW80PX:2030`<016ATH0RXZ:06IVIP1HF5P0I6AT02PX:019
BDT0DU9B079bLP1MGEd0RXZ:05YJFP0^;Rh0FEUI07AdM021PH40GUiN07IfMP1KFe/0=3@d06i^KP2Y
ZJT0MgMg03Lg=`1HF5P0AdM704I6AP1oOgl0UiNG03hn?P0d=3@0BTY:04I6AP1;Bd/0PH610;no_`0o
?cl0=cLg06MWI`1HF5P0EEEE08F5Q@2d];@0;bl_03Lg=`1CDe<0EEEE05iNGP2PX:00FUYJ02HV9P1C
De<0LG5a07YjNP28R8P0d=3@03Ph>00];Bd0FEUI04m?C`1FEUH0F5QH09NGU`16ATH0:2PX04m?C`1R
HV80Xj>S05EEE@2YZJT0PX:203`l?017AdL0Ng]k06QXJ01;Bd/0RHV905IFEP1KFe/0NGUi04Y:BP1h
N7P0EeMG06EUI@1WIfL0HV9R06][J`1/K6`0R8R807MgM`1CDe<0Ogmo055AD@1DE5@0De=C02/[:`0l
?3`0?Shn04M7A`15ADD0F5QH06MWI`1`L700QXJ60861P@1PH600IFEU04e=C@1VIVH0LW9b06ATI01O
Gel0EEEE07UiN@1?Cdl0K6a/03Lg=`1:BTX0G5aL04Y:BP1YJFT0A4A403`l?0004P14A4@0@D5103/k
>`0/;2`0DU9B03Ti>@10@400:RXZ04Q8B01MGEd0;bl_03/k>`0g=cL0@D51051@D00];Bd0<S8b02h^
;P80Bd];0:T0;Bd]05EEE@1MGEd0EEEE07MgM`2OWil0?clo04e=C@1?Cdl0?3`l028R8P13@d<0ADE5
05EEE@19BDT0;2`/04A4A011@D40B4Q804M7A`0V9RH0:RXZ03<c<`13@d<0<C4a03`l?01KFe/0;Rh^
02d];@0M7Ad0@D5102h^;P0Z:RX09bLW05QHF00P8200<C4a02LW9`1<C4`0ATI601dM7@0m?Cd0?clo
055AD@0[:b/0=cLg03@d=014A4@0=cLg03Ti>@2IVIT0MWIf03Lg=`1@D500<S8b06QXJ00e=CD0@d=3
055AD@1MGEd0Q8B405iNGP1SHf<0GUiN04];B`1NGUh0EUIF06m_K`0V9RH0EUIF02d];@3?cll0LG5a
0=3@d022PX80Fe]K0;Ng]`1RHV80UIFE07inOP11@D40EeMG02HV9P1=CDd0J6QX0410@019BDT09BDU
03Xj>P16ATH0@d=304Y:BP0];Bd0NGUi03Ph>02GUiL0MGEe059BDP1CDe<0B4Q8059BDP18B4P0MWIf
08V9R@16ATH0GUiN05YJFP0b<S80[jn_0;Rh^00h>3P0BDU903dm?@1UIFD0@d=306MWI`22PX80FUYJ
08^;R`1NGUh0IVIV0861P@1IFET0C4a<07QhN01:BTX0CTi>06i^KP1ZJVX0F5QH03Ph>01OGel0ATI6
0;2`/02[Zj/0@d=309BDU01BDU80AdM704a<C00h>3P0F5QH05EEE@0l?3`0JVYZ04i>CP16ATH0DE5A
03@d=01KFe/0ADE503dm?@0a<C40<30`05=CD`11@D40O7al020P801EEED0;Bd]038b<P1:BTX0=SHf
04M7A`1UIFD0=SHf02/[:`0k>c/0@d=30080ADE504d0;bl_04=3@`0k>c/0EEEE02HV9P0a<C40CDe=
03@d=01=CDd0<S8b034a<@1YJFT06a/K06ATI00h>3P0=CDe0410@00F5QH0Bd];04Y:BP0g=cL0Bd];
059BDP1JFUX0CDe=03dm?@1OGel0BDU905]KF`0i>CT0WIfM06UYJ@0Y:BT0>3Ph02XZ:P1YJFT0PX:2
04U9B@1SHf<0?Shn02l_;`1GEeL0;Bd]04a<C00n?Sh0DE5A03Ph>01DE5@0WYjN04I6AP1iNGT0L71`
04m?C`1FEUH0;Bd]07AdM01<C4`0?Shn05MGE`18B4P0DE5A04];B`1BDU80MGEe04U9B@1WIfL0@T92
05mOG`1LG5`0GEeM08Z:RP1NGUh0H61P07AdM01UIFD0F5QH0:b/[002ooooo`000;@0W9bL05YJFP1X
J6P0Jf][09bLW00o?cl0AdM7055AD@20P800PH6108J6QP0e=CD0<C4a04U9B@1OGel0D51@0:VYZ@14
A4@05aLG03`l?01RHV80CDe=096AT@2l_;`0>3Ph034a<@13@d<0JFUY04m?C`1[Jf/0I6AT038b<P19
BDT0NGUi07alO00`<300GemO04E5A@0S8b<0Hf=S0:b/[01VIVH0;bl_03hn?P0m?Cd08b<S04=3@`2N
WYh0I6AT02DU9@1EEED0>c/k05iNGP1SHf<0OGem02/[:`0f=SH0GEeM04I6AP1EEED0QhN704=3@`0H
61P0>CTi05IFEP14A4@0T92@08Z:RP0I6AT09RHV03/k>`1bLW80JVYZ0;Vi^@1eMGD06a/K04U9B@1C
De<0Hf=S08>3P`31`L40;bl_02TY:@1GEeL0I6AT06][J`2NWYh0CDe=020P8013@d<0I6AT06][J`1T
I6@0RXZ:04Q8B00J6QX0BDU90:>SX`29RHT0PX:20:VYZ@0L71`0=3@d059BDP1mOGd0?3`l05eMG@0[
:b/09BDU03dm?@1EEED0DU9B0410@01BDU80>3Ph03@d=013@d<0T92@08>3P`1FEUH0EEEE01DE5@0a
<C40HV9R08j>SP10@400C4a<04e=C@0X:2P0>SXj05eMG@2GUiL0CTi>03hn?P12@T80:BTY06UYJ@1[
Jf/0:b/[028R8P13@d<0>CTi03@d=01TI6@0LW9b04];B`0W9bL0F5QH04A4A00h>3P0V9RH0;Zj^P0a
<C40=SHf06i^KP19BDT0GemO0<30`01dM7@0=CDe07emO@20P800_;bl07alO00];Bd09bLW06UYJ@2V
YZH0QXJ60<S8b01^KVh0<C4a06YZJP23Ph<0RHV908B4Q03Fe]H0UiNG02TY:@1<C4`20:b/[00e08J6
QP2o_kl0J6QX02`/;01TI6@0Ng]k09JFUP2PX:00WYjN02DU9@0n?Sh0LG5a0861P@1PH600SHf=0<W9
b@0T92@0DE5A0;bl_02=SHd0?clo06MWI`1<C4`0Jf][08b<S02n_[h0QXJ605ADE01hN7P0?Cdm04Q8
B01XJ6P0SXj>04Y:BP1^KVh0BTY:03De=@29RHT0bl_;07]kN`1?Cdl0HV9R02h^;P23Ph<0d=3@05iN
GP10@400FUYJ03hn?P1DE5@0VYZJ05QHF00^;Rh00P0o?cl0601:BTX0VIVI08b<S00^;Rh0E5AD065Q
H@1_Kfl0Shn?0<K6aP1^KVh0>SXj06=SH`1]KFd0X:2P0:^[Z`0c<c<0?3`l069RHP1;Bd/0K6a/0=?C
d`2o_kl092@T0492@P80Jf][03d0TI6A0;Ng]`1cLg<0>3Ph05ADE01FEUH0O7al08f=S@3@d=00D51@
04E5A@19BDT0OWin06UYJ@1gMgL0ZZZZ08V9R@0^;Rh0;bl_08^;R`2<S8`0R8R809>CT`0[:b/0=3@d
0492@P2@T900O7al075aL@1SHf<09RHV04Y:BP1FEUH0Kfm_04m?C`1cLg<0BDU903@d=01MGEd0IfMW
05iNGP0m?Cd0JFUY05YJFP0U9BD0?Shn07alO01oOgl0?Shn06e]K@1DE5@092@T02HV9P1EEED0Y:BT
04m?C`14A4@0P82006a/K01FEUH0Jf][0080HF5Q0>H0N7Qh05]KF`1GEeL0GemO059BDP11@D40@410
07UiN@1oOgl0TY:B07=cL`1RHV80Ng]k05aLG01_Kfl0EEEE03Ph>01@D500>3Ph04];B`0m?Cd0H61P
05MGE`1@D500HV9R075aL@1kNg/0J6QX03dm?@1?Cdl0Fe]K06][J`1EEED0HF5Q06EUI@1IFET0E5AD
03Ph>018B4P0DE5A0451@@1DE5@0>SXj04E5A@0k>c/0?Shn034a<@0R8R80DE5A04E5A@1OGel09BDU
038b<P1@D50061PH03hn?P14A4@0=cLg04m?C`10@400DU9B04E5A@1VIVH0Cdm?03Hf=P1NGUh0LG5a
06MWI`1/K6`0RXZ:03Xj>P11@D40IfMW06YZJP1DE5@0DU9B03De=@1CDe<0=CDe05MGE`1`L700BDU9
04m?C`1KFe/0?clo030`<00_;bl0DE5A03Ph>00n?Sh0De=C0410@012@T80?Shn0451@@17AdL0?Shn
04A4A01SHf<0>SXj05=CD`16ATH0?Cdm04U9B@0d=3@0G5aL05MGE`1LG5`0?clo04m?C`0n?Sh0<S8b
04m?C`1SHf<0_[jn08V9R@1EEED0IfMW04E5A@1GEeL0@D5106EUI@1QHF40>SXj065QH@12@T80=cLg
03hn?P1[Jf/0H61P02d];@0^;Rh0=SHf04Q8B00O7al0Hf=S04A4A03Hf=P0P82004i>CP2>SXh0?Shn
08J6QP1VIVH0HV9R07QhN00X:2P0HV9R0820P00G5aL0=3@d03Lg=`1ADE40Lg=c0492@P1DE5@0:2PX
07AdM01RHV80_[jn07IfMP1RHV80ADE5059BDP13@d<0G5aL079bLP1[Jf/0<C4a06e]K@1hN7P0P820
0;fm_@2a/K40MWIf05iNGP1HF5P0Fe]K03Hf=P1IFET0TI6A04A4A029RHT0FUYJ04a<C01KFe/0?Cdm
04=3@`1cLg<0=SHf07AdM01VIVH0EeMG051@D00/;2`0Lg=c02XZ:P1[Jf/0KFe]04e=C@2GUiL0AdM7
04m?C`1:BTX0@D5108R8R015ADD0@D5104Q8B011@D40<c<c05=CD`1LG5`0@d=304Q8B011@D40Bd];
04i>CP1DE5@0A4A405eMG@1ADE40HF5Q04A4A01DE5@0GemO02d];@0d=3@0C4a<01dM7@809BDU0500
>c/k03<c<`1>CTh0<S8b04e=C@1;Bd/0GemO03Xj>P0m?Cd0Hf=S03dm?@1ADE40>CTi05EEE@22PX80
>SXj061PH014A4@0AdM704];B`0j>SX0DE5A051@D00c<c<0<C4a03De=@1;Bd/0@d=303/k>`1LG5`0
BDU904Q8B00o?cl0FUYJ04Q8B011@D40@41003De=@1;Bd/0HF5Q04Y:BP1IFET0=SHf03/k>`1JFUX0
92@T04];B`1=CDd0JVYZ06IVIP1QHF40Shn?05=CD`2VYZH0Jf][071`L02>SXh0D51@09:BTP1:BTX0
De=C08f=S@1IFET0EeMG04Y:BP1ADE40MgMg04E5A@1IFET0>SXj04A4A01NGUh0OWin0::RXP1MGEd0
DE5A06=SH`1PH600GemO07alO0;ooooo0000>P2GUiL0JVYZ08:2PP1MGEd0L71`07IfMP15ADD0HF5Q
03/k>`16ATH0XJ6Q04a<C00n?Sh0BDU904=3@`1:BTX0N7Qh09BDU00a<C40>CTi03<c<`13@d<0L71`
08f=S@1JFUX0<30`05UIF@1CDe<0EUIF096AT@1nOWh071`L02DU9@1GEeL0K6a/06UYJ@2j^[X0J6QX
01DE5@0c<c<0HF5Q092@T01TI6@0[jn_06m_K`0W9bL0=CDe03hn?P1DE5@0KFe]0::RXP0b<S809BDU
03dm?@1?Cdl0AdM7075aL@2g]kL203@d=00O07AdM01jNWX0DE5A08b<S01;Bd/0=3@d03dm?@1kNg/0
GEeM08V9R@1cLg<0;2`/03dm?@1VIVH0PX:203@d=01dM7@0AdM701hN7P1LG5`0UiNG06i^KP1EEED0
FEUI03hn?P0e=CD0JVYZ07=cL`0a<C40>3Ph059BDP0202l_;`3o07MgM`21PH40:2PX034a<@13@d<0
;Rh^04m?C`2MWId0;Bd]02HV9P10@400=CDe05IFEP2YZJT0K6a/01<C4`0^;Rh0Cdm?03dm?@1GEeL0
Z:RX04Y:BP0U9BD0@d=304];B`19BDT0KFe]09>CT`0U9BD05QHF04e=C@28R8P0De=C09ZJVP22PX80
7alO0492@P19BDT0Jf][061PH02FUYH0Ng]k01LG5`0c<c<0DU9B05=CD`1JFUX0XZ:R04i>CP0K6a/0
=cLg06ATI02KVi/0K6a/0;6a/@1BDU80=cLg0492@P2_[jl0Shn?07UiN@1QHF408R8R02PX:01FEUH0
Z:RX05aLG013@d<0820P04Y:BP23Ph<0DE5A04A4A01VIVH0?3`l02l_;`17AdL0T92@03<c<`12@T80
EeMG02d];@0o?cl0KFe]0:FUY@1GEeL0@41006MWI`18B4P0IfMW08:2PP2TY:@0FEUI071`L01hN7P0
CTi>05]KF`2SXj<0IFEU034a<@1UIFD0QXJ607UiN@2QXJ40dm?C03Hf=P0_;bl0IfMW08V9R@1ZJVX0
YJFU03/k>`0d=3@0L71`06m_K`1/K6`0RXZ:0<G5a@0h>3P0Bd];08n?S`1dM7@0RXZ:0<30`01jNWX0
8b<S03<c<`20P800O7al0:f][@2k^k/092@T02PX:01hN7P0SXj>096AT@2EUID0<C4a04a<C01KFe/0
HF5Q08>3P`2^[Zh0=cLg03@d=01cLg<0TY:B07alO02NWYh0N7Qh03De=@1@D500QHF507QhN02JVYX0
QhN702l_;`1DE5@0`/;208b<S023Ph<0QHF504I6AP0i>CT0QhN70=GEe@2GUiL0OWin08B4Q016ATH0
KVi^09NGU`37alL0EeMG08V9R@19BDT0<S8b05ADE02;Rh/0ZJVY04m?C`1GEeL0R8R803Ti>@0e=CD0
P8200:f][@19BDT0Bd];06MWI`0c<c<0EeMG0::RXP1EEED0=SHf06=SH`19BDT0Bd];071`L02WYjL0
BTY:03<c<`1`L700I6AT07alO02@T900FUYJ02HV9P0o?cl0Hf=S05IFEP1<C4`0YJFU09BDU00g=cL0
:BTY05ADE01fMWH0GemO09RHV02a/K40?Shn02LW9`1IFET0YZJV071`L01OGel0L71`05MGE`13@d<0
Jf][04U9B@16ATH0Jf][04E5A@1aLG40CTi>04M7A`21PH40NWYj06a/K01HF5P0LG5a07AdM01>CTh0
LG5a04A4A01?Cdl0De=C01dM7@0g=cL0C4a<04A4A010@400D51@000U04i>CP19BDT0Hf=S06UYJ@1U
IFD0KVi^04E5A@1QHF40C4a<05mOG`1@D500De=C065QH@1=CDd0HF5Q03lo?`19BDT0Bd];04A4A01L
G5`0BDU90451@@12@T80CTi>03dm?@0g=cL0GEeM03Ph>014A4@0;bl_059BDP1HF5P09bLW05IFEP19
BDT0AdM705=CD`0203<c<`0Q04I6AP1NGUh0De=C03/k>`1SHf<0L71`05eMG@1eMGD0YJFU0410@01=
CDd0IVIV05eMG@1[Jf/0IVIV04];B`1KFe/0;2`/03<c<`1RHV80BTY:04Q8B01@D500:b/[03@d=00o
?cl0ATI604A4A010@400GemO03Ph>01?Cdl07alO0080?Cdm00/0>c/k030`<01FEUH07AdM05IFEP0U
9BD0B4Q804U9B@0h>3P0Hf=S05=CD`0205IFEP1M04=3@`0k>c/0>CTi05MGE`15ADD0a<C408b<S01Z
JVX0MWIf04E5A@1FEUH09BDU071`L00j>SX09RHV06ATI00];Bd0B4Q8051@D01hN7P0O7al04m?C`1C
De<0=CDe05MGE`15ADD0Shn?03Xj>P2UYJD0J6QX075aL@2VYZH0=cLg08Z:RP1WIfL0NGUi0:^[Z`10
@400De=C05YJFP0f=SH0J6QX02/[:`19BDT0Cdm?04];B`1UIFD0B4Q805eMG@1IFET0YZJV06ATI01;
Bd/0;Bd]04i>CP15ADD0GemO08Z:RP22PX807alO07AdM026QXH0:2PX0:n_[`2JVYX0E5AD05YJFP0a
<C40JFUY03lo?`17AdL0`<30075aL@31`L40@41004e=C@1QHF40G5aL0451@@1QHF40ADE5069RHP1W
IfL0IFEU05IFEP0b<S80D51@01dM7@2PX:00Q8B403hn?P2:RXX0@d=30080C4a<01X0>c/k07alO01H
F5P0?Cdm04e=C@0o?cl0DU9B06MWI`1:BTX0@d=3034a<@1LG5`0CTi>03dm?@1OGel0?Shn071`L014
A4@0IFEU055AD@16ATH0CDe=03`l?01;Bd/0De=C024Q8@80;Bd]02<0A4A405ADE01?Cdl0E5AD04a<
C01OGel0I6AT03Hf=P0_;bl0IFEU04E5A@1<C4`0=SHf05EEE@1[Jf/0<30`07]kN`10@400>CTi0492
@P0R8R80HF5Q055AD@0f=SH0?3`l03Ti>@1:BTX0A4A4059BDP1UIFD0ADE5055AD@19BDT0HV9R04];
B`0205mOG`0B04E5A@1HF5P0GemO03`l?01bLW80Cdm?04=3@`1/K6`0?Shn04m?C`18B4P0De=C04E5
A@1WIfL0R8R8059BDP1oOgl0J6QX0P1LG5`05`1RHV80a/K605aLG00i>CT0IfMW03@d=02BTY80GEeM
05iNGP1UIFD0BTY:07QhN01NGUh0F5QH05iNGP1DE5@0CDe=05ADE01IFET0F5QH07=cL`1NGUh0Jf][
00;ooooo0000O025QHD0Ph>30:2PX018B4P0G5aL075aL@1bLW80^KVi04U9B@0d=3@0EeMG07MgM`24
Q8@0Vi^K02LW9`0`<300:b/[07inOP1LG5`0SXj>06IVIP0a<C40B4Q806UYJ@1dM7@0Hf=S0:2PX01;
Bd/071`L055AD@2KVi/0MGEe06=SH`1OGel08B4Q03lo?`1@D500O7al04E5A@1=CDd0D51@028R8P1N
GUh0GemO08>3P`10@400B4Q806=SH`0R8R80CTi>0:f][@1lO7`0;Bd]05ADE00g=cL0?clo04e=C@2O
Wil0TI6A03@d=018B4P0<30`06IVIP2b/[80B4Q802PX:01:BTX0FUYJ02l_;`1eMGD0UIFE02DU9@0K
6a/0>c/k05YJFP14A4@0ZZZZ09BDU00S8b<08B4Q04A4A01VIVH0M7Ad08^;R`0k>c/09bLW03Ti>@1X
J6P0IVIV07UiN@1lO7`07AdM02<S8`11@D40J6QX05=CD`1iNGT0OGem01/K6`0U9BD0Bd];05iNGP1H
F5P0[Zj^03Xj>P0I6AT0EUIF07moO`14A4@0F5QH05mOG`0^;Rh0:b/[03Ph>01MGEd0C4a<07YjNP1a
LG40>CTi038b<P1mOGd0IFEU04U9B@1HF5P202h^;P3o03Ti>@29RHT0FEUI0492@P1RHV809BDU03<c
<`1EEED0YJFU059BDP1<C4`0E5AD02HV9P0j>SX0FEUI07inOP0a<C40=CDe04Y:BP0b<S80>3Ph06AT
I02CTi<0>c/k06QXJ01=CDd0>SXj08B4Q02c/k<0<C4a02h^;P1<C4`0GUiN08J6QP2;Rh/09BDU03/k
>`1JFUX0FEUI07EeM@3@d=00C4a<02XZ:P0f=SH0De=C05YJFP2JVYX0/[:b03/k>`0/;2`0@T9207=c
L`1XJ6P0WYjN0;:b/P0_;bl0@T9206YZJP1UIFD0G5aL0<K6aP2l_;`0=cLg05=CD`25QHD0O7al05AD
E02][Jd0G5aL0451@@1_Kfl0ZZZZ07MgM`1XJ6P0Shn?03Xj>P0d=3@0R8R80:2PX012@T80PX:203De
=@0i>CT0ADE5071`L02b/[80DE5A05iNGP0O7al0;bl_07MgM`2VYZH0IFEU04M7A`10@400=cLg055A
D@2HV9P0De=C03/k>`1NGUh0;Bd]075aL@2MWId0M7Ad04M7A`1[Jf/0:RXZ051@D02WYjL0SHf=04I6
AP1TI6@0DE5A0410@02ATI40/;2`04A4A00k>c/0GEeM04I6AP1PH600Ph>3038b<P0e=CD0D51@06e]
K@2PX:00WIfM03<c<`0Y:BT0BDU9079bLP1OGel0/;2`0;Bd]00j>SX0=cLg06a/K02RXZ80NGUi0=3@
d02UYJD0<C4a02PX:01@D500Ph>307EeM@2DU9@0/k>c03/k>`0n?Sh0CDe=06e]K@1TI6@0ZZZZ09:B
TP0i>CT0FEUI055AD@1UIFD0HV9R0:j^[P1:BTX0<C4a05MGE`2IVIT0M7Ad06IVIP1ZJVX07alO02XZ
:P23Ph<0XZ:R05MGE`2:RXX0I6AT02h^;P0`<300BDU908F5Q@1SHf<0EEEE071`L00Y:BT0?clo04=3
@`1WIfL0OGem04M7A`25QHD0AdM704];B`1aLG40NWYj06i^KP1GEeL0PX:205UIF@1BDU80JVYZ05aL
G01JFUX0F5QH06MWI`14A4@0@d=3061PH01cLg<0RHV90:j^[P1^KVh0L71`04m?C`1CDe<0EEEE02HV
9P0m?Cd0<S8b051@D01DE5@0EUIF05QHF01dM7@0PX:208f=S@1ZJVX0N7Qh04U9B@1_Kfl0EUIF06i^
KP1OGel0EUIF07QhN01;Bd/0IFEU04I6AP1GEeL0FUYJ0410@01XJ6P0@D5104e=C@1KFe/0A4A405EE
E@18B4P0LW9b04E5A@1GEeL0BDU903@d=01?Cdl09bLW000i03lo?`0i>CT0;2`/061PH00f=SH0A4A4
055AD@1/K6`0BDU905eMG@1TI6@0GemO055AD@2EUID0XZ:R02`/;00i>CT0GemO04a<C01FEUH0Fe]K
03Ph>01VIVH0=SHf03<c<`1_Kfl0BDU90451@@1SHf<0:b/[02@T900f=SH0BDU904E5A@0n?Sh0C4a<
02XZ:P0o?cl0<c<c04=3@`0e=CD0>3Ph03dm?@1<C4`0;Bd]04a<C00Y:BT0ADE50492@P0Y:BT0@D51
04=3@`1BDU80AdM703dm?@15ADD0?Shn0080FEUI02H0TI6A06i^KP14A4@0GUiN04i>CP1KFe/0@d=3
04M7A`0j>SX0AdM707EeM@1@D500GemO05aLG01ADE40KVi^061PH01DE5@0G5aL07EeM@1KFe/0Vi^K
0861P@3>c/h0Rh^;0:FUY@3?cll0M7Ad0:>SX`1iNGT0KFe]09RHV01=CDd0K6a/075aL@17AdL0>CTi
03Ph>080C4a<09<0A4A405ADE019BDT0S8b<04];B`2XZ:P0IfMW06UYJ@1ADE40CDe=02/[:`14A4@0
DE5A05=CD`10@400[:b/09RHV00n?Sh0]kNg0<O7a`1@D500JFUY059BDP2@T900C4a<06QXJ02VYZH0
IFEU05aLG01BDU80M7Ad06m_K`1LG5`0K6a/07moO`1QHF40RHV908F5Q@2>SXh0Lg=c059BDP1SHf<0
@D510:BTY01bLW80EUIF07alO01;Bd/0Ph>305ADE015ADD0E5AD04M7A`0g=cL0BTY:04E5A@1IFET0
L71`03dm?@19BDT0=CDe04];B`14A4@0EEEE07EeM@1ADE40Ogmo061PH01lO7`0GemO03lo?`1>CTh0
EUIF03lo?`1EEED0A4A404E5A@1?Cdl0Bd];059BDP1KFe/0=3@d05aLG016ATH0GUiN03lo?`0c<c<0
EEEE05ADE01nOWh0=3@d051@D01UIFD09BDU08j>SP11@D40CTi>051@D00g=cL0QXJ604I6AP0b<S80
>c/k0410@01QHF40DU9B04I6AP1NGUh0@D5104e=C@0_;bl0VIVI05mOG`0c<c<0@41001`L701IFET0
FUYJ01lO7`1KFe/08B4Q05QHF024Q8@0E5AD05]KF`17AdL0CDe=034a<@26QXH0QhN703@d=01MGEd0
AdM7092@T01fMWH0>c/k055AD@1>CTh0HF5Q07AdM01<C4`0BTY:04];B`1MGEd0Hf=S034a<@1:BTX0
0P15ADD02@1/K6`0L71`07inOP1KFe/0ATI605MGE`1ADE40DU9B071`L002ooooo`000280KFe]059B
DP1_Kfl0GUiN07YjNP0m?Cd0ATI605YJFP1NGUh0GemO06MWI`0g=cL0A4A407QhN01`L700BTY:05aL
G00_;bl0>SXj04m?C`1@D50092@T0451@@1?Cdl0ATI606ATI02CTi<0De=C028R8P0m?Cd0B4Q806QX
J01iNGT0TI6A0P0V9RH0A`14A4@0>c/k06m_K`1dM7@0PX:201TI6@0S8b<0@d=305IFEP1@D500LG5a
07AdM00Z:RX0>3Ph04Y:BP1MGEd0MgMg0:JVYP0];Bd0;2`/030`<01IFET0MWIf08:2PP2=SHd0<c<c
02LW9`1hN7P0P82005=CD`27QhL0I6AT03lo?`15ADD0N7Qh05IFEP1BDU80HF5Q02h^;P0];Bd0EEEE
07emO@1_Kfl0Fe]K05MGE`0E5AD0<C4a04m?C`1KFe/0C4a<07IfMP0^;Rh092@T04Y:BP2DU9@0De=C
02`/;01WIfL09bLW02/[:`19BDT0Shn?03dm?@0j>SX0ATI6034a<@0m?Cd0J6QX051@D00L71`0=cLg
0080;Bd]0=80KFe]08V9R@0b<S80<30`03dm?@0j>SX0B4Q809FEU@2FUYH0=3@d03Xj>P1FEUH0ADE5
06=SH`2LW9`0ADE502XZ:P1>CTh0FUYJ05]KF`2;Rh/0VYZJ02HV9P0d=3@0EUIF07=cL`1CDe<0Ti>C
0820P00L71`0;Rh^05UIF@2IVIT0HF5Q092@T02XZ:P0;bl_03hn?P1DE5@0Lg=c07alO03Ng]h0`<30
04a<C00n?Sh0MGEe07emO@24Q8@0][Jf03Hf=P1VIVH0SXj>05UIF@2:RXX0KFe]038b<P1IFET0/[:b
0;2`/01kNg/0P820055AD@0l?3`0Lg=c096AT@1cLg<0De=C06a/K01EEED0;Bd]05aLG02g]kL0NGUi
05ADE02@T900@T9202l_;`1XJ6P0_[jn09^KV`1UIFD0VIVI03/k>`1PH600Zj^[08N7Q`19BDT0LW9b
09^KV`1<C4`0I6AT0:6QX@1;Bd/0;bl_05EEE@1MGEd0FUYJ08^;R`1XJ6P092@T02d];@1OGel0NWYj
06][J`2[Zj/0E5AD02LW9`1;Bd/0M7Ad08Z:RP2^[Zh0Kfm_02LW9`1VIVH0VYZJ069RHP29RHT0Vi^K
030`<00d=3@0Ph>3079bLP2LW9`0VYZJ01hN7P0f=SH0GEeM06ATI01RHV80Ph>303Xj>P0Q8B40C4a<
0:VYZ@2>SXh0[Jf]08^;R`0b<S80ATI607=cL`1aLG40G5aL06YZJP0W9bL0Bd];08V9R@1jNWX0@d=3
08:2PP1=CDd0;bl_03/k>`2;Rh/0H61P05ADE01IFET0@41003hn?P10@400UYJF05iNGP1=CDd0P820
03Ph>00_;bl0D51@07=cL`1HF5P0;bl_05IFEP0c<c<0;Bd]06EUI@1mOGd0?Cdm04i>CP1;Bd/0;2`/
04U9B@1aLG40X:2P04=3@`0k>c/0@d=303/k>`25QHD0/;2`02d];@0K6a/0=SHf05IFEP1LG5`0T92@
0:>SX`0R8R80:RXZ0451@@1?Cdl0<c<c08F5Q@3?cll0D51@02d];@0k>c/0@D5106i^KP1FEUH0[:b/
065QH@0k>c/207moO`1b05QHF018B4P0Jf][05YJFP1WIfL0NWYj0451@@1gMgL0L71`07AdM01@D500
Cdm?07QhN01]KFd0Ph>305EEE@1BDU80I6AT04Y:BP1NGUh0CTi>02@T900l?3`0>SXj03Ph>00f=SH0
CDe=04a<C015ADD0H61P05=CD`1ADE40FEUI05IFEP1XJ6P0DU9B05=CD`1DE5@0HF5Q05MGE`1@D500
DE5A03/k>`1ADE40FUYJ06ATI01SHf<0?Shn04Q8B00c<c<0EeMG03Ti>@0g=cL0JVYZ06=SH`25QHD0
?Shn04E5A@1VIVH0;Bd]05UIF@14A4@0=3@d06YZJP0n?Sh0Ng]k05YJFP1QHF40?3`l03Ph>01HF5P0
EEEE04];B`1IFET0Jf][03Hf=P19BDT0MgMg05UIF@1NGUh0PH6103dm?@1aLG40?Cdm06a/K025QHD0
?clo04E5A@1GEeL0E5AD03@d=00i>CT0A4A405eMG@0i>CT0De=C03Ph>01SHf<09BDU0451@@0b<S80
Cdm?03/k>`1NGUh0?Cdm05iNGP0^;Rh0BTY:04E5A@10@400E5AD05eMG@1YJFT0EUIF0P1JFUX05P19
BDT0Kfm_079bLP2j^[X0SHf=05IFEP1ADE40?3`l04Y:BP0R8R80JVYZ02LW9`0];Bd0FEUI03hn?P0h
>3P0EUIF061PH01BDU80DE5A05QHF01>CTh206MWI`2a08n?S`1_Kfl0b<S807]kN`1oOgl0QhN704E5
A@2<S8`0L71`09>CT`2HV9P08b<S05]KF`1ZJVX0?Shn059BDP1FEUH0FUYJ07QhN01KFe/0Jf][02PX
:01_Kfl0>3Ph09BDU00f=SH0Fe]K034a<@1LG5`0BTY:06YZJP28R8P0NGUi01dM7@1IFET0GEeM03De
=@2?Shl0LG5a03hn?P1DE5@0:RXZ061PH011@D40?3`l09FEU@1<C4`0QXJ604I6AP1GEeL0C4a<04M7
A`0h>3P0EeMG06e]K@2LW9`0IFEU03hn?P0g=cL0@41006ATI00P8200Ph>307inOP1XJ6P0OWin03/k
>`1DE5@0EeMG03Lg=`1OGel0<S8b04e=C@2KVi/0;Rh^04I6AP1EEED0=CDe06][J`18B4P0IFEU03lo
?`0g=cL0A4A4034a<@1PH600E5AD06e]K@19BDT0F5QH051@D00];Bd0JFUY09nOW`0X:2P0<c<c02TY
:@1EEED0EUIF05]KF`11@D40@d=304Y:BP1LG5`0:2PX034a<@1NGUh0=SHf04Q8B00b<S80IfMW075a
L@0Z:RX0F5QH02PX:00b<S80<c<c01@D501HF5P0A4A4038b<P0T92@0;Rh^03De=@0g=cL08B4Q04e=
C@13@d<0BDU902PX:01@D500@T9204=3@`14A4@0:2PX08b<S027QhL0=cLg07MgM`0R8R80>CTi04e=
C@0a<C40DE5A04];B`1GEeL0=cLg04a<C01:BTX0<S8b0861P@0g=cL0PX:208Z:RP1KFe/0IFEU05IF
EP1@D500K6a/05aLG01DE5@0DU9B05eMG@1bLW80DU9B05IFEP17AdL0C4a<05UIF@1_Kfl0Hf=S04e=
C@1ADE40I6AT05ADE01EEED0N7Qh00;ooooo0000U02[Zj/0Hf=S06][J`1QHF40^[Zj05YJFP0o?cl0
C4a<05EEE@1XJ6P0Zj^[03@d=012@T80EeMG06YZJP1gMgL0V9RH03/k>`0[:b/0HV9R06YZJP1TI6@0
Vi^K0:ZZZP0I6AT0BTY:06ATI01oOgl0GemO08J6QP25QHD09RHV0451@@1iNGT0MGEe05EEE@2RXZ80
@d=301/K6`1BDU80P82005=CD`0e=CD0PX:202h^;P0Y:BT0A4A408>3P`1NGUh0>CTi05MGE`0[:b/0
9BDU05=CD`1hN7P0?clo05YJFP1NGUh0;2`/038b<P1`L700A4A403/k>`1MGEd0>SXj03Ti>@1MGEd0
I6AT02d];@1ADE40N7Qh030`<01]KFd0UIFE03`l?00S8b<0@T9204A4A00g=cL0Ph>30;6a/@0/;2`0
:BTY04E5A@1EEED0C4a<09nOW`12@T806a/K024Q8@18B4P0G5aL05iNGP22PX80=SHf038b<P0W9bL0
CDe=069RHP2NWYh0HV9R01HF5P16ATH0E5AD04a<C01IFET0UIFE05aLG00@4100820P04A4A01GEeL0
HV9R07EeM@0K6a/092@T02l_;`1cLg<0GEeM06YZJP1=CDd06QXJ03Lg=`13@d<0GEeM03dm?@1OGel0
IVIV02TY:@1<C4`0Ti>C07AdM00n?Sh0L71`04e=C@0i>CT0@T92096AT@1RHV80=cLg07AdM013@d<0
=cLg06=SH`30`<00UiNG061PH02BTY8203/k>`0:08F5Q@2UYJD0GUiN055AD@1@D500@D51059BDP27
QhL0IFEU04E5A@80CTi>00/0JFUY0;:b/P1CDe<0=SHf059BDP17AdL0TI6A0<S8b01:BTX0:BTY05AD
E00207IfMP2L08:2PP3>c/h0F5QH02`/;00k>c/0Ogmo09JFUP25QHD0d=3@04];B`0^;Rh0Fe]K09NG
U`2;Rh/0WIfM0;no_`1DE5@0<c<c06QXJ02g]kL0N7Qh0;6a/@2ZZZX0?Shn07UiN@2][Jd0UYJF07Ui
N@2l_;`0A4A403Xj>P1^KVh0/[:b07QhN02PX:00XJ6Q04I6AP0n?Sh0F5QH0820P01TI6@0VIVI06MW
I`0e=CD0J6QX08Z:RP1GEeL0O7al09ZJVP11@D40<c<c08>3P`1QHF40DE5A06YZJP0[:b/0A4A4092@
T01MGEd0@D5105eMG@0T92@0GUiN0:j^[P1bLW80@d=306e]K@1aLG40@d=307AdM02YZJT0EEEE071`
L01FEUH0=CDe08f=S@2j^[X0=CDe051@D01]KFd0FEUI05QHF02][Jd0U9BD02l_;`19BDT0G5aL06IV
IP1eMGD0/[:b06ATI00o?cl0E5AD07IfMP1nOWh0M7Ad0;Fe]@1MGEd092@T04M7A`1cLg<0MGEe05QH
F02h^;P0FUYJ02TY:@1RHV80S8b<04M7A`2EUID0PH61028R8P12@T80LW9b09NGU`1cLg<0XJ6Q06MW
I`0c<c<0@410069RHP1UIFD0B4Q805mOG`0l?3`0B4Q805EEE@1KFe/0NWYj04A4A01bLW80M7Ad02l_
;`16ATH0MWIf071`L01;Bd/0L71`04E5A@0V9RH0=SHf08>3P`31`L40G5aL08R8R026QXH0EeMG04Q8
B01[Jf/0GEeM05EEE@1TI6@0BDU906QXJ016ATH0GEeM0P1DE5@0?`1`L700OWin079bLP1NGUh0I6AT
08n?S`1KFe/0L71`05UIF@0X:2P0BDU903Ti>@10@400ADE5055AD@16ATH0BTY:05iNGP1GEeL0G5aL
079bLP15ADD0FEUI051@D01RHV80CTi>05QHF01OGel0J6QX07EeM@1QHF40EeMG05EEE@0m?Cd0G5aL
0451@@17AdL0<c<c03hn?P0f=SH0<C4a061PH00g=cL0D51@03@d=01>CTh0@D5103`l?01]KFd0@d=3
0410@01DE5@0;Bd]04E5A@0o?cl0FUYJ051@D01<C4`0GEeM051@D01VIVH0Ti>C09NGU`0204Y:BP0f
06][J`2;Rh/0S8b<06a/K00g=cL0CTi>03Hf=P0c<c<0I6AT03hn?P10@400F5QH03/k>`19BDT0?Cdm
03De=@11@D40>SXj04U9B@0W9bL0@T9203@d=016ATH0:b/[03De=@15ADD0EeMG02/[:`0d=3@0:RXZ
04A4A012@T80EUIF05YJFP1ADE40GEeM06ATI00a<C40GEeM06MWI`1oOgl0CTi>0:6QX@25QHD0NWYj
075aL@1DE5@0ATI603hn?P1SHf<0=cLg038b<P1BDU80Bd];0P16ATH0<`1NGUh0KVi^05]KF`1YJFT0
EEEE06YZJP1YJFT0Jf][0410@02g]kL0EUIF09:BTP2:RXX0G5aL09JFUP1RHV80UiNG0;>c/`15ADD0
I6AT05mOG`0i>CT0QHF503/k>`14A4@0C4a<02/[:`0m?Cd051@D06ATI00d=3@0Shn?04I6AP23Ph<0
:2PX03dm?@0Q8B40?Cdm04a<C01ZJVX0@d=3075aL@1[Jf/0;Rh^0=OGe`2h^;P0;Rh^051@D00];Bd0
XJ6Q08:2PP0206EUI@03065QH@24Q8@0@D510080De=C01@0<30`05]KF`1nOWh0ADE506m_K`1XJ6P0
EeMG04i>CP1;Bd/0HF5Q051@D02DU9@0RHV904];B`1VIVH0@T9203lo?`13@d<0A4A407inOP80>CTi
03<0GUiN03De=@1DE5@0KVi^02d];@0n?Sh0=CDe04e=C@0l?3`0EEEE06i^KP0l?3`0Jf][06e]K@2:
RXX0CTi>04I6AP1BDU80=CDe030`<00j>SX0:BTY04Q8B00g=cL0?Cdm03<c<`1?Cdl0@410055AD@15
ADD0CDe=03Hf=P0[:b/0ADE503Ti>@1EEED0:BTY04Y:BP1TI6@0;Bd]069RHP0d=3@0@T920410@00^
;Rh0JVYZ03Ti>@0[:b/06QXJ03Lg=`0b<S800P10@400<`1UIFD0@T9204M7A`0h>3P0H61P04a<C01H
F5P0CTi>03Hf=P11@D40CTi>05QHF029RHT0BTY:03dm?@1@D500=SHf04U9B@0j>SX0CDe=02DU9@1_
Kfl0ATI6024Q8@22PX80F5QH0::RXP1MGEd0LW9b08f=S@17AdL0C4a<069RHP0h>3P0GemO04M7A`1M
GEd0GUiN05YJFP1mOGd0FUYJ04a<C01ADE40Fe]K06][J`1<C4`0FEUI065QH@1PH600EUIF07QhN002
ooooo`000=H0/k>c0:JVYP2NWYh0DU9B05mOG`1VIVH0EUIF08>3P`0d=3@0BDU908>3P`1eMGD0FEUI
07=cL`0W9bL0D51@06a/K026QXH0?Shn07EeM@1KFe/0<S8b05YJFP1cLg<0IVIV0410@01SHf<0?Cdm
04U9B@1VIVH0RXZ:03<c<`0b<S80@D51051@D01>CTh0PH6105YJFP0D51@0:2PX06EUI@1BDU80E5AD
0;Jf]P19BDT07AdM034a<@1PH600Fe]K05aLG02DU9@09bLW03/k>`0j>SX0EUIF08J6QP2HV9P0Vi^K
02<S8`0V9RH0>CTi055AD@1nOWh0];Bd02TY:@0I6AT0B4Q806i^KP1DE5@0TY:B09FEU@0m?Cd0>c/k
04U9B@1MGEd0GUiN09fMW@14A4@09bLW04a<C01jNWX0MGEe07IfMP2?Shl0<S8b02PX:01?Cdl0Ng]k
05MGE`1mOGd0KVi^01PH600n?Sh0IFEU08^;R`1DE5@0GEeM05iNGP0K6a/0HV9R096AT@0l?3`0ATI6
06=SH`0V9RH09BDU065QH@28R8P0>SXj05YJFP0o?cl0:BTY03dm?@21PH40Cdm?02<S8`0n?Sh0=cLg
04Y:BP1WIfL0OGem03`l?00];Bd0G5aL03dm?@19BDT0WinO07MgM`0O7al0:BTY04m?C`1CDe<0EUIF
09fMW@1OGel0:BTY03Ph>01DE5@0HF5Q05ADE02DU9@0B4Q802l_;`1XJ6P0MgMg07moO`21PH40a<C4
03Ti>@0h>3P0G5aL06YZJP1aLG40U9BD09RHV00W9bL0=CDe07]kN`2>SXh0RXZ:04I6AP0V9RH0@D51
05MGE`1QHF40PH6109FEU@14A4@0<c<c07emO@2BTY80EEEE08R8R01aLG40D51@04m?C`1cLg<0X:2P
04];B`1ZJVX0NWYj0492@P1`L700Xj>S0;>c/`1UIFD0YZJV06IVIP19BDT0De=C0:6QX@1]KFd0>CTi
075aL@13@d<0EeMG079bLP2LW9`0D51@03Hf=P1[Jf/0>c/k07EeM@2WYjL0Lg=c030`<01GEeL0?Shn
03`l?020P800`<3006UYJ@0_;bl0Cdm?0P11@D420:j^[P0o03De=@14A4@0Cdm?03/k>`1lO7`0ZJVY
02h^;P0m?Cd0J6QX05iNGP1fMWH0Zj^[03De=@1@D500JVYZ05=CD`1_Kfl0LG5a01dM7@0K6a/0HV9R
08B4Q01SHf<0UiNG05EEE@0j>SX0GEeM05iNGP16ATH0S8b<07EeM@0R8R80BDU90:NWY`15ADD0NWYj
096AT@19BDT0A4A407emO@33`l<0HV9R09NGU`2HV9P0Bd];05]KF`1oOgl0`L7106EUI@2][Jd0HF5Q
03Hf=P1]KFd0Ti>C0;Vi^@1OGel0SXj>05YJFP0`<300A4A407UiN@2VYZH0AdM70080IVIV03D0ADE5
05ADE01oOgl0B4Q80451@@1VIVH0>3Ph03Xj>P20P800U9BD03<c<`1QHF40Lg=c03Lg=`17AdL0SXj>
05eMG@0S8b<0BDU906ATI015ADD0CDe=09BDU02TY:@0<C4a02l_;`1gMgL0I6AT04E5A@2GUiL0X:2P
03De=@0O7al0Cdm?07alO01/K6`0NGUi071`L01IFET0DU9B08:2PP1>CTh0EeMG079bLP1>CTh0Jf][
05QHF01eMGD0DU9B055AD@1PH600GUiN07EeM@0206QXJ01j06][J`13@d<0Fe]K04m?C`0D51@0?Cdm
03Xj>P0o?cl0<30`04E5A@1:BTX0De=C06EUI@1CDe<0ADE506=SH`1?Cdl0Jf][04I6AP1KFe/0Lg=c
07IfMP1PH600@41006QXJ017AdL0B4Q804M7A`1<C4`0FUYJ05=CD`1_Kfl0ADE504];B`10@400?Cdm
07YjNP1;Bd/0Lg=c04A4A012@T80GEeM02TY:@1=CDd0AdM706YZJP1XJ6P0?Cdm059BDP0e=CD0Jf][
04M7A`15ADD0De=C06ATI013@d<0Vi^K09bLW015ADD0Fe]K05ADE017AdL0D51@06EUI@19BDT0N7Qh
03Xj>P0e=CD0FUYJ04E5A@19BDT0E5AD0492@P0];Bd0Bd];04=3@`1;Bd/0>3Ph051@D00Q8B40AdM7
010@4018B4P08b<S0451@@1=CDd0BTY:02PX:01DE5@07AdM03`l?00e=CD0?Shn04a<C010@400<c<c
04=3@`0Y:BT0FUYJ03De=@1OGel0E5AD0:BTY01]KFd0B4Q806IVIP1[Jf/0HV9R03De=@1?Cdl0>c/k
03Ph>01QHF40BDU9059BDP1CDe<0FEUI04e=C@1QHF40H61P06i^KP23Ph<206m_K`0g06ATI02][Jd0
PX:20<71`@2[Zj/0E5AD08V9R@1aLG40VIVI0:n_[`0m?Cd0J6QX05YJFP0_;bl0Bd];02XZ:P15ADD0
IFEU03Ti>@1<C4`0<c<c06a/K01?Cdl0T92@04U9B@0j>SX0<c<c04m?C`0];Bd0NWYj09bLW01VIVH0
>c/k07UiN@24Q8@0Cdm?0820P029RHT0EEEE061PH01ADE40IFEU02d];@1KFe/0DE5A03Ph>01PH600
<C4a05IFEP1OGel0=3@d04=3@`1KFe/0?Cdm07moO`0205mOG`1g0492@P1BDU80G5aL01hN7P3?cll0
K6a/05aLG01fMWH0CTi>06i^KP1RHV80?Shn04U9B@0[:b/0=SHf065QH@0S8b<0>CTi04];B`0V9RH0
FUYJ04=3@`1HF5P0CTi>051@D01fMWH0FEUI07QhN01PH600LW9b03@d=018B4P0BTY:03/k>`0d=3@0
FUYJ02DU9@0k>c/06a/K05EEE@0d=3@0EEEE02LW9`17AdL0@T92055AD@0_;bl09bLW04];B`0n?Sh0
GUiN02PX:01`L700I6AT01/K6`1eMGD08b<S04A4A00_;bl03`l?05UIF@0^;Rh0=SHf02/[:`1?Cdl0
B4Q8055AD@13@d<0ATI604a<C01:BTX0?Shn08>3P`17AdL0?clo03hn?P14A4@0HV9R05EEE@1ADE40
NGUi04A4A01BDU80K6a/03Ti>@18B4P0@d=305ADE00<30`0IFEU059BDP0a<C40ZJVY04e=C@2VYZH0
PH6108F5Q@2e]KD0ATI604];B`1PH6006QXJ05aLG00i>CT0FUYJ05iNGP1?Cdl0MGEe04m?C`1GEeL0
DE5A06][J`1oOgl0E5AD04M7A`1bLW80EUIF059BDP1hN7P00_ooool0000E05iNGP1hN7P0/K6a05IF
EP1UIFD0GEeM06a/K030`<00AdM702d];@1[Jf/0BDU906UYJ@2LW9`0>3Ph01lO7`0m?Cd0EUIF04a<
C02@T900NGUi0080;2`/0280DE5A069RHP1mOGd0^k^k05MGE`0K6a/0=3@d06YZJP1bLW80X:2P07]k
N`0Q8B40EeMG07YjNP2KVi/0EUIF06m_K`1SHf<09BDU03Xj>P1/K6`0NGUi05EEE@1]KFd0CTi>02LW
9`17AdL0CTi>04E5A@10@400CTi>01DE5@0f=SH0E5AD0P1FEUH06`1ZJVX0LG5a02TY:@0o?cl0Rh^;
09VIV@0f=SH0LG5a02@T900P8200AdM706e]K@0Z:RX09bLW055AD@0R8R80?Shn08b<S02IVIT09bLW
03Ph>012@T80;Bd]05UIF@2UYJD0De=C01dM7@0203De=@0`069RHP2b/[80UiNG02TY:@0L71`0?clo
04=3@`1_Kfl0[Zj^07inOP0I6AT0;Rh^03Ph>01<C4`0Ng]k0:FUY@0X:2P07AdM03Xj>P1BDU80@410
07emO@2GUiL07alO03<c<`1aLG40OGem04a<C025QHD0AdM701TI6@1;Bd/0Q8B407=cL`1aLG40J6QX
03Hf=P10@400C4a<08B4Q015ADD0EEEE08f=S@0f=SH0<S8b065QH@2HV9P0EEEE0P1]KFd01@0N7Qh0
>3Ph07IfMP2ZZZX0@D510080I6AT08H09bLW05=CD`2=SHd0QhN704A4A01hN7P0@41003lo?`25QHD0
T92@0451@@0n?Sh0EUIF02d];@23Ph<0_[jn02d];@19BDT0GemO02l_;`1^KVh0_;bl055AD@0_;bl0
CDe=04];B`0o?cl0OWin08N7Q`0a<C40EEEE05mOG`23Ph<0I6AT09FEU@2<S8`0;Rh^05EEE@1RHV80
SHf=07AdM02k^k/0TY:B03Ph>016ATH0V9RH0;>c/`1[Jf/0bl_;05UIF@0o?cl0EeMG07EeM@28R8P0
MWIf0:BTY00^;Rh0:RXZ08N7Q`2XZ:P0FUYJ0:^[Z`1?Cdl06a/K02<S8`1`L700M7Ad05mOG`2ATI40
=SHf01lO7`1=CDd0`l?306a/K02=SHd0A4A401lO7`13@d<0]kNg06YZJP1RHV80LW9b02d];@10@400
EeMG04m?C`1FEUH0G5aL024Q8@1;Bd/0Ng]k04M7A`1ADE40GEeM03Ti>@0b<S80R8R809FEU@16ATH0
N7Qh061PH013@d<0LG5a07QhN00m?Cd0FUYJ06UYJ@10@400K6a/0:^[Z`1KFe/0Bd];07=cL`1RHV80
DU9B069RHP1mOGd0@T9203`l?01GEeL0EEEE05=CD`2RXZ80]KFe03lo?`0b<S80Bd];06=SH`1?Cdl0
`l?309nOW`0_;bl0?Shn05EEE@80JVYZ07l0[jn_09jNWP0n?Sh0GemO06QXJ01LG5`0MWIf0;>c/`1@
D500;2`/07=cL`2@T900Kfm_07UiN@2DU9@0:BTY02/[:`1OGel0Lg=c05=CD`1cLg<0Q8B403Lg=`0^
;Rh0?clo0:NWY`2g]kL0HF5Q0<k>cP1DE5@0>SXj03/k>`1_Kfl0NWYj0492@P2;Rh/0?Cdm03`l?027
QhL0OGem05eMG@1>CTh0IFEU04m?C`1HF5P0Jf][03hn?P2:RXX0Lg=c07YjNP1<C4`0DU9B07alO01i
NGT0RXZ:07EeM@1ZJVX0Kfm_05EEE@1[Jf/0J6QX03Ti>@19BDT0@d=304Q8B00c<c<0B4Q804];B`0o
?cl0Hf=S07IfMP1KFe/0MGEe0492@P1_Kfl0FUYJ06MWI`1:BTX0E5AD06=SH`1eMGD0Kfm_04];B`1P
H600DU9B05=CD`1EEED0;Bd]03Ti>@0P8200Cdm?028R8P0n?Sh0IVIV04E5A@1^KVh0@T9204];B`1C
De<0CDe=05QHF00a<C40A4A405mOG`1EEED0EUIF02XZ:P1BDU80>SXj05=CD`1DE5@0CTi>03Lg=`1R
HV80J6QX02TY:@0m?Cd0NGUi08Z:RP1hN7P0G5aL02h^;P1SHf<0?Cdm051@D01RHV80>CTi0080?3`l
06@0@T9201LG5`0h>3P0?3`l04i>CP14A4@0@T9202l_;`15ADD0:b/[04i>CP0_;bl0?Cdm04A4A010
@400?Cdm05MGE`0n?Sh0CDe=05]KF`1/K6`0KVi^06=SH`1KFe/0JVYZ051@D01RHV80A4A406e]K@1X
J6P0PH6107=cL`1oOgl0K6a/0410@01EEED0O7al09VIV@0f=SH0I6AT05QHF00];Bd0?Shn03Ph>01T
I6@0B4Q809nOW`1HF5P0De=C055AD@2DU9@0ZZZZ08V9R@2LW9`0De=C06MWI`1UIFD0ATI608b<S020
P800][Jf0:ZZZP1CDe<0RXZ:08:2PP13@d<0C4a<05=CD`13@d<0Fe]K03hn?P1=CDd07QhN07=cL`0g
=cL0SXj>04A4A01YJFT092@T04a<C00M7Ad0Bd];07IfMP1aLG40;bl_061PH01`L700;Bd]0<K6aP2H
V9P0:b/[04=3@`0J6QX0YZJV02l_;`1QHF40Fe]K05ADE02?Shl0B4Q80P1BDU80A`0k>c/0N7Qh079b
LP1?Cdl0QHF505QHF01^KVh0EEEE06EUI@1MGEd0:BTY09^KV`1?Cdl0Jf][06MWI`0h>3P0BDU903lo
?`10@400FUYJ03`l?00n?Sh0EeMG02LW9`13@d<0J6QX04U9B@0g=cL0CDe=05eMG@10@400ATI604M7
A`0`<300EEEE05mOG`1]KFd0<c<c051@D01HF5P0<S8b03`l?01IFET06QXJ03/k>`0I6AT0A4A402LW
9`16ATH0<S8b04e=C@14A4@0CDe=03<c<`0j>SX0BDU903dm?@1CDe<0>CTi0451@@17AdL07alO05mO
G`0J6QX0Bd];03@d=00W9bL0FEUI03/k>`0n?Sh0<c<c0080?clo03D0ADE503/k>`18B4P0@T9203De
=@0^;Rh0EEEE03/k>`1RHV80Cdm?03Lg=`2:RXX0QHF505YJFP1YJFT08b<S038b<P15ADD0:BTY05eM
G@1DE5@0H61P038b<P1bLW80?3`l03Lg=`1aLG40Cdm?0<O7a`1mOGd0Ng]k09ZJVP1HF5P0FUYJ07If
MP0e=CD0G5aL034a<@1_Kfl0Jf][05ADE01/K6`0?clo04=3@`1@D500RXZ:09JFUP1@D500KFe]08:2
PP1KFe/0DU9B08>3P`02ooooo`0008X0K6a/06i^KP2RXZ80PX:20:b/[016ATH0Fe]K05UIF@1lO7`0
QHF506][J`0g=cL0BDU9079bLP1oOgl0G5aL07UiN@0H61P0=cLg05IFEP1cLg<0Cdm?06][J`1`L700
:2PX02/[:`1aLG40Rh^;04=3@`1TI6@0?Shn0451@@1TI6@0Shn?05=CD`0i>CT0CDe=02l_;`0n?Sh0
IVIV07AdM00/;2`0820P04];B`18B4P0=SHf07AdM02WYjL0;bl_02`/;01VIVH0Bd];05MGE`2OWil0
Cdm?028R8P1:BTX0IFEU03lo?`2g]kL0P82001lO7`10@400C4a<05mOG`1RHV80_[jn03Hf=P0V9RH0
C4a<07AdM01_Kfl0PH610:f][@1BDU80;Rh^03dm?@1TI6@0B4Q808^;R`1ADE408B4Q02l_;`1DE5@0
PX:206i^KP2?Shl0;Rh^01LG5`1?Cdl0UIFE07moO`1@D500Rh^;03/k>`0_;bl0D51@07QhN013@d<0
AdM703De=@0W9bL0DU9B07alO01^KVh0<30`05=CD`0j>SX0;Bd]051@D02BTY80G5aL03dm?@1=CDd0
;Rh^04U9B@1kNg/0MGEe038b<P0n?Sh0;Rh^03hn?P1@D500M7Ad04E5A@0O7al0EUIF06UYJ@1ADE40
?Cdm07YjNP0];Bd08R8R03@d=01@D500BTY:07IfMP2?Shl202LW9`1U04Y:BP1aLG40?Shn08V9R@2A
TI40:b/[03<c<`1KFe/0UYJF05ADE030`<00Fe]K02<S8`1ADE40LG5a051@D022PX80Ng]k02TY:@1;
Bd/0VYZJ07QhN028R8P0V9RH038b<P0g=cL0CTi>07alO01gMgL0UiNG02d];@0e=CD0Bd];069RHP1I
FET0WYjN08F5Q@0U9BD0?Shn07IfMP1dM7@0E5AD06YZJP1nOWh0=3@d03Ti>@23Ph<0^;Rh065QH@1]
KFd0R8R80410@01?Cdl0KFe]06m_K`1ADE40T92@08V9R@0X:2P0FUYJ08^;R`21PH40CDe=07emO@1@
D500>CTi07inOP22PX80@D5104];B`1HF5P0ATI6059BDP2b/[80M7Ad03hn?P1MGEd0MgMg05EEE@2_
[jl0MGEe01hN7P0k>c/0CDe=061PH01jNWX0Zj^[03@d=015ADD0F5QH04i>CP1kNg/0]KFe03Xj>P0a
<C40IVIV05QHF02:RXX0^k^k05IFEP0T92@00P1fMWH0;@1[Jf/0d];B04i>CP0W9bL0I6AT0:f][@1Z
JVX0XZ:R05eMG@0n?Sh0CDe=08f=S@29RHT0OWin0<g=c@1TI6@0=3@d05mOG`2^[Zh0M7Ad09:BTP2G
UiL0>c/k03Ti>@21PH40XZ:R08B4Q01dM7@0XZ:R03@d=00l?3`0QXJ60:f][@1NGUh0De=C09>CT`1<
C4`0<S8b06i^KP2WYjL0IVIV05UIF@1EEED07alO05EEE@02092@T00704Y:BP1dM7@0BTY:03`l?01E
EED0PH6104i>CP0204I6AP1;03Hf=P1FEUH0EEEE07inOP0i>CT09RHV0410@01>CTh0GemO05eMG@2A
TI40O7al02l_;`13@d<0AdM706QXJ01RHV80X:2P071`L00m?Cd0Rh^;07inOP1EEED0BDU906][J`1E
EED0BTY:05UIF@12@T80H61P04];B`1MGEd0BTY:04i>CP1bLW80MgMg06YZJP1NGUh0OWin06][J`1K
Fe/0GEeM04Y:BP0m?Cd0F5QH04Q8B011@D40?3`l05mOG`14A4@0>CTi04m?C`1MGEd0KVi^065QH@0l
?3`0EeMG05QHF01NGUh0CTi>05QHF01DE5@0De=C05eMG@17AdL0CDe=04A4A00o?cl0BTY:04U9B@1G
EeL0<C4a03hn?P0U9BD0E5AD0080De=C04<0JVYZ030`<00k>c/0?3`l02/[:`1BDU80:2PX065QH@1g
MgL0?Shn03`l?00o?cl0HF5Q04A4A00n?Sh0Cdm?071`L01?Cdl0T92@07AdM00/;2`0B4Q806a/K01M
GEd0OWin061PH010@400GEeM02PX:00a<C40JVYZ04I6AP1EEED0BDU904A4A00R8R80B4Q803`l?00f
=SH0@T9204M7A`10@400EeMG0451@@1MGEd0AdM704Y:BP1^KVh0Cdm?02d];@1:BTX092@T04U9B@0a
<C40?3`l03/k>`10@400<c<c04=3@`0/;2`0CTi>04Y:BP1WIfL0G5aL08j>SP1GEeL0BTY:0080DE5A
00d0B4Q803Ph>01:BTX0HV9R04M7A`0n?Sh0EUIF05eMG@17AdL0EEEE03/k>`1<C4`0B4Q80080KFe]
0;80Kfm_061PH01HF5P0XJ6Q04M7A`2@T900R8R805eMG@1kNg/0Fe]K0<K6aP2b/[809RHV05IFEP1U
IFD0De=C06IVIP19BDT0EEEE04m?C`0g=cL0DE5A03<c<`1eMGD0@D51096AT@13@d<0GEeM02d];@1O
Gel09bLW05ADE01@D500?clo02h^;P1[Jf/0GUiN04M7A`2NWYh0Rh^;030`<013@d<0=cLg08B4Q00j
>SX0K6a/04a<C01CDe<0L71`04=3@`1KFe/0F5QH0492@P1JFUX0Kfm_03lo?`1iNGT0?3`l069RHP1?
Cdl0@d=303lo?`0n?Sh0^;Rh04m?C`1oOgl0MWIf03Ti>@11@D40<C4a04M7A`1bLW80CTi>03Lg=`12
@T808B4Q03hn?P16ATH0>3Ph03Ti>@0g=cL0@d=302PX:01DE5@0GEeM02/[:`1=CDd0@T9206EUI@0]
;Bd0<30`038b<P0K6a/09RHV03Lg=`0@4100<C4a02LW9`1KFe/0>c/k05ADE014A4@0@d=3055AD@1B
DU80=cLg034a<@1LG5`0?3`l04m?C`0Y:BT0I6AT05=CD`0m?Cd0GEeM02LW9`12@T80@41003dm?@1>
CTh05aLG0492@P0X:2P0B4Q804=3@`1;Bd/0<c<c04U9B@0o?cl0>3Ph02DU9@1JFUX0;bl_0451@@0o
?cl0<C4a055AD@1JFUX0Kfm_08b<S00Y:BT0?Cdm04I6AP0X:2P0A4A406UYJ@2ATI40EUIF07EeM@0m
?Cd0J6QX0:n_[`11@D40Lg=c065QH@1/K6`0Rh^;02l_;`15ADD0E5AD01/K6`1DE5@07QhN05mOG`1?
Cdl0C4a<07UiN@1CDe<0C4a<04m?C`23Ph<0I6AT05UIF@1CDe<0DU9B05=CD`1BDU80H61P0_ooool0
003o08R8R01UIFD0Kfm_06MWI`2GUiL0N7Qh0451@@1LG5`0BTY:07AdM027QhL0;Bd]02XZ:P19BDT0
@41006m_K`1eMGD0=cLg024Q8@1<C4`0HF5Q04];B`2>SXh0XZ:R01/K6`0e=CD0AdM705]KF`1NGUh0
_[jn07EeM@0P8200DU9B08R8R01MGEd0RHV90:n_[`0Z:RX07alO05ADE02?Shl0RXZ:06e]K@28R8P0
;2`/055AD@1LG5`0L71`06ATI01QHF40IVIV01TI6@1GEeL0WYjN08R8R015ADD0EUIF04M7A`0L71`0
FUYJ09^KV`1;Bd/0@41007alO00[:b/09bLW06YZJP1YJFT07AdM065QH@1DE5@0820P04];B`1PH600
LG5a03Ph>01GEeL0<30`03lo?`1CDe<0EUIF03De=@1PH600LG5a03@d=015ADD0N7Qh04I6AP0L71`0
;Rh^03Ph>011@D40NWYj08Z:RP0a<C40:2PX03`l?01XJ6P0FEUI09:BTP2>SXh051@D034a<@1dM7@0
EEEE05QHF02;Rh/0@410028R8P1EEED0J6QX05IFEP1dM7@0U9BD02h^;P0k>c/0EEEE07MgM`1aLG40
UiNG03`l?00M7Ad0=SHf075aL@2h^;P0Hf=S0<K6aP1?Cdl06a/K03Hf=P1aLG40S8b<05iNGP1lO7`0
=SHf03<c<`1DE5@0JFUY07AdM018B4P0SHf=03lo?`0a<C40?Cdm08F5Q@1ZJVX0DU9B06YZJP19BDT0
AdM706QXJ02WYjL0FEUI08N7Q`1eMGD0>3Ph05aLG02YZJT0D51@06EUI@1@D500>SXj07MgM`2i^KT0
E5AD04m?C`1;Bd/09bLW07emO@2BTY80Lg=c03Lg=`1GEeL0B4Q8055AD@2:RXX0Xj>S05]KF`0a<C40
CTi>06][J`1UIFD0Shn?0<C4a01=CDd092@T04U9B@1lO7`0XJ6Q0;Bd]036a/H0=cLg05QHF02ATI40
PH61071`L02n_[h0aLG502XZ:P0h>3P0LG5a09fMW@2RXZ80[Jf]04E5A@0o?cl0CDe=06QXJ02CTi<0
WIfM08N7Q`0/;2`0CTi>05QHF02TY:@0Lg=c09RHV01PH600;Rh^09FEU@2][Jd0DE5A09VIV@0j>SX0
>c/k05MGE`1oOgl0FEUI05QHF01KFe/0:b/[05EEE@29RHT0K6a/06IVIP2PX:00Bd];0492@P2j^[X0
c/k>04a<C02QXJ40GUiN04=3@`1/K6`0QHF504a<C01SHf<0Cdm?03@d=01nOWh0X:2P03Xj>P1EEED0
IFEU003104M7A`0c<c<0SHf=0:BTY00k>c/0Hf=S08b<S01<C4`0De=C09>CT`1^KVh0>3Ph06e]K@2D
U9@0FUYJ07MgM`2m_Kd0U9BD03Ph>01=CDd0J6QX06][J`1^KVh0[Jf]07=cL`12@T80?Shn07IfMP20
P800TY:B0:>SX`0f=SH09BDU069RHP2ATI40JFUY08j>SP1ADE40@41005YJFP1XJ6P0DU9B075aL@2B
TY80@4100451@@1/K6`0Ogmo08R8R01>CTh0Ti>C05EEE@0U9BD0@d=3071`L01eMGD0BDU908>3P`0k
>c/08R8R03dm?@1OGel0T92@05aLG021PH40LW9b05IFEP1:BTX0OGem04];B`1ADE40L71`0451@@22
PX80DU9B079bLP1<C4`0Hf=S07inOP1VIVH0Q8B408^;R`1MGEd0ATI604e=C@1UIFD0P82001lO7`1D
E5@0EEEE04Q8B00a<C40DU9B051@D00j>SX0GemO08^;R`1YJFT0MWIf03/k>`1jNWX0HV9R08>3P`1@
D500IfMW07AdM01hN7P0M7Ad05EEE@1TI6@0CDe=04];B`1gMgL0B4Q805QHF011@D40BTY:03Xj>P0l
?3`0CDe=03dm?@1FEUH0EEEE06=SH`15ADD0=SHf04E5A@0S8b<0C4a<06a/K01OGel0JFUY03hn?P1>
CTh0C4a<05MGE`1=CDd0@d=304U9B@2QXJ40MGEe03hn?P1NGUh0JVYZ06UYJ@1bLW80MGEe05aLG01c
Lg<0>3Ph03dm?@1GEeL0?Shn04E5A@0k>c/0BTY:01lO7`0j>SX0<C4a03hn?P0m?Cd0>c/k02HV9P0o
?cl071`L055AD@0Y:BT0?Shn04e=C@0i>CT0>3Ph04Q8B00Z:RX0;bl_02/[:`19BDT0ATI605EEE@0X
:2P0A4A403@d=01?Cdl0=3@d05MGE`1EEED0Rh^;05=CD`1GEeL0DE5A05mOG`1UIFD0HF5Q05]KF`02
04A4A01B06QXJ018B4P0@D5105eMG@1YJFT0KFe]0820P01YJFT0De=C0492@P27QhL0E5AD061PH027
QhL0=cLg08j>SP1@D500H61P08J6QP1<C4`0Ogmo092@T00l?3`0RHV906MWI`15ADD0CDe=0410@013
@d<0DU9B0410@01UIFD0@D5105]KF`1QHF40OWin06EUI@1HF5P0<S8b07QhN00Z:RX0FEUI06QXJ01T
I6@0>c/k071`L01>CTh0BDU90:b/[02ATI40?Shn04U9B@0];Bd0OGem03hn?P1UIFD0Fe]K04=3@`1S
Hf<07alO05IFEP1EEED0<S8b04U9B@1GEeL0;Rh^08R8R01OGel0WinO06a/K01YJFT0Cdm?04E5A@3C
dm<0HV9R06ATI01DE5@0G5aL0:FUY@1HF5P0>3Ph051@D080@D5106P0EeMG02/[:`0o?cl0CDe=02l_
;`26QXH0FEUI059BDP0P8200;bl_04Q8B00/;2`0AdM707EeM@2TY:@0ATI603De=@0n?Sh0;2`/03lo
?`0n?Sh0>3Ph05ADE00n?Sh0FEUI03Xj>P1>CTh0@T9205mOG`1LG5`0D51@05ADE010@400B4Q805]K
F`1_Kfl0>CTi05ADE01MGEd0?clo05aLG00Y:BT0CDe=04A4A00/;2`0Ng]k02h^;P0e=CD0=SHf07Mg
M`0m?Cd0B4Q804U9B@1UIFD0?clo04U9B@1[Jf/0WIfM03dm?@14A4@0?Cdm0410@01LG5`0J6QX05QH
F01SHf<0<30`05=CD`1iNGT0@T9204e=C@10@400C4a<03Hf=P2ZZZX0IVIV07]kN`1`L700>CTi07in
OP1]KFd0Ogmo0;^k^`13@d<0CDe=05aLG013@d<0Vi^K04U9B@1WIfL0F5QH06QXJ02SXj<0D51@05EE
E@1CDe<0N7Qh06=SH`1UIFD0IVIV08B4Q01VIVH0EEEE07EeM@;ooooo0000`P1oOgl0SXj>09nOW`1<
C4`0KFe]08n?S`2PX:00U9BD03`l?01;Bd/0ZJVY07UiN@2GUiL0PX:20410@014A4@0F5QH09fMW@1Q
HF40Z:RX03De=@11@D40DU9B06=SH`1WIfL0De=C0861P@0];Bd0CTi>06m_K`2NWYh0EUIF06UYJ@10
@400ADE503/k>`1kNg/0FEUI034a<@1ZJVX0?3`l02TY:@15ADD0I6AT055AD@0N7Qh0EUIF03Hf=P1B
DU80JVYZ08N7Q`0];Bd06a/K03Ti>@1MGEd0F5QH07QhN00b<S805ADE028R8P1/K6`0I6AT07QhN02H
V9P09BDU024Q8@0m?Cd0CDe=03hn?P2JVYX0LW9b01TI6@0T92@0E5AD071`L01bLW80ZJVY02TY:@0Z
:RX0EUIF059BDP17AdL0WYjN0;fm_@17AdL0=SHf04m?C`2?Shl0EeMG09FEU@1mOGd06ATI03Hf=P1a
LG40O7al06QXJ01oOgl0Bd];02HV9P1>CTh0SHf=04m?C`1jNWX0KVi^02/[:`0X:2P0HV9R0820P00g
=cL0N7Qh05MGE`0`<300@410096AT@1nOWh0<30`06UYJ@0b<S80<30`07IfMP2ATI40?3`l02`/;01;
Bd/0:b/[05mOG`2?Shl0NWYj02l_;`1?Cdl0GemO03hn?P1GEeL0LW9b04a<C00L71`0EUIF05aLG00m
?Cd0AdM708j>SP1FEUH08B4Q03lo?`11@D40BDU907AdM02h^;P0B4Q8034a<@13@d<0GUiN04U9B@2J
VYX0[Zj^020P800c<c<0RXZ:06e]K@2TY:@0DE5A03<c<`11@D40R8R807MgM`2j^[X0Shn?020P800i
>CT0GEeM08>3P`2ATI40^;Rh05ADE00k>c/0EEEE08B4Q02FUYH0M7Ad0;Rh^025QHD0@d=3075aL@2f
][H0_[jn08J6QP2ZZZX0Fe]K04];B`1]KFd0Z:RX092@T01jNWX0YJFU0P0d=3@0o`2@T900]KFe065Q
H@1TI6@0Cdm?02`/;01:BTX0T92@09^KV`0j>SX0De=C02@T900j>SX0N7Qh09BDU01BDU80=CDe05YJ
FP0g=cL0DE5A08n?S`2e]KD0BDU9059BDP1ADE40EUIF08V9R@24Q8@08b<S04];B`20P800FUYJ075a
L@2UYJD0<C4a02d];@1RHV80Bd];06EUI@27QhL0=3@d03<c<`1;Bd/0Shn?069RHP2h^;P0Fe]K02l_
;`1GEeL0K6a/05IFEP2QXJ40PH6102TY:@0e=CD0IVIV065QH@25QHD0W9bL03Xj>P13@d<0E5AD09JF
UP1hN7P0[Zj^0:FUY@0l?3`0JFUY07QhN02?Shl0Cdm?0<30`027QhL0<C4a0451@@1lO7`0V9RH07]k
N`2][Jd0K6a/034a<@12@T80GUiN07moO`1GEeL0Ogmo04];B`1CDe<0FUYJ07MgM`1NGUh0L71`06EU
I@0e=CD0=SHf06m_K`1XJ6P0:RXZ069RHP1[Jf/0<30`03De=@1TI6@0Kfm_030`<018B4P0IfMW0410
@00e=CD0LW9b05QHF00I6AT0A4A405eMG@0m?Cd0HF5Q07YjNP1bLW809RHV03Lg=`1BDU80IfMW06AT
I02?Shl0Ti>C08j>SP2;Rh/0Q8B404a<C01=CDd0PH6106IVIP1`L700EUIF05mOG`1ZJVX0Fe]K05aL
G01RHV80GEeM05UIF@1OGel0Fe]K04U9B@1DE5@0GUiN02d];@1@D500>3Ph04a<C010@400FEUI05EE
E@1:BTX0C4a<0820P01UIFD0O7al04Q8B01gMgL0J6QX07=cL`1]KFd0V9RH06a/K01DE5@0Bd];04m?
C`1IFET0Jf][06i^KP1EEED0@T9204m?C`10@400EEEE02DU9@1<C4`0IVIV04M7A`1MGEd0>3Ph03hn
?P1LG5`0BTY:06IVIP1LG5`0GUiN05MGE`1DE5@0EUIF04M7A`1BDU80Cdm?030`<01;Bd/0Cdm?05MG
E`2:RXX0C4a<03Hf=P1;Bd/0QhN706IVIP1lO7`0IVIV03De=@1^KVh0FUYJ06ATI01WIfL0A4A403hn
?P1=CDd0BDU902l_;`18B4P0>c/k055AD@1>CTh0?clo034a<@1=CDd07QhN05mOG`0`<300DE5A06m_
K`12@T80ADE504i>CP0];Bd0@41003@d=01RHV80A4A405QHF00^;Rh0Fe]K03Hf=P1<C4`0?Cdm06=S
H`1FEUH0I6AT05eMG@2GUiL0IFEU04Q8B01=CDd0S8b<061PH00`<300J6QX05iNGP00/@14A4@0Cdm?
05UIF@1iNGT0=SHf07AdM01@D500Lg=c04E5A@1WIfL0EEEE075aL@2FUYH0@d=30:VYZ@1ADE40D51@
06a/K01aLG40[:b/09JFUP0k>c/0QHF508>3P`15ADD0D51@04i>CP1<C4`0JVYZ03De=@1LG5`0A4A4
06i^KP1=CDd0Ogmo05ADE01YJFT0<c<c055AD@1MGEd0Ti>C07YjNP1_Kfl0Fe]K09NGU`1]KFd0D51@
0<?3``2VYZH0?3`l05MGE`0f=SH0S8b<01LG5`23Ph<0R8R805IFEP1fMWH0>SXj07alO01_Kfl0B4Q8
05=CD`1ZJVX0@D5108J6QP0_;bl0CDe=05IFEP1iNGT0BDU904Q8B01mOGd0:BTY06m_K`1ADE409bLW
04A4A012@T80Cdm?05QHF00L71`0>CTi08B4Q00];Bd0@T9205UIF@0c<c<0A4A403Lg=`1TI6@06QXJ
04A4A00_;bl0?Shn04M7A`0];Bd0ATI603@d=00c<c<0?Cdm02@T9019BDT0JVYZ03@d=00n?Sh0;Rh^
05UIF@13@d<0E5AD038b<P18B4P0FUYJ04M7A`0g=cL0=SHf04I6AP0d=3@0@D5102PX:01VIVH0DU9B
06UYJ@2HV9P0?Cdm04a<C00c<c<0ATI60410@00O7al0=CDe04e=C@1;Bd/0ADE504i>CP14A4@0BTY:
05aLG012@T80=CDe05EEE@0S8b<0@d=30410@00o?cl0OWin06UYJ@10@400KFe]01/K6`1MGEd0K6a/
05eMG@1eMGD0DE5A061PH00N7Qh0KVi^02d];@1]KFd0M7Ad0451@@23Ph<0PX:206QXJ026QXH0F5QH
06][J`1/K6`0>CTi05EEE@1?Cdl0QHF507QhN01MGEd0Kfm_04M7A`0204];B`0805MGE`1BDU80Bd];
05]KF`1DE5@0D51@06=SH`1IFET2ooooo`000>/0FEUI07AdM01fMWH0I6AT08j>SP1DE5@0D51@0:VY
Z@1FEUH0DE5A0451@@0f=SH0H61P09bLW018B4P0=SHf0410@01_Kfl0?3`l0861P@1bLW80:BTY04A4
A01?Cdl0FEUI06=SH`2CTi<0=3@d02TY:@1NGUh0J6QX055AD@20P800MWIf02PX:011@D40Cdm?04];
B`1QHF40f][J051@D00L71`08b<S05=CD`1jNWX0Lg=c0;Zj^P11@D406ATI04E5A@1lO7`0F5QH075a
L@1JFUX07alO03dm?@1_Kfl0TY:B03hn?P1OGel0=SHf02l_;`1:BTX0KFe]06ATI01EEED0Vi^K030`
<00[:b/0E5AD07IfMP0j>SX0Cdm?07AdM00i>CT0DU9B07moO`29RHT0?Cdm065QH@18B4P0:b/[059B
DP1RHV80MGEe02TY:@1hN7P0;bl_03De=@1@D500KVi^03Ti>@13@d<0?Cdm01lO7`0l?3`0NWYj065Q
H@0N7Qh0@4100451@@0l?3`0Lg=c08^;R`0/;2`07AdM030`<00j>SX0B4Q808n?S`1nOWh0:b/[02h^
;P1LG5`0Rh^;06a/K02GUiL0?clo02HV9P0o?cl0M7Ad08V9R@1aLG40VIVI02l_;`0f=SH0EeMG08R8
R01NGUh0QHF509BDU00S8b<0=3@d06EUI@2KVi/0GUiN0861P@22PX808R8R0451@@20P800NGUi05]K
F`2][Jd0N7Qh02`/;01BDU80H61P09BDU01]KFd0YZJV0451@@15ADD0LW9b09bLW01nOWh0Ti>C07Yj
NP0c<c<0IVIV0;^k^`1HF5P0OGem092@T00];Bd0G5aL0;6a/@1RHV80GEeM06QXJ01BDU80B4Q807=c
L`2RXZ80AdM7059BDP1[Jf/0BDU903`l?01dM7@0XJ6Q03Lg=`0c<c<0CTi>03dm?@16ATH0Ogmo08B4
Q00l?3`0@d=305YJFP1[Jf/0O7al0;jn_P1JFUX0:BTY04M7A`1dM7@0OWin08>3P`2<S8`0:BTY02/[
:`1@D500Ng]k08^;R`2MWId0EeMG02<S8`1LG5`0Jf][05ADE01jNWX0/k>c02/[:`15ADD0TI6A0:RX
Z01iNGT0/K6a059BDP13@d<0GEeM08f=S@1LG5`0QhN708B4Q01>CTh0De=C09:BTP1cLg<0SHf=08^;
R`0^;Rh0D51@0080Jf][01`0MgMg06a/K00Q8B40@D5107]kN`2/[:`0BDU905YJFP0Q8B40:b/[06AT
I01nOWh0Bd];07EeM@13@d<0>c/k05eMG@2>SXh0KFe]05EEE@1eMGD0>SXj04m?C`1RHV80_Kfm08R8
R01LG5`0JFUY0P0l?3`0o`1nOWh0ZJVY0451@@15ADD0GUiN04Q8B01?Cdl0O7al09BDU00d=3@0A4A4
05aLG01>CTh0L71`0:JVYP1dM7@0;bl_04Y:BP1ADE40H61P075aL@2h^;P0FEUI030`<01:BTX0DE5A
05mOG`2?Shl0[jn_01lO7`18B4P0DU9B04m?C`1=CDd0PX:20:f][@0Q8B40@410069RHP1GEeL0?Shn
0861P@2h^;P07AdM04A4A01WIfL0GEeM03Ph>01HF5P0[Zj^02XZ:P1>CTh0Shn?08J6QP1BDU80>SXj
04m?C`1KFe/0DU9B04e=C@0a<C40JVYZ051@D01UIFD0@T92051@D01ZJVX0GUiN09VIV@1SHf<0Q8B4
07inOP19BDT0JVYZ06IVIP0V9RH0ADE504a<C01=CDd0=cLg04e=C@1?Cdl0Vi^K08B4Q01ZJVX0F5QH
05aLG01SHf<0MWIf05iNGP1=CDd0<30`065QH@1PH600Cdm?071`L01UIFD0FEUI04i>CP1:BTX0G5aL
0410@01>CTh0<c<c03hn?P0^;Rh0ATI605IFEP1ADE40FEUI03<c<`0j>SX0Bd];071`L01WIfL0Bd];
061PH01dM7@0ATI606QXJ014A4@0CDe=06=SH`1>CTh0EEEE04i>CP1EEED0UiNG06YZJP0n?Sh0BDU9
08N7Q`2XZ:P0X:2P06=SH`1;Bd/0EEEE02d];@0c<c<0IVIV04I6AP1>CTh0@D5105=CD`0f=SH0@T92
04Q8B00h>3P0CTi>03Xj>P0g=cL0@D5103<c<`1CDe<0>3Ph05ADE01lO7`0@D5103Hf=P11@D40>c/k
04U9B@12@T80=CDe03lo?`1MGEd0D51@03Hf=P0o?cl0DE5A04Y:BP1]KFd0I6AT08J6QP1KFe/0CTi>
05EEE@1CDe<0I6AT0:BTY01/K6`0?3`l06EUI@15ADD0?Cdm04a<C01>CTh0Kfm_0492@P1^KVh0JVYZ
05MGE`1DE5@0WYjN07EeM@1VIVH0K6a/06=SH`36a/H0GemO05aLG01SHf<0D51@09ZJVP2;Rh/0Fe]K
07QhN02JVYX0CDe=06ATI01XJ6P0=3@d03Lg=`0h>3P0@41002XZ:P1=CDd0IfMW0:>SX`1?Cdl0E5AD
05QHF01>CTh0=cLg051@D01WIfL0PH6106EUI@1EEED0?clo06=SH`39bLT0P82003Ph>01HF5P0?Shn
08n?S`0i>CT0K6a/05IFEP1UIFD0QHF502/[:`18B4P0?clo02XZ:P1gMgL0OWin04];B`28R8P0:b/[
05mOG`1BDU80Q8B404a<C000=`0i>CT0XJ6Q03Ph>01cLg<0FEUI0410@01MGEd0<C4a05]KF`1fMWH0
8R8R02LW9`1DE5@0?Cdm05]KF`1XJ6P0;Rh^05EEE@0k>c/0AdM702/[:`1HF5P0<C4a03<c<`11@D40
ATI606QXJ00O7al0=CDe02l_;`0T92@0ATI603hn?P0];Bd0Bd];02l_;`0i>CT0<30`03dm?@0c<c<0
ATI604M7A`1<C4`0?Cdm03<c<`10@400ADE505YJFP0_;bl0HV9R04Y:BP0_;bl0CDe=030`<01UIFD0
0P10@400>`0k>c/061PH04Q8B011@D40DU9B02l_;`0e=CD0@T9205IFEP13@d<0=cLg04];B`1RHV80
8b<S051@D016ATH0>CTi0410@01VIVH0C4a<07IfMP0^;Rh0Bd];04a<C00[:b/0ADE503hn?P1LG5`0
AdM709>CT`0e=CD0L71`04A4A016ATH0P82006EUI@1bLW80SXj>04U9B@1ADE40FUYJ04a<C01aLG40
DU9B05]KF`1FEUH0Kfm_09RHV01TI6@0@D51051@D01[Jf/0GemO04i>CP1KFe/0LW9b04i>CP1;Bd/0
G5aL00;ooooo0000I`23Ph<0HV9R07inOP1[Jf/0][Jf065QH@0o?cl0JFUY06IVIP2ATI40KVi^03Hf
=P1RHV80M7Ad06EUI@2<S8`0O7al034a<@0[:b/0EEEE07alO01ADE40Ph>306e]K@0Q8B40GEeM04Q8
B01DE5@0@T920:NWY`1LG5`0<C4a075aL@1_Kfl0HF5Q06EUI@2HV9P0B4Q801hN7P1YJFT0/;2`05=C
D`1/K6`0G5aL03<c<`0i>CT0QXJ607UiN@0];Bd0>CTi04U9B@0X:2P0DU9B07UiN@0n?Sh0;bl_04e=
C@1?Cdl0>SXj065QH@1LG5`07QhN03@d=01;Bd/0AdM704E5A@2LW9`0?Shn01lO7`1;Bd/0C4a<0492
@P1QHF40ZJVY03De=@0Q8B40C4a<06][J`1ADE40T92@04A4A00X:2P0?3`l05aLG01mOGd0DU9B0;Jf
]P0c<c<07QhN04I6AP1SHf<0FEUI08b<S02][Jd0:BTY02@T901@D500NWYj05MGE`1/K6`0@T9201hN
7P0m?Cd00P1iNGT08@1SHf<0Ng]k024Q8@0_;bl0?Cdm05aLG01hN7P0Jf][065QH@0R8R80:2PX05aL
G023Ph<0D51@08N7Q`0i>CT07AdM03Lg=`1<C4`0HV9R04M7A`1fMWH09bLW01lO7`1:BTX0Hf=S055A
D@0e=CD0F5QH034a<@0e=CD0HV9R071`L00203Lg=`3108R8R00m?Cd0A4A409jNWP2MWId0BTY:0410
@01JFUX0=CDe03hn?P2JVYX0GEeM02<S8`1ZJVX0QHF505MGE`1WIfL0UYJF02l_;`12@T80MGEe05QH
F02HV9P0WinO030`<00i>CT0EEEE05MGE`1_Kfl0WIfM030`<015ADD0HF5Q06e]K@1oOgl0WinO0;:b
/P0l?3`0EEEE06=SH`2PX:00QHF508V9R@2LW9`07AdM0451@@1`L700UiNG08F5Q@2?Shl0RXZ:02PX
:01CDe<0KVi^08B4Q01GEeL0QhN705iNGP10@400Q8B4079bLP1RHV80<30`0::RXP1BDU80:b/[08F5
Q@2/[:`0DE5A09JFUP1DE5@0@D5106ATI02GUiL0OWin04Y:BP2j^[X0A4A403Ph>02ATI40ZJVY04A4
A01_Kfl0>3Ph02d];@1FEUH0]KFe04Y:BP1MGEd0EeMG03Xj>P1@D500QHF504];B`0m?Cd0HF5Q04U9
B@2MWId0WinO03hn?P0a<C40EEEE065QH@1eMGD0T92@03Hf=P0O7al0BDU9069RHP1?Cdl0UYJF069R
HP0/;2`0DU9B06QXJ01kNg/0MgMg09nOW`1@D500@41004M7A`1ZJVX0OWin08>3P`2e]KD0=SHf04m?
C`1VIVH0YjNW08R8R01]KFd0X:2P03De=@1MGEd0PH6109nOW`1VIVH0KVi^096AT@12@T80=cLg08Z:
RP2i^KT0F5QH0861P@1CDe<09RHV05QHF01NGUh0QhN705=CD`20P800@T9202`/;024Q8@0ZZZZ05UI
F@0h>3P0J6QX04Q8B00[:b/0BDU908Z:RP1BDU80=3@d06ATI015ADD0;Rh^06i^KP2/[:`0GemO02LW
9`0o?cl0DE5A03Ti>@1IFET0^k^k07moO`0l?3`0Kfm_07alO01IFET0C4a<06EUI@19BDT0B4Q804m?
C`11@D40KVi^071`L01VIVH0ADE505QHF00208J6QP0h09JFUP1SHf<0Ng]k08V9R@1^KVh0NGUi06YZ
JP0g=cL0G5aL04m?C`12@T80@41005mOG`11@D40@d=305iNGP1MGEd0Kfm_06EUI@16ATH0C4a<05YJ
FP1aLG40GemO07IfMP1MGEd0Fe]K06IVIP1GEeL0H61P05EEE@1LG5`0H61P03Lg=`1ADE40?3`l05IF
EP15ADD0B4Q805EEE@0i>CT0Cdm?04=3@`0o?cl0@d=303Hf=P1GEeL0ADE505mOG`1_Kfl0@T9207Ee
M@1BDU80De=C06IVIP1ADE4205aLG01:05EEE@2MWId0M7Ad04A4A01:BTX0GemO04m?C`1TI6@0F5QH
04a<C01XJ6P0@d=304Q8B01dM7@0F5QH065QH@0l?3`0GemO03Hf=P1KFe/0<c<c03/k>`0l?3`0<c<c
02@T900h>3P0:RXZ04U9B@0d=3@0FUYJ06YZJP1ADE40ADE505IFEP17AdL0D51@04E5A@1GEeL0Cdm?
06YZJP10@400G5aL03lo?`1=CDd0?3`l04Q8B01TI6@0SHf=05YJFP1CDe<0Jf][05QHF01^KVh0B4Q8
07AdM013@d<0SXj>075aL@1@D500Cdm?04e=C@2GUiL0M7Ad07inOP1BDU80L71`069RHP25QHD0FEUI
09nOW`2GUiL0Hf=S07=cL`1OGel205MGE`0_02XZ:P1KFe/0E5AD03<c<`1oOgl0PX:2069RHP1ZJVX0
D51@06UYJ@1?Cdl0>CTi04I6AP1SHf<0MGEe07moO`1VIVH0E5AD06=SH`0f=SH0Jf][01lO7`1hN7P0
MWIf061PH014A4@0H61P06MWI`2;Rh/0j^[Z0:FUY@13@d<0AdM703hn?P23Ph<08b<S06=SH`19BDT0
Bd];06QXJ00i>CT0F5QH04Q8B01:BTX0F5QH051@D011@D400P1eMGD04P1UIFD0LW9b04i>CP0m?Cd0
IVIV09ZJVP0Z:RX0E5AD04E5A@1DE5@0Q8B404I6AP1LG5`0Hf=S02TY:@1EEED0L71`02<S8`80;Bd]
00L0:2PX04U9B@0a<C40BDU901<C4`1<C4`092@T0080>CTi05/0DU9B08F5Q@0_;bl0DU9B04U9B@0X
:2P0@41003lo?`0J6QX0=CDe018B4P1BDU80BTY:04U9B@0n?Sh0FEUI05mOG`10@400BTY:034a<@0l
?3`0AdM704e=C@0h>3P0G5aL03Hf=P18B4P0J6QX02d];@0c<c<0<C4a04U9B@0j>SX030`<038b<P0e
=CD0DU9B03dm?@16ATH0?clo03Ti>@1<C4`0ADE505mOG`1eMGD0E5AD04E5A@0n?Sh0ADE505IFEP1U
IFD0M7Ad08Z:RP1<C4`0IfMW06m_K`0`<300?Shn0492@P1GEeL0D51@0;:b/P13@d<0N7Qh06MWI`0n
?Sh0Kfm_03lo?`1JFUX0Q8B403<c<`1CDe<0?clo02@T901GEeL0<C4a061PH01=CDd0EEEE06QXJ010
@400BDU905MGE`1bLW80De=C05EEE@1PH600IFEU05aLG01?Cdl0P82000;ooooo0000K@2BTY80Shn?
07AdM01?Cdl0Hf=S06YZJP1/K6`0JVYZ03Xj>P0d=3@0MGEe061PH01ADE40JFUY03Ph>00d=3@0GEeM
034a<@0U9BD0>SXj030`<00o?cl0K6a/08b<S00Q8B40<c<c04m?C`1=CDd0Fe]K09fMW@35aLD09bLW
030`<01CDe<0GEeM08B4Q01hN7P0:BTY01TI6@0o?cl0DU9B04i>CP2=SHd0]KFe034a<@0T92@0G5aL
06][J`1ADE40UiNG06UYJ@0W9bL0<S8b06UYJ@1MGEd0MWIf09NGU`0k>c/0:RXZ05=CD`1ADE40=3@d
06YZJP1WIfL092@T034a<@1RHV80Ng]k05=CD`1eMGD0=cLg01LG5`0o?cl0Ph>306EUI@1LG5`0HV9R
01DE5@10@400Fe]K06QXJ00g=cL0?3`l05IFEP0M7Ad0Bd];06YZJP1?Cdl0=3@d05]KF`10@4008b<S
06ATI01RHV80I6AT0492@P1PH600=SHf0492@P1JFUX0FEUI02`/;00o?cl0De=C020P801@D500VIVI
04Y:BP0M7Ad00P0Y:BT0^00k>c/0O7al096AT@0j>SX09bLW04=3@`1IFET0HF5Q0:j^[P29RHT0:BTY
03Xj>P16ATH0?Cdm07alO039bLT0HV9R02<S8`1<C4`0EeMG069RHP1]KFd0_Kfm034a<@0I6AT0=SHf
075aL@1jNWX0Kfm_0<G5a@0j>SX0<c<c05=CD`2QXJ40Rh^;08N7Q`2YZJT0?3`l051@D01HF5P0Lg=c
059BDP2/[:`0EeMG030`<01iNGT0R8R807]kN`2;Rh/0=3@d0451@@2JVYX0bLW907]kN`21PH40Ng]k
02<S8`1HF5P0SHf=08Z:RP1IFET0SXj>04a<C00n?Sh0EUIF075aL@1TI6@0A4A40:2PX01TI6@0@d=3
06ATI027QhL0KVi^03@d=01^KVh0DE5A05YJFP1`L700[Zj^0451@@0l?3`0GemO04a<C01fMWH0WIfM
0:>SX`0c<c<0@T9206YZJP1QHF40CTi>0<?3``2<S8`08b<S03dm?@1[Jf/0Cdm?0:>SX`1dM7@07QhN
04e=C@27QhL0M7Ad06e]K@3De=@0?clo01TI6@1IFET0Shn?07UiN@2i^KT0Cdm?02/[:`19BDT0OWin
06a/K02PX:00SHf=02@T9010@400C4a<075aL@24Q8@0UYJF02<S8`14A4@0OGem06=SH`1/K6`0[jn_
03Lg=`0j>SX0UYJF07alO00m?Cd0MGEe05ADE00T92@0H61P09^KV`14A4@0LG5a05=CD`0_;bl0CDe=
07alO02:RXX0FUYJ07]kN`1OGel0AdM705eMG@1lO7`0EEEE0451@@1PH600>SXj0492@P1RHV80SXj>
05eMG@0Z:RX0Cdm?04Y:BP1[Jf/0OWin0:FUY@1QHF40;Bd]03Ti>@1TI6@0Ogmo08R8R01jNWX09bLW
03De=@1kNg/0O7al05UIF@2ATI40C4a<028R8P0e=CD205YJFP1_05]KF`2BTY80?Cdm02d];@0m?Cd0
MgMg06m_K`1/K6`0^k^k061PH00^;Rh0ADE507AdM028R8P0DU9B0:>SX`1GEeL08R8R04M7A`1DE5@0
Vi^K061PH026QXH0NGUi06YZJP1VIVH0JFUY04m?C`1ADE40HF5Q0451@@1CDe<0BDU905MGE`1;Bd/0
ADE505ADE018B4P0IFEU08:2PP1lO7`0JFUY03hn?P1TI6@0FUYJ01LG5`0g=cL0=SHf05IFEP0m?Cd0
?Shn03Ti>@1=CDd0BTY:04=3@`1?Cdl0A4A403/k>`1?Cdl0C4a<04i>CP12@T80FEUI04a<C01=CDd0
?Shn04=3@`17AdL0E5AD05iNGP16ATH0>CTi04I6AP0^;Rh0CDe=01hN7P1HF5P0DE5A03hn?P1?Cdl0
<C4a04M7A`1?Cdl0<S8b05=CD`16ATH0I6AT07IfMP1;Bd/0EeMG04Y:BP1PH600G5aL05EEE@1TI6@0
LG5a06EUI@2MWId0Bd];0410@01;Bd/0Ng]k075aL@2;Rh/0J6QX05mOG`1SHf<0?clo04M7A`1fMWH0
@d=30080E5AD04P0GUiN059BDP18B4P0>CTi03Xj>P1;Bd/0=cLg038b<P1;Bd/07QhN05IFEP0[:b/0
G5aL08R8R00m?Cd0ATI603lo?`0Z:RX0>CTi02h^;P1GEeL0>SXj069RHP0h>3P0I6AT03lo?`0l?3`0
<30`04e=C@1SHf<0/k>c05YJFP1PH600Kfm_09:BTP1mOGd0IVIV04Y:BP0l?3`0QXJ604=3@`1OGel0
HV9R051@D01fMWH0ADE508n?S`1JFUX0M7Ad051@D01cLg<0SHf=0:RXZ02ATI40M7Ad09>CT`15ADD0
HV9R05iNGP1MGEd0OWin07alO01<C4`0IVIV04M7A`18B4P0BTY:04=3@`0j>SX0I6AT04E5A@1GEeL2
04];B`0807IfMP2YZJT0D51@08V9R@0_;bl0AdM704=3@`1@D50206][J`2@069RHP1jNWX0De=C04A4
A01nOWh0OGem04I6AP1LG5`0?Cdm07=cL`0i>CT0R8R808^;R`1cLg<0OWin05YJFP21PH40G5aL04e=
C@1PH600GUiN030`<020P800GEeM06i^KP1MGEd0IVIV04M7A`1GEeL0Ogmo0410@01/K6`0JFUY0492
@P17AdL0>CTi04];B`1@D5008b<S0492@P1FEUH0?3`l05eMG@1GEeL0<30`03lo?`1ADE40GUiN02<S
8`1BDU80;2`/055AD@14A4@0?3`l05mOG`0T92@0?clo034a<@0T92@0ATI604];B`0K6a/0;Bd]00L7
1`18B4P0=CDe04a<C00/;2`0ATI605eMG@1:BTX0@D5104A4A01=CDd0CTi>05QHF00i>CT0S8b<04m?
C`1:BTX0C4a<03Ti>@1ZJVX0<30`05EEE@0^;Rh04a<C05EEE@1>CTh0HF5Q03Ti>@0n?Sh0?3`l03De
=@1PH600>3Ph04A4A01<C4`06a/K03/k>`19BDT0B4Q806UYJ@1/K6`0=CDe06ATI00^;Rh0DU9B08N7
Q`18B4P0Hf=S05IFEP1JFUX0G5aL07moO`11@D40G5aL030`<00l?3`0QXJ604I6AP1KFe/0HV9R034a
<@1OGel0GUiN038b<P1HF5P0?3`l07]kN`1QHF40CTi>05ADE00d=3@0De=C03Ti>@1TI6@0DE5A05=C
D`18B4P0ATI605eMG@1lO7`0L71`0_ooool0001i06YZJP21PH40X:2P04e=C@1_Kfl0DU9B08R8R02R
XZ80=3@d03Ph>01NGUh0@D5108F5Q@2k^k/0<C4a04A4A01EEED0BTY:07QhN02b/[80=cLg03`l?01K
Fe/0N7Qh05QHF01_Kfl0TI6A02@T900Z:RX0QhN70:>SX`1^KVh0Q8B404E5A@0E5AD0@D5107YjNP1Z
JVX0E5AD09bLW01gMgL09RHV03<c<`1mOGd0S8b<05IFEP2GUiL0B4Q801<C4`16ATH0Vi^K05]KF`1@
D500FUYJ02HV9P0_;bl0J6QX09>CT`1<C4`0Bd];03hn?P0`<300Fe]K05aLG00];Bd0@d=3061PH00f
=SH0CDe=09VIV@1=CDd06a/K03Ti>@1SHf<0BTY:06MWI`2SXj<0A4A401lO7`19BDT0DE5A075aL@23
Ph<0PH6102LW9`0Q8B40@T9205QHF01@D500YjNW079bLP0N7Qh0:BTY05ADE01SHf<0Kfm_09ZJVP0c
<c<09bLW05UIF@1nOWh0AdM707inOP1OGel05aLG030`<01WIfL0G5aL04Q8B01@D5006ATI01`L700X
:2P0Lg=c06UYJ@1TI6@0Hf=S024Q8@0];Bd0C4a<0820P002061PH03e05iNGP0a<C40=3@d069RHP2d
];@0Hf=S06a/K01WIfL09BDU03lo?`1CDe<0IVIV03<c<`1OGel0BDU903Lg=`1:BTX0HV9R0861P@0d
=3@0LW9b059BDP1KFe/0M7Ad0:BTY01?Cdl0=3@d05QHF00k>c/0Bd];07moO`2FUYH0<c<c05MGE`1e
MGD0@4100:JVYP17AdL0>c/k05=CD`1/K6`0F5QH0:ZZZP2a/K40;Bd]04E5A@1@D500JVYZ06i^KP2g
]kL0QhN7034a<@1EEED0E5AD0861P@1YJFT0alO709BDU00];Bd0EUIF06IVIP2>SXh0MgMg0;:b/P2C
Ti<092@T06IVIP2IVIT0WIfM08b<S02;Rh/0@D5104a<C025QHD0];Bd069RHP2EUID0QXJ602h^;P13
@d<0OGem0:VYZ@1;Bd/0Hf=S02h^;P0a<C40LW9b0:f][@1IFET0GUiN07]kN`0M7Ad0@D510:n_[`2Z
ZZX0CTi>07YjNP12@T80<c<c04m?C`29RHT0=3@d06e]K@1JFUX0?Shn04e=C@2EUID0FUYJ04=3@`1P
H600>CTi055AD@2PX:00O7al05MGE`1gMgL0A4A405QHF02KVi/0PX:20410@01DE5@0HV9R03lo?`2=
SHd0LW9b02LW9`1;Bd/0LW9b04];B`2?Shl0W9bL02`/;00a<C40A4A406EUI@1VIVH0/k>c08^;R`0c
<c<0FUYJ08j>SP1kNg/0Lg=c0:^[Z`1>CTh0=3@d03lo?`20P800OGem07EeM@2k^k/0L71`02<S8`1I
FET0TY:B0;^k^`1mOGd0Shn?04=3@`0h>3P0Vi^K0;Fe]@1dM7@0F5QH0:RXZ00c<c<0?Shn07inOP27
QhL0@41006ATI01UIFD0<30`04U9B@1VIVH0Ng]k02l_;`1RHV80Fe]K04=3@`1;Bd/0E5AD06UYJ@0j
>SX0G5aL0820P00e=CD0ATI604Q8B01_Kfl0;Rh^02XZ:P1EEED0>CTi03@d=027QhL0VYZJ05eMG@18
B4P0KVi^05mOG`1ZJVX0J6QX03hn?P1RHV80J6QX05]KF`0k>c/0FEUI08n?S`2CTi<0M7Ad04m?C`1D
E5@0DE5A04Y:BP1EEED0Bd];02LW9`11@D40<C4a02/[:`0l?3`0ATI604a<C010@400De=C07=cL`1E
EED0HV9R03Ph>01UIFD0GUiN07=cL`1:BTX0KVi^071`L01lO7`0DE5A05]KF`1HF5P0=SHf03<c<`0e
=CD00P0f=SH0=P0/;2`0Bd];02h^;P19BDT0BTY:05=CD`16ATH0=cLg04];B`1@D500DE5A04];B`15
ADD0Ng]k03Ti>@1;Bd/0FUYJ05ADE01BDU80GEeM05=CD`19BDT0AdM706ATI02EUID0?clo04Q8B01Y
JFT0UIFE09bLW01nOWh0De=C04I6AP1ZJVX0EeMG06][J`25QHD0IFEU075aL@1HF5P0H61P03Hf=P1@
D500@T9204Q8B01CDe<0@T92055AD@1BDU80>CTi05QHF012@T80I6AT079bLP80B4Q802/0EEEE038b
<P1<C4`0?Cdm05eMG@1@D500Jf][04I6AP1OGel0ADE504A4A00i>CT0Cdm?04a<C01bLW80E5AD05eM
G@1NGUh0De=C08J6QP2DU9@0MWIf04I6AP28R8P0BDU9030`<00h>3P0?Shn069RHP0V9RH0Fe]K03dm
?@1_Kfl0B4Q8096AT@1/K6`0[jn_07moO`1jNWX0TI6A06QXJ022PX80TY:B0080GEeM00L0Jf][06=S
H`25QHD0OWin04e=C@1FEUH0CDe=0080H61P08H0@410030`<01>CTh0JFUY09BDU02EUID0A4A405=C
D`19BDT0DU9B02TY:@1?Cdl0AdM703/k>`13@d<0BTY:03<c<`1XJ6P0^[Zj06EUI@1IFET0M7Ad055A
D@1WIfL0CTi>0820P014A4@0G5aL05mOG`0c<c<0Fe]K04e=C@0V9RH0HF5Q05aLG00_;bl0QHF50492
@P1;Bd/0F5QH07IfMP1UIFD0NGUi06e]K@1LG5`0[:b/04a<C00];Bd0BTY:02XZ:P1TI6@0Ng]k02<S
8`0n?Sh0Bd];02DU9@1FEUH0C4a<02`/;01CDe<09bLW04Y:BP0[:b/0De=C03`l?018B4P0=SHf055A
D@1RHV80;2`/075aL@1KFe/0BTY:05]KF`18B4P0;Bd]04Q8B00d=3@0Bd];03hn?P18B4P0?Shn0492
@P1MGEd0E5AD04U9B@0c<c<0>3Ph05eMG@1QHF407alO05QHF00];Bd0?Cdm05MGE`0f=SH0>3Ph02@T
901?Cdl0:b/[030`<00k>c/0:2PX04Y:BP0e=CD0@D5105IFEP0n?Sh0ADE503@d=01DE5@0DU9B03@d
=01KFe/0BTY:04=3@`1>CTh0LW9b06i^KP2PX:00:BTY05ADE01IFET0>CTi04M7A`1VIVH0Q8B404e=
C@1lO7`0=CDe06MWI`1LG5`0AdM705iNGP80EeMG01H0H61P04Q8B01MGEd0EEEE04a<C01SHf<0AdM7
05iNGP17AdL0Bd];05EEE@15ADD0A4A404];B`1`L700CDe=04m?C`1FEUH0EeMG065QH@1jNWX0FUYJ
0_ooool0001X05mOG`1eMGD0L71`08J6QP2h^;P0ADE504i>CP1dM7@0MgMg05aLG01QHF40=cLg03Xj
>P1aLG40K6a/06i^KP1PH600:b/[04m?C`1YJFT0Cdm?03Ti>@1jNWX0?3`l04=3@`1HF5P0JVYZ03`l
?00d=3@0H61P03`l?01?Cdl0PX:209^KV`0X:2P0=cLg069RHP11@D40>c/k08J6QP1`L700:BTY04Q8
B010@400@d=304i>CP2`/;00H61P01/K6`0T92@0ADE503dm?@2FUYH0T92@02DU9@0/;2`0@41005eM
G@1ADE40X:2P08V9R@0J6QX0=cLg06m_K`1QHF40P8200;Ng]`0`<3008b<S07=cL`2:RXX0De=C07=c
L`1jNWX0=cLg06UYJ@1hN7P0R8R8071`L025QHD0<C4a03Lg=`1GEeL0Q8B408V9R@1PH600N7Qh01hN
7P0a<C40@D5107moO`1EEED0NGUi05YJFP0a<C40=cLg06=SH`1QHF40<30`04E5A@0_;bl0<c<c06=S
H`2?Shl203Hf=P3o04Y:BP0d=3@0B4Q806IVIP0o?cl08R8R0451@@0n?Sh0FUYJ07EeM@1mOGd0;2`/
01hN7P0V9RH0EeMG04e=C@25QHD0SHf=02@T900];Bd0<C4a05ADE01>CTh0PX:207emO@0T92@0?3`l
071`L01XJ6P0ATI608N7Q`2ATI40<c<c059BDP2<S8`0ZJVY05iNGP33`l<0LG5a03Lg=`1FEUH0Xj>S
06i^KP1jNWX0UYJF030`<00W9bL0IVIV09BDU01PH600ZZZZ0:RXZ013@d<0F5QH09jNWP1aLG40Zj^[
069RHP0[:b/0C4a<08n?S`1KFe/0FEUI069RHP0d=3@0CDe=06YZJP24Q8@0DU9B096AT@2SXj<0=3@d
04=3@`1UIFD0Ti>C055AD@1IFET0JFUY02HV9P18B4P0Lg=c0:2PX01?Cdl0HV9R07EeM@0d=3@0PH61
08F5Q@1:BTX0>SXj06i^KP0n?Sh0E5AD07EeM@1TI6@0:b/[02XZ:P1KFe/0KVi^07AdM025QHD0Cdm?
028R8P0o?cl0GemO06IVIP1cLg<0[jn_02d];@0Z:RX0CTi>09>CT`1mOGd0g]kN07alO010@400@T92
061PH01SHf<0_[jn09FEU@0^;Rh0BDU905UIF@1[Jf/0X:2P0;6a/@0V9RH0F5QH06UYJ@1[Jf/0[Zj^
0;Fe]@0`<300AdM707moO`1cLg<0Ph>30;jn_P1?Cdl0;2`/06EUI@2f][H0J6QX08j>SP1TI6@0ADE5
04m?C`2SXj<0LW9b05]KF`1`L700;bl_04e=C@1CDe<0X:2P05]KF`1dM7@0Hf=S03/k>`1[Jf/0RXZ:
0:6QX@1;Bd/0GEeM05iNGP0k>c/0G5aL06][J`1oOgl0>3Ph02h^;P11@D40=cLg08F5Q@2DU9@0SHf=
038b<P0m?Cd0ADE504I6AP1TI6@0/[:b05IFEP0b<S80ATI605]KF`1OGel0Ph>308F5Q@0K6a/0<C4a
04I6AP1IFET0DE5A069RHP1eMGD07AdM0451@@1DE5@0H61P04a<C01[Jf/0ZZZZ02/[:`11@D40J6QX
06m_K`1[Jf/0FUYJ0;Fe]@0a<C40?Shn06][J`2SXj<0EeMG04a<C01JFUX0@410051@D01HF5P0ATI6
06ATI01>CTh0H61P03Xj>P1SHf<0K6a/04i>CP1TI6@0FUYJ08B4Q01fMWH0IfMW08B4Q018B4P0=CDe
065QH@19BDT0>CTi04I6AP1HF5P0BDU903Lg=`19BDT0De=C07AdM01QHF40>CTi04Y:BP1@D500H61P
04A4A01HF5P0CTi>000J04E5A@1<C4`0ADE503Ti>@0o?cl0Bd];04U9B@1IFET0G5aL02d];@14A4@0
61PH05UIF@0d=3@0<c<c04=3@`0k>c/0BTY:02d];@0O7al08b<S04U9B@21PH40?Shn02d];@15ADD2
06YZJP0m04a<C017AdL0GemO06ATI01WIfL0MWIf05=CD`1bLW80PX:2051@D01;Bd/0I6AT07YjNP1o
Ogl0GUiN02LW9`0`<300CDe=03lo?`1NGUh0>c/k04a<C00m?Cd0FEUI03@d=00[:b/0Bd];02l_;`0Z
:RX0;2`/05IFEP1`L700>CTi059BDP2TY:@0@d=303<c<`0h>3P0EUIF06i^KP18B4P0?3`l0451@@21
PH40ATI604m?C`1PH600IVIV04m?C`1ADE40S8b<0;Ng]`1PH600Ogmo075aL@22PX80Lg=c08Z:RP1b
LW80@D5109:BTP0206a/K00H05]KF`1<C4`0H61P04a<C01kNg/0De=C08j>SP19BDT0/;2`069RHP3F
e]H0PH6109RHV03=cLd0>c/k05aLG01OGel0AdM70;Vi^@1WIfL0<30`05IFEP0h>3P0NGUi0P1CDe<0
A`0o?cl0ATI606YZJP1FEUH0@D51055AD@2?Shl0WYjN06ATI01cLg<0ATI6059BDP0n?Sh0Kfm_06][
J`1VIVH0D51@04a<C00n?Sh0RXZ:0;Ng]`21PH40B4Q804i>CP10@400FEUI02PX:025QHD0=CDe05IF
EP1QHF40>SXj05]KF`1QHF40J6QX0;Fe]@1dM7@0FUYJ07IfMP1bLW80DE5A059BDP1?Cdl0EEEE08>3
P`2@T900Fe]K05eMG@12@T80>c/k04a<C00h>3P0IFEU069RHP0];Bd0FEUI04];B`0F5QH0B4Q8051@
D01:BTX0JFUY0410@01CDe<09BDU06m_K`0c<c<0DE5A059BDP23Ph<0PX:20080?clo02L0=cLg01/K
6`0o?cl0@D5102DU9@1;Bd/0BTY:05MGE`13@d<0D51@0451@@1DE5@0K6a/055AD@1EEED0@41003dm
?@1;Bd/0C4a<02@T901VIVH0:RXZ075aL@1UIFD0=CDe04M7A`0c<c<0Bd];01DE5@0M7Ad0A4A404I6
AP1/K6`0AdM70492@P1RHV80A4A404];B`15ADD00P1NGUh01013@d<0>SXj05=CD`1<C4`2055AD@0A
05aLG01VIVH0MGEe04a<C01]KFd0BTY:038b<P0f=SH0EEEE04];B`1nOWh0EUIF0:6QX@0h>3P0=3@d
06ATI01;Bd/00P1[Jf/0401UIFD0JVYZ06ATI01WIfL0JVYZ0410@01KFe/0>3Ph04a<C01JFUX0;Rh^
04I6AP17AdL0?Cdm04a<C01>CTh206=SH`0304e=C@1EEED0H61P00;ooooo0000o`23Ph<0GEeM05QH
F01fMWH0[Zj^07emO@15ADD0Cdm?05]KF`2=SHd0EeMG02TY:@0i>CT0>SXj03<c<`1kNg/0V9RH01PH
600];Bd0Bd];04M7A`1GEeL0/k>c07IfMP0P8200E5AD08:2PP1=CDd0MgMg0<71`@1?Cdl092@T05aL
G02HV9P0Jf][07emO@2e]KD0:b/[0451@@19BDT0LG5a05UIF@2<S8`0Ti>C02LW9`0X:2P0?clo08Z:
RP1CDe<0LG5a03lo?`0_;bl0:BTY06EUI@1DE5@0DU9B071`L00/;2`0?clo03De=@1ADE40=3@d05=C
D`0o?cl07AdM04Q8B01NGUh0@T9204=3@`25QHD0CDe=01dM7@1UIFD0/;2`0410@00g=cL0GEeM03Xj
>P0l?3`0JFUY06a/K00Q8B40GUiN05=CD`0_;bl0IVIV0;:b/P0e=CD08R8R04=3@`0k>c/0?clo08R8
R02TY:@08B4Q03De=@0f=SH0@D5105eMG@2k^k/0ADE502LW9`0o?cl0E5AD05mOG`2>SXh0Vi^K01/K
6`0b<S80Kfm_07YjNP1;Bd/0VYZJ03Ph>00O7al0ADE507moO`1dM7@0OGem0:BTY00R8R80?clo05UI
F@2JVYX0U9BD05]KF`21PH40>SXj02LW9`1OGel0LG5a05YJFP1<C4`0Kfm_024Q8@0S8b<0Bd];0820
P01KFe/0E5AD07moO`0U9BD0@d=306UYJ@1WIfL0ADE506ATI01VIVH0;bl_04e=C@2XZ:P0GEeM02XZ
:P0l?3`0?Cdm03`l?01RHV80KVi^0410@019BDT0<c<c06UYJ@2ATI40WinO0410@014A4@0F5QH04E5
A@2[Zj/0Z:RX02DU9@0j>SX0DE5A05aLG01>CTh0ZZZZ0;Bd]00/;2`0B4Q806e]K@1kNg/0FEUI0;Vi
^@2k^k/0;Rh^03Lg=`1cLg<0Vi^K07alO02d];@0YZJV02XZ:P11@D40PX:206m_K`26QXH0clo?06IV
IP0o?cl0NWYj08N7Q`1aLG40IVIV09ZJVP0d=3@0G5aL07EeM@22PX80CDe=0:BTY00c<c<0=cLg075a
L@2JVYX0IVIV069RHP1QHF407QhN04M7A`2VYZH0/k>c05EEE@1JFUX08b<S04a<C01LG5`0ZJVY06][
J`19BDT0DU9B02PX:01kNg/0][Jf06=SH`1`L700MgMg02HV9P1HF5P0c/k>09fMW@1TI6@0FEUI03lo
?`10@400Ng]k071`L00g=cL0CTi>03dm?@1PH600Vi^K08>3P`0Y:BT0Bd];05UIF@00a01FEUH0JVYZ
0:NWY`1BDU809bLW04i>CP1PH600DE5A0:VYZ@2BTY80=SHf03`l?01LG5`0P82007EeM@2WYjL0Vi^K
02`/;01GEeL0P82009JFUP1XJ6P0RHV907moO`0R8R80E5AD08b<S02RXZ80PH6107=cL`1FEUH0@d=3
069RHP2KVi/0[Jf]07alO02LW9`0?3`l02d];@14A4@0NWYj04i>CP16ATH0Kfm_02`/;00X:2P0J6QX
07MgM`1WIfL0E5AD08b<S01=CDd0:2PX04a<C01LG5`0Lg=c03Ti>@1gMgL0B4Q802l_;`0k>c/0J6QX
07moO`11@D40JFUY05mOG`1RHV80HF5Q05IFEP1BDU80EeMG06UYJ@1OGel0KVi^06QXJ01SHf<0D51@
061PH01ZJVX0HV9R06UYJ@21PH40LW9b05YJFP0l?3`0FUYJ04];B`0];Bd0?Shn03Xj>P10@400ADE5
0492@P1>CTh0BDU906EUI@1QHF40Fe]K051@D014A4@0Fe]K06UYJ@1SHf<0D51@06EUI@1MGEd0C4a<
051@D01=CDd0Bd];05=CD`1SHf<0ADE503@d=00o?cl0=CDe0451@@0X:2P0CTi>04e=C@18B4P0@D51
03dm?@1@D500?Shn03De=@0b<S80;2`/03lo?`1<C4`0Fe]K05YJFP1EEED0FEUI05iNGP19BDT0@410
04m?C`21PH40WinO04e=C@0f=SH0?Cdm05EEE@1SHf<0EEEE038b<P0_;bl0C4a<02l_;`0o?cl0KVi^
04=3@`1GEeL0BDU906][J`10@400GemO0451@@1EEED0E5AD04e=C@13@d<0C4a<03Ph>01:BTX0>c/k
061PH01OGel0@D5104I6AP1GEeL0>SXj04I6AP0h>3P0CDe=04A4A01CDe<0@D5104m?C`11@D40>c/k
03`l?014A4@0@41004];B`12@T80H61P05YJFP1CDe<0IFEU08V9R@28R8P0J6QX0:RXZ011@D4206=S
H`0V04=3@`1VIVH0?clo07AdM01DE5@0LW9b05=CD`2MWId0I6AT0;Rh^01LG5`0NWYj0:6QX@1VIVH0
QhN707moO`1EEED0NGUi06UYJ@1/K6`0TY:B04I6AP1>CTh0?Cdm04A4A01CDe<0BTY:03Ti>@0j>SX0
KVi^04U9B@1cLg<0UYJF061PH01UIFD0KFe]07IfMP0m?Cd206e]K@<0EEEE00X0De=C071`L01OGel0
A4A405UIF@1OGel0Jf][07IfMP1QHF40TY:B0P1QHF40PP1cLg<0Cdm?0861P@1IFET0BTY:059BDP1@
D500@d=306UYJ@1XJ6P0P82006UYJ@1VIVH0GEeM05EEE@2JVYX0Kfm_07IfMP1IFET0L71`0861P@1A
DE40IfMW06ATI00N7Qh0JFUY06YZJP0b<S80GemO03Ph>00c<c<0@T9203Ti>@1>CTh0=SHf06YZJP0m
?Cd0FEUI03/k>`1VIVH0LG5a028R8P1IFET0=3@d00H61P0l?3`0;Rh^02HV9P1;Bd/0DE5A04a<C013
@d<0BDU90410@01;Bd/0I6AT03lo?`10@400;bl_02DU9@1;Bd/0De=C01hN7P1HF5P0<c<c04I6AP0e
=CD0<c<c04A4A00[:b/0GUiN02`/;00M7Ad0=cLg03lo?`1JFUX0DU9B055AD@1YJFT0A4A404E5A@1E
EED0WYjN06][J`15ADD0@d=30492@P18B4P0BTY:07alO01WIfL0RXZ:03Lg=`1WIfL0O7al0492@P11
@D40BTY:07]kN`1VIVH0PX:203hn?P1?Cdl0EeMG05IFEP1KFe/0Bd];05MGE`1aLG40Cdm?08V9R@0l
?3`0@D5104m?C`19BDT0NGUi04e=C@18B4P0LG5a05ADE01MGEd0CTi>08>3P`1HF5P0GEeM07MgM`1K
Fe/0F5QH06a/K01TI6@2ooooo`000700YjNW09FEU@1UIFD0ADE508R8R02SXj<0SXj>09JFUP0a<C40
CTi>071`L019BDT0TI6A07YjNP0T92@0>SXj075aL@1KFe/0ATI604a<C00T92@0:2PX06UYJ@2TY:@0
G5aL07EeM@19BDT0<S8b04m?C`24Q8@0UiNG03Hf=P1@D500?Cdm02LW9`1;Bd/0Kfm_07IfMP13@d<0
I6AT03Xj>P18B4P0FEUI05mOG`1=CDd0?Cdm06=SH`0g=cL0AdM709VIV@1kNg/09BDU02d];@12@T80
=SHf04I6AP2CTi<0@41002HV9P1bLW80Cdm?03Lg=`1hN7P0OGem01<C4`0g=cL0K6a/03lo?`1=CDd0
^[Zj07MgM`0N7Qh0BTY:06MWI`1PH600][Jf0:JVYP0O7al0BDU906ATI01bLW80Hf=S0:VYZ@2d];@0
7AdM04=3@`2HV9P0S8b<05IFEP26QXH0BDU9028R8P1<C4`0QhN707=cL`1dM7@0PX:202TY:@0W9bL0
JFUY08F5Q@0d=3@0AdM702LW9`0U9BD0AdM70861P@1JFUX0<S8b030`<00[:b/0<C4a0P1EEED203Hf
=P1o04E5A@0[:b/0JFUY08R8R01EEED09bLW02/[:`0f=SH0@d=304a<C02?Shl0ADE501/K6`0l?3`0
EUIF03dm?@1NGUh0cLg=03`l?00P8200BDU9051@D00l?3`0Jf][0<71`@0l?3`0<S8b07YjNP22PX80
EUIF0:^[Z`3:b/X0:RXZ03hn?P1GEeL0PH6106e]K@2UYJD0>SXj02@T9012@T80P82007=cL`1mOGd0
;Rh^03dm?@1LG5`0XJ6Q07inOP2SXj<0PX:202/[:`1GEeL0V9RH071`L01aLG40XZ:R05=CD`0l?3`0
CTi>06QXJ01jNWX0DU9B0;Vi^@19BDT0@d=304i>CP1bLW80E5AD0492@P2HV9P0:BTY0451@@1LG5`0
SHf=04Y:BP1BDU80Lg=c03dm?@16ATH0QHF509BDU00h>3P0GemO04A4A00o?cl0GEeM08N7Q`1aLG40
=CDe06UYJ@12@T80<c<c06i^KP1bLW80:BTY04e=C@1ZJVX0I6AT08n?S`1gMgL0:2PX02DU9@1MGEd0
Jf][07]kN`2ZZZX0>3Ph03De=@1ADE40HF5Q06e]K@2HV9P0P82001LG5`1FEUH0MGEe05=CD`2JVYX0
[:b/034a<@0S8b<0LG5a09RHV026QXH0RHV902TY:@0204M7A`0h07]kN`1aLG40V9RH04I6AP0V9RH0
Kfm_0:ZZZP1XJ6P0YJFU07EeM@0];Bd0C4a<06e]K@2QXJ40JVYZ0:NWY`1KFe/0;Bd]05=CD`2/[:`0
NWYj06=SH`2FUYH0DU9B03De=@1kNg/0Vi^K079bLP1BDU80MWIf02`/;01;Bd/0G5aL09JFUP2?Shl0
?clo06IVIP0[:b/0H61P08^;R`20P800;bl_05eMG@1PH600?Shn04I6AP2:RXX0GemO02l_;`1CDe<0
F5QH05MGE`1IFET0X:2P05ADE00^;Rh204A4A016055AD@1MGEd0WYjN08^;R`0P8200?clo05IFEP1B
DU80CDe=0::RXP2FUYH08b<S03Ph>01=CDd0S8b<06EUI@1_Kfl0N7Qh03dm?@0b<S80HF5Q05EEE@1`
L700E5AD03`l?01ADE40A4A40451@@0b<S80CTi>07UiN@27QhL0Jf][04a<C01MGEd0F5QH04A4A01;
Bd/0;Rh^03Lg=`1ADE40;bl_01lO7`0d=3@0ATI603Ph>00_;bl0@T9204e=C@23Ph<0DU9B02h^;P10
@400J6QX05UIF@0n?Sh0AdM705ADE01JFUX0=SHf04Q8B01<C4`0;2`/03Ph>00c<c<0De=C0492@P0K
6a/0:2PX01<C4`<0>c/k02X0=3@d02l_;`0i>CT0<c<c05aLG01BDU80GemO09^KV`0c<c<0>CTi0451
@@1SHf<0EUIF04E5A@1:BTX0De=C051@D01ZJVX0Kfm_03<c<`11@D40Bd];07inOP1fMWH0I6AT04U9
B@1;Bd/0EUIF04Q8B01CDe<0GemO0410@01EEED0FEUI07UiN@0n?Sh0I6AT04e=C@12@T80D51@04U9
B@1;Bd/203dm?@2`06QXJ016ATH0HF5Q07inOP1?Cdl0BDU904i>CP0m?Cd0G5aL04M7A`1SHf<0B4Q8
06e]K@19BDT0FEUI04Y:BP19BDT0A4A405IFEP1_Kfl0Rh^;05IFEP1XJ6P0GEeM075aL@1eMGD0TI6A
0;Bd]01ADE40KFe]05YJFP16ATH0DE5A05EEE@1LG5`0;2`/05iNGP1TI6@0TI6A05ADE02>SXh0E5AD
0=OGe`2?Shl0TY:B0:VYZ@15ADD0LW9b065QH@0n?Sh0PX:204m?C`0h>3P0DE5A02d];@17AdL0@d=3
07=cL`0n?Sh0BDU907EeM@0n?Sh0Fe]K02d];@2<S8`0R8R804a<C01LG5`0?Cdm04U9B@0f=SH0SHf=
08j>SP1JFUX0B4Q808>3P`1ADE40Ph>30;bl_01<C4`0Hf=S05YJFP0n?Sh0DE5A069RHP2ATI40>SXj
04M7A`16ATH0=cLg06m_K`1HF5P0?Cdm07YjNP1DE5@0A4A408R8R00o?cl0>c/k04];B`1VIVH0>CTi
07EeM@2GUiL0I6AT07MgM`0l?3`0;bl_05]KF`1BDU80Kfm_065QH@0`<300ATI60410@01=CDd0WIfM
06=SH`0f=SH0BTY:06IVIP1cLg<0>c/k05UIF@0m?Cd0De=C03De=@1FEUH0DU9B01PH601ADE40>3Ph
00X:2P18B4P0>c/k02LW9`0b<S80>SXj030`<017AdL0@41003/k>`18B4P0FUYJ04Y:BP17AdL0A4A4
03Ph>01;Bd/0D51@02HV9P1XJ6P07AdM05ADE018B4P0>CTi04M7A`0`<300Fe]K04];B`0e=CD0GUiN
05EEE@1KFe/0E5AD04];B`1gMgL0FEUI055AD@14A4@0De=C03Hf=P0];Bd0?Shn04I6AP1TI6@206IV
IP0Q051@D01]KFd0=SHf0492@P1eMGD0DE5A06e]K@1aLG40OWin05iNGP1oOgl0@D5106ATI00l?3`0
GUiN09FEU@0m?Cd0D51@04E5A@0[:b/0DU9B02d];@1;Bd/0E5AD03Ti>@1KFe/0GEeM07=cL`1XJ6P0
C4a<0410@018B4P0E5AD0080BTY:00D0Fe]K04];B`1KFe/0Jf][07UiN@02ooooo`0002@0HV9R06MW
I`1/K6`0EUIF06IVIP18B4P0G5aL071`L01CDe<0GEeM0492@P1?Cdl0EEEE08b<S01<C4`0>c/k03Hf
=P0c<c<0IFEU08N7Q`0V9RH07AdM0410@00o?cl0H61P075aL@1RHV80:BTY03<c<`19BDT0PH6108J6
QP1TI6@0:2PX01dM7@0V9RH2065QH@3P07UiN@2KVi/0=CDe02DU9@0m?Cd0G5aL07MgM`1]KFd0[jn_
03De=@0G5aL0DU9B08N7Q`1=CDd0Ng]k05iNGP0[:b/0=SHf05iNGP2FUYH0@d=309^KV`0_;bl0:b/[
04E5A@1UIFD0@d=30451@@1UIFD06QXJ02`/;01PH600OWin03@d=01fMWH0@D5101lO7`0d=3@0L71`
05aLG00a<C40GUiN02PX:00e=CD0GUiN07MgM`19BDT09RHV04=3@`0e=CD0?clo08F5Q@1RHV807QhN
03De=@0n?Sh0A4A407emO@2d];@0=SHf01@D5011@D40EeMG05iNGP2BTY80A4A401PH600Z:RX0KVi^
06EUI@1OGel0K6a/02HV9P0i>CT0?clo05UIF@1PH600PX:208^;R`0X:2P0?Cdm05iNGP1jNWX0OWin
07]kN`1IFET0:2PX04E5A@1oOgl0WYjN069RHP22PX80MWIf03Hf=P15ADD0P8200:ZZZP10@400Z:RX
05eMG@0n?Sh0?clo07QhN01jNWX0EeMG09bLW01LG5`0@T9206UYJ@2MWId0Q8B405iNGP2ATI40=CDe
04Y:BP1VIVH0Ph>3038b<P1[Jf/0Fe]K04A4A01aLG40DE5A04m?C`1^KVh0@T9203Xj>P1YJFT0QHF5
04E5A@11@D40Jf][0451@@14A4@0N7Qh075aL@0d=3@0GUiN06ATI01=CDd0KFe]0:b/[01bLW80=3@d
069RHP1MGEd0B4Q808F5Q@3MgMd0Bd];02/[:`1YJFT0QhN706IVIP2EUID0Ph>303hn?P0m?Cd0GemO
05QHF01SHf<0_Kfm08f=S@0U9BD0>SXj05eMG@1XJ6P0JVYZ0;^k^`1NGUh0?clo04U9B@1WIfL0D51@
09jNWP29RHT08R8R06=SH`2BTY80Cdm?05]KF`26QXH0A4A40410@026QXH0PX:203lo?`24Q8@0>SXj
03/k>`1MGEd0NGUi04a<C01jNWX0EEEE02l_;`1>CTh0XZ:R06i^KP1JFUX0IFEU02/[:`1lO7`0[Zj^
0861P@1OGel0PX:203De=@0^;Rh0SHf=0861P@0[:b/0E5AD03De=@0];Bd0EEEE07]kN`11@D40<c<c
04i>CP0a<C40KVi^0:VYZ@2[Zj/203hn?P2807EeM@18B4P0MgMg0<;2`P1iNGT0=3@d03dm?@1WIfL0
OGem09jNWP2TY:@0AdM702l_;`1HF5P0GemO0820P01oOgl0ZZZZ04E5A@0S8b<0GemO09RHV01WIfL0
YJFU0:VYZ@0c<c<0Cdm?07AdM02CTi<0Kfm_07QhN01MGEd0?clo04m?C`1TI6@0TY:B04Y:BP1hN7P0
EUIF01lO7`1=CDd0JFUY09bLW01GEeL0H61P08>3P`0b<S80B4Q8079bLP2JVYX0IfMW0451@@27QhL0
9bLW0492@P1HF5P0MWIf04m?C`18B4P0L71`05EEE@1WIfL0KFe]04];B`1hN7P0DU9B06e]K@14A4@0
JFUY06YZJP1<C4`0KVi^05MGE`2<S8`0M7Ad04e=C@1cLg<0Bd];04Y:BP0k>c/0A4A403Ph>01CDe<0
DE5A04m?C`0f=SH0@d=303/k>`15ADD0C4a<03lo?`1ZJVX0De=C075aL@1CDe<0MGEe05]KF`1EEED0
A4A404m?C`1:BTX0?3`l04Y:BP12@T80=SHf04];B`0[:b/0@41001@D501FEUH0:BTY03Hf=P0k>c/0
BTY:05aLG00[:b/0=3@d03Lg=`0a<C40BTY:02d];@0k>c/0De=C06ATI01QHF40De=C04E5A@1XJ6P0
L71`06a/K01`L7008b<S059BDP1IFET0?3`l03dm?@80AdM701`0C4a<04Q8B00T92@0<S8b05MGE`1Q
HF40H61P03@d=013@d<0;bl_04i>CP0j>SX0>3Ph05MGE`0];Bd0>CTi03De=@0l?3`0AdM703hn?P1J
FUX0O7al04I6AP11@D40=CDe0410@01KFe/0=3@d0P11@D407`1VIVH0@D5104Y:BP1=CDd0ADE503dm
?@18B4P0OWin09:BTP1DE5@0HF5Q05aLG01XJ6P0GEeM0:JVYP2PX:00De=C08n?S`1:BTX0ADE505UI
F@1=CDd0L71`04a<C01MGEd0ATI606EUI@12@T80GUiN0820P02OWil00P1iNGT0HP2b/[80I6AT08N7
Q`21PH40MWIf0;bl_025QHD0@41004i>CP0R8R80SXj>02l_;`0k>c/0?3`l04Y:BP0h>3P0DU9B06m_
K`0h>3P0GUiN04e=C@1CDe<0CTi>069RHP1UIFD0<C4a05QHF01DE5@0B4Q806][J`1oOgl07QhN08b<
S02YZJT0?3`l04E5A@1EEED0ADE505eMG@13@d<0LW9b02HV9P1eMGD0I6AT04E5A@1aLG40Lg=c05mO
G`2DU9@0D51@0410@01QHF40EUIF04m?C`1/K6`0UYJF055AD@1]KFd0U9BD079bLP2CTi<0?clo0451
@@1;Bd/07AdM07]kN`1]KFd0:2PX06e]K@0o?cl0=cLg05]KF`0g=cL0?Shn04m?C`10@400Cdm?04=3
@`1UIFD0@T9206MWI`18B4P0M7Ad05mOG`0`<300E5AD04m?C`0Y:BT0CTi>03dm?@0a<C40F5QH04I6
AP0_;bl0@T92051@D016ATH0D51@0P1NGUh01014A4@0AdM704U9B@19BDT20492@P1306m_K`1DE5@0
EeMG0492@P1GEeL0K6a/03<c<`1BDU80?Cdm03Xj>P0e=CD0=cLg05UIF@16ATH0BDU906ATI00o?cl0
EUIF04A4A01QHF40DU9B03Ph>014A4@0E5AD051@D00_;bl0BDU906=SH`25QHD0Cdm?06ATI01^KVh0
?clo0451@@0l?3`0GemO09>CT`2KVi/0I6AT09RHV01FEUH0De=C07AdM017AdL0Jf][04I6AP1HF5P0
IFEU02PX:00h>3P0=SHf03/k>`1UIFD0>3Ph04E5A@0g=cL0?Shn06ATI019BDT0I6AT05IFEP1JFUX0
G5aL05ADE01XJ6P0Jf][05IFEP02ooooo`000?l0G5aL08V9R@1nOWh0VYZJ09fMW@0l?3`0GUiN07Mg
M`1UIFD0_;bl03hn?P0m?Cd0De=C05eMG@1BDU80R8R807YjNP0/;2`0:2PX06YZJP2BTY80EUIF09ZJ
VP1=CDd0;Bd]0410@01SHf<0B4Q804a<C01iNGT0>SXj03Hf=P1[Jf/0QHF504=3@`18B4P0E5AD034a
<@0^;Rh0J6QX07=cL`0_;bl0?Shn02<S8`0O7al0>3Ph07MgM`2EUID0>c/k04E5A@0h>3P09bLW06=S
H`29RHT0<S8b01hN7P0j>SX0FEUI05QHF029RHT0Lg=c01hN7P0g=cL0BTY:05IFEP2>SXh0W9bL02HV
9P0N7Qh0ATI605QHF016ATH0/K6a08>3P`0Q8B40:b/[051@D01[Jf/0K6a/0<;2`P1MGEd08B4Q04U9
B@1hN7P0HV9R06a/K01jNWX08B4Q028R8P0d=3@0Kfm_051@D02MWId0IVIV01TI6@0c<c<0D51@0861
P@1BDU80VYZJ030`<00W9bL0FUYJ06][J`0h>3P0B4Q804U9B@0];Bd0:b/[05MGE`1>CTh0<C4a06UY
J@0N7Qh0<C4a04i>CP1PH600BTY:055AD@1mOGd06ATI02d];@1fMWH0J6QX03`l?00a<C40F5QH03@d
=01CDe<0EEEE06=SH`0U9BD0<30`04e=C@1?Cdl0AdM708N7Q`1bLW8071`L03@d=00h>3P0BDU9059B
DP2GUiL0GUiN02TY:@1GEeL0S8b<06i^KP25QHD0g=cL03dm?@15ADD0Ng]k092@T01LG5`0PX:208J6
QP0g=cL0IFEU08:2PP29RHT0bl_;03/k>`0e=CD0G5aL07YjNP1RHV80OGem0;:b/P0O7al0BTY:07Ui
N@1ZJVX0B4Q80:ZZZP2e]KD07AdM0451@@29RHT0QXJ606a/K02/[:`0_[jn03Ti>@14A4@0QHF50:6Q
X@1:BTX0QhN706e]K@0a<C40ATI6071`L01<C4`0CDe=08V9R@0a<C40=cLg05UIF@2EUID0AdM7055A
D@1VIVH0;2`/04I6AP1iNGT0UIFE04=3@`1>CTh0;bl_03lo?`1fMWH0Vi^K04e=C@15ADD0CDe=03hn
?P1GEeL0_kno07UiN@0`<300ADE504e=C@1GEeL0Rh^;09nOW`0_;bl0D51@06QXJ01DE5@0TY:B07Qh
N00T92@0?clo05aLG01[Jf/0GUiN0;^k^`0f=SH0;Bd]07YjNP1kNg/0MgMg0;Vi^@0W9bL0?Shn07Ad
M01VIVH0B4Q80:NWY`1<C4`07QhN03hn?P2EUID003/0KVi^06EUI@2LW9`0:b/[02XZ:P1@D500[jn_
08B4Q01mOGd0T92@03De=@1=CDd0BTY:08J6QP1QHF40TI6A06i^KP0`<300JFUY06IVIP1NGUh0@d=3
06i^KP1VIVH06a/K04U9B@31`L40[:b/04i>CP1EEED0BDU9024Q8@1LG5`0ZZZZ055AD@0f=SH0F5QH
02h^;P0/;2`0HF5Q08f=S@0h>3P0<c<c051@D00m?Cd0=SHf06IVIP25QHD0=cLg030`<01@D500DU9B
05aLG01ZJVX0ZZZZ0492@P0P8200<S8b05YJFP0204I6AP070:ZZZP0/;2`0>c/k06=SH`1QHF40G5aL
05ADE002061PH00?06e]K@1[Jf/0Jf][06m_K`1QHF40O7al05UIF@1dM7@0O7al06UYJ@2<S8`0WIfM
08>3P`1YJFT0C4a<0080IfMW0=/0>SXj051@D01GEeL0BDU905QHF014A4@0KVi^06ATI01mOGd0Kfm_
04m?C`1@D500F5QH065QH@1NGUh0G5aL04I6AP1^KVh0FEUI05ADE012@T80Cdm?03Ti>@1EEED0GEeM
04E5A@17AdL0G5aL03/k>`1;Bd/071`L04M7A`0`<300@T92030`<00Y:BT0De=C03dm?@1;Bd/0HV9R
04U9B@1`L700?Cdm04=3@`1IFET0EeMG055AD@1NGUh0DE5A04Q8B015ADD0Ng]k07QhN00V9RH0<S8b
03lo?`1CDe<0IfMW079bLP1TI6@0FUYJ06i^KP0e=CD0@T9205aLG00g=cL0AdM704E5A@1BDU80@T92
059BDP0d=3@0;Rh^05]KF`0Y:BT0?Shn02h^;P1<C4`0A4A403De=@1>CTh0M7Ad030`<015ADD0;Rh^
04I6AP1BDU80;2`/04e=C@0f=SH0FEUI04I6AP14A4@0ADE503Hf=P0m?Cd0@410059BDP1WIfL0@d=3
051@D01=CDd0EUIF04i>CP1CDe<0JVYZ06EUI@2OWil0AdM7079bLP1dM7@0Bd];07QhN00d=3@0L71`
051@D02ATI40K6a/06EUI@1^KVh0`l?307IfMP25QHD0ZZZZ05mOG`2;Rh/0MgMg04a<C01`L700GEeM
03Ph>016ATH0@D510492@P0d=3@0CTi>03`l?00e=CD0BDU905aLG02:RXX0FUYJ0:j^[P24Q8@0DE5A
03Xj>P1DE5@0ATI602<S8`1TI6@0MgMg051@D01<C4`0I6AT02l_;`2FUYH0[Zj^0451@@1VIVH0De=C
04m?C`0h>3P0NWYj09VIV@0m?Cd0BTY:051@D01NGUh0U9BD065QH@0j>SX0BTY:04U9B@1^KVh0NWYj
05iNGP1SHf<0E5AD05=CD`1LG5`0L71`09VIV@22PX80UIFE05IFEP1aLG40H61P024Q8@1IFET0EeMG
01`L702IVIT0<C4a02HV9P1dM7@0>SXj05]KF`1PH600BDU905UIF@0h>3P0S8b<04i>CP1HF5P0>c/k
09FEU@1iNGT0=SHf05iNGP1RHV80:b/[05MGE`10@400>SXj04Y:BP1BDU80De=C04m?C`0g=cL00P1:
BTX0B`1aLG40>CTi05EEE@0n?Sh0<c<c05]KF`1SHf<0ATI605]KF`1QHF40R8R804Q8B00d=3@0A4A4
04e=C@1eMGD0CTi>02HV9P1FEUH0C4a<05IFEP1<C4`0BDU9055AD@15ADD0JFUY05ADE02RXZ80R8R8
055AD@1LG5`0BDU904E5A@19BDT0=SHf051@D02MWId0A4A407=cL`1YJFT0I6AT07UiN@1<C4`0G5aL
0:2PX02IVIT0DU9B075aL@0X:2P0D51@05ADE00e=CD0M7Ad05iNGP18B4P0RXZ:04e=C@15ADD0AdM7
03lo?`1/K6`0FUYJ04m?C`0k>c/0<S8b04Q8B019BDT0HF5Q03lo?`14A4@0FEUI05YJFP1IFET0IFEU
059BDP02ooooo`0008l0Ti>C07MgM`1:BTX0FEUI092@T01CDe<0@d=304M7A`0n?Sh0L71`07alO00m
?Cd0A4A404];B`0V9RH0I6AT09^KV`10@400@d=302DU9@0d=3@0DE5A051@D019BDT0:BTY04=3@`0l
?3`0<C4a07=cL`2XZ:P0D51@02<S8`10@400DE5A04A4A022PX80N7Qh02LW9`0m?Cd0B4Q80820P01R
HV80RXZ:07YjNP0I6AT0BDU904E5A@1ZJVX0F5QH0:^[Z`14A4@0;2`/0492@P14A4@0J6QX05eMG@2E
UID0;Rh^03hn?P1>CTh0DE5A03Ti>@1dM7@0HF5Q01<C4`0a<C40O7al05ADE01FEUH0Ng]k02LW9`0T
92@0ATI608f=S@1DE5@0CDe=04];B`0S8b<0@410079bLP2a/K40HF5Q0861P@13@d<092@T05UIF@2c
/k<0FUYJ03dm?@1FEUH0@d=303De=@1nOWh0YjNW03Ph>00d=3@0Jf][03De=@1HF5P0Shn?06m_K`0O
7al0IFEU05ADE00k>c/0SXj>079bLP0S8b<0;bl_04=3@`0g=cL0F5QH0;Jf]P0c<c<061PH02h^;P1G
EeL0FUYJ06UYJ@2m_Kd0:2PX02<S8`0n?Sh0EEEE06ATI01gMgL0]kNg02`/;00i>CT0HV9R07MgM`1Y
JFT0JVYZ07UiN@0[:b/0;bl_06][J`26QXH0E5AD09:BTP2ZZZX07AdM03De=@0208f=S@1m06e]K@2L
W9`0MgMg03Xj>P19BDT0bLW908f=S@1BDU80/k>c065QH@0`<300EeMG06][J`1JFUX0G5aL03`l?01O
Gel0JFUY08>3P`0i>CT0O7al06IVIP0f=SH0Bd];08N7Q`1jNWX0>c/k06i^KP15ADD0;Bd]06EUI@2f
][H0De=C038b<P1OGel0De=C055AD@1jNWX0ZZZZ04E5A@1<C4`0DE5A04E5A@0i>CT0VYZJ0;Zj^P0l
?3`0?clo05iNGP17AdL0Jf][08j>SP14A4@0:RXZ04A4A01lO7`0FEUI06UYJ@1aLG40:2PX02XZ:P1T
I6@0TY:B04m?C`2<S8`08B4Q02DU9@1?Cdl0KVi^0492@P2EUID0QXJ601hN7P0h>3P0LG5a0:6QX@1a
LG40LW9b02<S8`1;Bd/0G5aL0;6a/@1_Kfl0Ti>C05MGE`0c<c<0Fe]K08n?S`1;Bd/0Lg=c03Hf=P0^
;Rh0Fe]K07]kN`1cLg<0EEEE04i>CP0j>SX0A4A406a/K01cLg<0<c<c06MWI`0^;Rh0=CDe071`L024
Q8@0=3@d04m?C`1FEUH0>SXj05UIF@1nOWh0Lg=c03<c<`23Ph<0BTY:05iNGP2>SXh0XJ6Q05EEE@0k
>c/0KVi^04Y:BP1;Bd/00P2^[Zh0?P0d=3@0AdM706QXJ01JFUX0AdM70:VYZ@2f][H0=cLg02h^;P1I
FET0OWin06i^KP2i^KT0MgMg034a<@12@T80MGEe09NGU`21PH40`/;204E5A@12@T80E5AD06e]K@1[
Jf/0QXJ609NGU`0[:b/0?3`l055AD@1MGEd0Kfm_065QH@2a/K40DU9B01dM7@1DE5@0PX:206i^KP1@
D500KFe]06i^KP0M7Ad0@D5104a<C01fMWH0>c/k05mOG`1dM7@0C4a<04Y:BP1SHf<0EeMG05aLG01J
FUX0Cdm?05eMG@1>CTh0Cdm?03dm?@1PH600MgMg0P1_Kfl06P1;Bd/0MgMg08b<S01bLW80Lg=c0451
@@0i>CT0Fe]K0492@P0n?Sh0EUIF069RHP1BDU80>SXj05EEE@1_Kfl0LW9b06][J`19BDT0IVIV06e]
K@1YJFT0DE5A06YZJP1`L700KFe]0P1EEED0400Y:BT0?Cdm055AD@1@D500Cdm?05ADE00j>SX0@D51
01dM7@1?Cdl0ADE505aLG00e=CD0<S8b04U9B@0e=CD2055AD@0V061PH020P800=cLg06m_K`1GEeL0
PH61069RHP1XJ6P0KFe]05ADE01VIVH0[:b/08b<S00S8b<0@D5105EEE@1^KVh0O7al06a/K017AdL0
ATI605iNGP1DE5@0GUiN08R8R01<C4`0EEEE04];B`1RHV80>3Ph0492@P17AdL0:b/[03/k>`0c<c<0
BDU903Hf=P10@40204U9B@0i04a<C01;Bd/0?clo069RHP0a<C40?clo04a<C00k>c/0Hf=S03<c<`1E
EED0IFEU05QHF00j>SX0>3Ph04A4A017AdL0IFEU07MgM`1BDU80HV9R04M7A`1<C4`0BDU9065QH@1[
Jf/0AdM706ATI00n?Sh0=cLg04A4A01IFET0EUIF02/[:`1@D500BTY:06ATI01IFET0UIFE05IFEP2j
^[X0?Shn06=SH`2;Rh/0D51@09fMW@1RHV80E5AD09FEU@1CDe<0BDU905YJFP0Z:RX0DE5A0410@01[
Jf/0FUYJ00<0BDU909`0RXZ:04M7A`2PX:00JFUY071`L01OGel0HF5Q05EEE@0g=cL0V9RH0:BTY014
A4@0De=C05IFEP0F5QH0Y:BT0;2`/00Y:BT0E5AD0451@@0h>3P0B4Q805IFEP1LG5`0HF5Q05iNGP1/
K6`0AdM705]KF`1>CTh0ADE506YZJP17AdL0?Cdm04Y:BP14A4@0@410061PH01oOgl0Bd];05YJFP1c
Lg<0TY:B0<G5a@1aLG40=SHf0410@00e=CD0[Jf]08>3P`0k>c/0JVYZ04E5A@1NGUh0Z:RX04Y:BP0l
?3`0ATI606YZJP1fMWH0Cdm?05YJFP1IFET0Vi^K04a<C01_Kfl0BDU906IVIP30`<00K6a/03`l?01?
Cdl0A4A4038b<P1;Bd/0AdM703@d=01MGEd0@T9203`l?00m?Cd0IVIV04E5A@0n?Sh0E5AD03`l?01:
BTX0BDU9059BDP2;Rh/0>3Ph055AD@1:BTX0@d=306m_K`0j>SX0FUYJ03Hf=P0i>CT0=CDe03/k>`1>
CTh0=SHf0492@P1RHV80BTY:05=CD`0m?Cd0De=C04U9B@10@400MgMg03Ph>01cLg<0Ogmo03`l?011
@D40M7Ad01dM7@12@T80E5AD04i>CP1/K6`0Lg=c07QhN01kNg/0MgMg05MGE`2>SXh0;2`/06EUI@1h
N7P0DU9B0:RXZ01]KFd0E5AD096AT@12@T80E5AD030`<00f=SH0E5AD03Ti>@16ATH0=SHf03Ph>016
ATH0Bd];06i^KP1;Bd/0C4a<05UIF@17AdL0Hf=S07IfMP1YJFT2ooooo`000700LW9b0<?3``1EEED0
FEUI07AdM01gMgL0WinO05iNGP0n?Sh0>CTi06e]K@1OGel0][Jf06=SH`0];Bd0:BTY05UIF@17AdL0
JFUY06m_K`0N7Qh0<c<c059BDP1JFUX0@41008B4Q01RHV804a<C02<S8`1TI6@0QHF505QHF02;Rh/0
:BTY03Ti>@1=CDd0PX:207emO@1JFUX0IVIV02TY:@16ATH0K6a/07YjNP1BDU80GUiN06IVIP0S8b<0
<30`05=CD`1UIFD0<30`03lo?`17AdL0;2`/04I6AP1[Jf/0O7al03@d=01FEUH0>3Ph030`<01iNGT0
PX:201HF5P0W9bL0B4Q803<c<`1XJ6P0WinO02/[:`0W9bL0;bl_03Ti>@1[Jf/0MWIf07AdM00M7Ad0
:RXZ03<c<`1kNg/0KVi^0:ZZZP1IFET0:BTY03De=@1EEED0MGEe07MgM`2>SXh0?Cdm03Ph>01?Cdl0
O7al07]kN`1jNWX0QhN703Ph>00c<c<0M7Ad08j>SP1SHf<0X:2P055AD@0P8200@d=309BDU01IFET0
QhN708Z:RP0O7al0<30`0P1PH600C014A4@0MgMg04i>CP0l?3`0FEUI06i^KP2ATI40?Cdm06EUI@0b
<S808b<S04];B`1WIfL0G5aL030`<01aLG40>3Ph03Hf=P1RHV80I6AT03dm?@1?Cdl0T92@04Q8B011
@D40FEUI09ZJVP2CTi<0?3`l06a/K013@d<0@41009:BTP2TY:@0<30`02l_;`1ZJVX0C4a<04E5A@2I
VIT0Jf][02d];@0i>CT0MWIf05mOG`25QHD0:BTY05ADE01oOgl0SXj>065QH@2SXj<0RXZ:02h^;P1K
Fe/0GemO09RHV01QHF40cLg=04A4A015ADD0ATI6071`L02@T900IfMW08f=S@1FEUH0;Bd]07EeM@2B
TY80?clo08Z:RP2[Zj/0<30`03Ti>@1?Cdl209^KV`1J075aL@1?Cdl07QhN061PH01bLW80NWYj04];
B`2=SHd0C4a<03@d=01YJFT0GUiN04m?C`1XJ6P0QXJ603/k>`0l?3`0HF5Q07AdM00m?Cd0Ogmo05AD
E00];Bd0AdM707UiN@0g=cL0C4a<05YJFP1;Bd/0AdM705MGE`1CDe<0@D5106][J`15ADD0<30`08Z:
RP2ATI40:RXZ06ATI01UIFD0De=C08n?S`1lO7`09bLW04E5A@1CDe<0JVYZ07alO02CTi<0;bl_03Lg
=`1:BTX0H61P05MGE`2h^;P0?Cdm034a<@16ATH0DU9B05QHF01TI6@0X:2P01lO7`1;Bd/0Jf][096A
T@1PH600ZZZZ06YZJP0V9RH0FEUI0861P@1eMGD0Hf=S09BDU00n?Sh0<c<c07=cL`2UYJD0Jf][07Ui
N@26QXH0=SHf03<c<`1SHf<0][Jf0:^[Z`2:RXX0XZ:R0P0b<S807P1CDe<0Xj>S055AD@1XJ6P0Ng]k
01dM7@18B4P0MWIf096AT@0h>3P0DE5A05aLG00Q8B40Cdm?08n?S`1XJ6P0:b/[065QH@13@d<0;Rh^
04a<C01TI6@0FEUI03De=@0o?cl0DE5A03hn?P1FEUH0Jf][07inOP80<30`0?l0HV9R05IFEP1CDe<0
FEUI07emO@1ADE40D51@07emO@1HF5P0OGem06i^KP1CDe<0PX:205QHF01PH600ADE508:2PP23Ph<0
I6AT08j>SP21PH40WIfM06e]K@13@d<0Hf=S04M7A`0o?cl0@D5104m?C`0i>CT0E5AD04U9B@1TI6@0
?clo055AD@1?Cdl0BTY:05EEE@12@T80Hf=S055AD@1PH600BTY:07alO01DE5@0GEeM03dm?@1;Bd/0
DU9B03dm?@1?Cdl0Bd];04A4A01=CDd0=SHf04E5A@0];Bd0FEUI02`/;016ATH0?3`l04m?C`1JFUX0
<c<c03`l?015ADD0D51@05YJFP0P8200ATI606IVIP1GEeL0EEEE05QHF01ADE40F5QH05UIF@1UIFD0
GemO04U9B@1KFe/0GUiN04i>CP1HF5P0KFe]04U9B@15ADD0EUIF02XZ:P10@400Rh^;06m_K`1TI6@0
>c/k059BDP0n?Sh0D51@03lo?`0_;bl0E5AD03Lg=`15ADD0;Bd]05=CD`0m?Cd0ADE505ADE01_Kfl0
=CDe051@D00`<300EUIF05aLG00k>c/0@d=303`l?01IFET0BDU904Y:BP1@D500ATI605]KF`1?Cdl0
V9RH08F5Q@1;Bd/0I6AT05IFEP1SHf<0ATI605mOG`1IFET0AdM707alO018B4P0IVIV051@D00m?Cd0
HV9R02`/;01FEUH0GemO06MWI`16ATH0G5aL04=3@`34a<@08R8R05iNGP1MGEd0:BTY06UYJ@10@400
E5AD0:^[Z`1ADE40=cLg0492@P0e=CD0HV9R02<S8`16ATH0>c/k04i>CP1NGUh0B4Q808>3P`0b<S80
XJ6Q03Lg=`18B4P0=cLg06ATI01FEUH0?Cdm04Q8B01?Cdl0De=C04Y:BP1ADE40:BTY0<C4a032`/80
:RXZ07inOP1iNGT0HV9R09RHV01XJ6P0L71`03lo?`1`L700H61P03Ti>@1PH600@T9204Y:BP1gMgL0
<S8b03/k>`1FEUH0@41004m?C`1=CDd0FUYJ05eMG@1`L700TI6A07=cL`1kNg/0FUYJ04M7A`11@D40
;bl_04U9B@1NGUh0Bd];07]kN`14A4@0CTi>075aL@0f=SH0CTi>03dm?@0j>SX0@D5104a<C022PX80
CTi>04Y:BP1FEUH0_kno09NGU`1DE5@0W9bL05aLG00W9bL0Bd];03@d=00j>SX0E5AD05=CD`0j>SX0
FUYJ04a<C016ATH0@T92071`L011@D40@d=305ADE012@T80JVYZ04I6AP0o?cl003/0CTi>03/k>`1`
L700?Cdm03Ph>01SHf<0?Cdm061PH01IFET0?clo03@d=00f=SH0FEUI04=3@`12@T80Fe]K02DU9@1?
Cdl0>SXj07inOP1HF5P0;2`/02d];@0O7al0C4a<04m?C`0c<c<0Jf][08j>SP12@T80F5QH055AD@1K
Fe/0JVYZ04e=C@1@D500^k^k09JFUP1:BTX0N7Qh02TY:@1`L700IfMW08n?S`39bLT0N7Qh071`L029
RHT0;Bd]04i>CP0k>c/0EEEE06][J`0c<c<0JVYZ04Y:BP1?Cdl0DU9B0451@@0205QHF00605=CD`1J
FUX0GUiN059BDP1MGEd0J6QX0_ooool0002O05QHF01gMgL0Rh^;06IVIP1cLg<0BTY:05=CD`25QHD0
B4Q806EUI@0_;bl0:BTY04Y:BP1]KFd0<c<c04e=C@1:BTX0;Rh^04m?C`1]KFd0@d=303`l?01?Cdl0
<S8b04i>CP1XJ6P0Rh^;03/k>`0Y:BT0C4a<055AD@1CDe<0RHV9061PH00K6a/0ADE504M7A`0n?Sh0
J6QX0:BTY00f=SH06ATI04=3@`1WIfL0@T9206][J`2CTi<0GEeM01XJ6P14A4@0MGEe069RHP1cLg<0
OWin01XJ6P0Z:RX0@41006MWI`1PH600/[:b038b<P0Z:RX0>3Ph05aLG01ADE40U9BD051@D00Q8B40
?Cdm071`L01eMGD0IFEU09:BTP0n?Sh061PH05YJFP2DU9@0IfMW04A4A01VIVH08b<S04i>CP1aLG40
Rh^;0410@013@d<0B4Q801LG5`0j>SX0BTY:04a<C00^;Rh0FUYJ04A4A00Q8B40CTi>065QH@1BDU80
=CDe07YjNP0];Bd0=3@d06IVIP11@D406a/K03Ti>@12@T80;Bd]05ADE02CTi<0DE5A02HV9P0o?cl0
@D5104m?C`1PH600ADE502d];@0o?cl0DE5A04m?C`1aLG40^KVi06=SH`0K6a/0<c<c04a<C00o?cl0
Cdm?0;bl_01MGEd07QhN04E5A@1MGEd0@d=305iNGP2b/[80H61P03<c<`0h>3P0J6QX07moO`1TI6@0
bl_;04i>CP13@d<0Cdm?08b<S01mOGd0Xj>S09FEU@0g=cL0F5QH06MWI`2c/k<0I6AT07emO@1UIFD0
>CTi0080FUYJ0?l0CDe=08j>SP0Z:RX0<c<c055AD@1eMGD0D51@07YjNP2>SXh07QhN04M7A`1bLW80
OWin04E5A@1iNGT0FUYJ03dm?@1NGUh0M7Ad07QhN00n?Sh0LW9b08B4Q01@D500IfMW09ZJVP1[Jf/0
<c<c07YjNP1dM7@0?3`l0:>SX`2o_kl0ADE503dm?@1bLW80IfMW059BDP2SXj<0Shn?038b<P0m?Cd0
FUYJ03`l?026QXH0bl_;05ADE00X:2P0?Shn05iNGP1EEED0bLW907emO@0a<C40>CTi06a/K01YJFT0
YZJV0=OGe`1KFe/0;2`/04U9B@1DE5@0KFe]0<O7a`1iNGT0<30`03Ti>@1VIVH0GemO0;>c/`27QhL0
9RHV06m_K`2n_[h0R8R808:2PP1bLW80?Shn07EeM@2^[Zh0M7Ad06a/K01eMGD0:2PX04M7A`2;Rh/0
Ogmo055AD@2MWId0De=C03De=@1<C4`0PH6105EEE@1KFe/0Ogmo02h^;P1MGEd0T92@08b<S00i>CT0
?clo06][J`0o?cl0HV9R07UiN@1HF5P0>SXj05MGE`1YJFT0Fe]K05YJFP1mOGd0CDe=02h^;P1LG5`0
HV9R03hn?P1PH600^k^k059BDP0d=3@0@D5106=SH`1XJ6P0OGem08f=S@0Q8B40<C4a04=3@`1eMGD0
MWIf07]kN`2;Rh/08b<S03@d=01JFUX0OGem04E5A@26QXH0Lg=c01dM7@1;Bd/0LW9b06YZJP1<C4`0
Ti>C0:BTY00b<S809bLW069RHP2DU9@0N7Qh06EUI@2g]kL0<c<c03@d=01GEeL0P82006][J`1RHV80
NGUi065QH@1nOWh0KVi^05eMG@27QhL0Fe]K06QXJ01DE5@0OWin08J6QP1dM7@0LG5a05ADE01^KVh0
IFEU06ATI01cLg<0B4Q804M7A`1>CTh0DE5A04E5A@1`L700GEeM07EeM@1<C4`0GemO06MWI`1OGel0
KVi^059BDP1lO7`0L71`06a/K01VIVH0Ogmo05UIF@1ZJVX0BDU905EEE@1IFET0ADE505UIF@1:BTX0
AdM705mOG`0g=cL0ADE502h^;P1QHF40@41005EEE@0o?cl0?3`l05UIF@0c<c<0@T92065QH@1LG5`0
Kfm_03hn?P1EEED0HV9R06YZJP1HF5P0HF5Q051@D01ADE40LG5a08Z:RP2=SHd0@D5103Ph>01JFUX0
Fe]K06YZJP1JFUX0D51@06MWI`1KFe/0<c<c03lo?`1UIFD0?Cdm06MWI`1:BTX0HV9R04E5A@1@D500
>CTi03Lg=`1UIFD00<d0;bl_04Q8B00];Bd0B4Q803Ph>013@d<0DU9B05UIF@0Z:RX0D51@020P800e
=CD0ATI602`/;01CDe<0:2PX04Q8B01BDU80?clo04U9B@0c<c<0BTY:03dm?@1JFUX0G5aL03lo?`1J
FUX0CDe=05]KF`14A4@0EEEE05eMG@1QHF40Ogmo04Y:BP15ADD0DU9B04e=C@1gMgL0>SXj05mOG`12
@T80F5QH07=cL`2FUYH0BTY:09bLW00T92@0MgMg07moO`15ADD0/k>c059BDP0j>SX0UYJF055AD@1N
GUh0CTi>034a<@1;Bd/0<30`04U9B@1CDe<0<C4a03Xj>P10@400Lg=c03hn?P2WYjL0AdM707EeM@1H
F5P0HV9R04a<C00k>c/0LW9b07AdM01?Cdl0HV9R06IVIP1=CDd0R8R808Z:RP1?Cdl0LG5a04Q8B017
AdL0@T9206=SH`1QHF407AdM05=CD`1@D500BTY:06MWI`17AdL0?clo05EEE@0o?cl0NGUi06MWI`1;
Bd/0EEEE05aLG021PH40GUiN0861P@2CTi<0RHV909FEU@1;Bd/0AdM705MGE`0n?Sh0JVYZ061PH01K
Fe/0Xj>S06ATI01/K6`0S8b<04i>CP1SHf<0BDU905UIF@1DE5@0>c/k05mOG`17AdL0NWYj055AD@1S
Hf<0IVIV04A4A01BDU80D51@02DU9@1_Kfl0D51@04i>CP1FEUH0GemO055AD@1YJFT0?3`l04Q8B017
AdL0LG5a0451@@12@T80Cdm?02/[:`12@T80ATI604E5A@1RHV80@d=30820P013@d<0?clo04m?C`1:
BTX0Hf=S034a<@0U9BD0<S8b02/[:`11@D40;bl_03<c<`1FEUH0@D5106IVIP0c<c<0GemO04i>CP12
@T80CTi>03/k>`1]KFd0QHF504];B`17AdL0HF5Q024Q8@1FEUH0GUiN06][J`1YJFT0FEUI061PH01`
L700PX:206YZJP2BTY80>CTi079bLP2=SHd0L71`08:2PP0h>3P0?clo05=CD`0M7Ad0ATI60080>3Ph
00l0BTY:03/k>`1ADE40=3@d03dm?@1;Bd/0H61P07alO01JFUX0BDU905aLG015ADD0EUIF06IVIP1L
G5`00_ooool0000^05YJFP1FEUH0Lg=c08f=S@24Q8@0?Cdm03lo?`1bLW80JVYZ09NGU`18B4P0:2PX
0410@01?Cdl0>c/k0:2PX02GUiL07AdM030`<01PH600D51@07]kN`2DU9@06a/K04M7A`1DE5@0JVYZ
071`L01eMGD0C4a<02HV9P0n?Sh0IVIV08N7Q`1NGUh0Rh^;04E5A@0c<c<0@T9207UiN@2MWId0GEeM
07IfMP17AdL07QhN04Q8B080L71`01X0DE5A06YZJP15ADD07AdM04I6AP1CDe<0?3`l03<c<`16ATH0
7AdM024Q8@1eMGD0IfMW03@d=01GEeL0=CDe01dM7@19BDT0OWin02XZ:P0e=CD0AdM702h^;P17AdL0
U9BD07QhN0806a/K00@0CDe=05iNGP1UIFD0X:2P0P0V9RH0o`0a<C40H61P05ADE01iNGT0P82001DE
5@0i>CT0Bd];05EEE@0c<c<0SHf=06a/K00N7Qh0?Cdm04U9B@1NGUh0C4a<0<71`@0/;2`0;Rh^051@
D01PH600DU9B06m_K`0o?cl07QhN034a<@1LG5`0QHF505MGE`1gMgL07QhN02`/;019BDT0H61P04M7
A`1nOWh0^k^k02HV9P0[:b/0C4a<08>3P`17AdL0HF5Q08>3P`0O7al0:RXZ05]KF`1fMWH0<30`04Y:
BP1GEeL08R8R024Q8@1NGUh0Lg=c04=3@`1GEeL0EUIF034a<@0c<c<0GEeM06UYJ@0j>SX0G5aL04I6
AP15ADD0Fe]K0:BTY01DE5@0>c/k04Q8B01=CDd0>CTi075aL@1]KFd0:b/[05=CD`13@d<0P8200:n_
[`10@4009bLW05mOG`1DE5@0EeMG09nOW`2a/K409RHV04i>CP1[Jf/0Kfm_059BDP2f][H0R8R802/[
:`1JFUX0Kfm_06i^KP1FEUH0e=CD0:VYZ@0];Bd0BDU905ADE01^KVh0DU9B0;:b/P2MWId0DU9B04E5
A@2<S8`0I6AT09>CT`2;Rh/0=SHf03/k>`1ZJVX0Rh^;05QHF01OGel0EeMG02/[:`12@T80X:2P08R8
R01DE5@0L71`02@T900/;2`0Shn?09jNWP1BDU80IfMW0492@P0f=SH0BDU90;Zj^P2h^;P0LG5a04m?
C`0U9BD0@D5107MgM`2^[Zh0EEEE08^;R`0g=cL0@41007IfMP2h^;P0CTi>065QH@0l?3`0BDU907al
O01YJFT0;2`/05ADE01iNGT0?3`l07inOP2][Jd0?Cdm034a<@1FEUH0E5AD04M7A`2KVi/0@D5102/[
:`0k>c/0KVi^06IVIP1jNWX0Ti>C038b<P0_;bl0GemO08R8R01KFe/0NWYj09BDU00i>CT0=cLg08>3
P`1RHV80KVi^0<o?c`2IVIT0@T9205]KF`1IFET0LG5a06MWI`3Fe]H0SXj>04];B`1=CDd0H61P08J6
QP20P800WIfM04E5A@0`<300E5AD06IVIP1]KFd0EeMG08^;R`0c<c<0<C4a0492@P1JFUX0ADE504U9
B@25QHD0=CDe03Ti>@1;Bd/0MGEe04Q8B019BDT0HF5Q03@d=00b<S80CTi>05iNGP1PH600<S8b04Y:
BP14A4@0>3Ph04E5A@1mOGd0Cdm?02/[:`1DE5@0M7Ad059BDP1@D500IVIV069RHP1gMgL0Fe]K05=C
D`1XJ6P0I6AT04I6AP0j>SX0I6AT06e]K@1EEED0LG5a04i>CP007@1dM7@0IfMW04E5A@1HF5P0@d=3
03Ph>019BDT0Fe]K05=CD`1[Jf/0DE5A06QXJ01WIfL0JVYZ061PH01fMWH0Cdm?03`l?01=CDd0De=C
05aLG017AdL0F5QH04U9B@1DE5@0?Cdm05YJFP19BDT0@D510080De=C0180Jf][055AD@10@400@d=3
02HV9P1HF5P0<30`059BDP0_;bl0A4A404i>CP0l?3`0Cdm?05YJFP1]KFd0NGUi02HV9P15ADD206i^
KP0a05mOG`1JFUX0Hf=S05eMG@1gMgL0Zj^[08V9R@0d=3@0A4A4069RHP1[Jf/0Ph>305=CD`18B4P0
DU9B06][J`18B4P0FUYJ07alO01?Cdl0Hf=S04a<C01IFET0=CDe055AD@1?Cdl0>SXj069RHP17AdL0
CTi>03Ti>@1DE5@0Bd];05UIF@1DE5@0MgMg0451@@1FEUH0>c/k04i>CP1EEED0A4A406MWI`17AdL0
Fe]K05=CD`1OGel0CDe=04Y:BP0205IFEP1K09VIV@25QHD0DE5A06ATI016ATH0Fe]K0410@01SHf<0
=cLg03hn?P1oOgl0CTi>03hn?P1<C4`0D51@05eMG@0f=SH0EeMG05YJFP1YJFT0Cdm?06QXJ01BDU80
`/;203@d=01QHF40ADE502l_;`1hN7P0ATI604=3@`2GUiL0GUiN04m?C`1KFe/0=3@d04e=C@0b<S80
I6AT03hn?P1<C4`0Cdm?02`/;01oOgl0ATI60;>c/`0R8R80GUiN03@d=01=CDd0>SXj05iNGP2QXJ40
W9bL05eMG@24Q8@0Lg=c04Q8B03>c/h0]kNg03hn?P2SXj<0ADE504Q8B01:BTX0J6QX075aL@1@D500
RXZ:06EUI@0m?Cd0@T9203Ph>01NGUh0Rh^;04a<C01;Bd/0CDe=04M7A`1<C4`0QHF50:NWY`1XJ6P0
Ph>309nOW`2_[jl0Ti>C05iNGP1QHF40E5AD04];B`0206UYJ@0T059BDP2FUYH0OWin0:NWY`33`l<0
A4A404E5A@0X:2P0BTY:04A4A00o?cl0De=C04Q8B01bLW80@T9208^;R`1kNg/0I6AT0<g=c@1eMGD0
?Shn04=3@`0n?Sh0@D5104a<C01>CTh0=3@d04E5A@0`<300>SXj030`<01HF5P0=CDe03Ti>@1<C4`0
=3@d0P1>CTh05P1IFET0MGEe02l_;`1DE5@0;bl_04=3@`1UIFD0;Bd]06QXJ00W9bL0820P02PX:00`
<300BDU90410@016ATH0NGUi04I6AP15ADD0@d=3096AT@1aLG4206=SH`0/02`/;01SHf<0G5aL02HV
9P1UIFD0[Jf]02TY:@1@D500FUYJ08R8R01hN7P0GUiN059BDP2o_kl0RHV907=cL`2?Shl0>SXj06UY
J@1EEED0R8R80:RXZ00d=3@0EEEE061PH00d=3@0CDe=02PX:017AdL0FUYJ065QH@2:RXX0GemO04I6
AP14A4@0C4a<05aLG00n?Sh0@d=305QHF017AdL0Jf][07MgM`1FEUH2ooooo`000?l0XZ:R09^KV`1@
D500Hf=S0;6a/@1TI6@0GemO0410@01CDe<0Ogmo0<71`@1EEED0L71`05QHF00/;2`0LW9b09>CT`0i
>CT0B4Q804Y:BP0O7al0?Shn08:2PP12@T807AdM065QH@11@D40?3`l08V9R@25QHD0<c<c02<S8`13
@d<0;2`/061PH02`/;00HF5Q02TY:@0/;2`0C4a<071`L01LG5`0/K6a04i>CP0O7al06a/K0410@012
@T80@D51079bLP1QHF4061PH01lO7`19BDT0=CDe06=SH`27QhL07alO01PH600^;Rh0D51@04e=C@27
QhL0CTi>02XZ:P0g=cL0G5aL04=3@`1iNGT0ZZZZ01`L700o?cl0Cdm?075aL@1=CDd0G5aL06QXJ00J
6QX0>CTi0410@01XJ6P0ATI607QhN013@d<0>3Ph04M7A`1MGEd0BTY:04M7A`2GUiL0Cdm?04a<C01`
L700XJ6Q05=CD`1UIFD0RHV9020P801:BTX0P82009:BTP17AdL0FUYJ02@T900g=cL0C4a<07AdM013
@d<0>3Ph04m?C`0d=3@0Cdm?07EeM@0m?Cd06a/K03hn?P0m?Cd0@T9206MWI`2HV9P0B4Q8024Q8@1A
DE40B4Q806e]K@1bLW80a/K603`l?00P8200F5QH07alO01XJ6P0UiNG06m_K`0U9BD071`L04U9B@1P
H600CTi>07EeM@2JVYX06a/K0410@01;Bd/0HV9R05QHF02EUID0Ng]k02/[:`15ADD0IFEU06][J`1T
I6@0V9RH03De=@14A4@0D51@07emO@1GEeL0J6QX01/K6`0];Bd0M7Ad08N7Q`19BDT0[:b/05mOG`0M
7Ad0GEeM09fMW@1;Bd/0BDU908n?S`0d=3@08B4Q06QXJ02NWYh0D51@055AD@1OGel0>3Ph03Ti>@1M
GEd0];Bd05IFEP19BDT0E5AD02TY:@0X:2P0N7Qh0:ZZZP1EEED0CDe=03Ti>@0n?Sh0Hf=S061PH00^
;Rh0;bl_06=SH`11@D40GemO08N7Q`1<C4`0820P02/[:`1MGEd0EeMG09FEU@2ATI40820P02PX:01J
FUX0J6QX04e=C@2HV9P0C4a<01lO7`0b<S80Kfm_08Z:RP32`/80WIfM02LW9`0f=SH0CTi>08J6QP1^
KVh0d];B05YJFP0/;2`0FUYJ07YjNP1aLG40UiNG06][J`0J6QX0EUIF0:ZZZP1^KVh0P82008V9R@0`
<300<S8b07inOP1OGel0FUYJ07emO@0Z:RX0;Bd]06EUI@2?Shl0IFEU07EeM@16ATH00?l0@T9206IV
IP1ZJVX0GUiN0820P02DU9@0<C4a030`<01>CTh0[jn_07=cL`1GEeL0Q8B403Ti>@0f=SH0M7Ad0:6Q
X@1JFUX0IfMW05]KF`0a<C40:BTY059BDP2=SHd0CTi>06ATI00c<c<0=3@d05=CD`20P800QHF503Xj
>P1KFe/0Cdm?03`l?02:RXX0dM7A061PH00b<S80F5QH04Y:BP13@d<0NGUi0:NWY`1ADE40<C4a04Q8
B01EEED0E5AD0820P03<c<`0GemO02LW9`12@T80BDU906EUI@1_Kfl0TY:B07IfMP0X:2P0ADE5071`
L022PX80Jf][051@D02:RXX0GEeM059BDP1lO7`0JVYZ07inOP1FEUH0CTi>05EEE@1CDe<0@d=303De
=@1gMgL0N7Qh06i^KP2ATI40Lg=c09bLW01bLW80Bd];05ADE00k>c/0@T92055AD@11@D40?Cdm05UI
F@1WIfL0DE5A03hn?P17AdL0?clo04e=C@1RHV80ATI607MgM`1KFe/0JVYZ05]KF`28R8P0FEUI06i^
KP18B4P0H61P05IFEP0n?Sh0EUIF04a<C00g=cL0?clo03De=@0m?Cd0;Bd]05QHF00_;bl0DE5A02h^
;P14A4@0CDe=02l_;`0k>c/0A4A405QHF01PH60092@T0492@P18B4P0H61P05QHF018B4P0CDe=07Ad
M01_Kfl0MGEe08V9R@0l?3`0A4A406EUI@1DE5@0IfMW06QXJ01FEUH0Hf=S05QHF00[:b/0@41007Ad
M01ZJVX0Hf=S04U9B@1HF5P0A4A405EEE@0o?cl0AdM7069RHP0l?3`0=cLg02XZ:P1JFUX0>SXj04E5
A@1:BTX0IVIV03Hf=P10@400820P059BDP1FEUH0;bl_04];B`0l?3`0FEUI04U9B@0g=cL0G5aL03hn
?P1SHf<0CTi>092@T022PX80DE5A05YJFP18B4P0FEUI0410@019BDT0>c/k04];B`1dM7@0A4A405IF
EP1>CTh0@d=307AdM011@D40M7Ad05QHF01PH600LW9b08j>SP1BDU80`l?304E5A@21PH40?3`l03hn
?P2:RXX0CDe=06=SH`30`<00FUYJ06][J`1EEED0@d=305iNGP19BDT0E5AD04m?C`0];Bd0>SXj04e=
C@2GUiL0ADE509RHV00i>CT0I6AT0410@01jNWX0>3Ph04I6AP1LG5`0GEeM07emO@21PH40Fe]K03Lg
=`2h^;P0]KFe04E5A@0o?cl09RHV06QXJ00l?3`0De=C05aLG00a<C40FUYJ05=CD`11@D400P1BDU80
8`1JFUX0Ogmo04E5A@1ADE40GEeM05EEE@1KFe/0CDe=04Q8B01FEUH0OGem07UiN@27QhL0Y:BT03lo
?`14A4@0C4a<02l_;`2VYZH0EUIF04A4A027QhL0ATI6051@D01OGel0@d=307AdM01IFET0DE5A059B
DP1OGel0NWYj03Ph>01ADE408b<S0080O7al0P0j>SX0E`0m?Cd09bLW05MGE`0n?Sh09BDU03Ph>01N
GUh09bLW04e=C@0W9bL0CDe=03Ph>01RHV80:b/[03<c<`1?Cdl0?3`l065QH@0n?Sh0=cLg04a<C00e
=CD0Hf=S02@T900_;bl0AdM702h^;P2FUYH0:b/[02l_;`13@d<0@41004e=C@0j>SX0;2`/05iNGP0`
<300D51@04m?C`1cLg<0De=C03Ti>@0o?cl0@D5106a/K01PH600>c/k04];B`1SHf<0C4a<08N7Q`1Z
JVX0JFUY04I6AP1<C4`0<c<c0;Vi^@21PH40IFEU07=cL`0d=3@0Hf=S061PH01[Jf/0OGem04=3@`1_
Kfl0MGEe0492@P1gMgL0HF5Q069RHP1QHF40@T9206QXJ00j>SX0@D5103Lg=`1IFET0Ogmo04=3@`1@
D500Jf][04i>CP1DE5@0LW9b055AD@02ooooo`000440F5QH0;Zj^P1`L700Fe]K05iNGP1KFe/0XJ6Q
04a<C00b<S80BTY:04m?C`1XJ6P0aLG506ATI00S8b<0>3Ph05EEE@10@400L71`06IVIP0V9RH0:BTY
0410@01SHf<0DE5A0;2`/01>CTh05aLG02@T9024Q8@0Xj>S06=SH`2h^;P0<c<c02PX:01_Kfl0];Bd
08n?S`1jNWX0Ng]k034a<@0N7Qh0D51@09FEU@1UIFD0OGem09^KV`0Z:RX09bLW03Lg=`1SHf<0ATI6
05aLG01BDU809BDU034a<@2;Rh/0UIFE04A4A01kNg/0=CDe02HV9P1:BTX0CDe=03Hf=P0204M7A`39
02XZ:P13@d<0FEUI04M7A`0a<C40B4Q802LW9`0n?Sh0De=C08Z:RP1LG5`0;bl_05eMG@0f=SH0FUYJ
0861P@2?Shl0:b/[03hn?P0i>CT0CDe=06][J`2j^[X0J6QX01/K6`0j>SX0=CDe03Ph>01]KFd0T92@
02<S8`0`<300@d=304a<C02UYJD0];Bd03Xj>P0U9BD0=cLg05YJFP1_Kfl0Q8B40:>SX`0M7Ad0;Bd]
059BDP1mOGd0DU9B07alO011@D40820P04i>CP1[Jf/0U9BD05UIF@23Ph<0;Rh^03De=@1dM7@0/[:b
09^KV`1<C4`0G5aL02TY:@13@d<0MGEe0:^[Z`1?Cdl0ATI605YJFP0Y:BT09bLW055AD@1PH600@T92
02d];@1cLg<0:BTY03Ti>@1EEED0O7al03Xj>P1KFe/0CDe=02DU9@1;Bd/0HV9R04M7A`0S8b<0De=C
02/[:`12@T80J6QX034a<@0o?cl0IfMW059BDP1ADE40VIVI05QHF00h>3P0@d=305QHF01<C4`0Jf][
0<30`01[Jf/071`L051@D01^KVh0@d=307AdM03>c/h0Fe]K02d];@1?Cdl0LG5a09NGU`2VYZH0ZJVY
03Ph>00c<c<0GEeM0::RXP1oOgl0UiNG079bLP0R8R80Cdm?069RHP1SHf<0HF5Q0;Fe]@11@D407AdM
04E5A@1WIfL0BTY:05EEE@1eMGD0=3@d03Hf=P1KFe/0M7Ad0410@02][Jd0I6AT02TY:@0o?cl0LG5a
03dm?@1OGel0OWin04E5A@0f=SH0QXJ606e]K@15ADD0P82004E5A@0`<300?clo05UIF@10@400IVIV
04Q8B00i>CT0UiNG08b<S010@400IfMW05aLG00e=CD0N7Qh0;Bd]012@T80>c/k05=CD`14A4@0GUiN
09^KV`0e=CD0:BTY04A4A01MGEd0M7Ad08V9R@1^KVh0:b/[05MGE`1RHV80?Cdm09:BTP31`L40AdM7
02d];@18B4P0MgMg075aL@24Q8@0`L710080?Shn02l0CTi>07AdM01eMGD0UiNG09^KV`0V9RH0ATI6
05EEE@1RHV80Bd];0<G5a@2KVi/06QXJ04Y:BP1nOWh0Ogmo04a<C01iNGT0J6QX04=3@`1<C4`0WYjN
0:FUY@1WIfL0Zj^[03hn?P10@400@D5106m_K`1iNGT0E5AD07alO01IFET0:2PX03lo?`1MGEd0N7Qh
04M7A`1IFET0HV9R01lO7`10@400J6QX06EUI@14A4@0CDe=08>3P`0202XZ:P3[04i>CP1VIVH0OWin
06EUI@1LG5`0BDU906=SH`1aLG40K6a/06MWI`1FEUH0G5aL07IfMP1SHf<0PH610820P01nOWh0VIVI
075aL@1JFUX0BDU905]KF`1IFET0>c/k03lo?`1?Cdl0DE5A05eMG@1JFUX0GemO05IFEP1[Jf/0CTi>
055AD@1PH600I6AT065QH@1GEeL0EUIF06EUI@1_Kfl0EEEE05eMG@1JFUX0Fe]K061PH01XJ6P0M7Ad
051@D019BDT0EeMG05=CD`12@T80<c<c05MGE`1@D500Hf=S02XZ:P0j>SX0D51@03Ti>@15ADD0BTY:
06ATI01`L700<30`04I6AP0j>SX0KVi^05=CD`1HF5P0EeMG05aLG01HF5P0[Zj^0861P@14A4@0DU9B
06IVIP1CDe<0G5aL05QHF011@D40C4a<05]KF`1;Bd/0DU9B07EeM@1@D500IfMW051@D01>CTh0:RXZ
04e=C@12@T80=SHf04e=C@0`<300@T9201lO7`1=CDd0>c/k04Y:BP1ADE40Jf][02d];@13@d<07QhN
0492@P16ATH0:b/[05EEE@0h>3P0E5AD04Q8B010@400E5AD03`l?01ADE40BDU908:2PP1RHV80ADE5
05YJFP18B4P0EeMG04E5A@1GEeL0ADE5051@D01[Jf/0@41003dm?@17AdL0@T9206i^KP1<C4`0IFEU
05]KF`1gMgL0QhN70:b/[01gMgL0bl_;05QHF02TY:@0Ng]k05MGE`2DU9@0>3Ph04];B`2QXJ40?3`l
07EeM@1OGel0@T9203/k>`0Y:BT0Lg=c04M7A`1:BTX0KFe]04e=C@1hN7P0JVYZ0;:b/P1DE5@0K6a/
0820P01bLW80EEEE051@D01ZJVX0KFe]05YJFP1GEeL0Jf][03/k>`39bLT0U9BD03Lg=`1nOWh0=SHf
05=CD`0o?cl0C4a<06QXJ011@D40FUYJ04m?C`19BDT0EEEE038b<P1WIfL0/;2`03dm?@1@D500FUYJ
05EEE@1VIVH0EeMG079bLP2<S8`0^;Rh07IfMP1]KFd0I6AT0451@@16ATH0@d=303<c<`1GEeL0De=C
06UYJ@2ZZZX0@T9207inOP1bLW80?Shn04=3@`0Z:RX0Cdm?02h^;P14A4@0GemO059BDP1XJ6P06ATI
06e]K@1dM7@0@41006a/K00b<S803`l?03dm?@0202`/;00W04m?C`1EEED0@410051@D00e=CD0Bd];
0410@01NGUh0=SHf03/k>`1=CDd0?Shn059BDP17AdL0Bd];05eMG@10@400Q8B402/[:`0f=SH0ADE5
03@d=01DE5@0HV9R04];B`0j>SX0BTY:05=CD`17AdL0D51@06YZJP17AdL0E5AD055AD@2IVIT0Kfm_
04Y:BP17AdL0E5AD0080GUiN02T0@D5105ADE025QHD092@T059BDP0X:2P0L71`04I6AP1[Jf/0DU9B
05eMG@1NGUh0KFe]07AdM00W9bL0EUIF06EUI@24Q8@0SXj>01hN7P14A4@0B4Q802LW9`1:BTX071`L
03Ti>@1@D500?Shn071`L00a<C40Bd];059BDP1cLg<0UYJF04A4A019BDT0M7Ad05YJFP17AdL0Ogmo
05]KF`02ooooo`0001L0FEUI06UYJ@1mOGd0[Zj^08V9R@19BDT0EUIF06YZJP1UIFD0TY:B03Hf=P0d
=3@0?Cdm065QH@13@d<0L71`03Ti>@0^;Rh0>CTi04];B`1:BTX0DU9B05YJFP0202HV9P3503@d=01S
Hf<0A4A405MGE`1?Cdl0;Rh^0410@01XJ6P0?Shn034a<@1DE5@0;Rh^02PX:01bLW80NGUi0492@P0k
>c/0G5aL038b<P0K6a/0C4a<08F5Q@1;Bd/08B4Q04M7A`10@400FEUI06YZJP1bLW805aLG03De=@15
ADD0MGEe08N7Q`30`<00@D51020P801:BTX0@D5105UIF@2KVi/0SXj>018B4P0];Bd0GUiN0451@@1i
NGT0a<C403/k>`0D51@0>CTi06i^KP1fMWH0TI6A0=3@d00c<c<0;Bd]05=CD`24Q8@0Hf=S0;Vi^@2?
Shl0;bl_03Hf=P1TI6@0QXJ605=CD`2=SHd0=SHf02l_;`1<C4`0GUiN04m?C`1JFUX0PH6102<S8`0n
?Sh0MWIf05mOG`0e=CD0DE5A03dm?@0I6AT0FEUI0:6QX@1gMgL0;2`/05=CD`0S8b<0ADE506YZJP1d
M7@0;Rh^02d];@1BDU80>CTi05YJFP1cLg<0A4A401TI6@0a<C40AdM7079bLP1fMWH0O7al02LW9`0Z
:RX0>c/k05EEE@1WIfL0M7Ad0:j^[P0a<C408B4Q03/k>`1MGEd0Cdm?07QhN026QXH092@T01/K6`0n
?Sh0O7al05ADE02YZJT0P82002PX:00P8200H61P08:2PP1NGUh0YZJV038b<P0L71`0G5aL05=CD`1f
MWH0TI6A0451@@0c<c<0J6QX09:BTP1CDe<0YjNW07]kN`0_;bl0AdM706=SH`2WYjL0Fe]K07UiN@1[
Jf/0>c/k0492@P1JFUX0N7Qh03lo?`22PX80EEEE02l_;`1/K6`0MGEe069RHP1IFET0MgMg04a<C017
AdL0GemO09FEU@1EEED0JFUY06YZJP0m?Cd0H61P08:2PP2MWId0>CTi059BDP1UIFD0=3@d065QH@2J
VYX0>CTi03/k>`1HF5P0>CTi03Xj>P2h^;P0Lg=c02l_;`1GEeL0Bd];03Xj>P2:RXX0YJFU059BDP0b
<S800P17AdL06`1gMgL0/K6a07IfMP0i>CT0E5AD04Y:BP1kNg/0Shn?06IVIP0F5QH0CDe=07IfMP1>
CTh0_kno06IVIP0a<C40>c/k0:f][@2@T900UIFE08>3P`0U9BD0@d=307emO@1TI6@0D51@05eMG@02
03/k>`0]06QXJ02MWId0G5aL09VIV@27QhL0@d=303/k>`2:RXX0PX:205MGE`1UIFD0OWin03lo?`18
B4P0Z:RX059BDP0o?cl0PX:203dm?@1BDU80WinO0::RXP0m?Cd0Bd];09^KV`12@T80D51@0:6QX@2S
Xj<0<S8b03<c<`1ADE40CTi>05mOG`1lO7`0HF5Q02<S8`0g=cL0A4A406QXJ01VIVH0QhN706UYJ@0N
7Qh0?clo0080HF5Q02`0I6AT0:2PX01fMWH0:RXZ04Q8B01[Jf/0Fe]K04U9B@1jNWX0L71`02XZ:P0O
7al0BDU908J6QP1WIfL0Hf=S0;Rh^00a<C40?Cdm05IFEP1JFUX0=cLg03dm?@1QHF40Lg=c05iNGP15
ADD0BDU905iNGP1bLW80>CTi03dm?@1ZJVX0EeMG04Q8B01[Jf/0OWin06i^KP1XJ6P0Hf=S04U9B@0c
<c<0Cdm?04a<C080@T9200d0CDe=051@D01:BTX0DE5A059BDP1@D500Hf=S04A4A00l?3`0Fe]K06=S
H`1LG5`0DU9B0080H61P00T0GUiN04Y:BP1CDe<0D51@03Hf=P1CDe<0B4Q804e=C@18B4P00P0b<S80
400m?Cd0EeMG03Xj>P16ATH0>c/k03dm?@11@D40>CTi04];B`14A4@0J6QX05MGE`0m?Cd0>CTi04=3
@`1bLW8204];B`0F04e=C@1MGEd0GUiN09FEU@1`L700<S8b03dm?@1HF5P0RXZ:08B4Q01@D500B4Q8
04];B`1<C4`0@T9204m?C`1HF5P0BTY:065QH@1YJFT0Hf=S0451@@80DU9B07D0>3Ph05QHF019BDT0
CTi>01`L701BDU80@T9206ATI01<C4`0MGEe04E5A@1PH6007AdM05=CD`1FEUH0?3`l075aL@0h>3P0
E5AD05aLG00m?Cd0Fe]K04U9B@1iNGT0EEEE0:^[Z`1]KFd0GemO06IVIP10@400EUIF05UIF@1hN7P0
>3Ph04];B`1/K6`0<c<c04A4A018B4P0Cdm?055AD@0b<S80CDe=06ATI01RHV80CDe=06YZJP1IFET0
c/k>06ATI01OGel0>SXj05IFEP2`/;00OGem071`L02IVIT0Ng]k06][J`1iNGT0Cdm?051@D013@d<0
EUIF05MGE`0_;bl0?Shn04];B`2TY:@0Hf=S0;Vi^@0m?Cd0P820034a<@1lO7`0C4a<07AdM02PX:00
`<3005EEE@2?Shl0G5aL034a<@2j^[X0[Jf]03Xj>P22PX80>CTi04m?C`0n?Sh0IFEU05]KF`0c<c<0
E5AD05EEE@1BDU80IFEU03lo?`20P800];Bd05IFEP1bLW80Hf=S05]KF`1EEED0=cLg05IFEP13@d<0
S8b<0820P028R8P0OWin06][J`26QXH0HF5Q038b<P28R8P00P1:BTX0J@28R8P0B4Q806EUI@29RHT0
Bd];04m?C`10@400LW9b03lo?`1GEeL0IVIV0451@@1LG5`0=CDe08:2PP20P800CDe=06ATI017AdL0
>3Ph04U9B@1:BTX0=SHf03hn?P1JFUX0;bl_06UYJ@0X:2P0D51@04Y:BP1TI6@0?Cdm04E5A@1SHf<0
@41005]KF`0k>c/0?Cdm06EUI@0h>3P0NWYj03hn?P0m?Cd0CDe=04U9B@2?Shl0De=C04M7A`0l?3`0
B4Q804I6AP0j>SX0>CTi05mOG`19BDT0EeMG03Ph>01jNWX0C4a<03dm?@19BDT08B4Q06=SH`1VIVH0
?clo04a<C023Ph<0?clo05mOG`0Y:BT0Jf][04];B`1EEED0De=C06i^KP1SHf<0FUYJ075aL@0d=3@0
IFEU06m_K`1^KVh0OGem020P801>CTh0AdM701lO7`1DE5@0:b/[0451@@1;Bd/08b<S05EEE@0M7Ad0
A4A403lo?`1OGel0MGEe05EEE@17AdL0FUYJ051@D01ADE40JFUY05iNGP02ooooo`000P2@T900``1D
E5@0JFUY09JFUP12@T80FUYJ04A4A017AdL0Ogmo079bLP0b<S80A4A403Ph>01FEUH0RHV907alO00S
8b<0@4100492@P19BDT0Kfm_0:j^[P0n?Sh0;Bd]05IFEP1<C4`0A4A40820P01`L7009BDU03De=@1U
IFD0GemO05=CD`2LW9`0QhN701<C4`16ATH0JFUY05eMG@1GEeL0Vi^K04i>CP0O7al0?Shn03Ti>@1L
G5`0@41007QhN00J6QX0:RXZ04I6AP1?Cdl0Bd];05=CD`1`L7005ADE04=3@`2<S8`0Kfm_03hn?P1V
IVH0=SHf02`/;011@D40WinO05aLG01<C4`0GUiN028R8P0b<S80E5AD05eMG@0R8R80>3Ph04I6AP0T
92@0BDU907emO@13@d<0>SXj04];B`0h>3P0>SXj04];B`1mOGd0>3Ph03dm?@1iNGT0D51@05aLG01n
OWh0AdM702TY:@1HF5P0?3`l03Ph>025QHD0/;2`02`/;00P8200ATI605iNGP1;Bd/0RHV907emO@0M
7Ad0:2PX05aLG026QXH0GUiN08B4Q00N7Qh06ATI030`<01YJFT0H61P0861P@2KVi/06a/K03@d=01;
Bd/0OWin061PH02KVi/0^k^k02LW9`1?Cdl0JVYZ06ATI018B4P0SXj>06MWI`0];Bd0AdM706e]K@1J
FUX0>CTi07EeM@0j>SX08b<S04U9B@2YZJT0MGEe038b<P1:BTX0>CTi03`l?01SHf<0T92@05ADE010
@400BTY:02DU9@13@d<0SXj>08n?S`0[:b/0@T92030`<00n?Sh0NWYj04e=C@0/;2`0Bd];04U9B@13
@d<0MGEe08^;R`0Z:RX0=cLg04M7A`1BDU80Jf][0820P01bLW808b<S03lo?`1KFe/0HF5Q05mOG`2N
WYh0YjNW01dM7@0j>SX0F5QH069RHP1ZJVX0d=3@04m?C`1:BTX0Fe]K07emO@1nOWh0WinO0861P@02
04=3@`3T08:2PP2[Zj/0GemO08B4Q01>CTh0820P04a<C02EUID0JVYZ092@T02PX:00A4A402/[:`1`
L700PX:204m?C`2LW9`0@d=302HV9P0/;2`0S8b<0:ZZZP1[Jf/0MgMg02h^;P0Z:RX0IVIV0;fm_@1/
K6`0[Zj^03lo?`0^;Rh0XZ:R0;Ng]`1:BTX0Lg=c03lo?`0X:2P0FUYJ07EeM@0];Bd0HV9R04Q8B00f
=SH0CDe=07QhN00o?cl0De=C07EeM@12@T80QHF509ZJVP1@D500>CTi059BDP1HF5P0DU9B09RHV02D
U9@0:b/[04I6AP1RHV80EeMG05aLG02ZZZX0R8R803Ph>018B4P0HV9R06a/K029RHT0/;2`04M7A`0a
<C40D51@09>CT`1NGUh0TI6A0=SHf022PX80?clo05IFEP2KVi/0HF5Q07EeM@2`/;00>SXj038b<P1`
L700UIFE05eMG@2>SXh0NWYj034a<@16ATH0G5aL09BDU018B4P0E5AD09FEU@0f=SH0;Bd]07AdM02B
TY80@41003Ti>@20P800C4a<02@T901WIfL0N7Qh05QHF018B4P0J6QX03<c<`0O7al0GUiN08>3P`1^
KVh0?Shn04e=C@24Q8@0AdM704e=C@1VIVH0@d=305mOG`1@D500Cdm?055AD@1;Bd/0@d=30451@@2:
RXX0MgMg06=SH`1]KFd0LG5a09:BTP1YJFT0@D5104m?C`19BDT0?Shn04e=C@1ADE40Bd];071`L01e
MGD0Bd];03`l?01<C4`0BDU906][J`18B4P0D51@05QHF01DE5@0H61P05YJFP1UIFD0AdM7061PH01:
BTX0BDU903dm?@16ATH0E5AD03hn?P0k>c/0ADE504a<C00`<300<C4a04=3@`0a<C40D51@0492@P0o
?cl0ATI602l_;`11@D40GEeM075aL@1VIVH0=CDe04M7A`0h>3P0H61P05YJFP1RHV80I6AT07UiN@1[
Jf/0YJFU09BDU01OGel0NGUi075aL@1=CDd0HF5Q06ATI019BDT0G5aL04A4A00k>c/0CDe=06i^KP1M
GEd0LW9b03dm?@1GEeL0Bd];04i>CP13@d<0Cdm?06YZJP11@D40>3Ph02/[:`1RHV80F5QH05EEE@1V
IVH0Ph>304E5A@0n?Sh0>c/k0P1DE5@0900n?Sh0E5AD04I6AP1ADE40AdM704I6AP1ADE40Bd];055A
D@1=CDd0[jn_06IVIP18B4P0H61P03`l?01RHV80CDe=05IFEP18B4P0C4a<05eMG@1;Bd/0Kfm_05YJ
FP1CDe<0E5AD03hn?P12@T80M7Ad06UYJ@1MGEd0PX:202/[:`2g]kL0A4A4061PH080@D5102l0Ti>C
03Lg=`1dM7@0]KFe06m_K`1SHf<0CTi>06ATI01XJ6P0<S8b05YJFP16ATH0=SHf04M7A`0g=cL0DE5A
05mOG`2BTY80>SXj09JFUP0n?Sh0N7Qh03De=@2<S8`0a/K60820P01SHf<0/K6a05iNGP0_;bl0/K6a
07YjNP18B4P0Y:BT03Ph>01lO7`0>SXj071`L01UIFD0AdM706a/K015ADD0DU9B069RHP10@400KFe]
08^;R`0204i>CP1j059BDP1IFET0DE5A05IFEP1WIfL0Bd];08Z:RP15ADD0R8R809JFUP1ADE40Bd];
03lo?`0Q8B40I6AT03dm?@1DE5@0Zj^[04m?C`1TI6@0MgMg04I6AP1PH6007AdM04=3@`0Z:RX0JFUY
069RHP1YJFT0M7Ad02XZ:P22PX80K6a/059BDP1fMWH0:b/[02@T901?Cdl0>CTi030`<01=CDd0DU9B
04U9B@16ATH0@D5105=CD`19BDT0DU9B03Lg=`0m?Cd0CTi>04m?C`1/K6`0C4a<04i>CP1MGEd0@T92
08J6QP0`<300FUYJ06UYJ@1=CDd0UIFE02TY:@0n?Sh07alO051@D01KFe/0AdM70451@@1VIVH0AdM7
05EEE@1<C4`0Q8B404Q8B01YJFT0EEEE04];B`1JFUX0IFEU01lO7`11@D40UiNG02`/;01:BTX0=3@d
051@D00e=CD0E5AD02`/;01oOgl0GUiN04a<C01;Bd/0:BTY06m_K`1YJFT0Jf][07]kN`0d=3@0De=C
03`l?00`<300KVi^01`L7019BDT0ADE5034a<@1SHf<0?3`l05QHF01JFUX0K6a/07AdM00o?cl0@410
06ATI01IFET0C4a<0820P023Ph<2ooooo`000400WYjN0:f][@1@D500EeMG08j>SP1XJ6P0UYJF04e=
C@10@400KFe]09nOW`1_Kfl0Ph>304M7A`0Y:BT0PX:20<;2`P1XJ6P0NWYj04A4A00];Bd0ADE508f=
S@1iNGT0Cdm?05mOG`0b<S808B4Q05QHF02DU9@0KFe]04];B`1jNWX092@T03<c<`1JFUX0OGem059B
DP1MGEd0EeMG02h^;P11@D40F5QH07EeM@0[:b/0>3Ph04Y:BP0f=SH0EUIF08j>SP1QHF407alO04Y:
BP16ATH0A4A406IVIP2][Jd0ADE501dM7@1<C4`0DU9B06i^KP2EUID0;Rh^0P0a<C40E@1aLG40ATI6
07AdM02>SXh05ADE03lo?`1IFET0IfMW03/k>`1[Jf/0EEEE01/K6`0a<C40CTi>04e=C@1YJFT0[Jf]
04E5A@0M7Ad0@d=305iNGP1IFET0Ph>30<;2`P1KFe/05ADE05IFEP24Q8@0>c/k096AT@1UIFD08b<S
04E5A@1YJFT0K6a/04U9B@1TI6@06a/K02PX:01IFET0LW9b05IFEP1IFET0ATI601lO7`10@400IVIV
06a/K00`<300IfMW02/[:`0G5aL0<C4a05]KF`1GEeL0:2PX05]KF`0U9BD08R8R030`<022PX80?3`l
02/[:`17AdL0=SHf04E5A@1:BTX0IVIV028R8P0o?cl0Q8B404M7A`1:BTX0Z:RX06i^KP0U9BD0:BTY
065QH@1`L700J6QX07UiN@0/;2`092@T04E5A@23Ph<00P21PH40Z02PX:00<c<c02LW9`1VIVH0TI6A
04U9B@1kNg/0<30`03/k>`1/K6`0S8b<07QhN02n_[h0=cLg03/k>`1MGEd0N7Qh06IVIP1lO7`0/k>c
03lo?`0/;2`0F5QH08f=S@1:BTX0F5QH0:BTY011@D40<C4a04i>CP1`L700BTY:06UYJ@1>CTh09BDU
051@D01ZJVX0N7Qh03/k>`1_Kfl0;Bd]034a<@1OGel0PH6105QHF00i>CT0O7al03/k>`16ATH0Lg=c
08^;R`0n?Sh0CTi>04M7A`0Z:RX0GEeM07moO`17AdL0?Cdm05MGE`13@d<0EeMG079bLP1_Kfl07alO
03Lg=`1MGEd0F5QH05]KF`2ATI40<30`02LW9`0o?cl0Lg=c069RHP35aLD0HF5Q02DU9@15ADD0SHf=
06i^KP2PX:00CDe=02d];@1BDU80IfMW04A4A02OWil0Rh^;01TI6@1?Cdl0WYjN04e=C@1NGUh0UIFE
01hN7P0T92@0Cdm?0820P01QHF40V9RH05UIF@0X:2P0FEUI09:BTP1@D500J6QX09>CT`0h>3P0;Bd]
04e=C@1mOGd0G5aL09RHV02QXJ408B4Q04Y:BP25QHD0Hf=S0410@01OGel0ADE503Hf=P18B4P0Kfm_
08f=S@1;Bd/0L71`05iNGP0`<300?clo05]KF`1FEUH0@D5104];B`10@400;Rh^075aL@2;Rh/0@d=3
02h^;P1MGEd0DE5A04=3@`1RHV80XZ:R07YjNP0Z:RX0CTi>06i^KP1QHF40GEeM092@T018B4P0:BTY
03Ph>01?Cdl0Ng]k07MgM`2l_;`0EEEE01PH600^;Rh0JFUY05eMG@1/K6`0D51@08R8R080C4a<09H0
KVi^055AD@1gMgL0KVi^06][J`1TI6@0DU9B04=3@`17AdL0QhN7075aL@1SHf<0NGUi07YjNP2XZ:P0
Lg=c04a<C01HF5P0=cLg04Y:BP1>CTh0De=C04Q8B01CDe<0EeMG04];B`0n?Sh0FUYJ04U9B@1NGUh0
BTY:05QHF01lO7`0J6QX06ATI01>CTh0GEeM059BDP1PH600Bd];04m?C`1LG5`0ATI606ATI013@d<0
De=C06QXJ01:BTX0EeMG04Y:BP1RHV80?Shn06IVIP0f=SH0?Shn04Q8B00`<300?clo0451@@1CDe<0
Bd];01`L700o?cl09BDU05mOG`1EEED0Cdm?05eMG@1KFe/0HF5Q0<;2`P1`L700<c<c03dm?@1JFUX0
G5aL05]KF`1OGel0GUiN07]kN`1CDe<0B4Q8055AD@1JFUX0AdM705eMG@1EEED0N7Qh04I6AP1>CTh0
B4Q80492@P1DE5@0@41004I6AP0Y:BT0ATI603Xj>P1;Bd/0@d=305ADE00b<S80@d=303De=@1RHV80
Hf=S03Lg=`1OGel0@D5104M7A`1HF5P0@41006EUI@11@D40H61P065QH@24Q8@0GUiN05=CD`1^KVh0
DE5A06EUI@1EEED0G5aL071`L020P800Ph>3055AD@0e=CD0@T9204I6AP1IFET0FUYJ06IVIP1IFET0
J6QX07IfMP2BTY80ADE50;Bd]01PH600WYjN04E5A@1EEED0Xj>S03Xj>P1?Cdl0NGUi04A4A01`L702
04M7A`2C0410@00a<C40IVIV04e=C@10@400E5AD03`l?01JFUX0EeMG09:BTP0S8b<0AdM702XZ:P1X
J6P0>3Ph06UYJ@1WIfL0FUYJ04Y:BP1UIFD0EUIF0492@P2l_;`0MgMg04I6AP1WIfL0>CTi04U9B@0`
<300PH6107IfMP0n?Sh0CDe=0492@P19BDT0CDe=02`/;01dM7@0P82004i>CP1`L700>c/k04e=C@1<
C4`0?3`l05]KF`18B4P0JVYZ05]KF`24Q8@0SXj>04M7A`1?Cdl0EeMG0451@@1bLW80>SXj05ADE026
QXH0EEEE07moO`22PX80B4Q805ADE016ATH0LW9b02d];@1ZJVX0L71`04E5A@1FEUH0@D5108V9R@1j
NWX0>SXj03hn?P0R8R807QhN04i>CP12@T80ADE50451@@1HF5P0:RXZ06i^KP0P8200AdM703`l?01T
I6@0<C4a03Lg=`1KFe/0?Cdm05ADE00];Bd0@D5106a/K00o?cl0S8b<03Ti>@1:BTX0D51@02l_;`1K
Fe/0<S8b03Lg=`0P8200AdM703Ti>@15ADD0=cLg055AD@14A4@0J6QX04];B`24Q8@0A4A404E5A@19
BDT0;Bd]04a<C01EEED09RHV03Ti>@1TI6@0<30`03Ti>@0V9RH0I6AT04E5A@1nOWh0?Cdm0:FUY@1X
J6P0EeMG05QHF00d=3@0OWin05eMG@1FEUH0IfMW03/k>`1QHF40@d=302PX:01ADE40:RXZ0080FUYJ
00X0?clo051@D00I6AT0?3`l03Hf=P27QhL0PH6103Xj>P1=CDd0Ogmo0P1?Cdl00`1_Kfl0Cdm?oooo
o`01ooooo`0002P0DU9B0;:b/P1kNg/0KVi^059BDP19BDT0MGEe08J6QP0n?Sh0Lg=c03hn?P1=CDd0
Lg=c05MGE`0Y:BT0Cdm?07EeM@1FEUH0KFe]05YJFP0O7al08R8R03Xj>P15ADD0C4a<07=cL`0`<300
4a<C020P801OGel0Fe]K06a/K02@T9006a/K01TI6@0m?Cd0JVYZ055AD@2a/K40UiNG0P0Y:BT0o`0f
=SH0MgMg04=3@`2IVIT0NGUi01TI6@0/;2`0?Cdm075aL@1?Cdl0[Jf]05ADE00N7Qh0;Bd]06UYJ@23
Ph<0B4Q809JFUP0d=3@0:BTY07MgM`2CTi<0?clo05iNGP12@T80:RXZ03hn?P1fMWH0FEUI03Ti>@1O
Gel06a/K024Q8@19BDT0Jf][04M7A`0n?Sh0CDe=01lO7`13@d<0MGEe06UYJ@0V9RH0@D5102l_;`0V
9RH0H61P0:f][@1nOWh0820P051@D00^;Rh0@d=306a/K020P800;2`/02l_;`1?Cdl0@41005EEE@1R
HV808b<S01TI6@13@d<0=cLg0410@01cLg<0Q8B401@D500U9BD0ATI605EEE@18B4P0VYZJ05iNGP0L
71`0=CDe04M7A`1mOGd0EEEE08N7Q`0Y:BT08R8R051@D01FEUH0K6a/08j>SP29RHT0;Bd]03<c<`1>
CTh0L71`04=3@`1HF5P0O7al04I6AP0m?Cd0EUIF0:VYZ@1MGEd0MGEe07]kN`0X:2P0H61P08f=S@28
R8P0ATI605eMG@0e=CD0@T9205EEE@1[Jf/0IfMW0492@P1^KVh07alO02<S8`1GEeL0FEUI04Y:BP1h
N7P0;Bd]03Ti>@20P800PH6103Lg=`1TI6@0De=C03Ph>01@D500YZJV06=SH`0e=CD0D51@03lo?`1=
CDd0Fe]K06][J`1nOWh0:b/[04a<C012@T80ADE50:n_[`2YZJT0:BTY03De=@1jNWX0S8b<05IFEP2g
]kL0MgMg01XJ6P0e=CD0Lg=c08J6QP1KFe/0`L7104];B`0O7al0>SXj08:2PP1EEED0WYjN06a/K00O
7al0:RXZ04Q8B01/K6`0RXZ:0;Zj^P0k>c/0;2`/04a<C02JVYX0EeMG07=cL`1mOGd0<30`04M7A`1a
LG40QXJ6069RHP2EUID0:b/[04Y:BP1<C4`0H61P04];B`26QXH0EUIF03hn?P24Q8@0TI6A04i>CP1[
Jf/0>SXj03Lg=`28R8P0XZ:R0492@P1:BTX0GEeM04E5A@1IFET0XJ6Q05IFEP0b<S80F5QH03De=@19
BDT0NGUi08N7Q`0j>SX0D51@05IFEP1;Bd/0XJ6Q0:BTY00m?Cd0;bl_05=CD`1UIFD0?3`l08^;R`2^
[Zh0@D51038b<P1aLG40MgMg05IFEP2MWId0JFUY020P800l?3`0EEEE06ATI01RHV80UIFE096AT@0O
7al0@T9206=SH`1PH600Hf=S08F5Q@1EEED07QhN04e=C@2GUiL0IfMW05eMG@1iNGT0BDU9028R8P00
7@1ADE40EEEE07MgM`1IFET0WYjN08N7Q`0P8200A4A406=SH`1XJ6P0>3Ph08Z:RP1XJ6P0:b/[04i>
CP1OGel0MWIf03dm?@1YJFT0PX:203Ph>00n?Sh0HV9R07]kN`1<C4`0AdM705IFEP1EEED0IfMW0080
CDe=0200HV9R05YJFP16ATH0ATI605]KF`1UIFD0GemO06i^KP25QHD0NWYj06QXJ01MGEd0Bd];03dm
?@1<C4`0CTi>04=3@`0l?3`0EUIF069RHP1KFe/0G5aL03/k>`1QHF40K6a/04Y:BP0k>c/0DE5A065Q
H@1SHf<0NWYj061PH080CDe=0?l0A4A405aLG01ADE40CDe=05iNGP1<C4`0F5QH05UIF@1>CTh0?Cdm
03lo?`17AdL0>CTi05aLG00b<S80>SXj03Ti>@0^;Rh0@D5103`l?01PH600De=C02PX:019BDT0=cLg
05iNGP1OGel0De=C07AdM01BDU80Lg=c08Z:RP1XJ6P0?Cdm04M7A`1kNg/0GUiN06m_K`1nOWh0C4a<
06=SH`15ADD0>SXj04m?C`1RHV80FEUI05aLG013@d<0GEeM04U9B@1DE5@0CDe=04I6AP1QHF40Bd];
04M7A`0_;bl0CDe=04A4A01<C4`0BDU907AdM016ATH0CTi>03hn?P1GEeL0L71`03/k>`1OGel0@d=3
04Y:BP1LG5`0CDe=06e]K@1:BTX0K6a/06e]K@2VYZH0LG5a069RHP1YJFT0ADE506IVIP1OGel0F5QH
06m_K`1<C4`0FUYJ03@d=011@D40D51@05aLG01>CTh0=SHf0451@@1dM7@0I6AT05EEE@1ZJVX0SHf=
0=OGe`1;Bd/0HV9R04=3@`1EEED0TI6A04I6AP1iNGT0YZJV05UIF@1DE5@0DU9B05MGE`0i>CT092@T
04E5A@14A4@0Hf=S04e=C@1QHF40NGUi06QXJ02DU9@0A4A406][J`0n?Sh0KVi^02/[:`1MGEd0EeMG
06YZJP1?Cdl0QXJ605ADE011@D40b<S807]kN`0j>SX0NWYj03lo?`1OGel0<S8b05=CD`1BDU80?3`l
08B4Q01:BTX0B4Q805=CD`0c<c<0Rh^;0861P@0_;bl0EEEE0410@019BDT0ATI603lo?`1YJFT0<C4a
069RHP19BDT0Ti>C07emO@1NGUh0IFEU05=CD`18B4P0Ti>C05YJFP1>CTh0MgMg04i>CP24Q8@0LW9b
0492@P19BDT0;Rh^04M7A`0b<S80EEEE04Y:BP1^KVh0IFEU04Q8B02BTY80Kfm_04E5A@19BDT0ATI6
03De=@1OGel0BTY:03`l?01>CTh0CDe=03Ph>018B4P0<C4a04m?C`10@400De=C03@d=00c<c<0DU9B
04i>CP1KFe/0@41005aLG01^KVh0=cLg069RHP0Z:RX0D51@05=CD`0f=SH0J6QX01dM7@15ADD0;bl_
0410@00l?3`0@T9202@T901=CDd0<C4a04a<C00b<S80DU9B02/[:`1OGel0De=C02LW9`1SHf<0GEeM
024Q8@0j>SX0UIFE02h^;P17AdL0<C4a04I6AP0];Bd0C4a<03dm?@1?Cdl0GEeM06EUI@1CDe<0=cLg
06=SH`11@D40HF5Q069RHP0T92@001D0C4a<04E5A@12@T80NGUi02HV9P0g=cL0?Cdm04=3@`1aLG40
<C4a04I6AP10@400F5QH05UIF@18B4P0IFEU07moO`1EEED0D51@06YZJP1PH6000_ooool0003o05EE
E@1mOGd0O7al09nOW`1UIFD0?Cdm05MGE`2ZZZX0GemO0:>SX`0^;Rh0<30`06][J`2CTi<0@T9209fM
W@1<C4`0;Rh^03`l?01]KFd0DU9B07IfMP26QXH09BDU02TY:@1HF5P0[Zj^05]KF`1[Jf/0=CDe038b
<P1CDe<0LW9b06QXJ014A4@0OWin038b<P0V9RH0BTY:08R8R01SHf<0=cLg05eMG@0V9RH071`L055A
D@1WIfL0>3Ph03Xj>P1RHV806a/K03Xj>P1aLG40MgMg02XZ:P0f=SH0@D5102PX:01RHV80Ti>C04Q8
B00Y:BT0?clo03Xj>P1JFUX0HV9R04];B`0S8b<0=CDe05UIF@1VIVH0GemO08^;R`0P82004a<C04U9
B@1gMgL0F5QH07alO028R8P05QHF02DU9@1dM7@0RXZ:051@D02RXZ80HF5Q02HV9P0];Bd0IFEU08V9
R@19BDT0alO704=3@`0P8200<c<c05mOG`1EEED0NGUi08V9R@0B4Q80>c/k05=CD`1JFUX0=SHf0:b/
[00m?Cd0:BTY02DU9@1IFET0Fe]K05EEE@1eMGD06QXJ02LW9`1LG5`0QHF504E5A@16ATH0DU9B020P
801:BTX0Kfm_07QhN00m?Cd0K6a/04Y:BP0K6a/0E5AD0:b/[017AdL0820P05MGE`11@D40>c/k04E5
A@20P800>SXj02/[:`0k>c/0>3Ph04=3@`1=CDd0RHV902PX:00a<C40DE5A04U9B@1^KVh0QhN705IF
EP0N7Qh0?Cdm06=SH`1RHV80K6a/0:n_[`1@D50071`L059BDP1^KVh0N7Qh0<G5a@0_;bl0ADE505IF
EP1ZJVX0H61P07moO`1jNWX092@T05UIF@2DU9@0P82006ATI027QhL0PH6101LG5`0k>c/0BDU9061P
H01NGUh0VYZJ08B4Q00P8200Bd];07MgM`1EEED0H61P06UYJ@0e=CD0?Cdm04Y:BP2MWId0G5aL065Q
H@1<C4`09BDU055AD@1iNGT0T92@03lo?`1LG5`0;Rh^03Xj>P1?Cdl0I6AT04I6AP1VIVH0FEUI01lO
7`1MGEd0Rh^;055AD@0g=cL0D51@02l_;`0m?Cd0GemO08>3P`0g=cL0Hf=S06QXJ00i>CT0Hf=S092@
T01CDe<0=SHf05YJFP1EEED0MgMg0:VYZ@1lO7`08b<S04e=C@1:BTX0HV9R0<[:bP1FEUH0<c<c04E5
A@26QXH0DE5A092@T02OWil0<C4a0410@01`L700IFEU0861P@2b/[80ATI603`l?01DE5@0J6QX003o
06a/K037alL0U9BD020P801<C4`0Ph>306][J`1WIfL0[:b/07moO`0l?3`0A4A406MWI`1EEED0KVi^
09NGU`0l?3`0C4a<05IFEP1oOgl0ATI605YJFP1WIfL0?Shn04I6AP1]KFd0YZJV04m?C`1BDU80BTY:
03Xj>P18B4P0UiNG07alO00V9RH0?clo0492@P0n?Sh0Bd];07emO@1bLW80;Bd]02HV9P1BDU80?clo
02d];@2BTY80^KVi030`<00Y:BT0KFe]05ADE00h>3P0QXJ60:NWY`0c<c<0:BTY051@D01ADE40F5QH
09^KV`2OWil0Cdm?02/[:`1ZJVX0K6a/04Q8B019BDT0Bd];03Xj>P1BDU80ADE503Ti>@0h>3P0?Shn
0492@P14A4@0Kfm_06=SH`1KFe/0Ogmo09bLW02JVYX0F5QH03dm?@1HF5P0BDU902h^;P0g=cL0@D51
04A4A015ADD0@41004Y:BP15ADD0G5aL03hn?P1QHF40H61P07alO01TI6@0G5aL05MGE`1ADE40EeMG
055AD@18B4P0Bd];04E5A@19BDT0CDe=04a<C011@D40=cLg03Hf=P0_;bl09bLW051@D017AdL0:RXZ
04Q8B00f=SH0BDU903De=@0Z:RX0>CTi03/k>`1<C4`0>3Ph03dm?@1]KFd0;bl_05mOG`1EEED0?clo
069RHP1UIFD0UYJF09FEU@1gMgL0C4a<05IFEP1`L700EeMG069RHP1VIVH0Jf][07MgM`0i>CT0@410
04];B`17AdL0CTi>04];B`0];Bd0DE5A04i>CP0k>c/0B4Q804M7A`1PH600?clo04M7A`0W9bL0D51@
03hn?P16ATH0>c/k06ATI00j>SX0@d=302`/;01/K6`0J6QX04A4A01ADE40Cdm?05]KF`1GEeL0?Shn
06MWI`1:BTX0J6QX051@D02OWil0Jf][05IFEP1JFUX0CDe=06MWI`1;Bd/0GemO03lo?`1FEUH0MWIf
04U9B@17AdL0GemO04m?C`1]KFd0B4Q8079bLP1NGUh0C4a<06e]K@2CTi<0EeMG0;Fe]@15ADD0KFe]
04a<C013@d<0PH6102<S8`1LG5`0Rh^;07MgM`1jNWX0OWin07MgM`1YJFT0DE5A07YjNP1=CDd0>3Ph
05iNGP1YJFT0Lg=c07moO`2WYjL0?clo079bLP1<C4`0QhN703Lg=`1[Jf/0P82007MgM`1PH600TY:B
04U9B@0o?cl0`<3006UYJ@17AdL0W9bL03@d=01ZJVX08R8R06=SH`1<C4`0=cLg05EEE@15ADD0KVi^
000J071`L00O7al0Bd];051@D00e=CD0F5QH04E5A@1DE5@0BDU90410@01<C4`0?Shn05MGE`0f=SH0
Rh^;07emO@0g=cL0BTY:03hn?P0L71`0UIFE03lo?`1dM7@0Rh^;04Q8B02?Shl206ATI01T07EeM@0U
9BD0Cdm?01DE5@1oOgl0GEeM04];B`1/K6`09BDU06YZJP1SHf<0D51@06QXJ00Y:BT0?Shn04M7A`0i
>CT0BTY:05ADE01WIfL0=SHf065QH@0d=3@0GUiN0410@01>CTh0<S8b030`<01GEeL0KFe]096AT@0i
>CT0DE5A065QH@10@400L71`03Lg=`19BDT0F5QH0451@@2CTi<0>3Ph04Y:BP0Q8B40BDU9030`<019
BDT0=SHf04E5A@0_;bl0BTY:0492@P26QXH0=3@d0492@P0`<3006ATI04];B`16ATH0:b/[05YJFP2>
SXh0>3Ph05]KF`0b<S80EeMG05QHF01OGel0A4A406a/K01TI6@0GemO06MWI`18B4P0H61P059BDP1n
OWh0S8b<04=3@`1;Bd/0GemO03hn?P1>CTh0;Rh^04U9B@1CDe<0?Cdm05]KF`11@D40GUiN05]KF`1i
NGT0Q8B406=SH`1;Bd/0Jf][04];B`15ADD0LG5a06ATI0;ooooo00002`1fMWH0Lg=c04m?C`1WIfL0
LW9b04I6AP1NGUh0@D5104I6AP1VIVH0LG5a0080@T9201L0=CDe030`<01_Kfl0Ti>C03Hf=P1FEUH0
=CDe02LW9`0g=cL0K6a/04M7A`0L71`0AdM702HV9P1FEUH0LG5a06EUI@0];Bd0>SXj04=3@`0e=CD0
HF5Q0::RXP0202TY:@0W034a<@1MGEd0KFe]06UYJ@2a/K40820P018B4P13@d<0NGUi06m_K`1gMgL0
PH6102TY:@0H61P0FUYJ08B4Q01CDe<0SHf=07inOP0X:2P0:BTY06=SH`1VIVH0Hf=S08b<S00Q8B40
;Rh^04A4A01QHF40<S8b059BDP1[Jf/06a/K04i>CP1VIVH0O7al04M7A`1fMWH0AdM70080>3Ph07l0
N7Qh05YJFP1DE5@0Q8B403/k>`15ADD0B4Q807QhN00e=CD0CDe=07QhN00Z:RX0;Bd]07IfMP1gMgL0
;Bd]059BDP0^;Rh0=CDe05=CD`1eMGD0@d=302LW9`19BDT0:2PX04a<C02TY:@0X:2P02/[:`0^;Rh0
B4Q8034a<@1fMWH0]KFe03`l?00K6a/0<c<c05YJFP0f=SH0PH6106UYJ@0U9BD0@T9204];B`1GEeL0
B4Q80;>c/`1XJ6P08b<S02HV9P1GEeL0MgMg05mOG`2MWId0@T9202DU9@1NGUh0KVi^05MGE`1RHV80
Xj>S05aLG00E5AD0@T9209ZJVP1/K6`0D51@08R8R00a<C40<30`05MGE`2;Rh/0GemO05eMG@1^KVh0
5QHF05QHF02EUID0Xj>S04i>CP1GEeL0>CTi05aLG020P800HV9R04E5A@1mOGd0=SHf02TY:@27QhL0
Ph>304E5A@0l?3`0Jf][034a<@0i>CT0R8R80:2PX019BDT0=3@d06YZJP0a<C40B4Q808B4Q02?Shl0
<c<c03dm?@1KFe/0>CTi06e]K@2KVi/0Jf][02d];@1QHF40Bd];069RHP1jNWX0OGem01lO7`1IFET0
V9RH07QhN01/K6`0RHV904e=C@0Q8B40LG5a0080I6AT02D0VIVI0:2PX00L71`07AdM07YjNP1TI6@0
HF5Q09>CT`11@D409BDU05EEE@2<S8`0IFEU09ZJVP2BTY80:b/[05]KF`26QXH0P820051@D01KFe/0
7QhN02XZ:P24Q8@0/K6a04e=C@26QXH0>SXj02LW9`1mOGd0Zj^[0451@@1JFUX0=SHf03@d=019BDT0
Shn?0080De=C09H0IVIV02h^;P16ATH0Ph>307IfMP1:BTX0TY:B0451@@0d=3@0J6QX0;jn_P1gMgL0
@41005UIF@0h>3P0>CTi07EeM@2FUYH0De=C05MGE`1KFe/0G5aL06EUI@2JVYX0B4Q802h^;P1?Cdl0
G5aL05mOG`1dM7@0Ng]k03/k>`0g=cL0@T9206][J`1PH600O7al06EUI@0[:b/0;2`/06YZJP2BTY80
EUIF079bLP1^KVh06a/K02h^;P1jNWX0Ph>306=SH`1eMGD0Q8B4034a<@0[:b/0DE5A09NGU`1hN7P0
EeMG08J6QP1@D500;2`/034a<@1oOgl0G5aL05mOG`1`L700>3Ph01hN7P10@400GemO06=SH`1PH600
G5aL065QH@1lO7`0MGEe069RHP1<C4`0JFUY06EUI@1OGel0FUYJ04i>CP1`L700LW9b07emO@1[Jf/0
IfMW09VIV@2RXZ80QhN7061PH01=CDd0DE5A0451@@10@400AdM705=CD`1KFe/0Hf=S065QH@24Q8@0
QHF506e]K@1EEED0CTi>03Ti>@1BDU80MgMg079bLP1mOGd0HV9R07EeM@1ADE40IfMW04i>CP1:BTX0
FUYJ04m?C`1CDe<0?clo055AD@1MGEd0@d=303Lg=`0i>CT0CTi>03<c<`1>CTh0;Rh^034a<@11@D40
DE5A065QH@1:BTX0EUIF04];B`0_;bl0D51@03<c<`1DE5@0EUIF04E5A@1RHV80EEEE07EeM@2GUiL0
G5aL02PX:00g=cL205=CD`3906YZJP1EEED0<C4a04e=C@0h>3P0@d=3051@D01CDe<0>3Ph04U9B@0f
=SH0F5QH03Lg=`0i>CT0@T9203<c<`13@d<0@41003Ti>@0H61P0:b/[02LW9`11@D407alO03Hf=P0^
;Rh0@D51024Q8@0`<300;bl_03Xj>P10@400<C4a0451@@1=CDd0?Cdm04e=C@0g=cL0FEUI04a<C01h
N7P0C4a<05EEE@1MGEd0CDe=04m?C`1CDe<0L71`04e=C@1QHF40KFe]0410@01CDe<0C4a<059BDP1Q
HF40CTi>04E5A@1RHV80LW9b09nOW`2m_Kd0Z:RX0=OGe`1EEED0QhN706][J`1FEUH0Ti>C05]KF`20
P800U9BD03lo?`1IFET0ATI6079bLP1_Kfl0CDe=05ADE01XJ6P0ADE504e=C@21PH40P82007emO@2K
Vi/0KVi^07EeM@1FEUH0KVi^04I6AP21PH40VYZJ09JFUP1XJ6P0Q8B406=SH`1PH600];Bd06a/K00l
?3`0H61P03/k>`1JFUX0=3@d071`L01FEUH0?3`l05iNGP1EEED0D51@04Y:BP0j>SX0PH6107AdM019
BDT0G5aL04i>CP16ATH0C4a<04A4A01JFUX0GemO0820P01OGel0MWIf06IVIP12@T80EUIF04m?C`13
@d<0P82004m?C`1cLg<0W9bL05EEE@30`<00Q8B40492@P16ATH0>CTi07MgM`0H61P0De=C03Xj>P1A
DE40EUIF03lo?`2HV9P0G5aL03Ti>@12@T80>3Ph03<c<`1YJFT0ADE503/k>`12@T80G5aL03Ti>@1K
Fe/0:BTY04I6AP13@d<0BDU902XZ:P0X:2P0DU9B03hn?P1=CDd0<30`04i>CP1VIVH0E5AD0:NWY`11
@D40C4a<04U9B@0b<S80BTY:02<S8`14A4@08R8R05ADE00^;Rh0?clo034a<@1=CDd0@d=305UIF@13
@d<0DE5A03lo?`0m?Cd0A4A404];B`2:RXX0OWin03@d=01BDU80HF5Q0080C4a<02@0A4A405MGE`0Y
:BT0GUiN05YJFP22PX80OGem05=CD`1/K6`0DU9B06YZJP0/;2`0EeMG08^;R`17AdL0F5QH04];B`0m
?Cd0DE5A03Lg=`1=CDd0E5AD05eMG@1VIVH0>c/k04Q8B014A4@0M7Ad05EEE@15ADD0@D5106IVIP15
ADD0D51@08J6QP1KFe/2ooooo`000<D0NWYj09RHV01GEeL0FUYJ06][J`1OGel0/k>c065QH@10@400
K6a/05QHF020P800_[jn061PH00`<300@41007AdM01kNg/0Vi^K09JFUP0O7al0ADE506i^KP20P800
@D5107MgM`0Y:BT09BDU05eMG@2`/;00B4Q807IfMP1/K6`08b<S04i>CP19BDT0De=C03De=@1NGUh0
BTY:02LW9`1MGEd0NGUi06e]K@0g=cL0GemO055AD@0V9RH0GUiN09fMW@1IFET0<30`05YJFP0l?3`0
;2`/07YjNP2f][H0=SHf02@T901ADE406QXJ03De=@2CTi<0KFe]02LW9`1PH600B4Q803hn?P1kNg/0
YJFU034a<@10@400?Shn034a<@19BDT0^KVi07emO@0U9BD0CDe=0820P01]KFd0Kfm_0;6a/@1>CTh0
7alO05MGE`1@D500DU9B0:JVYP3QhN40BDU901XJ6P1[Jf/0K6a/04E5A@2n_[h0O7al01XJ6P0j>SX0
Rh^;06EUI@1`L700PH6103Ti>@0R8R80Fe]K0;Vi^@2>SXh0RXZ:08R8R00_;bl0=3@d06i^KP20P800
GEeM08^;R`0m?Cd0;Bd]03Ti>@1XJ6P0@T9205EEE@21PH4092@T0410@01BDU80QHF503@d=013@d<0
F5QH02/[:`0n?Sh0Jf][08R8R00M7Ad0=CDe05IFEP0l?3`0;2`/0861P@2UYJD0;2`/034a<@1JFUX0
B4Q80451@@1gMgL0G5aL01PH6017AdL0EEEE03Hf=P1iNGT0]KFe055AD@0M7Ad0>c/k05MGE`13@d<0
T92@01dM7@1CDe<0HF5Q05ADE01YJFT0dM7A065QH@0J6QX0EUIF08N7Q`14A4@0SHf=0;Rh^017AdL0
:RXZ051@D02<S8`0GUiN07alO02k^k/0ATI602<S8`1BDU80R8R806UYJ@2UYJD0^k^k03Lg=`0k>c/0
G5aL09BDU01SHf<0^;Rh05aLG011@D40IFEU06=SH`0205=CD`170:n_[`0`<300?3`l07inOP1jNWX0
8B4Q05MGE`0_;bl071`L05IFEP2ZZZX0JVYZ05EEE@1MGEd0;Rh^05mOG`1nOWh0PH6102/[:`13@d<0
F5QH051@D02NWYh0Ti>C03Lg=`11@D40De=C059BDP1TI6@0U9BD04i>CP0U9BD0EUIF06=SH`1WIfL0
YJFU05ADE00d=3@0C4a<06ATI01ADE40Rh^;075aL@0N7Qh0CTi>06IVIP1FEUH0O7al0:FUY@0k>c/0
=SHf06UYJ@1jNWX0LW9b0:b/[00m?Cd0<30`03Ti>@2>SXh0UYJF08N7Q`2;Rh/09bLW04I6AP1KFe/0
OGem06ATI01kNg/0LG5a02TY:@1DE5@00P1_Kfl07P1HF5P0Shn?04e=C@0d=3@0EeMG07]kN`1_Kfl0
EEEE06e]K@1JFUX09BDU06MWI`25QHD0FEUI04=3@`1[Jf/0DE5A0451@@1jNWX0X:2P05ADE00k>c/0
Lg=c06UYJ@0j>SX0Fe]K08>3P`25QHD0FUYJ03dm?@80@d=301H0B4Q8075aL@1BDU80:2PX03hn?P1@
D500DE5A05=CD`1iNGT0DU9B01hN7P16ATH0D51@04I6AP1iNGT0KFe]06][J`17AdL0Bd];05YJFP1;
Bd/0I6AT0P14A4@05`1QHF40?3`l0410@011@D40JVYZ08N7Q`1iNGT0KFe]08R8R02JVYX0NWYj06QX
J01PH600=CDe04U9B@1?Cdl0DE5A03`l?01VIVH0G5aL04A4A015ADD0CDe=0080Kfm_06H0BDU905EE
E@1WIfL0NWYj075aL@1TI6@0P82006YZJP1_Kfl0Hf=S05UIF@1LG5`0C4a<06UYJ@1IFET0E5AD05=C
D`1>CTh0>CTi04a<C01IFET0C4a<06=SH`0c<c<0?Cdm03`l?00[:b/0ADE505ADE01YJFT0GUiN03Ph
>01GEeL0;Rh^05ADE01KFe/0IfMW05mOG`1ADE40T92@09FEU@1oOgl0@d=304Y:BP1iNGT0DE5A07Mg
M`1CDe<0AdM706EUI@1LG5`0IfMW075aL@1:BTX0@D5104e=C@18B4P0Hf=S04I6AP1CDe<0HV9R04e=
C@1EEED0Cdm?05UIF@0[:b/0BDU903`l?01IFET0=SHf05aLG00n?Sh0GemO02l_;`1ADE40De=C04];
B`1CDe<0=cLg059BDP1RHV80@T9205UIF@15ADD0QXJ605eMG@2BTY80IfMW06m_K`1/K6`0Bd];05=C
D`1dM7@0UYJF0492@P11@D40@d=302l_;`14A4@0?clo04i>CP0f=SH203lo?`0i0820P01HF5P0J6QX
07MgM`2UYJD0jn_[06EUI@1ZJVX0CDe=0410@01VIVH0=3@d08:2PP32`/80BDU905MGE`0l?3`0?Shn
02d];@0H61P0AdM706a/K028R8P0PH6108J6QP1gMgL0Vi^K0::RXP1XJ6P0MGEe05YJFP1gMgL0=cLg
06m_K`27QhL0Xj>S09BDU02RXZ80@410079bLP2>SXh0DU9B04];B`1YJFT0>CTi06=SH`0K6a/0FUYJ
03Hf=P0c<c<0KVi^06=SH`1VIVH0DU9B05iNGP1MGEd0IFEU0080DU9B07X0;Rh^04m?C`19BDT0Cdm?
05YJFP16ATH0SXj>05=CD`2VYZH0IfMW06ATI027QhL0J6QX04Y:BP1nOWh0GemO07]kN`26QXH0CTi>
08B4Q022PX80DE5A05EEE@0o?cl0CTi>024Q8@1NGUh0<c<c069RHP1HF5P0=CDe069RHP0f=SH0@d=3
05UIF@0K6a/0:2PX0410@00_;bl0ATI604=3@`1CDe<09bLW04a<C00K6a/0DU9B03Lg=`0h>3P0;Rh^
01lO7`1CDe<0@d=305aLG00`<300IVIV07MgM`0b<S80FEUI02@T901KFe/0H61P04I6AP1bLW806a/K
03Lg=`0P8200DE5A04A4A01;Bd/0JFUY07MgM`1IFET0DU9B05eMG@1lO7`0D51@05iNGP1@D500?Cdm
04];B`19BDT0?Shn04];B`1GEeL0<c<c04A4A00b<S80I6AT04m?C`1LG5`092@T071`L00g=cL0Bd];
04A4A01OGel0QXJ604i>CP1KFe/0MWIf03<c<`1VIVH0ATI602d];@19BDT0820P04A4A00d=3@0?clo
06ATI00X:2P0C4a<03/k>`2FUYH0HF5Q04Q8B01/K6`0NGUi05EEE@1KFe/0PH6106IVIP;ooooo0000
o`1OGel0LG5a079bLP2OWil0HV9R04I6AP1UIFD0XZ:R06m_K`2PX:00;Rh^0410@01DE5@0LG5a03dm
?@1]KFd0;bl_04Q8B01PH600TY:B069RHP0e=CD0@T9203<c<`18B4P0IVIV03Ph>00L71`0?3`l038b
<P10@400KFe]07emO@0_;bl0;Bd]051@D01^KVh0Fe]K0;2`/02MWId06a/K02HV9P1FEUH0KFe]05AD
E01aLG40Kfm_01XJ6P0S8b<0EUIF06UYJ@1KFe/0Ph>3051@D00K6a/0<C4a08N7Q`2CTi<0O7al07mo
O`0U9BD0A4A4055AD@1_Kfl0Fe]K09fMW@14A4@0;Rh^05]KF`1`L700BTY:0;Rh^02JVYX07AdM024Q
8@14A4@0O7al04Q8B01nOWh0];Bd03@d=00a<C40AdM707moO`0i>CT0QXJ603Ti>@0Q8B40AdM707in
OP1kNg/0=cLg04i>CP0Q8B40:2PX04U9B@1TI6@0<c<c04=3@`0k>c/0:BTY02LW9`1HF5P0?3`l02@T
900n?Sh0;2`/03Lg=`1BDU80KVi^02/[:`0P8200;bl_03Lg=`0`<300Ogmo06YZJP0I6AT0<30`03De
=@19BDT0GUiN09FEU@0g=cL092@T0451@@1GEeL0L71`08B4Q023Ph<092@T034a<@1CDe<0Shn?05aL
G01UIFD0TI6A038b<P0];Bd0@D5108n?S`1aLG40P82007]kN`0V9RH0E5AD05IFEP2;Rh/0ATI608>3
P`1_Kfl0<30`04i>CP1SHf<0Shn?06EUI@2;Rh/0?Shn02d];@1ADE40C4a<06m_K`1nOWh0?3`l04A4
A01RHV80WYjN04Q8B021PH40O7al02PX:00f=SH0QXJ6071`L00h>3P0F5QH05ADE010@400?Shn07]k
N`29RHT0<c<c061PH00k>c/07AdM04E5A@2EUID0FEUI03Xj>P1DE5@0A4A403De=@1OGel0NWYj02h^
;P0o?cl0H61P04Y:BP1OGel0UYJF07emO@0Y:BT0?Shn07EeM@11@D40WYjN061PH00I6AT0:BTY061P
H01FEUH0MgMg0:NWY`0Z:RX0>SXj06YZJP1WIfL0JFUY07UiN@2JVYX0:BTY03Hf=P1mOGd0G5aL08N7
Q`2?Shl0<S8b03lo?`1^KVh0QhN705YJFP2UYJD0<C4a04e=C@28R8P0K6a/05MGE`1aLG40@d=3059B
DP1EEED0Shn?03`l?01aLG40F5QH03Xj>P0g=cL0U9BD092@T01EEED0I6AT03<c<`1>CTh0EEEE05=C
D`007P0^;Rh0DU9B05UIF@0c<c<0KVi^06YZJP12@T80>3Ph05]KF`1?Cdl0C4a<0:BTY02=SHd0<30`
04A4A026QXH0K6a/05UIF@2/[:`0Ogmo034a<@1@D500EeMG04m?C`1NGUh0LG5a05eMG@0Y:BT0=3@d
069RHP80IVIV03l0Vi^K071`L00O7al0>3Ph07UiN@1aLG40Bd];08R8R01kNg/0<c<c03`l?01HF5P0
NGUi05YJFP2DU9@0F5QH02@T900h>3P0EEEE06i^KP1CDe<0NGUi06e]K@0N7Qh0ADE504m?C`1XJ6P0
@41006a/K01_Kfl071`L059BDP1ZJVX0Ng]k04m?C`1>CTh0JVYZ05eMG@1hN7P0BDU904A4A01RHV80
ATI603Xj>P10@400OWin07emO@1iNGT0Ng]k08j>SP2RXZ80LW9b05QHF01ADE40;Rh^02l_;`11@D40
AdM70492@P1>CTh0DU9B04i>CP11@D400P14A4@04@1BDU80@T9205aLG01YJFT0MGEe06ATI01IFET0
H61P03@d=01?Cdl0A4A404e=C@1ADE40BTY:05aLG01;Bd/0B4Q80080?Cdm0480<c<c055AD@0m?Cd0
;2`/05IFEP1=CDd0DE5A0410@00`<300A4A406EUI@2VYZH0OGem04=3@`1;Bd/0GEeM07IfMP1UIFD0
@d=305QHF01:BTX0OGem0=oOg`2KVi/0Bd];0492@P1QHF40R8R808f=S@1KFe/0I6AT075aL@16ATH0
=3@d055AD@1HF5P0De=C04I6AP0k>c/0DE5A05EEE@1@D500AdM704Y:BP1TI6@0>SXj03Ti>@0U9BD0
Fe]K038b<P15ADD0<30`06IVIP0^;Rh0>SXj02XZ:P1HF5P0De=C04m?C`12@T80BTY:05QHF01IFET0
C4a<05QHF01<C4`205EEE@0Z0:JVYP1UIFD0H61P05eMG@1ADE40J6QX04i>CP1EEED0@T9205UIF@1C
De<0FEUI06e]K@1CDe<0CDe=03dm?@1;Bd/0@D51059BDP0_;bl0KVi^07moO`1<C4`0Rh^;0410@01X
J6P0N7Qh04U9B@1bLW806ATI05ADE02GUiL0<c<c05aLG00k>c/0Fe]K04M7A`0a<C40CDe=038b<P0o
?cl0>3Ph0P1eMGD0I01hN7P0HF5Q05QHF02=SHd0@T9206a/K00X:2P0_kno0:VYZ@1jNWX0Fe]K079b
LP1<C4`0N7Qh09>CT`1YJFT0C4a<06UYJ@0d=3@0EeMG02l_;`1gMgL0FUYJ04M7A`1OGel0=3@d05=C
D`1<C4`05QHF05UIF@1HF5P0ATI605QHF01>CTh0G5aL06MWI`1<C4`0IfMW04A4A01lO7`0>c/k06=S
H`1QHF40>c/k04E5A@17AdL0Bd];06UYJ@1LG5`0EeMG08R8R01cLg<0X:2P06IVIP1DE5@0FUYJ04U9
B@1IFET0Cdm?06MWI`1:BTX0FEUI04U9B@0n?Sh0Lg=c02`/;014A4@0De=C01`L700];Bd0C4a<030`
<010@400AdM705iNGP0c<c<0EEEE03Xj>P1;Bd/0CDe=059BDP0n?Sh0>3Ph059BDP1OGel0Lg=c03Ti
>@1LG5`0FUYJ03De=@1bLW809BDU04E5A@1BDU80@T9207AdM00^;Rh0@T9204=3@`1TI6@204I6AP0e
03Lg=`1NGUh0A4A405]KF`1EEED0G5aL04];B`11@D40?Shn02TY:@1<C4`0CDe=01XJ6P1EEED0H61P
03/k>`1=CDd0=CDe055AD@0k>c/0Cdm?0492@P1iNGT0B4Q8069RHP1BDU80>3Ph051@D01ADE40LG5a
0820P012@T80E5AD03De=@0/;2`0CDe=02XZ:P17AdL0@D5106QXJ026QXH0Cdm?04a<C01ADE40L71`
061PH01?Cdl0EEEE06QXJ01SHf<0Cdm?06QXJ01UIFD00_ooool0003U06MWI`1YJFT0IfMW09NGU`2>
SXh0?3`l04M7A`1/K6`0IfMW0:VYZ@0l?3`0;Rh^04Y:BP1TI6@0EeMG08j>SP19BDT08B4Q02h^;P1V
IVH0Kfm_09fMW@29RHT08b<S02HV9P1>CTh0IVIV055AD@33`l<0BDU901/K6`1:BTX0LG5a03dm?@1Q
HF40OGem024Q8@0Y:BT0HV9R08V9R@11@D40I6AT07QhN00A4A409bLW055AD@1DE5@0GUiN07EeM@27
QhL051@D03@d=013@d<0F5QH03De=@1MGEd0IfMW01HF5P1PH600O7al03/k>`19BDT0GEeM01lO7`0^
;Rh0MGEe0;6a/@10@400;bl_03/k>`0_;bl0DU9B08j>SP1GEeL0<C4a04U9B@0`<3006a/K05MGE`2N
WYh0?3`l02LW9`16ATH0BTY:06UYJ@2OWil0Jf][01PH600];Bd0@d=305aLG01gMgL0[:b/05YJFP0T
92@0CTi>0451@@0i>CT0Ph>309fMW@0F5QH06a/K0492@P1NGUh0EUIF0;Ng]`0n?Sh0410@02@T901E
EED0ADE505iNGP29RHT05aLG028R8P0n?Sh0MgMg04Y:BP1eMGD0J6QX01PH600^;Rh0GUiN08B4Q00g
=cL0LW9b03Hf=P0U9BD0E5AD065QH@1VIVH0@T9206e]K@0Q8B40>CTi04Y:BP1OGel0JFUY03De=@1I
FET0;Rh^030`<00c<c<0Ph>304a<C00_;bl0EeMG03Ph>00_;bl0FUYJ09^KV`1ADE40Cdm?05aLG00l
?3`0?clo08N7Q`1eMGD0=CDe04I6AP0a<C40HV9R08V9R@0/;2`0<C4a04a<C01;Bd/0GEeM09FEU@2M
WId0?3`l03Ph>01BDU80IFEU06i^KP2HV9P0MgMg02TY:@12@T80@d=307IfMP1NGUh0`/;20:>SX`0_
;bl0@d=305ADE01/K6`0P8200:JVYP11@D40=3@d06ATI020P800HF5Q06e]K@1KFe/0:2PX05=CD`1X
J6P0O7al065QH@29RHT0Rh^;038b<P0j>SX0PX:206MWI`1ZJVX0LW9b02TY:@0j>SX0DE5A04e=C@0n
?Sh0Ng]k02XZ:P0];Bd0F5QH07emO@1EEED0D51@055AD@0O7al0C4a<08n?S`1/K6`0EEEE071`L002
038b<P0@09>CT`2ATI40Fe]K065QH@0k>c/0KFe]0<S8b01GEeL0;bl_05UIF@1QHF40@41008R8R02Q
XJ408B4Q02XZ:P80Cdm?01@0GUiN0:BTY00^;Rh0@d=306i^KP1[Jf/0Cdm?09JFUP2;Rh/0;Rh^0451
@@1cLg<0De=C06IVIP27QhL0H61P02h^;P1IFET0TY:B04i>CP80O7al05/0?Shn05mOG`1RHV80XJ6Q
04a<C01gMgL0P82003/k>`19BDT0HF5Q08F5Q@1BDU80M7Ad06a/K00a<C40;Bd]07inOP2JVYX0E5AD
06ATI01aLG40=cLg03lo?`1IFET0NGUi030`<011@D40M7Ad0492@P0S8b<0Kfm_0:6QX@0c<c<0>CTi
04i>CP0k>c/08R8R04e=C@2IVIT0<c<c030`<01cLg<0?3`l030`<01OGel0XZ:R03`l?00c<c<0K6a/
07alO01IFET0HF5Q06UYJ@17AdL0IFEU075aL@1IFET0L71`034a<@1SHf<0LW9b08b<S01lO7`0MGEe
0:ZZZP3Cdm<0WinO06=SH`1HF5P0MGEe05IFEP1<C4`0D51@05]KF`1>CTh0DU9B05YJFP1kNg/0G5aL
05UIF@1CDe<0Hf=S069RHP24Q8@0L71`07inOP24Q8@0Ph>308V9R@1NGUh0LG5a0080De=C00L0GemO
05aLG01kNg/0BTY:05=CD`1/K6`0EEEE0080BTY:03l0DU9B03hn?P1OGel0=cLg04A4A00`<300>CTi
0492@P1;Bd/0EeMG04a<C00V9RH0D51@04=3@`1@D500EEEE03Xj>P1XJ6P0IfMW06][J`1VIVH0H61P
05YJFP1KFe/0EeMG04=3@`1OGel0EUIF04A4A01[Jf/0:b/[03hn?P1VIVH0FUYJ03/k>`0n?Sh0<c<c
05ADE018B4P0>3Ph03lo?`17AdL0DE5A0451@@1CDe<0?Cdm04=3@`1CDe<0B4Q803hn?P1PH600AdM7
055AD@0l?3`0BDU904a<C01:BTX0Bd];059BDP1FEUH0GUiN059BDP1aLG400P1RHV80b01TI6@0RXZ:
07EeM@1WIfL0J6QX06MWI`1OGel0G5aL07inOP0o?cl0Lg=c07AdM00l?3`0<30`0410@01ADE40HV9R
0492@P13@d<0EeMG03Xj>P2>SXh0SHf=07=cL`37alL0BDU908:2PP1OGel0E5AD09:BTP0C4a<0P820
0:BTY00W9bL0S8b<03@d=01CDe<0<c<c02DU9@1KFe/0?clo04];B`1<C4`0OWin071`L02MWId0OWin
03Ti>@1ADE40?3`l06MWI`0X:2P0GemO08n?S`26QXH0De=C05EEE@16ATH0PX:20;2`/01LG5`0@410
05aLG016ATH0E5AD03De=@18B4P0AdM703hn?P21PH40@41005eMG@1ADE40;Rh^06ATI01OGel0GEeM
075aL@1<C4`0D51@0451@@1NGUh0SXj>07EeM@29RHT0IfMW092@T01fMWH0CTi>05ADE00g=cL0=SHf
0861P@1LG5`0EeMG0820P01GEeL0/k>c071`L01ZJVX0Hf=S03lo?`1>CTh061PH07AdM018B4P0Fe]K
05=CD`1@D500NGUi04Y:BP1BDU80C4a<04Q8B00f=SH0De=C04U9B@1>CTh0F5QH04m?C`0n?Sh0GEeM
03Ti>@1@D500Bd];059BDP10@400?Cdm05EEE@1>CTh0G5aL02l_;`1NGUh0K6a/04Y:BP20P800ATI6
051@D01CDe<0Fe]K06m_K`0n?Sh0AdM701`L701HF5P0@410059BDP1;Bd/0A4A404M7A`1ADE40<C4a
05YJFP0_;bl0@D51059BDP12@T80EUIF06QXJ010@400=cLg03`l?012@T80NWYj04M7A`1BDU80@D51
055AD@15ADD0XJ6Q0451@@1aLG40H61P04M7A`1^KVh07alO055AD@1cLg<0=CDe05ADE01KFe/0A4A4
04];B`13@d<0C4a<05MGE`1TI6@0GEeM02/[:`1UIFD0FUYJ09VIV@1?Cdl0?3`l04e=C@1_Kfl0AdM7
059BDP24Q8@0De=C0_ooool0000B0820P02IVIT0D51@06][J`2<S8`0EUIF0:2PX016ATH0AdM7061P
H01JFUX0GemO06i^KP0j>SX0?Shn04i>CP1JFUX0@D510P1ADE401P0N7Qh0>SXj08>3P`1aLG40ATI6
05=CD`8071`L0;00Cdm?08^;R`14A4@0;2`/04=3@`0];Bd0@T9209ZJVP0k>c/051@D03Hf=P1>CTh0
<C4a05UIF@2i^KT0Cdm?01/K6`0i>CT0>3Ph04Q8B01nOWh0]KFe02HV9P0Y:BT0DU9B03lo?`0h>3P0
QHF50;2`/00M7Ad0820P06e]K@16ATH0IFEU06m_K`0P8200?Cdm05YJFP28R8P0Lg=c05EEE@0g=cL0
9BDU02`/;019BDT0IFEU07=cL`2TY:@0;Bd]02LW9`0Y:BT0Cdm?05eMG@16ATH0Ph>3020P800[:b/0
N7Qh08B4Q00c<c<0H61P07IfMP0Y:BT0E5AD06IVIP1RHV80EEEE07YjNP12@T80;Bd]04=3@`2:RXX0
Lg=c04=3@`1KFe/0<S8b03@d=01JFUX0Shn?0451@@12@T80FEUI01PH600j>SX0Q8B404a<C00[:b/0
C4a<03Ph>00d=3@0Hf=S0:FUY@0f=SH0<30`04=3@`17AdL0FEUI07moO`1nOWh06ATI02h^;P1BDU80
=3@d07inOP30`<00KFe]01XJ6P13@d<0@D5104Y:BP1QHF40^[Zj07EeM@0Q8B40@D51059BDP1SHf<0
PH610:b/[00d=3@0<S8b04Q8B01ZJVX0KFe]08N7Q`2PX:006ATI02TY:@1PH600M7Ad06MWI`1/K6`0
;2`/04A4A027QhL0QXJ606][J`27QhL07alO03Hf=P1PH600T92@04m?C`1^KVh0QHF502TY:@0f=SH0
N7Qh07UiN@0a<C40C4a<08V9R@0U9BD0:2PX04];B`1hN7P0CDe=06EUI@1_Kfl06a/K04Y:BP1IFET0
IfMW03Hf=P1NGUh0De=C03Ti>@1KFe/0UiNG02h^;P0j>SX0Lg=c03Ph>01:BTX0Hf=S09:BTP80@d=3
01L0<C4a03@d=01]KFd0NGUi03Ph>00_;bl0GEeM04A4A01iNGT0[Jf]05]KF`0I6AT0CDe=05mOG`1<
C4`0Ti>C08R8R00R8R80;Rh^04Q8B01FEUH0KFe]0;2`/00203Lg=`3T04i>CP1VIVH0PH6109bLW00Q
8B40;Rh^07MgM`2;Rh/0FEUI06m_K`0g=cL09BDU05YJFP2LW9`0Ogmo04Y:BP1iNGT0?Cdm069RHP20
P800KFe]05MGE`25QHD0>3Ph03lo?`18B4P0K6a/04Q8B01ZJVX0I6AT01/K6`1ADE40Q8B407AdM00j
>SX0GemO06IVIP0];Bd0DE5A092@T01GEeL0?clo07UiN@1=CDd0<c<c065QH@2f][H0JVYZ03lo?`1Z
JVX0EUIF03@d=01LG5`0Y:BT04e=C@0`<300DU9B065QH@12@T80Fe]K09JFUP17AdL07alO03Ti>@1O
Gel0D51@061PH02JVYX0A4A402@T900g=cL0Jf][05UIF@1XJ6P0W9bL03lo?`0[:b/0>3Ph06UYJ@1M
GEd0Hf=S0:RXZ00c<c<0>3Ph04e=C@1;Bd/0EEEE06ATI022PX80KVi^05MGE`1FEUH0E5AD05QHF01B
DU80AdM704a<C01ZJVX0=cLg04Q8B00o?cl0HV9R096AT@1iNGT0DE5A04U9B@1DE5@0GEeM05MGE`1<
C4`0>c/k04e=C@0k>c/0:RXZ030`<01>CTh0ATI602PX:00c<c<0@d=305iNGP1@D500?3`l04e=C@1B
DU80GemO051@D01]KFd0Hf=S06QXJ01?Cdl0A4A40492@P15ADD0A4A405eMG@13@d<0C4a<05ADE01V
IVH0@d=3051@D01EEED0FEUI06=SH`0h>3P0BDU904a<C02BTY80][Jf04];B`1lO7`0KVi^03dm?@1I
FET0:BTY05IFEP1VIVH0ATI606EUI@1/K6`0RXZ:08j>SP2UYJD0B4Q804U9B@1oOgl0SHf=09:BTP17
AdL0BDU906MWI`1HF5P0LW9b08n?S`1VIVH0ADE505]KF`1LG5`0HF5Q04];B`1CDe<0CTi>05ADE01W
IfL0BDU905EEE@0k>c/0De=C0410@01JFUX0ADE506a/K00d=3@0JFUY0410@01FEUH0Cdm?04I6AP1L
G5`0DU9B05MGE`1MGEd0E5AD05eMG@1@D500MGEe07=cL`2BTY80C4a<05mOG`2?Shl0GUiN06IVIP1I
FET0IfMW07IfMP1cLg<0I6AT03Ph>011@D40De=C07QhN01LG5`0@d=304a<C01eMGD0De=C0P1;Bd/0
BP2a/K40hN7Q03Ti>@15ADD0@d=305]KF`2/[:`0;2`/08F5Q@2OWil0;2`/06IVIP0];Bd0B4Q802HV
9P0G5aL0>CTi034a<@1kNg/0C4a<05MGE`1CDe<0Vi^K0820P018B4P0Kfm_04U9B@1eMGD0=3@d05IF
EP1<C4`0Bd];05iNGP1TI6@0BTY:07QhN02RXZ80HF5Q055AD@1JFUX0ADE507QhN00i>CT0J6QX04I6
AP1JFUX0K6a/04=3@`1HF5P0C4a<0410@01aLG40@T9203Hf=P1?Cdl07alO059BDP1DE5@0EEEE06EU
I@1OGel0T92@04=3@`2EUID0JFUY04E5A@1>CTh0?Cdm03lo?`1nOWh0HF5Q08b<S02:RXX0@4100P1U
IFD05@1>CTh0Bd];055AD@1DE5@09bLW05MGE`0c<c<0H61P05QHF01FEUH0Ogmo04=3@`1KFe/0GemO
02TY:@14A4@0CDe=030`<018B4P0BTY:05ADE00203lo?`1>03dm?@18B4P0?clo0451@@14A4@0=SHf
051@D01CDe<0G5aL03Ti>@1LG5`0IVIV03/k>`1RHV808B4Q059BDP1:BTX0@T9206MWI`0/;2`0@T92
03Hf=P19BDT0>SXj03<c<`0f=SH0B4Q803`l?00b<S80?Cdm05]KF`1:BTX0GUiN04Q8B00P8200C4a<
04Y:BP0W9bL0EUIF05mOG`1ADE40IfMW04i>CP1eMGD0@d=304M7A`0[:b/0EEEE04a<C01]KFd0Bd];
05EEE@1dM7@0?clo051@D01WIfL0ATI607IfMP17AdL0>c/k03dm?@0];Bd0=CDe04U9B@1WIfL0GEeM
030`<010@400>c/k09VIV@12@T80?Cdm061PH01NGUh0Cdm?05aLG01cLg<0FEUI0_ooool0001R05UI
F@1hN7P0DU9B05MGE`1ADE40BTY:07]kN`1UIFD0@T9205ADE01<C4`0PH6109JFUP13@d<0;2`/055A
D@15ADD0Hf=S0:>SX`2MWId0:b/[018B4P0i>CT0DU9B06MWI`2][Jd0=CDe02LW9`0e=CD0D51@06EU
I@2@T900R8R801hN7P0^;Rh0De=C07emO@1>CTh0[jn_06UYJ@0j>SX0;2`/05YJFP1dM7@0J6QX071`
L00b<S8092@T061PH01JFUX0KFe]04e=C@33`l<0=SHf01hN7P0f=SH0U9BD07IfMP1GEeL0Cdm?02@T
900b<S80ADE501/K6`0h>3P0JFUY02d];@0k>c/0UYJF08V9R@0Y:BT0B4Q803Hf=P0N7Qh0BDU909nO
W`1FEUH06QXJ04];B`0c<c<0EEEE06i^KP2h^;P0De=C01/K6`0c<c<0F5QH05IFEP1eMGD0ZJVY02DU
9@0`<300DE5A0492@P1KFe/0[Jf]04e=C@0K6a/204Q8B00N04m?C`1QHF40P82002/[:`0T92@0ADE5
04=3@`11@D40Kfm_0:NWY`0V9RH0;bl_05QHF01KFe/0G5aL09ZJVP1ADE40:2PX03lo?`1QHF40GemO
07QhN01fMWH06ATI030`<01>CTh0F5QH04I6AP1EEED0Ogmo0P0[:b/0o`1mOGd0RHV903De=@1BDU80
=SHf02`/;00Y:BT0Hf=S09JFUP0o?cl0EEEE05QHF00U9BD0De=C08F5Q@27QhL0=CDe0820P00o?cl0
<30`07=cL`34a<@0OWin04e=C@25QHD0=3@d02d];@1oOgl0;2`/04=3@`1DE5@0=SHf08F5Q@3Bd]80
Fe]K02PX:014A4@0Fe]K06MWI`1oOgl0];Bd0410@00e=CD0D51@05mOG`1MGEd0RHV909VIV@14A4@0
<C4a04a<C01BDU80G5aL08V9R@2c/k<08b<S03Ti>@1IFET0N7Qh04Q8B02ZZZX0?3`l030`<01`L700
Zj^[069RHP1YJFT0SXj>03Hf=P0M7Ad0Cdm?0:BTY01aLG40M7Ad0451@@0N7Qh0De=C07inOP1hN7P0
FUYJ09bLW00f=SH0:b/[09BDU02ZZZX0;Bd]06UYJ@1OGel0ADE505iNGP2^[Zh0@d=30451@@1PH600
<S8b03Xj>P2IVIT0Ogmo051@D01HF5P0=CDe04];B`2JVYX0LW9b03De=@1EEED0BTY:04a<C02;Rh/0
I6AT024Q8@1=CDd0@D5104M7A`1^KVh0PX:203Ph>019BDT0EEEE04e=C@1mOGd0ZZZZ04E5A@0f=SH0
EUIF06e]K@1EEED0T92@0:VYZ@0`<300:b/[05QHF01WIfL0GUiN0:j^[P2FUYH0<c<c0410@01ADE40
H61P079bLP37alL0J6QX03De=@0h>3P0FEUI075aL@1TI6@0Z:RX06ATI015ADD0HF5Q06UYJ@1aLG40
KVi^09ZJVP1WIfL0=SHf06ATI02=SHd0UiNG055AD@2LW9`0KFe]02/[:`1;Bd/0NWYj071`L00b<S80
Hf=S04i>CP0N7Qh0=cLg071`L01bLW80?Shn07UiN@1dM7@0>3Ph03<c<`1TI6@0Ti>C038b<P1]KFd0
?3`l02@T901ADE40PH6106IVIP1:BTX0DU9B07EeM@2:RXX0Lg=c04i>CP1MGEd0UYJF04];B`1EEED0
CTi>06EUI@1]KFd0IfMW07IfMP21PH40LG5a06ATI01]KFd0FEUI04=3@`1CDe<0Fe]K04I6AP10@400
KVi^05IFEP1YJFT0<c<c04m?C`2SXj<0QXJ604M7A`1ADE40N7Qh08F5Q@1MGEd0I6AT071`L01iNGT0
Kfm_04e=C@1BDU80CDe=04Q8B01_Kfl0N7Qh07EeM@1GEeL0GEeM03dm?@2BTY80CTi>03@d=01CDe<0
?Cdm04Y:BP0S8b<0;bl_04E5A@1CDe<0YJFU05aLG011@D40EeMG03<c<`00401GEeL0CDe=04a<C01G
EeL0OGem07AdM02MWId0MGEe04];B`1=CDd0K6a/04m?C`1`L700Bd];04U9B@1/K6`2030`<080H61P
01@0HV9R03/k>`0e=CD0BTY:03dm?@0k>c/0BTY:04a<C01LG5`0>c/k04=3@`0d=3@0@d=304e=C@1@
D500@T9205iNGP1>CTh0DE5A03hn?P80C4a<07P0DE5A0410@01<C4`0F5QH05UIF@1ADE40EEEE05AD
E01aLG40Fe]K09VIV@1XJ6P0M7Ad069RHP1NGUh0I6AT07inOP2SXj<0?3`l07alO02=SHd0Bd];04E5
A@1EEED0JVYZ034a<@12@T80?Cdm061PH012@T80MWIf0:RXZ02:RXX0XJ6Q055AD@19BDT0NGUi06i^
KP2LW9`0NGUi08f=S@39bLT0EUIF07alO00o?cl0ATI602TY:@0I6AT0=SHf038b<P0k>c/0<30`071`
L014A4@0];Bd06QXJ011@D40J6QX03`l?01]KFd05ADE05IFEP0a<C408B4Q05eMG@2XZ:P0=CDe05mO
G`2ATI40?Cdm05eMG@1ZJVX0>CTi04m?C`0/;2`0M7Ad03Ph>00c<c<0KVi^03<c<`1VIVH0BDU9018B
4P1;Bd/0<C4a03hn?P1FEUH0<S8b06IVIP1>CTh0Cdm?061PH01ADE40UIFE03/k>`1eMGD0GEeM05]K
F`22PX80GemO04A4A01WIfL0<c<c04];B`1?Cdl0BTY:09VIV@1SHf<0E5AD05IFEP1?Cdl0ADE503Xj
>P1OGel092@T0492@P1;Bd/0CDe=04i>CP0G5aL2034a<@1G01DE5@0e=CD0CTi>020P800n?Sh0CDe=
04Y:BP16ATH0CTi>03Ti>@1HF5P0DE5A04E5A@1BDU80=SHf051@D021PH40PX:204a<C01NGUh0CDe=
0451@@1UIFD071`L03Hf=P0`<300>c/k06i^KP1=CDd0@T9204i>CP14A4@0>c/k04I6AP1OGel0G5aL
0451@@1;Bd/0KFe]09fMW@0o?cl0820P01dM7@0[:b/0CDe=03`l?00[:b/0LW9b075aL@16ATH0Bd];
03Ti>@17AdL0@D5105aLG00c<c<0EeMG04I6AP2f][H0IFEU03dm?@1ZJVX0AdM707moO`1kNg/0=SHf
0410@00e=CD0>c/k04];B`0c<c<0@41004=3@`1UIFD0HF5Q03Hf=P1:BTX0FUYJ0=3@d01NGUh0De=C
08F5Q@1hN7P0De=C04U9B@1iNGT0H61P00;ooooo00009P1HF5P0Q8B408:2PP2h^;P0D51@04=3@`1>
CTh0RHV909NGU`2HV9P08B4Q0492@P1TI6@0GUiN06QXJ02HV9P0@d=3030`<01CDe<0Ti>C06i^KP1Q
HF40Hf=S02TY:@0g=cL0Bd];08:2PP1;Bd/0L71`03/k>`0d=3@0GEeM06MWI`0i>CT0:b/[05eMG@0^
;Rh0>SXj0P1?Cdl0kP0S8b<0<c<c05iNGP0_;bl0FUYJ07moO`0j>SX0820P03Ti>@1?Cdl0=cLg06i^
KP2;Rh/0ATI601DE5@0Z:RX0:2PX04Q8B02<S8`0UYJF02`/;012@T80GemO03Xj>P1XJ6P0_;bl03`l
?00`<300>SXj05eMG@0f=SH0Ph>307QhN00J6QX0;2`/05mOG`1aLG40Cdm?0=GEe@2;Rh/08b<S04m?
C`1gMgL0V9RH065QH@2<S8`07QhN03Ph>01GEeL0Kfm_06UYJ@0b<S80De=C02@T900e=CD0Jf][092@
T00g=cL0HV9R03Lg=`0D51@0?3`l08:2PP1]KFd0@D5107EeM@0c<c<05QHF051@D02UYJD0QhN7034a
<@11@D40:2PX02l_;`1fMWH0Ng]k03@d=00l?3`0;2`/02DU9@1DE5@0XZ:R04M7A`0M7Ad0ADE505UI
F@1?Cdl0KFe]07UiN@0N7Qh06a/K0451@@1cLg<0>c/k07YjNP1PH60071`L02LW9`11@D40Q8B4059B
DP1OGel0OGem01dM7@0Q8B40FEUI07moO`1?Cdl0[Jf]06=SH`0I6AT0@T9207YjNP2@T900Hf=S0=7A
d@0j>SX0?clo05UIF@19BDT0Lg=c08:2PP0E5AD0;Rh^06ATI01HF5P0Cdm?06EUI@0c<c<08B4Q055A
D@1oOgl0KFe]06EUI@2^[Zh0CTi>02<S8`1CDe<0MgMg06UYJ@0k>c/0PH6103Xj>P0_;bl0IfMW09BD
U01_Kfl0DU9B071`L00W9bL0B4Q806ATI01SHf<0?Cdm05IFEP1kNg/07alO05IFEP2VYZH0IVIV02l_
;`1ADE40DU9B02/[:`25QHD0QhN702<S8`0l?3`0@T9204A4A013@d<0W9bL06MWI`0N7Qh0@D51059B
DP0m?Cd0OWin05YJFP0T92@0>CTi06IVIP14A4@0JVYZ08b<S00V9RH0<S8b05YJFP1LG5`0R8R80;Jf
]P0_;bl0ADE505eMG@1hN7P0Ph>3092@T00f=SH0CTi>07=cL`22PX80DE5A0:VYZ@1aLG407alO05QH
F02WYjL0J6QX08j>SP2:RXX0;Rh^04=3@`1fMWH0V9RH06QXJ01cLg<0DE5A02h^;P1HF5P0XZ:R08Z:
RP1GEeL0Ogmo03Hf=P0h>3P0Jf][0:2PX01:BTX0DE5A05=CD`0_;bl0B4Q806IVIP2EUID0BTY:051@
D01QHF4203@d=03K0::RXP2e]KD0>SXj03/k>`1IFET0?Shn03/k>`2ATI40[Jf]03@d=00a<C40GUiN
075aL@13@d<0S8b<09ZJVP0`<300:BTY055AD@1NGUh0C4a<09:BTP26QXH06a/K03De=@12@T80EUIF
03dm?@2HV9P0Z:RX02HV9P0o?cl0DU9B07EeM@1LG5`0/k>c08B4Q00J6QX0=cLg075aL@2DU9@0FUYJ
065QH@1JFUX0C4a<07MgM`1iNGT0Hf=S06a/K00k>c/0HV9R06YZJP1eMGD0MgMg07alO02SXj<0^KVi
09VIV@1]KFd0E5AD06UYJ@15ADD0?Cdm03Ti>@1CDe<0ADE505IFEP1OGel0MGEe04a<C01JFUX0C4a<
055AD@1GEeL0HV9R04m?C`1GEeL0HF5Q06e]K@1CDe<0?Shn051@D016ATH0=cLg04];B`1CDe<0J6QX
03/k>`0d=3@0C4a<04U9B@10@400AdM703hn?P14A4@0CTi>03Ph>017AdL0;Bd]04I6AP10@400?Shn
04=3@`0a<C40:BTY03Xj>P0d=3@0>CTi03Ph>00g=cL0E5AD07YjNP1UIFD0Rh^;08b<S02@T900WinO
06IVIP1OGel0Kfm_07EeM@1bLW80KFe]02TY:@0e=CD0De=C04Q8B00o?cl0@41003Ph>017AdL0DE5A
03Lg=`13@d<0GemO06ATI00l?3`0>CTi030`<01GEeL0:RXZ051@D00K6a/0FUYJ03Lg=`1ADE40>3Ph
05]KF`0i>CT0?3`l03dm?@1FEUH0Cdm?04a<C01KFe/0CDe=04I6AP1TI6@0IFEU0:ZZZP17AdL0Fe]K
07UiN@1dM7@0DU9B051@D01UIFD0A4A40820P024Q8@0GEeM06QXJ01IFET0L71`05UIF@1OGel0>c/k
06][J`1DE5@0U9BD0820P02HV9P0_;bl05ADE01NGUh0Lg=c05MGE`2QXJ40?Cdm0:FUY@3Fe]H0GemO
06ATI01/K6`0IfMW0451@@0X:2P0=SHf04I6AP1DE5@0C4a<07QhN01<C4`0PH6105eMG@14A4@0HV9R
04m?C`1XJ6P07AdM06m_K`1DE5@0?3`l03dm?@1eMGD0<c<c06MWI`2TY:@0@4100080BDU902`0<30`
05QHF00S8b<0De=C038b<P0f=SH0JVYZ04A4A01JFUX0ATI6038b<P25QHD0EEEE06m_K`1gMgL0BTY:
04A4A019BDT0E5AD05eMG@1dM7@0/k>c0451@@26QXH0FEUI03Ti>@16ATH0<C4a0410@01gMgL0=SHf
06ATI02?Shl0LW9b0:ZZZP1PH600Shn?05EEE@1HF5P0FEUI03@d=01ZJVX0E5AD05aLG080IVIV00L0
G5aL018B4P1=CDd0D51@01dM7@15ADD0DU9B0080G5aL00h0L71`06UYJ@17AdL0D51@03lo?`0k>c/0
DE5A03Lg=`0f=SH0;Bd]04i>CP1=CDd0ADE503Lg=`80I6AT0480CDe=06i^KP1:BTX0EEEE05QHF01Q
HF40P82004Q8B010@400E5AD06][J`1CDe<0BDU90410@00h>3P0?Shn04M7A`0b<S80Bd];03Ti>@19
BDT0@41002<S8`1>CTh0@d=303Ph>012@T80E5AD04=3@`1FEUH0>CTi05MGE`1]KFd0Ng]k04];B`1C
De<0?3`l059BDP1KFe/0FUYJ07=cL`10@400]KFe079bLP0n?Sh0GEeM05YJFP0i>CT0@D5103Ph>018
B4P0E5AD09>CT`2@T900EEEE05ADE01IFET0MGEe06ATI01IFET0EEEE065QH@1fMWH0Ng]k096AT@2E
UID2ooooo`000380IVIV07MgM`15ADD0UYJF08F5Q@13@d<0HF5Q03/k>`1BDU80TI6A03Xj>P0_;bl0
B4Q804A4A00k>c/0Xj>S06ATI00S8b<0F5QH06YZJP17AdL0GemO09BDU00/;2`0=3@d02XZ:P0g=cL0
C4a<0;Ng]`1QHF405QHF02LW9`1=CDd0BTY:07AdM030`<00:RXZ024Q8@18B4P0O7al04Y:BP1gMgL0
ZJVY01dM7@0Z:RX0HV9R07alO01NGUh0VYZJ07EeM@80;2`/0?l0IVIV05QHF00k>c/0Rh^;05QHF00C
4a<0?3`l0861P@16ATH0Kfm_0451@@0U9BD0C4a<08f=S@1MGEd0B4Q806a/K01_Kfl08R8R059BDP25
QHD0>c/k03`l?01QHF40;Bd]02/[:`1EEED0Ph>302DU9@0Y:BT0C4a<03@d=01[Jf/0PH6104U9B@0S
8b<0<S8b03Ti>@19BDT0IVIV092@T00Z:RX06a/K03Hf=P19BDT0EUIF08>3P`1bLW808B4Q020P800o
?cl0GUiN04=3@`2SXj<0=SHf01`L700];Bd0LG5a08F5Q@17AdL0N7Qh01<C4`0Y:BT0ATI607AdM01H
F5P0Vi^K05YJFP0J6QX0@41007=cL`1PH600ADE508F5Q@0i>CT08R8R05=CD`2PX:00MgMg04Y:BP1S
Hf<08B4Q03Xj>P1:BTX0[Jf]05IFEP10@400NWYj04A4A00U9BD0@T9207=cL`1ADE40EeMG079bLP0`
<300?Cdm05mOG`1^KVh0?clo06a/K016ATH08b<S04e=C@2[Zj/0GemO02/[:`1?Cdl0<30`0:FUY@3:
b/X0C4a<03lo?`1OGel0@41005iNGP2m_Kd0Jf][02<S8`0k>c/0GUiN04Q8B01SHf<0_kno071`L00]
;Bd0?Cdm079bLP1DE5@0FEUI0;Bd]01gMgL0<c<c03hn?P1hN7P0JFUY065QH@2>SXh0>CTi02XZ:P28
R8P0RHV907YjNP2@T900^k^k038b<P0/;2`0LW9b07inOP1FEUH0PH6105=CD`0O7al0>3Ph07IfMP17
AdL0OGem07MgM`0K6a/0820P06IVIP2BTY80BTY:09ZJVP0[:b/0;bl_04=3@`1ZJVX0A4A405eMG@15
ADD0:RXZ059BDP1fMWH0CTi>04E5A@1fMWH0?Cdm04M7A`1dM7@0OWin06EUI@22PX809BDU055AD@2W
YjL0MWIf0492@P1/K6`0C4a<03`l?01aLG40Y:BT04Q8B01QHF40De=C04Y:BP1=CDd0OWin04I6AP0h
>3P0DU9B02`/;01UIFD0_Kfm09ZJVP0[:b/0>3Ph05ADE01BDU80IVIV0;>c/`1^KVh07alO03Ti>@1e
MGD0HV9R0861P@2XZ:P0<C4a02h^;P14A4@0KVi^06YZJP2DU9@0WIfM034a<@0V9RH0ADE508N7Q`1@
D500FUYJ08N7Q`0Z:RX0=CDe06i^KP2OWil0KVi^04m?C`1mOGd0;bl_02h^;P0k>c/0EEEE03dm?@1C
De<0XZ:R03Xj>P0b<S80CDe=06a/K00l?3`0Cdm?061PH00S8b<001d0820P03dm?@1aLG40BTY:02/[
:`1CDe<07AdM02/[:`24Q8@0MWIf03De=@1:BTX0KFe]065QH@1BDU80DE5A059BDP1HF5P0G5aL04=3
@`1MGEd0Ph>303@d=01GEeL0DE5A07AdM02GUiL0M7Ad05YJFP0205IFEP0407YjNP1eMGD0ADE503/k
>`80G5aL01T0ATI604a<C01mOGd0Lg=c05=CD`0o?cl0De=C0:BTY01iNGT0?Shn05MGE`1`L700T92@
07IfMP1LG5`0MWIf05aLG01PH600A4A403dm?@17AdL0BDU905EEE@1>CTh0EEEE0080IVIV0=00@D51
05EEE@1;Bd/0F5QH06UYJ@0f=SH0D51@02LW9`1YJFT0FEUI03Ph>01JFUX0=3@d03hn?P1UIFD08R8R
04I6AP1@D500>c/k05YJFP10@400H61P09JFUP1`L700;2`/02l_;`18B4P0GEeM05iNGP0`<300:2PX
06][J`0h>3P0?clo06a/K01DE5@0Bd];04m?C`0n?Sh0C4a<034a<@10@400AdM703@d=013@d<0B4Q8
03Ti>@0W9bL0<C4a03`l?012@T809RHV0451@@0m?Cd0A4A4020P800Y:BT0;Rh^04];B`0c<c<0=SHf
05=CD`1GEeL0=CDe038b<P1>CTh0EUIF03Ph>00i>CT0C4a<06m_K`1HF5P0BTY:05EEE@1PH600L71`
0492@P1[Jf/0HV9R04Q8B01?Cdl0Jf][08B4Q016ATH0BTY:04M7A`2?Shl0De=C061PH01RHV80[Jf]
0;Vi^@1[Jf/0QHF504];B`2;Rh/0cLg=05UIF@1^KVh0WYjN05EEE@2?Shl0FEUI06][J`1DE5@0HF5Q
079bLP1KFe/0DE5A07]kN`1oOgl0Jf][0;:b/P1gMgL0Cdm?06MWI`1BDU80O7al03Ph>024Q8@0Lg=c
06m_K`1IFET0GemO05MGE`1cLg<0Ti>C05YJFP1NGUh0H61P03hn?P1FEUH0<30`05eMG@13@d<0@410
06=SH`10@400Fe]K059BDP0P8200TI6A02h^;P0h>3P0?3`l02DU9@18B4P0Bd];06][J`1RHV80?3`l
06MWI`1TI6@0TI6A06=SH`0l?3`0C4a<03lo?`1MGEd0Ng]k03Ti>@2<S8`0Zj^[09VIV@2FUYH0I6AT
05eMG@1SHf<0EEEE0410@011@D40WIfM04Y:BP1IFET0EUIF09RHV02FUYH0B4Q804m?C`1FEUH0De=C
075aL@2ATI40F5QH05mOG`12@T80CTi>04a<C01HF5P0ADE504M7A`1RHV80CDe=04E5A@16ATH0FUYJ
059BDP1JFUX0@D5106YZJP1TI6@0G5aL092@T00n?Sh0DU9B04U9B@0j>SX0F5QH0P16ATH0>@0c<c<0
C4a<02`/;012@T80=CDe04I6AP1GEeL0EUIF04E5A@1DE5@0AdM704];B`1EEED0GEeM09BDU01DE5@0
3@d=03Xj>P1oOgl0@d=3075aL@1<C4`0AdM7038b<P1GEeL0L71`08F5Q@1IFET0M7Ad08J6QP1TI6@0
P82005MGE`1_Kfl0QXJ604i>CP1RHV80ATI606m_K`25QHD0ADE504a<C00];Bd0AdM705MGE`0o?cl0
Lg=c04m?C`2c/k<0GEeM05IFEP1XJ6P0LG5a05MGE`1EEED0KVi^05eMG@02ooooo`000<P0OGem0:j^
[P1<C4`0Bd];08:2PP1PH600Xj>S04i>CP0n?Sh0Bd];065QH@1kNg/0QXJ602XZ:P0`<300A4A40861
P@1?Cdl0/[:b05UIF@0b<S80;Rh^06UYJ@27QhL0B4Q805iNGP0K6a/0<C4a0410@025QHD0DU9B05EE
E@1ADE40:BTY02l_;`1HF5P0IfMW02d];@1BDU80>c/k024Q8@0];Bd0BTY:03Ph>00/;2`0KVi^02TY
:@0O7al0ADE506MWI`0Q8B40<C4a05MGE`0];Bd0Fe]K0;^k^`1ZJVX08b<S03@d=016ATH0?Shn09FE
U@1YJFT05ADE02HV9P1CDe<0E5AD05QHF02e]KD0Hf=S01DE5@0_;bl0I6AT04Y:BP1bLW80/k>c03@d
=00R8R80?clo07UiN@2?Shl0L71`0:JVYP0X:2P0=3@d04A4A01?Cdl0BDU908R8R023Ph<04Q8B03Hf
=P1RHV80ATI604m?C`1bLW809RHV020P801<C4`0PH6108R8R01gMgL0Vi^K03Ti>@0W9bL0ADE507Ad
M00g=cL0HV9R05]KF`0a<C40De=C07=cL`0i>CT08b<S06YZJP0h>3P0>SXj06m_K`2VYZH0>SXj03@d
=01@D500=SHf04a<C028R8P0Fe]K01TI6@0c<c<0FUYJ069RHP1CDe<0TY:B03Xj>P0T92@0?Shn05EE
E@1SHf<0Fe]K09RHV01LG5`0:b/[03Lg=`1MGEd0G5aL05]KF`2LW9`0Hf=S02DU9@1CDe<0IfMW04U9
B@2RXZ80Ti>C02TY:@0`<300NGUi06MWI`1ZJVX0P82003Lg=`1PH600bLW906ATI01mOGd0RXZ:02d]
;@0m?Cd0J6QX09fMW@0m?Cd0GEeM05QHF00g=cL0;Rh^05=CD`2n_[h0Fe]K059BDP29RHT0?Shn02h^
;P1MGEd0SHf=03hn?P1IFET0CTi>02LW9`0n?Sh0Fe]K06m_K`1EEED0KFe]02PX:00Z:RX0Bd];07Ee
M@1KFe/0DE5A05eMG@809bLW01`0LW9b08J6QP13@d<0B4Q804E5A@0X:2P0E5AD0;2`/010@4009bLW
059BDP12@T80D51@09VIV@1[Jf/0<C4a06e]K@19BDT0GUiN0;Vi^@2LW9`0:b/[034a<@1bLW80Cdm?
07EeM@2/[:`0@4100P1JFUX0b@1EEED0QXJ60;6a/@0f=SH0>SXj07MgM`20P800JFUY09jNWP0k>c/0
8B4Q04Q8B01iNGT0<c<c09:BTP2HV9P0>SXj05]KF`1hN7P0J6QX08B4Q02GUiL0;bl_030`<01[Jf/0
ZJVY05iNGP1QHF40Lg=c030`<01BDU80H61P0:>SX`1HF5P0I6AT05aLG00n?Sh0E5AD07QhN01dM7@0
AdM707IfMP0i>CT0<30`04I6AP1gMgL0EeMG034a<@1ADE40?3`l04Q8B01UIFD0WYjN05ADE00K6a/0
>SXj04I6AP19BDT0G5aL08:2PP0j>SX0<30`04e=C@16ATH0EUIF065QH@2DU9@0A4A403lo?`19BDT0
HV9R04i>CP1jNWX0S8b<02/[:`0I6AT0DE5A06QXJ01?Cdl0K6a/08V9R@0X:2P06QXJ05]KF`27QhL0
>CTi075aL@1bLW80J6QX04i>CP1HF5P0MgMg07]kN`1ZJVX0CDe=04];B`1QHF40E5AD04];B`1?Cdl0
KFe]06UYJ@1`L700S8b<0:VYZ@2FUYH0IFEU04m?C`1UIFD0=CDe03@d=00];Bd0Cdm?04e=C@1<C4`0
BDU906EUI@0n?Sh0CDe=03/k>`1IFET0BDU905=CD`1BDU80JVYZ05MGE`1PH600E5AD04Y:BP1NGUh0
DU9B05]KF`1FEUH0BTY:065QH@1`L700KFe]04e=C@1:BTX0EeMG09bLW017AdL0?Shn04Y:BP0o?cl0
CDe=01hN7P0e=CD0@d=30492@P1lO7`0:RXZ03Ph>01@D500:RXZ04e=C@17AdL0B4Q8055AD@1FEUH0
Jf][0::RXP1^KVh0Bd];059BDP1OGel0Q8B407moO`11@D40K6a/07IfMP19BDT0ADE504m?C`1YJFT0
M7Ad03hn?P0h>3P0?Shn055AD@0];Bd0?3`l04Y:BP1=CDd0=CDe02/[:`0a<C40BDU90410@00i>CT0
;Rh^04m?C`0e=CD0>SXj0410@01/K6`0?Shn0410@00S8b<0Bd];03lo?`0203/k>`1N04A4A011@D40
DU9B05ADE022PX80GEeM05MGE`1HF5P0DE5A04Q8B01XJ6P0MGEe03Xj>P1BDU80I6AT06QXJ01[Jf/0
EUIF04I6AP0o?cl0B4Q802/[:`13@d<0<C4a07inOP1bLW80XJ6Q08F5Q@19BDT0EEEE034a<@0_;bl0
JFUY03De=@1ZJVX0ZZZZ055AD@18B4P0=CDe07MgM`0j>SX0?3`l0492@P1/K6`0U9BD071`L02OWil0
[:b/0;Jf]P2m_Kd0QXJ607moO`1iNGT0Ogmo05ADE025QHD0NGUi07moO`1CDe<0B4Q806QXJ02:RXX0
][Jf06EUI@1SHf<0K6a/059BDP1UIFD0DE5A06i^KP1XJ6P0Bd];05mOG`1EEED0GUiN05QHF01JFUX0
Xj>S05EEE@1CDe<0Kfm_05MGE`1?Cdl0JVYZ04e=C@1SHf<0Kfm_09JFUP1JFUX0SXj>07MgM`1;Bd/0
C4a<034a<@80Bd];06/0?3`l09RHV02`/;00WIfM06UYJ@1BDU80JVYZ04a<C01`L700EUIF02XZ:P1>
CTh0?clo05YJFP1?Cdl0GemO06ATI013@d<0D51@05QHF00h>3P0ADE505ADE00/;2`0Fe]K04A4A01B
DU80?Shn04=3@`0m?Cd0BTY:05YJFP0h>3P0Bd];02l_;`0n?Sh0LW9b06IVIP10@400MgMg075aL@12
@T80CTi>04Q8B01dM7@0DE5A04A4A01DE5@092@T03`l?00N7Qh0Cdm?034a<@1<C4`0DE5A05aLG017
AdL0DE5A05eMG@1TI6@0EUIF04m?C`12@T80Bd];04I6AP0f=SH0>SXj051@D02HV9P0GemO096AT@1H
F5P0L71`05aLG01SHf<0ADE507=cL`0j>SX0Hf=S05]KF`1RHV80Rh^;04A4A01lO7`0F5QH0492@P1S
Hf<0AdM704Q8B01EEED0CTi>07IfMP0o?cl0HF5Q06QXJ00a<C40E5AD05iNGP2>SXh0E5AD05YJFP1_
Kfl0F5QH06ATI01DE5@0J6QX096AT@02ooooo`0001d0DU9B0:>SX`1XJ6P0Lg=c04=3@`17AdL0LG5a
08N7Q`1IFET0IfMW02XZ:P19BDT0Ti>C07UiN@0c<c<0LG5a03Xj>P0_;bl0S8b<09JFUP0[:b/0>SXj
04U9B@12@T80EUIF09BDU011@D407QhN04A4A0020492@P3o07EeM@1jNWX08B4Q04=3@`1FEUH0UIFE
065QH@2NWYh0NWYj01DE5@11@D40JFUY05eMG@1?Cdl0YJFU02XZ:P0=3@d0?clo07QhN01@D500Jf][
08j>SP0Y:BT06QXJ051@D02NWYh0AdM7096AT@0d=3@0>3Ph03Xj>P1BDU80=cLg05IFEP1<C4`04a<C
02d];@1MGEd0N7Qh0410@012@T80A4A401hN7P18B4P0Kfm_05EEE@0];Bd0HF5Q038b<P0a<C40G5aL
07QhN01HF5P0<C4a04A4A00Z:RX0FEUI07AdM02NWYh0=cLg02/[:`12@T80>c/k05=CD`2DU9@0AdM7
01DE5@0`<300<S8b03`l?01;Bd/0XZ:R05mOG`0R8R80:b/[04A4A011@D40QXJ6096AT@0H61P0?clo
07emO@1JFUX0B4Q80:^[Z`16ATH06a/K0492@P1_Kfl0>CTi07AdM025QHD04A4A03Ph>01dM7@0PH61
04A4A02QXJ40QHF502<S8`13@d<0OWin07emO@19BDT0LG5a06=SH`0S8b<0ATI607=cL`22PX80B4Q8
079bLP1=CDd07AdM04I6AP1FEUH0TY:B04];B`1UIFD0A4A401lO7`12@T80OGem0451@@17AdL0GemO
02@T900_;bl0HV9R02LW9`1=CDd0C4a<059BDP1SHf<0O7al03`l?00g=cL0Q8B4061PH01>CTh0UiNG
09fMW@0l?3`0=SHf04M7A`1dM7@0EEEE071`L02][Jd0>SXj02`/;012@T80H61P04U9B@22PX80QhN7
02XZ:P0m?Cd0EEEE04Y:BP1SHf<0^[Zj05QHF00O7al0<C4a06][J`1UIFD0VIVI08^;R`0];Bd08B4Q
03Xj>P1oOgl0GUiN07inOP1>CTh0:BTY05]KF`1NGUh0Jf][0492@P1/K6`09bLW02h^;P23Ph<0Xj>S
04E5A@2FUYH0CTi>02DU9@0c<c<0JVYZ03hn?P13@d<0HV9R02@T900h>3P0EEEE04E5A@1BDU80BTY:
01lO7`19BDT0GUiN065QH@1KFe/0L71`02LW9`0m?Cd0^;Rh08:2PP10@400Hf=S04Q8B00V9RH0De=C
0:>SX`1GEeL0BTY:061PH00k>c/0SHf=0;Fe]@1bLW80;2`/05EEE@1LG5`0EEEE07alO02YZJT0B4Q8
04=3@`1CDe<0LW9b0820P021PH40R8R8034a<@11@D40CDe=07]kN`1SHf<0][Jf04Y:BP0`<300?Cdm
05=CD`1WIfL0H61P08B4Q01ZJVX08B4Q04Y:BP23Ph<0MgMg000[05ADE01aLG40H61P01dM7@16ATH0
I6AT05mOG`1DE5@0QXJ6038b<P0O7al0ATI608>3P`1bLW80IfMW07AdM00[:b/0=3@d05IFEP21PH40
R8R80410@02KVi/0<c<c020P800b<S80MWIf071`L00[:b/0HV9R02`/;00M7Ad0=3@d06e]K@1`L700
CTi>0492@P1LG5`0E5AD07]kN`1=CDd0IVIV08b<S00205]KF`0D055AD@2BTY80QXJ608>3P`2VYZH0
^k^k0:FUY@1bLW80EEEE065QH@0k>c/0Cdm?04M7A`1:BTX0ATI606EUI@1PH600LG5a04U9B@1oOgl2
07QhN00;05EEE@1]KFd0LW9b08b<S01gMgL0GUiN07MgM`1FEUH0H61P04A4A013@d<00P1;Bd/0201K
Fe/0>c/k04E5A@1CDe<0C4a<04M7A`1:BTX0@d=30P18B4P0IP0j>SX0Bd];02/[:`10@400?Shn04E5
A@1TI6@0;2`/02LW9`1GEeL0?clo08J6QP1CDe<0<30`05UIF@1]KFd0FEUI069RHP1FEUH0MGEe08j>
SP1aLG40Fe]K065QH@19BDT0?clo04e=C@0b<S80:b/[055AD@0o?cl0>c/k04];B`0_;bl0=cLg03`l
?00[:b/0>SXj03dm?@16ATH0=3@d02PX:00W9bL0@T9202l_;`0a<C409bLW0451@@0a<C40;Bd]02PX
:00b<S80:b/[04A4A00O7al0Cdm?04I6AP17AdL0E5AD04A4A00k>c/0EUIF05QHF02@T900BTY:05AD
E01BDU80KFe]03Xj>P1JFUX0G5aL02XZ:P1iNGT0Fe]K0410@01JFUX0Cdm?05]KF`0o?cl0GemO03Ph
>01MGEd0=SHf06a/K01SHf<0KFe]05iNGP1MGEd0I6AT055AD@16ATH0ZZZZ02HV9P2CTi<0_;bl05UI
F@1PH600?Cdm04E5A@0O7al0=3@d04Y:BP80IVIV01h0M7Ad06a/K028R8P0emOG0:n_[`24Q8@0M7Ad
07UiN@1gMgL0I6AT08R8R02RXZ80P82006UYJ@2IVIT0B4Q806EUI@28R8P0@41007UiN@1aLG40?Cdm
06a/K00f=SH0QhN703hn?P1>CTh0QHF50492@P1ADE4203dm?@0A07alO00`<300Bd];061PH00Z:RX0
DE5A05EEE@1BDU80EeMG05IFEP2=SHd0ADE507inOP1YJFT0ADE504a<C01NGUh00P1DE5@0J`1?Cdl0
OGem08n?S`2DU9@0TY:B07AdM016ATH0Hf=S04a<C011@D40BDU906ATI017AdL0GUiN06YZJP1gMgL0
W9bL04e=C@10@400B4Q802<S8`1EEED0Kfm_03@d=01BDU80Bd];04m?C`17AdL0C4a<04Y:BP1ADE40
IVIV04a<C01:BTX0?Shn04e=C@1HF5P0E5AD03/k>`1BDU80FEUI05aLG02@T900?clo055AD@0k>c/0
?clo06m_K`0[:b/0?3`l04Q8B01ADE40>3Ph04M7A`13@d<0FEUI04=3@`19BDT0?Cdm04M7A`0e=CD0
@D5103Xj>P0/;2`0EEEE05UIF@0`<300GEeM08n?S`0m?Cd0Bd];04E5A@0j>SX0=cLg05QHF01CDe<0
IVIV05=CD`26QXH0Jf][08^;R`2n_[h0MGEe08^;R`14A4@0L71`0::RXP1WIfL0Cdm?05ADE010@400
Bd];03`l?011@D40HV9R04M7A`2ATI40KVi^0;Ng]`1dM7@0GUiN071`L01dM7@0HV9R05EEE@1QHF40
DU9B00;ooooo00002P1?Cdl0Q8B406UYJ@2WYjL0A4A403Ph>01IFET0Ph>3079bLP1nOWh203Lg=`3T
04e=C@2<S8`0IVIV0;Vi^@0`<3009RHV04U9B@1gMgL0JVYZ07MgM`1IFET0:b/[02h^;P1;Bd/0Lg=c
04I6AP23Ph<0:2PX02`/;01?Cdl0G5aL04I6AP1ADE40Lg=c01dM7@0m?Cd0GemO08F5Q@1@D500IFEU
06IVIP0P8200>c/k07]kN`26QXH0<C4a04E5A@1:BTX0:RXZ03Lg=`1gMgL0AdM702`/;011@D40;bl_
03De=@1gMgL0RXZ:02TY:@0i>CT0@T9204U9B@1eMGD0YjNW03Ph>00P8200DU9B07=cL`1RHV80UiNG
07]kN`0N7Qh0:2PX05MGE`1JFUX0F5QH0:f][@2;Rh/08R8R034a<@1ZJVX0PX:208B4Q02_[jl071`L
03Hf=P1WIfL0PH6106MWI`1UIFD0EEEE00l?3`19BDT0SXj>08J6QP13@d<0PX:20492@P0^;Rh0<c<c
05MGE`20P800Fe]K0::RXP0Q8B40:BTY04Q8B01MGEd0BDU90451@@12@T806ATI02l_;`1jNWX0IVIV
02XZ:P1;Bd/0<c<c02h^;P0l?3`0NGUi04A4A00L71`0AdM703dm?@0c<c<0Fe]K07]kN`0V9RH09BDU
04a<C00g=cL0<30`06e]K@2=SHd0;bl_02h^;P1<C4`0EUIF03Ph>01gMgL0Ti>C02PX:00a<C40EEEE
07QhN01MGEd0VYZJ07EeM@0O7al0>3Ph04a<C01CDe<0Lg=c0:ZZZP0T92@0>3Ph06][J`1CDe<0YjNW
06IVIP0];Bd0B4Q80820P01cLg<0JVYZ08B4Q01HF5P08B4Q069RHP2a/K40Hf=S07AdM02@T900DE5A
03Xj>P1UIFD0M7Ad06][J`1UIFD0Ti>C03Ti>@1:BTX0IfMW09^KV`1DE5@0D51@08Z:RP0O7al0?Cdm
06EUI@2d];@0MgMg0861P@1[Jf/08b<S04m?C`2h^;P0[Zj^03Ph>01VIVH0H61P020P801NGUh0N7Qh
02<S8`14A4@0EEEE03`l?01[Jf/0WYjN04Q8B00Y:BT0B4Q804A4A010@400U9BD09ZJVP0Z:RX0ADE5
04m?C`1MGEd0KFe]0::RXP0m?Cd0>CTi05ADE018B4P0VIVI0:FUY@0a<C40>3Ph05QHF01JFUX0O7al
09bLW00`<3008B4Q0P1jNWX0E`1bLW80Y:BT05mOG`0J6QX0@410071`L01@D500NGUi07YjNP0`<300
<S8b06IVIP2NWYh0IFEU07inOP1JFUX0?Cdm05QHF02BTY80FEUI07=cL`1mOGd0A4A4055AD@1VIVH0
QXJ604M7A`1TI6@0AdM7034a<@1@D500M7Ad08V9R@1:BTX0O7al08F5Q@0Z:RX0>CTi04a<C01VIVH0
@d=306=SH`1TI6@09RHV038b<P1^KVh0Fe]K028R8P16ATH0@T9203<c<`1PH600]kNg05]KF`0O7al0
;bl_05ADE00o?cl0FUYJ0:f][@1]KFd08R8R03dm?@17AdL0=CDe02XZ:P2_[jl0MgMg01LG5`0j>SX0
ATI603`l?019BDT0Xj>S06MWI`0O7al0A4A4071`L01_Kfl0L71`05UIF@1QHF40IVIV075aL@1VIVH0
JFUY09NGU`0204m?C`0Q04i>CP1UIFD0SHf=06QXJ01]KFd0KVi^07QhN01RHV80F5QH051@D013@d<0
Bd];03dm?@19BDT0CTi>07IfMP1XJ6P0GUiN04a<C01TI6@0S8b<05QHF00c<c<0BDU905ADE01cLg<0
CTi>055AD@1IFET0IFEU05=CD`0l?3`0C4a<0080AdM702h0CTi>04E5A@1FEUH0DU9B04m?C`1@D500
F5QH04e=C@1BDU80De=C03De=@1CDe<0ATI604U9B@1<C4`0AdM706UYJ@14A4@0DE5A06a/K013@d<0
C4a<059BDP1=CDd0GEeM05UIF@1WIfL0]KFe07=cL`0b<S80>SXj065QH@1/K6`0P82004Q8B00o?cl0
KFe]0492@P1:BTX0K6a/04Q8B01SHf<0F5QH03/k>`1:BTX0C4a<0P16ATH0C01?Cdl0BDU903Lg=`16
ATH0@D5104m?C`0d=3@0B4Q802LW9`1>CTh0<30`03Ph>00c<c<0BDU9034a<@19BDT06ATI059BDP18
B4P0C4a<03Hf=P10@400>3Ph05YJFP1BDU80SXj>04m?C`1DE5@0GEeM04Y:BP1@D500Lg=c07emO@1C
De<0Ph>3065QH@1;Bd/0EEEE05UIF@1_Kfl0<30`04];B`0k>c/0QhN702l_;`1_Kfl0GUiN0:j^[P2P
X:00AdM705ADE00^;Rh0@D51096AT@0b<S80M7Ad0:>SX`1DE5@0SXj>04e=C@1XJ6P0?3`l0410@01I
FET0DU9B0861P@1BDU80U9BD05eMG@2=SHd0E5AD0861P@1RHV80D51@06ATI00l?3`206m_K`2B06IV
IP1:BTX0GemO06YZJP1?Cdl0BDU904E5A@16ATH0@T9204M7A`1GEeL0@41006QXJ010@400@d=305QH
F01PH600Q8B405iNGP1@D500NWYj059BDP19BDT0IfMW04a<C01UIFD0HF5Q05=CD`1XJ6P0KFe]09>C
T`1BDU80R8R805QHF011@D40GemO04I6AP1>CTh0FEUI09>CT`33`l<0/k>c07IfMP1hN7P0FEUI04M7
A`19BDT0Hf=S04U9B@0h>3P0Ng]k02`/;01=CDd0B4Q807=cL`2FUYH0ATI605EEE@1>CTh0<S8b04E5
A@1KFe/0<c<c06=SH`0j>SX0C4a<05iNGP1>CTh0?Cdm03`l?01kNg/0ADE504];B`17AdL0Bd];05MG
E`1QHF40?3`l07QhN01OGel0@D51061PH00l?3`0KVi^03Xj>P1>CTh0G5aL0451@@1GEeL0?3`l05IF
EP16ATH0FUYJ0410@00m?Cd0GEeM059BDP15ADD0FUYJ04U9B@0o?cl0DU9B0451@@22PX80Cdm?01LG
5`1MGEd0RHV905UIF@1_Kfl0C4a<05IFEP17AdL0C4a<06IVIP2NWYh0JVYZ05IFEP12@T80EeMG07Ee
M@1LG5`0Shn?071`L014A4@0Jf][03hn?P1PH600Jf][065QH@2;Rh/0@T9205mOG`1FEUH0<S8b05YJ
FP1aLG40^k^k06EUI@1LG5`0OGem05iNGP1?Cdl0?clo04m?C`1KFe/2ooooo`000?l0KVi^075aL@1E
EED0N7Qh07=cL`1NGUh0GemO04A4A01JFUX0PX:204E5A@10@400Cdm?03Xj>P16ATH0Zj^[05YJFP0W
9bL0AdM703De=@0b<S80RHV907emO@0k>c/0:BTY0451@@0a<C40G5aL08F5Q@1[Jf/0820P03/k>`1D
E5@0J6QX06a/K02[Zj/0@D51018B4P15ADD0Lg=c03`l?02?Shl0WinO01DE5@0F5QH0A4A407EeM@15
ADD0MWIf0820P00Z:RX0EeMG06m_K`1@D500@d=307AdM00i>CT08B4Q0492@P1KFe/0?clo05EEE@0_
;bl07QhN04Y:BP1]KFd0I6AT04=3@`25QHD0E5AD02h^;P16ATH0RXZ:0410@014A4@0Hf=S02<S8`0`
<300B4Q807AdM00i>CT0Fe]K05IFEP0/;2`0BTY:05QHF012@T8061PH051@D00h>3P0=3@d09ZJVP2W
YjL0?clo02<S8`11@D407alO02/[:`1cLg<0EEEE01HF5P0a<C40;bl_055AD@1?Cdl0SXj>05mOG`0M
7Ad0@d=305IFEP1=CDd0UYJF08f=S@0E5AD08B4Q0492@P16ATH0Fe]K0:BTY01DE5@09BDU02l_;`10
@400LW9b05iNGP2JVYX07alO02@T900i>CT0Q8B4079bLP1ZJVX0QXJ6038b<P14A4@0?3`l05eMG@1Z
JVX0MgMg07inOP0O7al0ADE5055AD@1=CDd0FEUI0410@01dM7@0;bl_03Hf=P1KFe/0QXJ604e=C@1E
EED0B4Q801PH600k>c/0Cdm?06i^KP0b<S80I6AT02h^;P1]KFd0LG5a02LW9`1DE5@0?3`l03/k>`16
ATH0QhN705MGE`0a<C40@d=303`l?012@T80@41007alO01ZJVX071`L04Y:BP1BDU80@D5105ADE02W
YjL0K6a/02<S8`1;Bd/0OGem06YZJP1QHF40];Bd04A4A00K6a/0BTY:06m_K`1FEUH0ZJVY07alO00V
9RH0820P04];B`1lO7`0KVi^09:BTP1^KVh05ADE04=3@`1TI6@0De=C09jNWP2SXj<0>CTi02l_;`2C
Ti<0QXJ604];B`29RHT0<c<c02XZ:P0m?Cd0PX:205mOG`27QhL0MgMg01lO7`1EEED0OWin05EEE@1e
MGD0FEUI034a<@0c<c<0QXJ605eMG@1]KFd0@d=301dM7@15ADD0Jf][051@D01UIFD0Ph>30451@@0g
=cL0O7al0:FUY@12@T80GEeM05IFEP0k>c/0EeMG092@T01<C4`0EUIF05eMG@18B4P000`0EUIF09JF
UP2GUiL0@D5104U9B@1MGEd0G5aL07QhN02RXZ80J6QX02/[:`1QHF4205EEE@0m07inOP2NWYh0>c/k
030`<01YJFT0EeMG051@D01gMgL0]kNg038b<P0_;bl0A4A406][J`1ADE40MWIf08R8R00Y:BT0:RXZ
04A4A01UIFD0;bl_069RHP18B4P06ATI03Xj>P1NGUh0FEUI02TY:@15ADD0De=C03lo?`0W9bL0Fe]K
09:BTP0f=SH0DU9B069RHP0U9BD0820P04Y:BP1]KFd0<C4a05eMG@1BDU806a/K03Ph>01fMWH0XZ:R
04U9B@1UIFD0H61P07MgM`13@d<0A4A404i>CP1BDU80NWYj04m?C`1ZJVX0VYZJ06MWI`0204Q8B02H
09RHV02EUID0Shn?08b<S02OWil0QhN709:BTP1^KVh0GEeM03dm?@1?Cdl0DU9B04=3@`15ADD0Fe]K
061PH01MGEd0BDU906m_K`1UIFD0KFe]0451@@1SHf<0LG5a08R8R01PH600F5QH06e]K@1EEED0D51@
03Ti>@1;Bd/0BDU903Xj>P1CDe<0B4Q804e=C@18B4P0ATI605EEE@1JFUX0@T9203<c<`1?Cdl0@410
05=CD`0X:2P0820P03hn?P1>CTh0JFUY034a<@0Z:RX0ADE5038b<P1YJFT0Bd];03<c<`1?Cdl0E5AD
05iNGP1RHV80FEUI04I6AP1:BTX0IVIV051@D01PH600?3`l04Q8B01EEED08R8R02<S8`11@D40?Cdm
06e]K@0o?cl0=3@d0451@@1;Bd/0<S8b03lo?`1OGel0@D5103<c<`0b<S80BTY:051@D011@D40@T92
04=3@`1=CDd0?Shn03/k>`1@D500Fe]K03Xj>P11@D40<S8b065QH@1DE5@0EeMG04m?C`1IFET0DE5A
06ATI01fMWH0UiNG06ATI01LG5`0Jf][05eMG@1VIVH0LW9b06EUI@17AdL0Lg=c07QhN01JFUX0Cdm?
069RHP1QHF40ADE5059BDP0e=CD0Bd];02d];@25QHD0IfMW07emO@24Q8@0BDU905EEE@0`<30092@T
075aL@0E5AD0LW9b0;fm_@13@d<0Fe]K03lo?`23Ph<0CTi>04U9B@1OGel0Fe]K06EUI@1CDe<0MWIf
05YJFP2ATI4205EEE@0L04m?C`1NGUh0IfMW02h^;P22PX80TY:B05aLG01EEED0MWIf06EUI@2NWYh0
`l?3079bLP1WIfL0P82005MGE`1OGel0DE5A07]kN`1HF5P0E5AD07AdM01?Cdl0AdM703/k>`1LG5`0
JFUY03`l?080KFe]03H0De=C04a<C01[Jf/0Lg=c05UIF@1^KVh0VIVI05aLG02@T900KVi^05aLG01^
KVh0Fe]K04e=C@1GEeL0N7Qh05=CD`1ZJVX0?Shn07emO@1CDe<0BDU903De=@1NGUh0G5aL03dm?@1D
E5@0;Bd]07QhN01;Bd/0De=C09JFUP19BDT0GEeM04Y:BP0S8b<0Bd];05IFEP0V9RH0CDe=04A4A015
ADD0?clo03De=@0m?Cd0=CDe04A4A00a<C40?3`l03Ph>00m?Cd0DE5A05YJFP17AdL206IVIP1205aL
G01YJFT0>c/k05IFEP1=CDd0A4A4069RHP0Z:RX0?Cdm02d];@1NGUh0<S8b04i>CP1EEED0EUIF04I6
AP0b<S80FUYJ06YZJP1NGUh0GEeM03`l?013@d<0D51@05QHF00j>SX0ADE506UYJ@10@400Jf][07Ad
M01_Kfl0BDU904m?C`1KFe/0S8b<04a<C01LG5`0Bd];0861P@2i^KT0G5aL07=cL`0`<300Lg=c0:VY
Z@1NGUh0De=C03Xj>P0_;bl0@D51034a<@1RHV80G5aL034a<@1CDe<0B4Q808F5Q@16ATH0FUYJ05AD
E01>CTh0NWYj055AD@1CDe<0Ph>30_ooool0003K07QhN01nOWh0DE5A04m?C`1GEeL0K6a/08F5Q@11
@D40>3Ph069RHP1LG5`0IFEU075aL@0`<300:RXZ06EUI@1oOgl0MGEe0:FUY@2TY:@08B4Q04E5A@1n
OWh0I6AT06YZJP2GUiL0<30`03@d=01MGEd0TI6A04e=C@27QhL0HV9R024Q8@0i>CT0N7Qh09ZJVP1C
De<0U9BD05iNGP0^;Rh0=SHf07IfMP0l?3`0:b/[05mOG`0T92@05ADE02TY:@1OGel09BDU02XZ:P16
ATH03`l?02LW9`0m?Cd0I6AT02XZ:P0d=3@0>3Ph05EEE@2GUiL0Cdm?01LG5`0R8R80@D51034a<@1P
H600][Jf03Ph>00Y:BT0=3@d04E5A@0j>SX0K6a/0:j^[P0Q8B40<S8b04A4A01PH600CDe=09NGU`2d
];@06a/K030`<017AdL0EeMG051@D02KVi/0Ogmo02<S8`0b<S80RXZ:06QXJ01HF5P0MGEe02@T901;
Bd/0E5AD07inOP1:BTX0JVYZ07moO`0K6a/0>3Ph065QH@1PH600=cLg06QXJ01@D5006ATI0451@@23
Ph<0D51@05EEE@1ZJVX09BDU03dm?@1:BTX0MGEe03Ph>017AdL0G5aL018B4P12@T80/K6a08>3P`0a
<C40DU9B04Q8B00S8b<0AdM70:6QX@1[Jf/08B4Q03lo?`19BDT09RHV05=CD`2VYZH0K6a/01/K6`1=
CDd0AdM7059BDP1CDe<0^k^k07EeM@0K6a/0>3Ph04a<C01aLG40R8R805YJFP0O7al0<30`04=3@`16
ATH0Bd];071`L00d=3@0MGEe06ATI00m?Cd0Q8B409FEU@0O7al0CDe=06QXJ01jNWX0ZZZZ0:^[Z`1L
G5`071`L04e=C@1UIFD0KVi^04];B`2OWil0MWIf02DU9@1<C4`0DE5A07emO@1KFe/0NGUi04U9B@0^
;Rh0CDe=08R8R02CTi<0G5aL05YJFP0V9RH0<S8b05]KF`2IVIT0LG5a0410@01NGUh07AdM02`/;01O
Gel0S8b<0410@012@T80;Bd]02LW9`1:BTX0IFEU03@d=00`<300Fe]K02d];@1BDU80Y:BT061PH00/
;2`0CDe=0080>3Ph0:h0C4a<071`L00_;bl0:b/[04=3@`15ADD0TI6A08^;R`0d=3@0?3`l05=CD`1=
CDd0]KFe0:RXZ00Z:RX0;2`/04A4A00f=SH0JFUY0<[:bP1SHf<0:BTY05UIF@2LW9`0DU9B09nOW`2K
Vi/0<S8b03@d=01dM7@0KFe]09jNWP2a/K40<c<c03Ph>017AdL0UiNG07QhN02NWYh0UiNG03Lg=`14
A4@0Jf][0:f][@1ZJVX0`<3007UiN@0];Bd0F5QH07IfMP1KFe/0DU9B08^;R`12@T80=CDe04e=C@1N
GUh0E5AD05eMG@2:RXX0B4Q803lo?`1GEeL0Q8B404e=C@0`<300R8R804E5A@0m?Cd0IVIV07emO@17
AdL0>SXj07emO@1WIfL0CDe=061PH01cLg<0=cLg02@T900n?Sh0Bd];0410@01XJ6P0Ph>302LW9`0P
8200>3Ph04];B`0j>SX0TI6A07MgM`0Q8B407QhN04E5A@1_Kfl0CDe=06EUI@1TI6@0M7Ad05MGE`17
AdL0B4Q804m?C`25QHD0Cdm?06QXJ02=SHd0IVIV04U9B@1;Bd/0NWYj09JFUP1iNGT0`<300>7Qh@2H
V9P0IFEU04a<C01UIFD0FUYJ03lo?`0f=SH0DE5A05QHF01]KFd0M7Ad075aL@1EEED0PH6107IfMP1U
IFD0KFe]08Z:RP23Ph<0MGEe07alO023Ph<0K6a/05mOG`1EEED0Bd];04e=C@1IFET0AdM705iNGP16
ATH0FEUI05YJFP1@D500CDe=04Y:BP11@D40=cLg04M7A`0];Bd0DU9B02/[:`0X:2P0BTY:04U9B@1Z
JVX0Bd];02/[:`1LG5`0:2PX04U9B@1?Cdl0;Bd]05eMG@1SHf<0JVYZ07moO`1cLg<2059BDP0607Yj
NP1BDU80OGem05QHF01BDU80HF5Q0P0o?cl05P1BDU80?Shn065QH@1?Cdl0:RXZ04E5A@1;Bd/0;Bd]
04U9B@1?Cdl0=SHf02TY:@0d=3@0;bl_04=3@`0_;bl0ATI603Hf=P1@D500BTY:04E5A@0i>CT204A4
A028051@D00[:b/0FUYJ04M7A`10@400DE5A0410@00a<C40BDU905QHF02JVYX0Bd];04E5A@1=CDd0
IFEU04A4A016ATH0Bd];04A4A02][Jd0FEUI04=3@`1OGel0EUIF06QXJ010@400EEEE04m?C`1GEeL0
DU9B08B4Q01lO7`0/[:b09bLW01aLG40PH6105]KF`17AdL0OWin04=3@`1IFET0QhN7065QH@1VIVH0
<C4a05YJFP0^;Rh0=3@d079bLP1dM7@0BDU905ADE01eMGD0G5aL0<71`@1oOgl0EUIF03De=@0^;Rh0
BTY:01lO7`1CDe<0BTY:04I6AP1RHV80OWin04Y:BP1NGUh0G5aL04A4A02NWYh0PH6103dm?@1]KFd0
DU9B07alO011@D40BTY:05EEE@0k>c/0FEUI04U9B@1aLG40TY:B03Ph>012@T80C4a<03Xj>P19BDT0
AdM704Q8B01BDU80IfMW07alO01fMWH0UIFE061PH00j>SX0ADE507]kN`21PH40I6AT07MgM`1?Cdl0
G5aL04E5A@1ADE40@41006IVIP1TI6@0BDU90492@P0`<300I6AT01`L701:BTX0<c<c03lo?`1aLG40
?Cdm051@D00k>c/09RHV04a<C01IFET0<c<c055AD@0o?cl0DE5A05IFEP17AdL0@d=303`l?01JFUX0
?clo04U9B@80BTY:04L0LG5a07IfMP1;Bd/0J6QX05IFEP1aLG40RXZ:04i>CP1KFe/0ADE504=3@`1M
GEd0>SXj04];B`0j>SX0DU9B03De=@0l?3`0<S8b03/k>`12@T80DU9B04Q8B01;Bd/0?Cdm03<c<`0V
9RH0;bl_05UIF@1@D500?Shn07IfMP22PX80Bd];04a<C019BDT0=cLg03hn?P1>CTh0NGUi09FEU@1E
EED0TY:B051@D01CDe<0Lg=c05MGE`1XJ6P0AdM704E5A@1RHV80@T9206MWI`1KFe/0?clo04];B`0I
6AT0<S8b03Xj>P0V9RH0S8b<05EEE@2DU9@0@T9204M7A`22PX80MGEe04i>CP1?Cdl0KVi^05MGE`02
ooooo`000<<0EEEE06YZJP1OGel0QhN703lo?`1>CTh0Hf=S06a/K01IFET0OWin038b<P10@400EEEE
05eMG@1=CDd0MGEe038b<P0o?cl0Lg=c07UiN@1FEUH0De=C06][J`0^;Rh0>3Ph09VIV@1KFe/0;Bd]
05aLG00d=3@0;bl_05]KF`2;Rh/0:b/[038b<P1/K6`0@41002PX:024Q8@0E5AD02TY:@0j>SX0DE5A
03/k>`1?Cdl0TY:B04Y:BP0L71`0@d=305=CD`14A4@0GemO09fMW@0Q8B40=SHf04e=C@1?Cdl0BDU9
07AdM00j>SX05QHF0492@P17AdL0=CDe06a/K01bLW806a/K03<c<`1?Cdl0Bd];051@D025QHD0MWIf
01XJ6P0l?3`0K6a/06ATI014A4@0PX:205UIF@0Q8B40C4a<08N7Q`19BDT0E5AD06QXJ00N7Qh0@T92
05MGE`1iNGT0@T9204E5A@1BDU80;Bd]05UIF@2>SXh0IFEU02l_;`1>CTh0>c/k03@d=01>CTh0Ti>C
0492@P0J6QX0;bl_02XZ:P0T92@0R8R807AdM00E5AD0=3@d04Y:BP10@400IFEU0:BTY01:BTX05ADE
0451@@1MGEd0@d=3069RHP1jNWX08B4Q01lO7`1DE5@0MGEe06EUI@2>SXh0Jf][01PH600X:2P0IVIV
0::RXP1=CDd0KFe]05UIF@0L71`0@T9207MgM`1nOWh0?Shn05]KF`0m?Cd0;Rh^03/k>`1nOWh0b/[:
05aLG02:RXX0<c<c020P801KFe/0LW9b03Lg=`1HF5P0GUiN02DU9@0i>CT0JFUY03Hf=P1eMGD0=CDe
034a<@1IFET0N7Qh051@D00m?Cd0LW9b02TY:@16ATH0/k>c0;Fe]@1DE5@0:RXZ05=CD`1BDU80;2`/
07=cL`2f][H0G5aL0492@P1XJ6P0?Shn05QHF02EUID0Ogmo02LW9`1:BTX0De=C06ATI01/K6`0S8b<
03Ph>00i>CT00P1ADE40QP13@d<0K6a/08^;R`0V9RH09bLW05mOG`1XJ6P0Cdm?09^KV`19BDT05aLG
04A4A01XJ6P0LG5a06YZJP2XZ:P0<c<c02<S8`1hN7P0YjNW06a/K02PX:00>SXj02TY:@13@d<0Ogmo
07inOP1[Jf/0L71`01LG5`16ATH0WIfM07EeM@1UIFD0GUiN03Xj>P0g=cL0UiNG07QhN01LG5`0HV9R
02HV9P1>CTh0R8R80::RXP1WIfL0PH6103Xj>P13@d<0E5AD0:>SX`1bLW80FEUI05=CD`0a<C40>CTi
07emO@1cLg<0>3Ph04m?C`15ADD0>CTi06a/K02h^;P0B4Q803Xj>P16ATH0@41004A4A02`/;00W9bL
02LW9`14A4@0F5QH03/k>`19BDT0_Kfm09ZJVP0^;Rh0@T9206EUI@18B4P0EEEE0:VYZ@1QHF408b<S
04e=C@1XJ6P0EEEE05QHF035aLD0H61P02<S8`14A4@0FUYJ05UIF@1ZJVX0bl_;05UIF@0d=3@0>SXj
05QHF01SHf<0S8b<08Z:RP12@T80AdM705QHF01iNGT0KVi^04M7A`1/K6`0<30`02HV9P1<C4`0NGUi
04Q8B01;Bd/0N7Qh030`<00];Bd0FEUI06ATI023Ph<0JFUY03lo?`1EEED0EUIF09NGU`1kNg/0GUiN
06UYJ@17AdL0M7Ad0P1aLG40o`2CTi<0GEeM04E5A@0n?Sh0Cdm?05]KF`1ADE40>c/k04A4A01:BTX0
<30`05ADE01KFe/0JFUY05EEE@1KFe/0De=C05iNGP1bLW80EUIF034a<@1IFET0LW9b06m_K`1<C4`0
ATI605aLG01JFUX0AdM702h^;P16ATH0Bd];05MGE`1KFe/0Bd];04m?C`1]KFd0L71`059BDP1IFET0
C4a<03dm?@1IFET0<S8b05ADE00T92@0?clo05QHF01EEED0KVi^03@d=00`<300GemO03/k>`1IFET0
F5QH03Ph>01OGel0IVIV07moO`2@T900MWIf04E5A@1>CTh0J6QX05IFEP1fMWH0>3Ph04Y:BP1=CDd0
<C4a04M7A`1>CTh0?Shn05iNGP1PH600FEUI04U9B@18B4P0;bl_0492@P1>CTh0>CTi02`/;00c<c<0
=SHf04e=C@0d=3@0DU9B03/k>`1JFUX0ATI604=3@`12@T80C4a<04E5A@1JFUX0@D5105iNGP1:BTX0
Bd];04M7A`0j>SX0?3`l055AD@18B4P0TY:B04U9B@1ADE40HV9R06QXJ01NGUh0IVIV06i^KP13@d<0
L71`05QHF019BDT0C4a<06e]K@1jNWX0=3@d04e=C@0k>c/0Kfm_03Ph>01WIfL0C4a<0;Rh^02LW9`0
ATI605MGE`0h>3P0<c<c07]kN`0d=3@0J6QX08b<S01VIVH0Ogmo05MGE`1VIVH0@d=302DU9@1EEED0
E5AD055AD@1LG5`0TI6A06][J`2j^[X0GemO06i^KP0n?Sh0?Cdm059BDP0[:b/0GemO05IFEP1;Bd/0
@D5104e=C@0o?cl0PH610:f][@0g=cL0C4a<04];B`0m?Cd0HV9R03hn?P1jNWX0@41003Ph>01JFUX0
B4Q808j>SP13@d<0ADE504e=C@0T92@0BTY:05IFEP0j>SX0IFEU03/k>`1?Cdl0@T92071`L01ZJVX0
@41007UiN@0o?cl0>SXj0410@00b<S80>3Ph04];B`1<C4`0J6QX04];B`1_Kfl0VIVI03hn?P0c<c<0
>CTi04U9B@13@d<0?Cdm059BDP0m?Cd0EUIF04=3@`1HF5P0RXZ:06YZJP1IFET0C4a<01dM7@1WIfL0
G5aL03hn?P17AdL0@d=305ADE01ADE40BDU904m?C`19BDT0GEeM03/k>`1;Bd/0DU9B03Hf=P13@d<0
@T9203@d=02>SXh0GemO04Q8B01EEED0>SXj08:2PP0h>3P0ATI6065QH@18B4P0FUYJ04i>CP1mOGd0
Fe]K05UIF@1PH600EeMG06EUI@00<P16ATH0CTi>05mOG`1:BTX0Bd];02HV9P13@d<0QXJ604E5A@0R
8R80G5aL055AD@1[Jf/0Hf=S065QH@1[Jf/0C4a<0492@P16ATH0JVYZ06ATI01=CDd0ATI60:2PX02U
YJD0Hf=S09>CT`1HF5P0AdM707QhN00i>CT0I6AT04E5A@1DE5@0LG5a03Hf=P1JFUX0D51@02`/;00o
?cl0CDe=0:n_[`13@d<0BDU906YZJP1OGel0EUIF071`L01dM7@0Fe]K0_ooool0002c079bLP1UIFD0
K6a/09bLW01RHV80C4a<05IFEP1IFET0PX:209bLW00_;bl0:2PX04U9B@18B4P0OGem0:f][@0_;bl0
8B4Q038b<P1@D500@41009>CT`2BTY80:2PX01@D5016ATH0M7Ad05mOG`2c/k<0?Cdm02TY:@0a<C40
QXJ606UYJ@28R8P0][Jf02XZ:P0o?cl0>CTi0492@P1KFe/0Q8B407UiN@0I6AT0<S8b02LW9`1ADE40
@410096AT@1FEUH09RHV02XZ:P15ADD0?clo05=CD`1kNg/0B4Q803Hf=P1_Kfl0IVIV03Lg=`1ADE40
?clo028R8P1OGel0XZ:R04e=C@12@T80GUiN02/[:`0b<S80MgMg075aL@0V9RH0:RXZ04Y:BP0/;2`0
>c/k0:2PX01nOWh07AdM03<c<`1?Cdl0EEEE075aL@2BTY809RHV028R8P0h>3P0GEeM04i>CP21PH40
MgMg01hN7P0a<C40EUIF075aL@1QHF40V9RH03Ph>00P8200AdM706e]K@1OGel0IFEU08^;R`0H61P0
5aLG02l_;`1`L700BDU905aLG01UIFD05QHF02/[:`1LG5`0F5QH038b<P1>CTh0;Rh^024Q8@1?Cdl0
K6a/04I6AP12@T80I6AT02DU9@0e=CD0A4A408V9R@19BDT0=3@d05UIF@0k>c/0>3Ph04e=C@1_Kfl0
;Rh^02d];@1ADE40B4Q8061PH01GEeL0GEeM01lO7`0b<S80EEEE04E5A@1JFUX0];Bd06MWI`0N7Qh0
=cLg055AD@19BDT0MGEe09bLW00J6QX0@41006MWI`1CDe<0YZJV05mOG`0K6a/0?clo09>CT`1SHf<0
HV9R0=;BdP1:BTX08R8R05YJFP2:RXX0IfMW06UYJ@2DU9@0C4a<04A4A01=CDd00P1eMGD0b`1MGEd0
Ti>C03Ti>@0i>CT0Fe]K08n?S`1FEUH0GEeM0820P00P8200=SHf06i^KP2?Shl0C4a<0::RXP1NGUh0
@D510492@P1eMGD0Fe]K051@D01^KVh0:RXZ03Lg=`1EEED0GUiN03<c<`1LG5`0>SXj034a<@1ADE40
PX:206i^KP0o?cl0E5AD03De=@1FEUH0O7al08Z:RP11@D40EeMG05UIF@1GEeL0LW9b07YjNP0a<C40
>c/k03Hf=P1=CDd0H61P06][J`0];Bd0=CDe0451@@1DE5@0HF5Q08^;R`0];Bd0:b/[06=SH`1HF5P0
JFUY0<G5a@1`L700>SXj04=3@`1aLG40IFEU08R8R020P800>3Ph04Y:BP18B4P0S8b<05mOG`2_[jl0
Jf][0451@@17AdL0EeMG05eMG@1`L700[:b/03Xj>P16ATH0CTi>08f=S@1=CDd0K6a/069RHP0W9bL0
>CTi04a<C02UYJD0GUiN065QH@1`L700>3Ph03dm?@1>CTh0N7Qh03/k>`1kNg/0NGUi030`<00^;Rh0
MGEe09JFUP0d=3@0EUIF038b<P0Q8B40>CTi07UiN@2:RXX0>3Ph0492@P1GEeL0820P03Lg=`2HV9P0
Cdm?024Q8@0j>SX0CTi>02l_;`1@D500QhN704Q8B00P8200>CTi03Ph>011@D40ADE50820P012@T80
9BDU03`l?01kNg/0GemO06YZJP18B4P0EeMG05EEE@18B4P0:b/[055AD@2:RXX0Bd];03`l?00o?cl0
OGem08j>SP26QXH0V9RH0820P02<S8`0KVi^055AD@1MGEd0=CDe04Y:BP0[:b/0@d=303/k>`1`L700
J6QX055AD@1DE5@0O7al09NGU`1_Kfl0Bd];05eMG@1/K6`0JFUY06][J`1QHF40EeMG04i>CP1<C4`0
<S8b0410@016ATH0?3`l04E5A@18B4P0BDU903<c<`0[:b/0BDU905YJFP14A4@0Bd];04I6AP0c<c<0
ADE502/[:`0e=CD0?Cdm04m?C`1HF5P0=cLg0080HV9R01/09bLW04Y:BP1GEeL0EEEE05MGE`1PH600
GEeM08:2PP1UIFD0A4A403lo?`1LG5`0HV9R06a/K015ADD0BDU9055AD@0K6a/09RHV04];B`0a<C40
Fe]K03dm?@0];Bd0<c<c03Xj>P10@4000P14A4@0200m?Cd0CDe=02/[:`0o?cl0CDe=03lo?`0j>SX0
=CDe0P17AdL0300Y:BT0>SXj04];B`0b<S80M7Ad02/[:`1IFET0GEeM04a<C019BDT0AdM706UYJ@80
G5aL06/0Ti>C075aL@1lO7`0DE5A061PH01GEeL0TY:B04m?C`11@D40RXZ:06EUI@22PX80KFe]06QX
J01gMgL0>SXj059BDP12@T80EeMG04M7A`1jNWX0JVYZ0:6QX@1oOgl0B4Q807EeM@1CDe<0:b/[06a/
K00R8R80Q8B40:RXZ01?Cdl0IFEU03Lg=`2@T900?Shn05YJFP28R8P0Xj>S079bLP1JFUX0PH6106MW
I`2XZ:P0MGEe0492@P19BDT0HF5Q05eMG@0c<c<0>CTi04I6AP0e=CD0BDU9071`L00c<c<0CTi>0861
P@0`<300IVIV04];B`0g=cL0ADE503De=@1gMgL0;2`/04Q8B01TI6@09RHV03dm?@0V9RH0J6QX07em
O@0e=CD0JVYZ05iNGP0/;2`0=cLg03dm?@1jNWX0C4a<07AdM01_Kfl0Hf=S09VIV@13@d<0EeMG07Ad
M01IFET0H61P03Xj>P1dM7@0NWYj034a<@1:BTX0GUiN02@T901BDU80ATI6079bLP1<C4`0<c<c04i>
CP0[:b/0LG5a04M7A`0205mOG`0o059BDP24Q8@0EUIF04a<C01ADE40FEUI03/k>`1;Bd/0>c/k04i>
CP1QHF40?Shn05=CD`1GEeL0MWIf04i>CP0o?cl0AdM7055AD@1?Cdl0D51@0492@P1VIVH0HV9R05iN
GP1TI6@0AdM704e=C@18B4P0FEUI07AdM00l?3`0=3@d03Ph>01NGUh0<c<c030`<00o?cl0<C4a03dm
?@0^;Rh0EUIF05aLG015ADD0CDe=024Q8@0/;2`0@D5102<S8`0A4A40A4A40492@P10@400ATI604M7
A`1UIFD0JFUY06e]K@1MGEd0RHV905YJFP25QHD0NWYj0080JFUY00`0GemO05=CD`1BDU80Kfm_09>C
T`1=CDd0FUYJ05QHF00e=CD0ADE502TY:@19BDT203Xj>P0;05UIF@0n?Sh0EeMG04a<C01KFe/0FEUI
051@D01JFUX0De=C07]kN`1QHF400_ooool0002C09:BTP1oOgl0Bd];065QH@1^KVh0LW9b07QhN00d
=3@0EeMG06QXJ01EEED0FUYJ05mOG`0/;2`0>SXj06m_K`1nOWh0?Cdm0861P@0l?3`0:2PX03/k>`25
QHD0H61P04I6AP0d=3@0;2`/03Ti>@1MGEd0P82002<S8`1BDU80=SHf02h^;P0n?Sh0Ti>C059BDP0g
=cL0QhN702TY:@0U9BD0Ph>30;6a/@0X:2P08R8R04U9B@0`<300=CDe09JFUP2QXJ409BDU02XZ:P17
AdL0?clo05ADE02e]KD0CDe=02XZ:P0i>CT0EUIF04];B`2@T900Cdm?02DU9@1?Cdl0E5AD04m?C`23
Ph<0^k^k02d];@0T92@0ATI6071`L01FEUH0O7al0::RXP0U9BD0;Rh^04M7A`1fMWH0>SXj08Z:RP1O
Gel08B4Q04Q8B01MGEd0H61P05MGE`29RHT0@T9202XZ:P0m?Cd0O7al03Hf=P0l?3`0CDe=01TI6@0_
;bl0EEEE07inOP0_;bl0EUIF06a/K00H61P0@41007moO`1FEUH0;Bd]04];B`10@400=SHf06=SH`2A
TI40;bl_02`/;013@d<0CDe=03dm?@29RHT0B4Q801LG5`0N7Qh0A4A403Lg=`1[Jf/0YJFU03Hf=P0L
71`08R8R059BDP1<C4`0De=C0:j^[P0j>SX09bLW04E5A@1RHV80Hf=S06UYJ@2SXj<0>c/k03De=@19
BDT0NWYj07=cL`1JFUX0T92@0080<c<c02D0@410092@T01GEeL0UYJF05YJFP0^;Rh0@D5107IfMP1@
D500GEeM061PH00`<300IfMW08R8R019BDT0DE5A04E5A@0O7al0=SHf09ZJVP2WYjL0AdM706IVIP1P
H600=CDe04U9B@1]KFd0GEeM02XZ:P13@d<0?Cdm04I6AP1]KFd0Ph>304e=C@0g=cL0ADE50080?Cdm
02L0De=C0;Ng]`1>CTh0:RXZ03Lg=`19BDT0N7Qh0:BTY01VIVH07QhN03lo?`1MGEd0Hf=S04a<C02C
Ti<0<30`01TI6@19BDT0E5AD03@d=02<S8`0HV9R01dM7@0/;2`0GemO06=SH`1NGUh0X:2P03@d=00e
=CD0K6a/08V9R@1]KFd0Rh^;08F5Q@0M7Ad0EUIF08>3P`15ADD00P1UIFD0>`0V9RH0EUIF07UiN@1@
D500I6AT06MWI`0];Bd0H61P075aL@1CDe<0DU9B07emO@0n?Sh0=SHf08>3P`2d];@0@D5105]KF`16
ATH0>c/k051@D02KVi/0HV9R05UIF@1LG5`09BDU04A4A01IFET0OWin04M7A`1LG5`0JVYZ0410@01e
MGD0V9RH07=cL`0n?Sh0MWIf059BDP1PH600IFEU07IfMP17AdL0<c<c069RHP1HF5P0D51@06][J`2?
Shl0=SHf03Lg=`20P800H61P03De=@1kNg/0UiNG03Lg=`0^;Rh0EEEE0080CTi>04h0WIfM05YJFP0R
8R80>c/k04E5A@1IFET0NGUi0861P@2>SXh0>3Ph02<S8`1cLg<0TI6A04Y:BP1UIFD0[Jf]02DU9@0X
:2P0F5QH05=CD`12@T80QhN706][J`0L71`0BDU905EEE@1[Jf/0?3`l08B4Q02<S8`0IFEU04m?C`1=
CDd0H61P06IVIP1aLG40B4Q805aLG01eMGD0J6QX03hn?P14A4@0KFe]08j>SP1kNg/0TY:B09JFUP25
QHD0NWYj06EUI@1TI6@0BDU9055AD@15ADD0BDU904A4A01GEeL0H61P059BDP1HF5P0Fe]K06MWI`1G
EeL0IFEU06][J`1kNg/0De=C04i>CP1UIFD0EEEE05=CD`1ADE40@D5104A4A01DE5@0ADE5065QH@0m
?Cd204i>CP1[04=3@`1?Cdl0@41003dm?@0i>CT0ADE502d];@11@D409bLW04Q8B016ATH0E5AD06IV
IP0N7Qh08B4Q0492@P0_;bl0FEUI0410@00U9BD0B4Q8051@D01/K6`0GemO05]KF`10@400?Shn04=3
@`14A4@0H61P04Q8B01GEeL0BTY:03Lg=`1UIFD0GEeM03Xj>P1RHV80@41003Xj>P15ADD0CDe=02LW
9`0i>CT0B4Q802XZ:P0M7Ad0;bl_03Xj>P1?Cdl0=cLg03<c<`0k>c/0C4a<03Ti>@0];Bd0C4a<069R
HP0o?cl0?Shn02`/;01FEUH0=cLg02l_;`1;Bd/0<c<c028R8P0^;Rh0H61P08j>SP0d=3@0?3`l051@
D01JFUX0B4Q803/k>`1CDe<0B4Q807UiN@0l?3`0<c<c051@D01BDU80IVIV04m?C`1HF5P0:2PX04I6
AP0];Bd0WIfM0492@P2NWYh0Rh^;07YjNP26QXH0D51@03`l?01^KVh0;Bd]03@d=01HF5P0D51@05YJ
FP0b<S80?3`l02h^;P0j>SX00P1HF5P204a<C00H09NGU`1?Cdl0[Zj^05=CD`1<C4`0<30`03Lg=`1E
EED0;Bd]07MgM`1[Jf/0E5AD05QHF01`L700@410079bLP2ATI40;bl_06QXJ016ATH0?Shn04m?C`0e
=CD0P8200P0_;bl0C@1:BTX0<S8b065QH@0/;2`0?Cdm04a<C00M7Ad0Bd];03dm?@0k>c/0FEUI03/k
>`1FEUH0AdM709bLW01^KVh0HV9R08n?S`14A4@0GEeM075aL@13@d<0BDU902LW9`1;Bd/0J6QX02`/
;01VIVH0NGUi02XZ:P19BDT0;bl_03Xj>P0l?3`0BDU905MGE`0d=3@0GEeM03Xj>P21PH40K6a/03Lg
=`19BDT0?3`l02l_;`28R8P0IfMW034a<@1>CTh0ADE504];B`1GEeL0>SXj05YJFP0o?cl0Fe]K030`
<00j>SX0A4A403Ti>@1_Kfl0HV9R03Ph>01_Kfl0DE5A05iNGP1VIVH0<S8b05]KF`0c<c<0BDU906i^
KP0h>3P0C4a<02LW9`0m?Cd0?clo0080ATI603@0>CTi05MGE`0n?Sh0GUiN06QXJ01=CDd0@d=303`l
?01PH600KFe]03/k>`0A4A40Jf][04E5A@19BDT0?clo05=CD`1=CDd0ATI603Lg=`19BDT0OGem06UY
J@28R8P0EeMG05eMG@1ZJVX0Rh^;09>CT`1ADE40De=C06][J`1GEeL0LW9b05MGE`1>CTh0GemO03Hf
=P1<C4`0AdM703<c<`17AdL0@T9207YjNP0f=SH0BDU904Q8B01=CDd0G5aL07emO@1nOWh0EeMG0_oo
ool0001C06e]K@2EUID0CDe=05IFEP18B4P0D51@07MgM`1FEUH0>3Ph04m?C`1<C4`0EEEE06IVIP0b
<S80:BTY05ADE01IFET0D51@0::RXP1?Cdl08b<S030`<01<C4`0F5QH06ATI01RHV808b<S030`<016
ATH0SHf=05=CD`2NWYh0ATI602TY:@16ATH0OWin04m?C`17AdL0c/k>030`<00Y:BT0;bl_06MWI`1?
Cdl0EUIF07IfMP0U9BD0?3`l03hn?P1dM7@0CTi>05YJFP1<C4`07alO03Xj>P1<C4`0OWin04];B`1V
IVH04A4A02d];@15ADD0DU9B034a<@1<C4`0IFEU03Lg=`1<C4`0TI6A069RHP0N7Qh0A4A403/k>`0m
?Cd0<S8b06][J`1=CDd08B4Q05IFEP1:BTX0E5AD08:2PP2SXj<00P0o?cl0o`1:BTX0=cLg061PH039
bLT0Jf][028R8P0W9bL0IFEU04I6AP24Q8@0W9bL01lO7`0D51@0CTi>06=SH`0d=3@0UiNG09ZJVP0^
;Rh09BDU04m?C`1HF5P0ATI608J6QP0k>c/07AdM03Xj>P1[Jf/0I6AT07UiN@28R8P09RHV034a<@1J
FUX0XJ6Q04U9B@1gMgL0AdM702<S8`0m?Cd0JFUY08F5Q@1EEED0P82005=CD`0M7Ad0=SHf05ADE01Z
JVX0<C4a05=CD`1HF5P09RHV04Q8B01@D500F5QH02h^;P19BDT0=3@d03Lg=`1hN7P0KFe]04I6AP0V
9RH0@41002XZ:P0h>3P0O7al08R8R00c<c<0AdM704Q8B00i>CT0CTi>0820P00^;Rh0ADE503lo?`1:
BTX0[jn_09nOW`0U9BD0;bl_05UIF@1iNGT0HF5Q0;6a/@2o_kl0;bl_02@T901cLg<0SHf=05EEE@2G
UiL0PH6101`L700a<C40R8R80:6QX@1/K6`0/;2`0410@00U9BD0;bl_096AT@2OWil0ADE505EEE@0O
7al08R8R069RHP2WYjL0M7Ad05MGE`1JFUX06QXJ03dm?@1jNWX0NGUi0451@@1[Jf/0=cLg01lO7`13
@d<0O7al04=3@`1?Cdl0Fe]K038b<P0Y:BT0K6a/08F5Q@0g=cL0Cdm?03<c<`0V9RH0ADE507moO`0m
?Cd0@41005QHF00n?Sh0EEEE08N7Q`0n?Sh0@D51051@D011@D40Ph>309bLW017AdL0=SHf05UIF@0o
?cl0Jf][0:NWY`0h>3P09BDU04A4A01UIFD0DU9B09>CT`1GEeL0:2PX04A4A01JFUX0LW9b09>CT`2J
VYX06a/K0451@@1VIVH0KFe]05aLG025QHD0Y:BT02DU9@0h>3P0Hf=S06IVIP1eMGD0b/[:07]kN`0Z
:RX0E5AD05eMG@1NGUh0L71`0;>c/`1LG5`0BDU905MGE`1WIfL0Ogmo05YJFP2d];@0Cdm?03Lg=`0/
;2`0LG5a059BDP13@d<0Ti>C03`l?00Z:RX0Bd];05mOG`0e=CD0BTY:06QXJ00X:2P0=SHf05IFEP23
Ph<0FUYJ04Q8B01XJ6P0<30`03Ph>01>CTh0K6a/05aLG00h>3P0EUIF030`<00i>CT0D51@08Z:RP13
@d<0:RXZ05ADE00g=cL0CDe=06IVIP2ATI40RHV907alO014A4@0D51@05IFEP2=SHd0KFe]06m_K`1g
MgL0E5AD04a<C019BDT0NGUi079bLP1/K6`0_[jn0<;2`P2>SXh0EEEE04Y:BP002P1=CDd0?Shn04i>
CP19BDT0MGEe06YZJP1TI6@0M7Ad061PH01^KVh206UYJ@0h05UIF@15ADD0Lg=c07emO@1_Kfl0H61P
06a/K01YJFT0DE5A04I6AP0O7al0<C4a03Ph>00k>c/0DU9B03De=@1>CTh0FUYJ055AD@1>CTh0DU9B
04M7A`1:BTX0@d=302`/;00`<3007AdM01lO7`0o?cl0@d=305ADE00S8b<0>CTi05eMG@0];Bd0@D51
04M7A`0n?Sh0DU9B05IFEP1UIFD0QHF506a/K01ADE40E5AD05iNGP1/K6`0Hf=S0410@01@D500GEeM
034a<@0U9BD0BDU902h^;P1DE5@203`l?00O03/k>`0n?Sh0AdM704=3@`0m?Cd0=SHf02h^;P0d=3@0
8B4Q04=3@`0a<C40BTY:034a<@0j>SX0B4Q8034a<@0b<S80?clo02HV9P1JFUX0=cLg04a<C01ADE40
C4a<04M7A`0g=cL0<c<c04a<C017AdL0GemO0492@P04051@D00e079bLP1;Bd/0<S8b06a/K00d=3@0
ADE5059BDP1JFUX0OGem02<S8`0i>CT0AdM7055AD@0_;bl0@T920410@02RXZ80Shn?03/k>`1JFUX0
=cLg02XZ:P1mOGd08b<S061PH01lO7`0@d=306EUI@0h>3P0MWIf03Lg=`1=CDd0Ph>305iNGP1?Cdl0
CTi>05]KF`0i>CT0_Kfm079bLP0m?Cd0<C4a03dm?@1;Bd/0;2`/0=?Cd`34a<@0BDU904m?C`1UIFD0
G5aL061PH02DU9@00P1]KFd04P1IFET0EEEE07UiN@1PH600MGEe05EEE@12@T80EEEE04I6AP1IFET0
J6QX04I6AP1MGEd0CDe=06][J`1eMGD0De=C03dm?@80H61P03<0Lg=c07AdM021PH40JFUY07moO`1/
K6`0<S8b04Y:BP1FEUH0Hf=S05YJFP1ADE40De=C03lo?`1UIFD0MWIf04e=C@13@d<0?Cdm04Q8B00i
>CT0=cLg04i>CP0T92@0Jf][02<S8`1=CDd0BDU903Lg=`1XJ6P0@D5101hN7P0k>c/0=SHf02d];@18
B4P0:BTY03Lg=`1NGUh0@41003/k>`14A4@0Hf=S03hn?P0k>c/0EeMG03lo?`10@400A4A403<c<`2<
S8`00P1;Bd/0@@1FEUH0<c<c05aLG00i>CT0ADE505aLG00[:b/0>SXj02/[:`0h>3P0BTY:04U9B@1:
BTX08b<S03lo?`0/;2`0?3`l05IFEP17AdL0E5AD038b<P0`<300@d=303Hf=P0g=cL0DE5A04M7A`1L
G5`0A4A405QHF01OGel0BDU904e=C@13@d<0OWin05UIF@1SHf<0ADE507AdM01QHF40=SHf051@D01D
E5@0De=C07MgM`0a<C40EUIF05eMG@1;Bd/0EeMG04M7A`1HF5P0Fe]K04=3@`1?Cdl0GUiN07inOP1:
BTX0H61P04e=C@1LG5`0F5QH06m_K`1VIVH0GEeM00;ooooo0000=`1FEUH0Kfm_06MWI`2=SHd0ATI6
055AD@1JFUX0MGEe06ATI029RHT08b<S05EEE@29RHT0GUiN04M7A`2SXj<0EEEE0492@P1dM7@0Zj^[
04I6AP1iNGT0KFe]020P8017AdL0H61P04];B`0c<c<0FUYJ01dM7@0j>SX0BTY:06EUI@0];Bd0LG5a
05aLG00c<c<0B4Q808F5Q@1cLg<0;bl_0451@@1?Cdl0:BTY06ATI02LW9`0>c/k01dM7@1BDU80<c<c
069RHP1CDe<0Lg=c01hN7P0Z:RX00P1FEUH04P1MGEd0^KVi05IFEP0P8200D51@05IFEP1ADE40KVi^
07IfMP0S8b<09bLW05aLG01]KFd0Cdm?07IfMP0b<S809bLW04i>CP80ATI608X0@4100:RXZ00Z:RX0
?Shn061PH01UIFD0B4Q807emO@1RHV806a/K024Q8@1WIfL0XJ6Q051@D01MGEd0>3Ph02LW9`0k>c/0
SHf=09bLW016ATH0P820020P800_;bl0E5AD06MWI`17AdL0?clo06EUI@0V9RH0AdM705ADE019BDT0
7QhN03De=@0d=3@0;Bd]05eMG@2=SHd0Bd];01TI6@15ADD0>c/k05aLG025QHD0IFEU01`L700e=CD0
G5aL034a<@0f=SH0QHF509JFUP0W9bL0;Bd]06EUI@1QHF40=CDe0861P@2JVYX09BDU03De=@1SHf<0
DE5A05IFEP1ZJVX0KFe]01LG5`18B4P0N7Qh05aLG01VIVH0QHF502<S8`0];Bd0DU9B06=SH`18B4P0
NWYj06EUI@0S8b<0CTi>06MWI`1QHF40/[:b05YJFP0V9RH0@41009fMW@1oOgl0@d=30:RXZ017AdL0
8B4Q059BDP2SXj<0KVi^03dm?@2IVIT0=cLg04M7A`1JFUX0M7Ad04E5A@1DE5@0EUIF02`/;01<C4`0
LW9b09:BTP0l?3`0@D5105mOG`0l?3`0QXJ609ZJVP1ADE40;2`/05mOG`12@T80De=C07IfMP26QXH0
9BDU03lo?`14A4@0?Shn04];B`1oOgl0HV9R02`/;00f=SH0C4a<05IFEP1eMGD0UiNG03Xj>P0a<C42
04];B`2L06m_K`2^[Zh0CDe=02/[:`1RHV80HF5Q03`l?02HV9P0X:2P02XZ:P1;Bd/0NGUi04a<C01b
LW80P820024Q8@0i>CT0OGem051@D01mOGd0SHf=02XZ:P0[:b/0O7al07=cL`1aLG40MGEe04e=C@13
@d<0DE5A09JFUP1OGel0Lg=c05IFEP13@d<0GemO07EeM@1GEeL0HF5Q0;:b/P1PH600Cdm?07inOP2K
Vi/0EeMG05]KF`2JVYX0B4Q8030`<02<S8`0a/K604Q8B01ADE40F5QH02LW9`0o?cl0OWin0;2`/01=
CDd0AdM7071`L00c<c<0;bl_07moO`1kNg/0=3@d03`l?00i>CT0=SHf06i^KP25QHD0Cdm?02<S8`1;
Bd/0@d=30492@P1cLg<0QXJ603hn?P0N7Qh0?clo04=3@`1EEED0J6QX09nOW`1ADE409bLW03Ti>@1;
Bd/0HF5Q08j>SP2RXZ80>3Ph02`/;00b<S80EEEE06ATI01ZJVX0Ph>303<c<`0W9bL0ATI608R8R01e
MGD0ADE504=3@`1<C4`0De=C05IFEP0h>3P0BTY:07=cL`1BDU80QXJ608f=S@2JVYX0T92@05EEE@1W
IfL0EeMG08B4Q01mOGd0F5QH05MGE`0c<c<0Hf=S04Q8B011@D40?clo05=CD`1:BTX0?Cdm069RHP1P
H600RXZ:06a/K01:BTX0CTi>06a/K01fMWH0EEEE05UIF@1>CTh0IVIV05mOG`0V9RH0?3`l0451@@16
ATH0IFEU04a<C01QHF40FEUI04A4A01<C4`0Cdm?0P0k>c/0e`1?Cdl0:BTY05UIF@0[:b/0<30`04e=
C@1DE5@0G5aL03Ti>@1?Cdl0IFEU02DU9@1?Cdl0F5QH05YJFP1CDe<0C4a<071`L02d];@0JVYZ0410
@012@T80Cdm?03hn?P1IFET0ATI60410@012@T808b<S034a<@17AdL0?Cdm06UYJ@0];Bd0@T9204M7
A`12@T80=cLg03lo?`1;Bd/0@T9204i>CP0];Bd0;bl_03Hf=P0c<c<0=CDe030`<013@d<0?Cdm038b
<P0e=CD0@D5102h^;P1?Cdl0;Bd]04e=C@13@d<0?3`l04A4A019BDT0JFUY059BDP1FEUH0MWIf05QH
F01YJFT0ADE504e=C@14A4@0EEEE05=CD`14A4@0H61P03dm?@1LG5`0EEEE04Y:BP1UIFD0ADE505QH
F00n?Sh0AdM706MWI`2^[Zh0B4Q806m_K`1mOGd0IVIV07alO00k>c/09RHV08V9R@0I6AT0VYZJ0:f]
[@19BDT0Jf][02l_;`1IFET061PH02`/;018B4P0NWYj03dm?@1BDU80Ng]k09^KV`2YZJT0O7al05YJ
FP1eMGD0CTi>05IFEP0c<c<0?Cdm04I6AP0n?Sh0Cdm?06ATI01EEED0MgMg0<[:bP0k>c/0HF5Q05MG
E`1/K6`0MGEe04M7A`2>SXh0CDe=02/[:`1?Cdl0=cLg06MWI`1;Bd/0E5AD05mOG`0Q8B40D51@059B
DP0d=3@0@d=30451@@1ZJVX0B4Q807UiN@1BDU80J6QX09BDU00i>CT0?Cdm04M7A`12@T80Bd];06][
J`12@T80EeMG05EEE@2;Rh/0R8R801hN7P0o?cl09bLW04E5A@0l?3`0>SXj04U9B@18B4P0EEEE03Lg
=`1[Jf/0Cdm?03hn?P1]KFd0?Cdm024Q8@1JFUX0CTi>03De=@1HF5P0BDU9051@D01VIVH0AdM7061P
H017AdL0Jf][0492@P0^;Rh0EeMG030`<01KFe/0A4A403dm?@1aLG40DU9B06ATI01LG5`0?Cdm05QH
F00f=SH0IVIV07YjNP0l?3`0EUIF02HV9P12@T80?Cdm03Ti>@1TI6@0;2`/04U9B@1?Cdl0H61P0080
EUIF00`0AdM703lo?`16ATH0C4a<02d];@0U9BD0GemO04m?C`0j>SX0De=C05IFEP0k>c/205QHF00P
0492@P1mOGd0BDU9079bLP19BDT0K6a/061PH01>CTh0Hf=S05MGE`1HF5P0K6a/0451@@1KFe/0DU9B
04e=C@1HF5P0:BTY06MWI`1PH600=SHf04Q8B01SHf<0UIFE04];B`1PH600F5QH061PH01BDU80J6QX
069RHP1MGEd2ooooo`0000X0IFEU061PH01GEeL0GemO05YJFP1KFe/0FUYJ0410@01EEED0J6QX0P1>
CTh0AP1]KFd0?Cdm051@D022PX80JVYZ02d];@0j>SX0C4a<03@d=01KFe/0R8R8020P800X:2P0>c/k
04A4A01MGEd0YZJV03Xj>P0N7Qh0H61P05iNGP19BDT0YZJV0;:b/P0H61P0?Shn071`L01_Kfl0I6AT
07emO@11@D4071`L02<S8`1:BTX0K6a/04a<C02DU9@0=3@d02/[:`0k>c/0PX:207UiN@1SHf<0PH61
03hn?P0X:2P0EeMG0;Ng]`1KFe/0GemO03Xj>P0K6a/0EEEE08R8R00d=3@0A4A406UYJ@0Q8B409bLW
07alO021PH409bLW03hn?P1EEED0<30`055AD@1jNWX0EeMG01/K6`0g=cL20492@P2i05eMG@2=SHd0
;2`/028R8P0l?3`0DE5A05ADE022PX80IfMW01HF5P0b<S80=3@d06][J`1EEED0Zj^[02h^;P0B4Q80
AdM7051@D014A4@0Hf=S09NGU`0O7al09BDU06m_K`1bLW80?Shn06YZJP1LG5`05ADE02DU9@1HF5P0
Ng]k03/k>`1YJFT092@T01PH6017AdL0Fe]K03Xj>P18B4P0Jf][02d];@0G5aL0A4A408n?S`1IFET0
@d=305YJFP0c<c<0:RXZ034a<@29RHT0GEeM04m?C`1^KVh08R8R03<c<`1JFUX0Lg=c0451@@15ADD0
EUIF03dm?@11@D40I6AT05YJFP0U9BD0BDU904e=C@0d=3@0Kfm_08>3P`0U9BD0<c<c04];B`16ATH0
S8b<08B4Q00N7Qh0=CDe055AD@1LG5`0J6QX09NGU`1aLG40:2PX04m?C`1KFe/0JFUY05=CD`2ZZZX0
JFUY02HV9P1@D500Cdm?03Ph>020P800[jn_02l_;`0];Bd0DE5A09ZJVP1OGel0N7Qh0<O7a`14A4@0
>c/k07QhN02TY:@0M7Ad0:n_[`2;Rh/08B4Q05=CD`2;Rh/0@D5105YJFP1YJFT06a/K02HV9P1PH600
J6QX06ATI025QHD0JVYZ034a<@1<C4`0^k^k08R8R01ADE40SXj>055AD@1IFET0M7Ad0:2PX017AdL0
NWYj03/k>`0O7al0FUYJ09JFUP1SHf<0De=C06ATI00_;bl0CTi>08b<S01:BTX0ATI6051@D00o?cl0
JFUY09VIV@0n?Sh0?clo05UIF@0k>c/0OGem0<C4a01MGEd0>SXj055AD@19BDT0Bd];0:>SX`2ATI40
@41004U9B@1bLW80AdM7061PH02k^k/0UIFE03Lg=`1RHV80T92@05EEE@1SHf<0YJFU06i^KP0Y:BT0
GEeM08>3P`1IFET00P25QHD0V00[:b/0>CTi04];B`2MWId0K6a/07inOP2JVYX0:b/[0492@P1GEeL0
NGUi065QH@2WYjL0P82002<S8`19BDT0Shn?06e]K@0l?3`0N7Qh04a<C00H61P0>3Ph08n?S`21PH40
A4A405]KF`1VIVH0:BTY03@d=01PH600Q8B40492@P1MGEd0@d=301TI6@15ADD0IfMW069RHP0f=SH0
I6AT034a<@0];Bd0@D51096AT@1_Kfl05aLG03Hf=P2EUID0NGUi05IFEP1UIFD0T92@08Z:RP1cLg<0
CDe=04i>CP1JFUX0?Shn03Ti>@17AdL0GemO05UIF@1?Cdl0UYJF0:b/[01HF5P0BTY:04A4A01@D500
:RXZ04I6AP0f=SH0DE5A04m?C`1_Kfl0GemO03Ti>@0n?Sh0:b/[04U9B@1CDe<0ADE505mOG`1FEUH0
J6QX04a<C01IFET0JFUY04i>CP1;Bd/0=3@d04M7A`1=CDd0ATI6051@D018B4P0AdM704E5A@1>CTh0
J6QX06MWI`10@400A4A4055AD@1@D500FEUI02HV9P0a<C40?3`l05YJFP1UIFD09RHV03Ph>01@D500
@d=3069RHP18B4P0>CTi04I6AP1@D500BTY:06=SH`1EEED0IfMW075aL@1EEED0BDU904a<C00a<C40
>CTi05EEE@0O7al0<c<c05QHF00/;2`0<30`024Q8@0j>SX0D51@055AD@0i>CT0CDe=05aLG00e=CD0
9bLW034a<@0n?Sh0E5AD0451@@12@T80?Shn0P1;Bd/0?@15ADD0EEEE06=SH`0h>3P0Hf=S04E5A@1J
FUX0CTi>04];B`17AdL0ATI603lo?`15ADD0HF5Q07IfMP13@d<0EEEE03`l?018B4P0A4A405eMG@19
BDT0A4A405=CD`1BDU80BTY:06=SH`1=CDd0IfMW06=SH`1MGEd0?clo03Ti>@0j>SX0GEeM0410@02E
UID0L71`059BDP1nOWh0H61P0410@022PX80?Shn05mOG`1_Kfl0C4a<06IVIP12@T80FEUI010@4019
BDT0?Cdm04i>CP1CDe<0DU9B08V9R@1cLg<0X:2P065QH@1SHf<00P1>CTh08P1JFUX0<C4a07EeM@1h
N7P0B4Q805UIF@1XJ6P0AdM704A4A01IFET0@T9206ATI01<C4`0>SXj04a<C01EEED0Ph>304E5A@18
B4P0CDe=0492@P1IFET0D51@08f=S@20P800DE5A05UIF@1JFUX0?Cdm04Q8B00i>CT0BTY:0451@@1c
Lg<2061PH00N08B4Q00P8200CTi>04i>CP0d=3@0EUIF04U9B@2OWil0Z:RX08:2PP2>SXh0QhN703lo
?`1cLg<0=SHf04U9B@0_;bl0FUYJ059BDP0a<C40GUiN02/[:`2IVIT0EeMG05]KF`1RHV80<C4a04E5
A@1TI6@0H61P0P13@d<0DP15ADD0@d=3061PH00a<C40KFe]04E5A@1SHf<0?Shn03@d=01FEUH0<c<c
0820P01NGUh0?Shn07EeM@16ATH0L71`06][J`12@T80EeMG02DU9@10@400FUYJ02h^;P1BDU80?3`l
04U9B@1;Bd/0BTY:069RHP1BDU80BDU903dm?@1QHF40HV9R03Hf=P18B4P0>CTi03`l?01@D500CTi>
03@d=01[Jf/0:2PX0451@@17AdL0DE5A03hn?P1QHF40?Shn04Q8B01eMGD0OWin0;6a/@1`L700PH61
051@D016ATH0C4a<034a<@1MGEd0MGEe04U9B@1YJFT0IFEU04a<C01GEeL09bLW065QH@1JFUX0?clo
04Q8B01iNGT0Xj>S04U9B@0o?cl0B4Q804E5A@1>CTh0HF5Q06][J`1hN7P2ooooo`000780UYJF08V9
R@1?Cdl0T92@079bLP2=SHd0][Jf03Hf=P1=CDd0Q8B406YZJP24Q8@0PH6103lo?`0i>CT0GEeM09^K
V`1OGel0T92@0410@00/;2`0<S8b071`L01fMWH0BTY:04U9B@0H61P0;Rh^04M7A`24Q8@0=3@d07]k
N`0];Bd08B4Q051@D01^KVh0?3`l03De=@1TI6@0:RXZ0492@P1OGel0MgMg04A4A010@400@D51038b
<P11@D40N7Qh06YZJP0O7al0>CTi05aLG00_;bl0@d=309:BTP0f=SH09bLW030`<01<C4`0B4Q808B4
Q01ADE405aLG051@D01;Bd/0DU9B06IVIP2>SXh09RHV02h^;P1?Cdl0K6a/04a<C01nOWh0NWYj01XJ
6P12@T80EeMG06i^KP1VIVH0RXZ:02`/;00`<300CTi>05]KF`1VIVH0GEeM096AT@0I6AT0>3Ph069R
HP1eMGD0<c<c04M7A`1SHf<03Ph>02DU9@1OGel0NWYj02d];@1MGEd0DE5A02LW9`0m?Cd0A4A403/k
>`0c<c<0De=C02`/;00d=3@0D51@06a/K00`<30203Xj>P1J02<S8`11@D40EeMG05iNGP0=3@d09bLW
03Ti>@0c<c<0HF5Q06a/K01BDU808b<S02`/;017AdL0CDe=0492@P1lO7`0:b/[01lO7`18B4P0CDe=
04];B`1oOgl0U9BD03@d=00N7Qh0?3`l05IFEP1dM7@0ZZZZ09>CT`0W9bL0CDe=0820P026QXH0F5QH
09FEU@13@d<0:BTY059BDP2=SHd0@D5106][J`1_Kfl0;Bd]06i^KP2QXJ40J6QX07EeM@20P800<C4a
04];B`1^KVh0YZJV069RHP2b/[80QXJ603Lg=`13@d<0Ti>C0;Bd]01@D500Ti>C055AD@0[:b/0CDe=
0:NWY`2ZZZX0H61P07inOP1PH600;2`/051@D024Q8@0Lg=c04U9B@1@D50092@T03Ph>01XJ6P0M7Ad
04E5A@1OGel0ADE5024Q8@1QHF40XJ6Q05IFEP0c<c<0BTY:0P0k>c/0^@1mOGd0N7Qh01/K6`0b<S80
EeMG051@D01FEUH0U9BD05EEE@0c<c<0F5QH07QhN01JFUX0Y:BT06a/K00I6AT0@41005IFEP1:BTX0
S8b<08j>SP0U9BD0=CDe07=cL`1WIfL0R8R807emO@0c<c<0BTY:06YZJP0n?Sh0De=C06=SH`0O7al0
>SXj0861P@1WIfL0EUIF08N7Q`0n?Sh0:RXZ05MGE`2EUID0FEUI079bLP1/K6`0=SHf03Xj>P1]KFd0
[Jf]0820P02TY:@0NGUi03Lg=`1HF5P0D51@07MgM`1aLG40/[:b06=SH`0b<S80FEUI08b<S017AdL0
GemO06QXJ00Y:BT0>c/k05=CD`24Q8@0EeMG04];B`1`L700<c<c02PX:01GEeL0W9bL04Q8B00^;Rh0
EUIF04Y:BP0n?Sh0L71`0820P00W9bL0;2`/059BDP1HF5P0A4A407UiN@28R8P0:BTY03/k>`0o?cl0
?Cdm079bLP2XZ:P0Ng]k02<S8`0[:b/0B4Q803lo?`1ADE40[:b/071`L00K6a/0=SHf065QH@1VIVH0
EEEE09BDU02=SHd0N7Qh05]KF`17AdL0ATI605aLG01mOGd0E5AD061PH01YJFT0<C4a04e=C@1CDe<0
EeMG06QXJ01GEeL0F5QH05=CD`1WIfL0OGem069RHP1BDU80;bl_069RHP0k>c/0GemO051@D01EEED0
Bd];04e=C@1PH600Bd];05aLG01@D500GEeM06QXJ01WIfL0Fe]K05YJFP1bLW80Hf=S05MGE`18B4P0
8B4Q03`l?016ATH0EeMG05IFEP0o?cl0CTi>065QH@1DE5@0:RXZ03De=@0j>SX0ATI60410@00Z:RX0
C4a<038b<P0e=CD0Cdm?059BDP1ZJVX05aLG02l_;`1GEeL09RHV02h^;P0e=CD0?3`l03dm?@0h>3P0
EeMG0080KFe]00D0=cLg0492@P12@T80BDU907AdM00204A4A00B05eMG@0c<c<0Cdm?05UIF@0[:b/0
EEEE03Hf=P0o?cl0=cLg04I6AP0k>c/0>CTi038b<P0Y:BT0=3@d02h^;P0/;2`0@d=30P0a<C405@0c
<c<0=cLg04A4A00a<C40;Rh^03/k>`0O7al0F5QH03Lg=`0k>c/0D51@04A4A01KFe/0<C4a0451@@17
AdL0F5QH061PH016ATH0Cdm?04Q8B00204=3@`0X05=CD`12@T80?Shn04U9B@0];Bd0@D5105YJFP1K
Fe/0PH6103dm?@1OGel0?clo04a<C010@400Ng]k04E5A@2c/k<0UYJF03hn?P1PH600N7Qh04M7A`1j
NWX0DE5A08^;R`2ATI40Cdm?08n?S`1=CDd0FEUI0451@@1?Cdl0=3@d0410@00a<C40De=C08^;R`17
AdL0a<C404A4A080=cLg0340>c/k03lo?`0i>CT0`/;209JFUP0Y:BT0>SXj0451@@0l?3`0I6AT0:>S
X`19BDT0JFUY05=CD`1KFe/0HV9R05aLG022PX80?clo03Lg=`0l?3`0:b/[06a/K00_;bl0CDe=04Q8
B00V9RH0Fe]K055AD@1OGel0KVi^03Lg=`13@d<0EUIF0;Fe]@1OGel0Kfm_08R8R00e=CD0E5AD07Ad
M01@D500GEeM0410@00e=CD0I6AT04i>CP1mOGd0LG5a0080?3`l06@0ADE5059BDP0o?cl0?Cdm0410
@00n?Sh0EEEE03Xj>P23Ph<0FEUI061PH01_Kfl0De=C03dm?@28R8P0C4a<034a<@0`<300>SXj03dm
?@1SHf<0@T9205YJFP1?Cdl0EEEE04A4A013@d<0E5AD04i>CP1NGUh0AdM703hn?P1]KFd0I6AT05AD
E01CDe<0?clo05QHF00i>CT0GemO07YjNP1;Bd/0@T9205EEE@1GEeL0De=C04E5A@1hN7P08b<S04a<
C016ATH0FEUI05IFEP11@D40A4A403dm?@1[Jf/0Ph>302h^;P0U9BD0De=C02DU9@1=CDd0EEEE05QH
F014A4@0EUIF03lo?`1GEeL0K6a/04Y:BP1GEeL0B4Q807AdM01MGEd0W9bL096AT@24Q8@0F5QH05AD
E012@T80Shn?05mOG`1ADE40HF5Q03dm?@2=SHd0LG5a04I6AP1ZJVX0TY:B0;jn_P1=CDd0FUYJ07Yj
NP1^KVh0H61P08Z:RP1VIVH0H61P0_ooool0000Y07IfMP2KVi/0Jf][06UYJ@0o?cl0IfMW08N7Q`2:
RXX0FEUI04e=C@0^;Rh0EeMG05eMG@1@D500;Bd]05IFEP0d=3@0?Cdm05EEE@1]KFd0>c/k04=3@`18
B4P0>c/k03Lg=`1jNWX0=SHf02h^;P1BDU80BTY:0451@@1/K6`0?Cdm024Q8@10@400EEEE04I6AP1c
Lg<0Y:BT03lo?`0N7Qh00P1@D500M`1<C4`0PX:20:NWY`0W9bL0=CDe05aLG01gMgL0H61P09bLW01f
MWH0<S8b03dm?@1LG5`0OGem075aL@2?Shl09RHV03<c<`1>CTh0Kfm_05MGE`2RXZ80IfMW02d];@1<
C4`0Ph>307alO00l?3`0U9BD05EEE@0_;bl0?3`l06UYJ@1FEUH0=3@d06][J`0j>SX0<30`07IfMP1^
KVh0<30`04U9B@1_Kfl0<c<c059BDP1aLG40>CTi01lO7`1>CTh0G5aL03/k>`1MGEd0VIVI02l_;`0P
8200?3`l0410@016ATH0UYJF07]kN`0N7Qh0?3`l05MGE`15ADD0CTi>07YjNP0c<c<05ADE03@d=01[
Jf/0;bl_05]KF`1iNGT05aLG030`<01;Bd/0Rh^;03<c<`1EEED0<30`010@400V9RH0D51@08Z:RP0n
?Sh0I6AT04I6AP0R8R80>SXj06e]K@2XZ:P0ATI609VIV@11@D409bLW03/k>`29RHT0Lg=c038b<P1J
FUX0?Shn02l_;`1/K6`0Xj>S07emO@0_;bl0FEUI02TY:@0e=CD0E5AD07UiN@17AdL0?clo05aLG00K
6a/0Fe]K07AdM00Y:BT0EEEE0080;Rh^02l0GemO07EeM@0];Bd06ATI069RHP0a<C40?clo05iNGP1k
Ng/0;2`/03De=@1cLg<0@D5103dm?@1YJFT0OWin02@T900V9RH0Bd];04=3@`1;Bd/0ZJVY07YjNP0Z
:RX0;Bd]06UYJ@2BTY80Lg=c09fMW@0W9bL0:RXZ03lo?`27QhL0DE5A09VIV@26QXH071`L0451@@1/
K6`0HF5Q0451@@26QXH0<C4a02HV9P1HF5P0Q8B403dm?@0203hn?P0601`L700f=SH0P8200:FUY@1G
EeL0LW9b0P0j>SX02P2>SXh0U9BD03lo?`1_Kfl0B4Q802DU9@12@T80QXJ605mOG`1]KFd202h^;P1H
04i>CP25QHD0DE5A04U9B@26QXH0?Cdm05MGE`2ATI40@T9203Hf=P1SHf<0ATI606ATI02BTY80Bd];
02@T900m?Cd0>CTi04I6AP1jNWX0JVYZ02DU9@0b<S80@d=305mOG`1/K6`0S8b<08^;R`0Z:RX0@d=3
06ATI019BDT0G5aL0;Vi^@22PX80:2PX03Lg=`1kNg/0EUIF06ATI02XZ:P0>c/k03De=@1:BTX0Ti>C
06YZJP1]KFd0c<c<04=3@`0e=CD0B4Q807IfMP1BDU80K6a/06i^KP0U9BD0@D5106YZJP1RHV80?clo
04E5A@1ZJVX09bLW02<S8`1NGUh0P820075aL@1TI6@0R8R803Ph>00O7al0GemO0;Bd]01IFET0GemO
055AD@0S8b<0=cLg03Ph>01PH600>CTi02l_;`1VIVH07QhN02d];@1PH600SHf=05mOG`80CTi>01h0
JFUY07IfMP1JFUX0ADE506=SH`2OWil0De=C0492@P14A4@0GUiN08Z:RP1MGEd0LW9b07QhN01>CTh0
A4A404Q8B01:BTX08R8R05YJFP0o?cl0?Cdm04=3@`1]KFd0CDe=02h^;P1<C4`0@d=306MWI`1BDU82
0410@00906QXJ01JFUX0BDU9055AD@1=CDd0O7al05iNGP0V9RH0>SXj0080?Shn02d0D51@06ATI01X
J6P0Fe]K04I6AP10@400@d=30410@019BDT0A4A402TY:@1?Cdl0>c/k04M7A`1=CDd0CTi>06MWI`0f
=SH0?clo06YZJP0k>c/0CDe=05EEE@1DE5@0GUiN04i>CP1SHf<0PX:2075aL@1;Bd/0DE5A05QHF01/
K6`0OGem0492@P14A4@0EeMG03Ph>00`<300ADE503Lg=`1GEeL0=3@d03/k>`0/;2`00P1;Bd/08016
ATH0BTY:03dm?@15ADD0;bl_02LW9`13@d<0?3`l03/k>`0f=SH0>c/k0410@00a<C40=cLg03/k>`0R
8R80Bd];03<c<`13@d<0FUYJ03Ph>00i>CT0<30`05=CD`0m?Cd0De=C06a/K01QHF40IfMW038b<P19
BDT0?Cdm0P1CDe<0600^;Rh0@D5101/K6`0e=CD0D51@03`l?01@D500>c/k04Q8B019BDT0DE5A05]K
F`20P800F5QH06e]K@1`L700EEEE06IVIP1iNGT0Jf][0;2`/015ADD0Ph>309:BTP80CDe=0:D0DE5A
069RHP0n?Sh0MWIf05mOG`1IFET0Bd];06IVIP1WIfL0?Cdm07=cL`0c<c<0BTY:05ADE011@D40BDU9
04e=C@1;Bd/0DE5A02d];@18B4P0D51@0492@P14A4@0NWYj04I6AP1GEeL0DE5A06EUI@1GEeL0CTi>
05ADE00l?3`0Bd];06=SH`0o?cl0B4Q80451@@2ZZZX0Ti>C03Ti>@1VIVH0CDe=02<S8`0R8R80:RXZ
04U9B@0X:2P0ATI605=CD`1YJFT0RHV904=3@`0a<C40BDU905EEE@2NWYh0BDU906EUI@26QXH0ADE5
08^;R`1SHf<05QHF04Q8B00b<S80C4a<04A4A01DE5@0Hf=S04i>CP1@D500CDe=08N7Q`0`<300BDU9
06IVIP0Y:BT09bLW05MGE`12@T80=CDe04A4A01>CTh0E5AD06i^KP1=CDd0GemO05]KF`1kNg/0DE5A
04I6AP1UIFD0CDe=06YZJP1]KFd0Bd];06i^KP1TI6@0OWin07]kN`1>CTh0MgMg02HV9P1VIVH0GEeM
034a<@12@T80?Cdm05iNGP1<C4`0DU9B09NGU`18B4P0BDU9030`<01YJFT0IfMW051@D01NGUh0:2PX
04M7A`0j>SX0<c<c0451@@1IFET0B4Q808f=S@1BDU80Ng]k04a<C01TI6@0?clo0451@@1<C4`0LW9b
0;6a/@1DE5@0BDU904a<C01GEeL0EUIF03De=@1OGel0JVYZ03Ph>01PH600=CDe04U9B@1JFUX0<S8b
04A4A00i>CT0;bl_0492@P1lO7`0_[jn04];B`18B4P0HV9R05ADE01HF5P0EeMG06MWI`2DU9@00_oo
ool0001505EEE@1UIFD0RHV909NGU`13@d<0>3Ph06a/K023Ph<0OGem07IfMP0X:2P0>3Ph06][J`2J
VYX0IVIV0:JVYP0c<c<0=CDe05QHF01^KVh0HV9R06e]K@1mOGd0:BTY04U9B@16ATH0I6AT05UIF@2e
]KD06a/K02LW9`1>CTh0>SXj03De=@1^KVh0IVIV01HF5P0R8R80Ng]k07UiN@1@D500JFUY028R8P0B
4Q80:BTY075aL@1GEeL0D51@07QhN00^;Rh06ATI03@d=026QXH0C4a<05mOG`1TI6@0:BTY0492@P1?
Cdl0Fe]K03@d=01?Cdl0;Bd]02LW9`2@T900ZJVY02l_;`0a<C40?Cdm0080;Bd]0?l0P82008:2PP0Y
:BT0@41004m?C`0f=SH0MgMg0=oOg`1WIfL04a<C04E5A@1ZJVX0F5QH09>CT`2HV9P0<c<c0410@01O
Gel0Cdm?05aLG02?Shl0GemO010@401@D500JVYZ065QH@1UIFD0YJFU04I6AP0B4Q80Jf][0:^[Z`1X
J6P0I6AT05EEE@0X:2P0CTi>06QXJ01OGel09RHV051@D01;Bd/0=cLg055AD@1mOGd0EEEE02d];@1O
Gel0>CTi04Q8B01EEED0R8R802XZ:P0O7al0C4a<02TY:@0U9BD0=3@d07MgM`0X:2P0;Rh^04e=C@14
A4@0C4a<07IfMP17AdL0820P02@T9012@T80ADE505IFEP1VIVH0>SXj01dM7@0Y:BT0IVIV09JFUP1K
Fe/0Ti>C028R8P0S8b<0<C4a06IVIP1DE5@0I6AT06][J`0S8b<0?Shn05UIF@11@D40S8b<03Xj>P0R
8R80@41007inOP1`L700ATI60;Zj^P14A4@0?clo06YZJP1FEUH0E5AD04i>CP37alL0>CTi03Ph>01`
L700MgMg04I6AP0n?Sh0KVi^02LW9`0i>CT0J6QX0:JVYP1GEeL0F5QH06=SH`0g=cL0AdM706IVIP1^
KVh0:2PX05iNGP0_;bl0>c/k07EeM@1]KFd0B4Q803`l?017AdL0;bl_0451@@1/K6`0LG5a04Y:BP19
BDT0A4A403lo?`2;Rh/0UYJF03dm?@0[:b/0De=C03Ti>@1XJ6P0ZZZZ08>3P`0[:b/0>c/k05aLG014
A4@0UIFE07QhN00^;Rh0>3Ph04Y:BP1MGEd0Xj>S04E5A@0K6a/0CTi>05YJFP1GEeL0MGEe08V9R@0e
=CD0E5AD06IVIP1JFUX0GemO07MgM`0d=3@08b<S05UIF@1jNWX0K6a/0;fm_@1BDU80?Shn04U9B@1d
M7@0BTY:07=cL`2DU9@0D51@03hn?P1hN7P0QhN704e=C@1NGUh0SXj>03/k>`14A4@0GemO08n?S`1Z
JVX0Ogmo05YJFP0c<c<0A4A405EEE@1XJ6P0>CTi06m_K`0g=cL0<C4a04U9B@1BDU80G5aL03Ti>@1Z
JVX0FUYJ02d];@1>CTh0Z:RX06a/K00c<c<0EEEE06QXJ00_;bl0Fe]K0:>SX`1GEeL05ADE03Hf=P1<
C4`0=cLg07MgM`2UYJD0Cdm?020P800f=SH0?clo04A4A01]KFd0TI6A02DU9@0e=CD0E5AD05]KF`11
@D40Cdm?0:^[Z`0e=CD07QhN03lo?`2BTY80RHV904Q8B01BDU80CDe=06EUI@1OGel004H0?Cdm05]K
F`1GEeL0@D51030`<00k>c/0HV9R05QHF01GEeL0MGEe075aL@2@T900G5aL055AD@1MGEd08b<S04M7
A`0f=SH0>CTi03Ph>011@D40EUIF03/k>`1OGel0ATI603`l?011@D40<c<c05aLG01bLW80Jf][04a<
C01EEED0H61P04Y:BP1BDU80<S8b04I6AP1ADE40@D5105ADE00a<C40=CDe04I6AP0o?cl0EEEE05mO
G`0h>3P0?clo059BDP1=CDd0Cdm?024Q8@0Z:RX0Bd];06IVIP1XJ6P07alO038b<P1=CDd0<c<c06EU
I@1ADE40C4a<04U9B@1MGEd0FUYJ05aLG01FEUH0H61P0P1MGEd0EP0l?3`0JFUY05mOG`1_Kfl0EEEE
02h^;P0j>SX0IVIV03/k>`19BDT08b<S038b<P0l?3`0FEUI05EEE@1?Cdl0GemO0492@P0c<c<0<30`
0451@@1HF5P0BDU903Hf=P1>CTh0DU9B04M7A`0/;2`0BTY:061PH00h>3P0GUiN04=3@`1JFUX0CTi>
04I6AP1BDU80B4Q803dm?@1<C4`0O7al08N7Q`15ADD0De=C04U9B@1IFET0De=C04];B`1=CDd0?Cdm
04Q8B00c<c<0Fe]K069RHP0l?3`0K6a/03dm?@1DE5@0=cLg03De=@1<C4`0WinO030`<02/[:`0MgMg
03hn?P1aLG40HV9R04a<C01]KFd0:b/[08f=S@2OWil0?clo05eMG@0b<S80GemO03<c<`0k>c/0GEeM
075aL@17AdL0De=C096AT@1CDe<0V9RH0`1ADE40U`1SHf<0GEeM051@D01kNg/0Kfm_07QhN01ADE40
EUIF059BDP1jNWX0Kfm_03/k>`1eMGD0De=C04I6AP1:BTX0CTi>075aL@0i>CT0B4Q805aLG00b<S80
HF5Q02l_;`1PH600GUiN03/k>`19BDT0ATI603/k>`13@d<0Cdm?05YJFP1?Cdl0LW9b03<c<`1YJFT0
QhN703De=@17AdL0C4a<04];B`1EEED0@D510:^[Z`2`/;00@41004i>CP0c<c<0@D5107moO`0b<S80
IFEU05MGE`1WIfL0LW9b05YJFP1iNGT0IfMW08R8R01KFe/0G5aL07AdM01=CDd0=SHf06ATI01cLg<0
De=C05IFEP1IFET0CDe=05UIF@1GEeL0RXZ:04m?C`1>CTh0GUiN04e=C@1BDU80FUYJ0:6QX@1XJ6P0
DU9B07inOP1WIfL0M7Ad06QXJ00g=cL0DU9B02/[:`1[Jf/0JVYZ038b<P13@d<0=SHf04E5A@12@T80
=cLg059BDP0U9BD0Bd];03Ti>@19BDT0@d=303`l?00j>SX0?Cdm06EUI@1SHf<0@D5104e=C@1YJFT0
=CDe04Q8B00b<S80Bd];0410@01BDU80@D5105]KF`1LG5`0EUIF05EEE@1JFUX0Rh^;06m_K`1gMgL0
QXJ604a<C00e=CD0@T9204M7A`2CTi<0De=C04M7A`1?Cdl0?Cdm051@D01ADE40?clo04Y:BP1KFe/0
Jf][03hn?P1BDU80IFEU04m?C`1:BTX0DE5A04m?C`1oOgl00_ooool0000C09BDU01LG5`0DU9B07Qh
N01NGUh0IfMW05UIF@18B4P0EeMG0861P@17AdL0ADE505EEE@10@400D51@08b<S01iNGT0;Rh^06YZ
JP0204];B`1J05]KF`1YJFT0>3Ph024Q8@14A4@09bLW03@d=01jNWX0Bd];01LG5`1<C4`0@D5102TY
:@1aLG40QHF501/K6`0Q8B40?Shn03Xj>P1=CDd0Y:BT0451@@0K6a/09BDU03dm?@19BDT0Hf=S0;Jf
]P0f=SH08B4Q02@T9016ATH0D51@09FEU@2][Jd06a/K02LW9`0e=CD0BTY:04A4A01;Bd/0<c<c02h^
;P0g=cL0IVIV0410@01CDe<0QhN701hN7P0`<300DU9B05MGE`1YJFT0Ogmo0:6QX@0Z:RX0?Cdm07Mg
M`2JVYX0;Rh^05EEE@0E5AD0:b/[04A4A01]KFd0=cLg03lo?`1^KVh0:BTY02DU9@1^KVh0N7Qh02h^
;P0j>SX0BTY:03Ph>01;Bd/0N7Qh04a<C00Q8B40=CDe04e=C@0h>3P0JFUY08b<S00G5aL0<30`04U9
B@1HF5P0@T920P22PX801P0Y:BT0AdM7055AD@1BDU80@T920:ZZZP80<S8b0:L0?clo05]KF`1GEeL0
Lg=c08:2PP0R8R80:BTY03Hf=P1XJ6P0EEEE07UiN@2<S8`07alO03Ph>01KFe/0Q8B404a<C026QXH0
Ph>302PX:013@d<0F5QH09JFUP1;Bd/0K6a/05QHF00[:b/0CTi>071`L01DE5@0BDU907IfMP1@D500
<30`05MGE`1nOWh0?3`l05UIF@1QHF40CDe=06=SH`1TI6@09RHV04m?C`1HF5P0<C4a030`<023Ph<0
YZJV03<c<`1GEeL0K6a/02TY:@18B4P0Rh^;08R8R00i>CT0BTY:059BDP0m?Cd0Fe]K09^KV`0d=3@0
8B4Q03/k>`1GEeL0FUYJ069RHP1eMGD0;2`/0410@01=CDd0PX:2069RHP28R8P0@41001PH600i>CT0
PH610410@01OGel0FEUI02TY:@17AdL0E5AD06MWI`1FEUH0N7Qh059BDP0b<S80EUIF07YjNP1WIfL0
=SHf07emO@0n?Sh0?clo05ADE01nOWh0DU9B05aLG00e=CD0<C4a0451@@1fMWH0Bd];07UiN@1?Cdl0
:BTY05mOG`22PX80ATI606a/K01]KFd0;Bd]04E5A@2b/[80CTi>059BDP1VIVH0;bl_03hn?P20P800
IFEU0451@@1GEeL0;Rh^03dm?@1cLg<0Jf][038b<P1=CDd0BDU904A4A017AdL0SXj>05MGE`0e=CD0
CTi>055AD@1IFET0HV9R0:ZZZP13@d<0ADE505MGE`1QHF40Jf][08J6QP2?Shl0<C4a04E5A@1>CTh0
FEUI061PH02XZ:P0NGUi03De=@10@400GEeM06ATI01ADE40WYjN059BDP0e=CD0>CTi075aL@02061P
H080Kfm_03L0?3`l02/[:`1/K6`0RHV903`l?01QHF40@T9203@d=00g=cL0IFEU09:BTP12@T80NWYj
03hn?P0[:b/0Bd];06=SH`1NGUh0>SXj06UYJ@10@400;bl_0410@01PH600EEEE030`<01FEUH0Vi^K
07inOP19BDT0D51@05YJFP1oOgl0M7Ad04Y:BP1nOWh0M7Ad04i>CP0_;bl0ADE50861P@1bLW80Kfm_
0;>c/`2YZJT0T92@069RHP1DE5@0GUiN0410@01@D500?3`l03hn?P16ATH0DE5A0080IFEU02L0P820
05UIF@1RHV80DE5A04E5A@1eMGD0Shn?0820P01RHV80MgMg06e]K@1DE5@0EeMG02d];@0b<S80EeMG
06ATI01PH600>SXj04i>CP1EEED0@D5104];B`1/K6`0A4A403hn?P1;Bd/09bLW04];B`0[:b/0;2`/
04=3@`1>CTh0GEeM014A4@0X:2P0CDe=03`l?01ADE400P0o?cl0:P15ADD0Cdm?05EEE@1/K6`0G5aL
03lo?`16ATH0CTi>04Q8B01KFe/0<C4a03hn?P1WIfL09RHV0410@01RHV80<S8b069RHP0h>3P0;bl_
03lo?`1EEED0AdM704A4A01ADE40>CTi03De=@0^;Rh0:b/[0410@00^;Rh0<c<c03De=@0k>c/0>3Ph
03<c<`0W9bL0<c<c01dM7@1EEED0Cdm?04A4A080C4a<0;X0EEEE04E5A@1=CDd0A4A4075aL@1bLW80
B4Q805aLG01:BTX0EEEE04M7A`1BDU80BTY:05ADE01aLG40@T9204=3@`1<C4`0@d=306UYJ@0i>CT0
DU9B04M7A`14A4@0CTi>07UiN@13@d<0[Jf]06m_K`0b<S80IFEU06YZJP1JFUX0Ng]k02XZ:P1KFe/0
MGEe02h^;P1aLG40;Rh^04e=C@0H61P0K6a/04e=C@1>CTh0<30`04a<C02KVi/0B4Q809JFUP1IFET0
G5aL0451@@0b<S80<c<c03Ti>@2[Zj/0R8R80451@@1eMGD0Rh^;069RHP2CTi<0XJ6Q04U9B@1BDU80
AdM704i>CP1?Cdl0GEeM07IfMP0_;bl0BDU905=CD`1NGUh0TY:B04m?C`1ZJVX0PH6104Q8B01HF5P0
Jf][059BDP1TI6@0D51@04a<C01@D500S8b<04=3@`1]KFd0RHV904=3@`1<C4`0@D5103<c<`1[Jf/0
>SXj04m?C`1nOWh0?clo061PH01EEED08R8R0451@@13@d<0A4A402d];@1RHV80L71`04Y:BP1[Jf/0
MGEe0<30`01NGUh0Kfm_08R8R00e=CD0EUIF071`L01RHV80@d=304i>CP1LG5`0Bd];0861P@0a<C40
C4a<04=3@`1MGEd0<c<c02LW9`1OGel0;Rh^059BDP1CDe<0@D5107moO`1@D500JFUY06a/K019BDT0
EeMG03@d=01:BTX0FEUI03De=@0i>CT0=cLg04U9B@16ATH0@D5107=cL`19BDT0ADE503De=@1ADE40
EUIF059BDP1NGUh0;2`/069RHP1gMgL0<c<c04Q8B01LG5`0;Bd]07QhN01:BTX0OGem04Y:BP1<C4`0
ADE5061PH01FEUH0De=C09>CT`1FEUH0Ng]k05YJFP2KVi/0U9BD03Ti>@1NGUh0CTi>0410@01IFET2
04E5A@0@06i^KP0a<C40ATI603hn?P1IFET0GemO07]kN`2QXJ40;Rh^03De=@1fMWH0D51@04a<C01H
F5P0CTi>0:JVYP;ooooo0000<01fMWH0RXZ:04e=C@1[Jf/0D51@08b<S02BTY80>SXj04M7A`1IFET0
@D5107UiN@27QhL0<c<c04A4A01FEUH0IfMW04E5A@2BTY80=SHf02`/;018B4P0JFUY05QHF01LG5`0
KVi^02d];@0n?Sh0IVIV09NGU`1JFUX0Xj>S04I6AP0W9bL0?clo06m_K`19BDT0IVIV08^;R`0U9BD0
=3@d07]kN`21PH40ADE5061PH01JFUX07QhN0451@@80GemO08<0>3Ph04Q8B00n?Sh06ATI03Hf=P24
Q8@0CDe=03Hf=P1LG5`08B4Q03`l?025QHD0GEeM01LG5`0m?Cd0Hf=S03De=@1;Bd/0Ph>304I6AP0K
6a/0EEEE03Xj>P0];Bd0L71`0<C4a00f=SH09BDU06UYJ@1fMWH0FUYJ08^;R`0W9bL05aLG02LW9`1S
Hf<0BDU906=SH`1cLg<06a/K01XJ6P18B4P0U9BD05MGE`1lO7`0QhN701lO7`0/;2`0MgMg0:2PX01W
IfL0ZZZZ03dm?@0f=SH0@D5105aLG01RHV80BTY:07]kN`0T92@0:b/[0492@P1`L700?Cdm04M7A`1K
Fe/07QhN02PX:00f=SH0De=C038b<P1HF5P0@d=301DE5@0T92@0EeMG06QXJ00K6a/0AdM704a<C00J
6QX0=CDe08N7Q`1ZJVX0<C4a05YJFP0b<S80;bl_04M7A`28R8P0De=C02PX:01XJ6P0BTY:0410@01Q
HF40S8b<038b<P12@T80Fe]K03@d=015ADD0TI6A06i^KP0K6a/0:2PX04M7A`0k>c/0T92@079bLP0R
8R80E5AD05]KF`0g=cL0R8R809nOW`0g=cL0A4A4051@D02>SXh0FEUI0:6QX@2HV9P0=cLg03hn?P1=
CDd0JVYZ06IVIP2/[:`0Jf][03`l?00205ADE02O071`L016ATH0QHF505aLG00W9bL0FEUI07IfMP1>
CTh0?clo055AD@0e=CD0D51@0:6QX@1mOGd0<30`061PH00`<300<C4a05]KF`1hN7P08B4Q01`L7011
@D40=CDe03Xj>P2<S8`0K6a/02HV9P0b<S80EEEE03Lg=`1@D500Ogmo06][J`0a<C40BTY:0451@@1S
Hf<0RHV9061PH00a<C40@4100492@P1EEED0Ogmo05mOG`0];Bd0?3`l04I6AP1NGUh0KFe]07QhN00f
=SH0>CTi05eMG@1BDU80IVIV09fMW@0Y:BT09BDU061PH01VIVH0EEEE07IfMP0];Bd0?3`l06e]K@1T
I6@0@d=306UYJ@1GEeL09RHV05ADE01CDe<0HF5Q04e=C@2CTi<0?Cdm02XZ:P1GEeL0LW9b06YZJP1[
Jf/0TI6A04Y:BP14A4@0DE5A08n?S`1GEeL0Ng]k08R8R00c<c<09BDU06IVIP1mOGd0BDU905IFEP1o
Ogl0>SXj02LW9`2SXj<0Vi^K03Hf=P0i>CT0GUiN03Hf=P0e=CD0G5aL07QhN00n?Sh0D51@06a/K00a
<C40DU9B06UYJ@1DE5@0<C4a03Hf=P0c<c<0@d=304U9B@2?Shl0I6AT02LW9`0f=SH0DU9B03Ti>@1D
E5@0IFEU05aLG00S8b<0=CDe069RHP1;Bd/0H61P0:ZZZP2LW9`0R8R8069RHP1ADE40Kfm_06ATI01[
Jf/0@D5105ADE024Q8@0Cdm?04Y:BP1GEeL0IVIV08Z:RP1_Kfl0Lg=c069RHP1oOgl0FUYJ04a<C01G
EeL09bLW0080@D510740Fe]K04i>CP1:BTX0@D5103Lg=`1XJ6P0I6AT0861P@1=CDd0>CTi05ADE02;
Rh/0De=C04=3@`1HF5P0EUIF08Z:RP1@D500AdM7051@D017AdL0>CTi04A4A01JFUX0E5AD051@D013
@d<0CTi>05MGE`15ADD0De=C05YJFP0f=SH0GUiN03Ti>@0f=SH0Cdm?04];B`1OGel09bLW03Lg=`1Q
HF40>SXj05UIF@1LG5`0CDe=05eMG@1PH600JVYZ06][J`1TI6@0ATI605QHF01RHV80AdM7079bLP1:
BTX0Cdm?06e]K@0l?3`0=3@d051@D00o?cl0DE5A02h^;P1:BTX0B4Q805aLG00l?3`0Bd];069RHP14
A4@0?3`l03<c<`0h>3P0EeMG03/k>`16ATH0BDU905UIF@14A4@0?Shn04I6AP1>CTh0<30`06MWI`1E
EED0GemO04U9B@1;Bd/0FEUI04I6AP19BDT0G5aL06][J`1:BTX0?Shn06][J`1>CTh0EUIF0410@01D
E5@0O7al04U9B@1LG5`0?clo04Y:BP1RHV80Cdm?05YJFP0h>3P0D51@05aLG00207AdM00K09VIV@1V
IVH0e=CD0;Jf]P1CDe<0Hf=S06QXJ01ZJVX0SHf=05IFEP1fMWH0MgMg04a<C01]KFd0EEEE05=CD`0U
9BD0@d=302TY:@11@D40C4a<0451@@1`L700<c<c0<g=c@0k>c/0Cdm?0080@d=305l0@T92030`<00i
>CT0A4A402/[:`0k>c/0@d=304M7A`1eMGD0WIfM06IVIP1aLG40K6a/05MGE`1:BTX0DU9B05YJFP10
@400ATI605mOG`0a<C40BTY:02d];@1OGel0Ogmo05=CD`1lO7`0LG5a03dm?@11@D40>CTi04e=C@1S
Hf<0XZ:R03lo?`1jNWX0TI6A04E5A@1VIVH0IfMW05iNGP1oOgl0>c/k06e]K@26QXH0L71`06EUI@1D
E5@0D51@04m?C`1<C4`0JFUY04=3@`1BDU80DE5A03/k>`12@T80>c/k05mOG`17AdL0N7Qh079bLP1A
DE40@T920861P@1?Cdl0Bd];03Ti>@0o?cl0@D5104a<C012@T80GUiN04U9B@1@D500DE5A03Lg=`1>
CTh0ATI6071`L01VIVH0BTY:08J6QP17AdL0MGEe06UYJ@1ADE40JFUY02`/;01SHf<0IVIV03De=@1=
CDd0B4Q80451@@0204=3@`0e0:FUY@0o?cl0AdM702HV9P1NGUh0Bd];02l_;`0`<300>CTi05=CD`1E
EED0:2PX0451@@1DE5@0:BTY0410@012@T80ADE504=3@`1^KVh0De=C05mOG`0n?Sh0OGem0;no_`1e
MGD0XJ6Q06EUI@1SHf<0Cdm?03@d=02>SXh0K6a/04I6AP1YJFT0ADE503Ph>01<C4`0B4Q805UIF@17
AdL0ATI603dm?@1MGEd0PH6104U9B@18B4P0HV9R05EEE@1@D500E5AD05]KF`1fMWH00_ooool0000;
06QXJ024Q8@0SXj>08:2PP1;Bd/0ADE5075aL@1OGel0QhN708^;R`0`<3000P1>CTh0[P1@D500BDU9
07UiN@0P8200<30`04Y:BP1gMgL0>3Ph06QXJ011@D40>3Ph03hn?P1OGel0@T9205MGE`2FUYH0=SHf
01lO7`1@D500Bd];02<S8`17AdL0>3Ph03<c<`0h>3P0H61P03@d=00R8R80DU9B04=3@`1IFET0TI6A
061PH00^;Rh0:2PX04Q8B01>CTh0EeMG08N7Q`1WIfL07QhN01lO7`1;Bd/0DU9B08R8R02HV9P0820P
01dM7@10@400J6QX06a/K01jNWX0MGEe020P800e=CD0CDe=06a/K01?Cdl0/;2`03Ti>@0L71`0>SXj
07QhN01eMGD0CDe=0::RXP0f=SH0820P04U9B@1LG5`0?clo05MGE`0^;Rh0?Cdm05mOG`1RHV80GEeM
038b<P1nOWh09bLW02PX:00m?Cd0F5QH02l_;`0Z:RX0@D5101hN7P11@D40KFe]06QXJ00M7Ad0=CDe
03@d=00m?Cd0De=C096AT@0e=CD05ADE03Ph>00n?Sh0?clo09VIV@2PX:009bLW02TY:@13@d<0E5AD
04M7A`21PH40Rh^;024Q8@0M7Ad0@41005mOG`16ATH0TY:B051@D00P8200AdM704Q8B01PH600HF5Q
09ZJVP0g=cL0:BTY0451@@1JFUX0LG5a05EEE@2SXj<0<c<c03@d=01TI6@0QXJ6069RHP1jNWX0MgMg
02HV9P0`<300DE5A08^;R`17AdL0FUYJ05IFEP0T92@0>3Ph08B4Q01ADE40Ogmo04U9B@0X:2P0ATI6
0820P016ATH0:RXZ05mOG`0/;2`0ADE505ADE02GUiL0FEUI06IVIP1eMGD09bLW03Lg=`2BTY80[jn_
0451@@0o?cl0IFEU03lo?`0n?Sh0ZJVY0<71`@80@D5109H0LW9b05UIF@1TI6@0Hf=S02PX:00a<C40
G5aL05eMG@1FEUH0/;2`04m?C`0H61P0<c<c06a/K014A4@0G5aL08n?S`0^;Rh08B4Q055AD@2MWId0
Bd];06UYJ@1fMWH08b<S030`<01lO7`0NWYj06EUI@2TY:@0@410030`<01[Jf/0W9bL051@D01ZJVX0
=SHf03Xj>P1XJ6P0K6a/04i>CP1cLg<0?Cdm02@T901oOgl0Z:RX05EEE@1OGel0L71`03lo?`1?Cdl0
]kNg07inOP1<C4`0G5aL0410@01KFe/0R8R807EeM@0_;bl0Hf=S04];B`14A4@0UIFE09nOW`15ADD0
BTY:08j>SP19BDT0FEUI0;jn_P2MWId0?Cdm03lo?`1SHf<0>3Ph065QH@2k^k/0Cdm?0410@01;Bd/0
Cdm?04M7A`1lO7`0[Jf]055AD@0Y:BT0B4Q805MGE`1:BTX0I6AT08>3P`0h>3P0820P05ADE029RHT0
Jf][06ATI01NGUh0;Rh^03hn?P17AdL0LG5a04a<C01;Bd/0L71`028R8P0g=cL0KVi^069RHP0n?Sh0
GemO051@D00H61P0<C4a05iNGP2KVi/0?Cdm03`l?014A4@0:RXZ04U9B@1;Bd/0HF5Q03dm?@14A4@0
N7Qh02HV9P0[:b/0O7al09JFUP1ZJVX0ADE5055AD@1EEED0KFe]05]KF`14A4@0G5aL04m?C`10@400
F5QH05mOG`1NGUh0LG5a05ADE02o_kl0^KVi0820P01^KVh205MGE`0X02DU9@1VIVH0@d=304e=C@1<
C4`0G5aL05=CD`0n?Sh0D51@04U9B@1GEeL0BTY:03Lg=`0j>SX0D51@05aLG01?Cdl0FEUI051@D00j
>SX0Bd];02d];@0Y:BT0@D5104A4A01EEED0?Shn03Xj>P0o?cl0<S8b051@D01GEeL0=3@d03Hf=P1>
CTh0A4A404I6AP0X:2P0>SXj04=3@`80EeMG05H06a/K051@D01EEED0=CDe05=CD`1IFET0GUiN05MG
E`1@D500GUiN09:BTP1/K6`0@D5105IFEP1RHV80I6AT06][J`13@d<0B4Q80451@@0N7Qh08b<S05YJ
FP0e=CD0HV9R02XZ:P1;Bd/0>CTi0492@P11@D40@d=305ADE00n?Sh0A4A402d];@0n?Sh0BDU90410
@00h>3P0@d=30492@P0m?Cd0=3@d04E5A@18B4P0;Bd]05=CD`18B4P0D51@05iNGP0m?Cd0DE5A05QH
F01QHF40ATI6075aL@1IFET0CDe=061PH01<C4`0HF5Q051@D01JFUX0@41004Y:BP1_Kfl0ATI6059B
DP1IFET0?clo065QH@0Z:RX0FUYJ04I6AP0j>SX0GemO08j>SP1RHV80QXJ606UYJ@0V9RH0E5AD08F5
Q@1WIfL0Ph>306i^KP80Shn?0:L0FUYJ06EUI@1JFUX0J6QX04i>CP1VIVH0C4a<0451@@0l?3`0A4A4
07AdM00/;2`0JFUY03Lg=`1BDU80DE5A08B4Q01RHV80ADE506][J`1KFe/0410@04];B`1oOgl08B4Q
0451@@1VIVH0@D5109^KV`1LG5`0BTY:04M7A`14A4@0Ph>302LW9`14A4@0CTi>02`/;022PX80>3Ph
06a/K01^KVh0820P0410@00^;Rh0<S8b04e=C@0m?Cd0Fe]K055AD@1dM7@0=CDe04Y:BP1_Kfl0=CDe
04I6AP1GEeL0AdM704U9B@1FEUH0MWIf09>CT`1RHV80Lg=c04M7A`0h>3P0EEEE02<S8`15ADD0<30`
05MGE`1JFUX0G5aL06ATI01;Bd/0RXZ:03/k>`0o?cl0IVIV030`<01HF5P0IFEU04I6AP0o?cl0DU9B
04a<C00o?cl0HV9R04Y:BP1eMGD0D51@05=CD`1JFUX0B4Q805=CD`1EEED0TY:B06][J`0m?Cd0L71`
04i>CP28R8P0MWIf03Ti>@1BDU80:BTY05aLG01QHF40>c/k04Q8B017AdL0CDe=04E5A@0i>CT0GEeM
02d];@1BDU809bLW05iNGP1=CDd0>SXj04e=C@0_;bl0PH6107alO01@D500LW9b06YZJP11@D40D51@
02d];@1HF5P0=SHf04=3@`1=CDd0EEEE0451@@18B4P0F5QH059BDP1LG5`0FEUI09FEU@2@T900D51@
04U9B@0e=CD0CDe=07QhN019BDT0ADE504Y:BP0E5AD0?Shn051@D00k>c/0AdM706m_K`2PX:00F5QH
069RHP2>SXh0Jf][05]KF`1PH600CDe=07AdM002ooooo`000<d0Ng]k05MGE`1@D500U9BD061PH01?
Cdl0Fe]K03Xj>P1mOGd0UYJF03lo?`1EEED0H61P055AD@1iNGT0TY:B0410@00f=SH0CTi>04Q8B01H
F5P0^k^k092@T00L71`0?Shn03@d=00/;2`0GEeM0;Fe]@12@T80=SHf03<c<`16ATH0IfMW0;Vi^@2G
UiL06a/K02XZ:P1ADE40Jf][07UiN@2l_;`0Cdm?02/[:`0m?Cd0RXZ:07UiN@2>SXh0MgMg01lO7`0b
<S80GemO079bLP17AdL0DE5A03Hf=P0F5QH092@T04=3@`1>CTh0<30`04a<C00L71`0;Bd]061PH01T
I6@09bLW02TY:@1:BTX09RHV04i>CP2_[jl0L71`01PH600m?Cd0>3Ph02DU9@1KFe/0fMWI06ATI00N
7Qh0>CTi03Lg=`15ADD0V9RH07=cL`0P8200?Cdm04m?C`1>CTh0?Shn0;Vi^@1JFUX07AdM04M7A`1W
IfL0BTY:05=CD`25QHD08b<S03`l?011@D40M7Ad04M7A`1^KVh0JFUY020P800a<C40P82007]kN`0j
>SX0EeMG04a<C00M7Ad0ADE508n?S`1eMGD0AdM706=SH`0Q8B40;2`/05MGE`2=SHd0FUYJ03Ph>01R
HV80:2PX03<c<`1DE5@0W9bL04M7A`1OGel0D51@02XZ:P0X:2P0GemO079bLP0_;bl0CDe=05]KF`0c
<c<09bLW06i^KP1jNWX09BDU03hn?P19BDT0?Shn09NGU`1gMgL07AdM024Q8@0j>SX0A4A405IFEP1h
N7P0GemO01TI6@0c<c<0Cdm?06ATI02OWil0HF5Q01HF5P19BDT0K6a/03`l?01BDU80_kno04e=C@0I
6AT0BTY:07emO@1JFUX0Ti>C0;jn_P14A4@092@T05=CD`2SXj<0L71`07UiN@2<S8`0<30`02/[:`18
B4P0M7Ad07]kN`2BTY80W9bL02@T901HF5P0O7al06IVIP1]KFd0`/;204U9B@0S8b<0L71`09FEU@0m
?Cd0EeMG05]KF`0f=SH0=cLg0080F5QH0?h0>CTi059BDP1:BTX0=cLg0451@@23Ph<0Bd];05aLG01a
LG40>SXj0451@@1VIVH0H61P034a<@0l?3`0<S8b04M7A`1SHf<0JVYZ02<S8`10@400E5AD04U9B@2:
RXX0IfMW02/[:`18B4P0O7al069RHP20P800VYZJ02TY:@1<C4`0F5QH05iNGP1YJFT0[Zj^03Ti>@0m
?Cd0QhN706=SH`1DE5@0/k>c05UIF@0V9RH0Hf=S08R8R01<C4`0OWin09VIV@1@D500:b/[07IfMP2R
XZ80JVYZ07UiN@2ATI40CDe=03lo?`1aLG40RHV904=3@`1bLW80Jf][04=3@`10@400DE5A06=SH`1=
CDd0T92@0410@00_;bl0?3`l05=CD`1IFET0?3`l05aLG00e=CD0?Cdm05=CD`1RHV80BDU90451@@1N
GUh0BTY:038b<P0k>c/0KFe]03<c<`0I6AT0BDU903@d=00k>c/0JVYZ08F5Q@0c<c<06a/K03Ph>01K
Fe/0De=C05YJFP1oOgl07AdM02LW9`1FEUH0L71`03lo?`1OGel0Z:RX02d];@0I6AT0>SXj09>CT`2D
U9@0BTY:055AD@1GEeL0K6a/07AdM01EEED0Fe]K06IVIP0b<S80>CTi04i>CP2CTi<0]KFe06QXJ01Y
JFT0CDe=06YZJP1QHF40E5AD05UIF@0U9BD0?Cdm02h^;P18B4P0A4A403/k>`1BDU80@d=308V9R@1]
KFd0D51@04m?C`1>CTh0Fe]K08N7Q`1_Kfl0KFe]08:2PP1fMWH0EEEE05YJFP0c<c<0?clo05]KF`1C
De<0IVIV04M7A`1DE5@0H61P03`l?019BDT0EeMG03hn?P0l?3`0ADE502LW9`10@4009BDU02TY:@14
A4@0Hf=S05QHF00B4Q80:BTY059BDP17AdL0MGEe04Y:BP0];Bd0ADE504e=C@1:BTX0=SHf04Q8B00m
?Cd0BDU904e=C@0d=3@0HF5Q04a<C01VIVH0GUiN02DU9@0^;Rh0@4100451@@1MGEd0;bl_055AD@1?
Cdl0FUYJ03hn?P1?Cdl0K6a/03Hf=P0k>c/08R8R05EEE@1@D500;bl_03De=@1;Bd/0?clo03Ti>@0b
<S80Cdm?05YJFP0P8200D51@04];B`1=CDd0=SHf03Ti>@1cLg<0>3Ph03dm?@0k>c/0SXj>05ADE00f
=SH0E5AD04i>CP1IFET0?Shn03dm?@1>CTh0DU9B06ATI012@T80F5QH05UIF@14A4@0De=C03dm?@1O
Gel0BTY:04i>CP1mOGd0XZ:R05ADE080Vi^K03L0?Cdm05EEE@21PH40HV9R07AdM00];Bd0CDe=0820
P01<C4`0Q8B404E5A@13@d<0<30`0:>SX`2FUYH0KVi^04M7A`1RHV80QXJ606=SH`37alL0HF5Q05=C
D`16ATH0A4A404e=C@17AdL0MWIf05ADE00_;bl0=3@d04a<C00];Bd0HF5Q0:NWY`1?Cdl0HF5Q034a
<@0g=cL0?Cdm03/k>`1oOgl0=cLg0451@@1BDU80?Cdm06e]K@0n?Sh0Fe]K06YZJP1?Cdl0Hf=S04Y:
BP0n?Sh0IfMW0080@41004d0IVIV0;Jf]P0i>CT0EeMG07AdM00^;Rh0MWIf06=SH`0f=SH0F5QH0451
@@2/[:`0^;Rh06=SH`29RHT0B4Q804Y:BP1jNWX0=SHf08b<S00`<300Hf=S06m_K`1ADE40IfMW059B
DP2EUID0=cLg061PH01UIFD0?Cdm03`l?023Ph<0B4Q803lo?`1MGEd0F5QH055AD@1HF5P0>CTi04A4
A01=CDd0F5QH03Xj>P0P8200FUYJ02HV9P1ADE40B4Q803Xj>P1hN7P0ATI6059BDP1>CTh0@T9206AT
I00K6a/0CDe=055AD@0e=CD0>SXj04e=C@0m?Cd0@T9203dm?@1bLW80<C4a05MGE`0W9bL0FUYJ06AT
I01VIVH0DU9B05mOG`1;Bd/0?clo0410@002051@D00W03lo?`1aLG40?3`l05IFEP0^;Rh0D51@0492
@P1nOWh0EeMG05IFEP22PX80CDe=08R8R01YJFT0Cdm?05ADE00[:b/0Cdm?03lo?`0l?3`0G5aL04Y:
BP14A4@0GEeM01TI6@1BDU80;bl_05EEE@1DE5@0M7Ad0::RXP0`<300=cLg05YJFP14A4@0ATI605aL
G01VIVH0HV9R00;ooooo0000G@2SXj<0H61P05EEE@1NGUh0GEeM07UiN@20P800=CDe05aLG028R8P0
Cdm?08n?S`2ATI40=SHf04U9B@2VYZH0QhN705ADE020P800=3@d01dM7@1XJ6P0VYZJ05ADE01HF5P0
?Cdm01TI6@0O7al0IFEU09>CT`15ADD0NWYj02h^;P0X:2P0LG5a08f=S@0b<S80?3`l05YJFP0K6a/0
=cLg07YjNP21PH408b<S03@d=00j>SX0;Bd]06=SH`2PX:00EeMG01DE5@0g=cL0@d=305ADE02IVIT0
QXJ602<S8`0b<S80DU9B03dm?@1QHF40[Jf]03De=@0I6AT0<C4a06IVIP19BDT0IFEU0820P00W9bL0
;Bd]06UYJ@2SXj<0AdM708j>SP1QHF407QhN034a<@22PX80b<S804m?C`1XJ6P05ADE02l_;`1CDe<0
LW9b04];B`1ZJVX0IfMW018B4P0a<C40Bd];061PH00205EEE@2606ATI00J6QX0=3@d069RHP1ADE40
;bl_075aL@11@D40?3`l06EUI@1fMWH0:b/[03<c<`1ADE40>SXj030`<01eMGD0JVYZ02h^;P0i>CT0
>c/k0492@P1<C4`0LW9b03Lg=`0/;2`0ATI605iNGP1KFe/0EeMG06i^KP0S8b<0?3`l03Ph>01^KVh0
DE5A07MgM`1jNWX07QhN03Ti>@0j>SX0Fe]K05ADE02=SHd0O7al02XZ:P0n?Sh0EeMG06e]K@18B4P0
Rh^;08:2PP0I6AT0AdM709JFUP1FEUH0CDe=09fMW@0n?Sh08R8R05mOG`2=SHd0>3Ph04Y:BP1ZJVX0
;bl_08Z:RP2EUID0?Cdm06a/K01RHV807QhN02TY:@1cLg<0WinO03@d=01TI6@0B4Q801dM7@0g=cL0
M7Ad05mOG`0X:2P0?Cdm03Ti>@0h>3P0Bd];09BDU01?Cdl09bLW04U9B@0h>3P0<C4a0820P02c/k<0
F5QH02`/;01<C4`0Cdm?06YZJP32`/80GUiN02d];@0j>SX0?clo03Hf=P1fMWH0X:2P02XZ:P0e=CD0
DU9B04M7A`1BDU80Ti>C07IfMP0_;bl0F5QH06UYJ@1JFUX0P8200;Jf]P0o?cl0Fe]K08R8R01TI6@0
DE5A08j>SP1@D500:b/[05IFEP1gMgL0A4A406UYJ@1RHV8204A4A00m0820P01BDU80SXj>04];B`0l
?3`0ATI609JFUP22PX80N7Qh07]kN`13@d<0AdM707moO`1eMGD0Cdm?069RHP0n?Sh0;bl_06=SH`1n
OWh0E5AD06QXJ014A4@0@d=305QHF02GUiL0HV9R03`l?01NGUh0?Shn05aLG01ZJVX0SXj>05=CD`1=
CDd0IFEU065QH@14A4@0N7Qh07EeM@0n?Sh0@D5105=CD`1;Bd/0J6QX0:FUY@2=SHd0:BTY0410@019
BDT0I6AT08F5Q@2QXJ40CDe=028R8P1CDe<0Fe]K04I6AP1bLW80/K6a06QXJ00202h^;P1@06ATI01W
IfL0E5AD092@T00/;2`0=3@d03Hf=P1bLW80MWIf06a/K01bLW80>3Ph02`/;00o?cl0M7Ad079bLP0k
>c/0Cdm?02TY:@0X:2P0BDU908b<S01lO7`0:RXZ061PH02JVYX0SHf=055AD@1GEeL0RXZ:07IfMP1O
Gel0>CTi05iNGP1gMgL0AdM704Y:BP1FEUH0L71`06IVIP20P800K6a/06EUI@1lO7`0EeMG05IFEP1@
D5007QhN04Q8B00j>SX0CDe=04];B`0m?Cd0?clo04E5A@1QHF40GemO09BDU01FEUH0>CTi04e=C@1o
Ogl0MgMg04];B`1CDe<0Fe]K06][J`1GEeL0;bl_04M7A`15ADD0>3Ph04M7A`1DE5@0GEeM05EEE@11
@D40ADE505YJFP1BDU8205]KF`0:03@d=01UIFD0=CDe038b<P1CDe<0FUYJ065QH@0N7Qh0:b/[055A
D@80<c<c03h0A4A404Q8B017AdL0@41004Q8B01eMGD0G5aL05ADE01ADE40De=C04U9B@1:BTX0;Bd]
02XZ:P1?Cdl0@41004=3@`1<C4`0?clo05ADE00`<300@d=302h^;P0j>SX0Bd];03`l?015ADD0?3`l
03dm?@0G5aL09RHV03Ti>@0a<C40;Bd]02/[:`0];Bd0?Shn02LW9`0X:2P0>3Ph01LG5`1CDe<0<C4a
03@d=014A4@0;Bd]03Ph>00Z:RX0ADE504=3@`1BDU80?Cdm04=3@`1BDU80@41004I6AP0j>SX0E5AD
04I6AP1XJ6P0Ogmo04Y:BP80EEEE05T0F5QH05iNGP0d=3@0De=C06IVIP15ADD0=SHf04A4A012@T80
^[Zj08>3P`0T92@0JFUY06ATI01oOgl0YjNW03<c<`1UIFD0LG5a03De=@1=CDd0ATI605eMG@0V9RH0
?Cdm05QHF01lO7`0EUIF07MgM`2m_Kd0Jf][0<71`@1IFET0KFe]03/k>`1FEUH0=cLg055AD@1iNGT0
IFEU05MGE`1`L700PX:207alO01dM7@0/K6a06][J`2ATI40FEUI03lo?`18B4P0H61P096AT@0_;bl0
EeMG06][J`12@T80HF5Q05iNGP1VIVH0Rh^;06][J`1TI6@0IVIV030`<01EEED0EUIF06QXJ01;Bd/0
Kfm_0451@@2;Rh/0SXj>03hn?P0k>c/0Bd];05ADE02CTi<0>c/k051@D01OGel0=3@d059BDP0c<c<0
71`L0451@@0d=3@0Bd];03Ti>@0205IFEP1B05eMG@1/K6`0B4Q805iNGP0g=cL0IfMW07EeM@0c<c<0
:b/[04i>CP0f=SH0CDe=02h^;P18B4P0=SHf06EUI@0];Bd0C4a<03<c<`0o?cl0ADE502/[:`1>CTh0
;Bd]06e]K@1BDU80>SXj09^KV`0n?Sh0GemO04a<C00m?Cd0CTi>01TI6@1MGEd0@D5102<S8`0b<S80
ADE504a<C01:BTX0DE5A061PH01HF5P0De=C0492@P1IFET0De=C05aLG01eMGD0;Rh^05MGE`1IFET0
@41005ADE00m?Cd09bLW04m?C`0d=3@0J6QX05aLG01DE5@0?3`l04E5A@13@d<0Bd];04e=C@0n?Sh0
M7Ad06a/K02CTi<0Jf][04A4A02@T900CTi>0410@01UIFD09RHV04i>CP1XJ6P0?3`l05mOG`<0@d=3
00X0LW9b0:2PX00o?cl0?Shn059BDP1@D500EUIF05EEE@1BDU80NWYj0_ooool0001:06ATI02e]KD0
KVi^06i^KP1;Bd/0HV9R09nOW`1JFUX0W9bL05MGE`0l?3`0E5AD075aL@0k>c/0?Shn04Q8B00c<c<0
RHV908J6QP12@T805aLG02h^;P1;Bd/0@d=309FEU@1_Kfl06a/K02h^;P1:BTX0De=C07AdM031`L40
:RXZ01lO7`1=CDd0Lg=c03lo?`1lO7`0WinO024Q8@0X:2P0AdM706IVIP1=CDd0PH6105mOG`0N7Qh0
>3Ph06ATI02GUiL0D51@08b<S023Ph<07alO04Y:BP2:RXX0GEeM04a<C01[Jf/09BDU02HV9P1BDU80
FUYJ0410@01GEeL0>CTi020P800j>SX0VIVI06a/K014A4@0O7al02l_;`14A4@206IVIP2202<S8`0o
?cl0CDe=04=3@`1KFe/0QXJ606EUI@0P8200BDU903lo?`16ATH0V9RH08b<S00V9RH0<c<c059BDP19
BDT0GEeM08^;R`2UYJD0;Rh^02HV9P1GEeL0N7Qh05=CD`32`/80?clo014A4@12@T80RHV904I6AP1b
LW80S8b<02LW9`0Q8B40@T9208j>SP0g=cL0LW9b05YJFP0Y:BT0ATI604e=C@1SHf<0@D5107YjNP0e
=CD05aLG04Y:BP1VIVH0GemO03Xj>P1mOGd08b<S01lO7`1<C4`0HF5Q0451@@16ATH0IVIV03/k>`0U
9BD0AdM709FEU@1QHF40De=C09:BTP0[:b/0;Bd]055AD@1eMGD0<C4a03De=@0g=cL0;bl_04I6AP1M
GEd0ATI602<S8`1ADE40@D5102PX:00c<c<0JVYZ024Q8@15ADD0B4Q803Xj>P1NGUh0Q8B401hN7P0P
8200D51@05iNGP1<C4`0YjNW07=cL`0S8b<0=3@d065QH@1[Jf/0FUYJ09VIV@10@4008R8R030`<01l
O7`0UYJF04Y:BP2GUiL0=CDe01lO7`0h>3P0PX:208Z:RP1gMgL0B4Q801dM7@0g=cL0AdM706][J`1?
Cdl0Xj>S05=CD`0];Bd0=cLg05aLG01VIVH0BDU905EEE@80:BTY04T0BDU908n?S`0k>c/0B4Q804Y:
BP0^;Rh0@41007alO01bLW80?clo05=CD`0e=CD0?Cdm05eMG@1cLg<0?Shn04m?C`0n?Sh0C4a<07=c
L`1jNWX0?clo04m?C`0n?Sh0@d=30<K6aP2JVYX0<S8b04Q8B01KFe/0?Shn09JFUP30`<00>CTi04m?
C`1XJ6P0FUYJ06ATI02NWYh0BTY:02l_;`1EEED0De=C05IFEP2a/K40AdM703Ti>@1DE5@0X:2P06][
J`1cLg<0_;bl065QH@0^;Rh0EeMG05=CD`1ZJVX0KVi^08b<S00f=SH0@d=304e=C@1TI6@0IVIV09nO
W`2;Rh/08B4Q03Xj>P1IFET0Ti>C07MgM`2TY:@0P8200080;Bd]07<0NWYj07alO01=CDd0B4Q804i>
CP0k>c/0=cLg06e]K@2SXj<0Cdm?04];B`1OGel0<C4a0410@01ZJVX0J6QX02l_;`17AdL0>SXj024Q
8@1CDe<0L71`06i^KP0c<c<0?Cdm04=3@`0h>3P0MGEe08n?S`10@4006a/K03Hf=P1RHV80E5AD06MW
I`2n_[h0QHF506UYJ@16ATH0C4a<05mOG`1/K6`0H61P04e=C@1]KFd0H61P04=3@`1EEED0LW9b096A
T@2;Rh/0R8R80:BTY02DU9@0TI6A05QHF01FEUH0EeMG030`<011@D40>c/k03hn?P1>CTh0EEEE0410
@00g=cL0G5aL04i>CP1=CDd0C4a<03Lg=`13@d<0De=C07IfMP1ADE40EeMG06][J`1BDU80Fe]K02@T
900j>SX0B4Q803Ph>01CDe<0>SXj04A4A01JFUX0=CDe04i>CP1QHF40?Shn03@d=01;Bd/0?Shn05=C
D`0a<C40>CTi04];B`1LG5`0FEUI01lO7`13@d<0EeMG03`l?01;Bd/0EEEE05QHF01DE5@0De=C06EU
I@2NWYh0Jf][034a<@0i>CT0BDU90080HV9R00D0<c<c03`l?017AdL07QhN028R8P0204a<C03W06QX
J00m?Cd0ADE504I6AP1;Bd/0>CTi0410@01<C4`0=3@d03Ti>@0L71`0DU9B04I6AP0^;Rh0<30`04I6
AP0d=3@0>CTi02DU9@1:BTX0Cdm?01lO7`1=CDd0@D5104A4A016ATH0=SHf04E5A@0S8b<0B4Q803/k
>`1/K6`0?Shn04e=C@1JFUX0@D5104m?C`1ADE40Fe]K04=3@`10@400J6QX02d];@1^KVh0CDe=03`l
?017AdL0>3Ph0492@P0_;bl0;2`/05YJFP1KFe/0<C4a07=cL`18B4P08B4Q04i>CP0g=cL0;bl_059B
DP0T92@0SHf=06e]K@0U9BD0FUYJ030`<019BDT0:BTY05mOG`1CDe<0FUYJ08F5Q@1IFET0G5aL03hn
?P2NWYh0?clo055AD@11@D40D51@02PX:00h>3P0E5AD055AD@0X:2P0MGEe0::RXP0l?3`0Fe]K07Qh
N01XJ6P0P82007AdM01IFET0ADE506ATI01iNGT0A4A405UIF@1DE5@0;2`/069RHP0^;Rh0UYJF0:BT
Y011@D40GemO06MWI`1ADE40HF5Q04Y:BP18B4P0DE5A08F5Q@1?Cdl0IfMW08^;R`15ADD0BTY:04];
B`14A4@0BTY:06QXJ02CTi<0VIVI03Xj>P1;Bd/0A4A403@d=01@D500=SHf05QHF016ATH0FEUI04a<
C01@D500De=C05QHF01lO7`0?3`l08b<S02YZJT0?Shn04M7A`1UIFD0<c<c03hn?P0_;bl0?Cdm04];
B`26QXH0DU9B05ADE01;Bd/0GUiN051@D014A4@0KVi^05IFEP1aLG40FUYJ05UIF@1lO7`0FUYJ06=S
H`1FEUH0Cdm?05iNGP0a<C40IfMW05YJFP15ADD0GUiN04e=C@1>CTh0F5QH04Y:BP1HF5P0=SHf06AT
I00/;2`0K6a/05YJFP13@d<0@D5102XZ:P1EEED0G5aL03lo?`1KFe/0=cLg02h^;P1FEUH0ADE507Mg
M`0j>SX0G5aL04M7A`1jNWX0CDe=04m?C`1MGEd0K6a/06YZJP1VIVH0KVi^06m_K`0h>3P0@T9203/k
>`1:BTX0IfMW03/k>`16ATH0DE5A01hN7P1FEUH0=3@d06e]K@1GEeL0DU9B06e]K@1CDe<0G5aL059B
DP1TI6@0L71`05IFEP1VIVH0Xj>S00;ooooo0000:P1NGUh0Ogmo09^KV`29RHT0ADE50492@P1ZJVX0
L71`0=[JfP22PX80<S8b03Ti>@1aLG40Jf][0:>SX`2;Rh/06a/K03@d=01QHF40MgMg05MGE`23Ph<0
CTi>02<S8`0f=SH0CDe=02`/;019BDT0JFUY02HV9P0g=cL0G5aL04a<C00_;bl0A4A403@d=00Q8B40
Cdm?0:f][@1jNWX0<30`03@d=080;2`/0:@0=cLg07QhN00h>3P0<C4a03`l?00d=3@0C4a<05iNGP25
QHD0C4a<03/k>`18B4P0=3@d08J6QP2UYJD0;Rh^01dM7@0i>CT0?3`l04M7A`2JVYX0IfMW01LG5`0I
6AT0>c/k04I6AP1EEED0bLW906=SH`0R8R80BTY:05]KF`13@d<0UYJF0<[:bP0Z:RX0?3`l07AdM01i
NGT0EEEE0;Fe]@1<C4`061PH04Q8B01mOGd0@d=306QXJ02JVYX0BTY:02d];@1[Jf/0TI6A0451@@1>
CTh0I6AT02LW9`0h>3P0OWin08F5Q@0j>SX0DE5A03Hf=P0_;bl0@T9205eMG@13@d<0>CTi05=CD`0e
=CD0=cLg05QHF01kNg/0:b/[02d];@0e=CD0?Cdm05MGE`2DU9@0D51@01TI6@0e=CD0@D5105ADE01L
G5`0WIfM03Lg=`0K6a/0A4A40410@016ATH0LG5a08b<S00_;bl09BDU03De=@13@d<0HV9R05eMG@3O
gml0ATI603@d=01mOGd0OWin04=3@`22PX80UiNG01dM7@0a<C40Lg=c05YJFP15ADD0V9RH04Q8B00E
5AD0A4A405MGE`0n?Sh0[:b/04E5A@0O7al0G5aL07MgM`1<C4`0?Cdm06m_K`0a<C40820P04M7A`1j
NWX0>SXj04m?C`1NGUh0=cLg03<c<`1VIVH0UIFE051@D00`<300Fe]K02@T9011@D40GemO06YZJP0^
;Rh0=3@d04A4A00l?3`0F5QH05iNGP0[:b/0<c<c04=3@`0Q8B40=CDe08Z:RP2EUID0>SXj03dm?@1N
GUh0B4Q807emO@2FUYH0?3`l02<S8`80AdM70200?Cdm0820P01iNGT0;2`/04e=C@1GEeL0GEeM06i^
KP2l_;`0;2`/03Hf=P1VIVH0Ng]k05]KF`2FUYH0ATI602/[:`1[Jf/0Shn?06MWI`1cLg<0=SHf02DU
9@1^KVh0]KFe06m_K`1ZJVX0J6QX034a<@13@d<0MWIf05mOG`80K6a/02L09RHV03hn?P1@D500J6QX
04a<C020P8007alO034a<@2IVIT0QHF5034a<@1@D500JVYZ03/k>`12@T80VIVI0:j^[P12@T80?clo
06MWI`0h>3P0DE5A0;fm_@1nOWh0=CDe04a<C01ADE40=cLg06i^KP32`/80HF5Q03lo?`18B4P0?Cdm
03De=@1gMgL0b/[:04e=C@0a<C400P1?Cdl0R@1^KVh0Zj^[05IFEP0K6a/0>3Ph051@D01WIfL0GEeM
06EUI@2MWId09BDU034a<@1dM7@0JFUY04U9B@1VIVH0BTY:028R8P0X:2P0Fe]K08:2PP1IFET0Ng]k
07MgM`0O7al09bLW06MWI`2VYZH0Cdm?071`L02GUiL0?clo02LW9`1IFET0QhN707moO`0e=CD0Cdm?
04];B`1fMWH0IVIV05=CD`20P800M7Ad034a<@1TI6@0G5aL06UYJ@2=SHd0K6a/05]KF`1CDe<0HV9R
055AD@1CDe<0Fe]K020P8013@d<0=CDe04Y:BP1ADE40Bd];05EEE@1WIfL0PX:207AdM01KFe/0F5QH
03lo?`18B4P0Kfm_06IVIP1<C4`0H61P07AdM01QHF40DU9B0410@01@D500De=C04];B`1FEUH0>CTi
04i>CP1YJFT0=3@d0451@@1RHV80A4A403lo?`1?Cdl0=SHf05IFEP0];Bd0:BTY04a<C01IFET0J6QX
01hN7P0Q8B40?clo04e=C@1EEED0BTY:04E5A@1=CDd0ADE504];B`1>CTh0DE5A04U9B@14A4@0BTY:
03dm?@1[Jf/0Cdm?051@D01QHF40=SHf03@d=01:BTX0?clo06YZJP1GEeL0E5AD0492@P14A4@0>SXj
04];B`1:BTX0>SXj03Ph>00/;2`09bLW04E5A@0^;Rh0A4A40080>3Ph00L0>c/k04M7A`0h>3P0ATI6
024Q8@1KFe/0?Shn0080A4A400d0=CDe055AD@0M7Ad0ADE503Xj>P1VIVH0>c/k03hn?P1?Cdl0BDU9
05aLG00c<c<0CDe=0080BTY:0780SHf=02l_;`0n?Sh0DE5A04U9B@1NGUh0CTi>05QHF017AdL0Bd];
06UYJ@1eMGD0@41007=cL`1/K6`0@41006a/K01YJFT0H61P079bLP14A4@0De=C051@D00^;Rh0JVYZ
03hn?P13@d<05ADE07emO@0m?Cd0GUiN03@d=013@d<0UiNG0410@02CTi<0@T9206e]K@0g=cL0EUIF
01`L701ADE40PX:205IFEP0P8200>SXj04Q8B00V9RH0EUIF06a/K00j>SX0TI6A04=3@`0i>CT0<c<c
05eMG@1lO7`051@D051@D01DE5@0A4A4092@T010@400HV9R061PH00j>SX0K6a/05IFEP0n?Sh0IVIV
03<c<`0h>3P0?3`l0861P@0f=SH0Kfm_06a/K00[:b/0JVYZ07AdM01>CTh0FEUI03/k>`1BDU80H61P
0410@01@D500<c<c0492@P1DE5@0:BTY05iNGP0_;bl0IFEU05aLG01GEeL0Bd];05]KF`1nOWh0=SHf
05MGE`1]KFd0G5aL0410@01VIVH0De=C055AD@1NGUh0F5QH05YJFP1iNGT0EeMG06e]K@1<C4`204m?
C`0802d];@1TI6@0>3Ph0861P@1hN7P0HF5Q09BDU01bLW8207QhN00V05]KF`1eMGD0C4a<06UYJ@1M
GEd0IVIV05iNGP18B4P0?3`l06EUI@1=CDd0Cdm?05]KF`24Q8@0@T9204a<C01BDU80K6a/06YZJP10
@400LG5a05QHF011@D40[:b/075aL@0l?3`0Lg=c03Ti>@1?Cdl0:RXZ059BDP1aLG40RXZ:06EUI@0o
?cl0Bd];051@D02@T90206YZJP0H05]KF`1>CTh0Y:BT069RHP0n?Sh0BTY:0492@P1]KFd0N7Qh04i>
CP1DE5@0@41004];B`1UIFD0PX:208j>SP1;Bd/0AdM7061PH01CDe<0EUIF07UiN@1lO7`0JFUY0_oo
ool0002d0:NWY`17AdL0IVIV08R8R01NGUh0J6QX05]KF`0g=cL0JVYZ0:FUY@10@400DE5A03Ph>014
A4@0BDU908R8R01@D500BTY:05EEE@0k>c/0>CTi06YZJP1SHf<08B4Q0492@P0j>SX0>c/k04Y:BP2Z
ZZX0Bd];01XJ6P1>CTh0FUYJ06YZJP2?Shl0F5QH01DE5@0S8b<0Fe]K08f=S@1VIVH0S8b<02h^;P0R
8R80;Bd]06QXJ01HF5P0QXJ609VIV@0[:b/0<C4a04m?C`28R8P0EEEE05MGE`0l?3`0;bl_06i^KP1o
Ogl0CTi>04U9B@1<C4`06a/K03<c<`1MGEd0LG5a034a<@1RHV80GUiN01`L700j>SX0LG5a08b<S00m
?Cd0Jf][04];B`0Z:RX0GemO09NGU`2CTi<0@T92065QH@0];Bd0@d=307moO`1UIFD0=3@d04];B`1D
E5@08R8R065QH@2/[:`0CTi>01DE5@0i>CT0J6QX02d];@1FEUH0RHV901LG5`0L71`0?3`l05YJFP1:
BTX0ZJVY07AdM00E5AD0=cLg06EUI@1?Cdl0I6AT0;bl_01@D5005QHF03hn?P1aLG40E5AD07IfMP1_
Kfl08b<S02l_;`1NGUh0TY:B04Y:BP2?Shl0SHf=02XZ:P0m?Cd0GEeM08>3P`0l?3`0K6a/055AD@0U
9BD0Hf=S07inOP1oOgl09BDU038b<P1BDU809BDU03@d=019BDT0LW9b03Lg=`1<C4`0ADE503`l?01E
EED0Kfm_05=CD`0`<300K6a/030`<00k>c/0XJ6Q08B4Q00g=cL0@41004e=C@0`<300Zj^[0;6a/@0]
;Bd0@41005eMG@1EEED0D51@0<30`01nOWh092@T04I6AP1<C4`0B4Q805IFEP2HV9P0<C4a03Ph>01I
FET0Fe]K0P1fMWH01P2d];@0;bl_03lo?`1;Bd/0LW9b06][J`80MWIf01L0:2PX03lo?`1EEED0Bd];
069RHP2>SXh0<C4a02d];@0_;bl0LW9b06ATI01QHF40Hf=S01/K6`0[:b/0MgMg06i^KP16ATH0RHV9
05aLG010@400A4A4079bLP0204A4A01k061PH00P8200BDU905aLG01=CDd0;2`/05UIF@0l?3`0@d=3
05aLG01fMWH0:b/[04=3@`1IFET0>3Ph08b<S01ZJVX0:BTY05IFEP10@400<S8b06m_K`2SXj<0=3@d
065QH@1CDe<0@d=306UYJ@2:RXX0;2`/03Ti>@1GEeL0HV9R06m_K`2e]KD0?Cdm02PX:01XJ6P0MWIf
06QXJ02:RXX0WYjN03Hf=P1<C4`0E5AD08^;R`24Q8@0P820075aL@0h>3P0ADE506QXJ02YZJT0JVYZ
09:BTP1=CDd0B4Q804i>CP1TI6@0U9BD08:2PP2WYjL0>SXj03Hf=P10@400J6QX08Z:RP1DE5@0JVYZ
03Xj>P0[:b/0Bd];08J6QP1?Cdl0FEUI07YjNP1:BTX0>SXj05MGE`1mOGd0Fe]K0451@@1YJFT0?Cdm
030`<01UIFD0MgMg03Ph>00b<S80BTY:03@d=00b<S80ADE507QhN00[:b/09RHV03Lg=`0Z:RX09bLW
05MGE`2TY:@0=CDe02`/;00o?cl0UIFE08:2PP12@T80EUIF04a<C01EEED0E5AD04];B`1KFe/0M7Ad
030`<01:BTX0GemO08f=S@2a/K40T92@07EeM@1gMgL0Ti>C0080EUIF01L0EEEE02HV9P13@d<0<c<c
0492@P1>CTh0>c/k03hn?P10@400IFEU05]KF`1YJFT0G5aL069RHP1IFET0HV9R06i^KP1LG5`0Ogmo
05QHF01FEUH0De=C03Hf=P020492@P0K034a<@15ADD0=cLg04=3@`1FEUH0<c<c04E5A@1CDe<0CDe=
04];B`1:BTX0;2`/06MWI`0f=SH0:BTY04Y:BP19BDT0G5aL03@d=00X:2P0AdM705ADE01ADE40IfMW
05mOG`1WIfL0CDe=0080KFe]00h0L71`03/k>`11@D40Bd];04I6AP1GEeL0<S8b03/k>`1EEED09RHV
02XZ:P1;Bd/0>3Ph069RHP80BTY:07/0?Cdm04E5A@15ADD0ATI604a<C018B4P0@D5102PX:00g=cL0
DU9B03`l?00m?Cd0>c/k0410@015ADD0=3@d03Hf=P10@400>CTi05]KF`15ADD0EUIF051@D00e=CD0
A4A402LW9`1=CDd0?clo06UYJ@1@D500ATI605YJFP0g=cL0FEUI03Hf=P1JFUX0JFUY02PX:01fMWH0
DE5A07moO`1LG5`0Bd];05mOG`0a<C40A4A405YJFP0m?Cd0De=C04a<C00W9bL0WIfM075aL@0X:2P0
EUIF05MGE`1[Jf/0X:2P03`l?01QHF40ATI602<S8`1dM7@0AdM704i>CP0e=CD0EeMG02`/;00m?Cd0
Bd];03Hf=P21PH40=CDe0<g=c@0h>3P0A4A404=3@`20P8009bLW04];B`1SHf<0EeMG01LG5`1NGUh0
L71`01dM7@1XJ6P0T92@04Q8B00h>3P0<S8b04a<C016ATH0A4A403`l?00/;2`0DE5A04a<C00N7Qh0
B4Q801hN7P29RHT0OGem05MGE`1lO7`0FUYJ0492@P1]KFd0CTi>04Y:BP1/K6`0UYJF05]KF`2NWYh0
QXJ603dm?@14A4@0Fe]K06MWI`29RHT0K6a/08B4Q023Ph<00P1NGUh08@1FEUH0>3Ph03Ti>@0b<S80
N7Qh055AD@1>CTh0ATI605MGE`1HF5P0?3`l05]KF`0b<S80Y:BT0=3@d01HF5P0D51@07MgM`1;Bd/0
HV9R03Lg=`17AdL0ATI606e]K@0g=cL0B4Q80492@P1GEeL0ADE502LW9`1SHf<0<S8b05aLG00204e=
C@0=08Z:RP14A4@0De=C04I6AP12@T80HF5Q03Ti>@1HF5P0B4Q803dm?@0g=cL0D51@03Ph>00204I6
AP0905]KF`18B4P0A4A404m?C`1nOWh0J6QX051@D014A4@0?Shn0080AdM702X0<c<c07QhN018B4P0
=CDe05=CD`0^;Rh0Ph>30451@@18B4P0?Cdm03`l?013@d<0?clo055AD@0l?3`0F5QH069RHP1lO7`0
BTY:034a<@1<C4`0EUIF05UIF@1SHf<0>3Ph03`l?01<C4`0<30`04Y:BP0M7Ad0ATI605ADE02HV9P0
[Jf]05MGE`1OGel0MGEe05]KF`1HF5P0I6AT059BDP1iNGT2ooooo`000?T0[Zj^09BDU01;Bd/0QHF5
07=cL`26QXH0OWin034a<@1IFET0Ti>C06=SH`2MWId0HF5Q04E5A@1LG5`0DU9B061PH01kNg/0MWIf
024Q8@0[:b/0J6QX07AdM00_;bl0QhN703Ph>00S8b<0Bd];08Z:RP1aLG40CDe=05]KF`0O7al0:BTY
051@D022PX80ADE5055AD@1DE5@0<S8b03Hf=P1KFe/0HV9R02HV9P0l?3`0>3Ph02XZ:P10@400N7Qh
05aLG00N7Qh0?3`l03Ph>01IFET0L71`05iNGP0S8b<0@d=306][J`0b<S80FEUI07inOP0R8R805aLG
051@D01[Jf/0?3`l08j>SP1XJ6P071`L01/K6`1TI6@0M7Ad05iNGP2[Zj/0@410020P800_;bl0RXZ:
0:NWY`1IFET0[Jf]01hN7P0T92@0ATI606EUI@13@d<0IVIV07=cL`0T92@0;bl_04];B`2BTY80AdM7
08b<S01LG5`092@T02h^;P23Ph<0DE5A04m?C`1WIfL09RHV02TY:@1KFe/0XJ6Q03<c<`0i>CT0FEUI
024Q8@0b<S80Rh^;09VIV@0];Bd0F5QH03hn?P0T92@0<c<c05eMG@10@400:b/[0410@00];Bd0820P
03Xj>P1gMgL0AdM703<c<`10@400;bl_0451@@1ADE40IfMW024Q8@0i>CT0C4a<04m?C`1DE5@0QXJ6
05aLG00N7Qh0@d=304Q8B01HF5P0EeMG0:VYZ@1:BTX08B4Q03hn?P1@D500?3`l059BDP2@T900=cLg
02LW9`0m?Cd0HF5Q04=3@`1jNWX0IfMW0451@@10@400QHF50410@01/K6`0?Shn02DU9@0o?cl0R8R8
0;^k^`1OGel0OGem061PH00`<300ADE508B4Q01hN7P0CDe=07YjNP0n?Sh0<30`05aLG026QXH0M7Ad
03hn?P1eMGD092@T03`l?01=CDd0Vi^K03hn?P0o?cl0@d=303Hf=P11@D40QXJ6079bLP0f=SH0EEEE
0451@@0h>3P0FUYJ0:2PX012@T80<c<c04I6AP12@T80?3`l08V9R@1KFe/092@T04e=C@1?Cdl0CDe=
07moO`2c/k<0@d=304I6AP1WIfL0I6AT06=SH`2GUiL0EEEE02LW9`1DE5@0Ph>304Q8B022PX80Ti>C
03De=@0m?Cd0HV9R03lo?`2GUiL0FEUI03<c<`18B4P0UYJF061PH02<S8`0Q8B403`l?01>CTh0Hf=S
071`L01EEED0Jf][038b<P1;Bd/00P1ZJVX0E`14A4@0Ph>304I6AP0n?Sh0PX:20:JVYP1RHV80EeMG
092@T00i>CT0D51@07alO02SXj<0H61P03lo?`1QHF40ATI606QXJ02:RXX0IVIV038b<P1<C4`0=SHf
0410@01ZJVX0XZ:R08^;R`0d=3@0@D5104E5A@14A4@0@41008V9R@1KFe/0;bl_0492@P14A4@0EeMG
05=CD`2@T900Cdm?034a<@1IFET0IFEU05iNGP1]KFd0Vi^K0492@P0j>SX0@T9206m_K`2LW9`0GUiN
08N7Q`0m?Cd0<C4a04M7A`1KFe/0F5QH05UIF@25QHD0;bl_020P800^;Rh0SHf=08N7Q`1IFET0OGem
07MgM`26QXH0ATI604Q8B01EEED0Kfm_05mOG`0d=3@0DU9B06EUI@1;Bd/0I6AT06MWI`1YJFT0FEUI
05MGE`2BTY80QhN706a/K00204U9B@1O051@D00i>CT0DE5A04i>CP13@d<0Cdm?03Ph>018B4P0A4A4
06m_K`1NGUh0PX:205mOG`14A4@0?clo06QXJ01;Bd/0DU9B06MWI`1HF5P0GUiN04Y:BP0i>CT0C4a<
04m?C`17AdL0FEUI0492@P1@D500I6AT03Ti>@1<C4`0EeMG03hn?P0f=SH0ATI602XZ:P1DE5@0;bl_
03Xj>P14A4@0D51@065QH@0V9RH0?Shn055AD@13@d<0CTi>05MGE`1EEED0B4Q804e=C@1?Cdl0KVi^
05iNGP0h>3P0?Shn04a<C019BDT0JFUY0410@01<C4`0LW9b02d];@0_;bl0D51@04];B`1LG5`0C4a<
04];B`0l?3`0Cdm?03Ph>017AdL0C4a<03lo?`0n?Sh071`L038b<P1@D500>3Ph04E5A@0i>CT0BDU9
04Y:BP11@D40<S8b0492@P0i>CT0Hf=S04];B`1IFET0@D510410@01@D5000P1=CDd0GP18B4P0JVYZ
04];B`1MGEd0Jf][04E5A@1PH600D51@05ADE01/K6`0<S8b06m_K`1>CTh0Bd];05QHF01@D500J6QX
03hn?P1PH600AdM703lo?`1PH600K6a/03De=@2GUiL0MWIf02`/;01QHF40MGEe06][J`1fMWH0Cdm?
0:f][@28R8P0@d=307EeM@19BDT0Ph>302DU9@1[Jf/0CTi>03hn?P1RHV80C4a<08N7Q`0Z:RX0ZZZZ
055AD@16ATH0=3@d05YJFP0F5QH0BDU906m_K`1@D500;Bd]06m_K`1jNWX07alO061PH02GUiL0>c/k
07QhN00m?Cd0Fe]K04Y:BP1HF5P0IFEU02HV9P1/K6`0F5QH02d];@2;Rh/0?3`l05iNGP1kNg/0=CDe
04Q8B00m?Cd0ADE5065QH@17AdL0>CTi05YJFP1/K6`0<30`069RHP1_Kfl0>3Ph04E5A@17AdL0>c/k
04e=C@19BDT209>CT`1Y05ADE019BDT08R8R02PX:01ADE404Q8B05ADE00Z:RX0E5AD04A4A00f=SH0
ATI604i>CP1eMGD08R8R04I6AP12@T809BDU02LW9`1BDU808b<S0410@00a<C40CTi>0451@@1FEUH0
AdM7059BDP1:BTX0CTi>059BDP10@400Hf=S04];B`1XJ6P0HF5Q05aLG028R8P0ADE5061PH012@T80
C4a<05ADE00S8b<0JFUY0492@P0l?3`0CTi>061PH00i>CT0CTi>04Y:BP28R8P0Bd];059BDP1=CDd0
IfMW05=CD`0n?Sh0B4Q80451@@1_Kfl0De=C05ADE02LW9`0AdM703<c<`1?Cdl0?Cdm04m?C`1QHF40
MGEe05EEE@1OGel0AdM705]KF`1PH600=SHf07YjNP1<C4`0VIVI03Ti>@0g=cL0HF5Q03`l?00i>CT0
DU9B03Ti>@1:BTX0C4a<01XJ6P1aLG407AdM03hn?P0e=CD0Cdm?069RHP0i>CT0>SXj04];B`0l?3`0
CDe=05iNGP1;Bd/0M7Ad00;ooooo0000:P29RHT0[Zj^08b<S01^KVh0AdM706UYJ@2?Shl0BDU907Yj
NP18B4P0ATI6075aL@1IFET0@D5103dm?@1>CTh09bLW07=cL`28R8P0Kfm_03@d=01?Cdl0EEEE02XZ
:P25QHD0EEEE024Q8@0];Bd0GEeM05IFEP1OGel0V9RH02DU9@0J6QX0;Bd]05MGE`1<C4`0MWIf061P
H00H61P06a/K03Lg=`80HF5Q0500OGem04i>CP0V9RH0>c/k03hn?P1YJFT0LG5a0<W9b@0e=CD08b<S
03Hf=P1DE5@0>3Ph08f=S@1cLg<0820P04a<C01RHV80BDU902d];@26QXH0>SXj028R8P11@D40FUYJ
04e=C@0l?3`0GEeM01`L700a<C40IVIV07MgM`0f=SH0D51@03@d=00];Bd0?clo05iNGP13@d<0<c<c
065QH@0P8200@T9206EUI@1aLG40=CDe03Ti>@0n?Sh0@D5106QXJ01eMGD0Ogmo02DU9@0h>3P0>CTi
05]KF`1/K6`0WIfM04Q8B00G5aL0;bl_06][J`1>CTh0MWIf08N7Q`0U9BD05aLG03Ph>021PH40@d=3
079bLP24Q8@07alO03Ti>@19BDT0De=C06][J`2=SHd08R8R01XJ6P80>3Ph0<00FEUI07UiN@2SXj<0
:b/[03<c<`1MGEd0EEEE03/k>`17AdL0SXj>04];B`0L71`0HF5Q0:6QX@13@d<0Bd];06MWI`0b<S80
;Bd]071`L02DU9@0<C4a04I6AP1:BTX0?Cdm04e=C@25QHD0GEeM03<c<`1EEED07AdM02DU9@1;Bd/0
LW9b038b<P1/K6`0A4A402h^;P1]KFd0Vi^K03Hf=P0m?Cd0LG5a04a<C00i>CT0SHf=08R8R00Y:BT0
;Bd]05IFEP1>CTh0=cLg09>CT`1/K6`07alO04i>CP1NGUh0<c<c05aLG02TY:@0Fe]K02h^;P1=CDd0
DU9B06ATI01OGel0R8R802XZ:P16ATH0FEUI05]KF`1[Jf/0U9BD04e=C@0`<300D51@05]KF`1kNg/0
K6a/09>CT`0N7Qh0>c/k05mOG`1dM7@0C4a<08^;R`1jNWX0;bl_05IFEP2HV9P0CDe=07UiN@2WYjL0
=cLg03Xj>P1@D500RHV905UIF@2FUYH0Kfm_03Hf=P1OGel0YjNW05YJFP1`L700>3Ph03Lg=`1XJ6P0
KVi^03dm?@1aLG40ATI60451@@1SHf<0UYJF059BDP18B4P0DU9B030`<01jNWX0][Jf04Y:BP0i>CT0
EUIF04I6AP1DE5@0[Zj^075aL@0V9RH0@D5107=cL`1EEED0RXZ:0<S8b016ATH0@d=3061PH01fMWH0
K6a/07emO@2UYJD0>3Ph04];B`1TI6@0OWin08F5Q@2YZJT0B4Q802l_;`1=CDd0Ph>30:f][@1ZJVX0
PH6107inOP0U9BD0C4a<06QXJ01oOgl0BDU907inOP11@D407alO04Q8B01=CDd0QXJ604];B`1eMGD0
@d=302`/;01OGel0Cdm?059BDP0j>SX0CTi>04e=C@0Q8B40?Cdm07QhN01dM7@0;Rh^05=CD`1BDU80
8R8R03lo?`1_Kfl0C4a<028R8P1LG5`0@D5103`l?01ADE4206m_K`0C07MgM`1CDe<0Hf=S06MWI`1V
IVH0JVYZ05iNGP1MGEd0MgMg03Xj>P15ADD0F5QH07=cL`1^KVh0Jf][05QHF01ZJVX0I6AT04a<C002
04U9B@0E02XZ:P0d=3@0<c<c05iNGP1FEUH0EeMG05UIF@1fMWH0Jf][05IFEP1^KVh0EEEE05ADE01=
CDd0De=C04];B`1MGEd0J6QX055AD@1FEUH0BTY:00<0?Cdm00L0@41004U9B@0e=CD0>3Ph04a<C00l
?3`0?clo0080B4Q809D0?Shn04Q8B00e=CD0AdM702HV9P0W9bL0@D5106ATI01/K6`0;2`/02TY:@0k
>c/0BDU905UIF@1HF5P0CDe=05aLG01OGel0I6AT06e]K@1ZJVX0?Cdm04A4A01DE5@0A4A407=cL`1D
E5@0EeMG061PH00d=3@0>SXj05]KF`0i>CT0@d=304i>CP1?Cdl0B4Q805MGE`0i>CT0CDe=04m?C`14
A4@0@410030`<019BDT0AdM703<c<`0n?Sh0BTY:03Xj>P18B4P0Cdm?0451@@19BDT0<30`05ADE017
AdL0DU9B04I6AP0b<S80EeMG02<S8`0g=cL0A4A406YZJP1FEUH0ATI605QHF00m?Cd0GemO03Ti>@1M
GEd0Lg=c03dm?@1ZJVX0Hf=S051@D01TI6@0BDU9069RHP1@D500De=C04U9B@1ADE40Shn?08b<S00n
?Sh0WYjN08B4Q013@d<0[jn_09JFUP1YJFT0M7Ad02XZ:P1oOgl0Kfm_02LW9`21PH40?3`l04=3@`0j
>SX0K6a/061PH01HF5P0E5AD06MWI`2DU9@0JVYZ0=GEe@1ZJVX0TI6A03lo?`1SHf<061PH06][J`2I
VIT0O7al018B4P1XJ6P0LG5a03Ph>01EEED0LW9b05=CD`1aLG40@D5103Lg=`0i>CT0LG5a08^;R`0d
=3@0C4a<03Hf=P0C4a<0F5QH01LG5`29RHT0M7Ad02`/;01XJ6P0?Cdm02h^;P1bLW80@T9204I6AP1^
KVh0Rh^;05eMG@0206YZJP0f03De=@10@400DU9B04];B`1UIFD0GemO0:^[Z`2>SXh0E5AD06][J`0m
?Cd0=CDe03Ph>00g=cL0KFe]03Lg=`1NGUh0ADE505iNGP1QHF40?Cdm0;Fe]@0k>c/0Ng]k08J6QP0Q
8B40=SHf05mOG`0k>c/0F5QH04i>CP1CDe<0AdM706ATI00l?3`0GUiN03hn?P0o?cl0CDe=01hN7P1F
EUH0<C4a09JFUP1fMWH0@T9208^;R`19BDT0LW9b04m?C`16ATH0G5aL024Q8@1KFe/0=3@d0P0b<S80
>@0j>SX0>3Ph05YJFP1@D500EUIF05ADE01GEeL08R8R07moO`1BDU80BDU9055AD@0`<300C4a<05iN
GP11@D40IVIV04A4A00d=3@0GemO04];B`17AdL0?clo04E5A@18B4P0Ph>303De=@0l?3`0C4a<03De
=@1]KFd0<C4a05QHF00Q8B40AdM7092@T01HF5P0@d=305YJFP0n?Sh0@d=304i>CP0b<S80BTY:02d]
;@1?Cdl0H61P08f=S@2BTY80B4Q804m?C`1QHF40De=C05]KF`1LG5`0GUiN06][J`02ooooo`000<00
L71`07alO027QhL0RHV903lo?`1<C4`0GUiN06e]K@2XZ:P0Cdm?03Lg=`1KFe/0Ng]k06YZJP25QHD0
SXj>01/K6`0c<c<0E5AD05eMG@1KFe/0WinO07emO@0m?Cd0<c<c05UIF@14A4@0T92@09JFUP0^;Rh0
@D5106m_K`1ZJVX0IfMW08V9R@0Q8B40=CDe03lo?`2f][H0Jf][07EeM@1_Kfl06QXJ03Lg=`12@T80
K6a/03hn?P16ATH0G5aL028R8P1`L700TI6A092@T00h>3P0EeMG04=3@`0M7Ad0Hf=S09FEU@0o?cl0
>3Ph051@D00c<c<0@D5108:2PP29RHT0:2PX04E5A@13@d<0DU9B051@D02MWId0GEeM02PX:01BDU80
ATI604e=C@2b/[80V9RH02DU9@0f=SH0F5QH03Ti>@1MGEd0b<S8059BDP0G5aL0GEeM0:>SX`12@T80
IVIV0;:b/P0R8R80Bd];04m?C`2IVIT0ADE508N7Q`1nOWh07QhN05=CD`1DE5@0LW9b0410@01dM7@0
I6AT01dM7@0i>CT0TY:B06i^KP13@d<0NWYj04=3@`0M7Ad0:b/[05MGE`0o?cl0<C4a05YJFP0I6AT0
AdM707QhN01/K6`0<S8b03dm?@1?Cdl06a/K05MGE`27QhL0E5AD02TY:@12@T80C4a<02`/;01CDe<0
YZJV04M7A`0U9BD0?Shn06UYJ@15ADD0JVYZ0:f][@0o?cl07AdM04a<C01fMWH0EEEE06m_K`1>CTh0
;Bd]03Ph>01XJ6P0FUYJ06][J`2CTi<0Bd];024Q8@18B4P0IfMW05UIF@2h^;P0E5AD03dm?@1?Cdl0
P82008N7Q`1aLG40]KFe03hn?P0g=cL0C4a<07]kN`2;Rh/0EeMG061PH00l?3`0AdM705eMG@1dM7@0
A4A407YjNP1[Jf/09bLW03lo?`18B4P0JVYZ04I6AP2<S8`0?clo02TY:@1>CTh2059BDP2H03hn?P1`
L7006QXJ03<c<`1DE5@0MgMg03dm?@1EEED0QhN7028R8P1>CTh0[:b/071`L00Z:RX0JVYZ05YJFP0`
<300IVIV0;2`/01EEED0>3Ph04m?C`1>CTh0Hf=S0;2`/01HF5P0=CDe0451@@0j>SX0BDU90;Zj^P20
P800:2PX0410@01YJFT0LG5a0:RXZ01cLg<0;Bd]05IFEP1ZJVX0C4a<0:b/[02:RXX0=CDe03dm?@1d
M7@0LG5a0:ZZZP2DU9@0:b/[03`l?01nOWh0KFe]05QHF01eMGD0;bl_051@D01`L700[jn_06a/K01b
LW80LG5a0451@@1SHf<0RXZ:07AdM010@400KFe]04=3@`0i>CT0FEUI08b<S02ATI40FEUI07alO00m
?Cd0>3Ph07emO@2?Shl0H61P06MWI`26QXH0=SHf04a<C01MGEd0UiNG065QH@0e=CD0KFe]04m?C`1D
E5@0MgMg09FEU@0m?Cd0=CDe04i>CP1:BTX0B4Q808>3P`1dM7@08b<S03lo?`1FEUH0C4a<04e=C@1i
NGT0QhN702<S8`0e=CD0CDe=07EeM@1DE5@0Vi^K08:2PP0K6a/0;2`/05]KF`2CTi<0C4a<08n?S`1m
OGd07AdM04I6AP1LG5`0J6QX07EeM@1;Bd/0@D5104E5A@16ATH0?Shn02`/;01NGUh0MgMg03Ph>01:
BTX0FUYJ07YjNP2DU9@0Lg=c06QXJ01JFUX0IVIV08J6QP1aLG40CDe=024Q8@12@T80;Bd]034a<@17
AdL203Xj>P2A0451@@1XJ6P0L71`09^KV`1dM7@0BDU905QHF025QHD0HV9R05IFEP1eMGD0I6AT09:B
TP1dM7@0;bl_02d];@15ADD0=SHf05QHF00l?3`0AdM706][J`0i>CT0>3Ph03hn?P0l?3`0:RXZ03<c
<`0W9bL0EUIF0492@P0f=SH0?clo03De=@19BDT0=SHf030`<00f=SH0>3Ph0492@P1CDe<0D51@04a<
C013@d<0GUiN06a/K01RHV80@d=304m?C`1EEED0C4a<061PH00l?3`0B4Q805ADE00[:b/09BDU04Y:
BP1aLG40IVIV0492@P0o?cl0=CDe03Xj>P15ADD0?Cdm0410@00l?3`0@d=302LW9`0X:2P0=SHf03<c
<`0e=CD0;Bd]02/[:`16ATH0=SHf02@T900_;bl0=cLg05ADE00n?Sh0Cdm?04A4A00Z:RX0ADE502`/
;012@T80=SHf079bLP0m?Cd0Bd];05eMG@0i>CT0FEUI0492@P1BDU80Hf=S00`<301`L700>3Ph04a<
C01MGEd0CDe=051@D00j>SX0FUYJ055AD@1BDU80G5aL06=SH`1CDe<0/k>c07YjNP13@d<0Jf][071`
L01OGel0Ng]k04I6AP2j^[X0P82002`/;01IFET0>c/k06MWI`0U9BD0Lg=c04M7A`1NGUh0D51@04U9
B@2^[Zh0?Shn0<k>cP1=CDd0Bd];05YJFP1WIfL07AdM061PH01KFe/0BTY:02LW9`0206=SH`0`00l?
3`1mOGd0UIFE03De=@1[Jf/0@D5104I6AP0a<C40DU9B05]KF`0H61P0LG5a059BDP0H61P0KFe]03<c
<`1ADE40L71`02TY:@1RHV80=3@d02XZ:P1MGEd0GUiN03<c<`1YJFT0U9BD0451@@32`/80YjNW038b
<P1EEED0B4Q8051@D01cLg<0>SXj0;bl_02UYJD0=SHf04i>CP0V9RH06QXJ03De=@0H61P0D51@0451
@@1ADE40@D510P1BDU80EP0j>SX0MWIf05MGE`29RHT0UiNG061PH01JFUX0R8R803`l?01RHV80>CTi
05QHF016ATH0MGEe03Ph>018B4P0E5AD04U9B@0k>c/0<S8b06=SH`11@D40Cdm?04Y:BP1[Jf/0Vi^K
04];B`1:BTX0?Cdm034a<@1;Bd/071`L05mOG`15ADD0<c<c04I6AP1BDU80@T9204Y:BP0m?Cd0JVYZ
03<c<`16ATH0;2`/06e]K@13@d<0;bl_03dm?@0W9bL0C4a<0451@@0S8b<0KVi^03Xj>P1=CDd0Ng]k
03dm?@1]KFd0GEeM04];B`1<C4`0Ogmo04Y:BP1ADE40K6a/04a<C02CTi<0AdM70:VYZ@1DE5@0@T92
05EEE@0o?cl0CDe=065QH@1<C4`0EUIF06EUI@0n?Sh0RXZ:030`<01?Cdl0A4A407emO@2BTY80CTi>
0P13@d<01@0n?Sh0AdM706MWI`18B4P0GemO00;ooooo00009P31`L40Bd];06e]K@24Q8@0IfMW0;Zj
^P1WIfL0>c/k0:ZZZP2g]kL0B4Q809:BTP19BDT0@d=305YJFP39bLT0Rh^;04i>CP1cLg<0;Bd]03Lg
=`1>CTh0SXj>03Ti>@1CDe<0>c/k024Q8@0m?Cd0QhN703`l?00c<c<0GemO03Ph>01:BTX0N7Qh051@
D00M7Ad0CDe=0P0n?Sh0T@1DE5@0YJFU0451@@0U9BD0ADE5059BDP1LG5`0P82008n?S`0];Bd0>c/k
07emO@2BTY80MGEe08f=S@0o?cl08b<S03Xj>P1QHF40GemO061PH02FUYH09bLW02/[:`16ATH0P820
0451@@2DU9@0J6QX01/K6`0c<c<0LW9b08Z:RP1NGUh0T92@04a<C00O7al0D51@0;6a/@1MGEd0MWIf
07]kN`0S8b<0?Cdm06=SH`1[Jf/0A4A405UIF@19BDT0;bl_04i>CP1[Jf/0D51@034a<@1bLW80ADE5
0451@@1IFET0U9BD02l_;`0^;Rh0G5aL04E5A@0i>CT0LW9b0:^[Z`17AdL07AdM04e=C@14A4@0;Bd]
08:2PP28R8P09BDU03`l?00m?Cd0AdM706YZJP2JVYX06a/K03<c<`1OGel0Shn?04e=C@1lO7`0JVYZ
02LW9`0X:2P0Hf=S07UiN@1=CDd0OGem04e=C@0h>3P0?Cdm06=SH`1jNWX0D51@07AdM01EEED06QXJ
02l_;`1:BTX0JVYZ04=3@`1YJFT0>CTi034a<@18B4P0AdM702<S8`1BDU80E5AD01lO7`0_;bl0GUiN
04e=C@0b<S80LW9b04I6AP13@d<0FUYJ07AdM00^;Rh0BDU9038b<P0V9RH0EEEE079bLP1mOGd0:BTY
07AdM010@400:b/[0820P02LW9`0<C4a030`<01=CDd0@D5102h^;P1`L700^[Zj05QHF00b<S800P1:
BTX0NP1OGel0ZZZZ0:^[Z`0c<c<0@d=3069RHP1OGel0EeMG0;>c/`1@D500:BTY04Q8B01UIFD0P820
09jNWP2`/;00=SHf038b<P1HF5P0Ph>3055AD@2QXJ40C4a<02TY:@1=CDd0Shn?06i^KP1WIfL0C4a<
02HV9P1EEED0Kfm_0:FUY@27QhL0OGem0410@00P8200Fe]K08:2PP1VIVH0Ti>C03Xj>P0f=SH0Q8B4
07inOP13@d<0LG5a0410@00f=SH0Hf=S0<[:bP1fMWH0F5QH06m_K`19BDT0Ph>307alO01<C4`0>SXj
06IVIP1@D500EEEE08b<S019BDT0;bl_055AD@1<C4`0E5AD09BDU02b/[80=cLg03`l?01aLG40HV9R
05=CD`2OWil0R8R8034a<@12@T80LG5a079bLP1VIVH0YZJV04M7A`0[:b/0@410055AD@1KFe/0Ng]k
0;:b/P0i>CT0<c<c03Lg=`1YJFT0I6AT071`L02HV9P0?Cdm04A4A01XJ6P0HV9R05ADE01WIfL0OWin
02DU9@1>CTh0DE5A0861P@1cLg<0Jf][06IVIP0K6a/0?3`l055AD@1FEUH0H61P06MWI`27QhL0;Rh^
02XZ:P1FEUH0Ti>C0P1DE5@0@01RHV80<C4a03Xj>P1HF5P0J6QX0410@00l?3`0JFUY065QH@1<C4`0
9BDU05ADE02>SXh0HV9R05=CD`0d=3@0ADE505=CD`0^;Rh0=SHf04Q8B01KFe/0GemO07EeM@1@D500
A4A407EeM@1;Bd/0DU9B0451@@0M7Ad0ATI602/[:`0b<S80IFEU04U9B@0g=cL0ADE505YJFP19BDT0
Bd];04i>CP0o?cl0@41005iNGP15ADD0BTY:05IFEP1`L700QXJ605=CD`0[:b/0CDe=03hn?P0l?3`0
CDe=05IFEP1VIVH0H61P03Xj>P1=CDd0GUiN03lo?`0c<c<204i>CP0d05=CD`0V9RH09BDU03Lg=`14
A4@0CTi>02@T900b<S80?Cdm03Ti>@1<C4`0A4A403Hf=P15ADD0I6AT05MGE`1bLW80G5aL04E5A@1;
Bd/0EEEE03dm?@1HF5P0LW9b07moO`1KFe/0:2PX02TY:@1@D500>CTi03/k>`14A4@0BDU904M7A`1?
Cdl0=3@d0451@@10@400=cLg03@d=00b<S80;2`/03Xj>P0_;bl0>SXj03De=@0n?Sh0=3@d03lo?`0S
8b<0;bl_03Lg=`80@D5101/0ATI604Q8B013@d<0>c/k04I6AP19BDT0=SHf06=SH`1ADE40B4Q805UI
F@1<C4`0DU9B02`/;01JFUX0EeMG028R8P1IFET0>CTi04a<C01;Bd/0?Shn04=3@`0e=CD0=cLg03dm
?@0f=SH00P1eMGD0N00i>CT0QhN706QXJ00a<C40P820079bLP1@D500DU9B03dm?@1UIFD0HF5Q02<S
8`1RHV80<30`04U9B@0k>c/0@T9203Ti>@1<C4`0>CTi04i>CP2b/[80Lg=c0:f][@1bLW80Kfm_05IF
EP1jNWX09RHV06QXJ01_Kfl0KFe]03`l?01KFe/0Cdm?02HV9P1?Cdl0IVIV03Ti>@1YJFT0;bl_05MG
E`0d=3@0@d=305IFEP0E5AD0@41003hn?P0K6a/0Q8B402DU9@1bLW80JVYZ03Ti>@1PH600>SXj02l_
;`1TI6@0@D51030`<012@T80KVi^03Ti>@1WIfL0LG5a01lO7`0j>SX0>3Ph038b<P1NGUh0@D51075a
L@1[Jf/0>CTi04m?C`0/;2`0=3@d03lo?`0B4Q80F5QH030`<01/K6`0=SHf03hn?P1GEeL061PH0::R
XP0e=CD0P8200:6QX@10@400=cLg05iNGP0m?Cd0DU9B04e=C@1?Cdl0EEEE065QH@1EEED0F5QH05YJ
FP1NGUh0DE5A03lo?`1CDe<0=CDe09ZJVP1VIVH0?clo079bLP13@d<0T92@05IFEP1=CDd0F5QH04i>
CP2NWYh0I6AT04Y:BP80Bd];03P0<S8b04I6AP0c<c<0DU9B03dm?@16ATH09bLW05MGE`0i>CT0:b/[
03Ti>@19BDT0Rh^;06=SH`17AdL0WYjN03Ph>00^;Rh0D51@04a<C01WIfL0J6QX04a<C01VIVH0MgMg
04=3@`15ADD0GUiN065QH@2=SHd0F5QH06ATI01NGUh0@T92065QH@0j>SX0GEeM07EeM@0a<C40<c<c
03`l?00];Bd0E5AD04Y:BP14A4@0AdM706MWI`1hN7P0EEEE05]KF`1hN7P0EEEE065QH@1IFET0Cdm?
05iNGP;ooooo0000eP29RHT0MWIf04];B`1]KFd0CTi>08J6QP27QhL0>SXj051@D01HF5P0L71`07mo
O`1PH600=CDe0492@P1>CTh0IVIV08n?S`1cLg<0;Bd]03@d=00m?Cd0IFEU05MGE`26QXH0@41001XJ
6P1:BTX0EeMG051@D01NGUh0De=C03@d=00j>SX0G5aL07AdM014A4@0W9bL03hn?P0c<c<0@T9204Q8
B01gMgL0=CDe069RHP0g=cL06a/K0410@01EEED0@D5104=3@`1^KVh05QHF02XZ:P1ZJVX0Rh^;03<c
<`1>CTh0BDU901XJ6P19BDT0DU9B04a<C00j>SX0EeMG01TI6@0e=CD0C4a<06EUI@0h>3P0;Bd]03Hf
=P0e=CD0CDe=08R8R01EEED05ADE030`<00m?Cd0GUiN06m_K`2QXJ40>SXj03Ti>@1FEUH0CTi>05EE
E@2=SHd0Ogmo01hN7P0];Bd0NGUi06e]K@1ADE40];Bd05]KF`0O7al0=SHf06a/K01UIFD0LG5a0<c<
c00i>CT0;Bd]051@D02<S8`0VYZJ065QH@2h^;P0?Shn0492@P1@D500KFe]04m?C`1EEED0F5QH02TY
:@0j>SX0JVYZ069RHP0j>SX0D51@02TY:@0b<S80Jf][0820P00o?cl0=cLg05=CD`0c<c<0<C4a08N7
Q`2DU9@0<c<c03Xj>P1VIVH0>CTi03De=@2FUYH0^;Rh03Xj>P0g=cL0DU9B030`<010@400YjNW09bL
W00S8b<0?Cdm05EEE@0];Bd0HF5Q0;^k^`1FEUH08b<S05iNGP1^KVh0?Shn09BDU01PH600:RXZ07Ad
M02UYJD0BTY:08V9R@10@4008b<S05ADE01iNGT0[jn_04Q8B02j^[X0EUIF038b<P15ADD0Jf][061P
H01MGEd0Kfm_02l_;`0X:2P0G5aL09JFUP1OGel0EeMG05YJFP0V9RH0:BTY06IVIP2VYZH0OWin04i>
CP1PH600;bl_04=3@`1FEUH0LG5a065QH@2;Rh/0?Cdm03<c<`1TI6@0KFe]03Ti>@1BDU80HF5Q02LW
9`0i>CT0KFe]08:2PP0o?cl0JFUY03@d=017AdL207]kN`3303Xj>P11@D40BTY:03dm?@1IFET0XZ:R
069RHP0K6a/0>c/k03Lg=`1IFET0][Jf09NGU`0i>CT0DE5A05iNGP1OGel0b/[:06ATI00W9bL0?clo
06QXJ02<S8`0[Jf]08f=S@0d=3@0FEUI06i^KP1=CDd0Lg=c0;2`/01KFe/0@D5105YJFP23Ph<0HV9R
0:RXZ01?Cdl0@d=3061PH021PH40O7al08F5Q@2EUID0@41005aLG01iNGT0R8R8069RHP2:RXX0H61P
03Ph>01:BTX0QHF506e]K@1;Bd/0PH6105UIF@0i>CT0?Cdm0:j^[P2i^KT0EeMG05]KF`17AdL0:b/[
03Lg=`1YJFT0MWIf03`l?01>CTh0GEeM03De=@1GEeL0UiNG06IVIP0e=CD0DE5A02/[:`1:BTX0UIFE
08:2PP1:BTX0:RXZ04];B`19BDT092@T04E5A@2a/K40Kfm_020P800n?Sh0CTi>03@d=01[Jf/0X:2P
030`<00X:2P0@T9207inOP1^KVh0Hf=S0:2PX01^KVh0H61P02l_;`0h>3P0?clo065QH@1/K6`0FEUI
06YZJP1]KFd0FEUI0820P021PH40T92@07alO01mOGd0Ng]k06UYJ@1/K6`0I6AT07EeM@1VIVH0@T92
0410@00a<C40<c<c055AD@1?Cdl0BTY:0451@@2=SHd0PH6107YjNP1SHf<0?Shn065QH@21PH40I6AT
05ADE01aLG40O7al05UIF@1BDU808B4Q03Xj>P1;Bd/0=SHf04Q8B00m?Cd0>c/k051@D00a<C40>CTi
04=3@`0m?Cd0;Bd]04=3@`0`<300ATI602@T900K6a/0ADE507alO01nOWh0:b/[02`/;00j>SX0=SHf
04a<C011@D40<c<c04=3@`14A4@0CTi>05eMG@1EEED0>CTi04a<C015ADD0@41005QHF00Y:BT0<c<c
07QhN00V9RH0:BTY05eMG@1>CTh0F5QH059BDP0n?Sh0@4100080?clo0:X0BTY:06e]K@16ATH0@T92
02@T901@D500>3Ph02XZ:P0f=SH0Bd];03<c<`18B4P0<S8b0410@01;Bd/0?3`l051@D019BDT0AdM7
034a<@0n?Sh0EeMG02DU9@0f=SH09RHV065QH@11@D40?3`l05QHF00[:b/0>CTi04Q8B015ADD0B4Q8
051@D02ATI40ADE503dm?@19BDT0@T9205EEE@0m?Cd0A4A404M7A`0n?Sh0LW9b07EeM@0l?3`0QXJ6
06i^KP0o?cl0SXj>07]kN`1NGUh0Hf=S05ADE02EUID0L71`03@d=024Q8@0<C4a0492@P0T92@0Lg=c
055AD@1UIFD0<S8b03Ph>02DU9@0BDU90;Vi^@1JFUX0MGEe05IFEP1MGEd0;bl_0820P01oOgl0EEEE
02/[:`1TI6@0Bd];01`L701/K6`0OWin04a<C01IFET0:BTY04A4A00e=CD0ATI6059BDP0/;2`0EeMG
04e=C@0b<S80WYjN03dm?@1iNGT0MgMg03@d=01DE5@0DU9B04a<C01LG5`0ATI604A4A01^KVh0TY:B
03lo?`1dM7@0Lg=c034a<@1VIVH0EEEE04M7A`1OGel0C4a<08R8R02IVIT0EEEE059BDP0i>CT07AdM
02d];@0E5AD0GUiN030`<01YJFT0BTY:03/k>`1=CDd05ADE07=cL`0f=SH0MWIf08N7Q`0W9bL0?Cdm
06=SH`0G5aL0ATI603De=@1MGEd0<S8b059BDP0a<C40FUYJ04A4A00k>c/0E5AD02l_;`1?Cdl0;bl_
04e=C@18B4P0@41006UYJ@0W9bL0C4a<03lo?`0m?Cd0CTi>02LW9`1:BTX0=3@d038b<P0g=cL0CDe=
03Hf=P80?clo01P0Jf][034a<@18B4P0=CDe07YjNP1DE5@0BTY:03Hf=P1FEUH0Fe]K04=3@`19BDT0
GEeM034a<@0c<c<0DU9B01/K6`1GEeL0P820079bLP1KFe/0LG5a05eMG@1IFET205IFEP0906IVIP0n
?Sh0Y:BT06i^KP1MGEd0Ogmo04Y:BP1FEUH0I6AT0080?Cdm0100Bd];01XJ6P1JFUX07QhN03/k>`1=
CDd0P82008j>SP19BDT0F5QH08V9R@1:BTX0ADE5051@D013@d<0DE5A0_ooool0002A0:RXZ02<S8`0
XZ:R06m_K`18B4P0Hf=S071`L018B4P0PX:203Xj>P1>CTh0F5QH09>CT`1HF5P0DE5A06QXJ00d=3@0
>SXj05QHF017AdL0>3Ph07YjNP0o?cl0=SHf05MGE`0m?Cd0:b/[059BDP1SHf<0Bd];05UIF@1QHF40
9BDU03Hf=P1DE5@0;bl_04=3@`11@D40DE5A02`/;017AdL0DE5A03De=@0m?Cd0KVi^06EUI@0`<300
=CDe03Hf=P0m?Cd0H61P08F5Q@0f=SH0;bl_069RHP1MGEd0=cLg06IVIP1ZJVX0;bl_0410@01?Cdl0
DU9B03dm?@2=SHd0KFe]03De=@0m?Cd0@d=305aLG014A4@0IFEU04M7A`0/;2`0De=C0492@P10@400
MgMg03Hf=P0V9RH0BTY:06m_K`1GEeL0IFEU06UYJ@0c<c<0:BTY069RHP1dM7@0N7Qh071`L01dM7@0
@D5104M7A`18B4P0LW9b03Xj>P1;Bd/0C4a<04M7A`15ADD0HF5Q06e]K@1?Cdl0FUYJ03Xj>P1@D500
@D5106m_K`1OGel0ADE5059BDP0a<C40A4A407YjNP1SHf<0>SXj069RHP1ADE40?Shn05MGE`1YJFT0
BTY:03De=@19BDT0LW9b05ADE01BDU80MgMg03hn?P0f=SH0B4Q808n?S`1FEUH0MgMg07inOP12@T80
ATI604];B`2<S8`0DU9B069RHP2GUiL0Cdm?04A4A00207moO`0n03hn?P1DE5@0GEeM04I6AP1IFET0
MgMg06][J`16ATH0LW9b04i>CP0^;Rh0K6a/06EUI@1=CDd0Ng]k03lo?`15ADD0Ph>3071`L010@400
JVYZ05ADE00g=cL0HV9R07emO@25QHD0EeMG06i^KP1?Cdl0>3Ph06e]K@2UYJD0KVi^04=3@`0c<c<0
EeMG05aLG01@D500JFUY07AdM01<C4`0DU9B08R8R01oOgl0IfMW09BDU01MGEd0AdM705QHF01KFe/0
G5aL07]kN`28R8P0ADE505mOG`2CTi<0H61P05UIF@1^KVh0<S8b04M7A`1gMgL205UIF@1`0:>SX`1=
CDd0@d=3096AT@1dM7@0@41005iNGP1ADE409BDU05EEE@1_Kfl0OGem04m?C`14A4@0I6AT04E5A@0n
?Sh0GemO075aL@2:RXX0EeMG02PX:01;Bd/0JVYZ04A4A01kNg/0H61P02l_;`0l?3`0Ti>C05YJFP1C
De<0Ogmo05aLG013@d<0CTi>06EUI@1BDU80B4Q8030`<018B4P0MgMg06=SH`1IFET0QhN7061PH014
A4@0De=C09>CT`1LG5`0Bd];059BDP1ADE40D51@07AdM021PH40?Cdm06ATI023Ph<0FUYJ04Q8B01V
IVH0Hf=S04A4A01@D500IfMW09VIV@29RHT0MWIf06ATI01;Bd/0IfMW05eMG@1iNGT0Ph>3079bLP1R
HV80:b/[07YjNP1^KVh0De=C079bLP1mOGd0;Rh^03Hf=P1IFET0J6QX06EUI@1CDe<0IfMW038b<P11
@D40KFe]05=CD`1`L700F5QH05mOG`20P800De=C03/k>`1]KFd0J6QX04e=C@17AdL0FUYJ03/k>`0e
=CD0J6QX06][J`20P800>CTi03<c<`<0>3Ph02X0;Rh^04E5A@1iNGT0CDe=03Lg=`0h>3P0CTi>05=C
D`17AdL0@D5104];B`1IFET0B4Q804Y:BP14A4@0HV9R07QhN016ATH0@T9203/k>`0_;bl0CDe=06EU
I@1SHf<0Cdm?04i>CP1SHf<0Bd];05]KF`1WIfL0Cdm?0492@P1EEED0S8b<0820P01[Jf/0Cdm?02LW
9`0`<300=SHf03De=@0`<3020410@01g03@d=00f=SH0AdM703Ti>@0h>3P0>SXj0410@018B4P0A4A4
05ADE01/K6`0JVYZ05=CD`0Z:RX0<S8b03/k>`0V9RH0:BTY03<c<`0S8b<0=cLg038b<P0o?cl0>CTi
04I6AP1WIfL0HF5Q06MWI`1=CDd0Ph>305=CD`1aLG40Hf=S03Ti>@0k>c/0BTY:05QHF01KFe/0HF5Q
06=SH`1LG5`0DU9B04I6AP0g=cL0AdM706QXJ01RHV80F5QH03dm?@0h>3P0;2`/04E5A@1OGel0;2`/
02XZ:P0R8R809RHV02d];@0[:b/0>3Ph034a<@17AdL0D51@06MWI`1iNGT0L71`05eMG@1WIfL0UiNG
05eMG@1DE5@0GEeM05QHF02ATI40J6QX05iNGP18B4P0AdM706i^KP1fMWH0L71`07]kN`1fMWH0Cdm?
034a<@0o?cl0CTi>05MGE`1KFe/0IVIV05UIF@2JVYX0J6QX04i>CP1WIfL0IFEU08>3P`2CTi<0QHF5
09FEU@1jNWX0M7Ad06e]K@1aLG40NGUi04U9B@1ADE40?Cdm06YZJP2:RXX0QhN70<;2`P1nOWh0S8b<
075aL@1HF5P0FUYJ071`L00d=3@00P0g=cL08`0l?3`0=CDe03lo?`0m?Cd0>CTi07=cL`1ZJVX0DU9B
08Z:RP1aLG40Lg=c079bLP1nOWh0MWIf04U9B@1GEeL0@41002/[:`1ADE40CTi>09nOW`2@T900HF5Q
06EUI@1fMWH0GEeM08N7Q`1@D500MgMg07UiN@2@T900MGEe05QHF01RHV80JVYZ0080Ng]k02D0JVYZ
06i^KP1`L700VIVI0:n_[`1eMGD0Fe]K07MgM`2<S8`0TI6A06UYJ@1[Jf/0OWin09>CT`26QXH0EeMG
05ADE01@D500^k^k08Z:RP2EUID0Ti>C05mOG`21PH40R8R8075aL@1HF5P0>CTi04M7A`1BDU80MWIf
06MWI`1LG5`0D51@03lo?`15ADD0BDU90080HF5Q01/0RHV908F5Q@20P800XZ:R06UYJ@29RHT0GemO
04m?C`1KFe/0D51@071`L01CDe<0@d=305aLG01XJ6P0>c/k04I6AP1=CDd0Kfm_05eMG@1^KVh0GemO
061PH01CDe<0EEEE06QXJ01QHF400P1:BTX0:01_Kfl0T92@06][J`1MGEd0KFe]0492@P1RHV80PX:2
04e=C@10@400BDU904E5A@1GEeL0HV9R05IFEP1SHf<0DU9B07UiN@2BTY80H61P065QH@0m?Cd0>CTi
04E5A@18B4P0DE5A075aL@1nOWh0RHV906YZJP1dM7@0MGEe07]kN`1mOGd0PH6105ADE01BDU80@D51
03lo?`17AdL204I6AP;ooooo0000QP2a/K40QhN70;Fe]@1TI6@0?clo051@D01;Bd/08b<S069RHP0h
>3P0MWIf06ATI01EEED0J6QX02d];@1KFe/0?Cdm02<S8`0Y:BT05QHF01TI6@1OGel0EUIF03hn?P1:
BTX0<C4a02<S8`1:BTX0Fe]K05aLG01PH600UYJF03lo?`0X:2P0@D5103Ph>00e=CD0ADE504I6AP0f
=SH0A4A4065QH@11@D4092@T06e]K@10@400=CDe04Y:BP1;Bd/0E5AD05UIF@1XJ6P0;Bd]03De=@1S
Hf<0IVIV02`/;01OGel0Hf=S05]KF`10@400BTY:05mOG`0c<c<0C4a<08B4Q01[Jf/0=cLg04Q8B01m
OGd08b<S03Hf=P21PH40;bl_0451@@19BDT0;Bd]08R8R00n?Sh0>3Ph04A4A01YJFT0C4a<04U9B@10
@400GemO02d];@1`L700SHf=08J6QP1KFe/0Bd];04U9B@1<C4`0?clo07UiN@1;Bd/0?3`l02`/;01M
GEd0?Shn04=3@`2PX:00[Jf]06m_K`1=CDd0Jf][030`<01iNGT0GUiN055AD@1UIFD071`L03hn?P1Z
JVX0?Shn051@D024Q8@0EUIF03Lg=`1fMWH0AdM707MgM`1bLW80=CDe05eMG@1HF5P0?3`l06MWI`1k
Ng/0MgMg0492@P1gMgL0>3Ph0P28R8P0R@1CDe<0@T92038b<P1dM7@0GemO04I6AP1MGEd0A4A404E5
A@2k^k/0QXJ60451@@19BDT0O7al02/[:`0c<c<0J6QX07MgM`10@400U9BD079bLP17AdL0HV9R06a/
K00k>c/0HV9R07EeM@0l?3`0I6AT06EUI@1QHF40NWYj059BDP0o?cl0Q8B406i^KP1UIFD0IfMW05MG
E`1MGEd0MGEe05EEE@2HV9P0NGUi079bLP10@400QXJ60:2PX01cLg<0>c/k0:>SX`1;Bd/0?3`l0;Zj
^P2RXZ80Fe]K08f=S@2HV9P0>3Ph0492@P1QHF40JFUY04Y:BP1aLG40<30`03hn?P1YJFT0HV9R04m?
C`18B4P0>CTi03De=@1bLW80G5aL08V9R@2f][H09BDU03`l?02i^KT0Ogmo03dm?@1bLW80AdM7024Q
8@11@D40NWYj06ATI01=CDd0<30`09ZJVP1QHF40DU9B03Ph>01LG5`0MGEe05UIF@0g=cL0NWYj09jN
WP1JFUX0JVYZ07emO@10@400;2`/07emO@1`L700AdM708f=S@1WIfL0@T9202@T901FEUH0L71`07al
O01IFET0BDU9071`L00l?3`0PH610;Zj^P2BTY80EeMG04=3@`1kNg/09bLW05eMG@1WIfL0DU9B05iN
GP1VIVH0EUIF03hn?P1ZJVX0Ogmo05QHF015ADD0;2`/0080JVYZ03L0GEeM05]KF`1VIVH0RHV906=S
H`14A4@0Kfm_05YJFP0b<S80Q8B407inOP1dM7@0EEEE02d];@1hN7P0Q8B403Xj>P1PH600Fe]K02PX
:00f=SH0L71`03dm?@1[Jf/0IVIV08F5Q@0k>c/0IVIV0:6QX@1aLG40=CDe02d];@0_;bl0P82007Qh
N01FEUH0ZJVY09jNWP26QXH0>CTi075aL@1JFUX0<30`09ZJVP24Q8@0ATI6034a<@0W9bL09BDU024Q
8@0L71`06QXJ01dM7@2?Shl0NWYj00809bLW01D071`L020P800O7al08R8R02d];@0[:b/0>c/k04I6
AP11@D40Q8B40:JVYP29RHT0B4Q802@T900U9BD0CTi>06YZJP0m?Cd0;bl_06i^KP0k>c/00`0[:b/0
7`0b<S80=cLg038b<P0m?Cd0Vi^K09nOW`2JVYX0KFe]02l_;`0U9BD092@T02<S8`0/;2`0:BTY02LW
9`0Y:BT0@41002XZ:P0R8R807alO03Ph>01LG5`0D51@0;2`/02TY:@0UiNG05aLG00Z:RX09BDU0492
@P0f=SH00P0G5aL09P0F5QH05aLG01DE5@0D51@07AdM04i>CP2XZ:P0[:b/0:VYZ@39bLT0d=3@0:>S
X`2[Zj/0M7Ad075aL@1KFe/0De=C0492@P0m?Cd0@d=304i>CP10@400@d=303Lg=`0T92@0>c/k07Yj
NP1oOgl0Shn?069RHP11@D40;2`/03Hf=P2ATI40GUiN02XZ:P0O7al08B4Q0P0V9RH0:`0Z:RX0;2`/
02l_;`1fMWH0VIVI0:n_[`1iNGT0[:b/0:RXZ01/K6`0ATI604M7A`0m?Cd0GEeM07inOP28R8P0HF5Q
03lo?`19BDT0K6a/0:2PX02c/k<0SHf=09FEU@0n?Sh06a/K01TI6@0K6a/09BDU02/[:`0g=cL0;Rh^
03dm?@1XJ6P0<c<c04E5A@1TI6@0MGEe09>CT`1lO7`0VYZJ0;6a/@32`/800P1PH6004@25QHD0Kfm_
06QXJ01NGUh0ZZZZ0<30`02[Zj/0]kNg0<G5a@2i^KT0SXj>07EeM@1HF5P0?clo03Lg=`0_;bl0;2`/
00<0;Rh^04H0;2`/04=3@`1VIVH0Cdm?05=CD`28R8P0ZZZZ07YjNP1/K6`0SXj>0;Rh^02LW9`0KFe]
03`l?00];Bd0<30`09^KV`1aLG40IfMW06ATI027QhL0@D5103Lg=`1[Jf/0YZJV0;>c/`3?cll0PH61
04E5A@0j>SX0BDU905YJFP2VYZH0ZJVY0;Rh^02d];@0V9RH0:^[Z`32`/80Ng]k07AdM02@T900eMGE
069RHP1XJ6P0UiNG0;Zj^P2ZZZX0FUYJ0410@01:BTX0J6QX0;Zj^P3?cll0a<C40<71`@2XZ:P0f][J
0=CDe01oOgl0<S8b030`<00c<c<0?Cdm04Y:BP1ZJVX0SHf=08n?S`1aLG40G5aL0P1ADE40402LW9`0
_[jn0<W9b@3Jf]X0fm_K0;Ng]`2FUYH0E5AD05mOG`1ADE40B4Q80492@P18B4P0De=C092@T01ZJVX2
05iNGP0f05MGE`11@D40=SHf061PH01lO7`0ADE5038b<P1RHV80`/;205aLG029RHT0bl_;07=cL`29
RHT0M7Ad059BDP1@D500A4A406m_K`3;bl/0Hf=S04Y:BP0];Bd0:BTY034a<@10@400EUIF04i>CP1Z
JVX0UYJF0;bl_01EEED0X:2P03<c<`0/;2`0;Rh^03/k>`2>SXh0XZ:R0;bl_02HV9P0FEUI075aL@2I
VIT0JVYZ09nOW`1mOGd0T92@03Ph>00];Bd0=SHf03Ph>00d=3@0=cLg0_ooool0003o0::RXP1kNg/0
SHf=07AdM015ADD0GUiN06i^KP0/;2`0PH6103dm?@1mOGd0J6QX03@d=01[Jf/0=CDe05UIF@0k>c/0
6a/K02TY:@0N7Qh0820P05iNGP1?Cdl0@T9204M7A`0k>c/0:b/[04U9B@1HF5P0IVIV05IFEP2=SHd0
@D5102h^;P0b<S809bLW02XZ:P1@D500?Shn02d];@0i>CT0PH61059BDP0Q8B40H61P04M7A`0n?Sh0
DU9B05ADE01PH600EUIF055AD@0U9BD0=3@d06e]K@1MGEd08b<S079bLP1HF5P0<S8b03Ph>01=CDd0
EUIF03<c<`13@d<0SXj>038b<P0];Bd0Cdm?071`L00X:2P0;Bd]05aLG00W9bL0A4A405QHF00a<C40
Ti>C038b<P0i>CT0G5aL092@T01EEED0@d=304m?C`0h>3P08B4Q051@D01aLG40Kfm_04i>CP1IFET0
E5AD02XZ:P0];Bd0DE5A04E5A@0l?3`0<c<c065QH@1UIFD0=3@d07EeM@2?Shl0IVIV059BDP2;Rh/0
@D5105UIF@10@400@D5107moO`0f=SH0ADE505eMG@0P8200BTY:08B4Q026QXH0=SHf05eMG@0Y:BT0
Hf=S096AT@13@d<0I6AT0451@@0U9BD0A4A405ADE01kNg/0@d=306IVIP0a<C40GemO08B4Q01ADE40
I6AT03Ph>014A4@0<c<c0410@01=CDd0E5AD03De=@29RHT0OWin04M7A`19BDT0PH61075aL@1>CTh0
IVIV07EeM@0Z:RX0RHV908b<S01CDe<0L71`06EUI@1HF5P0RXZ:0:6QX@18B4P0O7al038b<P0j>SX0
IfMW07emO@1>CTh0Rh^;05aLG013@d<0L71`08:2PP26QXH0J6QX05aLG02c/k<0QHF506EUI@0];Bd0
GEeM07=cL`1kNg/0@4100;:b/P2EUID0FUYJ0<W9b@2VYZH0>c/k07emO@2EUID0GemO04Y:BP1JFUX0
Ogmo04a<C02:RXX0MWIf051@D01VIVH0I6AT059BDP1NGUh0DE5A02d];@1aLG40D51@07]kN`2KVi/0
CDe=04I6AP2o_kl0Ogmo0451@@29RHT0PH6102d];@0c<c<0Rh^;05]KF`1?Cdl0:b/[07moO`1RHV80
HF5Q03hn?P1aLG40Jf][07UiN@1:BTX0B4Q808Z:RP1RHV80Hf=S075aL@1=CDd0DE5A08R8R02<S8`0
Bd];09VIV@1dM7@0=CDe02l_;`1cLg<0OGem092@T01DE5@0A4A4071`L01CDe<0F5QH000909bLW025
QHD0GUiN03`l?027QhL0BDU905IFEP1PH600HV9R0080FEUI05d0EeMG04E5A@1SHf<0Ph>306=SH`1>
CTh0:RXZ06i^KP1MGEd0K6a/07EeM@1IFET0P82007EeM@10@400J6QX08V9R@1?Cdl0Jf][09RHV027
QhL0Bd];02d];@1/K6`0QHF50451@@1XJ6P0LG5a03<c<`0l?3`0M7Ad03dm?@1UIFD0I6AT06m_K`0^
;Rh0NGUi0:BTY027QhL0?clo02d];@0g=cL0Q8B402h^;P0l?3`0KFe]0820P022PX80=cLg06a/K00_
;bl071`L07inOP1TI6@0?Shn03<c<`0h>3P0=cLg02LW9`0N7Qh05aLG01`L702HV9P0^KVi04=3@`0W
9bL07AdM01HF5P0H61P06a/K020P800Y:BT0:2PX02l_;`1KFe/0Rh^;09NGU`2UYJD0];Bd09>CT`1Q
HF40Ogmo079bLP0`<300Kfm_06=SH`0^;Rh092@T020P800R8R80820P02HV9P0c<c<00P12@T80202B
TY80YjNW09NGU`1CDe<0>3Ph02PX:00V9RH092@T0P0V9RH06P0P8200@d=302/[:`0K6a/071`L01lO
7`1UIFD0TI6A0;no_`3AdM40]KFe0:2PX01`L700;bl_02/[:`18B4P061PH01<C4`0D51@05aLG024Q
8@10@400FUYJ04E5A@13@d<0PH610P2NWYh02P2JVYX0YjNW0;^k^`1eMGD0?clo01lO7`0X:2P0;Bd]
02l_;`0];Bd302DU9@0k01lO7`0Q8B40=SHf06m_K`1`L700LG5a08F5Q@1=CDd0@41003Ti>@1IFET0
Ti>C05eMG@0a<C40;2`/02l_;`0c<c<0>c/k05UIF@1VIVH0YZJV0:2PX02k^k/0alO70;bl_02n_[h0
RHV906MWI`1MGEd0Cdm?09:BTP1gMgL0M7Ad07MgM`1NGUh0GEeM07YjNP2>SXh0Y:BT0;Ng]`2ZZZX0
J6QX02@T900I6AT061PH024Q8@0N7Qh07AdM01hN7P0R8R80G5aL04i>CP0T92@0>c/k09:BTP2CTi<0
YJFU055AD@1^KVh00P2MWId0E01DE5@0@D5104A4A00j>SX0@4100<71`@36a/H0^;Rh0<71`@2][Jd0
[jn_07alO01<C4`0>CTi03Hf=P0c<c<0<S8b03De=@0j>SX0?3`l03Xj>P0e=CD0BDU906IVIP2QXJ40
^KVi06i^KP2WYjL0YZJV0=GEe@2n_[h0]kNg0;^k^`31`L40_[jn08n?S`2`/;00MGEe06ATI01PH600
R8R807EeM@0k>c/07QhN02l_;`1>CTh0?clo0;Zj^P2LW9`0CTi>03hn?P1BDU80C4a<0;fm_@1ADE40
GUiN0;Bd]02ATI40XJ6Q0<71`@38b<P0Xj>S09^KV`34a<@0KFe]09RHV02d];@0X:2P06MWI`0d=3@0
?Cdm04Q8B01SHf<0Fe]K0;jn_P31`L40inOW0=;BdP2l_;`0d];B08J6QP0_;bl0<30`03@d=080?Cdm
00X0A4A404E5A@17AdL0FEUI06e]K@1bLW80YJFU0<K6aP2d];@0]kNg0P3>c/h0@`2ZZZX0IFEU04A4
A01ADE40JFUY04Y:BP0m?Cd0<c<c06=SH`1hN7P0C4a<03hn?P0f=SH0@41004U9B@1;Bd/0JVYZ07Ee
M@1NGUh0@T9204m?C`2a/K40QHF505=CD`2f][H0N7Qh09RHV01KFe/0@D5104I6AP11@D40Ogmo0=OG
e`28R8P0ADE503hn?P0a<C40=3@d05ADE01ZJVX0MWIf0<;2`P38b<P0b/[:09RHV032`/80MGEe05IF
EP1?Cdl0Ng]k0:2PX01OGel0Shn?06i^KP1KFe/0KFe]06][J`1PH600NGUi04U9B@22PX80J6QX034a
<@0c<c<0=SHf03Lg=`0e=CD00_ooool0000d0;fm_@2:RXX0KVi^07alO019BDT0Hf=S07IfMP0];Bd0
O7al0451@@1_Kfl0Hf=S020P801OGel0?Cdm05EEE@0e=CD051@D02PX:00Z:RX09bLW05mOG`1=CDd0
<30`051@D01DE5@0<S8b04M7A`1@D500EUIF05MGE`2>SXh0?Shn03Ph>00c<c<092@T03<c<`1@D500
@T92020P800Y:BT0PX:206QXJ00P8200E5AD01`L700/;2`0AdM70410@01EEED0F5QH055AD@809bLW
05l0F5QH03Xj>P0I6AT0JFUY08B4Q01SHf<0=3@d04M7A`1KFe/0@D5104M7A`2ATI40KVi^03/k>`0o
?cl0MgMg03<c<`0Y:BT0GemO02l_;`1ADE40FEUI02d];@29RHT08B4Q02PX:012@T80Lg=c0492@P1F
EUH0F5QH03dm?@0U9BD0Lg=c08j>SP1dM7@0>CTi06IVIP1nOWh0FEUI03Xj>P1FEUH0>SXj02TY:@0M
7Ad0>c/k079bLP1<C4`0TI6A0::RXP1FEUH0@41008f=S@1?Cdl0HF5Q0410@00e=CD0Lg=c03De=@15
ADD0DE5A02/[:`0a<C40FEUI08:2PP0h>3P0H61P03Hf=P1EEED0OGem04E5A@1ADE40EEEE03dm?@18
B4P0CDe=06i^KP1:BTX0PX:205IFEP1LG5`0N7Qh051@D02CTi<0ADE504];B`0a<C40?3`l06][J`20
P800DU9B09bLW01_Kfl0<30`05MGE`0208V9R@07059BDP1jNWX0Ng]k03hn?P2>SXh0XZ:R03hn?P02
08>3P`1<03Lg=`1NGUh0VIVI04U9B@1]KFd0L71`05]KF`1VIVH0QXJ6069RHP2YZJT0WinO08b<S01c
Lg<0HF5Q09ZJVP1IFET0EeMG0;no_`2][Jd0W9bL03/k>`1^KVh0G5aL04I6AP0_;bl0OWin08b<S01Q
HF40`L71096AT@1ZJVX0M7Ad08j>SP1SHf<0BTY:05ADE01<C4`0E5AD0:6QX@1oOgl0FUYJ05iNGP1=
CDd0?clo055AD@1EEED0:b/[06QXJ00i>CT0LW9b0:RXZ01]KFd0ADE509bLW024Q8@0<S8b06=SH`1f
MWH0>CTi02LW9`2<S8`0FUYJ051@D00j>SX0O7al05EEE@1>CTh0>SXj06MWI`1LG5`0MgMg04];B`17
AdL0QHF506IVIP80JVYZ05/0ADE502XZ:P1ZJVX0TI6A059BDP28R8P0KVi^0410@00S8b<0C4a<05iN
GP1mOGd0EeMG0410@01XJ6P0HF5Q06=SH`2ATI40K6a/05YJFP0a<C40UIFE05ADE01JFUX0EEEE04A4
A01=CDd0GEeM04Y:BP18B4P0N7Qh079bLP11@D40?3`l02HV9P1fMWH0C4a<06e]K@21PH40F5QH08N7
Q`20P800>CTi06UYJ@27QhL0@T9207alO02>SXh0NWYj03Lg=`14A4@0Q8B408n?S`1>CTh0HF5Q06][
J`0Q8B40<30`07EeM@17AdL0IFEU07]kN`1TI6@0:b/[061PH02HV9P0CDe=034a<@0h>3P0BTY:08V9
R@1gMgL0>CTi06YZJP1mOGd0EUIF02XZ:P1iNGT0FEUI024Q8@1[Jf/0WIfM08:2PP1ZJVX0GUiN05aL
G01YJFT0IFEU04I6AP1WIfL0bl_;0080a<C401X0De=C02/[:`0G5aL061PH01LG5`0E5AD06QXJ038b
<P0U9BD0=CDe08n?S`2GUiL0X:2P08>3P`3Cdm<0gMgM0;Fe]@1PH600OGem07=cL`1:BTX0<S8b02HV
9P0T92@08R8R01hN7P8092@T00X0:b/[03Lg=`10@400S8b<0;6a/@1dM7@0F5QH04A4A00R8R80820P
0P0N7Qh0400_;bl0G5aL05mOG`16ATH0B4Q806EUI@2>SXh0YjNW0;Fe]@2GUiL0Shn?08J6QP1oOgl0
@410020P801ADE4201LG5`0C034a<@14A4@0@410038b<P0g=cL0>CTi04m?C`1DE5@0PH6109BDU02^
[Zh0XZ:R09NGU`1lO7`0NGUi05]KF`0d=3@092@T024Q8@0201hN7P8071`L02<06a/K01dM7@0l?3`0
JVYZ05mOG`1XJ6P0JVYZ09JFUP2:RXX0UiNG0:RXZ02d];@0WYjN04A4A016ATH0IfMW05EEE@1;Bd/0
?clo069RHP1ZJVX0VIVI0;bl_02VYZH0Vi^K0:VYZ@2UYJD0T92@07UiN@1_Kfl0QHF50;bl_02d];@0
/k>c08Z:RP0209:BTP090;Zj^P35aLD0/[:b0;Zj^P1oOgl0>c/k01lO7`0G5aL071`L00807alO0P0Q
8B406P0[:b/0E5AD02`/;00g=cL0OWin09>CT`2h^;P0XZ:R06YZJP1aLG40Z:RX04=3@`0j>SX0>CTi
06ATI02/[:`0/K6a0<30`03EeMD0_Kfm05iNGP0o?cl0MWIf092@T01CDe<0>c/k0P0m?Cd0E013@d<0
@T9203hn?P0k>c/0?3`l03Hf=P1/K6`0a<C40<71`@1hN7P0Ogmo0:2PX02k^k/0QhN705MGE`1TI6@0
Lg=c06e]K@2DU9@0e=CD0:JVYP2PX:00RHV904M7A`0_;bl0AdM704I6AP0R8R809bLW030`<01lO7`0
/[:b096AT@16ATH0BDU9071`L02QXJ40DU9B04M7A`20P800?3`l05ADE01SHf<0ADE5096AT@34a<@0
`<300;Vi^@2OWil0VIVI07emO@15ADD0;2`/03Xj>P10@400CTi>03dm?@2^[Zh0Shn?0>;RhP3Ti>@0
c<c<0;Vi^@3=cLd0Ph>307alO02@T900WinO09:BTP2>SXh0NGUi07AdM01TI6@0EUIF0820P02f][H0
WinO0<C4a02NWYh0]kNg0;Fe]@1kNg/0XZ:R055AD@80Bd];03D0CTi>03Ti>@0d=3@0I6AT04A4A00e
=CD0>3Ph02l_;`0g=cL0@T9204];B`1XJ6P0Kfm_09fMW@1QHF40Q8B406i^KP1OGel0PH610:j^[P3A
dM40bLW907MgM`17AdL0?clo05=CD`2d];@0K6a/0:6QX@1fMWH0@d=302`/;00`<300P8200:f][@3=
cLd0b/[:0=[JfP3IfMT0`/;20;:b/P2/[:`0OWin06e]K@1aLG40TI6A0::RXP1IFET0>SXj04m?C`1l
O7`0IFEU08Z:RP0204Q8B00705EEE@2?Shl0?3`l02d];@0_;bl0>3Ph03@d=002ooooo`0002`0Ti>C
04E5A@1IFET0IfMW04M7A`1`L700>CTi01lO7`1SHf<0@41004Y:BP0G5aL04A4A05EEE@0h>3P0BDU9
03Ph>0092@T09RHV038b<P0V9RH0AdM704Q8B00M7Ad0<C4a0451@@0X:2P0CTi>02PX:00O7al0<C4a
07MgM`13@d<0=cLg04M7A`0`<300:2PX03hn?P15ADD0=CDe020P801aLG40F5QH01TI6@80H61P07d0
>CTi0410@00h>3P0@d=306QXJ01cLg<0@D5102LW9`1JFUX0?Cdm01TI6@1QHF40S8b<0820P015ADD0
CDe=04E5A@0N7Qh0@41008J6QP1UIFD0>SXj0451@@1LG5`0;2`/03Hf=P23Ph<0Bd];05eMG@1<C4`0
:2PX07AdM01OGel0@41005EEE@1SHf<09bLW03Xj>P1SHf<0H61P03@d=01kNg/0SHf=06IVIP0S8b<0
D51@065QH@1=CDd0=CDe059BDP13@d<0<C4a01hN7P0b<S80H61P03De=@29RHT0W9bL061PH017AdL0
SXj>05QHF01NGUh0Cdm?03/k>`1`L700<C4a05ADE01RHV80CDe=03Lg=`1BDU80Ogmo04a<C01iNGT0
Cdm?04e=C@1VIVH0<30`069RHP1]KFd0A4A4059BDP1GEeL0D51@02/[:`1XJ6P0I6AT04];B`1hN7P0
?clo07IfMP0n?Sh0IfMW03dm?@0a<C40CDe=06i^KP1>CTh0VYZJ08^;R`17AdL0@D5107AdM01MGEd0
?Cdm065QH@1cLg<0DU9B07QhN02a/K40Fe]K07UiN@1fMWH0@41006a/K027QhL0ADE508B4Q02?Shl0
LG5a071`L01dM7@0D51@096AT@0208j>SP80KFe]03L0LG5a04E5A@0o?cl0[jn_08R8R02@T900BTY:
07moO`1NGUh0SHf=03Xj>P1kNg/0MGEe055AD@30`<00QXJ606YZJP1eMGD0XJ6Q06=SH`1;Bd/0C4a<
08F5Q@0i>CT0XJ6Q08Z:RP1BDU80G5aL08:2PP1FEUH0?Cdm05iNGP0X:2P0JFUY059BDP1]KFd0[Jf]
04e=C@0o?cl0OWin08j>SP0c<c<0H61P05QHF00k>c/07alO08n?S`1DE5@0=CDe0410@01PH600@d=3
04E5A@10@400L71`0080J6QX02l0CTi>0492@P1iNGT0LW9b06a/K01jNWX0EUIF03Hf=P1WIfL0Shn?
065QH@1hN7P0IfMW04I6AP0Y:BT0Bd];059BDP22PX80GemO0492@P21PH40NWYj05UIF@2LW9`0MgMg
06ATI00f=SH0TY:B04A4A01IFET0BDU902/[:`1=CDd0MgMg05=CD`17AdL0LW9b06UYJ@1CDe<0:BTY
03Lg=`2@T900OWin08V9R@1fMWH0GEeM08N7Q`0203Hf=P0Q0820P02?Shl0De=C07moO`2GUiL0BTY:
01/K6`0b<S80Fe]K079bLP0h>3P0KVi^07moO`0k>c/0Bd];09VIV@0h>3P0EeMG05QHF01aLG40B4Q8
08B4Q02QXJ40MGEe03/k>`0R8R80;bl_07EeM@1cLg<0D51@08J6QP2=SHd0Shn?0080EeMG01@0AdM7
02PX:01cLg<0WinO075aL@19BDT0ADE503dm?@0a<C40Cdm?0:6QX@2m_Kd0MWIf06i^KP2][Jd0]KFe
08J6QP0h>3P05aLG01DE5@805aLG01407alO02<S8`0R8R80=SHf08Z:RP2BTY80CDe=0:NWY`3AdM40
c<c<0:NWY`2EUID0DE5A03Ph>00b<S809bLW024Q8@0201lO7`807AdM03<07QhN020P800S8b<0>3Ph
07UiN@2`/;00GEeM04m?C`18B4P0:b/[03Lg=`1:BTX0@T92034a<@17AdL0DU9B06ATI01MGEd0EEEE
09FEU@2PX:00SHf=07AdM01eMGD0YZJV06IVIP1JFUX0UYJF05iNGP1QHF40=3@d024Q8@0W9bL09RHV
03De=@1:BTX0>3Ph02@T901JFUX0VYZJ075aL@1]KFd0Q8B407YjNP1BDU80MgMg08Z:RP1MGEd0<c<c
01hN7P0O7al00`0L71`0;00M7Ad0EEEE06QXJ01<C4`0FUYJ04];B`2FUYH0]kNg0:BTY02:RXX0Ng]k
079bLP1QHF40KVi^04];B`0f=SH0@d=307alO01QHF40A4A407MgM`2b/[80[Jf]0<30`02GUiL0M7Ad
04I6AP10@400?clo0451@@1lO7`0OWin06m_K`1<C4`0IfMW08B4Q02h^;P0/K6a07AdM02GUiL0ZJVY
05QHF00];Bd071`L0`0M7Ad0=@0O7al08R8R02LW9`0a<C40CTi>03/k>`23Ph<0TI6A0:FUY@2`/;00
TI6A051@D01cLg<0?clo04m?C`2@T900NWYj03/k>`23Ph<0ZZZZ08F5Q@24Q8@0D51@04I6AP0Y:BT0
OGem0:RXZ01QHF40ATI604M7A`0o?cl0?Cdm03Lg=`0c<c<0=cLg04Y:BP2i^KT0_Kfm06MWI`1UIFD0
D51@08f=S@2ATI40G5aL03Xj>P0i>CT0=CDe03@d=01_Kfl0/[:b09fMW@2OWil0>CTi0080820P04<0
8R8R03De=@1FEUH0ATI603/k>`1YJFT0Lg=c0:JVYP2k^k/0XJ6Q09fMW@0g=cL0Fe]K0492@P1/K6`0
>3Ph04A4A01QHF40=SHf07IfMP2/[:`0gmoO0=KFeP3@d=00S8b<0:JVYP16ATH0>3Ph04=3@`1IFET0
@41003lo?`2i^KT0Zj^[0=gMg@3Bd]80MgMg08^;R`3EeMD0bl_;06i^KP0m?Cd0=3@d034a<@0g=cL0
>CTi04Q8B01kNg/0e]KF0:f][@1ADE40XJ6Q09FEU@1bLW80YZJV09RHV01hN7P0E5AD0:6QX@1BDU80
<C4a03De=@12@T80LG5a06UYJ@0m?Cd0>CTi0080<c<c02X0;bl_03@d=014A4@0IfMW06a/K01XJ6P0
O7al0;Vi^@1jNWX0IfMW096AT@31`L40b/[:0;Jf]P2^[Zh0XJ6Q08V9R@2e]KD0EUIF02XZ:P1TI6@0
b/[:092@T00g=cL0De=C0:f][@3@d=00dm?C0=gMg@3Ti>@0eMGE0<?3``2e]KD0/[:b0;no_`2b/[80
^;Rh0<71`@2e]KD0][Jf09fMW@2BTY820;>c/`0:09JFUP0m?Cd0A4A4055AD@2BTY80Vi^K03/k>`0d
=3@0>CTi03dm?@;ooooo0000802RXZ80M7Ad06UYJ@1bLW80?3`l04e=C@1JFUX0;Rh^04Q8B00V9RH0
E5AD04m?C`0F5QH0ATI603Ti>@1:BTX0G5aL01/K6`0i>CT0<C4a020P800a<C40FUYJ04e=C@15ADD0
>SXj01LG5`13@d<0EEEE03lo?`1=CDd0VYZJ0P0c<c<07`1WIfL0HV9R02XZ:P0C4a<0<30`05EEE@0R
8R80P82004U9B@0E5AD0E5AD05iNGP0e=CD0?Shn02d];@0Y:BT0H61P07]kN`1>CTh0:BTY04M7A`1J
FUX0:2PX04U9B@21PH40OGem051@D01GEeL0E5AD05mOG`0d=3@00P1[Jf/0=P0g=cL0EEEE04i>CP0Q
8B407AdM069RHP13@d<0CTi>04M7A`0S8b<0KFe]04e=C@0h>3P0IFEU06QXJ01gMgL0@41005EEE@1a
LG40>3Ph09>CT`2[Zj/0R8R805]KF`1HF5P0GUiN03hn?P0o?cl0I6AT079bLP1CDe<09RHV02d];@1K
Fe/08b<S07IfMP2PX:00N7Qh04i>CP2BTY80:2PX05UIF@1UIFD0>CTi06YZJP0S8b<0>SXj05IFEP1E
EED0?clo05mOG`1WIfL0<30`06][J`80DU9B0=P0PX:203dm?@13@d<0GemO02XZ:P19BDT0IFEU07]k
N`19BDT0JFUY04=3@`16ATH0OGem04];B`1JFUX0<30`069RHP1ADE40?clo05IFEP1?Cdl0=3@d08F5
Q@2UYJD0KFe]04Q8B01TI6@0MgMg05mOG`1XJ6P0JFUY05EEE@1?Cdl0_kno07emO@26QXH0R8R803Ti
>@1TI6@0RXZ:05mOG`20P800WinO07EeM@1cLg<0TI6A08N7Q`2FUYH0U9BD08Z:RP1^KVh0R8R809bL
W02:RXX0BDU90<c<c01]KFd0Ogmo03dm?@1lO7`0IFEU09BDU019BDT0M7Ad08Z:RP16ATH0XJ6Q07Ui
N@1WIfL0F5QH0:JVYP1VIVH0Cdm?05QHF02<S8`0;bl_08B4Q02?Shl0BTY:06e]K@1mOGd0De=C0451
@@1VIVH08R8R07emO@1gMgL0IVIV0:JVYP1TI6@0AdM707EeM@2JVYX0?Cdm065QH@1XJ6P0=3@d02h^
;P2:RXX0W9bL06m_K`1DE5@0J6QX0:RXZ017AdL08B4Q03lo?`0k>c/0Kfm_04U9B@1?Cdl0MgMg03@d
=01NGUh0M7Ad06UYJ@0g=cL0G5aL07inOP1<C4`0Ph>309ZJVP1LG5`0=cLg04Q8B01?Cdl0P82003Xj
>P1ADE40MgMg08f=S@14A4@0][Jf08V9R@0Q8B40:b/[07MgM`1EEED0HF5Q06a/K00_;bl0;Bd]0410
@01FEUH0=3@d06EUI@26QXH0O7al03dm?@0P8200FEUI06ATI018B4P0FUYJ08f=S@2KVi/0C4a<02DU
9@1:BTX0Lg=c03/k>`21PH40Vi^K07IfMP0n?Sh0?Cdm05ADE027QhL0D51@05ADE01_Kfl0:RXZ03/k
>`2:RXX0C4a<06IVIP1FEUH0Jf][04Y:BP2IVIT0WYjN07emO@16ATH0:2PX02d];@1UIFD0;2`/05iN
GP20P800L71`08b<S01NGUh0M7Ad04A4A00I6AT0IVIV0<C4a02/[:`0GemO059BDP19BDT0Kfm_07If
MP1/K6`0T92@03dm?@0O7al0;2`/09ZJVP2l_;`0MWIf05MGE`0f=SH06ATI01LG5`0I6AT201hN7P0D
028R8P20P800Kfm_06][J`12@T80Z:RX0<O7a`2EUID0ATI603Ph>00f=SH0;bl_03<c<`0R8R807QhN
020P800O7al07AdM01hN7P0L71`201dM7@0a02/[:`2ATI40W9bL04i>CP1TI6@0S8b<08N7Q`1UIFD0
De=C05QHF02CTi<0JFUY0410@00l?3`0B4Q809VIV@1gMgL0NGUi07AdM01`L700aLG50:ZZZP2^[Zh0
_kno07emO@0V9RH0;Bd]03lo?`17AdL0BTY:04A4A00/;2`07alO01hN7P1@D500JVYZ05EEE@29RHT0
V9RH07=cL`10@400?clo04];B`1TI6@0Lg=c06EUI@14A4@0=SHf02/[:`0202DU9@0[07QhN01?Cdl0
@D5104];B`14A4@0G5aL08N7Q`29RHT0`l?30<;2`P1JFUX0?3`l04U9B@1>CTh0CDe=06][J`2>SXh0
?3`l0410@023Ph<0JVYZ096AT@2<S8`0U9BD08F5Q@1oOgl0>CTi02/[:`0];Bd0@d=30820P01bLW80
DE5A05EEE@13@d<0H61P0<;2`P1IFET0I6AT092@T022PX80B4Q8028R8P0301dM7@05020P800O7al0
820P02@T901dM7@00P22PX80;P2WYjL0XZ:R09ZJVP2_[jl0X:2P0861P@2TY:@0dM7A0:JVYP0i>CT0
=cLg09fMW@1RHV80ATI608R8R01IFET0CDe=034a<@0i>CT0_[jn09fMW@1VIVH0F5QH051@D011@D40
?3`l03Ti>@1ADE40YjNW0:JVYP2;Rh/0C4a<05ADE01iNGT0J6QX0:^[Z`1kNg/0:b/[02h^;P0];Bd0
<C4a08F5Q@1`L700TY:B08^;R`0_;bl201hN7P0Z024Q8@0M7Ad0;2`/05=CD`27QhL0WinO09fMW@2V
YZH0/K6a0<k>cP28R8P0>CTi06i^KP10@400GUiN030`<01>CTh0SXj>06EUI@2j^[X0U9BD0=cLg03G
emL0cLg=09FEU@2d];@0JVYZ061PH01cLg<0RHV907moO`2QXJ40bLW90<;2`P3Ng]h0];Bd08b<S01A
DE40][Jf08>3P`0O7al0820P0P0O7al0C`0R8R808B4Q02DU9@0[:b/0UiNG0820P00g=cL0FEUI05QH
F01_Kfl0V9RH08Z:RP1bLW80ATI60492@P2:RXX0De=C02`/;00n?Sh0PH61075aL@10@400>SXj03Hf
=P0i>CT0<c<c03Hf=P14A4@0L71`06QXJ01CDe<0T92@06m_K`28R8P0^[Zj08j>SP2k^k/0QhN707em
O@1`L700T92@0<O7a`27QhL0F5QH065QH@1TI6@0[jn_0=;BdP30`<00]KFe0<k>cP3=cLd0`/;20<c<
c03EeMD0f=SH0;Zj^P2FUYH0Rh^;09NGU`2UYJD0/k>c0;2`/02QXJ40QHF508^;R`2YZJT0_kno0<?3
``1lO7`09BDU03<c<`1LG5`0/K6a0=;BdP2`/;00Q8B405mOG`2WYjL00_ooool0003o07YjNP1LG5`0
[jn_09jNWP1?Cdl0D51@071`L00l?3`0HF5Q04Q8B00o?cl0GemO01`L700b<S807QhN030`<01EEED0
71`L03/k>`0W9bL03`l?01XJ6P1;Bd/0@D5103hn?P0d=3@05ADE02d];@1=CDd0@41005mOG`2VYZH0
@D51028R8P11@D40Hf=S030`<00i>CT0;bl_0410@00R8R80Ph>308N7Q`0X:2P0DE5A05mOG`13@d<0
EeMG06IVIP0k>c/0BDU906e]K@1MGEd0<30`05EEE@20P800CDe=04];B`2:RXX0?clo038b<P1=CDd0
F5QH06][J`0b<S80JVYZ05UIF@0Z:RX0K6a/07YjNP10@4007alO06QXJ00];Bd0<S8b05IFEP0i>CT0
KVi^03<c<`0R8R80H61P07QhN01iNGT0@410079bLP0f=SH06ATI05mOG`2LW9`0P82004I6AP1PH600
Ph>304=3@`0W9bL0>3Ph03hn?P13@d<09BDU03Ti>@1eMGD0=3@d06UYJ@29RHT0L71`04A4A02SXj<0
G5aL04A4A01=CDd0;2`/07=cL`1OGel0A4A4055AD@0m?Cd0<c<c04];B`2>SXh0CDe=06][J`1GEeL0
?Cdm07]kN`1UIFD0@41006YZJP17AdL0@d=3059BDP22PX80HF5Q06a/K01aLG40ADE508R8R01DE5@0
JVYZ05ADE01EEED0De=C03`l?01EEED0P82005IFEP24Q8@0Xj>S07AdM00h>3P0GUiN09FEU@1XJ6P0
L71`06a/K01NGUh0AdM70<k>cP2@T900Lg=c08f=S@11@D40IFEU0:ZZZP1eMGD0NWYj08R8R01WIfL0
M7Ad08V9R@1/K6`0QXJ60:BTY021PH40M7Ad0;Bd]02@T900QXJ605eMG@38b<P0NWYj04m?C`15ADD0
PX:2092@T02>SXh0CDe=071`L01dM7@0:BTY08:2PP2:RXX0H61P04M7A`2`/;00BDU905aLG01nOWh0
R8R802/[:`1WIfL0ATI603Ph>01cLg<0QhN7051@D010@400E5AD02/[:`1`L700RHV905aLG02NWYh0
GUiN01hN7P1NGUh0Rh^;04Q8B01YJFT0LG5a02`/;00J6QX0Lg=c07IfMP0`<300<c<c05UIF@1LG5`0
AdM703lo?`1FEUH0ATI6096AT@1NGUh0@410079bLP1_Kfl0FEUI061PH016ATH0C4a<07QhN01VIVH0
9RHV0492@P1PH600Hf=S03dm?@1OGel0IVIV096AT@1>CTh0=cLg05mOG`1XJ6P0>3Ph001V09FEU@2:
RXX0Fe]K03Lg=`1bLW80D51@04E5A@1@D500?clo0451@@1HF5P0Cdm?02`/;01SHf<0Fe]K059BDP17
AdL0:BTY06e]K@1fMWH0LG5a051@D026QXH0RXZ:06i^KP11@D40SXj>0:VYZ@1aLG40PH6109FEU@1X
J6P0:RXZ055AD@20P800WIfM06YZJP1`L700VIVI034a<@0R8R80JFUY05YJFP1?Cdl0W9bL07emO@0a
<C40Jf][07EeM@1TI6@0B4Q802PX:00/;2`0IfMW05aLG00d=3@0H61P03dm?@1kNg/0IVIV06QXJ01Z
JVX0?3`l05eMG@3Ng]h0bLW90;Zj^P2BTY80SHf=07MgM`17AdL0?Shn05YJFP1/K6`08B4Q028R8P0[
:b/0U9BD0:ZZZP1@D500EeMG05YJFP1BDU80BTY:05YJFP1ADE40@T920:FUY@2KVi/0KFe]03/k>`2K
Vi/0/[:b06m_K`1BDU80<c<c02d];@0V9RH0;2`/02HV9P0Q8B407AdM0P0P8200;P0W9bL08b<S01`L
700L71`07QhN02h^;P2SXj<0Zj^[09jNWP2PX:00Z:RX05YJFP15ADD0D51@08>3P`1hN7P0>c/k03`l
?00e=CD0IVIV07moO`1lO7`0S8b<09:BTP3Hf=P0b<S809:BTP2QXJ40/k>c09BDU02HV9P0LW9b04A4
A00j>SX0:BTY020P800L71`07alO03hn?P1ADE40NWYj08V9R@2LW9`0LW9b05UIF@10@402024Q8@0B
03Ti>@1=CDd0EUIF061PH01dM7@0Ogmo0:JVYP3<c<`0>SXj030`<00a<C40>SXj08N7Q`1KFe/0LW9b
0<O7a`2RXZ80Fe]K0`0n?Sh07P0l?3`0>c/k06][J`1JFUX0EeMG08F5Q@13@d<0IfMW05aLG01eMGD0
R8R807UiN@2FUYH0L71`04E5A@12@T80G5aL06IVIP1ADE40@41003Hf=P10@400Shn?04];B`13@d<0
IFEU0:VYZ@19BDT0@41002DU9@807AdM04H07alO01dM7@0N7Qh0820P05mOG`2i^KT0/K6a09bLW02A
TI40_;bl0=[JfP31`L40_Kfm0:6QX@2?Shl0S8b<092@T02JVYX0_Kfm03Hf=P0h>3P0M7Ad05=CD`1G
EeL0?3`l02XZ:P2@T900V9RH05QHF01EEED0H61P06e]K@1hN7P0TI6A0;Jf]P2[Zj/0FEUI055AD@1F
EUH0Ti>C09FEU@1bLW80]kNg0;Jf]P1JFUX0>SXj03@d=016ATH0ZZZZ08B4Q01MGEd0SHf=051@D00N
7Qh07AdM01hN7P0O7al08b<S02DU9@1>CTh0_;bl09VIV@2^[Zh0TI6A0;Rh^03@d=00YjNW0;fm_@2M
WId0WinO0P2<S8`06P39bLT0d=3@0;6a/@2ZZZX0c<c<0:>SX`2l_;`0^k^k06UYJ@0b<S80:2PX02@T
900W9bL0:b/[03dm?@2;Rh/0RXZ:0<[:bP2=SHd0Shn?04a<C02LW9`0Kfm_01dM7@0L71`07AdM0P0O
7al08@0Q8B408R8R02@T902BTY80MgMg051@D01WIfL0Ti>C09:BTP2FUYH0T92@07MgM`0_;bl08b<S
02TY:@1kNg/0R8R807]kN`29RHT0JFUY055AD@0g=cL0ADE504M7A`10@400>3Ph04=3@`1NGUh0A4A4
05YJFP1gMgL0JVYZ0::RXP020<K6aP0[09^KV`2d];@0HV9R09BDU02b/[80]KFe07alO01VIVH0IfMW
08N7Q`37alL0g=cL0=oOg`3Ng]h0c<c<0;2`/03AdM40Xj>S0<[:bP3QhN40NWYj07IfMP1bLW80OWin
08n?S`2LW9`0[:b/06YZJP1?Cdl0GEeM06IVIP1lO7`0Jf][0;Fe]@1NGUh0Ogmo09JFUP1aLG40DU9B
06UYJ@2OWil0d=3@09^KV`02ooooo`000?<0MgMg09nOW`3@d=00^;Rh05YJFP1PH600CTi>02/[:`1^
KVh0K6a/05IFEP1NGUh08R8R04i>CP1@D500<30`04m?C`092@T0>3Ph04I6AP0S8b<06a/K05MGE`0Z
:RX0?Cdm05eMG@0a<C40=CDe04=3@`0[:b/0E5AD09FEU@1VIVH0;Rh^04E5A@0k>c/0:RXZ061PH011
@D40;bl_010@401KFe/0L71`02PX:01GEeL0<C4a02LW9`16ATH0JFUY03`l?01IFET0EEEE01DE5@0L
71`0A4A405mOG`0h>3P0=cLg06ATI01CDe<0@D5104I6AP1:BTX0AdM702PX:01mOGd0Lg=c02TY:@1L
G5`0FUYJ05=CD`0P8200HV9R04];B`0`<300IFEU04=3@`1GEeL0Lg=c03lo?`1;Bd/0N7Qh06e]K@11
@D40O7al069RHP0c<c<0OGem0;Fe]@23Ph<0=CDe03/k>`1FEUH0GemO03Hf=P11@D40@d=303Lg=`0I
6AT08B4Q06=SH`1:BTX0NGUi0::RXP1bLW80=cLg09jNWP1XJ6P0>3Ph05mOG`11@D40MgMg07emO@11
@D40BDU907]kN`14A4@0CTi>09RHV01[Jf/0GemO07UiN@15ADD0Ogmo06][J`15ADD0JVYZ05ADE019
BDT0Bd];075aL@1UIFD0H61P07IfMP13@d<0R8R8065QH@1VIVH0F5QH04Q8B01WIfL0ADE505aLG025
QHD0Jf][079bLP2PX:00Ogmo03Lg=`1TI6@0Z:RX06UYJ@1[Jf/0Kfm_04i>CP13@d<0[jn_075aL@1K
Fe/0QhN704m?C`2?Shl0alO707alO01UIFD0OWin04e=C@1kNg/0OGem069RHP1^KVh0T92@03Xj>P12
@T80LW9b07inOP1kNg/0B4Q80:j^[P2:RXX0M7Ad04I6AP1LG5`0Hf=S07UiN@1:BTX0L71`09>CT`11
@D40UiNG08V9R@1:BTX0GEeM0:RXZ01;Bd/0<S8b03hn?P1TI6@0>SXj071`L026QXH0C4a<05]KF`24
Q8@0AdM705QHF01RHV808b<S05aLG01[Jf/0C4a<0:NWY`1bLW80=SHf04I6AP1gMgL0;bl_05ADE01`
L700EUIF01dM7@1jNWX0R8R803/k>`1ADE40G5aL079bLP1BDU80EEEE06][J`1;Bd/0W9bL06m_K`15
ADD0IfMW07alO01^KVh0IFEU06e]K@0g=cL0H61P092@T01TI6@00P1VIVH0G@1JFUX0:b/[03dm?@1>
CTh0TI6A07EeM@0g=cL0FUYJ08V9R@14A4@0V9RH09FEU@1mOGd0ADE5071`L01fMWH0ATI605ADE01>
CTh0ATI606][J`1cLg<0EEEE05YJFP1OGel0HV9R030`<00n?Sh0QHF509NGU`2=SHd0Cdm?09fMW@2K
Vi/0EUIF02/[:`1:BTX0U9BD05IFEP23Ph<0_;bl09>CT`1<C4`0<C4a0451@@1nOWh0@41004Y:BP1n
OWh0DU9B02h^;P1WIfL0@D51038b<P2IVIT0OGem04Y:BP2<S8`0VYZJ055AD@0j>SX0AdM7055AD@1_
Kfl0Fe]K06YZJP2=SHd0?Shn07YjNP1MGEd0?clo06a/K015ADD0EUIF0=3@d02m_Kd0[jn_08F5Q@1Q
HF40E5AD055AD@18B4P0ATI607inOP0X:2P08R8R01lO7`0a<C40[jn_09nOW`20P800N7Qh079bLP02
09:BTP0@09RHV02`/;00clo?0<g=c@2][Jd0QhN709FEU@2WYjL0QhN70<30`013@d<0:2PX02@T900V
9RH09BDU02<S8`<071`L00<0820P024Q8@0M7Ad00`0M7Ad08P1DE5@0[Zj^09BDU02[Zj/0Xj>S07If
MP1hN7P0XZ:R08N7Q`2;Rh/0JVYZ09^KV`2OWil0Zj^[09nOW`2^[Zh0`<300:ZZZP2VYZH0VYZJ0<C4
a03Hf=P0c<c<0<[:bP2ATI40B4Q803`l?00S8b<07AdM02l_;`0c<c<0@D5105MGE`1ZJVX203Xj>P0m
0410@01IFET0LW9b05eMG@17AdL09RHV028R8P0W9bL0<S8b03Lg=`0a<C40=cLg05EEE@2NWYh0T92@
02l_;`0S8b<0J6QX06][J`1=CDd0Fe]K0:NWY`1iNGT0;Bd]02XZ:P0X:2P0:b/[030`<00f=SH0Fe]K
0:n_[`30`<00EEEE038b<P1CDe<0EEEE05ADE01<C4`0DU9B0:b/[01oOgl0<30`02TY:@0_;bl0JFUY
05aLG00h>3P0:2PX02HV9P1dM7@0E5AD02LW9`18B4P0Ng]k07alO00n?Sh0>3Ph02XZ:P0O7al07AdM
01hN7P02028R8P0905mOG`2SXj<0DE5A04];B`0o?cl0MGEe0;Rh^02e]KD0OGem0080IFEU02l0JFUY
06m_K`23Ph<0^;Rh03`l?00/;2`0EUIF05aLG01IFET0ADE503lo?`1jNWX0BTY:02HV9P0T92@08R8R
02DU9@0X:2P0CDe=0:VYZ@1>CTh0C4a<051@D021PH40H61P09>CT`2a/K40a/K60<g=c@2OWil0VYZJ
0:2PX032`/80e]KF0;Rh^00l?3`0Lg=c06e]K@0S8b<08R8R020P800R8R808b<S02DU9@1nOWh0L71`
09>CT`0208b<S00C0:FUY@39bLT0Cdm?04m?C`2SXj<0W9bL06IVIP3De=@0fMWI0;2`/02MWId0^k^k
0<G5a@2NWYh0b<S80:JVYP2;Rh/0KVi^02DU9@02020P800<01hN7P0T92@0K6a/06IVIP2UYJD0PH61
0;Jf]P1BDU80P82005mOG`0M7Ad071`L0`0M7Ad0B00O7al07QhN02/[:`2YZJT0K6a/06ATI022PX80
ZJVY07inOP2FUYH0YJFU08Z:RP0S8b<071`L01hN7P0V9RH0MWIf0=_Kf`35aLD0WYjN08>3P`1/K6`0
=SHf02l_;`0c<c<0@d=304a<C017AdL0@T9205=CD`1NGUh0J6QX06m_K`2][Jd0HF5Q05eMG@2WYjL0
clo?0<C4a03Bd]80NGUi09NGU`26QXH0[jn_0=7Ad@3:b/X0aLG50<C4a03EeMD0e=CD09bLW02HV9P0
IVIV0=CDe03Jf]X0`<3006YZJP0g=cL0@41004a<C01ADE40FUYJ08B4Q01:BTX0BDU904Q8B01<C4`0
Jf][0<K6aP2RXZ80H61P03dm?@80>CTi00@0ADE505QHF02b/[80JFUY0_ooool0000=05QHF01bLW80
dm?C0;Vi^@1HF5P0EeMG05QHF00Y:BT0CTi>04e=C@11@D40<S8b01@D50020451@@1=02TY:@1HF5P0
7alO034a<@10@4003Ph>01<C4`1]KFd0?Shn02HV9P0h>3P06ATI03Ph>01JFUX0:RXZ04Y:BP24Q8@0
IVIV02PX:01DE5@0Kfm_03@d=017AdL0;Bd]051@D00U9BD0M7Ad069RHP0L71`0AdM705QHF00c<c<0
>CTi03dm?@0Y:BT0K6a/07UiN@1OGel08b<S03Lg=`1EEED0A4A402`/;01hN7P0LW9b05MGE`1?Cdl0
@d=306QXJ00R8R80Jf][08>3P`0f=SH0Hf=S04E5A@0/;2`07QhN05UIF@1UIFD0>SXj06MWI`10@400
H61P08F5Q@1>CTh0D51@07YjNP1;Bd/0;2`/0861P@1VIVH0>CTi06a/K02XZ:P0QHF506EUI@1;Bd/0
0P1IFET0o`13@d<0?clo04E5A@18B4P0:b/[02`/;01[Jf/0GEeM06m_K`2BTY80Xj>S04I6AP2IVIT0
J6QX03@d=01PH600Bd];07AdM02;Rh/0@d=304Q8B02<S8`0ATI6055AD@2?Shl0Kfm_06QXJ027QhL0
ATI607YjNP1PH600EUIF07EeM@1PH600D51@04Q8B01QHF40@d=306MWI`27QhL0?3`l07alO00/;2`0
IVIV05YJFP0j>SX0EEEE02TY:@1>CTh0NWYj05eMG@1LG5`0[Jf]05eMG@0h>3P0Hf=S07moO`1RHV80
FUYJ08N7Q`0o?cl0>3Ph08n?S`1MGEd0DE5A08R8R00f=SH0De=C07moO`1dM7@0FUYJ092@T01FEUH0
Hf=S06m_K`1IFET0Hf=S0;Rh^02?Shl0IfMW0;Fe]@2SXj<0LG5a04I6AP2QXJ40Zj^[07moO`1>CTh0
T92@07IfMP1eMGD0A4A405UIF@26QXH0C4a<0::RXP2PX:00O7al06=SH`2e]KD0Jf][04E5A@11@D40
H61P03De=@1QHF40T92@05EEE@1QHF40S8b<04];B`0k>c/0IVIV02l_;`1?Cdl0GEeM034a<@26QXH0
PX:20451@@0m?Cd0OGem05aLG01DE5@0Q8B4075aL@0O7al0HF5Q0;2`/01NGUh0E5AD06e]K@1eMGD0
B4Q805EEE@1oOgl0IVIV09:BTP1ADE40?Shn06YZJP1RHV80M7Ad09RHV01ZJVX0<S8b06m_K`2YZJT0
O7al07YjNP1eMGD0HV9R03@d=010@400G5aL09^KV`23Ph<0?Cdm06a/K02HV9P0@41008f=S@2MWId0
IVIV03hn?P2?Shl0N7Qh04I6AP1QHF40CDe=02<S8`14A4@0EEEE06][J`1IFET0Shn?0820P01=CDd0
;bl_05eMG@1fMWH0BTY:03dm?@24Q8@0UYJF08V9R@0g=cL0D51@0:b/[01`L700JVYZ0:2PX028R8P0
MWIf04=3@`0o?cl0Ti>C07AdM014A4@0QhN706YZJP0h>3P0EUIF06=SH`13@d<0/K6a0:>SX`1NGUh0
RXZ:09FEU@1UIFD0E5AD02DU9@0`<300EEEE04Q8B01@D500Vi^K04U9B@23Ph<0P82003dm?@1IFET0
=SHf04];B`3Bd]80a<C409fMW@1oOgl0JVYZ05IFEP1EEED0D51@06YZJP2DU9@0>3Ph020P800M7Ad0
92@T09bLW03;bl/0ZJVY0820P01mOGd0OWin06YZJP1QHF40MGEe05aLG028R8P0`L710:RXZ032`/80
QXJ606i^KP009@3=cLd0QXJ606MWI`1DE5@0?3`l02<S8`0U9BD0820P01hN7P0K6a/071`L01dM7@0P
8200;Rh^01hN7P0Q8B40GEeM0:n_[`1_Kfl0Lg=c08Z:RP13@d<0?3`l09BDU02b/[80bl_;0<S8b02N
WYh0GEeM09JFUP1^KVh0MGEe08J6QP2:RXX0NGUi06e]K@2ZZZX00P34a<@09`3EeMD0OWin08B4Q019
BDT09RHV0410@017AdL0EeMG04A4A00W9bL0@d=304Y:BP0c<c<0<C4a03/k>`0a<C40FUYJ06=SH`1F
EUH0@41002HV9P0[:b/0;2`/03Lg=`0e=CD0=3@d03Hf=P2ATI40WYjN07IfMP1YJFT0>SXj04m?C`1Q
HF40Ogmo07AdM00U9BD09bLW02DU9@0202<S8`0O02PX:00c<c<0Ogmo0:b/[01cLg<0:RXZ0451@@1:
BTX0BDU904I6AP14A4@0PX:207IfMP0/;2`092@T02DU9@17AdL0K6a/04];B`0n?Sh09BDU08J6QP1Q
HF408R8R02TY:@1:BTX0SXj>06=SH`0n?Sh0>CTi02DU9@0301dM7@0I020P801SHf<0Vi^K05QHF018
B4P0KFe]0:FUY@1CDe<0SHf=07IfMP16ATH0?Cdm03Xj>P0m?Cd0>SXj08F5Q@1lO7`0=3@d0451@@29
RHT0Cdm?059BDP19BDT0SHf=03lo?`02028R8P0f01lO7`0T92@08B4Q03/k>`2<S8`0A4A406ATI023
Ph<0CDe=04a<C01>CTh0TY:B0<o?c`34a<@0MGEe05YJFP1XJ6P0PX:20;Ng]`2OWil0ADE506][J`1o
Ogl0;Rh^024Q8@0R8R80<30`03@d=01DE5@0Cdm?04I6AP1fMWH0L71`06][J`1fMWH0WIfM06MWI`2:
RXX0TY:B08J6QP2l_;`0[Zj^0<g=c@2<S8`0[:b/0<g=c@3>c/h0bLW908j>SP1YJFT0IFEU06MWI`1f
MWH0?3`l0`0N7Qh02@1ZJVX0F5QH08>3P`2][Jd0`L71096AT@1SHf<0MGEe01dM7@0201`L70<07AdM
00`07QhN03Ti>@2XZ:P0KFe]05QHF02>SXh0IfMW07]kN`2EUID0UYJF04m?C`0T92@201hN7P0o01lO
7`11@D40VIVI04E5A@1LG5`0T92@0::RXP1=CDd0<C4a03Xj>P1OGel0HV9R06ATI00U9BD07QhN034a
<@1>CTh0Hf=S09VIV@15ADD0Bd];08b<S03Bd]80e]KF0<;2`P1XJ6P0XJ6Q0=GEe@3?cll0/;2`08f=
S@33`l<0YZJV096AT@2l_;`0e]KF0;bl_02n_[h0ZJVY06QXJ01kNg/0_;bl08N7Q`0j>SX0>3Ph04];
B`1EEED0GUiN065QH@1:BTX0?Cdm05QHF02][Jd0bLW9092@T00[:b/0;2`/03<c<`0a<C40?clo04Q8
B025QHD0SXj>00;ooooo0000P`1DE5@0@T920:6QX@2l_;`0PH6104e=C@1[Jf/0DU9B04=3@`0k>c/0
=SHf06i^KP0X:2P0@D5104i>CP0Q8B40De=C02PX:00_;bl0Cdm?01TI6@0E5AD0C4a<03@d=00P8200
;bl_01dM7@0V9RH0CDe=038b<P1TI6@0S8b<04];B`0H61P0>CTi06UYJ@0`<300>c/k03<c<`13@d<0
9RHV06EUI@1cLg<0?clo04=3@`1^KVh0=SHf02d];@1BDU80=cLg05ADE01_Kfl0Q8B403Hf=P0/;2`0
D51@04E5A@0T92@0M7Ad05UIF@1GEeL0DE5A04I6AP20P800<S8b05mOG`2MWId0A4A404U9B@1ADE40
JFUY01/K6`19BDT0LW9b03Ph>01SHf<0=CDe03Lg=`2?Shl0@D5105QHF01fMWH0Kfm_04M7A`1ZJVX0
FEUI03Ti>@1UIFD0/k>c08B4Q01/K6`0AdM704Q8B00l?3`0?Cdm051@D01`L700HV9R03@d=00];Bd0
JVYZ04I6AP1DE5@0Ti>C0:>SX`1CDe<0OGem04U9B@0c<c<0IVIV04Y:BP1mOGd0Cdm?03@d=01HF5P0
NWYj04A4A01EEED0JVYZ034a<@1RHV80Kfm_04=3@`1eMGD0@410034a<@1OGel0EeMG04A4A01<C4`0
Hf=S0080B4Q800@0MgMg03/k>`1iNGT0De=C0P1HF5P0700g=cL0DU9B03<c<`19BDT0K6a/05iNGP17
AdL0Zj^[0820P011@D40De=C0820P01=CDd0Bd];08b<S01SHf<0CTi>09RHV01XJ6P0ADE507YjNP1I
FET0JVYZ08F5Q@1SHf<0DU9B08^;R`1ZJVX207EeM@2@059BDP18B4P0ZZZZ096AT@1SHf<0^;Rh08n?
S`1XJ6P0HV9R0::RXP2MWId0N7Qh05EEE@2<S8`0Ogmo09^KV`1RHV80GEeM09jNWP1KFe/0UYJF0;fm
_@1WIfL0De=C0<?3``1ZJVX0F5QH04M7A`1eMGD0A4A405iNGP2FUYH0EUIF05eMG@2OWil0IVIV04A4
A01PH600=cLg03dm?@1mOGd0DE5A08F5Q@24Q8@0Bd];03Hf=P23Ph<0Hf=S04U9B@20P800J6QX030`
<01aLG40bLW906QXJ01HF5P0PH6107MgM`1`L700:2PX03/k>`0n?Sh0LG5a04=3@`18B4P0P820059B
DP0m?Cd0GUiN08>3P`0b<S80HF5Q09BDU014A4@0JVYZ0:JVYP1lO7`0HF5Q03dm?@17AdL0Ph>304a<
C00c<c<0F5QH08N7Q`13@d<0RXZ:0:f][@1OGel0:BTY05=CD`1?Cdl0>SXj06IVIP1OGel0AdM704Q8
B01FEUH0BTY:03dm?@1`L700IfMW065QH@0j>SX0HV9R07IfMP1NGUh0EeMG08b<S02>SXh0Shn?03dm
?@16ATH0];Bd08j>SP1`L700WIfM09>CT`25QHD0B4Q803`l?01kNg/0JVYZ04U9B@2:RXX0LW9b04I6
AP19BDT0KVi^04I6AP2KVi/0IfMW065QH@1/K6`0TY:B06UYJ@1EEED0:b/[03<c<`1LG5`0HV9R03`l
?02FUYH0NWYj0P23Ph<0_`0g=cL0DE5A03@d=01ADE40alO70;Rh^02c/k<0LG5a05QHF01DE5@0CTi>
04a<C01;Bd/0HF5Q04Q8B00P8200?Cdm04a<C023Ph<0Ng]k07inOP1JFUX0Bd];04=3@`1@D500FEUI
05YJFP1kNg/0R8R809jNWP2^[Zh0K6a/08N7Q`2XZ:P0b/[:08R8R00k>c/0@D5106IVIP1RHV80De=C
03Lg=`0^;Rh08b<S01dM7@0L71`0>3Ph05iNGP0^;Rh0D51@04Y:BP2NWYh0[jn_07=cL`1mOGd0=cLg
02h^;P2DU9@0VYZJ0;>c/`2?Shl0Hf=S06EUI@1CDe<0<S8b020P800N7Qh0ATI608J6QP1]KFd0EEEE
07YjNP2DU9@0Z:RX0<C4a02GUiL0Ng]k05MGE`1UIFD0B4Q802PX:00O7al06a/K01`L700Z:RX0BDU9
03Lg=`0c<c<0;Rh^024Q8@0f=SH0JFUY05=CD`16ATH09bLW02PX:00_;bl0?Cdm03Ph>00[:b/0?clo
0;Ng]`2b/[80E5AD05]KF`1kNg/0/k>c0;jn_P2PX:00=CDe02`/;00V9RH09BDU02XZ:P0Y:BT0?Cdm
0861P@1cLg<0TY:B05MGE`0a<C40?clo03Xj>P11@D40A4A404i>CP1fMWH0>CTi02<S8`0Q8B40:2PX
05mOG`1;Bd/0CTi>06=SH`3<c<`0[Zj^06][J`0^;Rh08b<S051@D02>SXh0CTi>03Ph>014A4@07AdM
01`L700M7Ad0:RXZ05UIF@2OWil0/;2`09bLW02MWId0H61P071`L01JFUX0BTY:02TY:@0c<c<0;2`/
02XZ:P0U9BD0A4A40;Fe]@1LG5`0<C4a08^;R`1TI6@0W9bL07IfMP31`L40GEeM02XZ:P0W9bL0820P
030`<014A4@0GEeM08F5Q@1WIfL0Jf][05]KF`1=CDd0@d=306ATI02CTi<0V9RH04i>CP24Q8@0Fe]K
0080@T9200H0EeMG092@T01UIFD0HF5Q07inOP17AdL202<S8`0F0410@01@D500?3`l038b<P0];Bd0
J6QX05MGE`1>CTh0Ng]k07EeM@2f][H0UiNG04A4A01BDU80YJFU0=SHf039bLT0_kno0<c<c03Bd]80
S8b<092@T080GUiN0140D51@03@d=01=CDd0Lg=c065QH@0Y:BT07AdM07AdM01ADE40T92@0:ZZZP1l
O7`0Q8B406a/K02CTi<0@D51024Q8@0201`L700>01hN7P0L71`08B4Q065QH@2DU9@0JFUY06a/K01o
Ogl0?clo07emO@2PX:00TY:B05UIF@0P820202DU9@0o03lo?`2BTY80[Zj^03/k>`0_;bl0>c/k04a<
C026QXH0UIFE08^;R`2CTi<0NWYj05eMG@0K6a/07QhN02/[:`1;Bd/0Kfm_07UiN@13@d<0BDU908N7
Q`3Jf]X0e]KF09JFUP3Jf]X0gMgM0=WIf@2e]KD0YZJV0;fm_@30`<00]kNg0;Jf]P2LW9`0a/K60=cL
g03Kfm/0OWin03/k>`0W9bL0>c/k08f=S@2_[jl0G5aL03`l?01@D500DU9B075aL@1]KFd0N7Qh0;6a
/@2LW9`0TI6A0:VYZ@0j>SX0<S8b07=cL`27QhL0Cdm?059BDP2IVIT0^KVi00;ooooo00006@1CDe<0
A4A405ADE037alL0[jn_05QHF01[Jf/0GemO03dm?@27QhL0@4100861P@0d=3@0A4A4079bLP0Z:RX0
CTi>03Hf=P0V9RH0HF5Q02HV9P0E5AD0D51@0451@@0M7Ad00P0/;2`0o`0^;Rh0?3`l03@d=01YJFT0
Lg=c05YJFP0P8200<c<c06ATI00g=cL0?3`l03lo?`11@D40:RXZ05YJFP1nOWh0@d=303Ti>@1hN7P0
?3`l034a<@1QHF40BDU905eMG@1<C4`0Ng]k030`<00V9RH0EEEE02/[:`0I6AT0FEUI04I6AP1;Bd/0
EUIF051@D01lO7`0=SHf04i>CP2<S8`0@T920410@02@T900Ph>301`L7010@400NGUi04E5A@1/K6`0
@D5103De=@2FUYH0:BTY05eMG@1mOGd0Ng]k05EEE@1[Jf/0H61P02PX:00n?Sh0L71`06m_K`1DE5@0
@D5104Q8B00j>SX07AdM03dm?@15ADD0DU9B03De=@0c<c<0HF5Q03De=@15ADD0IFEU08N7Q`14A4@0
Ng]k06=SH`0a<C40AdM703@d=01fMWH0IFEU034a<@0l?3`0G5aL03lo?`1UIFD0QHF506MWI`1TI6@0
JFUY03lo?`1mOGd0Ph>304U9B@1gMgL0@D5103Lg=`16ATH0Ph>307MgM`1<C4`0NGUi03Xj>P1JFUX0
I6AT05ADE01<C4`0?3`l06a/K012@T80GEeM05aLG015ADD0>CTi08b<S01nOWh0ADE505YJFP2JVYX0
KFe]04e=C@27QhL0BDU904a<C02JVYX0Ogmo05MGE`1fMWH0<c<c07MgM`2ATI40WIfM05YJFP2FUYH0
GemO07emO@2@T900MGEe04a<C02a/K40Kfm_055AD@2XZ:P0ZJVY092@T01PH600/[:b09ZJVP1OGel0
;Rh^071`L026QXH0VYZJ05QHF01@D500QHF502TY:@1@D500T92@07]kN`17AdL0c<c<07AdM00d=3@0
B4Q8069RHP12@T80G5aL07YjNP0i>CT0Ogmo08j>SP1PH600E5AD04A4A00S8b<0De=C09jNWP1RHV80
OGem0:6QX@0i>CT0CTi>08F5Q@1WIfL0C4a<0::RXP0U9BD06ATI0410@02VYZH0FEUI0451@@1oOgl0
MGEe0820P01FEUH0De=C05QHF02@T900MGEe0451@@1]KFd0J6QX05YJFP1fMWH0E5AD0451@@26QXH0
Vi^K05YJFP11@D40EEEE05eMG@0Z:RX0>CTi05YJFP24Q8@0MWIf0492@P16ATH0MWIf05]KF`1bLW80
Xj>S08>3P`0j>SX0I6AT08>3P`14A4@0EeMG05EEE@0o?cl0ADE505=CD`1MGEd0A4A407=cL`1MGEd0
?clo03/k>`1CDe<0KFe]069RHP1TI6@0TI6A08:2PP2?Shl0FUYJ03Ti>@00BP2l_;`0S8b<06QXJ02I
VIT0OWin07AdM016ATH0GEeM08R8R024Q8@0E5AD07YjNP1fMWH0@D5106MWI`1nOWh0CDe=08N7Q`1T
I6@0DE5A05aLG02YZJT0SXj>06=SH`0b<S80=SHf06][J`11@D408b<S05aLG02:RXX0U9BD06ATI00^
;Rh0CTi>01/K6`0l?3`0XJ6Q08J6QP2QXJ40YjNW06QXJ011@D40@41004e=C@1DE5@0GEeM08R8R01R
HV80IFEU05MGE`14A4@0Cdm?05aLG017AdL0>CTi04A4A01QHF40QHF507IfMP1SHf<0LG5a05YJFP2n
_[h0^k^k0:f][@2[Zj/0G5aL0410@01TI6@0E5AD02l_;`0U9BD0?3`l0P1KFe/0501>CTh0;Bd]01dM
7@0h>3P0:b/[04i>CP1@D500FUYJ0:JVYP3:b/X0^[Zj0;Bd]02?Shl0XJ6Q0;>c/`22PX80K6a/06i^
KP18B4P09bLW0P0L71`03`0K6a/06ATI01TI6@0V9RH0IfMW08>3P`1`L700Shn?09RHV03;bl/0f=SH
0;no_`1hN7P0<c<c01lO7`0201`L700N01dM7@0F5QH05ADE01dM7@12@T80>3Ph03@d=00T92@07QhN
02h^;P1>CTh0IVIV04];B`0^;Rh07QhN03De=@1dM7@0OGem0:RXZ02`/;00^k^k09RHV01?Cdl0ATI6
06a/K024Q8@0P82007emO@1EEED0;Rh^0P0S8b<0900U9BD0EeMG07IfMP1ADE40EUIF08R8R01KFe/0
@41003Ph>013@d<0ATI604A4A01XJ6P0D51@02@T900O7al08R8R07emO@2k^k/0]KFe092@T02EUID0
KFe]096AT@2;Rh/0Jf][02l_;`1:BTX0UIFE04];B`0n?Sh0:BTY01dM7@0L71`0EeMG05IFEP80^;Rh
0840R8R807=cL`1GEeL0Shn?03@d=00h>3P07AdM02<S8`0_;bl09bLW02DU9@0/;2`0Kfm_09bLW016
ATH0De=C08f=S@2FUYH0][Jf0;Bd]02DU9@0MGEe04i>CP1=CDd0?clo02/[:`1IFET0PH61059BDP1>
CTh0H61P0492@P11@D40KFe]08B4Q00l?3`09RHV03De=@1]KFd0B4Q803`l?00h>3P0Hf=S07YjNP2<
S8`0VYZJ07inOP1MGEd0FEUI055AD@10@400<C4a02XZ:P0b<S80V9RH051@D00k>c/0DE5A06ATI02M
WId0S8b<04U9B@1ZJVX0[:b/0=SHf03:b/X0/[:b0=3@d033`l<0Jf][07moO`1VIVH0Cdm?03Hf=P0Y
:BT0;Bd]04E5A@0l?3`0O7al07QhN02PX:00IfMW075aL@1HF5P0D51@07AdM021PH40[jn_03De=@13
@d<09RHV01`L700M7Ad06a/K020P8023Ph<0Lg=c061PH01cLg<0Shn?069RHP2:RXX0eMGE0;:b/P2E
UID0RXZ:09RHV02WYjL0X:2P09FEU@2e]KD0ZZZZ05MGE`0];Bd0>CTi04U9B@2/[:`0MGEe05mOG`1R
HV80EEEE03/k>`0_;bl0<S8b04a<C02EUID0M7Ad0492@P1;Bd/00P2l_;`01@2DU9@0_;bl0=?Cd`3<
c<`0Z:RX0080ZZZZ00H0_;bl0:n_[`30`<00d=3@0<o?c`38b<P20=OGe`0I08j>SP0/;2`092@T02DU
9@0Y:BT0GemO0;:b/P2>SXh0DE5A05EEE@1bLW80`L7108b<S01KFe/0HF5Q08>3P`37alL0a<C40<W9
b@38b<P0bl_;0;Rh^02UYJD0UIFE0:ZZZP02ooooo`0001X0Fe]K04E5A@18B4P0`<300;Vi^@1MGEd0
IFEU06UYJ@0e=CD0QHF503hn?P1gMgL0?3`l05MGE`1kNg/0<C4a04a<C01>CTh08B4Q061PH00_;bl0
5ADE04=3@`0j>SX07AdM030`<080:BTY02L0@41003`l?01QHF40N7Qh07emO@0c<c<0=SHf05aLG015
ADD0DE5A0492@P13@d<09bLW04i>CP2[Zj/0EeMG034a<@1]KFd0>3Ph05IFEP1^KVh0A4A4061PH01H
F5P0DE5A02h^;P17AdL0I6AT04A4A00H61P0KFe]034a<@0R8R80<C4a03lo?`1RHV80=cLg04A4A025
QHD00P0O7al0301FEUH0IfMW01`L700h>3P0ADE501lO7`19BDT0Cdm?030`<01gMgL05aLG03Xj>P80
FEUI03D0?clo04i>CP1HF5P08b<S02d];@27QhL0O7al04i>CP0n?Sh0F5QH06i^KP0k>c/0@T9204M7
A`0l?3`06a/K03/k>`1SHf<0KVi^061PH02<S8`0];Bd0451@@1?Cdl0KVi^03lo?`1DE5@0:BTY055A
D@22PX80AdM704A4A012@T809bLW04];B`1eMGD0P82006a/K01fMWH0?clo05iNGP2>SXh0ADE506UY
J@1HF5P0?clo04E5A@1iNGT0SXj>05ADE028R8P0BDU906e]K@02079bLP29071`L016ATH0KFe]04Q8
B01IFET0OGem07AdM010@400UiNG06i^KP0c<c<0Jf][09RHV01iNGT0B4Q807=cL`1TI6@0=cLg07]k
N`23Ph<0EeMG07YjNP1KFe/0ADE506=SH`2EUID0EeMG08n?S`1JFUX0CTi>065QH@1/K6`0D51@0;no
_`1[Jf/0C4a<08F5Q@2BTY80QXJ605UIF@2PX:00UiNG06YZJP1;Bd/0J6QX06ATI020P800?3`l065Q
H@2LW9`0DU9B06][J`2UYJD0O7al03@d=02^[Zh0JVYZ03Ti>@0^;Rh0DE5A05EEE@1VIVH0TI6A04i>
CP14A4@0I6AT04=3@`1LG5`0H61P02`/;00a<C40N7Qh03/k>`2BTY80U9BD03Hf=P0P8200IfMW03<c
<`0f=SH0FUYJ055AD@0Z:RX0=cLg0<C4a00b<S80<c<c07]kN`0m?Cd0@T9205ADE01SHf<0K6a/07in
OP1TI6@0?Shn05aLG01HF5P0G5aL096AT@1^KVh0:BTY04m?C`2>SXh0OWin04e=C@1ZJVX0F5QH01dM
7@0Q8B40@T9206EUI@28R8P0Bd];04I6AP1aLG40L71`07emO@2d];@0NWYj02d];@1gMgL0Kfm_03Lg
=`1NGUh0@d=3038b<P1HF5P0MWIf05ADE015ADD0JVYZ05YJFP0n?Sh0@D5106i^KP2SXj<00P1WIfL0
C02>SXh0S8b<0861P@0[:b/0@T920:BTY01oOgl0CDe=08^;R`1`L700:b/[028R8P10@400I6AT06EU
I@13@d<0QHF503Lg=`0L71`0B4Q806UYJ@0h>3P0P8200:2PX010@400?Cdm07YjNP1OGel0DE5A02h^
;P0c<c<0FEUI02TY:@0];Bd0?Shn07AdM01/K6`0LG5a03Ti>@23Ph<0AdM703hn?P1WIfL0EUIF06AT
I02>SXh0[:b/06=SH`17AdL0;bl_04Q8B02;Rh/0RXZ:05EEE@1HF5P0?3`l03dm?@1@D500=SHf03Lg
=`1JFUX0L71`07AdM01nOWh0PX:208J6QP2HV9P0]KFe0=OGe`30`<00c<c<0:f][@22PX80KFe]03dm
?@0d=3@205aLG00>02d];@0N7Qh0;2`/03Xj>P13@d<0EUIF08^;R`2?Shl0MGEe0:>SX`2FUYH0XZ:R
0;Ng]`2GUiL20<_;b`0A0<;2`P3<c<`0SHf=03Lg=`0M7Ad06QXJ01LG5`0I6AT05aLG01DE5@0I6AT0
6a/K01DE5@0J6QX0EUIF0::RXP31`L400P39bLT01P3Fe]H0Xj>S02@T900M7Ad06QXJ01LG5`806QXJ
00P061PH01DE5@0G5aL06a/K03`l?00i>CT0:b/[01lO7`809BDU0580;bl_06MWI`1OGel0@d=302PX
:00W9bL0>SXj09VIV@2_[jl0TY:B0<G5a@2GUiL0I6AT061PH01OGel0ATI60492@P1<C4`0F5QH04Q8
B00l?3`0FUYJ09FEU@1IFET0H61P04i>CP1@D500MgMg06e]K@11@D40ADE50410@00m?Cd0Cdm?061P
H00O7al08R8R03@d=01fMWH0Ph>30;Rh^02`/;00KVi^04a<C010@400Hf=S06a/K029RHT0KFe]06IV
IP2DU9@0?Cdm03<c<`0g=cL0Fe]K0:j^[P2>SXh0b/[:0:2PX01kNg/0M7Ad0820P01CDe<0HV9R09nO
W`0k>c/092@T02d];@0W9bL09BDU02PX:00j>SX0Ti>C08F5Q@1OGel0bl_;0<W9b@2a/K40Ng]k04a<
C01LG5`0OGem0`2?Shl08`33`l<0RHV904i>CP1:BTX0ADE503`l?01NGUh0MgMg05IFEP0T92@09BDU
02HV9P0m?Cd0FUYJ0451@@0m?Cd0?Shn0820P028R8P0K6a/04I6AP1CDe<0IVIV079bLP1iNGT0LW9b
075aL@28R8P0Y:BT0:RXZ01_Kfl0H61P07moO`1DE5@0S8b<00<0Xj>S05D0`/;20;Fe]@2b/[80WYjN
09>CT`2[Zj/0YjNW04m?C`0c<c<0;2`/02l_;`0^;Rh0=cLg03lo?`1:BTX0IFEU0<k>cP2WYjL0JVYZ
05iNGP1YJFT0/k>c0;Vi^@3Hf=P0Cdm?02l_;`0m?Cd0;Bd]01XJ6P0M7Ad09RHV0:JVYP1OGel0B4Q8
07=cL`2SXj<0]KFe0<S8b02GUiL0/;2`0;Fe]@1TI6@0CTi>04U9B@1;Bd/0BDU9071`L02KVi/0^KVi
05]KF`0e=CD0M7Ad096AT@0f=SH0@D5108>3P`0c<c<09BDU04i>CP0i>CT0DE5A0;fm_@1`L700CDe=
08f=S@2o_kl0F5QH04M7A`2?Shl0e=CD06a/K01ADE40KVi^08f=S@39bLT0]kNg05aLG01SHf<0YJFU
0=KFeP2f][H0W9bL0;Ng]`0c<c<07alO00808b<S01@0:2PX0451@@2^[Zh0fMWI0<S8b02LW9`0U9BD
05ADE01<C4`0@T9205IFEP3<c<`0f=SH0:n_[`2BTY80RXZ:08F5Q@1jNWX0Shn?0:JVYP;ooooo0000
G01EEED0CTi>03hn?P2QXJ40ZJVY06=SH`1HF5P0B4Q803<c<`1ZJVX0<30`0410@00E5AD0;bl_05IF
EP0e=CD0C4a<04M7A`0I6AT0G5aL0410@00G5aL0?3`l03<c<`0I6AT0<C4a02XZ:P0[:b/0@T9201TI
6@0c<c<0Fe]K075aL@0k>c/0<30`038b<P0B4Q80@T9203Lg=`0l?3`03@d=02PX:01RHV80A4A4028R
8P1MGEd09BDU02`/;016ATH0?Shn05QHF01MGEd0>CTi02<S8`0M7Ad0ADE505ADE00M7Ad0E5AD06QX
J01NGUh0>SXj03/k>`1EEED0;Bd]04A4A02NWYh0E5AD01hN7P19BDT0H61P01lO7`0d=3@0QHF50451
@@1DE5@0IFEU02PX:02HV9P0HF5Q04];B`1TI6@0NGUi05mOG`1;Bd/0KFe]04M7A`0g=cL0VIVI08N7
Q`0_;bl0;Bd]0P0l?3`0I`13@d<0AdM7059BDP19BDT0<30`03<c<`17AdL0DU9B04M7A`21PH40[jn_
06i^KP1ADE40HV9R02l_;`1VIVH0De=C04a<C02=SHd0D51@05ADE01nOWh0Cdm?05EEE@1dM7@0OGem
07]kN`2NWYh0FEUI05iNGP1eMGD0B4Q807moO`1XJ6P0@d=304I6AP1LG5`0?3`l04U9B@2:RXX0BDU9
061PH01?Cdl0Bd];06UYJ@17AdL0CDe=03Lg=`0i>CT0GemO079bLP11@D40Z:RX07emO@0e=CD0ATI6
0:VYZ@24Q8@0AdM707UiN@1`L700BDU909VIV@2BTY80DU9B07moO`1`L700@T9205EEE@1`L700D51@
08f=S@2:RXX0FUYJ09bLW01MGEd0?Shn08F5Q@2HV9P0N7Qh08b<S02@T900CDe=03dm?@25QHD0YZJV
0820P01ADE40IfMW071`L022PX80DE5A03lo?`2:RXX0Fe]K0861P@2SXj<0I6AT03dm?@2HV9P0KFe]
03Ph>00b<S800P1;Bd/0JP1JFUX0SHf=06QXJ019BDT0MgMg0410@01ADE40FEUI03hn?P0b<S80X:2P
06e]K@1nOWh0RHV9034a<@0T92@0GemO04U9B@0`<300FEUI04=3@`0g=cL0A4A40<O7a`1JFUX0ADE5
08f=S@16ATH0Hf=S030`<01@D500OGem08:2PP1dM7@0>SXj05EEE@1CDe<0=cLg07moO`1lO7`0>CTi
075aL@1oOgl0;bl_03De=@22PX80R8R805IFEP0R8R80Bd];065QH@1OGel0<C4a05mOG`23Ph<0KFe]
079bLP2l_;`0H61P01PH6026QXH0MGEe03`l?01JFUX0Fe]K01lO7`0];Bd0@d=305MGE`0k>c/0GUiN
069RHP16ATH0:BTY03/k>`1@D500I6AT05QHF01jNWX0/[:b07EeM@0`<3008R8R08R8R01]KFd0EeMG
08J6QP2:RXX0Kfm_03`l?00o?cl0LG5a05EEE@0/;2`0TI6A06i^KP0m?Cd0E5AD06UYJ@0L71`0EEEE
08j>SP1XJ6P0Bd];07moO`1aLG4203Xj>P14059BDP1VIVH0CTi>0410@014A4@0U9BD09^KV`1ADE40
;Rh^071`L00m?Cd0>CTi055AD@16ATH0@D5104a<C01OGel0UYJF075aL@1jNWX0Kfm_06ATI019BDT0
>SXj08F5Q@0j>SX09RHV03/k>`1HF5P0Fe]K04A4A00e=CD0<C4a03<c<`0a<C40>CTi06a/K03=cLd0
gMgM0<C4a01[Jf/0SXj>03Ti>@1BDU80S8b<06MWI`12@T80FEUI06a/K01OGel0EEEE07AdM022PX80
RXZ:08n?S`1oOgl0RHV9096AT@2g]kL0_Kfm0:NWY`2/[:`0WIfM08B4Q01`L700YJFU06i^KP0K6a/2
01HF5P0301LG5`0L71`06a/K00805aLG00`061PH01/K6`0E5AD06ATI0410@02DU9@0_kno0;:b/P37
alL0RXZ:01`L700H61P201HF5P3501TI6@0G5aL061PH01LG5`0H61P05aLG01TI6@0e=CD0@T9202DU
9@0P82009bLW02<S8`0U9BD0Cdm?06YZJP1NGUh0M7Ad07EeM@23Ph<0VYZJ075aL@2RXZ80De=C04m?
C`1/K6`0VYZJ07moO`1bLW80MgMg08^;R`2BTY80ZJVY0=GEe@2WYjL0?clo051@D010@400<c<c055A
D@2EUID0XJ6Q0492@P0h>3P0=SHf0451@@1RHV809BDU03dm?@1cLg<0CTi>04E5A@1PH600PH6106IV
IP17AdL0BDU90410@01NGUh0D51@07alO02_[jl0][Jf0;no_`2g]kL0^;Rh0<_;b`3:b/X0a<C40=WI
f@3<c<`0Zj^[069RHP1oOgl0IFEU06][J`1/K6`0P820075aL@1WIfL0;Rh^02l_;`0W9bL0:BTY04];
B`2c/k<0ZJVY09jNWP2m_Kd0Q8B406][J`1PH600De=C05MGE`1HF5P0EeMG06i^KP2a/K40YjNW05mO
G`14A4@0@d=305IFEP1^KVh0N7Qh02PX:00N7Qh0820P01dM7@0S8b<0?Shn05]KF`16ATH0@T9205]K
F`2DU9@0SXj>07QhN01UIFD0E5AD0451@@0m?Cd0ATI604i>CP1?Cdl0De=C07YjNP36a/H0WinO0451
@@13@d<0SHf=09jNWP24Q8@0QXJ60<71`@2a/K40FEUI03lo?`28R8P0P82007inOP15ADD0=3@d0451
@@0m?Cd0;bl_03hn?P10@400C4a<0:6QX@3Ogml0g=cL0<S8b02/[:`0XJ6Q0:n_[`3De=@0bl_;0:RX
Z01HF5P0;bl_04=3@`0g=cL071`L051@D037alL0@T9205eMG@1OGel0[Zj^0<_;b`2n_[h0LG5a0;Vi
^@2>SXh0HF5Q05aLG01OGel0@D5103dm?@15ADD0KFe]05]KF`2<S8`0TY:B0;6a/@1lO7`0>c/k065Q
H@3:b/X0N7Qh07MgM`1dM7@0XZ:R0<C4a039bLT00P2GUiL0:`2b/[80Kfm_03@d=00k>c/0S8b<0<o?
c`1<C4`0D51@059BDP0d=3@0NWYj07moO`0o?cl0>SXj07UiN@3;bl/0TY:B079bLP2GUiL0RHV901dM
7@0N7Qh071`L01dM7@0S8b<0NGUi0=OGe`2CTi<0CTi>06ATI01dM7@0EEEE0410@01?Cdl0^k^k08j>
SP0g=cL0<C4a02h^;P0_;bl0?3`l06IVIP1lO7`00_ooool0000m055AD@13@d<0?Cdm0820P01[Jf/0
AdM704m?C`1>CTh0:b/[06i^KP0^;Rh0FEUI04=3@`0];Bd0De=C02`/;018B4P0ATI601<C4`0e=CD0
;bl_01<C4`0d=3@0=SHf01TI6@0W9bL0:BTY02@T901FEUH0<c<c04=3@`1OGel0NWYj03dm?@0e=CD0
DE5A04E5A@0d=3@09bLW04Y:BP0m?Cd0=cLg09NGU`0b<S806ATI079bLP0o?cl0AdM703lo?`0Y:BT0
ADE506=SH`1hN7P0ATI602PX:01@D500>c/k01@D500f=SH0Fe]K05EEE@0204E5A@0^04M7A`0h>3P0
<S8b07]kN`1VIVH08b<S04U9B@1WIfL071`L020P801ZJVX0=cLg04m?C`1HF5P0:BTY08^;R`1`L700
E5AD05]KF`1gMgL0;Bd]03Lg=`2IVIT0HF5Q02l_;`2>SXh0Xj>S07MgM`12@T80ADE503/k>`0/;2`0
Cdm?06m_K`1gMgL0EEEE03@d=00o?cl0C4a<03Xj>P1bLW80UYJF08B4Q01:BTX0Jf][024Q8@80Hf=S
0;X0@41005ADE00X:2P0?clo06IVIP15ADD0De=C06i^KP0m?Cd0CDe=07UiN@1EEED0Fe]K075aL@0b
<S80I6AT05IFEP15ADD0Fe]K07AdM01bLW80Bd];08Z:RP1?Cdl0HV9R08N7Q`1QHF40IfMW04M7A`1a
LG40D51@03Xj>P1TI6@0G5aL03`l?02^[Zh0YJFU04Y:BP15ADD0Shn?06EUI@16ATH0Shn?07AdM014
A4@0IfMW09JFUP18B4P0Ng]k07QhN00e=CD0D51@08Z:RP1XJ6P0Rh^;08j>SP1?Cdl0PX:207alO01=
CDd0SXj>0:BTY023Ph<0QHF508J6QP1EEED0H61P07MgM`2OWil0Kfm_05=CD`1SHf<0KVi^0:6QX@1^
KVh0@41008n?S`22PX80KFe]0;6a/@26QXH0@T9208N7Q`2?Shl0CDe=065QH@1cLg<0LG5a04M7A`1a
LG40JVYZ05YJFP2PX:00Lg=c05YJFP1GEeL0@D5104a<C02h^;P0Rh^;07]kN`2][Jd0@D5104Q8B026
QXH0MGEe02PX:01PH600;2`/01hN7P0Q8B40TI6A06UYJ@13@d<0RXZ:04M7A`1^KVh0@d=303lo?`1B
DU80K6a/06][J`0j>SX0CDe=071`L01GEeL0Hf=S07AdM00n?Sh0MGEe08n?S`1SHf<0>CTi06IVIP1k
Ng/0BDU902HV9P13@d<0De=C07alO01:BTX0=CDe07alO01eMGD0De=C0<C4a01kNg/0@D5105]KF`1d
M7@0>c/k05iNGP1KFe/0GUiN04];B`1@D500FEUI030`<01MGEd0UYJF07alO01?Cdl0>c/k06QXJ016
ATH0:b/[04A4A02JVYX0Ph>305=CD`0V9RH0Rh^;06m_K`0];Bd0KVi^08n?S`1dM7@0=SHf03hn?P1S
Hf<0CTi>02/[:`1hN7P0GEeM04M7A`0m?Cd204A4A00V06=SH`22PX80KVi^04E5A@1nOWh0T92@05iN
GP0Y:BT0:RXZ05EEE@0n?Sh0EeMG03De=@2QXJ40X:2P0820P00a<C40EEEE03Xj>P0i>CT0Hf=S04a<
C011@D40>3Ph04A4A016ATH0Rh^;0:b/[02;Rh/0Cdm?06QXJ02^[Zh0XZ:R05ADE01;Bd/0?3`l02TY
:@0Z:RX3024Q8@0V034a<@1JFUX0KFe]06EUI@1>CTh0_;bl0;6a/@1bLW80KFe]07QhN00P8200?Shn
07moO`2LW9`0QXJ60:n_[`33`l<0UiNG08N7Q`2ATI40N7Qh05ADE01bLW80N7Qh03dm?@1^KVh0Jf][
07QhN02SXj<0K6a/03Ph>011@D40AdM708B4Q01@D50061PH01TI6@0E5AD201LG5`0=01/K6`0I6AT0
5QHF01LG5`0E5AD05aLG028R8P2OWil0R8R80861P@2WYjL0WinO01`L700601DE5@1W01dM7@0G5aL0
5QHF01DE5@0H61P0;bl_04E5A@0T92@07alO02LW9`0];Bd0820P03/k>`2o_kl0YZJV05EEE@0o?cl0
TI6A0820P01NGUh09BDU02PX:015ADD0S8b<05eMG@0g=cL0<S8b02l_;`0i>CT0ATI60820P02][Jd0
NGUi03Lg=`0X:2P09bLW03dm?@1lO7`0NWYj09>CT`1CDe<0>CTi03De=@1JFUX0MWIf07MgM`1>CTh0
AdM704m?C`0d=3@0=cLg09VIV@1aLG40IFEU04U9B@16ATH0K6a/05EEE@2@T900TY:B09RHV02g]kL0
YJFU0:NWY`2YZJT0_[jn0;Jf]P2_[jl0][Jf0;:b/P1ADE40=3@d034a<@0c<c<0?3`l04];B`1iNGT0
QXJ606MWI`0[:b/09bLW04M7A`2FUYH0`<300:RXZ03De=@0_Kfm09FEU@2<S8`0NWYj06UYJ@1_Kfl0
Fe]K04];B`1DE5@0Y:BT08Z:RP2LW9`0WIfM0<;2`P1mOGd0=SHf01dM7@0201`L70807AdM00D09BDU
03/k>`1XJ6P0De=C07YjNP0209JFUP0N07inOP0b<S80=SHf03dm?@0P82007QhN020P800O7al08R8R
06QXJ02^[Zh0/k>c038b<P11@D40UIFE06ATI02?Shl0VIVI05QHF01lO7`0GUiN03Hf=P1dM7@0O7al
07moO`1RHV80@41003Lg=`13@d<0?3`l0P0k>c/00`22PX80clo?0<;2`P020:BTY00i0;Jf]P2][Jd0
]kNg0=CDe01:BTX0GemO0:RXZ02IVIT0AdM705IFEP1lO7`0^;Rh0<k>cP1nOWh0HF5Q06YZJP34a<@0
`<3009:BTP2[Zj/0KVi^04=3@`1;Bd/0De=C04=3@`1^KVh0H61P03Xj>P16ATH0K6a/05IFEP2MWId0
d=3@05UIF@1dM7@0];Bd09bLW022PX80Shn?0;no_`3=cLd0^KVi0;bl_035aLD0Y:BT0:RXZ00a<C40
;Rh^04A4A02f][H0a<C405UIF@16ATH07alO02LW9`1PH600MWIf0080A4A400L0De=C0<G5a@23Ph<0
MGEe08N7Q`2n_[h0@D5100807QhN00h08B4Q02TY:@24Q8@0[Zj^061PH01<C4`0GUiN079bLP2<S8`0
Bd];06ATI02UYJD0NWYj02TY:@80:b/[00@0<c<c04E5A@1?Cdl0Cdm?0_ooool0000n05ADE01VIVH0
CDe=08f=S@1lO7`0?Cdm05QHF01bLW80=cLg04U9B@0N7Qh0CTi>05MGE`0l?3`0GEeM01lO7`0[:b/0
De=C02XZ:P15ADD0=3@d00L71`0V9RH0@D51028R8P0c<c<0:RXZ01LG5`0l?3`0>CTi04Y:BP1fMWH0
RHV9024Q8@0V9RH0>CTi05=CD`0g=cL0:BTY038b<P0Z:RX0=CDe0;Ng]`1YJFT07AdM07=cL`0^;Rh0
EEEE075aL@1BDU80<S8b04A4A01`L700CTi>04Y:BP1WIfL0H61P02@T900b<S80>c/k03Ph>012@T82
05MGE`2;05EEE@0c<c<0O7al04I6AP0K6a/0@T9206UYJ@0Z:RX07QhN06e]K@0a<C40E5AD08>3P`0_
;bl0R8R806IVIP1OGel0J6QX092@T01bLW80?3`l09NGU`0/;2`07alO071`L02>SXh0De=C03dm?@1a
LG40GEeM038b<P0V9RH0?Shn04I6AP19BDT0=cLg03lo?`1KFe/0@d=3061PH025QHD0HF5Q04Q8B01o
Ogl0ADE505=CD`10@400@d=305mOG`1;Bd/0B4Q807EeM@1HF5P0EeMG07IfMP2FUYH0E5AD0820P01;
Bd/0FUYJ08b<S01<C4`0O7al04I6AP0h>3P0@d=305QHF025QHD0B4Q807moO`16ATH0BDU908R8R01F
EUH0Bd];03@d=01WIfL0CTi>03dm?@1TI6@0GUiN03Ti>@25QHD0L71`04U9B@0k>c/0Ogmo05MGE`0a
<C40GemO06m_K`13@d<0CDe=0;Ng]`1XJ6P0QhN708>3P`0g=cL0GUiN0:b/[01`L700TI6A08Z:RP1@
D500Shn?06][J`1;Bd/0SHf=08V9R@1WIfL0OGem09ZJVP1gMgL0MGEe07moO`2WYjL0Jf][04=3@`1E
EED0Rh^;09>CT`1^KVh0E5AD0:j^[P1BDU80=3@d07EeM@2=SHd0?3`l08:2PP2HV9P0:RXZ0451@@1H
F5P0GemO04E5A@1TI6@0>SXj03<c<`02079bLP1a04m?C`1^KVh0=3@d038b<P29RHT0PH6106YZJP2c
/k<0@41003@d=02FUYH0Ng]k02/[:`1lO7`0EUIF03`l?00P8200W9bL06IVIP0d=3@0TY:B07alO01j
NWX0Lg=c05EEE@1aLG40OWin06m_K`0c<c<0G5aL08R8R01XJ6P0PX:207IfMP13@d<0MWIf09JFUP28
R8P0D51@08F5Q@23Ph<0=cLg02<S8`11@D40GEeM09>CT`1WIfL0=CDe079bLP17AdL0>3Ph09^KV`2Q
XJ40C4a<079bLP1cLg<06a/K04E5A@1KFe/0GEeM04=3@`1?Cdl0EUIF02PX:01>CTh0Hf=S05MGE`1?
Cdl0?3`l06ATI01IFET0IfMW03dm?@2IVIT0QXJ604e=C@0U9BD0NWYj09:BTP1PH600CTi>08n?S`2<
S8`0?Cdm03lo?`1KFe/0LW9b03hn?P23Ph<0MGEe05]KF`1=CDd0Bd];06ATI01`L700Ph>306i^KP19
BDT0TY:B09bLW01cLg<0<c<c034a<@1IFET0EeMG05mOG`0m?Cd0_;bl0:RXZ01kNg/0=SHf05eMG@1B
DU800P10@4005`1<C4`0DU9B04Q8B010@400?Cdm06QXJ030`<00d];B0;Jf]P3Kfm/0cLg=06a/K01G
EeL0CDe=05ADE01YJFT0FEUI03Ph>01ADE40LG5a06][J`1@D500<S8b00809BDU00X0PX:20<W9b@3D
e=@0MWIf08B4Q015ADD0;2`/03Lg=`1QHF40/;2`0P3:b/X05`2>SXh0KFe]059BDP0n?Sh0>CTi08J6
QP2ZZZX0>c/k05iNGP1VIVH0EeMG0820P012@T80;2`/034a<@0j>SX0@d=306i^KP1@D50071`L01LG
5`0F5QH061PH00805QHF01@061PH01/K6`0I6AT0>CTi07]kN`33`l<0Z:RX07alO02UYJD0a/K604m?
C`17AdL0<c<c02/[:`0O7al06QXJ01LG5`0J6QX05aLG01DE5@<05aLG0480<c<c0492@P0O7al09bLW
04U9B@16ATH0=cLg0:>SX`1fMWH0D51@0451@@23Ph<0[:b/071`L00c<c<0@41005MGE`2HV9P0WIfM
06EUI@0j>SX0:BTY02PX:00/;2`0?3`l0<71`@2n_[h0U9BD07UiN@1oOgl0NWYj09FEU@25QHD0N7Qh
092@T01jNWX0H61P09VIV@2UYJD0O7al05ADE01>CTh0<30`034a<@0W9bL0<C4a079bLP2<S8`0RXZ:
05IFEP1:BTX0L71`0:RXZ02j^[X0X:2P09VIV@2m_Kd0[Zj^096AT@34a<@0alO70;Jf]P2a/K40^[Zj
08>3P`0o?cl202XZ:P0>038b<P0h>3P0>SXj0451@@1MGEd0NGUi07emO@2RXZ80`L710=WIf@2a/K40
T92@08J6QP2ATI420;Ng]`0=05MGE`1;Bd/0DE5A06ATI01[Jf/0SXj>08>3P`26QXH0MGEe0:BTY01i
NGT0820P01`L700201dM7@0?01lO7`0M7Ad0;2`/030`<01JFUX0IFEU096AT@2HV9P0Rh^;08R8R00i
>CT0;Bd]038b<P0P82008b<S008071`L07D07QhN03Ph>01ZJVX0/;2`05mOG`1VIVH0LG5a09JFUP1[
Jf/0>c/k03`l?01XJ6P0GemO05iNGP1aLG40K6a/09NGU`24Q8@0BTY:03Lg=`0k>c/0>SXj04Y:BP2<
S8`0`L710;Fe]@21PH40OWin07emO@2][Jd0bl_;0:RXZ02_[jl0HF5Q04e=C@1TI6@0U9BD0<o?c`3<
c<`0`L7108F5Q@3Bd]80/[:b05eMG@2PX:00`<3006][J`1gMgL0SXj>09nOW`1>CTh0>c/k05=CD`1K
Fe/0Cdm?061PH01YJFT0A4A404m?C`27QhL0_;bl0<o?c`2g]kL0/[:b07IfMP13@d<0CDe=08B4Q02_
[jl0cLg=0:^[Z`3@d=00dm?C0<71`@1KFe/0:b/[03hn?P2[Zj/0`/;20<W9b@1;Bd/08B4Q020P800[
:b/0FUYJ06ATI00g=cL0Cdm?08^;R`3<c<`0WinO07YjNP1^KVh0TI6A0:>SX`0d=3@07alO02@T900e
=CD0]KFe05]KF`1@D500>SXj04M7A`2][Jd0/;2`09BDU02TY:@0/[:b09JFUP19BDT0EeMG06UYJ@2H
V9P0GemO05IFEP1WIfL00_ooool0001L055AD@2ATI40H61P07alO01hN7P0<C4a04U9B@1SHf<0>3Ph
06QXJ00m?Cd0FEUI04M7A`0e=CD0MWIf0410@00f=SH0E5AD020P800i>CT0EEEE01hN7P0W9bL0Cdm?
00d=3@0V9RH0?Shn01hN7P11@D4051@D020P801BDU80Ogmo04I6AP0/;2`0=CDe01dM7@0g=cL0?Shn
02l_;`0@410061PH06IVIP1MGEd07QhN06MWI`0T92@0;2`/04=3@`1CDe<0=3@d055AD@12@T806ATI
02HV9P0n?Sh0G5aL02LW9`0];Bd0>CTi01@D500K6a/0<c<c03lo?`1;Bd/0:b/[08b<S01]KFd09RHV
038b<P1NGUh0;bl_024Q8@1`L700;Rh^034a<@1VIVH0<30`07inOP19BDT0=SHf03<c<`1WIfL0GEeM
03lo?`2LW9`0G5aL02h^;P2RXZ80_[jn05MGE`0`<302051@D02803dm?@0d=3@0EEEE04E5A@0W9bL0
;2`/03`l?01cLg<0E5AD07EeM@2GUiL0M7Ad03Ti>@23Ph<0Fe]K055AD@1EEED0Cdm?04U9B@13@d<0
B4Q804i>CP0e=CD0ATI606MWI`2;Rh/0DU9B07QhN01`L700CTi>08n?S`1QHF40JVYZ04U9B@16ATH0
C4a<05EEE@1cLg<0DE5A08n?S`1_Kfl0G5aL08V9R@1LG5`0TI6A05EEE@1IFET0De=C04A4A02?Shl0
SHf=04i>CP2@T900MGEe04Q8B01EEED0YZJV08b<S013@d<0N7Qh07YjNP0Z:RX0EUIF0861P@1MGEd0
Ti>C04e=C@1@D500K6a/09>CT`1YJFT0Ogmo07UiN@0`<300MGEe0820P01;Bd/0S8b<09bLW00k>c/0
B4Q807AdM01_Kfl0KFe]0861P@2l_;`0OWin051@D00k>c/0GemO092@T00W9bL0>CTi08Z:RP2XZ:P0
CDe=0:b/[02VYZH0>SXj05mOG`2FUYH0GEeM04A4A015ADD0@41005IFEP2HV9P0OWin0492@P22PX80
IFEU04Q8B027QhL0KFe]0410@02XZ:P0K6a/05]KF`2l_;`0IVIV04=3@`21PH40JVYZ02LW9`1XJ6P0
Kfm_04A4A00N7Qh0UYJF08^;R`0K6a/0B4Q8059BDP1mOGd0KFe]04m?C`80MWIf0280NGUi02d];@0h
>3P0Ng]k06EUI@2<S8`0F5QH030`<01oOgl0XZ:R08N7Q`1HF5P0RHV908:2PP1EEED05aLG03lo?`1T
I6@0UIFE06QXJ00m?Cd0DU9B07QhN00h>3P0RHV909fMW@1JFUX0Jf][07]kN`0o?cl0DU9B05EEE@1;
Bd/0ATI60P1FEUH01`1@D500HF5Q06EUI@1QHF40GemO038b<P1SHf<00P1jNWX0@P15ADD0V9RH07mo
O`1UIFD0;Bd]07UiN@2YZJT0M7Ad05]KF`2SXj<0QHF504E5A@1IFET0P82007EeM@0k>c/0OGem06e]
K@0e=CD0A4A40861P@1cLg<0O7al0:RXZ01YJFT07AdM06][J`1mOGd0NGUi03Lg=`0k>c/0H61P06EU
I@0];Bd0:b/[071`L01YJFT0Fe]K034a<@1WIfL0>CTi02<S8`1JFUX0?Cdm03<c<`0e=CD0>SXj03hn
?P1VIVH0Shn?07MgM`1EEED0[Jf]06e]K@0i>CT0820P02<S8`0a<C40SHf=0:ZZZP2QXJ40_kno05eM
G@0Y:BT08b<S02@T90808B4Q0280JVYZ0:6QX@2RXZ80]KFe08>3P`2QXJ40FUYJ051@D01CDe<0TY:B
0:>SX`2][Jd0JFUY04a<C01GEeL0RXZ:0:j^[P2JVYX0PH6107=cL`1lO7`0QXJ606YZJP22PX80@D51
02/[:`0W9bL0:2PX02l_;`0g=cL0FUYJ05eMG@0U9BD061PH0P0G5aL04P0E5AD071`L0410@01JFUX0
EEEE03Xj>P10@400WinO09RHV02UYJD0c/k>08b<S01:BTX0<c<c03@d=00h>3P0?Cdm04A4A080CDe=
07H0B4Q803hn?P0d=3@0;bl_038b<P2HV9P0JFUY051@D01VIVH0Bd];04Y:BP2d];@0Rh^;05iNGP17
AdL0K6a/0;Zj^P2IVIT0CDe=065QH@1?Cdl0_;bl0<_;b`24Q8@0DE5A04M7A`0`<300;2`/05IFEP2_
[jl0Kfm_0410@01>CTh0EeMG07]kN`2:RXX0YJFU0;fm_@2QXJ40_[jn0<g=c@2SXj<0TY:B096AT@21
PH40BTY:03@d=00N7Qh071`L024Q8@0];Bd0:b/[0410@01_Kfl0NGUi075aL@32`/80W9bL08R8R027
QhL0Vi^K0:NWY`39bLT0`<300;Rh^02/[:`0dM7A0:ZZZP1aLG40QhN706QXJ010@400;Rh^03De=@0b
<S80<C4a03De=@1<C4`0UIFE0:VYZ@2OWil0bl_;0<30`01KFe/0Bd];04E5A@1@D500M7Ad08:2PP1n
OWh0K6a/069RHP1GEeL0L71`09>CT`2YZJT0b<S80;Bd]01OGel07AdM01hN7P0L71`07alO020P800h
>3P0B4Q80451@@1ADE40Bd];08j>SP32`/80IfMW05mOG`1SHf<0;2`/02TY:@0P820071`L0`0M7Ad0
KP0b<S80C4a<092@T036a/H0YjNW09jNWP0g=cL0:2PX02XZ:P0d=3@0ATI606a/K027QhL0DE5A04a<
C02ATI40X:2P075aL@1=CDd0JFUY07]kN`2e]KD0`<300;Rh^02TY:@0S8b<08B4Q01TI6@0GemO06YZ
JP1`L700IVIV0;>c/`21PH40B4Q80820P03Cdm<0aLG507AdM02YZJT0[Jf]0=OGe`2o_kl0b/[:06YZ
JP18B4P0Y:BT09^KV`1PH600QHF5051@D00e=CD0CDe=06IVIP1DE5@0Bd];07IfMP1VIVH0ZZZZ0;Rh
^024Q8@0aLG50:FUY@1ADE40JVYZ05iNGP2;Rh/0R8R80:f][@37alL0d];B0=cLg02HV9P0:b/[03De
=@2XZ:P0][Jf0:^[Z`2OWil0RXZ:01lO7`0N7Qh0820P04M7A`1PH600Kfm_08j>SP1ZJVX0MgMg0:FU
Y@2MWId0H61P07QhN02a/K40XJ6Q02LW9`0Y:BT0UIFE08f=S@1;Bd/0B4Q803Ti>@1BDU80bLW90=CD
e02e]KD0_Kfm0<C4a02^[Zh0LG5a0P1YJFT0101iNGT0Lg=c07MgM`21PH42ooooo`0004L0DU9B07]k
N`1VIVH0O7al08j>SP13@d<0BTY:02h^;P0L71`0@d=303Xj>P0m?Cd07QhN01@D5011@D40=CDe03Lg
=`1;Bd/03`l?01TI6@0d=3@05ADE01lO7`10@4004a<C01hN7P0[:b/06a/K0451@@10@400>CTi051@
D024Q8@0EEEE034a<@10@400>c/k034a<@0o?cl0?Cdm0410@00P8200MgMg059BDP0L71`0KVi^03dm
?@1?Cdl0@41002TY:@0^;Rh0HF5Q06EUI@14A4@08b<S03hn?P1KFe/0;Bd]02PX:01=CDd0BDU9030`
<010@400BDU902<S8`0M7Ad0JVYZ07]kN`0`<300>c/k04I6AP0201`L700S071`L017AdL0<S8b05mO
G`0];Bd0PH6108R8R01CDe<0BTY:07IfMP0b<S80:2PX0:BTY01RHV80<c<c09NGU`2b/[80IfMW04a<
C01MGEd0Bd];034a<@0j>SX0GUiN04M7A`0[:b/0<C4a038b<P1bLW80Bd];06YZJP2IVIT0PX:204A4
A01lO7`00P1IFET0H01YJFT0EeMG05ADE018B4P0EEEE05YJFP1EEED0@D5106UYJ@1cLg<0BDU908N7
Q`1eMGD0DU9B079bLP0];Bd0FEUI05YJFP11@D40C4a<05QHF00o?cl0;Rh^065QH@1RHV80@41006YZ
JP0k>c/0Jf][04];B`1ADE40?Cdm02<S8`18B4P0IFEU0451@@2@T900QXJ602h^;P0U9BD0G5aL05MG
E`0a<C40MgMg09:BTP10@400Cdm?0:VYZ@0g=cL0G5aL08Z:RP0j>SX0C4a<07=cL`0g=cL0NWYj0:BT
Y01EEED0Q8B407=cL`0m?Cd0MWIf0:2PX02MWId0Fe]K07emO@1nOWh0?Shn05eMG@2b/[80Y:BT07mo
O`19BDT0OGem09JFUP1bLW80>SXj08f=S@2h^;P0D51@0861P@38b<P0HF5Q05EEE@2?Shl0GUiN04I6
AP0h>3P0IfMW03`l?01LG5`0Ogmo03`l?01eMGD0HF5Q04I6AP80Jf][0480>CTi09:BTP14A4@0@T92
09^KV`1PH600@41009bLW01FEUH09bLW05=CD`1;Bd/0?clo01dM7@2@T900NWYj02LW9`1UIFD0JFUY
06MWI`0n?Sh0C4a<09fMW@28R8P0MWIf03lo?`0k>c/0PH6105=CD`2>SXh0NWYj059BDP1NGUh0QXJ6
06EUI@14A4@0UYJF0:RXZ01ADE409bLW02`/;01:BTX0OWin06e]K@16ATH0IfMW096AT@1>CTh0J6QX
0:^[Z`1IFET0P82008f=S@0d=3@0FEUI05MGE`11@D40?Cdm07alO01TI6@0E5AD05YJFP1[Jf/0M7Ad
05IFEP1?Cdl208V9R@1007UiN@13@d<0TI6A08n?S`0];Bd0:BTY07inOP2HV9P0J6QX06ATI02UYJD0
KFe]02h^;P0o?cl0B4Q805QHF00];Bd0S8b<09jNWP1NGUh0@41006i^KP0[:b/0IVIV09nOW`1jNWX0
E5AD08V9R@22PX80FUYJ02/[:`1DE5@0OWin06i^KP1JFUX0;Rh^07UiN@1oOgl0EUIF01/K6`1`L700
EEEE03Xj>P2PX:00BDU903<c<`0/;2`0:2PX02DU9@11@D40IFEU05EEE@25QHD0DU9B04U9B@0Y:BT0
71`L01dM7@0T92@0HF5Q02DU9@0R8R80?Shn02DU9@808b<S0P0P82000`0O7al0Ng]k07EeM@0203Xj
>P2X079bLP2?Shl0Z:RX08F5Q@2HV9P0[jn_0;>c/`31`L40Zj^[09RHV02;Rh/0QhN70:BTY027QhL0
LG5a07=cL`27QhL0R8R80:FUY@2?Shl0EEEE03Ph>00W9bL08R8R02TY:@0/;2`0;bl_04Y:BP1gMgL0
=3@d01TI6@0N7Qh0>3Ph04I6AP0f=SH08b<S024Q8@0P8200=cLg079bLP2b/[80XZ:R0<c<c031`L40
^KVi08^;R`1@D500;bl_020P800I6AT092@T02h^;P0];Bd0>3Ph03@d=00f=SH0BDU907AdM017AdL0
<c<c04E5A@1IFET0JFUY0;Fe]@28R8P0KVi^07IfMP1dM7@0[:b/09VIV@1jNWX0QHF509^KV`2UYJD0
W9bL09RHV026QXH0J6QX061PH01EEED0Vi^K07alO01?Cdl0;2`/02PX:00U9BD0?Shn04i>CP1_Kfl0
VIVI0;Jf]P3>c/h0e]KF0<30`02g]kL0ZJVY07]kN`1SHf<0<30`01hN7P0M7Ad08b<S02d];@0T92@0
8B4Q02HV9P0o?cl0WinO0;no_`2DU9@0JVYZ09BDU031`L40hN7Q0=7Ad@2o_kl0b<S80:6QX@2:RXX0
`l?307UiN@13@d<0CTi>06EUI@1eMGD0GemO03hn?P0m?Cd0?clo051@D02ZZZX0QXJ60;:b/P2QXJ40
d=3@0:JVYP1cLg<0E5AD04A4A00k>c/0?clo04I6AP1OGel0MgMg07]kN`2>SXh0dm?C0<G5a@2UYJD0
b/[:075aL@0_;bl0:2PX01lO7`0Q8B40<30`07EeM@1FEUH0GUiN04a<C00h>3P0Ng]k07YjNP11@D40
Bd];05EEE@16ATH0820P0P0N7Qh201`L700_01TI6@0^;Rh0C4a<08j>SP3Rh^80h>3P08N7Q`0M7Ad0
8R8R02DU9@0Z:RX0>c/k07emO@28R8P0B4Q803/k>`0m?Cd0]kNg0=GEe@3>c/h0]kNg09jNWP2>SXh0
LW9b0:RXZ020P800>CTi03Ph>00];Bd09bLW03lo?`15ADD0J6QX05iNGP20P800EeMG096AT@2=SHd0
a<C407inOP2_[jl0HF5Q0;jn_P3Kfm/0[jn_0492@P1EEED00P1]KFd0A01hN7P0F5QH06YZJP1RHV80
>CTi04U9B@1JFUX0E5AD059BDP3;bl/0d=3@06i^KP2k^k/0a/K60<;2`P2KVi/0HF5Q05IFEP11@D40
IVIV0;Fe]@2^[Zh0^KVi0=WIf@2][Jd0EUIF0:FUY@2d];@0Q8B406MWI`1bLW80XZ:R03Lg=`0M7Ad0
<S8b07moO`2PX:00R8R803`l?00/;2`0ATI607moO`2MWId0QXJ605eMG@1eMGD0][Jf0::RXP2IVIT0
^;Rh04m?C`19BDT0<S8b06][J`2DU9@0];Bd0=KFeP38b<P0TY:B0:RXZ02RXZ80@d=303lo?`1NGUh0
S8b<05iNGP1YJFT0KFe]0_ooool0003o05ADE01QHF40>3Ph04=3@`21PH40B4Q805=CD`1]KFd0=SHf
03dm?@0V9RH0@d=306e]K@0c<c<0FEUI01/K6`0P8200De=C02LW9`0[:b/0BTY:00d=3@0>3Ph0@T92
02DU9@0Q8B40<C4a01hN7P11@D40C4a<03dm?@1GEeL0PX:202l_;`0W9bL0?clo04];B`0`<3009BDU
02LW9`0m?Cd07alO08:2PP1JFUX0:BTY06=SH`10@400@d=304];B`1RHV80<C4a04Y:BP1[Jf/0De=C
02@T900n?Sh0AdM701@D500L71`0F5QH04e=C@0_;bl0=SHf04];B`1PH600:BTY06i^KP2;Rh/0>c/k
04M7A`1@D500?Shn01lO7`1bLW80De=C02/[:`1ZJVX0?clo05eMG@21PH40EEEE04a<C01QHF40G5aL
04E5A@2LW9`0MWIf03Ph>026QXH0_kno06][J`1ADE40FEUI0410@00c<c<0?Cdm08j>SP22PX80@410
03<c<`0b<S80Lg=c034a<@1ZJVX0TY:B09^KV`1=CDd0Ng]k02<S8`1=CDd0MWIf051@D01NGUh071`L
02l_;`1>CTh0DU9B03hn?P1MGEd0G5aL03/k>`1LG5`0KVi^05ADE021PH40Fe]K04e=C@1DE5@0>3Ph
05QHF01kNg/0PH61055AD@1gMgL0?Shn03dm?@1lO7`0Fe]K06e]K@0g=cL0D51@04a<C011@D40F5QH
05mOG`0O7al0KFe]09JFUP1UIFD0;Rh^05mOG`1]KFd0B4Q805aLG01mOGd0D51@06][J`30`<00OWin
05iNGP2LW9`0@d=3055AD@1bLW80H61P059BDP2;Rh/0IVIV08J6QP28R8P0LG5a069RHP2LW9`0UYJF
05ADE022PX80LW9b06ATI01HF5P0^[Zj09jNWP2=SHd0A4A407alO02<S8`0QhN70410@01hN7P0`<30
05EEE@1jNWX0c<c<05aLG01<C4`0Rh^;07=cL`1;Bd/0@T9208F5Q@1<C4`0CDe=08F5Q@0k>c/0JFUY
09ZJVP1DE5@0JVYZ06EUI@0n?Sh0TI6A07UiN@1DE5@0];Bd07inOP1<C4`0Y:BT092@T00g=cL0DU9B
05mOG`0m?Cd09bLW092@T02KVi/0CDe=07]kN`1ZJVX0L71`03Xj>P0Z:RX0EUIF04Q8B01bLW80@d=3
03`l?01cLg<0ADE5055AD@1OGel0GEeM05IFEP2IVIT0LG5a04Y:BP1KFe/0EEEE07MgM`0o?cl0;bl_
04U9B@1YJFT0<S8b03<c<`1;Bd/0OGem001405UIF@29RHT0Y:BT03dm?@1@D500Jf][0410@01VIVH0
L71`04E5A@0b<S80BDU905=CD`1EEED0D51@09fMW@26QXH0B4Q802TY:@1:BTX0Fe]K0492@P0e=CD0
/[:b0:b/[01LG5`0;2`/05YJFP22PX80=CDe071`L02GUiL0Ti>C05MGE`10@400A4A4051@D00I6AT0
BTY:06ATI012@T80?clo05QHF015ADD0IFEU09nOW`1`L700CDe=0;Rh^02RXZ80FUYJ02TY:@0X:2P0
>SXj04A4A01DE5@0@D5107moO`1cLg<0EEEE04A4A01LG5`0?3`l02l_;`1VIVH0Ogmo04I6AP0Z:RX2
02DU9@0804=3@`1NGUh0S8b<06ATI017AdL0@D5101dM7@0K6a/201`L700V01TI6@0E5AD071`L02@T
900S8b<08B4Q01hN7P0P82009RHV02TY:@1/K6`0GemO02/[:`0U9BD0:RXZ04M7A`2WYjL0];Bd06IV
IP1RHV80/k>c0;Fe]@1`L700JFUY07AdM01iNGT0Jf][05eMG@1WIfL0NWYj07EeM@1aLG40Ph>30:JV
YP21PH40CTi>0492@P0b<S8202/[:`80;bl_00d0?3`l0:2PX02LW9`0Cdm?02/[:`0U9BD08b<S01`L
700R8R80;Rh^04a<C01^KVh0YjNW0080_;bl00T0VYZJ07alO021PH40Y:BT0:n_[`29RHT0CDe=02TY
:@0M7Ad00P0J6QX07P0L71`0820P02DU9@0i>CT0KFe]02`/;00K6a/08B4Q04Q8B021PH40LG5a04A4
A00d=3@0>SXj0:n_[`2GUiL0=SHf03`l?01aLG40H61P02XZ:P0W9bL0?clo05EEE@19BDT0J6QX0<G5
a@1[Jf/0IFEU03<c<`80:BTY04l0<S8b030`<00l?3`0QHF509jNWP2f][H0^;Rh0;^k^`2a/K40Vi^K
07moO`1nOWh0Cdm?03lo?`0h>3P0=cLg03dm?@0[:b/0:RXZ02DU9@0];Bd0Zj^[0:f][@3>c/h0/[:b
08B4Q026QXH0c/k>0:6QX@1DE5@0UIFE07inOP1TI6@0K6a/0:BTY02OWil0?clo03Ti>@19BDT0J6QX
07EeM@1[Jf/0Cdm?07AdM02BTY80^k^k0:ZZZP1DE5@0WIfM06e]K@0i>CT0@41005aLG01XJ6P0JFUY
04e=C@11@D40F5QH08R8R02j^[X0^KVi0<S8b01fMWH0NGUi06MWI`1SHf<0<C4a03`l?01IFET0[Zj^
09:BTP1WIfL0AdM70451@@1_Kfl0/K6a08B4Q00e=CD0>CTi0080Bd];01h0@d=301hN7P0L71`06QXJ
01PH600I6AT07alO059BDP2l_;`0b<S80:RXZ02i^KT0HV9R02<S8`0O7al09bLW02l_;`1kNg/0f=SH
0<_;b`2KVi/0MWIf0<71`@3;bl/0R8R806a/K01`L700RHV90:RXZ02][Jd2038b<P1C03Hf=P0/;2`0
9bLW038b<P1PH600ATI602/[:`12@T80Rh^;05iNGP0n?Sh0NGUi0<W9b@2UYJD0Jf][0<_;b`3IfMT0
dM7A071`L01_Kfl0?3`l03De=@0k>c/0FUYJ071`L01UIFD0PX:203De=@0m?Cd0GEeM09JFUP1oOgl0
]kNg0<c<c034a<@0^KVi08:2PP31`L40GUiN034a<@1YJFT0OGem08F5Q@2n_[h0clo?0:JVYP33`l<0
a/K60:n_[`1UIFD0@41005EEE@1VIVH0JFUY09JFUP0m?Cd0MWIf0:j^[P24Q8@0A4A403dm?@0c<c<0
A4A405=CD`2;Rh/0SXj>09>CT`1GEeL0LG5a0=7Ad@3Kfm/0Hf=S05QHF01GEeL0@D51059BDP2QXJ40
Xj>S09fMW@1/K6`0KFe]0;Zj^P1]KFd00P0V9RH01@0h>3P0EEEE03`l?00m?Cd0@T9200;ooooo0000
H01@D500V9RH06i^KP1=CDd0S8b<03Lg=`13@d<0HV9R04=3@`12@T80H61P04];B`2@T900=SHf051@
D01OGel0=3@d05mOG`1:BTX0<C4a04a<C00Z:RX04Q8B04=3@`0Y:BT07alO038b<P0_;bl0;Rh^06EU
I@13@d<0IFEU08F5Q@0d=3@08B4Q034a<@1;Bd/0:RXZ04U9B@0/;2`0=CDe01hN7P1oOgl0JFUY03@d
=01KFe/0CDe=03`l?01<C4`0N7Qh03Hf=P1EEED0MWIf06MWI`0[:b/0Bd];06e]K@0a<C405aLG051@
D00b<S80:b/[03Xj>P1^KVh0M7Ad02d];@1UIFD0I6AT02<S8`1<C4`0I6AT051@D00M7Ad0J6QX03dm
?@0];Bd0Lg=c059BDP1ADE40Jf][04E5A@1TI6@0O7al06][J`1<C4`0Shn?07UiN@0G5aL0<c<c07mo
O`1YJFT0;2`/05mOG`1[Jf/0?Cdm01lO7`80ADE50:X0Bd];02l_;`1;Bd/0SHf=03De=@19BDT0OWin
08R8R00b<S80Ng]k05eMG@1:BTX0De=C030`<01gMgL0GemO04=3@`1CDe<0A4A403`l?01eMGD0SXj>
065QH@1bLW80>SXj04E5A@2;Rh/0KFe]04];B`15ADD0;2`/03/k>`1=CDd0EUIF03`l?01ZJVX0EeMG
03Ph>01nOWh0GEeM05IFEP17AdL0FUYJ071`L01:BTX0EeMG07IfMP1UIFD0O7al08R8R01OGel0=SHf
065QH@1hN7P0JVYZ06UYJ@2OWil0Jf][06MWI`35aLD0VYZJ05aLG02YZJT0B4Q805=CD`28R8P0LW9b
04I6AP2?Shl0KVi^08:2PP2FUYH0P820075aL@2QXJ40YJFU061PH01oOgl0J6QX071`L01KFe/0b/[:
08j>SP1VIVH0A4A40:^[Z`2d];@0N7Qh03hn?P1]KFd0XJ6Q04Y:BP1jNWX0`l?305eMG@14A4@0UYJF
055AD@1<C4`0Jf][07MgM`1<C4`0@D51071`L01=CDd0VIVI09nOW`1DE5@0FEUI069RHP17AdL0Zj^[
08J6QP1<C4`0XZ:R06m_K`0];Bd0Ph>308n?S`0f=SH0BTY:04m?C`0`<3006QXJ0820P02ATI40<c<c
09JFUP2QXJ40SXj>071`L013@d<0IfMW05EEE@28R8P0:BTY05ADE025QHD0F5QH06UYJ@1OGel0K6a/
05YJFP2^[Zh0TY:B05QHF01`L700KFe]08V9R@18B4P0CDe=07EeM@2IVIT0SXj>034a<@1BDU80I6AT
03`l?02BTY80YJFU07alO01SHf<0OGem02<S8`1:BTX0Lg=c06m_K`1ADE40I6AT05iNGP80<c<c0440
IVIV07IfMP1YJFT0;Bd]05eMG@1bLW80AdM702LW9`1^KVh0PH6104a<C00X:2P0BTY:09nOW`1/K6`0
CTi>06a/K01dM7@0Fe]K05ADE01ZJVX0Ng]k03/k>`1BDU80L71`051@D01=CDd0OWin06UYJ@1JFUX0
ZZZZ05aLG00I6AT0CDe=07alO022PX80>SXj03/k>`16ATH0Jf][02PX:00U9BD0FEUI08n?S`1bLW80
ATI605QHF011@D40<C4a08R8R01^KVh0PH6103Lg=`0R8R809RHV04U9B@1kNg/0WIfM04Q8B00n?Sh0
=3@d01`L700Y:BT08b<S01/K6`0301DE5@03024Q8@0V9RH07AdM00807AdM01<07QhN04];B`1DE5@0
FUYJ02DU9@0Q8B409BDU02`/;02@T900]KFe09JFUP1MGEd0YJFU0:NWY`1bLW80IfMW03/k>`0m?Cd0
B4Q80080Cdm?0100E5AD06a/K02<S8`0]KFe06UYJ@1UIFD0N7Qh04Q8B012@T80BTY:0451@@0a<C40
:2PX02XZ:P1[Jf/0a<C40P0W9bL0A@0/;2`07alO01XJ6P0R8R80;bl_06IVIP29RHT0Vi^K0;no_`31
`L40];Bd0:>SX`29RHT0N7Qh07moO`2HV9P0[Jf]0;6a/@29RHT0ADE502/[:`0V9RH0:RXZ02h^;P0X
:2P0BDU908F5Q@15ADD09BDU05MGE`1ADE40=3@d02`/;00`<300Kfm_0=WIf@3Bd]80MWIf03Xj>P1T
I6@0HV9R02d];@0L71`07QhN02HV9P0m?Cd0P8200:BTY01nOWh0MWIf075aL@20P800=CDe02h^;P0]
;Bd0=SHf08:2PP2CTi<0Xj>S09RHV02<S8`0SHf=09BDU01lO7`0K6a/065QH@1KFe/0D51@04a<C002
05aLG00P06i^KP22PX80];Bd0;^k^`1[Jf/0YZJV04i>CP12@T80?Cdm0:>SX`1]KFd0ATI605YJFP18
B4P0=cLg0410@01LG5`0LW9b0:6QX@1YJFT0?Cdm03`l?013@d<0Cdm?05iNGP2LW9`0[:b/0<W9b@2<
S8`0DE5A07emO@0g=cL201dM7@0n01hN7P0P8200=cLg08j>SP3AdM40][Jf09NGU`2PX:00YjNW0;2`
/033`l<0Q8B404Y:BP1ADE40T92@0;Vi^@2o_kl0[Jf]08f=S@1bLW80CTi>04U9B@1LG5`0/K6a0:BT
Y01:BTX0B4Q804U9B@2BTY80De=C04e=C@0Q8B4071`L01/K6`0J6QX0@T9209fMW@36a/H0MWIf09fM
W@1XJ6P0SHf=09JFUP1GEeL0;Bd]03hn?P2l_;`0`l?309VIV@1kNg/0GUiN0;Bd]02b/[80YJFU09NG
U`26QXH0ZJVY0=CDe02BTY809bLW02TY:@0^;Rh202XZ:P1G02l_;`1<C4`0Ph>308F5Q@1YJFT0LW9b
0820P01QHF40KFe]0<c<c030`<00^;Rh0=WIf@2>SXh0QHF50<W9b@2ATI40>3Ph02XZ:P0Y:BT0=CDe
059BDP1jNWX0QXJ609BDU01dM7@0IfMW04Q8B025QHD0[Zj^0<K6aP1kNg/0Rh^;0:b/[024Q8@0_kno
09^KV`1fMWH0W9bL0<?3``2OWil0UYJF05mOG`2`/;00c<c<08J6QP17AdL0>SXj04I6AP1UIFD0Jf][
0<K6aP2NWYh0Ng]k04=3@`1nOWh0L71`04M7A`0g=cL0>CTi034a<@1[Jf/0MgMg08j>SP28R8P0V9RH
0=7Ad@3Rh^80`l?30:NWY`1NGUh0AdM706=SH`2SXj<0Vi^K055AD@1=CDd0Jf][0<_;b`1SHf<08b<S
02DU9@0O7al092@T03/k>`0f=SH0>3Ph00;ooooo0000;P1ADE40Ti>C06EUI@1>CTh0UYJF04m?C`0j
>SX0E5AD0410@00o?cl0Lg=c04E5A@1WIfL0;Bd]05=CD`1fMWH0=CDe075aL@17AdL0>3Ph05eMG@1>
CTh05ADE04M7A`0Y:BT08R8R04];B`0g=cL0<C4a05IFEP11@D40Ogmo0:FUY@1FEUH0<S8b03dm?@16
ATH0;bl_05eMG@0Z:RX0<S8b01TI6@1WIfL0Ng]k03Lg=`1SHf<203<c<`1I05mOG`1fMWH0=cLg06i^
KP1kNg/08b<S028R8P14A4@0JFUY0451@@0H61P0GemO02TY:@0R8R808B4Q0492@P1LG5`0:2PX06a/
K020P800>c/k02l_;`0m?Cd0:b/[01hN7P1]KFd0EUIF02DU9@17AdL0<C4a04Y:BP22PX80<30`02l_
;`1ADE40CDe=03/k>`20P800WYjN051@D01GEeL0_kno08J6QP0];Bd0>c/k0451@@0n?Sh0?3`l06IV
IP1=CDd0:b/[028R8P0];Bd0M7Ad05UIF@1YJFT0[:b/0:VYZ@11@D40LW9b06QXJ01?Cdl0DU9B04M7
A`1XJ6P0HV9R04=3@`18B4P0@410030`<01?Cdl0OGem05mOG`1SHf<0L71`04A4A028R8P0MgMg0410
@01HF5P0H61P04a<C01ADE40Fe]K04I6AP1OGel0OWin04=3@`2ATI400P1[Jf/0]@1LG5`0EUIF08f=
S@1KFe/0LG5a08F5Q@1fMWH0NGUi08b<S01dM7@0=cLg07YjNP2CTi<0GemO05IFEP2>SXh0ATI605UI
F@2`/;00R8R805iNGP2RXZ80GEeM08b<S02l_;`0OGem03`l?025QHD0HF5Q0:j^[P2c/k<0PH6106EU
I@2FUYH0Ng]k05aLG031`L40Ph>3071`L01KFe/0bLW90:2PX01:BTX0@41007QhN02OWil0QXJ603dm
?@1]KFd0YZJV06EUI@1_Kfl0b/[:06MWI`0n?Sh0XJ6Q07alO00m?Cd0?clo05]KF`1ADE40>c/k069R
HP0k>c/0GemO08^;R`1>CTh0G5aL07IfMP13@d<0Shn?0820P01ADE40^;Rh06MWI`18B4P0Lg=c0:>S
X`0o?cl0GUiN07MgM`1KFe/06ATI08:2PP2g]kL07AdM04U9B@1EEED0HV9R06i^KP1EEED0Q8B409VI
V@2GUiL0CDe=02DU9@1UIFD0JVYZ07]kN`1UIFD0;bl_0492@P2>SXh0VIVI07alO01fMWH0UIFE08f=
S@0P8200:RXZ0451@@1bLW80NWYj0492@P1[Jf/0QhN704];B`1HF5P0Y:BT05iNGP1dM7@0YZJV0492
@P1>CTh0DU9B03lo?`0^;Rh0NWYj07]kN`1[Jf/0@T9206QXJ01TI6@0;2`/03Lg=`1`L700Ph>306YZ
JP0a<C40IVIV08V9R@0Y:BT0;Bd]079bLP2IVIT0LG5a04m?C`1nOWh0IVIV02TY:@0d=3@0?Shn05mO
G`1=CDd0AdM707EeM@0a<C409BDU06i^KP1BDU80DE5A0;^k^`25QHD0EeMG08:2PP2MWId0P82003Lg
=`1=CDd0Hf=S075aL@1FEUH0>3Ph04i>CP1JFUX0@D510410@019BDT0>CTi01/K6`1`L7000P2JVYX0
2P2CTi<0E5AD03hn?P1[Jf/0_kno07QhN017AdL0@41002DU9@0L71`2020P800401HF5P0E5AD05ADE
01DE5@808R8R03<08B4Q01hN7P0M7Ad08R8R06i^KP1NGUh0?clo02HV9P0Q8B409BDU03dm?@2LW9`0
RHV904m?C`2=SHd0[:b/07]kN`1>CTh0F5QH03lo?`1JFUX0GEeM05ADE01SHf<0Q8B40;6a/@36a/H0
R8R806MWI`1@D500E5AD061PH01KFe/0>3Ph03Xj>P14A4@0B4Q805]KF`1PH600R8R806YZJP0a<C40
;Rh^038b<P11@D40CDe=04I6AP17AdL0TY:B08f=S@3>c/h00P2WYjL03P2UYJD0ZZZZ0;fm_@2FUYH0
N7Qh07inOP2;Rh/0VYZJ0;>c/`2@T900Kfm_04E5A@13@d<0ATI60P1DE5@03`1nOWh0@D5108b<S022
PX80BDU905IFEP2BTY80]KFe09JFUP2PX:00a<C40:b/[02:RXX0E5AD0451@@0201lO7`0G020P800[
:b/0VYZJ05YJFP2IVIT0YjNW07moO`2:RXX0MgMg05eMG@0o?cl0FUYJ061PH01UIFD0W9bL09jNWP2G
UiL0R8R80:^[Z`34a<@0R8R805YJFP0m?Cd00P0c<c<08P16ATH0@D510492@P16ATH0PX:20<[:bP2?
Shl0VIVI04M7A`11@D40@41008J6QP1iNGT0Bd];04I6AP0_;bl0:b/[02`/;00a<C40>c/k05IFEP2C
Ti<0^k^k07QhN01<C4`0ADE504M7A`2PX:00^[Zj09NGU`1WIfL0De=C05UIF@0h>3P301dM7@2F01lO
7`19BDT0QHF505iNGP1ADE40EEEE061PH01BDU80GEeM08>3P`2d];@0TI6A06EUI@2VYZH0hn?S0=[J
fP2l_;`0S8b<04i>CP1EEED0IfMW09nOW`33`l<0ZJVY096AT@2OWil0WIfM0861P@1eMGD0RHV905aL
G015ADD0>SXj06UYJ@2UYJD0WIfM0;Ng]`19BDT0`<3004M7A`1=CDd0OGem09^KV`2a/K40Z:RX0<g=
c@2c/k<0MgMg04a<C01PH600[:b/0:BTY01ZJVX0Ng]k07inOP1gMgL0Kfm_0:>SX`0h>3P0820P02XZ
:P0U9BD0:2PX02`/;01FEUH0`L710<S8b02ZZZX0JFUY07=cL`2j^[X0/;2`0=7Ad@3Ph>00fMWI0=;B
dP1[Jf/0TI6A0:NWY`2VYZH0WIfM05UIF@0];Bd0:RXZ030`<00l?3`0G5aL0;2`/02WYjL0IfMW0:b/
[03@d=00cLg=0<o?c`2`/;00UYJF08:2PP2FUYH0XJ6Q0=cLg03Fe]H0WYjN059BDP13@d<0De=C0:2P
X02WYjL0_kno08V9R@1lO7`0D51@03dm?@1UIFD0]KFe0;bl_02VYZH0>CTi04];B`2OWil0Y:BT030`
<00];Bd0:b/[02LW9`16ATH0UiNG07UiN@2TY:@0e=CD0=SHf03>c/h0DE5A04Q8B01SHf<0WYjN0;Zj
^P3EeMD0b/[:07moO`1GEeL0Ng]k0=KFeP1mOGd0:RXZ02PX:00P82008B4Q03dm?@0c<c<0>CTi0_oo
ool0000o055AD@1UIFD0=3@d030`<01OGel0B4Q803Ti>@16ATH06ATI02<S8`1:BTX0>SXj02d];@0C
4a<09RHV04=3@`0V9RH0MGEe01dM7@0>3Ph0>CTi038b<P0E5AD0ATI6010@400=3@d092@T024Q8@0]
;Bd0<c<c00l?3`0d=3@0JFUY05YJFP0Z:RX0CTi>03lo?`0M7Ad0ATI602PX:00j>SX04a<C04E5A@0n
?Sh06ATI04a<C018B4P09bLW034a<@0/;2`08R8R0451@@1UIFD0Bd];024Q8@0`<300Fe]K01/K6`0I
6AT0FEUI065QH@1EEED0;Rh^0080Bd];06T08B4Q055AD@2<S8`0EEEE03Lg=`13@d<0Bd];01TI6@1?
Cdl0I6AT02`/;01>CTh07QhN03Ph>023Ph<0?Shn03lo?`1IFET0Cdm?02<S8`1NGUh0WYjN05mOG`10
@400alO708^;R`1EEED0FEUI04E5A@12@T80?clo06a/K01TI6@0=SHf02TY:@0e=CD0QHF505QHF01O
Gel0YZJV0;^k^`1@D500KFe]06a/K01:BTX0JFUY05YJFP1bLW80M7Ad04=3@`1GEeL0N7Qh03dm?@1L
G5`0QHF5061PH01_Kfl0SXj>04a<C021PH40LG5a05EEE@2ATI40NGUi059BDP1>CTh0GUiN04A4A01e
MGD0TI6A04=3@`22PX80@T9208B4Q01RHV80ATI6071`L00d=3@0GUiN07QhN01UIFD0HV9R08f=S@0k
>c/0;Rh^05iNGP1gMgL0IVIV04A4A02ATI40@T9204A4A02LW9`0N7Qh05IFEP2BTY80ADE5055AD@1^
KVh0K6a/03Hf=P1dM7@0Fe]K069RHP1nOWh00P1YJFT0X@2KVi/0L71`05=CD`1nOWh0TI6A06QXJ01?
Cdl0cLg=0<S8b02MWId0ADE50:6QX@2f][H0LG5a03Hf=P28R8P0^k^k07moO`1kNg/0dM7A071`L00^
;Rh0U9BD0:JVYP1@D500CDe=04i>CP0_;bl0Hf=S09NGU`1QHF40M7Ad08^;R`0d=3@0PH6108R8R01=
CDd0Ng]k06EUI@0];Bd0KVi^07alO019BDT0KFe]0:VYZ@0W9bL0;Bd]05UIF@0o?cl0?Shn08>3P`2k
^k/0Cdm?06MWI`1/K6`0NGUi04M7A`14A4@0CTi>0::RXP2YZJT0GUiN02PX:01_Kfl0?3`l06IVIP1/
K6`0KVi^03<c<`1nOWh0QhN702LW9`0i>CT0IfMW07IfMP1JFUX0;Bd]04M7A`25QHD0>c/k02@T900o
?cl0PX:205QHF01QHF40[jn_04U9B@0m?Cd0Fe]K069RHP1ADE40FEUI055AD@0j>SX0A4A404];B`1`
L700ADE506YZJP1/K6`0GUiN02<S8`10@400IVIV07MgM`0k>c/0J6QX0861P@1DE5@0?Shn03Hf=P23
Ph<0J6QX05MGE`2EUID0XZ:R06e]K@15ADD0=cLg05aLG00c<c<0A4A40:JVYP1FEUH0?clo092@T01?
Cdl09RHV08j>SP2GUiL0HF5Q05aLG02NWYh0OGem02l_;`0V9RH0;bl_05MGE`1NGUh0A4A404i>CP1O
Gel0EUIF02DU9@13@d<0DE5A02d];@20P800NWYj06UYJ@1VIVH0PX:20<O7a`3EeMD0emOG065QH@10
@400<30`024Q8@0L71`08B4Q00<05ADE00<05QHF01DE5@0P82000P0M7Ad08`0O7al07AdM03<c<`1[
Jf/0IfMW030`<00U9BD08R8R02`/;01_Kfl0LG5a05mOG`1GEeL0Z:RX0=GEe@2j^[X0=SHf02LW9`0`
<300?3`l05IFEP0n?Sh0A4A404M7A`1:BTX0R8R803De=@17AdL0<S8b0410@01;Bd/0DU9B05aLG010
@400?Cdm0080MWIf04T0L71`05YJFP2HV9P0CTi>03dm?@1=CDd0<C4a01dM7@0Y:BT0KVi^06UYJ@2L
W9`0SXj>05QHF01]KFd0TI6A0;no_`2n_[h0Zj^[0:VYZ@2WYjL0LW9b0861P@22PX80Ogmo07MgM`2M
WId0V9RH07YjNP1bLW80JVYZ09jNWP36a/H0_;bl08:2PP1bLW80/K6a0::RXP1dM7@0De=C03lo?`1G
EeL0^KVi0<71`@2LW9`0NWYj06EUI@0k>c/0<c<c0861P@1YJFT0BTY:07MgM`2e]KD0PH610820P02R
XZ80[Jf]09fMW@2JVYX0K6a/05mOG`1NGUh0PH6107UiN@1MGEd0IFEU08n?S`1/K6`0IFEU059BDP0d
=3@0;Bd]00<0=3@d0;P0<c<c04E5A@2QXJ40^KVi0;2`/01[Jf/0>CTi061PH02XZ:P0/K6a06MWI`1O
Gel0:b/[02LW9`0X:2P0:b/[038b<P0g=cL0?clo07UiN@28R8P0:b/[020P800T92@0OWin06IVIP1R
HV80J6QX04a<C015ADD0BDU901lO7`0X:2P0>c/k05=CD`1@D500?Cdm038b<P0c<c<0@T9204M7A`18
B4P0De=C06a/K01oOgl0[jn_09VIV@2YZJT0gmoO0<?3``2][Jd0U9BD075aL@2PX:00aLG50:BTY01c
Lg<0J6QX051@D015ADD0DU9B04e=C@1UIFD0LG5a04];B`1iNGT0];Bd0:NWY`2f][H0alO708j>SP28
R8P0_kno05QHF018B4P0GEeM06e]K@2;Rh/0a<C40<c<c03=cLd0];Bd08R8R02^[Zh0a/K60<;2`P1_
Kfl0B4Q8030`<00/;2`0=SHf069RHP1`L7007alO02d];@0U9BD0:BTY03De=@1IFET0De=C0;Rh^02n
_[h0cLg=0;^k^`2g]kL0UYJF0<30`02OWil0SHf=0<?3``1iNGT0/K6a09RHV01<C4`0DU9B08B4Q02;
Rh/0IfMW03@d=00`<300?clo04Y:BP1MGEd07AdM08n?S`2NWYh0/k>c0;Bd]02i^KT0CTi>03Ph>01M
GEd0^KVi0=;BdP2VYZH0=CDe02h^;P0[:b/0=SHf05YJFP2j^[X0UYJF0;:b/P2f][H0^k^k08Z:RP2Z
ZZX0Xj>S07YjNP2JVYX0;Rh^034a<@23Ph<0fm_K09RHV015ADD0;bl_038b<P1^KVh0a/K608n?S`2Z
ZZX0cLg=0=GEe@3De=@0UiNG09ZJVP2e]KD0/[:b0<k>cP3=cLd0/K6a09bLW02VYZH0e]KF0;Ng]`2[
Zj/0=cLg02l_;`0[:b/09BDU02h^;P11@D40EeMG0_ooool0003V04m?C`1oOgl0GEeM04U9B@1dM7@0
CDe=03Lg=`1MGEd0ATI6034a<@0b<S80:2PX05EEE@0h>3P08b<S02XZ:P0B4Q80A4A402TY:@0I6AT0
>SXj01LG5`0;2`/09RHV024Q8@0G5aL08B4Q014A4@0F5QH0;2`/02TY:@1UIFD0Rh^;04I6AP0I6AT0
:BTY055AD@0^;Rh0>SXj01TI6@10@4009RHV05QHF01DE5@0BDU904Y:BP1IFET0<30`03<c<`1YJFT0
=SHf05ADE01KFe/0Lg=c03Ph>00i>CT0GUiN069RHP0N7Qh0@T92069RHP1IFET0<C4a04=3@`1gMgL0
C4a<04e=C@2CTi<0I6AT030`<01:BTX0IVIV01XJ6P1GEeL0MWIf02PX:01:BTX0>SXj02l_;`2KVi/0
>c/k03Lg=`1?Cdl0GUiN061PH011@D40WinO07EeM@10@400bLW909^KV`1XJ6P0E5AD04=3@`1JFUX0
@d=306ATI02?Shl0HV9R02h^;P0g=cL0NGUi055AD@1<C4`0VYZJ0;Rh^01NGUh0G5aL06i^KP14A4@0
NGUi055AD@1UIFD0@d=3038b<P1;Bd/0L71`03/k>`1OGel0JFUY03Ph>01=CDd0M7Ad04];B`20P800
GEeM03/k>`24Q8@0H61P04m?C`1>CTh0HF5Q04a<C01NGUh0RXZ:0451@@29RHT0GEeM07EeM@1EEED0
ADE509FEU@1=CDd0E5AD06QXJ01JFUX0H61P0;Fe]@1ZJVX0=SHf059BDP1/K6`0@D5104=3@`2QXJ40
I6AT04Q8B02WYjL0Kfm_05aLG02FUYH0KVi^05YJFP29RHT0IVIV03Ph>02IVIT0Ph>307]kN`1iNGT0
<C4a04i>CP2BTY80WIfM05mOG`2l_;`0X:2P03<c<`0a<C40S8b<0:JVYP1MGEd0BTY:09FEU@2m_Kd0
U9BD030`<01GEeL0RHV903<c<`1EEED0_;bl09bLW00S8b<0Fe]K06m_K`0c<c<0@D5106=SH`0g=cL0
9BDU05QHF016ATH0RXZ:0;6a/@0g=cL0?Shn06=SH`0h>3P0QhN70:2PX01PH600RHV907alO00/;2`0
GemO09>CT`1LG5`0=cLg05iNGP1<C4`05aLG04m?C`2][Jd0CTi>06a/K020P800IVIV05iNGP1ADE42
04=3@`0M09NGU`1XJ6P0=3@d069RHP1`L700GUiN069RHP23Ph<0>3Ph08n?S`2ZZZX0Ti>C04a<C02:
RXX0QhN7055AD@0_;bl0C4a<08>3P`1kNg/0BDU904M7A`2@T900CTi>07UiN@2o_kl0S8b<05mOG`1G
EeL00P1;Bd/0=@20P800Kfm_06ATI01JFUX0GEeM065QH@0m?Cd0LW9b09nOW`1fMWH09bLW0492@P1V
IVH0De=C02/[:`1iNGT0Z:RX07alO015ADD0>CTi08>3P`0N7Qh0@d=307=cL`2=SHd0Ng]k04Q8B00i
>CT0EUIF051@D00i>CT0LW9b05aLG00j>SX0T92@08F5Q@1FEUH0Vi^K07AdM01MGEd0;Bd]08B4Q01o
Ogl0>c/k02HV9P0d=3@0MWIf07]kN`1SHf<0CDe=05ADE01@D500H61P0080ADE500/0<c<c092@T020
P800RXZ:09BDU02MWId0d=3@0=_Kf`3Jf]X0TY:B02d];@0201`L700302HV9P0R8R805ADE00<05ADE
00@061PH02d];@0S8b<07AdM0P0L71`0;01QHF40CTi>06=SH`0Y:BT08b<S02@T900f=SH0U9BD08^;
R`26QXH0Shn?08R8R02DU9@0ZJVY05MGE`0U9BD092@T03De=@1:BTX09RHV02l_;`0k>c/0@41005MG
E`1HF5P0?3`l05IFEP1RHV80?3`l04Y:BP1WIfL0P82007emO@1CDe<0FEUI06QXJ01_Kfl0U9BD096A
T@1oOgl08B4Q01LG5`0i>CT0GemO0P1EEED08P2_[jl0Shn?061PH01GEeL0NGUi0;Ng]`2n_[h0[Jf]
0;Fe]@2[Zj/0QHF50:RXZ036a/H0UiNG0:NWY`1cLg<0Kfm_075aL@2NWYh0[jn_0;fm_@3@d=00VYZJ
08^;R`2@T900Fe]K04M7A`0h>3P0<C4a02`/;011@D40IfMW07UiN@2g]kL207alO00R06e]K@28R8P0
d=3@07YjNP1>CTh0G5aL0:VYZ@2QXJ40O7al09:BTP1eMGD0MgMg09nOW`1iNGT0T92@04a<C00a<C40
Hf=S05YJFP1DE5@0GUiN06][J`1IFET0EeMG05aLG00f=SH0:RXZ03@d=00a<C40;Rh^03lo?`2HV9P0
clo?0<K6aP80NWYj0740Z:RX09:BTP2a/K40[Jf]065QH@0e=CD0:b/[02DU9@0T92@09bLW03Lg=`0o
?cl0?Shn06QXJ018B4P0820P02@T901`L700EUIF04m?C`1SHf<0Bd];03Xj>P1hN7P0BTY:0492@P0g
=cL0=3@d034a<@0/;2`0;Rh^02/[:`0Y:BT0;bl_0410@01=CDd0PH6106i^KP2<S8`0]KFe0=7Ad@3R
h^80b<S80;:b/P39bLT0TI6A07YjNP1JFUX0D51@04Y:BP1<C4`0WinO06YZJP1PH600Hf=S04m?C`0f
=SH0<c<c06EUI@2RXZ80[Jf]0;Bd]03@d=00dM7A08F5Q@1PH600YZJV06m_K`1nOWh0[:b/0;no_`2k
^k/0]kNg0;Zj^P2i^KT0`<300<W9b@3Fe]H0emOG09nOW`2GUiL0M7Ad04a<C00k>c/0CDe=065QH@15
ADD0:RXZ02@T9014A4@0GEeM02d];@0b<S80/;2`06a/K02[Zj/0[Zj^0:ZZZP1mOGd0_;bl07EeM@1O
Gel0^[Zj065QH@1^KVh0O7al04E5A@0l?3`0?Shn04];B`21PH40Zj^[06a/K00202XZ:P0l04i>CP0g
=cL0PH61051@D01/K6`0UiNG06ATI00^;Rh0=3@d05iNGP1_Kfl0[jn_06a/K00V9RH0:2PX02HV9P0Z
:RX0>3Ph0:>SX`1fMWH0SHf=0=WIf@3WinL0c/k>0:BTY01GEeL0KVi^0:NWY`0`<300=cLg09nOW`2a
/K40`/;20:6QX@1EEED0PX:20;:b/P1eMGD0IFEU09FEU@31`L40c/k>0;:b/P2m_Kd0^;Rh0;fm_@2o
_kl0bLW90:b/[02IVIT0YjNW0:JVYP2EUID0f][J0=WIf@2][Jd0HV9R059BDP17AdL0B4Q80P1<C4`2
ooooo`0004H0GUiN05mOG`1YJFT0DU9B07]kN`1IFET0<30`04Q8B01PH6008b<S06e]K@0n?Sh0PH61
04];B`0S8b<0ATI602DU9@1>CTh0<c<c01`L700g=cL07alO01<C4`0a<C40:BTY01XJ6P0T92@07alO
02DU9@12@T80=CDe06=SH`25QHD0A4A401`L700_;bl0CDe=02XZ:P1BDU80:BTY02h^;P0O7al0ATI6
06MWI`1<C4`0A4A4059BDP0X:2P0<C4a05mOG`0m?Cd0EUIF05ADE01]KFd0>c/k04Q8B01RHV80GemO
020P8011@D40ADE504=3@`0_;bl0DE5A07EeM@1?Cdl0BDU90820P01;Bd/0>SXj0P1^KVh0W@0I6AT0
Cdm?06a/K00a<C40I6AT069RHP0U9BD0U9BD05=CD`0h>3P0E5AD08>3P`1cLg<0?Cdm0:>SX`1CDe<0
<C4a09JFUP2JVYX0L71`05IFEP1?Cdl0D51@02HV9P1<C4`0Lg=c06=SH`0`<300;bl_06a/K01LG5`0
Bd];08^;R`2a/K40EUIF04A4A026QXH0De=C05IFEP1=CDd0De=C05]KF`0l?3`0@D5105QHF00h>3P0
K6a/0861P@1fMWH0GEeM065QH@0f=SH0P820092@T015ADD0N7Qh02XZ:P0n?Sh0KFe]08n?S`1^KVh0
HV9R03dm?@0H61P0KVi^07IfMP1YJFT0:b/[02d];@2EUID0NGUi05ADE01CDe<05ADE03Hf=P2NWYh0
U9BD04=3@`1OGel0N7Qh01@D500U9BD0FUYJ061PH00j>SX0UiNG08N7Q`13@d<0JFUY03Xj>P1jNWX0
YjNW08V9R@0T92@0I6AT0451@@1[Jf/0WYjN061PH017AdL0MGEe04E5A@0d=3@0O7al08R8R025QHD0
E5AD09NGU`30`<00IVIV03`l?01gMgL0SHf=09ZJVP1<C4`0IFEU0:ZZZP1lO7`0JVYZ0<k>cP2b/[80
;Bd]04a<C02VYZH0CTi>03dm?@1gMgL0AdM702DU9@1IFET0DE5A05ADE02ATI40GemO03hn?P1WIfL0
ATI6051@D02QXJ40KVi^09VIV@2JVYX0GUiN051@D02NWYh0J6QX03dm?@2GUiL0N7Qh01`L701=CDd0
c<c<03dm?@1WIfL0Shn?08V9R@1kNg/00P1MGEd0=P1=CDd0Y:BT03`l?00h>3P0GEeM07IfMP1VIVH0
JFUY04U9B@14A4@0RHV90:6QX@2ATI40CTi>09>CT`2VYZH08b<S03<c<`1YJFT0Ogmo08n?S`1;Bd/0
A4A407moO`0d=3@0Cdm?09RHV028R8P0F5QH065QH@1@D500>CTi04i>CP1HF5P0GEeM05QHF01JFUX0
HV9R03<c<`14A4@0Lg=c06e]K@0[:b/0?3`l06IVIP12@T809BDU069RHP1`L700G5aL04Y:BP0^;Rh0
Shn?07alO080EeMG02d0SHf=07IfMP0i>CT0=CDe04];B`1PH600>c/k08J6QP1eMGD0>c/k09:BTP2N
WYh0JFUY09BDU01XJ6P0FEUI02`/;01@D500QHF504];B`0Y:BT0;bl_07QhN026QXH0J6QX04E5A@1L
G5`0Cdm?061PH00k>c/0A4A403Ti>@1cLg<0NWYj09FEU@2GUiL0TI6A09JFUP2YZJT0dM7A09VIV@1<
C4`08b<S01PH600M7Ad00P0G5aL06P0E5AD051@D01DE5@0S8b<0QhN708^;R`1GEeL0=SHf030`<01j
NWX0I6AT04A4A00X:2P0<S8b05MGE`1ZJVX0MGEe07=cL`1nOWh0N7Qh05aLG015ADD0CDe=09^KV`1W
IfL0:BTY0P0[:b/0600Q8B4092@T03Ph>01FEUH0EEEE061PH00Y:BT09RHV03@d=01JFUX0G5aL04Q8
B01`L700SHf=061PH00o?cl0<C4a03<c<`1mOGd0Lg=c0861P@0o?cl0ADE504Y:BP80?Shn00<0DU9B
065QH@1TI6@00P1DE5@0G@1SHf<0QhN704];B`0d=3@0=cLg030`<00L71`092@T03Hf=P1lO7`0YZJV
09RHV02JVYX0ZZZZ0:JVYP35aLD0emOG07alO02ATI40RXZ:05QHF01>CTh0GEeM079bLP1QHF40CTi>
06YZJP11@D40=cLg059BDP2HV9P0L71`05mOG`1BDU80QHF50;Vi^@2:RXX0IFEU06a/K02>SXh0ZJVY
0;no_`2YZJT0`/;209RHV01[Jf/0TY:B0451@@0Z:RX0;bl_07=cL`1DE5@0DE5A05YJFP1:BTX0D51@
055AD@1HF5P0>3Ph02LW9`0V9RH0;Rh^03Hf=P2LW9`0e=CD0=3@d02d];@0NWYj07MgM`1MGEd0K6a/
06IVIP1eMGD0GUiN03Xj>P0Z:RX08B4Q020P800V9RH0:2PX038b<P0k>c/0DU9B04=3@`0g=cL0KFe]
04=3@`0o?cl0OGem059BDP1ADE40@d=302h^;P0202TY:@0E02d];@0[:b/0:BTY02PX:00Y:BT0:2PX
02TY:@0/;2`0A4A405QHF01`L700U9BD0<O7a`3Ogml0_[jn0;^k^`2n_[h0alO70:n_[`20P800Bd];
0080DE5A03X0FEUI07YjNP1_Kfl0E5AD04Q8B01>CTh0>c/k03Hf=P1OGel0QXJ609fMW@2SXj<0aLG5
0;no_`2YZJT0R8R80=KFeP3=cLd0aLG50<?3``3;bl/0e=CD0=3@d039bLT0/k>c0;2`/03Jf]X0c<c<
08f=S@14A4@0EeMG07]kN`28R8P0YZJV0;6a/@2PX:00YZJV08R8R01lO7`0MWIf03Xj>P0_;bl0HV9R
08b<S01BDU80Kfm_0;6a/@37alL0Xj>S0=[JfP1DE5@0ADE50;>c/`15ADD0@41005eMG@15ADD0=SHf
0P0h>3P05@0o?cl0C4a<05IFEP0Q8B408R8R02l_;`20P800D51@06EUI@1GEeL0O7al03Ti>@0/;2`0
<S8b04m?C`1IFET0W9bL04i>CP0Q8B408b<S02DU9@0202d];@0L09^KV`1gMgL0GEeM0;Vi^@30`<00
X:2P0861P@1>CTh0GUiN0;2`/017AdL0MgMg03/k>`0W9bL0?clo06MWI`34a<@0W9bL05YJFP1GEeL0
GEeM0<30`034a<@0QhN705YJFP27QhL0YZJV0:2PX080WIfM00h0Y:BT0:j^[P1cLg<0KVi^0<71`@3>
c/h0TY:B07=cL`1IFET0?Shn03Lg=`0d=3@0>CTi04I6AP;ooooo0000o`1iNGT0Lg=c08B4Q01UIFD0
UIFE08f=S@0l?3`0C4a<05mOG`0R8R80NGUi0410@01iNGT0CDe=02/[:`1TI6@0=CDe05=CD`16ATH0
820P04Q8B017AdL071`L02XZ:P0l?3`05aLG02l_;`0o?cl0;Rh^04m?C`0_;bl0HF5Q08R8R01ADE40
9RHV02l_;`0h>3P0820P05YJFP0/;2`0?3`l01HF5P0e=CD0VIVI05IFEP10@400CTi>02@T901@D500
IFEU03Xj>P19BDT0EeMG04U9B@0[:b/0EUIF07=cL`1KFe/08B4Q03Lg=`13@d<09BDU01XJ6P0W9bL0
FEUI04Y:BP1@D500Q8B405UIF@0S8b<0?Shn065QH@0L71`0Bd];05=CD`0Q8B40A4A40451@@0M7Ad0
MGEe01hN7P0P8200;Bd]05mOG`1IFET0<c<c09nOW`1BDU80<S8b0:>SX`2VYZH0H61P04m?C`2ATI40
NGUi03dm?@1:BTX0RXZ:051@D00J6QX09BDU06=SH`22PX80Cdm?0:JVYP3De=@0B4Q803Ti>@2MWId0
GUiN05IFEP0[:b/0@41008F5Q@12@T80AdM70451@@0H61P0E5AD0820P01`L700CTi>038b<P0I6AT0
GEeM08Z:RP12@T80MWIf024Q8@0V9RH0?Cdm069RHP1JFUX0EUIF05mOG`0[:b/0G5aL06UYJ@1XJ6P0
Jf][02l_;`26QXH0AdM705EEE@1kNg/0IVIV03lo?`2<S8`0BTY:02DU9@1DE5@0QhN7069RHP0e=CD0
@T92065QH@0T92@0Hf=S08B4Q01KFe/0MgMg05]KF`14A4@0Ng]k08F5Q@0e=CD0DU9B06UYJ@1>CTh0
Jf][071`L01DE5@0LG5a09VIV@1^KVh0/K6a08Z:RP2LW9`0GUiN092@T037alL0Ph>304I6AP21PH40
H61P08f=S@1GEeL0O7al0<C4a01jNWX0I6AT0:j^[P2g]kL0ADE507YjNP2f][H0EUIF03dm?@1`L700
D51@02h^;P1hN7P0Kfm_05mOG`2BTY80EUIF05UIF@1mOGd0B4Q80451@@2CTi<0B4Q809>CT`2=SHd0
F5QH04e=C@2ATI40;bl_02LW9`1GEeL0@41001PH600n?Sh0b<S804e=C@15ADD0KFe]07]kN`1YJFT0
EUIF06][J`1ADE40Rh^;07MgM`0f=SH0@d=305iNGP1QHF40Hf=S075aL@0/;2`0D51@0:VYZ@2DU9@0
FEUI09NGU`2;Rh/0DU9B02@T900j>SX0FEUI08b<S01JFUX0@41006m_K`007P1gMgL0F5QH0;Vi^@2[
Zj/0C4a<05QHF02:RXX0Hf=S06m_K`1ADE40IfMW05YJFP1EEED0NWYj05=CD`1NGUh0R8R807QhN00b
<S80=cLg06MWI`1PH600>3Ph07alO01dM7@0IFEU04m?C`14A4@0YjNW092@T080Fe]K02`0MgMg06IV
IP16ATH0MgMg08R8R01`L700?Shn07moO`1eMGD0E5AD0:RXZ02YZJT0K6a/09nOW`1MGEd0DU9B05=C
D`24Q8@0R8R805EEE@0c<c<0=3@d07]kN`29RHT0L71`04Q8B01aLG40Lg=c071`L00n?Sh0Bd];034a
<@2DU9@0^KVi09nOW`2MWId0FEUI055AD@1UIFD0]kNg0;:b/P2DU9@0Fe]K01TI6@805ADE03l04a<C
01DE5@0E5AD06QXJ02/[:`0g=cL0DU9B07QhN029RHT0YjNW0;^k^`3AdM40MgMg0820P026QXH0MgMg
06QXJ02b/[80[Jf]06][J`1>CTh0A4A403@d=00a<C40Fe]K09BDU01KFe/0;2`/02<S8`0P82009bLW
03lo?`1HF5P0DU9B06a/K014A4@09BDU028R8P0Q8B40;2`/065QH@1/K6`0IFEU06e]K@16ATH0<30`
034a<@0];Bd0>CTi07alO01YJFT0<S8b02`/;00^;Rh0ADE503Lg=`0H61P0:BTY02XZ:P0b<S80<c<c
069RHP0V9RH01P0E5AD0A`0M7Ad0EUIF02l_;`0o?cl0JVYZ09ZJVP3Bd]80gMgM0=7Ad@2HV9P0JFUY
03lo?`11@D40?clo04M7A`1EEED0LW9b08N7Q`0l?3`0:2PX02LW9`1@D500Ph>3075aL@1FEUH0Lg=c
0<;2`P2RXZ80XJ6Q09RHV01HF5P0?clo06m_K`2QXJ40WinO0;fm_@1fMWH0Bd];05MGE`0/;2`09bLW
055AD@1XJ6P0DE5A03dm?@1?Cdl092@T02LW9`1;Bd/0Shn?0410@00T92@0?Shn0861P@3<c<`0`l?3
09bLW02IVIT0O7al05=CD`21PH40[Jf]06ATI017AdL0FUYJ06][J`13@d<09BDU020P800Q8B409BDU
0080:RXZ00@0<S8b051@D02PX:00E5AD0P0l?3`01P1]KFd0De=C06a/K010@400:b/[02d];@80:BTY
03d092@T020P800T92@08B4Q02@T900/;2`0@T9205]KF`1UIFD0IfMW09fMW@35aLD0][Jf09JFUP2d
];@0cLg=0;Rh^030`<00emOG0:RXZ027QhL0TY:B08J6QP11@D40BDU90451@@1EEED0BTY:04m?C`1:
BTX0IVIV071`L02HV9P0Vi^K08n?S`2EUID0_;bl09NGU`2SXj<0dM7A0<W9b@2n_[h0/K6a08:2PP20
P800SXj>0:ZZZP3Jf]X0fm_K09>CT`28R8P0BTY:03Ph>00k>c/0A4A403dm?@1WIfL0TY:B0:6QX@2O
Wil0YJFU0080_kno02H0^k^k0<c<c01VIVH0E5AD08b<S03De=@0d=3@0=SHf038b<P0^k^k08b<S02j
^[X0@T9203`l?017AdL0D51@02l_;`0a<C40=3@d03Lg=`0k>c/0?Shn03Ph>00U9BD0:2PX05aLG015
ADD0H61P04Y:BP1iNGT0;2`/034a<@0c<c<0CTi>05MGE`2^[Zh0?3`l02@T90809BDU0180:2PX02l_
;`2UYJD0Cdm?04A4A020P800HV9R0:BTY02LW9`0BDU905QHF02ZZZX0PH6102l_;`0/;2`0Cdm?096A
T@33`l<20;:b/P0J0:n_[`2VYZH0`<300<K6aP2ATI40a/K609RHV01WIfL0OGem09>CT`2a/K40Vi^K
09ZJVP2;Rh/0/;2`0<;2`P2UYJD0Q8B408V9R@1OGel0@41004Y:BP1KFe/0IFEU05YJFP1DE5@2oooo
o`0006<0UYJF07alO01dM7@0@T9206EUI@1SHf<0=SHf05QHF00/;2`05ADE04];B`0^;Rh0EUIF01/K
6`0P8200EEEE02TY:@1KFe/0C4a<00h>3P0c<c<0BDU901DE5@0N7Qh0AdM7010@400J6QX0<30`02`/
;01EEED0:BTY03De=@1FEUH0Hf=S02l_;`0b<S80?clo02HV9P1DE5@0;2`/04e=C@0U9BD0:2PX06MW
I`12@T80=CDe061PH01?Cdl0VIVI08R8R00[:b/0?Shn07]kN`1^KVh0>CTi03<c<`1;Bd/0FEUI028R
8P0b<S80LG5a06QXJ00^;Rh0<C4a05MGE`0F5QH0<S8b07IfMP2<S8`0=3@d05ADE018B4P04A4A05EE
E@2=SHd0A4A405=CD`0j>SX061PH06e]K@1:BTX0:b/[03De=@1ZJVX0;2`/02HV9P2LW9`0P82004i>
CP2LW9`0`/;2028R8P0X:2P0F5QH07alO01HF5P0ADE509JFUP1NGUh00P0K6a/0jP0j>SX0M7Ad04E5
A@2HV9P0d=3@06IVIP0[:b/0QXJ605MGE`1hN7P0@d=303Hf=P1]KFd0>SXj06MWI`1/K6`0>SXj04I6
AP1VIVH0?Shn04m?C`1aLG40@T9205ADE01UIFD0;bl_07IfMP1YJFT0=CDe04A4A01>CTh08B4Q03/k
>`2>SXh0D51@05aLG01FEUH0AdM707emO@0m?Cd0MgMg05IFEP0m?Cd0JVYZ07emO@1;Bd/0]kNg04m?
C`0n?Sh0BDU907IfMP1SHf<0FUYJ05eMG@26QXH0?Cdm06i^KP1mOGd0CTi>09BDU01oOgl0ATI608J6
QP29RHT0@410079bLP2KVi/0Hf=S06m_K`1QHF40H61P0820P02LW9`0Kfm_0;>c/`24Q8@0EEEE04A4
A028R8P0^KVi07moO`0h>3P0OGem04i>CP2;Rh/0ATI604A4A02EUID0J6QX05IFEP1WIfL0];Bd03<c
<`1ADE40QhN705ADE00k>c/0De=C03/k>`0m?Cd0QHF506UYJ@1NGUh0V9RH03Hf=P13@d<0H61P03hn
?P0d=3@0KFe]03lo?`1eMGD0JVYZ034a<@10@400OWin055AD@0b<S80DE5A038b<P0J6QX0<c<c0<W9
b@0m?Cd0De=C08N7Q`1mOGd0DE5A04Y:BP1UIFD0EEEE07moO`1OGel0>3Ph04E5A@1SHf<0D51@06MW
I`23Ph<0>SXj05EEE@2f][H0VYZJ06ATI02BTY80PX:20492@P0Y:BT0?clo05iNGP1kNg/0JFUY03lo
?`1YJFT0Ng]k04e=C@2e]KD0Vi^K04i>CP25QHD0QXJ605QHF01]KFd0BDU904E5A@1mOGd0U9BD08>3
P`1FEUH0IFEU07emO@1^KVh0:2PX05ADE02?Shl0O7al04Q8B01dM7@0JVYZ075aL@0];Bd08b<S06][
J`1hN7P0EUIF065QH@27QhL0G5aL028R8P0c<c<0@T9205UIF@0d=3@0R8R806QXJ00Z:RX0F5QH0861
P@11@D40V9RH07moO`1>CTh0<C4a04];B`1iNGT0D51@03`l?010@400Q8B404i>CP0d=3@0C4a<08>3
P`2?Shl0GUiN03Ph>01gMgL0<30`04Q8B01iNGT0L71`09BDU02IVIT0D51@069RHP22PX80Z:RX09:B
TP2TY:@0@D51020P800T92@07AdM01hN7P807AdM03@092@T02HV9P0V9RH0:2PX03De=@2ATI40];Bd
0;Jf]P28R8P0QHF507=cL`1XJ6P0De=C0;Bd]02h^;P0Jf][04i>CP1<C4`0A4A403<c<`0`<300@T92
07alO01VIVH0:2PX024Q8@0U9BD0?Cdm051@D01=CDd0EeMG05aLG00b<S809bLW02DU9@0O7al08R8R
06m_K`2QXJ40/k>c07inOP1SHf<0;Bd]02TY:@0o?cl0PH6105UIF@0f=SH09bLW038b<P0l?3`0;bl_
0P0J6QX01@0E5AD061PH02HV9P1BDU8092@T00@05ADE0P0G5aL03P0I6AT0N7Qh061PH00X:2P07alO
02d];@2JVYX0`/;20;jn_P2OWil0KFe]03/k>`0h>3P0<S8b0P0j>SX0Y010@400C4a<05YJFP0j>SX0
?3`l0410@01SHf<0YJFU06a/K02<S8`0d];B09ZJVP1QHF40C4a<04e=C@17AdL0DU9B08V9R@1UIFD0
Y:BT0;Vi^@2KVi/0EEEE061PH00/;2`0:2PX07UiN@1FEUH0=cLg03Ph>00o?cl0820P02DU9@0m?Cd0
[Zj^096AT@2UYJD0U9BD08Z:RP2SXj<0/k>c0:6QX@2f][H0Ph>306IVIP1dM7@0DU9B04a<C018B4P0
Bd];06m_K`1@D500<30`02LW9`0T92@09RHV02PX:00];Bd0=3@d071`L015ADD0@d=303Hf=P1:BTX0
FUYJ06MWI`13@d<0;2`/02d];@0/;2`09bLW02DU9@0T92@09bLW02d];@0h>3P0BTY:04a<C01BDU80
Kfm_0:f][@2JVYX0O7al09ZJVP2PX:00[jn_0:2PX032`/80UiNG0=?Cd`39bLT0TI6A07inOP1VIVH0
Ng]k05eMG@0i>CT0?Cdm04e=C@19BDT0EUIF07MgM`1VIVH0M7Ad05mOG`1ZJVX0YZJV0:>SX`2a/K40
_Kfm0:f][@2ZZZX0_kno0<g=c@3;bl/0][Jf06e]K@1FEUH0YZJV0<30`02CTi<0HV9R059BDP1;Bd/0
@T9204M7A`0k>c/0ADE5059BDP2@T900XZ:R07moO`1jNWX0BTY:06MWI`33`l<0NWYj0;:b/P38b<P0
bl_;0<o?c`2j^[X0FUYJ08^;R`2n_[h0c<c<04M7A`0b<S80?Shn03/k>`0c<c<0:b/[02d];@0a<C40
=CDe02d];@11@D40?Cdm038b<P1kNg/0EUIF055AD@1@D500Kfm_0P0[:b/0=P0c<c<0De=C07=cL`3B
d]80FEUI020P800R8R808b<S02TY:@0^;Rh0W9bL0451@@0n?Sh0Ng]k05EEE@2KVi/0_[jn05eMG@2M
WId0LG5a0<S8b02VYZH0UIFE08F5Q@1aLG40FUYJ055AD@22PX80bl_;0<[:bP3?cll0][Jf0;2`/02Y
ZJT0UiNG09BDU02=SHd0PH610;Zj^P2i^KT0]KFe0<C4a02k^k/0UIFE069RHP1TI6@0MWIf03hn?P0[
:b/0:BTY02PX:013@d<0Zj^[0:>SX`;ooooo00002@35aLD0Ti>C08B4Q01XJ6P0TI6A05QHF00Q8B40
?Cdm059BDP0202l_;`2L01LG5`11@D40A4A401dM7@0j>SX02`/;03Hf=P1MGEd0;Bd]03dm?@1JFUX0
0`<300X:2P1EEED0=3@d02DU9@0S8b<03Ph>04e=C@1LG5`0KFe]07]kN`20P80030`<02<S8`1IFET0
C4a<03`l?00C4a<0H61P04E5A@0_;bl0L71`02LW9`0P8200>CTi069RHP2o_kl0[:b/01@D500J6QX0
@D5107=cL`1ADE40=CDe05=CD`0a<C402@T901XJ6P1=CDd0Hf=S038b<P0j>SX0DU9B02d];@0Y:BT0
F5QH07QhN00e=CD0Fe]K06MWI`0F5QH0:BTY05mOG`0m?Cd0H61P04I6AP0I6AT0DE5A06MWI`0n?Sh0
ADE508B4Q00`<300410@0861P@1hN7P0B4Q806e]K@2m_Kd0JFUY03dm?@1CDe<0GUiN03Lg=`0o?cl0
SHf=09FEU@1LG5`0>3Ph03Hf=P1BDU8092@T05=CD`2PX:00RHV903<c<`1hN7P0<30`05YJFP1HF5P0
>c/k059BDP0S8b<0@d=307MgM`1JFUX0C4a<06IVIP18B4P0@T9206][J`1CDe<0EEEE08b<S011@D40
QHF5075aL@0n?Sh0IFEU07inOP1QHF40@d=307emO@19BDT0FUYJ075aL@1?Cdl0LW9b034a<@1gMgL0
Hf=S0410@01NGUh0ADE504U9B@2UYJD0IfMW04I6AP1DE5@0Jf][04M7A`0];Bd0?Cdm06m_K`0b<S80
G5aL0:BTY01IFET0BTY:07YjNP11@D40R8R807IfMP0_;bl0DE5A0P1cLg<0A@1jNWX0Jf][0410@01@
D500PX:206UYJ@2SXj<0L71`07YjNP1ZJVX0PX:20<k>cP24Q8@0@d=3069RHP1>CTh0SHf=06i^KP13
@d<0YZJV07alO01OGel0PX:20<k>cP1ADE40GemO0:VYZ@1YJFT0?clo04Q8B01QHF40;Bd]07alO01i
NGT0Fe]K08j>SP1VIVH0B4Q806EUI@19BDT09RHV07QhN01jNWX0U9BD06m_K`0b<S80@D5108F5Q@1U
IFD0=3@d05ADE013@d<0:2PX034a<@3=cLd0DE5A04];B`2>SXh0OWin06=SH`0h>3P0EEEE07]kN`28
R8P0Ogmo03dm?@0n?Sh0HF5Q04i>CP0209BDU00S03`l?01@D500YJFU0820P01EEED0Zj^[09jNWP16
ATH0<S8b03lo?`1EEED0QhN704M7A`1MGEd0R8R807]kN`18B4P0/[:b08F5Q@0b<S80Ph>3079bLP1@
D500Ng]k05mOG`0P8200@41004U9B@1FEUH0@D5107QhN02<S8`0L71`02TY:@0P82000P1EEED0GP0Q
8B40FUYJ07]kN`1LG5`0D51@02DU9@20P800CTi>03Ti>@1MGEd0OGem07EeM@0^;Rh0<30`04];B`1A
DE408b<S08J6QP1eMGD0ATI606EUI@2DU9@0;bl_079bLP1RHV80LG5a05MGE`1fMWH0NGUi034a<@0W
9bL0@d=307emO@1TI6@0BTY:02`/;01ADE40Ti>C03Hf=P0b<S80GemO030`<00m?Cd0?3`l07inOP1E
EED0Rh^;04i>CP1SHf<0UIFE0<W9b@38b<P0Xj>S09fMW@1`L700FEUI04a<C017AdL0?Shn03Lg=`0f
=SH0<S8b02TY:@0b<S80JFUY0<O7a`2RXZ80VIVI09bLW02XZ:P0CDe=04a<C02GUiL0@d=303Hf=P1W
IfL0K6a/04M7A`16ATH0Cdm?03`l?00V9RH0=cLg09NGU`1iNGT0CDe=02l_;`0m?Cd0Bd];04a<C01D
E5@0JFUY03lo?`0T92@202<S8`0B02DU9@0n?Sh0LG5a09NGU`31`L40[Jf]0:^[Z`1oOgl0WYjN0:NW
Y`1ZJVX0GemO04Q8B01FEUH0H61P04A4A00I6AT05aLG0P0E5AD01@0J6QX0DU9B02l_;`0E5AD05QHF
00@05ADE01P05QHF04E5A@2GUiL0UIFE04Y:BP0V9RH0De=C09FEU@1YJFT0MgMg07IfMP18B4P0@T92
04=3@`14A4@0?clo03`l?00m?Cd0B4Q8061PH014A4@0?Cdm04Q8B02WYjL20861P@0_08n?S`1LG5`0
@T920451@@0j>SX0>3Ph09jNWP1XJ6P0AdM704U9B@1^KVh0Lg=c08b<S01iNGT0ADE5028R8P1VIVH0
/K6a08N7Q`1dM7@0OWin038b<P0Q8B40820P05=CD`2OWil0F5QH05aLG01]KFd0YjNW0;2`/02i^KT0
_[jn05ADE00];Bd0<S8b059BDP17AdL0@T9203Ph>00g=cL0GUiN06=SH`0e=CD09BDU02<S8`0R8R80
0P0Y:BT0;@1GEeL0AdM706YZJP1JFUX0NWYj08Z:RP1ZJVX0@T9202`/;00X:2P0;2`/02XZ:P0X:2P0
9RHV02`/;00^;Rh0>3Ph05EEE@1_Kfl0PX:20::RXP1fMWH0IVIV06=SH`1ADE40[:b/05eMG@0c<c<0
QXJ60=?Cd`3Fe]H0^k^k0;Jf]P0o?cl09RHV05iNGP0h>3P0820P01hN7P0R8R80<30`05EEE@2ATI40
RXZ:08j>SP0209^KV`0N0:n_[`2GUiL0dM7A09FEU@1=CDd0GUiN08:2PP2ATI40V9RH09jNWP19BDT0
?3`l0:^[Z`2BTY80`/;207QhN01CDe<0D51@05IFEP1=CDd0BDU903`l?010@400^KVi0<S8b02d];@0
ATI603Hf=P1EEED0/K6a0P2o_kl0>P38b<P0a<C40;Jf]P2:RXX0IfMW059BDP1SHf<0[jn_0861P@0Y
:BT0<30`02/[:`0m?Cd0=CDe02h^;P0];Bd0=CDe03`l?00j>SX0HF5Q05EEE@2IVIT0I6AT055AD@1G
EeL0GemO02PX:00f=SH0M7Ad0;^k^`3IfMT0dm?C0;Vi^@1@D5009bLW01lO7`0W9bL0>SXj0:>SX`0h
>3P0@D5107EeM@1ADE40Lg=c09jNWP39bLT0JFUY09NGU`2a/K40IVIV059BDP1<C4`0?clo04A4A019
BDT0IVIV0:NWY`2YZJT20;Vi^@0F0:NWY`2?Shl0BDU9038b<P0a<C40=cLg04Q8B029RHT0`<300;^k
^`2DU9@0RXZ:079bLP1oOgl0N7Qh06EUI@0e=CD09bLW03<c<`0X:2P0NGUi0492@P;ooooo0000P`2U
YJD0e]KF0:RXZ01PH600Vi^K0:FUY@12@T80>3Ph06][J`0m?Cd0FEUI0492@P1HF5P0KFe]02PX:01<
C4`0A4A403hn?P1>CTh0<30`034a<@14A4@08b<S01DE5@10@4007alO02TY:@0e=CD07QhN04=3@`1Y
JFT0FEUI06i^KP1jNWX0>3Ph01dM7@0a<C40ADE5051@D00e=CD0EeMG03Xj>P0V9RH0QhN705aLG00O
7al0<C4a03Ti>@11@D40Ph>305ADE00^;Rh0@41006IVIP1IFET0A4A408>3P`1YJFT0>3Ph01TI6@1>
CTh0=cLg02/[:`1=CDd0Hf=S06MWI`0f=SH0HF5Q05eMG@0B4Q80ADE508:2PP0X:2P0>3Ph059BDP0G
5aL0>CTi05MGE`0U9BD0GEeM02h^;P0W9bL0;bl_051@D01WIfL0<C4a0820P00l?3`07alO03lo?`2T
Y:@0KFe]03lo?`1KFe/0F5QH038b<P0k>c/0Kfm_059BDP1@D500=cLg04U9B@1mOGd0CDe=09bLW02l
_;`0M7Ad038b<P2=SHd0HV9R065QH@1BDU80?Shn07EeM@12@T80C4a<071`L01>CTh0GemO07emO@1_
Kfl0CDe=04U9B@0L71`0DU9B08b<S016ATH0PX:203`l?00X:2P0@4100080E5AD07`0?3`l07emO@1B
DU80EeMG071`L01;Bd/0MWIf03<c<`1ZJVX0NGUi04U9B@1DE5@0N7Qh04Q8B02m_Kd0IVIV04Q8B01E
EED0KVi^07=cL`1;Bd/0HF5Q08b<S00[:b/0EeMG0;>c/`1jNWX0EUIF09VIV@0n?Sh0RHV908F5Q@17
AdL0GEeM06IVIP1BDU80K6a/08J6QP1HF5P0EEEE08f=S@1WIfL0S8b<07=cL`1hN7P0WinO0<k>cP3H
f=P0U9BD06=SH`1WIfL0F5QH08:2PP1iNGT0@41009nOW`21PH40IVIV0:VYZ@3Fe]H0LG5a05QHF02T
Y:@0M7Ad04I6AP1:BTX0K6a/03Hf=P23Ph<0NWYj04Q8B02@T900LG5a051@D01IFET0GUiN02@T9026
QXH0T92@09BDU01gMgL0De=C05EEE@2VYZH0RHV903`l?01SHf<0@d=302PX:00o?cl0YjNW07]kN`1=
CDd0Shn?08:2PP28R8P0@D5103<c<`1CDe<0KFe]05EEE@0n?Sh0DE5A07]kN`0o?cl0OGem05=CD`0`
<300F5QH0:FUY@1`L700;bl_05IFEP1EEED0DU9B03hn?P1GEeL0Lg=c09RHV015ADD0:BTY05iNGP0n
?Sh0:b/[0P2LW9`0100l?3`0GemO04m?C`0W9bL205UIF@1205ADE01BDU80GUiN06YZJP0Y:BT0Bd];
06=SH`23Ph<0?Cdm028R8P1NGUh0LW9b04U9B@1ADE40Cdm?06m_K`1]KFd09bLW07UiN@1XJ6P0A4A4
04M7A`1`L700KVi^02TY:@0g=cL0ADE505=CD`0V9RH0IfMW04];B`0f=SH0E5AD0::RXP1SHf<0P820
05UIF@1TI6@0IVIV0820P01dM7@0?clo02/[:`0m?Cd0GUiN05UIF@1TI6@0?Cdm06a/K02EUID0M7Ad
03hn?P1ADE409BDU03dm?@0f=SH0@41006i^KP1@D500_;bl069RHP2QXJ40/k>c09JFUP2j^[X0`L71
0P32`/800`2JVYX0KVi^051@D00204i>CP0M05YJFP1_Kfl0FEUI05UIF@2RXZ80VYZJ07=cL`1QHF40
IfMW07UiN@1kNg/0KFe]01hN7P0K6a/08R8R05aLG01cLg<0>3Ph02<S8`0O7al0;Rh^02DU9@0j>SX0
^[Zj08b<S00o?cl0;Rh^03hn?P18B4P00P1=CDd05P1ADE409BDU01XJ6P0S8b<08B4Q05]KF`2ZZZX0
X:2P0<71`@2=SHd0VIVI07alO02DU9@0/k>c08V9R@1MGEd0@41003hn?P0c<c<0>c/k03Ph>00S8b<2
01DE5@0301PH601:BTX0CDe=00@05ADE00d05aLG01PH600L71`08B4Q02@T901:BTX0Y:BT08j>SP1Y
JFT0XZ:R06MWI`1TI6@08b<S00807AdM02`071`L01dM7@0M7Ad092@T02/[:`10@400HV9R0861P@2O
Wil0MgMg08f=S@13@d<0:2PX02d];@1`L700@D5103Ti>@0f=SH0=cLg05aLG01kNg/0;Rh^030`<010
@400H61P07IfMP1NGUh0RHV908B4Q02QXJ40WinO092@T02KVi/0Y:BT07emO@1]KFd0E5AD07emO@1k
Ng/0B4Q805QHF01lO7`0M7Ad06][J`80SXj>00h0?clo030`<00];Bd0:BTY04i>CP10@400>CTi03Lg
=`0c<c<0B4Q8065QH@11@D408b<S020P80809bLW02H0CTi>08f=S@2a/K40UIFE08n?S`2g]kL0SHf=
07MgM`0j>SX09BDU02@T900/;2`0:RXZ02PX:00Z:RX0=CDe05ADE01KFe/0FEUI096AT@1UIFD0M7Ad
0:FUY@2=SHd0V9RH0:VYZ@1VIVH0<c<c04];B`3IfMT0bLW909jNWP1;Bd/0820P024Q8@1HF5P0>CTi
01`L70<07AdM01D0AdM7096AT@1^KVh0S8b<069RHP1VIVH0V9RH06][J`34a<@0Rh^;03lo?`0b<S80
@T9205=CD`1aLG40KFe]06][J`11@D40YZJV071`L01iNGT00P0`<300H@0h>3P0@D5105EEE@1MGEd0
GUiN0861P@2UYJD0];Bd0<;2`P1jNWX0QHF50;2`/02m_Kd0alO70<30`03<c<`0YJFU05=CD`1ADE40
GUiN05ADE01=CDd0DE5A092@T00d=3@09RHV02LW9`0e=CD0C4a<030`<00/;2`0<30`03Ph>00o?cl0
Ogmo08f=S@22PX80IVIV04i>CP1lO7`0J6QX08V9R@2k^k/0emOG0;Zj^P2BTY80F5QH05aLG02YZJT0
V9RH04I6AP0c<c<0Shn?0<30`019BDT0ADE507EeM@19BDT0G5aL0;6a/@2FUYH0AdM70;:b/P1ZJVX0
=3@d03Lg=`0a<C40=3@d03Lg=`14A4@0IVIV07YjNP28R8P0MGEe092@T02WYjL0@41002d];@0[:b/0
;Bd]02l_;`0g=cL0Ogmo08^;R`29RHT0Fe]K04E5A@0d=3@0ATI604E5A@18B4P0Cdm?02LW9`0c<c<0
L71`04];B`0j>SX00_ooool0001c0;Vi^@39bLT0SXj>05ADE02CTi<0YjNW04U9B@0k>c/0EUIF034a
<@1GEeL0Cdm?04Y:BP1NGUh0;Rh^06ATI01<C4`0?Cdm04U9B@0X:2P0820P04];B`0[:b/05QHF051@
D00O7al0;bl_04e=C@0/;2`0DE5A05mOG`1CDe<0TY:B092@T01EEED09RHV03Hf=P0c<c<0DE5A03lo
?`1SHf<0:BTY01/K6`26QXH0KFe]01PH600c<c<0820P04M7A`1KFe/0KFe]02XZ:P1@D500DE5A01XJ
6P0X:2P0A4A4061PH018B4P06QXJ04Q8B00f=SH09bLW02/[:`15ADD0G5aL03De=@1iNGT0RXZ:04E5
A@0c<c<0O7al02TY:@0k>c/0P82005ADE00l?3`0IVIV03<c<`1GEeL0DE5A02HV9P0[:b/0Fe]K069R
HP0o?cl0L71`07moO`1;Bd/0E5AD0<[:bP20P800>c/k065QH@2>SXh0G5aL04Y:BP1nOWh0FEUI02HV
9P0_;bl0HV9R08R8R01GEeL0WYjN0;bl_02@T9007alO07EeM@1SHf<0Fe]K03Hf=P0W9bL0L71`055A
D@0205QHF03o04e=C@0k>c/0Bd];07emO@1=CDd0CTi>04m?C`11@D40OGem04e=C@1OGel0CTi>03Ti
>@0m?Cd0D51@04e=C@0`<300QhN7075aL@23Ph<0Vi^K05MGE`29RHT0F5QH07AdM02>SXh0BTY:05=C
D`26QXH0DE5A0<;2`P26QXH0E5AD04i>CP1SHf<0K6a/04a<C01dM7@0Xj>S03Hf=P19BDT0[jn_0820
P01>CTh0VIVI03Ti>@2?Shl0TY:B059BDP1DE5@0MWIf03Xj>P1gMgL0U9BD05eMG@1>CTh0Ti>C071`
L02<S8`0VYZJ09NGU`1XJ6P0YJFU0<C4a02FUYH0@d=306=SH`2f][H0/K6a08b<S00n?Sh0W9bL05EE
E@0_;bl0QXJ60<71`@1nOWh0De=C0:b/[013@d<0BDU908B4Q01aLG40;bl_07=cL`1TI6@0OGem0;Jf
]P1bLW80EUIF06EUI@1?Cdl0ATI609JFUP2EUID0TY:B0:6QX@0m?Cd0>3Ph06QXJ01dM7@0=CDe06m_
K`1:BTX08b<S01PH602MWId0IFEU03lo?`1_Kfl0LW9b07alO01WIfL0?Shn06i^KP1SHf<0Ng]k03dm
?@0f=SH0M7Ad04U9B@2CTi<0RHV904M7A`0j>SX0Ph>309FEU@1]KFd0OWin06][J`16ATH0:BTY03<c
<`15ADD0TI6A06a/K00j>SX0IVIV07moO`0n?Sh0SXj>0:f][@1FEUH0L71`08:2PP1[Jf/0GEeM05MG
E`1QHF40F5QH05aLG01SHf<0CTi>05UIF@1[Jf/0Ti>C04e=C@0R8R80Hf=S07MgM`1ADE40GemO051@
D01XJ6P0GUiN034a<@2>SXh0R8R805UIF@1BDU80N7Qh06=SH`0c<c<0IfMW06i^KP1hN7P0?Cdm06e]
K@1LG5`0BDU907inOP2XZ:P0Hf=S08>3P`1_Kfl0EUIF05MGE`24Q8@0OGem04];B`0Y:BT0A4A4059B
DP1?Cdl0;Rh^02@T901XJ6P0RHV9079bLP0i>CT0EEEE02XZ:P0f=SH0;Rh^038b<P2o_kl0YJFU0;bl
_02UYJD0bLW90:FUY@2e]KD0Lg=c07UiN@3EeMD0f][J0<?3``2_[jl0NGUi04i>CP0m?Cd09bLW03Lg
=`17AdL0SXj>079bLP31`L40G5aL04a<C018B4P0EeMG0:6QX@1fMWH0?clo01hN7P0h>3P09RHV051@
D01KFe/09RHV01/K6`0L71`06a/K01`L701LG5`0^k^k09JFUP0/;2`0>3Ph03lo?`0n?Sh0A4A405AD
E00c<c<06a/K000H034a<@1eMGD0TI6A09>CT`2PX:00_kno0:BTY028R8P0IVIV04M7A`1QHF40QXJ6
071`L01SHf<0?Cdm02HV9P0U9BD0>CTi04U9B@14A4@05ADE01dM7@0e=CD0IVIV0P0I6AT01@0L71`0
6a/K01PH600Z:RX0<c<c008071`L00P07AdM034a<@1mOGd0bLW90=GEe@2o_kl0MgMg02HV9PL07AdM
00L08B4Q04=3@`1DE5@0PX:207UiN@1YJFT0:RXZ00809RHV0240IVIV05=CD`0a<C40;Bd]02PX:00n
?Sh0Z:RX03hn?P0k>c/0@T9204];B`1VIVH0>CTi03<c<`2MWId0^k^k04Y:BP11@D40CDe=06=SH`14
A4@0E5AD07YjNP3<c<`0[Jf]07=cL`0e=CD0=SHf06QXJ01>CTh0Ng]k08j>SP15ADD00P0X:2P0100W
9bL0<S8b05mOG`0l?3`203Lg=`0/02l_;`13@d<0Jf][055AD@0d=3@0;Rh^051@D02JVYX0WYjN0;jn
_P2;Rh/0L71`0820P02BTY80KVi^06QXJ01BDU80=SHf034a<@0/;2`0=3@d04Y:BP1MGEd0DE5A05eM
G@20P800Jf][07alO01bLW80JFUY08:2PP2n_[h0alO70<G5a@30`<00g=cL0>CTi02d];@0DE5A01lO
7`0M7Ad0820P05IFEP0g=cL201dM7@0H01`L700M7Ad0FUYJ059BDP11@D40Ph>305mOG`1DE5@0Rh^;
065QH@2SXj<0UIFE02`/;00T92@0=SHf03lo?`1;Bd/0EUIF06EUI@1[Jf/0ZJVY079bLP1cLg<08B4Q
0P0N7Qh0H00];Bd0FEUI0:6QX@2CTi<0M7Ad07YjNP2][Jd0Y:BT08:2PP3Cdm<0/;2`0;Vi^@3>c/h0
bl_;09VIV@1;Bd/0;2`/03dm?@1JFUX0DE5A04I6AP0o?cl0MgMg07emO@0U9BD09bLW02`/;00i>CT0
?Shn02`/;00];Bd0<C4a03`l?01SHf<0[:b/0::RXP28R8P0XZ:R0<W9b@3@d=00a<C409fMW@1bLW80
TI6A04];B`18B4P0GUiN06IVIP2ATI40`/;20;jn_P3Bd]80P8200:FUY@2OWil0UIFE05UIF@1aLG40
bl_;065QH@1VIVH0QXJ603/k>`0f=SH0<30`02TY:@0`<300=3@d04U9B@1jNWX0O7al08f=S@1cLg<0
E5AD04i>CP0o?cl0:2PX02LW9`0Y:BT0:b/[03Ph>027QhL0NWYj04Y:BP1DE5@0BTY:03@d=01<C4`0
AdM70410@01EEED0K6a/07UiN@1QHF40=SHf030`<0;ooooo0000?P2_[jl0`/;207emO@0g=cL0Cdm?
07EeM@0k>c/0?Shn03lo?`0O7al0=CDe03dm?@0o?cl0>CTi01DE5@16ATH0@41003`l?018B4P03@d=
00l?3`14A4@0;Bd]01HF5P1?Cdl04A4A018B4P0_;bl0:b/[04i>CP0f=SH071`L03dm?@1RHV80D51@
02@T900o?cl0=3@d038b<P0a<C40HF5Q030`<00E5AD0GEeM03hn?P0>3Ph0=CDe00X:2P0b<S80KFe]
08J6QP0J6QX0@d=305YJFP1MGEd0<S8b04I6AP1VIVH08R8R01TI6@1GEeL0Hf=S0P0n?Sh0o`13@d<0
:b/[01LG5`1FEUH0OWin051@D00Y:BT0IfMW01LG5`0U9BD0IfMW04m?C`0l?3`0B4Q801HF5P1;Bd/0
M7Ad0410@00g=cL0IVIV03/k>`0M7Ad0F5QH08^;R`1VIVH0?Shn0<[:bP1fMWH0:2PX03hn?P1ADE40
EUIF04=3@`1aLG40D51@03/k>`0X:2P0?clo07moO`1FEUH0Shn?0;Jf]P2=SHd0>3Ph07AdM01VIVH0
De=C05]KF`1;Bd/0N7Qh06ATI01?Cdl0Jf][0820P018B4P0EUIF08n?S`1IFET0EUIF06a/K017AdL0
OGem06=SH`1UIFD0K6a/04i>CP17AdL0Cdm?06UYJ@0f=SH0Ph>307QhN01bLW80ZZZZ061PH02=SHd0
IfMW05]KF`1aLG40ADE505ADE01fMWH0Bd];0:VYZ@2;Rh/0@41004=3@`1RHV80DU9B04E5A@1TI6@0
U9BD0492@P1DE5@0^;Rh08:2PP1CDe<0NWYj04];B`30`<00][Jf06YZJP13@d<0Ng]k03dm?@2ATI40
XJ6Q069RHP1:BTX0QXJ603/k>`1BDU80T92@08Z:RP1PH600RHV90<W9b@2NWYh0?Shn06YZJP2IVIT0
TY:B04];B`1BDU80YjNW07QhN01GEeL0GEeM0<c<c00n?Sh0=SHf08n?S`1`L700=SHf03<c<`0m?Cd0
>CTi09RHV01UIFD0?Shn06i^KP1DE5@0EEEE09BDU01EEED08b<S075aL@1BDU80N7Qh0:RXZ01MGEd0
ATI606i^KP1nOWh0?clo05]KF`1=CDd0=CDe01TI6@2HV9P0Ng]k04e=C@1TI6@0LG5a08F5Q@1/K6`0
@d=30:2PX01aLG40Shn?04M7A`0d=3@0Lg=c051@D020P800S8b<05eMG@11@D40Ti>C09ZJVP1bLW80
O7al07=cL`1IFET0>3Ph03@d=019BDT0VIVI07alO01CDe<0KFe]0820P018B4P0Rh^;0<71`@1TI6@0
OWin09jNWP1mOGd0I6AT05eMG@1IFET0I6AT08j>SP28R8P0Hf=S04];B`1MGEd0RXZ:055AD@0o?cl0
UiNG08F5Q@1?Cdl0JFUY055AD@1gMgL0<S8b01lO7`1[Jf/0M7Ad05IFEP1GEeL0Kfm_05QHF00U9BD0
A4A404i>CP1^KVh0?clo071`L01RHV809RHV0451@@26QXH0:RXZ07EeM@2RXZ80MgMg04U9B@1]KFd0
Lg=c01TI6@0P8200BTY:05]KF`1aLG40K6a/02h^;P1<C4`0X:2P04Y:BP0c<c<0SXj>03/k>`00H00h
>3P0@T920820P02/[:`0]KFe08f=S@2PX:00Y:BT0:2PX02o_kl0]KFe0:6QX@2FUYH0c<c<05iNGP1>
CTh0EUIF07inOP2<S8`0T92@08j>SP31`L40dM7A06e]K@24Q8@0TI6A04m?C`1JFUX0[Zj^09BDU00o
?cl0LW9b03De=@0Q8B409BDU01LG5`1JFUX0@d=301`L700J6QX05QHF01PH600`<300SHf=0=7Ad@1o
Ogl0BDU904I6AP1EEED0Fe]K069RHP1aLG40Kfm_08:2PP1_Kfl0N7Qh08R8R036a/H0`<3009bLW01O
Gel0>CTi03Ph>00f=SH0CTi>065QH@2=SHd0Jf][05MGE`0f=SH0<C4a03hn?P12@T80?3`l055AD@1Q
HF40V9RH06IVIP1dM7@0FUYJ06MWI`1UIFD0SHf=04M7A`15ADD0@T9204E5A@1HF5P0KVi^09VIV@3G
emL0aLG50;Rh^01kNg/0:b/[01dM7@@071`L0P0M7Ad0400T92@0BDU9071`L023Ph<0?clo02XZ:P0T
92@0;Rh^0:b/[03De=@0UYJF059BDP18B4P0QhN70;no_`2;Rh/207alO00H079bLP1/K6`0P82004Q8
B02=SHd0a/K6059BDP1JFUX0G5aL02LW9`0U9BD09bLW02PX:029RHT0MWIf06a/K00R8R80;Bd]04a<
C01MGEd0IVIV0;Fe]@1WIfL09RHV0P0W9bL0100U9BD0=SHf05=CD`0g=cL203@d=00/02/[:`19BDT0
W9bL08:2PP1eMGD0S8b<08>3P`2EUID0bLW909RHV01/K6`0LG5a07IfMP1ADE40GEeM07UiN@2:RXX0
O7al05=CD`13@d<0?3`l05aLG023Ph<0V9RH04=3@`0n?Sh0@D5104E5A@1OGel0P8200;Vi^@2b/[80
YJFU08J6QP2_[jl0e]KF0<?3``0a<C407QhN01dM7@0O7al0FEUI03`l?00M7Ad201`L700=01hN7P1_
Kfl0?Cdm03Xj>P2GUiL0YjNW09ZJVP1VIVH0EeMG08V9R@3=cLd0MWIf05IFEP02051@D00g05ADE01P
H600PH610<c<c02_[jl0Shn?061PH00Z:RX09bLW03/k>`1TI6@0EEEE06i^KP1CDe<0G5aL08^;R`2C
Ti<0KFe]07inOP2b/[80Zj^[0:ZZZP3=cLd0`<3005mOG`0Y:BT09RHV03@d=015ADD0D51@05EEE@0m
?Cd0DE5A0;:b/P17AdL08b<S02TY:@0a<C40@T9203dm?@11@D40Bd];07IfMP2o_kl0c<c<0=cLg03H
f=P0eMGE0<K6aP33`l<0Kfm_04Y:BP18B4P0EEEE08>3P`02059BDP0/05ADE01OGel0Rh^;0=;BdP20
P800>3Ph04Q8B02k^k/0[:b/0;Ng]`23Ph<0UIFE0:NWY`36a/H0KFe]03Ti>@0b<S80=3@d02h^;P0e
=CD0A4A408>3P`2/[:`0`l?309nOW`1hN7P0>c/k03Ti>@1DE5@0:b/[02LW9`0V9RH0;2`/03dm?@28
R8P0KFe]03/k>`0o?cl0E5AD03Ti>@1@D500ADE504M7A`1DE5@208>3P`0303De=@0o?cl0;bl_00;o
oooo0000G@38b<P0ZZZZ071`L01BDU80QHF508V9R@0Y:BT0<30`04m?C`0o?cl0>3Ph01hN7P0W9bL0
GUiN02d];@17AdL07QhN028R8P0l?3`0820P01HF5P0c<c<02`/;00l?3`0n?Sh09RHV020P800];Bd0
5ADE03lo?`1MGEd0D51@06a/K01gMgL0;bl_01PH600n?Sh0De=C038b<P0G5aL0EeMG04a<C00N7Qh0
Ng]k04=3@`0@4100Bd];02@T900G5aL0@D510:j^[P15ADD0@D5105MGE`1WIfL0>c/k04A4A01VIVH0
@D51014A4@0i>CT0AdM703Xj>P0d=3@0>c/k06ATI00T92@0GUiN08F5Q@1SHf<08b<S08N7Q`0k>c/0
;bl_08:2PP1YJFT0=SHf04a<C00^;Rh0=3@d075aL@13@d<0?Shn06=SH`1@D500;bl_03Xj>P2LW9`0
IfMW03dm?@2h^;P0YjNW05EEE@0204e=C@2?05QHF00_;bl0I6AT05ADE01SHf<0>SXj04E5A@2;Rh/0
J6QX08J6QP2^[Zh0XJ6Q04];B`1^KVh0Jf][04M7A`1QHF40DU9B07EeM@1HF5P0Cdm?06][J`29RHT0
C4a<05aLG026QXH0EeMG07EeM@1bLW80A4A407]kN`1FEUH0M7Ad09BDU01GEeL0DU9B05ADE01fMWH0
A4A408V9R@24Q8@0C4a<0820P010@400YJFU06e]K@1ADE40O7al03Xj>P1_Kfl0Ph>3059BDP2LW9`0
WIfM02l_;`1BDU80QHF50820P01?Cdl0F5QH09:BTP0S8b<0:RXZ06IVIP1MGEd0EEEE05eMG@0d=3@0
R8R80:>SX`1`L700?clo0:2PX00Z:RX0De=C06i^KP1ADE40HV9R09nOW`1]KFd0GUiN09ZJVP0k>c/0
6a/K06e]K@3Kfm/0_kno0:FUY@2^[Zh0alO709nOW`1iNGT0ATI606IVIP2@T900QXJ60861P@3Bd]80
SXj>03Xj>P1YJFT0SHf=0451@@0j>SX0HF5Q01lO7`1RHV80QhN704E5A@1oOgl0PH6104Y:BP1EEED0
JFUY02DU9@1/K6`0TI6A08V9R@2RXZ80Ng]k04e=C@1bLW80Y:BT05=CD`1RHV80GEeM04A4A00i>CT0
XZ:R0:VYZ@1HF5P0J6QX07UiN@2[Zj/0De=C02l_;`1[Jf/0IFEU08B4Q013@d<0@41006IVIP0b<S80
0P23Ph<0L01RHV80>c/k08^;R`25QHD0=cLg08N7Q`2JVYX0Q8B405QHF00e=CD0@d=308F5Q@0_;bl0
EUIF07alO023Ph<0B4Q808:2PP2_[jl0=cLg07QhN029RHT0K6a/05MGE`1jNWX0ADE503lo?`1ADE40
Fe]K04M7A`1KFe/0SHf=09^KV`0o?cl07alO051@D01WIfL0BDU9065QH@1UIFD0Shn?07alO00c<c<0
Q8B408b<S01OGel0H61P09RHV01aLG40<c<c03Ti>@10@400GemO02PX:01JFUX0NWYj05iNGP1:BTX0
Zj^[03dm?@1WIfL0NWYj08:2PP1XJ6P0QXJ607inOP0g=cL061PH030`<00o?cl0MWIf075aL@0/;2`0
EeMG0;:b/P0h>3P0:BTY07inOP1JFUX0DU9B05IFEP1;Bd/0DE5A0;:b/P2j^[X0/k>c0:^[Z`2?Shl0
XJ6Q09fMW@2FUYH0/K6a0;Bd]036a/H0L71`02LW9`0N7Qh07alO02h^;P1MGEd0alO70<K6aP1gMgL0
LG5a0<[:bP2a/K40];Bd0<c<c02l_;`0Lg=c03/k>`0W9bL201DE5@1B01@D500Z:RX0GUiN01dM7@0L
71`06ATI01dM7@0j>SX0VIVI0=KFeP3Cdm<0^k^k0;bl_020P800DU9B05iNGP2=SHd0U9BD0861P@1j
NWX0PH610;Fe]@3<c<`0^k^k07UiN@13@d<0=3@d02l_;`0i>CT0HV9R02d];@1>CTh0H61P05QHF01M
GEd0I6AT0410@00f=SH0E5AD06UYJ@1BDU80@41003Lg=`1WIfL0CDe=05=CD`1IFET0FUYJ04m?C`1J
FUX0EEEE05YJFP1HF5P0IFEU096AT@32`/80Rh^;04Q8B01iNGT0X:2P051@D00O7al071`L01TI6@0L
71`09BDU04I6AP1eMGD0TI6A09BDU02NWYh0@T9205=CD`1aLG40[:b/0:FUY@2MWId0YJFU0;2`/02[
Zj/0YJFU09^KV`80@d=304d0EUIF06UYJ@29RHT0WinO06m_K`2i^KT0`/;2096AT@1ZJVX0=cLg02h^
;P0Q8B407alO02DU9@2DU9@0M7Ad04e=C@0a<C40;2`/03De=@27QhL0[Jf]0<71`@23Ph<0?Shn034a
<@0U9BD09RHV02TY:@19BDT0De=C038b<P0g=cL0;2`/034a<@1LG5`0cLg=0;Zj^P2IVIT0N7Qh065Q
H@39bLT0XZ:R0451@@0i>CT0D51@0:2PX020P800UYJF0:j^[P2g]kL0NWYj069RHP1/K6`0[:b/0<k>
cP13@d<09BDU02LW9`0j>SX0NWYj0:NWY`36a/H0WYjN0;^k^`2FUYH0GEeM06=SH`2l_;`0/K6a03Lg
=`0M7Ad071`L01hN7P1/K6`0EEEE01lO7`0201hN7P0I03@d=029RHT0=cLg06e]K@1[Jf/0G5aL09JF
UP1dM7@0K6a/08J6QP3Lg=`0c<c<0<71`@32`/80d=3@0=CDe03@d=00d];B0>3Ph036a/H0]KFe06EU
I@19BDT0C4a<04i>CP0204a<C01<07YjNP1ADE40:RXZ03Xj>P14A4@0B4Q804A4A01UIFD0Y:BT0<c<
c02PX:00TY:B06][J`0_;bl0;Rh^03Hf=P11@D40RXZ:08F5Q@1lO7`0H61P0861P@2QXJ40D51@02TY
:@0X:2P0@T920::RXP2JVYX0Vi^K0;Rh^02`/;00fm_K0:^[Z`2DU9@0IVIV0;Jf]P2a/K40ATI602h^
;P0h>3P0EUIF07UiN@1YJFT0FUYJ04];B`1ADE40Shn?0<W9b@0o?cl0>3Ph051@D03AdM40c<c<0;jn
_P30`<00`L710=;BdP3De=@0];Bd071`L01PH600JVYZ08Z:RP2JVYX0_kno0<71`@2QXJ40Rh^;09JF
UP14A4@0<30`03<c<`1?Cdl0?Cdm02HV9P80:2PX00L0@D5107YjNP1OGel0;Rh^034a<@1?Cdl0ATI6
0080C4a<00L0B4Q805MGE`1`L700MgMg034a<@1FEUH0?Shn00;ooooo0000_P22PX80YJFU07YjNP1=
CDd0NGUi0:f][@1PH600<S8b05MGE`1@D500<S8b04M7A`0[:b/0Kfm_03<c<`15ADD0<c<c020P8011
@D407AdM01TI6@0K6a/05aLG01<C4`16ATH0<30`02@T900c<c<0:2PX0451@@1<C4`0Bd];06e]K@1X
J6P0>SXj01TI6@0`<300FEUI02TY:@0b<S80G5aL04Y:BP0K6a/0Kfm_04=3@`0Q8B40C4a<07MgM`0`
<300;2`/09FEU@1BDU80EUIF055AD@1SHf<0>c/k0492@P1VIVH0FUYJ01LG5`0f=SH0>CTi03@d=00_
;bl0?Cdm06YZJP0];Bd0EUIF07UiN@1XJ6P0:2PX0820P00n?Sh0;Rh^07moO`1bLW80=3@d04a<C014
A4@0;Bd]07IfMP0g=cL0ATI607MgM`1^KVh0C4a<03Ph>02OWil0>CTi03Hf=P2JVYX0^;Rh05aLG01<
C4`0Bd];04e=C@0d=3@0Q8B409^KV`1[Jf/0>CTi04Y:BP1gMgL0Cdm?07IfMP2/[:`0^;Rh069RHP1P
H600ATI604Y:BP1aLG40D51@07UiN@0k>c/0GemO07YjNP1kNg/0Bd];07UiN@1MGEd09BDU05eMG@1S
Hf<0C4a<08n?S`0a<C40@T9206e]K@0j>SX0GemO07YjNP1GEeL07alO061PH00o?cl0CTi>07AdM00`
<300EEEE03Lg=`1<C4`0PX:2038b<P17AdL0BDU902`/;020P800U9BD04U9B@0i>CT0F5QH06YZJP0k
>c/0PX:20:^[Z`1eMGD0>c/k09fMW@1=CDd0Cdm?07moO`1<C4`0NWYj09JFUP13@d<0:b/[07moO`1B
DU80LW9b07]kN`19BDT0?3`l07=cL`24Q8@0B4Q80:VYZ@1lO7`0G5aL04e=C@2TY:@0_[jn0;>c/`39
bLT0f=SH0=3@d02SXj<0A4A406IVIP2MWId208V9R@180=SHf02RXZ80>c/k04m?C`2<S8`0G5aL06IV
IP1mOGd09RHV04i>CP21PH40ADE509JFUP1kNg/0E5AD04i>CP1QHF40=3@d07IfMP1jNWX0JFUY09JF
UP1fMWH0=cLg08f=S@2NWYh0EeMG05]KF`1>CTh06ATI01`L701eMGD0RXZ:02d];@1FEUH0H61P08V9
R@1RHV80=CDe06i^KP1>CTh0Ng]k02PX:00j>SX0N7Qh05ADE01]KFd0FEUI01XJ6P0i>CT0W9bL0:2P
X01LG5`0Hf=S06m_K`1[Jf/0?3`l04I6AP1OGel0UIFE06YZJP0j>SX0DU9B08>3P`0g=cL0O7al0<;2
`P1`L700JFUY079bLP1@D500BTY:0P1XJ6P0Q@1>CTh0Jf][05aLG00k>c/0?Shn079bLP1mOGd0LG5a
03@d=01nOWh0PH6104Y:BP18B4P0BTY:0820P01cLg<0AdM709FEU@2JVYX0=CDe03Lg=`1KFe/0K6a/
05ADE01=CDd0EeMG071`L01<C4`0GemO071`L01OGel0FEUI0;Zj^P1`L700OGem07YjNP1^KVh0AdM7
075aL@1^KVh0F5QH01/K6`0[:b/0;Rh^07]kN`0b<S80;Rh^07YjNP2QXJ40O7al03Xj>P1[Jf/0D51@
04i>CP1CDe<0EeMG06a/K02XZ:P0WYjN0:RXZ03=cLd0W9bL08R8R02_[jl0YJFU09nOW`2IVIT0W9bL
09FEU@1OGel0D51@04Q8B00j>SX09BDU09:BTP33`l<0VYZJ0:b/[02_[jl0_;bl09NGU`1MGEd0G5aL
08R8R02EUID0Lg=c03Ti>@0U9BD06QXJ02@T902>SXh0@T92024Q8@0V9RH0KFe]08f=S@31`L40Z:RX
06i^KP20P800XJ6Q0;>c/`2h^;P0c/k>0<C4a01eMGD0B4Q802l_;`0Z:RX0D51@0:RXZ026QXH0WinO
06m_K`0j>SX0?Cdm05MGE`1?Cdl0<C4a02h^;P0o?cl0FEUI05]KF`1UIFD0NGUi071`L01EEED0D51@
05eMG@1`L700F5QH04U9B@1@D5000P1>CTh0H`19BDT0C4a<055AD@1?Cdl0EUIF079bLP1TI6@0K6a/
0:ZZZP1[Jf/0DE5A02XZ:P17AdL0OGem06YZJP0g=cL0?3`l05]KF`1JFUX0Cdm?03`l?00m?Cd0De=C
079bLP3<c<`0a/K609VIV@1cLg<0D51@0410@01<C4`0Ph>30:6QX@2WYjL0PH6107MgM`1@D500@d=3
03Ph>00m?Cd0E5AD06EUI@3;bl/0_kno0<30`01[Jf/0;Bd]02HV9P0[:b/0?3`l06=SH`33`l<0WIfM
075aL@1>CTh0<30`03lo?`3>c/h0]kNg08Z:RP1OGel0EUIF04m?C`12@T80ADE504Y:BP13@d<0O7al
04A4A01DE5@0K6a/05eMG@2IVIT0clo?09nOW`1GEeL0CDe=04Y:BP2m_Kd0g=cL0;6a/@2][Jd0Y:BT
0:NWY`2YZJT0/;2`0;Jf]P2c/k<0Xj>S0:NWY`3;bl/0jNWY0<c<c01^KVh0IfMW08R8R01mOGd0GemO
0:6QX@0209fMW@0]0::RXP2LW9`0TI6A0:^[Z`3Cdm<0f=SH0861P@0Q8B40820P038b<P2f][H0`l?3
09^KV`1kNg/0MWIf0:^[Z`2f][H0MgMg06ATI01DE5@0KVi^07alO016ATH0GEeM0::RXP2f][H0U9BD
08N7Q`22PX80TI6A09RHV02MWId0UIFE0<K6aP3Hf=P0_kno04Y:BP13@d<0B4Q804E5A@1OGel0X:2P
06e]K@0U9BD07QhN00807AdM00d0:2PX04A4A00h>3P0BDU909VIV@1TI6@0R8R806=SH`27QhL0LW9b
06i^KP1NGUh0FUYJ0080IFEU01X0M7Ad09>CT`3@d=00KVi^071`L01HF5P0O7al0;>c/`2RXZ80b<S8
0<30`03Fe]H0_[jn05IFEP1mOGd0ZZZZ06e]K@0i>CT0DE5A03dm?@0P820092@T03<c<`1PH600<S8b
02TY:@80:RXZ02h0Shn?0410@01RHV80_[jn0=WIf@3EeMD0b<S80;no_`39bLT0cLg=0;bl_02JVYX0
GEeM04I6AP1UIFD0T92@09NGU`30`<00T92@07alO01YJFT0Kfm_03lo?`0];Bd0<30`03@d=011@D40
;bl_02HV9P0Y:BT0?Cdm071`L01EEED0:BTY02/[:`0k>c/0KVi^04];B`1=CDd0Fe]K07YjNP2;Rh/0
YZJV06m_K`1UIFD0Q8B40_ooool0000K09nOW`22PX80Lg=c04e=C@1YJFT0]kNg079bLP0d=3@0F5QH
05iNGP0X:2P0DE5A03De=@1hN7P0=3@d04m?C`19BDT09RHV04Q8B00U9BD07alO024Q8@0X:2P06QXJ
0492@P1>CTh06a/K0080=cLg0?l0@d=3051@D01:BTX0Hf=S075aL@11@D408R8R02d];@1?Cdl09BDU
03/k>`1@D500E5AD01/K6`1YJFT0Cdm?02<S8`0o?cl0MWIf051@D00o?cl0PX:2059BDP1HF5P0DU9B
05IFEP0m?Cd0@41005UIF@1ADE406QXJ03@d=00m?Cd0820P03Ph>01WIfL0MgMg03De=@1ADE40Q8B4
02l_;`0K6a/0KVi^04E5A@0P8200MgMg04E5A@0i>CT0KFe]05MGE`0^;Rh0LG5a02DU9@0l?3`0HV9R
06=SH`0g=cL0=SHf0:JVYP0f=SH08B4Q071`L02CTi<0;bl_04M7A`1YJFT0EEEE01`L700m?Cd0C4a<
05ADE00b<S80GemO08B4Q00n?Sh0EeMG071`L02HV9P0=cLg05=CD`1UIFD0>3Ph03Ti>@0S8b<0Jf][
04A4A00d=3@0CDe=03/k>`0_;bl0GEeM06m_K`1FEUH0EEEE04I6AP0g=cL0MWIf071`L00j>SX0HV9R
02HV9P11@D40DE5A06][J`0d=3@0Fe]K06i^KP0j>SX0Hf=S04I6AP1EEED0MGEe04i>CP2YZJT0F5QH
04i>CP1YJFT0Fe]K08V9R@1hN7P0De=C04];B`1^KVh0Jf][04E5A@1HF5P0WIfM075aL@0k>c/0/;2`
07EeM@1?Cdl0R8R804Y:BP32`/80bl_;07moO`15ADD0Lg=c04e=C@28R8P0/;2`075aL@13@d<0NWYj
04A4A00d=3@0Lg=c07IfMP1TI6@0FEUI06UYJ@1ZJVX0G5aL08F5Q@1iNGT0U9BD08B4Q011@D40HV9R
0820P00j>SX0B4Q80;2`/029RHT0@41004M7A`1]KFd0;bl_0451@@1FEUH08B4Q03dm?@1MGEd0De=C
09FEU@21PH40F5QH04a<C01NGUh0;bl_06MWI`27QhL0DU9B08Z:RP1gMgL0;Rh^05aLG02CTi<0<30`
06=SH`1jNWX0Bd];01XJ6P1gMgL0Y:BT04=3@`1IFET0D51@07UiN@14A4@0=cLg07alO01/K6`0OWin
03hn?P0e=CD0FEUI03Hf=P1nOWh0NGUi061PH00d=3@0K6a/09ZJVP1YJFT0Vi^K0<C4a01aLG408b<S
02`/;017AdL0MWIf0820P019BDT0JFUY0861P@0f=SH0Cdm?09^KV`1UIFD0MGEe0::RXP1cLg<0BTY:
05iNGP11@D40ATI607inOP1[Jf/0IFEU0492@P1gMgL0OWin03`l?00W9bL0ATI6079bLP1YJFT0De=C
051@D01`L700?clo02/[:`1HF5P007<0OWin05ADE00k>c/0Hf=S05mOG`0N7Qh0?Shn055AD@1/K6`0
Bd];061PH01UIFD092@T030`<01dM7@0GUiN07EeM@1]KFd0Ng]k04i>CP1UIFD0Vi^K07alO00^;Rh0
:2PX02LW9`1UIFD0LG5a034a<@1<C4`0UIFE07=cL`0f=SH0Lg=c061PH01FEUH0DE5A051@D01:BTX0
>c/k08f=S@21PH40X:2P0451@@0k>c/0BTY:07EeM@2OWil0XJ6Q0;:b/P2;Rh/0>c/k02DU9@0Q8B40
<c<c04a<C028R8P0c<c<0;Rh^02^[Zh0`/;209:BTP23Ph<0EeMG0451@@0i>CT0?Shn04E5A@1RHV80
Jf][06EUI@1/K6`0]KFe0:VYZ@1XJ6P0K6a/0;fm_@2KVi/0MGEe04M7A`0l?3`0DU9B05eMG@1eMGD0
[Jf]0=?Cd`1OGel0?Cdm034a<@0W9bL09BDU03`l?027QhL0LW9b061PH01RHV80IFEU04M7A`1jNWX0
?Shn02TY:@0W9bL08b<S03lo?`1[Jf/0GUiN05mOG`1^KVh0D51@04U9B@1OGel0R8R803`l?015ADD0
@d=300<0?clo0140>CTi03/k>`0k>c/0ATI606i^KP1KFe/0IFEU0:RXZ01/K6`0F5QH05EEE@0R8R80
:RXZ08:2PP3Bd]80O7al03@d=002024Q8@1O02DU9@0V9RH0?Shn09:BTP2][Jd0^k^k07AdM01;Bd/0
BDU903hn?P12@T80QhN70:JVYP30`<00Jf][05IFEP1ZJVX0MGEe06ATI00e=CD09BDU07moO`2UYJD0
_kno09>CT`28R8P0CTi>03Xj>P1OGel0PX:205eMG@0i>CT0NGUi0;Jf]P28R8P0GUiN0:6QX@2CTi<0
UIFE092@T024Q8@0FUYJ055AD@1lO7`0S8b<09:BTP24Q8@0Xj>S0<[:bP2LW9`0Fe]K08j>SP2j^[X0
dm?C0;Vi^@1@D500>SXj04m?C`38b<P0Rh^;07=cL`23Ph<0OWin07UiN@1jNWX0SHf=09JFUP2UYJD0
/K6a0:^[Z`2WYjL0e=CD0<C4a02SXj<0RHV90:b/[022PX80Ph>3096AT@1fMWH0EEEE04];B`2BTY80
dM7A0<o?c`3Ph>00`l?30:n_[`1oOgl0A4A409bLW02IVIT0N7Qh05aLG01EEED00P1CDe<06`2BTY80
Xj>S07EeM@1_Kfl0Ti>C06a/K015ADD0F5QH0:RXZ02a/K40UIFE07IfMP1PH600MWIf06UYJ@1[Jf/0
L71`09RHV02`/;00Zj^[08V9R@1GEeL0ATI60492@P1BDU80Ti>C04M7A`0301dM7@1J01`L700K6a/0
8R8R03/k>`0e=CD0GUiN07IfMP2[Zj/0_Kfm06EUI@1IFET0QhN707UiN@1MGEd0HV9R05]KF`1@D500
Fe]K0=?Cd`2h^;P0IfMW09jNWP3Cdm<0bLW90<G5a@3EeMD0dm?C0:b/[01kNg/0Cdm?07moO`1eMGD0
EEEE02@T900/;2`0CTi>04=3@`0N7Qh08b<S05]KF`1kNg/0<30`03`l?00k>c/0Z:RX07QhN03;bl/0
b/[:0;6a/@2][Jd0[jn_09RHV02YZJT0Shn?07QhN024Q8@0OGem07YjNP1ZJVX0C4a<07UiN@2g]kL0
^k^k09BDU00h>3P0A4A407EeM@0W9bL09BDU02`/;00_;bl0?Cdm03hn?P0Z:RX0?clo07=cL`1GEeL0
820P02TY:@0f=SH0DU9B08V9R@1kNg/0UiNG08J6QP35aLD0eMGE0<W9b@2LW9`0Ti>C0_ooool0000d
0<C4a020P800LG5a051@D01kNg/0_;bl075aL@0e=CD0D51@04i>CP0h>3P0EEEE034a<@1cLg<0?clo
05EEE@1]KFd0:RXZ05mOG`17AdL0;Bd]03dm?@11@D406QXJ03lo?`13@d<061PH0410@00o?cl0@d=3
06ATI00k>c/0GUiN09JFUP1GEeL0;bl_02h^;P0l?3`0:b/[04e=C@0g=cL0AdM701<C4`1]KFd0QHF5
038b<P0e=CD0IfMW01XJ6P0b<S80R8R804Q8B080FEUI0:L0ADE503lo?`1YJFT0OGem05mOG`0T92@0
=CDe05=CD`0S8b<07QhN03De=@1:BTX08R8R05QHF02NWYh0LW9b01hN7P1VIVH0=cLg02LW9`1fMWH0
GUiN02DU9@0c<c<0:b/[02LW9`1cLg<0:BTY03<c<`1IFET0IVIV01XJ6P0W9bL0VIVI051@D00k>c/0
ZZZZ0:^[Z`0S8b<0<c<c04m?C`17AdL0;2`/05IFEP1ADE40=cLg01lO7`11@D40JFUY05eMG@1oOgl0
ZJVY0:NWY`1:BTX0@d=306a/K012@T80Bd];05QHF01TI6@0Bd];03lo?`1GEeL0QXJ605QHF01PH600
Ph>3075aL@1MGEd0NWYj04Q8B01lO7`0Ogmo03/k>`1fMWH0@41004E5A@1=CDd0I6AT04M7A`1TI6@0
P82003/k>`1nOWh0Fe]K07emO@2>SXh0Bd];0:^[Z`1UIFD0H61P071`L01VIVH0PX:206=SH`1?Cdl0
DU9B0:b/[02QXJ40Fe]K05UIF@2l_;`0A4A4020P802ATI40N7Qh04Y:BP2=SHd0AdM7065QH@2>SXh0
IVIV03lo?`1]KFd0ATI606YZJP2=SHd0Kfm_0451@@1/K6`0SXj>04a<C02KVi/0MgMg07=cL`1DE5@0
ATI605EEE@1jNWX0^KVi0=;BdP3:b/X0SXj>04U9B@1aLG40_[jn0::RXP1QHF40e=CD08R8R00k>c/0
Lg=c0:2PX01>CTh0A4A407AdM00/;2`0>SXj08V9R@0o?cl0Ogmo09ZJVP1NGUh0FUYJ07YjNP0f=SH0
IFEU07=cL`0e=CD0P82009bLW01DE5@0IfMW09bLW00i>CT0CDe=06EUI@0202l_;`2_07IfMP2SXj<0
GemO05eMG@1CDe<0S8b<03hn?P0T92@0GemO04E5A@1]KFd0;Rh^02/[:`1TI6@0E5AD061PH01DE5@0
IVIV03Xj>P1/K6`0Ph>302XZ:P19BDT0JFUY05aLG00m?Cd09BDU0492@P1kNg/0=CDe03dm?@1[Jf/0
PH6105iNGP1JFUX0];Bd0410@00g=cL0FUYJ06m_K`15ADD0I6AT04U9B@15ADD0Hf=S05]KF`1aLG40
AdM707MgM`1XJ6P0KFe]03De=@17AdL0Kfm_071`L01TI6@0E5AD05EEE@1kNg/0?clo07MgM`2=SHd0
De=C03hn?P1[Jf/0FUYJ028R8P0a<C40?Shn04I6AP0U9BD0JFUY04i>CP0o?cl0?3`l08>3P`1IFET0
Lg=c071`L027QhL0F5QH07inOP2QXJ40M7Ad02l_;`0O7al0:2PX069RHP23Ph<0=3@d061PH02/[:`0
SXj>04=3@`1`L700N7Qh04];B`0n?Sh0=SHf03Xj>P1]KFd0SHf=03Xj>P1NGUh0E5AD02l_;`0V9RH0
:BTY04M7A`2^[Zh0d=3@09JFUP0i>CT071`L01LG5`0I6AT0<C4a07QhN03>c/h0dm?C0<_;b`2KVi/0
KVi^03Ti>@1NGUh0L71`05YJFP0o?cl0>CTi03/k>`0j>SX0=3@d01lO7`0[:b/0Zj^[0:f][@2b/[80
Lg=c05YJFP0m?Cd0?clo04M7A`1IFET0KFe]08R8R01lO7`0a<C408^;R`1>CTh0<c<c02`/;00V9RH0
=CDe07YjNP1KFe/0A4A403@d=01MGEd0MgMg06MWI`0h>3P0:2PX02DU9@0S8b<08R8R02LW9`17AdL0
LG5a079bLP1eMGD0HF5Q05MGE`2JVYX0IVIV02@T900201dM7@<07QhN06D08B4Q02XZ:P0a<C40?clo
05eMG@1RHV80TY:B05YJFP18B4P0H61P02XZ:P0Q8B40<c<c0;Ng]`15ADD07alO01hN7P0R8R808B4Q
02XZ:P1EEED0Ph>306e]K@1eMGD0MWIf059BDP0i>CT0DE5A08R8R01[Jf/0Ng]k06QXJ01=CDd0FEUI
05mOG`1LG5`0Fe]K075aL@27QhL0d];B07EeM@2`/;00RXZ:06IVIP2HV9P0RHV908N7Q`0g=cL0;2`/
02DU9@0_;bl0IVIV08:2PP2DU9@0XZ:R079bLP1`L700IfMW05eMG@2IVIT0ZJVY06=SH`1IFET0KFe]
092@T034a<@0`/;20;6a/@2l_;`0UIFE08V9R@2@T900];Bd0:RXZ01GEeL0V9RH0<C4a00g=cL09bLW
02d];@0/;2`0>CTi06i^KP2TY:@0OGem06a/K01YJFT0Ogmo07]kN`2DU9@0c<c<0<O7a`38b<P0TY:B
0:^[Z`2/[:`0Cdm?0451@@0l?3`0HV9R0;6a/@020=GEe@090<o?c`2a/K40UiNG09nOW`3:b/X0V9RH
0492@P0Y:BT09BDU0080:b/[0200Fe]K0820P02WYjL0U9BD0::RXP1bLW80OGem05]KF`1gMgL0VIVI
059BDP1NGUh0LG5a08^;R`2HV9P0Ti>C07moO`28R8P0ZJVY0<K6aP2ATI40MgMg02`/;00M7Ad08B4Q
061PH01ADE40<C4a01dM7@0N7Qh08B4Q01hN7P807AdM00T0820P03De=@1[Jf/0bLW90=_Kf`3MgMd0
a/K608>3P`1iNGT00P1?Cdl0401KFe/0Kfm_05QHF01CDe<0aLG505EEE@2QXJ40[jn_0<30`036a/H0
e]KF0<K6aP37alL0H61P05MGE`1CDe<205mOG`0j08^;R`16ATH09BDU02`/;01IFET0NWYj04e=C@16
ATH0WIfM0861P@2IVIT0/K6a0=SHf03?cll0a/K60:j^[P23Ph<0Ng]k07=cL`2;Rh/0L71`055AD@18
B4P0F5QH08F5Q@26QXH0S8b<0:6QX@3Bd]80c/k>0:f][@2@T900;2`/03De=@1HF5P0?clo02DU9@0/
;2`0>3Ph02d];@0U9BD0;bl_05EEE@1nOWh0L71`020P800Y:BT0<30`03Ph>02PX:00dm?C0:b/[02g
]kL0];Bd0<G5a@31`L40XJ6Q08N7Q`;ooooo00002@2d];@0Cdm?06m_K`0l?3`0?Shn061PH00k>c/0
<30`05ADE00201dM7@1F02/[:`0O7al0Cdm?01`L700k>c/0F5QH02DU9@1^KVh0>3Ph010@4013@d<0
@D5101XJ6P0m?Cd0@d=300`<300N7Qh0:RXZ03hn?P1aLG405ADE02TY:@1CDe<0F5QH02DU9@0n?Sh0
AdM701PH600W9bL092@T04a<C00H61P0@41003@d=00G5aL0820P05MGE`0/;2`09bLW03lo?`0O7al0
Bd];05iNGP1<C4`09bLW02`/;01>CTh0>CTi01HF5P0[:b/0IfMW05EEE@0];Bd0?Shn05IFEP0a<C40
>c/k08f=S@27QhL0;bl_079bLP1QHF407AdM06a/K02:RXX0=CDe04E5A@0];Bd071`L06i^KP0_;bl0
@D5105=CD`1OGel0@d=303@d=02c/k<0LG5a04E5A@2LW9`0[Jf]03/k>`0n?Sh0B4Q804A4A00a<C42
05eMG@0f04U9B@0a<C40CDe=07emO@1bLW80H61P09ZJVP2i^KT0J6QX03`l?027QhL0CDe=06ATI01R
HV80GemO075aL@14A4@0MWIf08n?S`1SHf<0GUiN0861P@1]KFd0N7Qh08b<S012@T80M7Ad059BDP0g
=cL0LG5a055AD@14A4@0B4Q805QHF00b<S80BTY:08B4Q00d=3@0Jf][03@d=01DE5@0I6AT03Ph>01g
MgL0:b/[03dm?@1YJFT0FUYJ061PH01lO7`0?Shn02TY:@1[Jf/0U9BD0P1?Cdl0Z02JVYX0JFUY03Xj
>P2HV9P0J6QX05ADE02=SHd0LG5a06][J`2OWil0BTY:03/k>`1eMGD0QhN7071`L02JVYX0GUiN04m?
C`2=SHd0Ti>C03lo?`2HV9P0J6QX04Q8B00`<300MWIf0=;BdP2[Zj/0d=3@0>CTi03Lg=`0Ti>C04M7
A`1BDU80Zj^[08n?S`1gMgL0d=3@08>3P`0e=CD0CTi>08:2PP1BDU80Jf][06MWI`0T92@0DU9B09:B
TP1<C4`0U9BD09FEU@13@d<0KFe]0820P01FEUH0QhN706EUI@0f=SH0Kfm_09:BTP0^;Rh0DE5A08n?
S`1UIFD0D51@065QH@1<C4`06ATI05QHF02b/[80G5aL05mOG`1LG5`0Ng]k04i>CP0l?3`0O7al05MG
E`1dM7@0>3Ph02PX:01eMGD0OGem07]kN`1NGUh0Ogmo04M7A`1/K6`0Xj>S05mOG`1nOWh0U9BD07If
MP1CDe<09bLW0451@@1^KVh0LW9b0451@@0n?Sh0J6QX0451@@1NGUh0[jn_08N7Q`1?Cdl0I6AT05EE
E@16ATH0GemO051@D01KFe/0R8R805]KF`1lO7`0BTY:07EeM@21PH40Hf=S038b<P15ADD0NWYj08^;
R`1ZJVX0G5aL06i^KP2:RXX0ATI607=cL`2KVi/0@T920451@@2BTY80R8R80410@00e=CD0@T9204i>
CP11@D40GEeM069RHP1TI6@0ATI608j>SP1GEeL0F5QH0:VYZ@2TY:@0GUiN0820P02BTY80IVIV034a
<@0M7Ad08b<S07=cL`22PX80=3@d065QH@2XZ:P0QhN703hn?P2FUYH0RXZ:0492@P1KFe/0OGem09>C
T`80^[Zj02@0GUiN02l_;`1SHf<0A4A402/[:`0X:2P0>CTi0:JVYP3AdM40_Kfm06ATI00/;2`06ATI
02<S8`1JFUX0QXJ60=SHf03IfMT0gmoO0:BTY01FEUH0?3`l02XZ:P0V9RH0?Cdm06MWI`1SHf<0EUIF
04];B`1WIfL0=SHf030`<02HV9P0VYZJ03Ti>@0/;2`205UIF@0S061PH01CDe<0DE5A04e=C@1BDU80
IFEU0;6a/@2XZ:P0;Rh^03De=@0m?Cd0?clo04Y:BP2:RXX0JVYZ0451@@0l?3`0Jf][07UiN@2WYjL0
OWin0451@@0j>SX0<S8b03Lg=`13@d<0EEEE07emO@2DU9@0TI6A05IFEP1EEED0LW9b09VIV@1ADE40
0P0M7Ad00`0O7al07QhN024Q8@0202TY:@0602/[:`0`<300AdM708b<S02@T900@d=30P1<C4`09`1I
FET08B4Q02<S8`1oOgl0NGUi01lO7`0M7Ad0820P01hN7P0[:b/0LG5a05EEE@1OGel0NWYj05mOG`1M
GEd0J6QX08n?S`21PH40Ph>307=cL`0_;bl0>SXj03dm?@0d=3@0?Cdm05ADE01dM7@0QXJ60=7Ad@2Y
ZJT0L71`06YZJP1`L700U9BD06MWI`14A4@0@D510410@00202HV9P1h04E5A@2ATI40W9bL05eMG@1?
Cdl0?3`l03Lg=`17AdL0N7Qh0:FUY@1:BTX0GemO05]KF`1^KVh0aLG50<30`02h^;P0`/;209ZJVP1R
HV80CTi>05UIF@2NWYh0`l?30=cLg03Kfm/0I6AT02d];@0S8b<09BDU02HV9P0g=cL0MWIf06MWI`1Y
JFT0<c<c03De=@11@D40IfMW09RHV02IVIT0/k>c0=kNgP3De=@0OWin04I6AP1<C4`0J6QX0:6QX@2/
[:`0TI6A0:f][@27QhL0_;bl0:VYZ@36a/H0_[jn0;Zj^P2HV9P0EUIF024Q8@0N7Qh0<C4a06YZJP11
@D40K6a/09bLW02CTi<0FEUI07]kN`1MGEd0JFUY07AdM00m?Cd0;Bd]034a<@0m?Cd0@d=305YJFP29
RHT0b<S80:f][@26QXH0WinO08N7Q`1DE5@071`L03hn?P1<C4`0=3@d01lO7`0L71`07alO02HV9P0/
;2`09BDU028R8P0P8200:BTY08f=S@23Ph<0f][J0=7Ad@3=cLd0emOG0<;2`P1lO7`0=SHf02TY:@13
@d<0JVYZ08^;R`2SXj<0BDU905]KF`2e]KD0g]kN0=GEe@2n_[h0TY:B0P2JVYX00`0b<S809BDU02PX
:00204Y:BP0K07moO`0S8b<0:b/[04Q8B02d];@0Vi^K08B4Q02][Jd0`L710;jn_P2XZ:P0d=3@0<_;
b`1/K6`0LG5a07MgM`1/K6`0?Shn034a<@17AdL0LG5a07AdM01FEUH0CTi>08N7Q`2m_Kd0bLW90080
d=3@01`0Ng]k07MgM`0h>3P0;Rh^038b<P1]KFd0;bl_02TY:@0i>CT0<c<c02PX:01>CTh0ZJVY0<G5
a@2b/[80DU9B04E5A@1JFUX0MgMg0<g=c@3EeMD0c/k>0;2`/02OWil0Ti>C059BDP2m_Kd0d];B0_oo
ool0000N0<?3``1>CTh0EEEE069RHP1?Cdl0W9bL05IFEP0V9RH0@D5105MGE`0];Bd08b<S01`L701?
Cdl0ATI6034a<@13@d<0410@03`l?01BDU80:2PX05YJFP0`<3005ADE02DU9@15ADD06a/K01`L700^
;Rh08R8R0P1LG5`0501PH600MgMg08^;R`0i>CT09BDU03/k>`0S8b<0>SXj01/K6`1ADE40=cLg04];
B`1:BTX0@D51020P801VIVH0JFUY03Xj>P1aLG40Cdm?0P1DE5@0S`1TI6@0HF5Q03Ph>01LG5`0H61P
02LW9`0N7Qh0HV9R06ATI00b<S80ADE5069RHP1JFUX0@T9208F5Q@1bLW80;Bd]075aL@1ZJVX07AdM
061PH02ATI40A4A406ATI01HF5P08R8R07EeM@12@T80>CTi05IFEP24Q8@0Jf][03Ti>@2ZZZX0O7al
04U9B@20P800a<C406a/K010@400>SXj04M7A`0g=cL0DU9B0:6QX@2<S8`0EUIF04e=C@1oOgl0GemO
04m?C`2EUID0a/K608F5Q@0e=CD0JFUY034a<@1UIFD0EUIF04];B`1JFUX0;2`/055AD@1gMgL0EeMG
04m?C`1_Kfl0@D5104U9B@1bLW80@T9205=CD`1iNGT0<S8b08>3P`1kNg/0=CDe0451@@1]KFd0J6QX
05UIF@28R8P0>CTi06EUI@1IFET0IFEU05ADE00i>CT0Lg=c05eMG@17AdL0G5aL03Ti>@1CDe<0WinO
065QH@0g=cL0OGem07=cL`0R8R80ADE509RHV01VIVH0;bl_08f=S@1VIVH0@41006a/K01cLg<0GemO
09FEU@1WIfL0?Cdm05aLG02<S8`0IfMW08R8R01]KFd0?clo06i^KP27QhL0C4a<0::RXP1gMgL0MWIf
03hn?P0j>SX0_kno0>7Qh@3De=@0i>CT0>7Qh@2_[jl0EeMG05eMG@28R8P0=CDe04I6AP2ZZZX0V9RH
04m?C`1KFe/0O7al0080=3@d02P0Fe]K03@d=00d=3@0FUYJ0451@@1dM7@0W9bL04Y:BP15ADD0DU9B
02`/;01:BTX0O7al04m?C`1ZJVX0WYjN05MGE`17AdL0/;2`07QhN012@T80HV9R04e=C@0M7Ad0CDe=
0<?3``1HF5P0GEeM0:BTY02QXJ40I6AT04];B`2:RXX0F5QH07MgM`1=CDd0<S8b06QXJ024Q8@0F5QH
0P1^KVh0TP1=CDd0D51@09bLW028R8P0J6QX09FEU@2RXZ80L71`02h^;P18B4P0GUiN07EeM@15ADD0
Cdm?07MgM`0n?Sh0GEeM0<71`@2DU9@0D51@065QH@1UIFD0D51@07YjNP1aLG40KFe]08:2PP1DE5@0
Hf=S04a<C024Q8@0ZZZZ05]KF`0a<C40>SXj079bLP1OGel0F5QH07MgM`2][Jd0UIFE04E5A@1RHV80
[jn_04A4A00Z:RX0Fe]K06ATI01PH600;bl_04U9B@1DE5@0;Rh^05]KF`2XZ:P0QhN704];B`2@T900
DU9B03/k>`2SXj<0WYjN05mOG`2ATI40XJ6Q06EUI@0[:b/0@d=306ATI02DU9@0PX:203`l?01KFe/0
WinO05=CD`0H61P0L71`07]kN`1mOGd0JVYZ05]KF`1LG5`0LG5a09nOW`2[Zj/0NWYj03`l?01PH600
=cLg02d];@1[Jf/0][Jf09fMW@2ATI40^k^k09^KV`2EUID0U9BD0;>c/`3Kfm/0emOG0<o?c`3@d=00
bl_;09fMW@1MGEd0@d=301lO7`0K6a/07alO02TY:@17AdL0PH61065QH@1>CTh0GemO05UIF@0l?3`0
B4Q804U9B@14A4@0CDe=059BDP1gMgL0Kfm_06YZJP1iNGT0W9bL0:VYZ@2g]kL0<c<c01dM7@0Q8B40
820P03`l?01kNg/0J6QX06MWI`1lO7`0=CDe03Xj>P1bLW80bl_;0=OGe`3@d=00ZZZZ0P2h^;P02P3<
c<`0Z:RX08>3P`1XJ6P08B4Q02l_;`1?Cdl0NGUi09RHV00e=CD202<S8`0B02DU9@0/;2`0;Bd]03Hf
=P19BDT0P8200:FUY@3Rh^80^KVi04Y:BP18B4P0BDU905ADE01=CDd0<S8b05UIF@2a/K40<C4a0P0P
82003P0M7Ad0<30`06MWI`1:BTX0C4a<06i^KP20P800N7Qh0<W9b@2CTi<0Q8B408N7Q`1VIVH0EEEE
0P1TI6@09P1KFe/0ATI602DU9@0e=CD0De=C09jNWP2BTY80AdM704A4A01RHV80/K6a06][J`1aLG40
UYJF09VIV@1]KFd0JVYZ09>CT`2IVIT0TI6A0861P@17AdL0<C4a02l_;`0c<c<0CDe=0;Ng]`1NGUh0
>3Ph06a/K026QXH0EUIF0:ZZZP2o_kl0/[:b0;Bd]02n_[h0/K6a0`30`<00@P2l_;`0Shn?0:n_[`1G
EeL08b<S02DU9@0V9RH0:RXZ05ADE01:BTX0D51@02TY:@0W9bL09BDU03@d=00c<c<0K6a/08n?S`2Y
ZJT0g=cL09JFUP23Ph<0TI6A09ZJVP1JFUX0>c/k04E5A@2ATI40[jn_09nOW`34a<@0Zj^[09NGU`1m
OGd0PX:209ZJVP2BTY80Q8B408F5Q@0c<c<0>c/k07AdM02g]kL0RHV906e]K@20P800LG5a0820P01I
FET0@D5103De=@0b<S80>3Ph03`l?00o?cl0EEEE0;2`/032`/80^;Rh0:^[Z`2_[jl0YJFU03De=@1E
EED0@410030`<0807AdM01l09BDU02HV9P0M7Ad06a/K01`L700R8R80Shn?09jNWP2VYZH0emOG09^K
V`2BTY80WIfM0<71`@3<c<`0clo?09VIV@1BDU80BDU909^KV`2NWYh0S8b<0:j^[P3Jf]X0h>3P0=SH
f02IVIT0Ng]k0<71`@37alL0EUIF00809BDU0140<30`05]KF`1GEeL0TI6A061PH01gMgL0UIFE08R8
R02KVi/0_[jn0=gMg@3Kfm/0b/[:0=3@d038b<P0LG5a03lo?`0202DU9@0X02@T900S8b<09RHV03<c
<`12@T80I6AT07YjNP21PH40WinO08>3P`1^KVh0WYjN07alO01/K6`0EEEE02/[:`0`<300AdM70820
P00g=cL0F5QH06a/K02>SXh0`/;20<c<c033`l<0UYJF09jNWP29RHT0KVi^0:f][@2l_;`0^[Zj0<c<
c02ZZZX0[Jf]065QH@1EEED0c<c<0861P@;ooooo0000803<c<`0EeMG05EEE@1^KVh0De=C0:NWY`2>
SXh0=3@d04e=C@1gMgL0;bl_04Y:BP0k>c/0HF5Q05mOG`0/;2`0EeMG030`<016ATH0?Cdm01hN7P1:
BTX0<30`01hN7P0O7al0=SHf01TI6@0N7Qh0<c<c03De=@1CDe<0IVIV0P1XJ6P0C02=SHd0C4a<02d]
;@0g=cL0;bl_03/k>`0Q8B40ADE503De=@16ATH0H61P05IFEP0W9bL0@d=306=SH`0h>3P0NWYj05aL
G01BDU80Bd];04e=C@1NGUh0=cLg079bLP1SHf<0820P01`L701FEUH0AdM702DU9@1QHF40O7al05QH
F00h>3P0MWIf06m_K`0_;bl0DU9B071`L00M7Ad0BDU906=SH`0P8200AdM705UIF@0V9RH0LG5a03Hf
=P19BDT0JFUY096AT@1kNg/0>3Ph09ZJVP1ADE408R8R04Q8B02WYjL0HV9R03Hf=P0g=cL0@d=3034a
<@0W9bL0@D5104i>CP10@400=SHf06i^KP1LG5`0@T9207=cL`2d];@0MWIf02XZ:P1WIfL205]KF`0^
06i^KP1:BTX0GemO03`l?01HF5P0R8R806][J`12@T80J6QX08B4Q01CDe<0N7Qh059BDP1OGel0TY:B
03lo?`1hN7P0?3`l03<c<`1DE5@0Ph>3069RHP1NGUh0JVYZ03`l?01[Jf/0F5QH06IVIP1jNWX0Bd];
07moO`1EEED0BDU905QHF01QHF40?Cdm0861P@1:BTX0<S8b07moO`1gMgL0EUIF04E5A@2ZZZX0K6a/
02XZ:P80Shn?0500EeMG07alO01_Kfl0Hf=S0;Bd]01nOWh0@41007=cL`25QHD0G5aL09:BTP25QHD0
C4a<07QhN02?Shl0GemO09>CT`26QXH0R8R803Xj>P0o?cl0Ph>30>3Ph03Ogml0iNGU0>?Sh`2][Jd0
GEeM05EEE@2MWId0QXJ607inOP2n_[h0OGem059BDP1OGel0Shn?05]KF`11@D40LW9b04M7A`0a<C40
Jf][03/k>`1OGel0WIfM04Q8B01@D500EUIF03Hf=P1GEeL0Ph>305IFEP1PH600VIVI0492@P13@d<0
Xj>S05]KF`10@400Ogmo05UIF@0N7Qh0?clo0<c<c01OGel0;2`/05YJFP1fMWH0LG5a04e=C@1kNg/0
Fe]K09FEU@1<C4`0A4A407QhN01aLG40Cdm?07=cL`80@T920;40J6QX0:FUY@2BTY80GEeM09JFUP2J
VYX0>3Ph04A4A01oOgl0VYZJ096AT@1ADE40FEUI07MgM`0_;bl0DE5A0:j^[P2ATI40B4Q805]KF`1M
GEd0<C4a05EEE@1VIVH0GEeM07moO`1OGel0GEeM02TY:@1TI6@0S8b<08V9R@14A4@0=CDe07alO01:
BTX0@T9204U9B@1bLW80T92@061PH01JFUX0VIVI05QHF00c<c<0LW9b05UIF@1JFUX0;Bd]055AD@12
@T80@d=303/k>`1oOgl0QhN704i>CP25QHD0M7Ad04Q8B02>SXh0NGUi05mOG`2IVIT0[Jf]06e]K@16
ATH06a/K02LW9`1_Kfl0MgMg0492@P1DE5@0WYjN07inOP16ATH0LW9b07AdM01FEUH0D51@04a<C019
BDT0ATI604E5A@1KFe/0MWIf08:2PP1JFUX0GemO06i^KP2YZJT0G5aL06ATI00m?Cd0ADE50<W9b@3;
bl/0g=cL0<g=c@3Kfm/0`L7105eMG@19BDT0Jf][0:6QX@2ZZZX0PH6106QXJ014A4@0AdM704=3@`1<
C4`0I6AT06QXJ01JFUX0MgMg06=SH`1WIfL0EUIF05ADE01WIfL0U9BD06m_K`1OGel0Ti>C05=CD`0l
?3`0<30`069RHP1oOgl0MWIf01dM7@0L71`07AdM03Xj>P1dM7@0CDe=01`L700W9bL0<S8b04=3@`1e
MGD0b/[:08N7Q`1NGUh0C4a<059BDP24Q8@0WIfM09nOW`2;Rh/0KVi^01hN7P0L71`0820P04M7A`2O
Wil0`<3009:BTP27QhL0Ph>308j>SP2=SHd0T92@08f=S@2PX:00^[Zj0=;BdP3@d=00_kno05eMG@1G
EeL0AdM704i>CP0/;2`0BDU909^KV`1WIfL00P0O7al00`0M7Ad0BDU905ADE00203/k>`1004];B`39
bLT0/k>c08B4Q01bLW80MWIf05]KF`16ATH0?Shn03/k>`0h>3P0>c/k03De=@0S8b<09BDU02d];@1Z
JVX0K6a/03lo?`0i>CT0IVIV08Z:RP15ADD0De=C07emO@2b/[80gMgM0=CDe02;Rh/0UYJF04i>CP1f
MWH0K6a/03dm?@0`<300<S8b0451@@20P800cLg=0:VYZ@1jNWX0JFUY09^KV`2l_;`0gmoO09fMW@21
PH40d=3@09bLW01^KVh0QHF505eMG@2IVIT0>c/k05=CD`2PX:00GemO02LW9`0V9RH0;2`/05eMG@1D
E5@0KVi^02LW9`809RHV0P0Y:BT0=@1EEED0BTY:07UiN@3=cLd0dM7A0:BTY01VIVH0<C4a02@T900Y
:BT0;bl_04I6AP2m_Kd0UiNG09jNWP2k^k/0XJ6Q07alO01OGel0FUYJ065QH@2RXZ80WYjN04i>CP25
QHD0R8R807YjNP1SHf<0JFUY08R8R02WYjL0[Zj^04m?C`1:BTX0B4Q803`l?00d=3@0?Cdm05mOG`2Q
XJ40RXZ:06IVIP2>SXh0[jn_09jNWP2i^KT0^;Rh07MgM`0g=cL08B4Q01`L700O7al08B4Q008071`L
01D06a/K024Q8@1eMGD0Y:BT0;:b/P2g]kL0WIfM09NGU`2FUYH0TY:B0;bl_02][Jd0`L710<C4a038
b<P0`<300<o?c`3AdM40c<c<0=GEe@3AdM400P2n_[h03`39bLT0^k^k07emO@29RHT0RXZ:02/[:`0V
9RH0<30`04U9B@1fMWH0alO70:f][@2>SXh0XZ:R04e=C@0203Ti>@070<K6aP2^[Zh0b<S80<S8b02e
]KD0@T9203Xj>P0201lO7`0X02@T900S8b<08b<S02LW9`0^;Rh0AdM703hn?P1?Cdl0Kfm_08J6QP1<
C4`0Ng]k08j>SP24Q8@0GEeM03@d=00W9bL0>c/k08B4Q02e]KD0^;Rh0<S8b02d];@0R8R805eMG@1I
FET0SXj>08:2PP20P800a<C40<g=c@2XZ:P0UIFE0=[JfP2/[:`0cLg=08J6QP3:b/X0Ph>3051@D0;o
oooo0000o`2e]KD0EUIF05=CD`1IFET0CTi>09:BTP1nOWh0=CDe04Q8B016ATH0<c<c04e=C@0a<C40
G5aL04Y:BP0o?cl0J6QX030`<00o?cl0?Cdm01HF5P12@T80<c<c01/K6`0H61P0>c/k01<C4`0];Bd0
BTY:03dm?@1OGel0ATI604m?C`23Ph<0Ogmo04Y:BP0/;2`0@d=302HV9P17AdL09RHV034a<@0M7Ad0
<S8b06a/K01RHV807AdM03@d=00a<C40;bl_06MWI`1ADE40CDe=05ADE018B4P0>CTi03dm?@21PH40
IFEU03Lg=`0M7Ad0BDU902d];@0H61P0>3Ph05mOG`1VIVH0>3Ph07QhN02CTi<0GemO04m?C`23Ph<0
6QXJ03hn?P2IVIT0B4Q805EEE@1XJ6P0:2PX065QH@0h>3P09bLW03`l?01XJ6P0@410028R8P21PH40
MGEe05]KF`1QHF40cLg=04=3@`0[:b/0C4a<065QH@1LG5`0?Cdm06m_K`18B4P0@D5104=3@`2<S8`0
SXj>05aLG02XZ:P0bLW908R8R00_;bl0NGUi06=SH`1EEED0=SHf04Y:BP1]KFd0>3Ph05YJFP1WIfL0
@41003<c<`1<C4`0Jf][04Q8B01LG5`0>SXj04I6AP1nOWh0>CTi075aL@1VIVH0<S8b03`l?01PH600
G5aL05iNGP1iNGT0E5AD06][J`19BDT0IFEU09NGU`1<C4`0QHF505EEE@1PH600NGUi07alO011@D40
Ti>C069RHP11@D40UiNG0:^[Z`1_Kfl0@T920;Fe]@1>CTh0=cLg07emO@1nOWh0GUiN07=cL`0j>SX0
De=C08b<S02BTY80CDe=05QHF01ADE40>SXj09FEU@25QHD0AdM708:2PP17AdL0<c<c07UiN@2KVi/0
LG5a04U9B@1?Cdl0N7Qh0>CTi03Vi^H0j^[Z0=WIf@2[Zj/0FEUI051@D02/[:`0UIFE08R8R02^[Zh0
NWYj04];B`1nOWh0^KVi06][J`12@T80M7Ad04m?C`0c<c<0GemO04e=C@1VIVH0UYJF05=CD`1;Bd/0
FUYJ03dm?@1PH600KVi^04=3@`1WIfL0V9RH03Ti>@0n?Sh0VYZJ04E5A@0e=CD0KVi^03hn?P0I6AT0
<c<c0<W9b@1BDU80A4A406QXJ01KFe/0C4a<034a<@22PX80JFUY092@T013@d<0;Bd]05eMG@1PH600
BDU907emO@0g=cL0;Rh^03hn?P1bLW80FUYJ04M7A`27QhL0OWin01lO7`0R8R80ATI605ADE01iNGT0
AdM705]KF`00@`1PH600;2`/03lo?`2k^k/0Rh^;04M7A`1IFET0Q8B404a<C01FEUH0@41004E5A@1h
N7P0U9BD06][J`1:BTX0HF5Q08Z:RP1TI6@0=3@d05ADE02DU9@0MWIf06MWI`1OGel0MGEe079bLP0_
;bl0Hf=S09:BTP1TI6@0=cLg06YZJP1QHF40@T9204i>CP23Ph<0Ogmo05MGE`1>CTh0Ogmo08R8R01C
De<0RHV909>CT`1BDU80TI6A07UiN@1GEeL0TI6A0:n_[`23Ph<0F5QH01dM7@0];Bd0KVi^04];B`0_
;bl0Jf][0:b/[026QXH0>CTi071`L00o?cl0EEEE04];B`12@T800P0i>CT0AP0g=cL0=3@d04=3@`1h
N7P0Zj^[0<71`@3<c<`0Cdm?01/K6`1:BTX0D51@02DU9@23Ph<0[:b/0:j^[P2>SXh0Vi^K07MgM`0k
>c/0;2`/034a<@0m?Cd0BTY:079bLP22PX80CTi>04E5A@1:BTX0DU9B07MgM`1iNGT0>CTi02/[:`0R
8R80820P02@T900];Bd0Hf=S08R8R02@T900RXZ:04Y:BP0^;Rh0820P01dM7@0];Bd0Fe]K0:n_[`0m
?Cd06QXJ02HV9P1/K6`0WYjN04I6AP0K6a/0:b/[05QHF00m?Cd0Rh^;07UiN@0g=cL0:RXZ02TY:@0S
8b<071`L02/[:`1WIfL0Ogmo08R8R00Y:BT201`L702D02`/;01aLG40`l?309ZJVP1[Jf/0HV9R06AT
I01/K6`0L71`06m_K`1gMgL0M7Ad0::RXP2j^[X0d=3@0<71`@1]KFd0?clo03hn?P1=CDd0@T9207Ad
M02UYJD0<S8b02@T900[:b/0Vi^K04E5A@0^;Rh0<c<c051@D02;Rh/0W9bL07moO`1lO7`0MgMg03@d
=00U9BD0;Bd]02DU9@0X:2P09bLW02TY:@0[:b/0820P02<S8`1BDU80EUIF0492@P0/;2`0FEUI04i>
CP14A4@0?Shn06UYJ@2GUiL0_Kfm0;2`/01[Jf/0G5aL05]KF`1IFET0Ogmo08F5Q@1NGUh0AdM707em
O@2SXj<0alO70:RXZ019BDT0Jf][051@D01SHf<0XJ6Q069RHP2VYZH0_[jn06e]K@1?Cdl0FEUI06IV
IP1/K6`0=CDe02h^;P0d=3@0VYZJ08J6QP0];Bd0;bl_05UIF@1YJFT0LG5a02DU9@0W9bL0:b/[02@T
901BDU80DE5A0451@@0k>c/0XJ6Q0=cLg01PH6009RHV02DU9@0S8b<09BDU02HV9P0X:2P0S8b<0=;B
dP28R8P0G5aL0<G5a@2UYJD0Hf=S055AD@1;Bd/0JFUY0<O7a`2^[Zh0M7Ad04m?C`1NGUh0EUIF05UI
F@1]KFd0QHF507=cL`1_Kfl0EUIF04M7A`1@D500IfMW07=cL`29RHT0S8b<051@D015ADD0B4Q80820
P023Ph<0TI6A0<K6aP2^[Zh0ATI6024Q8@8071`L03<06QXJ01TI6@0L71`08B4Q06YZJP2NWYh0PX:2
0>3Ph01kNg/0WinO08j>SP1JFUX0FEUI09:BTP2EUID0UYJF09jNWP2i^KT0e=CD0>GUi@3Ogml0[jn_
0;Fe]@2<S8`0Ti>C0:RXZ02[Zj/0ZZZZ05QHF01MGEd0X:2P04e=C@0[:b/0>CTi05YJFP23Ph<0^k^k
04M7A`0j>SX0GEeM02l_;`0W9bL0<c<c08j>SP2DU9@0`<300<o?c`2c/k<0?Cdm02DU9@0N7Qh00P0Q
8B409`0T92@08R8R020P800U9BD0=3@d03Hf=P0h>3P0FUYJ06IVIP1/K6`0EEEE08F5Q@2HV9P0GUiN
06IVIP1GEeL0SHf=0=3@d03Lg=`0YJFU08F5Q@1jNWX0D51@04Y:BP1GEeL0MgMg0:2PX034a<@0e]KF
0=_Kf`2a/K40X:2P0<?3``3Ph>00g]kN0=;BdP2MWId0QHF507alO002ooooo`0006l0Lg=c04m?C`1A
DE40F5QH0492@P1iNGT0N7Qh03@d=00m?Cd0AdM702PX:00j>SX0;Bd]04U9B@0n?Sh09BDU04U9B@0j
>SX0@D5105ADE00E5AD0:b/[03/k>`0Q8B405aLG02l_;`0G5aL07AdM03Ph>00i>CT0Cdm?0492@P0_
;bl0ADE505aLG00g=cL0;2`/04A4A00`<300>3Ph02/[:`0b<S809BDU02<S8`1;Bd/0@41001TI6@0`
<300C4a<034a<@1TI6@0Bd];03`l?01KFe/0IFEU05QHF00X:2P0De=C05UIF@0k>c/08b<S04m?C`1D
E5@0<30`04M7A`15ADD0>CTi02TY:@1EEED0NGUi05]KF`0n?Sh0Kfm_01LG5`13@d<0TY:B05=CD`1D
E5@0FUYJ02TY:@1`L700GUiN03hn?P1;Bd/0R8R80410@00V9RH0O7al08R8R01RHV80KFe]0<c<c01c
Lg<0A4A404=3@`0n?Sh0ADE503Lg=`24Q8@0GemO034a<@0Z:RX0Cdm?08B4Q01BDU80Zj^[0;Zj^P2>
SXh0<30`05IFEP17AdL00P1VIVH0;`10@400EEEE02d];@1UIFD0SHf=07AdM00`<300AdM704m?C`0i
>CT0Q8B406EUI@1:BTX0HV9R020P801RHV80Ng]k03dm?@10@400DU9B02DU9@19BDT0M7Ad04m?C`1b
LW80?Cdm03Hf=P21PH40@D5106QXJ010@400=cLg05UIF@1]KFd0>c/k09BDU01PH6009BDU051@D020
P800Hf=S03dm?@2WYjL0G5aL02/[:`1NGUh0Q8B40080JFUY04D0RHV90451@@1gMgL0VIVI04E5A@17
AdL0PH6104Q8B01fMWH0SXj>04U9B@1RHV80GUiN05aLG01oOgl0Ng]k04];B`0k>c/0:b/[06][J`3N
g]h0f=SH0<k>cP1dM7@0SXj>061PH01`L700_[jn0:>SX`2EUID0bl_;09NGU`0h>3P0O7al0;Vi^@1^
KVh0BTY:06QXJ01ADE40ADE508j>SP1@D500CTi>0:f][@1ZJVX0H61P08^;R`19BDT0EeMG08^;R`0/
;2`0H61P0:NWY`1]KFd0A4A409JFUP1WIfL0=SHf061PH011@D40820P02d];@3Cdm<0NWYj04e=C@1e
MGD0De=C06a/K01=CDd00P2GUiL0102WYjL0J6QX02PX:01JFUX204];B`1B09:BTP1SHf<0A4A404M7
A`1gMgL0G5aL04U9B@2FUYH0N7Qh04e=C@0_;bl0BTY:05QHF02;Rh/0DU9B08j>SP1hN7P0BTY:055A
D@30`<00IfMW03hn?P2CTi<0P82004=3@`1JFUX0AdM7034a<@0e=CD0CDe=065QH@1<C4`0IfMW07If
MP11@D40820P028R8P1OGel0J6QX06=SH`1MGEd0HV9R07QhN01EEED0DU9B09>CT`1DE5@0;bl_06=S
H`1?Cdl0<S8b01lO7`17AdL0@D5104m?C`0o?cl0MgMg04I6AP0f=SH0IfMW08F5Q@0i>CT0TY:B071`
L00j>SX0GEeM08b<S01QHF40;Rh^030`<01>CTh0S8b<06UYJ@0b<S80;Bd]07QhN01[Jf/0<C4a092@
T01mOGd0@D5103Ti>@80=cLg01@0>c/k04m?C`1TI6@0MWIf09NGU`32`/80bl_;0;^k^`0h>3P07alO
028R8P1`L700IFEU09^KV`3Cdm<0b<S80<g=c@1oOgl0@d=302TY:@<09BDU02P09RHV02/[:`0j>SX0
SHf=06YZJP1RHV80Fe]K061PH023Ph<0<c<c01XJ6P0L71`06QXJ01dM7@0U9BD0CTi>0861P@2e]KD0
LG5a07MgM`1LG5`0;Bd]01dM7@0X:2P0BDU9096AT@2d];@0RXZ:09bLW03>c/h0`l?307YjNP0m?Cd0
HF5Q05EEE@0m?Cd0J6QX03@d=00S8b<06a/K0`0I6AT01@0L71`0CTi>06QXJ01EEED0I6AT008071`L
03@0<S8b05QHF01VIVH0aLG509bLW011@D40<S8b03Lg=`0c<c<0;Bd]030`<00];Bd0?3`l06][J`2]
[Jd0cLg=0=3@d01aLG40@410055AD@1FEUH0P8200=[JfP35aLD0YJFU0;bl_03Fe]H0SHf=03hn?P0^
;Rh0>SXj06ATI01`L700T92@07alO02:RXX0DU9B04i>CP1PH600@41002HV9P0Q8B4092@T02/[:`0U
9BD07alO03De=@1FEUH0ATI602/[:`1HF5P0;2`/0P0T92@04P0^;Rh0J6QX07QhN01oOgl0;Rh^02/[
:`0^;Rh0Lg=c0<W9b@2_[jl0^[Zj07emO@1EEED0Fe]K08f=S@35aLD0OWin0410@080:2PX0300GEeM
0:>SX`2f][H0N7Qh04I6AP1:BTX0CTi>04U9B@1fMWH0Cdm?03<c<`0[:b/0>3Ph07UiN@2FUYH0>SXj
03`l?01QHF40OWin02TY:@0[:b/08B4Q028R8P1GEeL0Bd];04I6AP1CDe<0WYjN0<g=c@11@D408B4Q
02<S8`0T92@08b<S024Q8@0/;2`0O7al0>CTi03Jf]X0NWYj06][J`35aLD0[:b/09FEU@29RHT0^k^k
0=;BdP2:RXX20410@00l0451@@1;Bd/0W9bL08^;R`1:BTX0De=C04a<C01NGUh0H61P04U9B@1hN7P0
YZJV09jNWP1ADE40?Shn03Ti>@1[Jf/0b/[:05]KF`2<S8`0/K6a09jNWP1iNGT0E5AD024Q8@0J6QX0
71`L01LG5`0/;2`0QhN708F5Q@1TI6@0`/;20;^k^`23Ph<0];Bd0<30`02/[:`0KFe]04Y:BP0h>3P0
=SHf0492@P1YJFT0Xj>S0=KFeP3Ogml0c<c<0:2PX02EUID0Rh^;04];B`0o?cl0IfMW09>CT`1XJ6P0
LG5a08B4Q00o?cl09bLW0P1NGUh03@2:RXX092@T02@T900_;bl0>c/k02LW9`0k>c/0HV9R0:j^[P3:
b/X0];Bd0;:b/P0_;bl00`0N7Qh0:00P82007QhN02@T900S8b<09BDU034a<@0m?Cd0=3@d04A4A01U
IFD0PH6106i^KP1]KFd0^;Rh09jNWP2RXZ80_[jn0<G5a@2l_;`0V9RH0;Fe]@2n_[h0W9bL0;Ng]`3:
b/X0d=3@0<K6aP2g]kL0Z:RX0:ZZZP2RXZ80^k^k0=;BdP2`/;00Xj>S0=[JfP3<c<`0Y:BT07=cL`1`
L702ooooo`000?l0EUIF05QHF01ADE40NGUi05EEE@1lO7`0QHF5038b<P15ADD0Jf][04Y:BP11@D40
>3Ph04U9B@1[Jf/0<S8b05eMG@0/;2`0=SHf061PH00^;Rh0=SHf04i>CP0K6a/06ATI04U9B@0[:b/0
92@T03Xj>P0I6AT0>c/k06e]K@1RHV80IfMW07]kN`0_;bl07alO03/k>`1HF5P0>CTi01/K6`0c<c<0
>c/k038b<P1OGel0@T9201XJ6P0L71`0Fe]K0492@P1WIfL0:BTY038b<P1KFe/0Jf][07QhN00f=SH0
HV9R06EUI@0N7Qh06QXJ03De=@15ADD0;Rh^055AD@18B4P0MWIf03`l?01GEeL0QHF505UIF@0l?3`0
SHf=02l_;`0b<S80PX:203/k>`1KFe/0G5aL02/[:`1OGel0B4Q803Lg=`1LG5`0OWin04i>CP0Y:BT0
M7Ad071`L00g=cL0=CDe08F5Q@1gMgL0Bd];0492@P13@d<0:2PX02@T901=CDd0IfMW05eMG@0[:b/0
Bd];08J6QP0^;Rh0Lg=c08:2PP2GUiL0?3`l05MGE`0T92@0Bd];06IVIP15ADD0B4Q802LW9`0n?Sh0
L71`075aL@0^;Rh0BTY:069RHP0a<C40JFUY06EUI@1;Bd/0KFe]03Lg=`1EEED0MWIf03lo?`0l?3`0
EUIF06YZJP1GEeL0Kfm_05=CD`1mOGd0MWIf05MGE`23Ph<0?Shn05=CD`2;Rh/0GUiN05YJFP21PH40
?Cdm09VIV@1EEED0@T9205]KF`2;Rh/0G5aL03lo?`2c/k<0RXZ:038b<P21PH40IFEU04U9B@2:RXX0
T92@04A4A01^KVh0QXJ60410@01aLG40TY:B04m?C`1^KVh0UYJF04a<C01YJFT0LW9b07UiN@1MGEd0
JFUY06ATI01SHf<0=cLg03hn?P2c/k<0Vi^K0::RXP1MGEd0MGEe02h^;P16ATH0Q8B40:>SX`1UIFD0
^k^k0:6QX@1?Cdl0DE5A09VIV@1cLg<0DE5A05mOG`1@D500B4Q808j>SP1BDU80@d=30::RXP1GEeL0
ADE507=cL`1FEUH0DE5A09bLW01BDU80E5AD0;Vi^@1]KFd0@D5108b<S02IVIT0ADE506YZJP1>CTh0
<c<c04U9B@3=cLd0W9bL04a<C01VIVH0D51@06i^KP0];Bd0?clo04e=C@1XJ6P0JFUY02DU9@1`L700
@41003@d=01eMGD0M7Ad04M7A`16ATH0Ogmo03Ti>@0n?Sh0PX:20820P01TI6@0<S8b04];B`1LG5`0
GemO02XZ:P1=CDd005<0IfMW06UYJ@1:BTX0_;bl075aL@0i>CT0FUYJ07IfMP16ATH0DU9B03lo?`1H
F5P0?Cdm06e]K@2<S8`0HV9R06MWI`1bLW80GEeM04U9B@0T92@0H61P0820P01gMgL0K6a/08N7Q`2W
YjL0JFUY059BDP2LW9`0ADE502@T9024Q8@0SXj>04i>CP0T92@0FUYJ04E5A@18B4P0?Cdm0:FUY@2;
Rh/0E5AD06IVIP1hN7P0<30`09bLW02JVYX0KVi^08V9R@2[Zj/0Ng]k02<S8`0I6AT0:BTY05ADE01d
M7@0=CDe02h^;P29RHT0De=C01DE5@1QHF40K6a/06i^KP1hN7P0MgMg07AdM01eMGD0Hf=S04U9B@0g
=cL0<S8b03<c<`1HF5P0Fe]K08f=S@25QHD0QXJ606UYJ@29RHT0d=3@0<g=c@020=GEe@040:>SX`1E
EED0:BTY02<S8`<0:2PX00T0;bl_02h^;P1FEUH0<C4a02`/;00W9bL0ATI6051@D00Q8B400P0K6a/0
6`0L71`07alO02<S8`0S8b<0;Rh^05UIF@1QHF40;Bd]04e=C@1VIVH0?Shn02HV9P0Y:BT0Y:BT0=CD
e02g]kL0RXZ:07YjNP2l_;`0OWin0:2PX02a/K40IFEU05MGE`1;Bd/09bLW01dM7@0201`L700>01XJ
6P0L71`06a/K03dm?@1aLG40:RXZ05aLG01=CDd0;2`/05QHF01DE5@0=cLg08R8R01_Kfl201XJ6P0F
01/K6`0O7al08b<S02DU9@0^;Rh0;2`/03/k>`1RHV80L71`0:JVYP3;bl/0X:2P061PH02NWYh0a/K6
0:RXZ01JFUX0E5AD05MGE`23Ph<0^[Zj09nOW`80NGUi01D0P82007IfMP20P800Kfm_05]KF`0X:2P0
:BTY0410@01@D500F5QH04E5A@0V9RH0:RXZ03lo?`0Q8B408b<S05MGE`1EEED0?Shn06a/K00T92@0
0P0P8200T@0T92@0=CDe04Y:BP1YJFT0:RXZ03dm?@24Q8@0Z:RX08:2PP1mOGd0a<C40<[:bP2o_kl0
Zj^[0<k>cP2b/[80Q8B4024Q8@0O7al0@d=308R8R02>SXh0KFe]04a<C00g=cL0ADE503Lg=`0Z:RX0
KVi^07EeM@0a<C40<30`02TY:@0d=3@0K6a/09JFUP1?Cdl0M7Ad0820P01@D500BTY:020P800c<c<0
FEUI04a<C01CDe<0;2`/05ADE02YZJT0D51@01lO7`0W9bL0:b/[02DU9@0T92@0=SHf08n?S`3Ti>@0
g]kN0<71`@2l_;`0_Kfm0:JVYP2k^k/0dm?C0=[JfP2_[jl0^;Rh07inOP1/K6`0IVIV07EeM@35aLD0
J6QX02TY:@0/;2`0>3Ph0410@01HF5P0RHV90;Ng]`2f][H0WinO065QH@15ADD0KVi^0;Fe]@21PH40
De=C0820P02<S8`0^[Zj0;jn_P2PX:00ATI602PX:00N7Qh0@D5108N7Q`2ZZZX0][Jf0;bl_01VIVH0
KVi^079bLP1EEED0QXJ609NGU`1ADE4071`L01hN7P0a<C40<30`03Ti>@1CDe<0e=CD0=oOg`3Bd]80
T92@05ADE01aLG40EEEE03Ti>@13@d<0GUiN0820P022PX80JFUY05EEE@0_;bl0EeMG04Y:BP1WIfL0
71`L024Q8@0R8R80<S8b02d];@19BDT0MgMg0<;2`P3QhN40X:2P08V9R@0b<S800P0M7Ad00`0L71`0
7AdM01`L700201dM7@0T02DU9@0W9bL0>c/k038b<P0o?cl0EeMG06UYJ@2@T900Y:BT0=CDe03Ti>@0
dm?C0<K6aP2BTY80FEUI04m?C`28R8P0alO706EUI@2IVIT0Hf=S05MGE`1EEED0GemO08j>SP3=cLd0
dM7A0<?3``2i^KT0ZZZZ0:FUY@2c/k<0Ti>C0;6a/@20P800T92@0_ooool0000P079bLP1>CTh0De=C
07IfMP1KFe/0N7Qh08>3P`0_;bl0<c<c05EEE@0l?3`0;Rh^03Lg=`12@T80LG5a02d];@1OGel0@d=3
034a<@1_Kfl0=CDe02d];@1HF5P0=CDe01HF5P15ADD0:b/[024Q8@0j>SX09bLW03Xj>P1iNGT2069R
HP3I096AT@1]KFd0:RXZ03Ph>01VIVH0?clo03Ti>@0b<S80ADE5034a<@1cLg<0JVYZ03hn?P0R8R80
BTY:02`/;01hN7P0IfMW02l_;`1ADE40M7Ad06=SH`0c<c<0MgMg07QhN01=CDd0820P030`<00Q8B40
61PH03dm?@14A4@0GEeM030`<01KFe/0M7Ad02<S8`0R8R80JFUY030`<00a<C40Ogmo02`/;00U9BD0
EEEE03De=@1GEeL0Cdm?01TI6@0`<300Fe]K04M7A`0X:2P0OGem0:VYZ@1^KVh0Bd];0:>SX`28R8P0
>3Ph05iNGP1RHV80C4a<03Hf=P1NGUh0AdM704I6AP0P8200?Shn08j>SP1FEUH0OGem09RHV02/[:`0
=cLg06m_K`1^KVh0GemO05QHF01ADE40NWYj06EUI@16ATH0Kfm_05eMG@0d=3@0Kfm_09>CT`1>CTh0
L71`04a<C01CDe<0Ti>C05MGE`1EEED0GEeM03De=@1=CDd0T92@07YjNP1OGel0M7Ad02l_;`1MGEd0
R8R805QHF01SHf<09RHV04Y:BP2:RXX0GUiN05IFEP1DE5@0?Cdm0<c<c02?Shl0D51@05QHF01^KVh0
<c<c02HV9P24Q8@0JVYZ02LW9`1iNGT0MGEe05IFEP1@D500R8R80451@@1NGUh0Rh^;03/k>`1HF5P0
UiNG04m?C`1WIfL0Kfm_04M7A`2HV9P0VIVI08R8R01@D500OWin09JFUP2HV9P0BTY:08^;R`2XZ:P0
U9BD08N7Q`2:RXX0/K6a079bLP1BDU80S8b<06i^KP11@D40WinO0:b/[01/K6`0EeMG09fMW@1QHF40
H61P08V9R@1PH600<S8b07AdM01LG5`0@4100:NWY`1LG5`0?3`l06a/K01WIfL0DE5A09nOW`1nOWh0
G5aL0;:b/P1YJFT0DE5A0:n_[`2ZZZX0?Shn07inOP15ADD07alO020P802m_Kd0T92@04];B`1oOgl0
Hf=S09VIV@1dM7@0IfMW05MGE`2FUYH0PX:203lo?`1mOGd0RHV904E5A@1^KVh0LG5a05IFEP1RHV80
XZ:R08R8R013@d<0Kfm_079bLP1KFe/0@T9207QhN0020:2PX080EUIF00`0OGem06UYJ@1FEUH0_kno
09BDU01QHF40Lg=c08Z:RP1MGEd0I6AT07AdM01cLg<203Xj>P0i06e]K@1EEED0OWin0:^[Z`23Ph<0
FEUI02@T901BDU80EeMG02XZ:P1_Kfl0VYZJ0;Bd]01YJFT0?Shn0<;2`P1>CTh06ATI0492@P1EEED0
IVIV02l_;`1SHf<0ADE506IVIP14A4@0LG5a07moO`1KFe/0K6a/08f=S@0h>3P0V9RH075aL@1dM7@0
T92@0;fm_@1dM7@0De=C01dM7@0h>3P0A4A4075aL@12@T80?Shn09nOW`1NGUh08b<S06QXJ01MGEd0
J6QX04=3@`0b<S809bLW024Q8@0O7al07AdM00806QXJ00X05ADE01`L701ZJVX0JVYZ09VIV@1SHf<0
K6a/0:NWY`1mOGd0Cdm?0P3De=@04@2l_;`0UiNG07alO00Z:RX0:2PX02d];@0/;2`0:b/[03dm?@14
A4@0:BTY02LW9`0Y:BT0Bd];01lO7`0L71`06a/K00807AdM01P07alO01hN7P0M7Ad08R8R03De=@1A
DE40Bd];02<S8`0`<300KVi^06m_K`23Ph<0WIfM09ZJVP22PX80Hf=S05ADE01WIfL0NGUi079bLP2P
X:00TI6A06=SH`0W9bL2024Q8@0@02PX:00/;2`092@T01lO7`0L71`0=SHf08>3P`0W9bL0CTi>071`
L01SHf<0Cdm?03hn?P0c<c<0JVYZ06ATI0H071`L00h07QhN01lO7`0Q8B40@41005ADE01GEeL0MgMg
0:j^[P3Jf]X0d];B0<_;b`1dM7@0=cLg03@d=080?3`l05<0E5AD08J6QP2QXJ40VYZJ0;Ng]`2[Zj/0
^KVi0:ZZZP11@D409BDU02HV9P0S8b<092@T02<S8`0i>CT0FUYJ059BDP0W9bL092@T02h^;P2YZJT0
[Zj^0<C4a028R8P08B4Q020P800M7Ad08b<S034a<@18B4P0_Kfm0:^[Z`2LW9`0QXJ605eMG@1IFET0
L71`09FEU@1dM7@0GEeM06EUI@2EUID0Ng]k09bLW01JFUX0Jf][07AdM00o?cl0LW9b065QH@1JFUX0
<S8b03@d=00Z:RX0:2PX05ADE02KVi/0F5QH03Hf=P0[:b/0;Bd]03Lg=`1cLg<0/K6a096AT@2YZJT0
VYZJ04e=C@13@d<0LW9b07QhN01RHV809BDU01`L700o?cl0QXJ606a/K00S8b<0:2PX02l_;`0`<300
<S8b05UIF@020<_;b`0=0;Ng]`1SHf<0DU9B096AT@31`L40]KFe0;Vi^@3EeMD0e=CD0<W9b@2e]KD0
Vi^K09jNWP020<o?c`0i04m?C`0Y:BT09BDU02HV9P0`<300@T9208Z:RP32`/80XJ6Q08F5Q@2m_Kd0
Vi^K0:BTY01VIVH07alO01dM7@0Z:RX0T92@0:BTY02NWYh0ZZZZ09RHV01`L700C4a<07]kN`30`<00
bLW90:RXZ01FEUH0Kfm_07MgM`0e=CD0:RXZ04a<C01?Cdl0FEUI05ADE00e=CD0:BTY02/[:`0a<C40
KVi^0<k>cP3Hf=P0bl_;05eMG@1LG5`0De=C05IFEP1DE5@0BDU904M7A`1IFET0JFUY0::RXP1gMgL0
DE5A0080EeMG0100GEeM01lO7`0M7Ad07alO02DU9@0i>CT0O7al0;no_`3Bd]80][Jf0:JVYP1^KVh0
Bd];01lO7`0M7Ad071`L0`0M7Ad02`0Q8B408R8R028R8P0T92@09RHV02l_;`16ATH0I6AT0;Jf]P3R
h^80eMGE0080clo?01P0e]KF09bLW02[Zj/0[jn_0:RXZ02LW9`0UYJF08:2PP0i>CT0>c/k04I6AP22
PX80Z:RX0<30`03De=@0alO70;^k^`37alL0/k>c0;Zj^P26QXH0Xj>S0=GEe@3MgMd2ooooo`000?l0
Ng]k04m?C`1>CTh0FEUI04e=C@21PH40UIFE04A4A00h>3P0DU9B03Lg=`17AdL0GemO04M7A`1TI6@0
;bl_06a/K01=CDd0:2PX05IFEP0S8b<09BDU04U9B@0/;2`06ATI0410@00J6QX08B4Q04M7A`0_;bl0
?Cdm05aLG00n?Sh0Lg=c09^KV`1lO7`0:RXZ03@d=00_;bl0<S8b051@D00a<C40:BTY01<C4`10@400
MgMg03hn?P0U9BD0:BTY018B4P1;Bd/0BDU902PX:01DE5@0LG5a034a<@0R8R80?3`l04=3@`1KFe/0
;Bd]03`l?01FEUH0?Shn0451@@0h>3P0<C4a01/K6`1/K6`0VYZJ07MgM`0W9bL0P82003dm?@0[:b/0
OWin071`L00^;Rh0LW9b03Ti>@1CDe<0Lg=c02h^;P0o?cl0MGEe03Ph>00F5QH0EeMG08F5Q@1kNg/0
De=C0:RXZ026QXH0;bl_0451@@1VIVH0GUiN0451@@1aLG40Cdm?04E5A@0T92@0DE5A09bLW01WIfL0
YZJV09nOW`35aLD0<C4a05YJFP1aLG40EeMG059BDP0n?Sh0HF5Q05iNGP11@D40NGUi05IFEP0b<S80
De=C06e]K@1>CTh0GEeM04=3@`0e=CD0L71`051@D016ATH0O7al038b<P0d=3@0D51@07EeM@1CDe<0
FUYJ06IVIP1ADE40NWYj05ADE01eMGD0HF5Q04m?C`23Ph<0EEEE05YJFP1ADE407alO09:BTP25QHD0
EEEE05IFEP1ZJVX0?clo030`<02FUYH0IFEU02`/;026QXH0Vi^K05eMG@1PH600Vi^K05mOG`2PX:00
^k^k05QHF01ADE40Q8B405UIF@1^KVh0SXj>05EEE@1UIFD0T92@07emO@16ATH0ZJVY0:>SX`1XJ6P0
GEeM07emO@2BTY80=3@d03Ti>@1QHF40R8R805mOG`1BDU80N7Qh0820P01:BTX0UYJF09>CT`1ZJVX0
K6a/0:NWY`1dM7@0:RXZ05IFEP1KFe/0:BTY065QH@13@d<0IFEU09nOW`1[Jf/0@T92079bLP0k>c/0
GEeM09:BTP1gMgL0DU9B0;6a/@1PH600;Bd]06=SH`2=SHd0>SXj0:>SX`2<S8`0>c/k020P8038b<P0
[:b/038b<P1VIVH0KVi^08n?S`1^KVh0PX:206i^KP2CTi<0@41001lO7`1<C4`0RHV904Y:BP2?Shl0
AdM701hN7P0f=SH0HF5Q08:2PP0o?cl0PX:209bLW00b<S807alO04I6AP1WIfL0TY:B06i^KP1JFUX0
00l0MGEe038b<P0g=cL0QhN7096AT@1WIfL0KVi^06QXJ00X:2P0<C4a059BDP1YJFT0@D51030`<01D
E5@00P1=CDd09@1KFe/0HF5Q05MGE`0Q8B40DE5A06QXJ01WIfL0L71`05ADE02JVYX0I6AT04m?C`2N
WYh0LW9b04M7A`1DE5@0F5QH07IfMP0j>SX0PX:207alO02;Rh/0De=C08V9R@26QXH0Fe]K092@T02S
Xj<0BDU90:ZZZP1RHV80=SHf06MWI`2YZJT0S8b<06][J`15ADD00P1WIfL08P1/K6`0?Shn03<c<`2C
Ti<0Lg=c0451@@1eMGD0D51@04Y:BP15ADD0@T9203Xj>P0/;2`0820P01`L700I6AT061PH01DE5@0[
:b/0OGem092@T020P800aLG50<g=c@2IVIT0:2PX01dM7@2_[jl0XZ:R08:2PP2XZ:P0OGem071`L00h
>3P2030`<00702HV9P12@T80;Bd]02PX:00Z:RX09bLW01/K6`0201DE5@0301HF5P0K6a/061PH00<0
71`L02L07AdM02@T901@D500CTi>03hn?P0M7Ad07QhN05aLG037alL0Ti>C09^KV`1UIFD0<C4a02<S
8`0O7al0<30`04e=C@1DE5@0O7al07IfMP1DE5@0ATI602@T900V9RH08R8R01hN7P0L71`06ATI04=3
@`2LW9`0@d=305UIF@1nOWh0T92@0410@00`<300=3@d05UIF@1_Kfl00P0L71`00`0J6QX071`L01`L
700401`L700I02@T901HF5P0E5AD06ATI02LW9`0h>3P0=7Ad@2g]kL0E5AD03@d=00V9RH0<C4a03`l
?00n?Sh0B4Q807alO02^[Zh0_Kfm0:>SX`2f][H0/k>c061PH00];Bd09BDU01lO7`03024Q8@0:02/[
:`0m?Cd0BDU907inOP2?Shl0ZJVY0;no_`2XZ:P0YJFU069RHP<07alO01P0=cLg08n?S`34a<@0PH61
05IFEP1>CTh0Bd];04Q8B01dM7@0O7al0492@P0n?Sh0ATI604=3@`1SHf<0@D5109JFUP1QHF40>c/k
02DU9@1/K6`0G5aL065QH@0^;Rh302@T902?05EEE@1jNWX0BDU904I6AP1IFET0JVYZ06UYJ@25QHD0
VIVI09jNWP24Q8@0Lg=c069RHP1MGEd0Kfm_08n?S`2:RXX0@T9201lO7`1TI6@0OWin08V9R@0X:2P0
:BTY03Hf=P13@d<0A4A40:^[Z`34a<@0YJFU0:NWY`1KFe/0I6AT0<C4a02HV9P0UYJF0;Zj^P2[Zj/0
UiNG0;Jf]P2IVIT0IVIV061PH01jNWX0/K6a09fMW@0m?Cd0;Bd]02XZ:P0X:2P0;Bd]06EUI@2^[Zh0
^KVi0;Bd]03WinL0a/K605iNGP0O7al06QXJ01dM7@0c<c<0`/;20=cLg036a/H0`/;20<O7a`2NWYh0
Z:RX0<c<c03?cll0WYjN07EeM@2IVIT0[Jf]04M7A`0L71`08R8R02d];@0O7al0=SHf07YjNP1hN7P0
C4a<06ATI027QhL0_Kfm0<o?c`3IfMT0b<S806a/K018B4P0@d=30451@@17AdL0EEEE05eMG@1DE5@0
F5QH07inOP2CTi<0VYZJ0:6QX@2@T900IfMW03Hf=P0g=cL0;Rh^02l_;`1GEeL0Y:BT0;Ng]`30`<00
Ph>306a/K01ZJVX0[:b/05]KF`1<C4`0@41003/k>`0^;Rh092@T01hN7P0Q8B407AdM020P800N7Qh0
9RHV04U9B@2;Rh/0[:b/0<[:bP35aLD0ZZZZ0;fm_@3De=@0_[jn0:FUY@2RXZ80QHF506IVIP1=CDd0
0P24Q8@03`2@T900`/;20;Bd]030`<00VYZJ08V9R@1gMgL0Jf][09NGU`3@d=00g=cL0=GEe@31`L40
_[jn08f=S@02ooooo`0000P0FUYJ04M7A`1HF5P0Hf=S03Lg=`1>CTh0H61P03Ph>080@41001d07AdM
02TY:@1:BTX0@D51038b<P0B4Q80@410055AD@0b<S80JVYZ020P800E5AD0CTi>02h^;P0J6QX0E5AD
01hN7P0@4100<C4a02TY:@14A4@0EEEE01lO7`19BDT0Lg=c06EUI@0];Bd0CDe=055AD@0203hn?P0@
03Ti>@1FEUH092@T055AD@1QHF40>CTi04=3@`1dM7@0?3`l06i^KP1UIFD0<30`06a/K02ATI40O7al
051@D080C4a<00D0B4Q801`L700a<C40@T9203/k>`020451@@3706ATI00f=SH0BDU9075aL@20P800
9bLW0820P00_;bl0;Bd]09VIV@1kNg/0;Bd]06=SH`0a<C40H61P08n?S`19BDT0@41005mOG`1LG5`0
=CDe05iNGP24Q8@0IfMW04m?C`2j^[X0V9RH069RHP0d=3@0AdM704a<C01:BTX0LW9b04M7A`1BDU80
92@T04=3@`22PX80JVYZ07moO`2][Jd0_;bl05aLG01PH600IVIV04m?C`1SHf<0DU9B08:2PP1=CDd0
@D5106YZJP24Q8@0BDU9061PH01cLg<0HF5Q05UIF@1jNWX0CDe=07UiN@1UIFD0ATI608F5Q@1;Bd/0
@41004a<C01[Jf/0H61P07MgM`1/K6`0Cdm?06m_K`11@D40Ti>C06EUI@1<C4`0N7Qh051@D01lO7`0
RXZ:04I6AP32`/80I6AT04i>CP1]KFd0U9BD06ATI00n?Sh0QhN705aLG00K6a/0Fe]K06][J`1DE5@0
IFEU09FEU@0k>c/0Cdm?0820P01LG5`0BTY:06=SH`0Y:BT0L71`08N7Q`1NGUh0MWIf09bLW00n?Sh0
>SXj08n?S`2IVIT0JFUY061PH027QhL0XJ6Q06][J`13@d<0MgMg0:2PX018B4P0H61P08^;R`2/[:`0
CTi>0:2PX02JVYX0@D5104A4A028R8P0VYZJ04E5A@1`L700;Bd]03Ph>01hN7P0H61P03Ti>@2DU9@0
@D5104e=C@2KVi/0Q8B403/k>`2BTY80=3@d03/k>`2ATI40_;bl04a<C01bLW80Rh^;01LG5`1JFUX0
TY:B04=3@`0T92@0aLG50:n_[`1=CDd0GUiN04m?C`1UIFD0Bd];06QXJ02ATI40V9RH06][J`0Y:BT0
DE5A06][J`0l?3`0RHV907]kN`1JFUX0A4A408^;R`1nOWh0BDU909^KV`2SXj<0R8R80451@@10@400
Fe]K096AT@19BDT0Ogmo08>3P`1jNWX0EUIF09nOW`1fMWH0De=C08f=S@2JVYX0GemO04Y:BP0204=3
@`1[04U9B@1KFe/0Kfm_06ATI01@D500JVYZ061PH01:BTX0>CTi07]kN`2DU9@0N7Qh06i^KP1DE5@0
S8b<05EEE@0j>SX0ZJVY08J6QP1?Cdl0E5AD05IFEP0l?3`0820P061PH01NGUh0OGem04];B`2MWId0
NGUi03lo?`1[Jf/0WIfM04I6AP2o_kl0RHV907alO01`L700YJFU06a/K00e=CD07QhN02`/;00l?3`0
G5aL0451@@0T92@0R8R807YjNP0b<S80MWIf08N7Q`1>CTh0BDU904=3@`0h>3P0@41004I6AP0h>3P0
;bl_024Q8@12@T80DE5A04Y:BP17AdL0Lg=c0<K6aP37alL0[:b/04E5A@0P8200W9bL096AT@1BDU80
FUYJ08F5Q@1NGUh0O7al055AD@0j>SX0A4A40410@00Y:BT09BDU028R8P0U9BD05aLG01@D500E5AD0
4a<C01DE5@0G5aL061PH01/K6`0J6QX07AdM01hN7P0_;bl0EEEE05=CD`0Z:RX07QhN03@d=022PX80
Cdm?0861P@1/K6`00P1NGUh07@1FEUH0Bd];04a<C01kNg/0IfMW04Y:BP1?Cdl0HF5Q06][J`17AdL0
9RHV01hN7P0Z:RX0=SHf08f=S@35aLD0G5aL04e=C@1<C4`0K6a/08^;R`0n?Sh0<c<c05EEE@2?Shl0
6a/K01TI6@0K6a/06ATI00<071`L01`07alO01`L700U9BD0@D510:>SX`1LG5`0/[:b0;Zj^P2n_[h0
G5aL06a/K021PH40D51@0451@@16ATH0DE5A04i>CP1KFe/0Q8B409fMW@2YZJT0/[:b09JFUP1TI6@0
GEeM030`<00R8R80:BTY0`0O7al0M@0U9BD0CTi>06YZJP1DE5@0BDU906a/K02>SXh0FUYJ08F5Q@1m
OGd0>SXj03Hf=P1iNGT0QhN707inOP1HF5P0D51@059BDP1<C4`0BDU907IfMP1ZJVX0>3Ph03Xj>P10
@400?Cdm04Y:BP1IFET0KVi^04=3@`0Q8B407alO05eMG@1KFe/0K6a/038b<P0O7al07AdM020P8012
@T80Fe]K0451@@0V9RH0;bl_0492@P2IVIT0Xj>S0:FUY@2FUYH0Ogmo05eMG@0n?Sh0=cLg02h^;P12
@T80GemO07AdM01LG5`0EUIF0:b/[037alL0R8R804I6AP13@d<0JVYZ0;2`/02e]KD0Q8B40410@00o
?cl0O7al0<G5a@2OWil0HF5Q07AdM02e]KD0Ng]k075aL@1YJFT0>3Ph04E5A@1NGUh0K6a/08f=S@22
PX80OWin04Y:BP0n?Sh0@T9203lo?`1dM7@0RHV908J6QP1SHf<0_;bl08F5Q@0O7al071`L028R8P1M
GEd0SXj>0;no_`33`l<0a/K60=?Cd`3@d=00[jn_0<S8b03Ng]h0`<3008f=S@1gMgL0N7Qh07EeM@1`
L70071`L01/K6`0201`L700Z02<S8`0k>c/0PH610<C4a02=SHd0N7Qh0:j^[P37alL0dm?C0<W9b@22
PX80BTY:04M7A`14A4@0ATI604];B`1DE5@0Lg=c08^;R`2i^KT0[jn_0;Zj^P2=SHd0[Jf]0:JVYP1n
OWh0IFEU04U9B@1=CDd0C4a<09:BTP2g]kL0e=CD07]kN`1mOGd0[Zj^07=cL`18B4P0@T920451@@15
ADD0BDU90P1>CTh0601<C4`0CTi>04Q8B00n?Sh0DU9B0:RXZ03AdM40emOG0>7Qh@3Ogml0UYJF0;>c
/`1eMGD0?3`l03dm?@10@400EUIF07YjNP2<S8`0`l?30=cLg03Jf]X0a/K607emO@80I6AT00X0@D51
03Ti>@10@400EeMG0<?3``3MgMd0f=SH0;6a/@2PX:00MGEe0_ooool0001S06IVIP0o?cl0A4A406e]
K@16ATH0KFe]06m_K`0M7Ad0;2`/0451@@0h>3P0:b/[02TY:@0m?Cd0E5AD028R8P0i>CT0?3`l02XZ
:P1^KVh0=SHf01dM7@0m?Cd07alO01LG5`15ADD0ATI6028R8P0e=CD05aLG02HV9P1DE5@0A4A407in
OP27QhL0Cdm?01LG5`0Y:BT0Fe]K03Ti>@0d=3@08R8R04=3@`0S8b<0Cdm?05aLG00Q8B406ATI03dm
?@0g=cL0FUYJ01hN7P0S8b<0B4Q806][J`1bLW80D51@03Ti>@1>CTh0@D51020P800[:b/0>c/k030`
<00a<C40=SHf06ATI00l?3`0CDe=07YjNP2:RXX0;Bd]06a/K01<C4`061PH05EEE@1_Kfl0;2`/059B
DP0Z:RX0Bd];08Z:RP13@d<0?Shn065QH@1VIVH0?Cdm04m?C`1kNg/0BDU904A4A02/[:`0[jn_061P
H012@T80@d=303lo?`10@400DE5A0080D51@01d0:RXZ04I6AP1iNGT0DE5A05aLG02IVIT0_Kfm061P
H01HF5P0DU9B05]KF`1hN7P0@T92071`L00i>CT0HF5Q0861P@1cLg<0CDe=069RHP1[Jf/0@41005aL
G01ZJVX0D51@07=cL`0h>3P0Cdm?07]kN`0204];B`1e04a<C00f=SH09bLW04M7A`1VIVH0>CTi07Qh
N00^;Rh0CTi>059BDP0o?cl0LG5a038b<P1=CDd0IfMW04E5A@2j^[X0TI6A03Ti>@0o?cl0F5QH05aL
G017AdL0T92@09>CT`1EEED0Ph>308N7Q`1HF5P0[Jf]0;fm_@1NGUh0J6QX0:BTY013@d<0De=C0:n_
[`1YJFT0LG5a05mOG`0k>c/0QHF50:2PX028R8P0?Shn07emO@2DU9@07alO02HV9P16ATH0Xj>S08^;
R`1BDU80MWIf09ZJVP16ATH0=CDe059BDP27QhL0EEEE08j>SP2BTY80FUYJ04M7A`29RHT0SXj>04=3
@`1QHF40CDe=01dM7@13@d<0KFe]03dm?@2QXJ40HV9R030`<01MGEd0Lg=c03/k>`2@T900ADE503Ti
>@1eMGD0MWIf03lo?`1QHF40WIfM0410@01/K6`0IfMW03Hf=P18B4P0^k^k0::RXP1MGEd0IFEU06QX
J01VIVH0<S8b03Ti>@1HF5P0K6a/05IFEP0_;bl0BTY:05]KF`12@T80L71`05]KF`1:BTX0ADE508N7
Q`1OGel0>CTi07UiN@2=SHd0K6a/0080@d=306H0Fe]K09NGU`1?Cdl0EEEE05mOG`1cLg<0FUYJ0:ZZ
ZP1fMWH0@T9205]KF`1dM7@0FEUI04a<C01ADE40?clo03Hf=P0j>SX0HV9R06ATI01=CDd0OWin07em
O@1KFe/071`L03hn?P1`L700Ng]k06IVIP1BDU80Vi^K09VIV@1:BTX0_kno08F5Q@1EEED0MgMg07al
O01YJFT0=SHf04m?C`1YJFT0Ogmo0451@@2ATI40SXj>05aLG01jNWX0RHV902TY:@1hN7P0EeMG06UY
J@21PH40_[jn0861P@1fMWH0820P03Xj>P0m?Cd0QHF506=SH`0Y:BT0PH6106YZJP0n?Sh0J6QX07Ee
M@18B4P0A4A40410@00c<c<0;Rh^02d];@0d=3@0CTi>08>3P`1CDe<0?clo03De=@0h>3P0PX:207al
O01_Kfl0VIVI0:>SX`1IFET0_;bl09ZJVP1ADE40?3`l03hn?P1/K6`0J6QX08R8R01TI6@0M7Ad0451
@@0_;bl07alO01`L700G5aL201DE5@804Q8B00<05ADE01/K6`0L71`00P0J6QX0300M7Ad06QXJ01hN
7P0g=cL0IFEU04Y:BP0S8b<0@D5106MWI`1PH600DE5A01TI6@806QXJ01X08B4Q03`l?023Ph<0YjNW
06e]K@1@D500FEUI05eMG@1/K6`0PH610:ZZZP2IVIT0MGEe06UYJ@1mOGd0_Kfm09fMW@1hN7P0Kfm_
05UIF@1hN7P0YjNW06UYJ@1aLG40`/;2028R8PD071`L04X07AdM01`L700M7Ad0;bl_05IFEP2DU9@0
X:2P0<K6aP2TY:@0`/;20:j^[P20P800HF5Q05UIF@1]KFd0Ogmo08f=S@1XJ6P0CDe=04i>CP1TI6@0
_;bl07inOP1iNGT0IFEU06UYJ@1dM7@0Cdm?02`/;00M7Ad07QhN01dM7@0f=SH0Kfm_05iNGP1JFUX0
>SXj0451@@2ZZZX0Ng]k04Y:BP1SHf<0XZ:R0:JVYP2;Rh/0KVi^06IVIP13@d<0A4A404I6AP0m?Cd0
Hf=S08Z:RP13@d<0<S8b03@d=00n?Sh0?clo0492@P1ZJVX0Kfm_06MWI`0e=CD07QhN05MGE`1MGEd0
Jf][03/k>`0N7Qh07alO020P800f=SH0BTY:0410@0808R8R03d0=3@d08J6QP1hN7P0P82007AdM01V
IVH0BDU903Hf=P0b<S80;Bd]038b<P15ADD0FUYJ06a/K01jNWX0`/;20<k>cP2GUiL0/;2`0:b/[03=
cLd0`<3007emO@0d=3@09RHV03Xj>P2ATI40ZJVY08b<S01cLg<0LW9b08^;R`20P800HF5Q020P800O
7al092@T02HV9P0Y:BT0Cdm?05iNGP28R8P0Vi^K05=CD`1ZJVX0CTi>09VIV@1SHf<0F5QH02l_;`1W
IfL0H61P01/K6`0a<C40VYZJ0:b/[02f][H0/K6a06IVIP2FUYH0d=3@0080a<C401X0g=cL0=3@d01h
N7P0BDU903`l?01>CTh0E5AD05MGE`15ADD07AdM01`L700J6QX09BDU02XZ:P22PX80Zj^[08J6QP1W
IfL0L71`0<O7a`3Cdm<0a<C40;>c/`1QHF40BTY:04E5A@80AdM702`0CDe=065QH@2NWYh0e=CD0<k>
cP3AdM40G5aL05]KF`1nOWh0Ph>309JFUP2QXJ40Q8B4069RHP34a<@0d=3@0=CDe03=cLd0TY:B07Yj
NP1TI6@0C4a<04=3@`0o?cl0@41003Lg=`0k>c/0Cdm?075aL@2IVIT0ZZZZ0;bl_02DU9@0DU9B09>C
T`2g]kL0dm?C0=;BdP3?cll0];Bd03De=@0Y:BT0;bl_01hN7P8071`L0100:2PX05IFEP3Jf]X0dm?C
0;Fe]@2[Zj/0BTY:03Hf=P0Y:BT0<C4a03/k>`17AdL0UYJF0<k>cP35aLD0LG5a0P1oOgl2ooooo`00
05h0N7Qh06e]K@17AdL0M7Ad04Y:BP1WIfL0OGem0410@00a<C40C4a<04=3@`0M7Ad0BDU903`l?01c
Lg<0<c<c03Ti>@0f=SH07AdM071`L01BDU806a/K055AD@0V9RH05ADE0410@01?Cdl092@T03De=@13
@d<0:BTY05aLG01GEeL0JVYZ07UiN@1<C4`0820P038b<P1YJFT0=cLg04=3@`0V9RH0BDU901lO7`1<
C4`0GUiN02XZ:P0M7Ad0D51@04U9B@1@D500=CDe02<S8`11@D40GEeM075aL@1ADE40<c<c05iNGP1:
BTX0;Bd]030`<00h>3P0<S8b03hn?P1:BTX0JVYZ0492@P16ATH0Ng]k07=cL`0h>3P0R8R807=cL`0M
7Ad0E5AD0820P00W9bL0JFUY05MGE`10@400Q8B403Ti>@12@T80LG5a05=CD`0/;2`0>SXj06e]K@0a
<C40@4100;jn_P2NWYh0FUYJ0P19BDT0300i>CT08b<S04Q8B020P800JFUY03Ti>@1:BTX0LW9b03lo
?`0c<c<0CDe=079bLP80E5AD07X0FUYJ03`l?01HF5P0?clo07=cL`1?Cdl0?3`l04U9B@1FEUH0@T92
07alO02FUYH0BDU905EEE@1RHV80BTY:08>3P`1SHf<0?Shn0861P@0c<c<0Cdm?08Z:RP1lO7`0B4Q8
05mOG`19BDT0@T9209>CT`1ZJVX0FEUI02/[:`0n?Sh0U9BD061PH01SHf<0@41002<S8`26QXH0X:2P
07IfMP1EEED0Lg=c03@d=00I6AT0E5AD08n?S`1EEED0LG5a08V9R@0g=cL0CTi>08>3P`1NGUh0OWin
0:6QX@12@T80=3@d06e]K@1WIfL0K6a/05aLG014A4@0De=C08>3P`28R8P0DE5A06EUI@24Q8@0N7Qh
071`L02@T900`L7108V9R@1:BTX0P82009RHV01hN7P0B4Q806=SH`2:RXX0C4a<08N7Q`2c/k<0LW9b
05IFEP2:RXX0VYZJ03hn?P1VIVH0IFEU028R8P1;Bd/0N7Qh03Xj>P2FUYH0Ph>304E5A@1/K6`0NGUi
03<c<`2?Shl0M7Ad05IFEP28R8P0PX:203<c<`1nOWh0/;2`0492@P1XJ6P0Lg=c02PX:00[:b/0[:b/
08B4Q01FEUH0NWYj09BDU01iNGT0FUYJ03dm?@80K6a/00l0GemO03Xj>P1NGUh0K6a/051@D01lO7`0
KFe]05MGE`1LG5`0Vi^K08b<S01;Bd/0MWIf08:2PP1HF5P00P1:BTX0401SHf<0YZJV06i^KP1CDe<0
KFe]06ATI01?Cdl0[Zj^0:2PX023Ph<0JVYZ06QXJ01KFe/0GEeM06IVIP1kNg/204Q8B01D05MGE`0l
?3`0Bd];09FEU@2=SHd0Ng]k024Q8@12@T80H61P06=SH`1hN7P0U9BD0<G5a@2>SXh0B4Q80<;2`P1^
KVh0;Bd]051@D01>CTh0JFUY03`l?00g=cL0LG5a05eMG@0_;bl0IFEU07emO@1RHV80LW9b0:6QX@1B
DU80X:2P05ADE01^KVh0RXZ:0<O7a`2HV9P0O7al02XZ:P0h>3P0@41008J6QP1jNWX0?Cdm07UiN@1f
MWH0FEUI06UYJ@1ZJVX0?3`l03Xj>P0n?Sh0?clo034a<@0Z:RX0:BTY03dm?@1iNGT0BDU902h^;P0Z
:RX0LW9b051@D00O7al0>SXj075aL@1^KVh0[:b/0=WIf@3MgMd0dM7A0:j^[P2ATI40Ogmo07QhN02B
TY80XZ:R09:BTP1OGel09RHV01`L700F5QH05aLG1@0E5AD0600G5aL06ATI01XJ6P0I6AT05aLG01XJ
6P0N7Qh09bLW061PH01]KFd0=CDe05]KF`1[Jf/0NGUi02TY:@0F5QH06ATI02@T900_;bl0<c<c061P
H00a<C408b<S02/[:`80;Bd]01L0@D51051@D01]KFd0MgMg02<S8`0K6a/0;Bd]0861P@2ZZZX0Ti>C
09BDU02>SXh0W9bL0;Vi^@2HV9P0XZ:R0=[JfP1/K6`0HF5Q05UIF@0k>c/0=SHf02XZ:P0202HV9P07
02LW9`0Y:BT0;bl_04E5A@2IVIT0_kno0<[:bP020<g=c@0?0=OGe`3?cll0ZJVY09>CT`25QHD0K6a/
05]KF`26QXH0NGUi07QhN022PX80[jn_07IfMP1kNg/0SHf=0080RXZ:00@0IFEU03Xj>P0o?cl0CTi>
0P1SHf<03`20P800D51@04A4A00n?Sh0a<C40;jn_P1hN7P0EEEE07moO`33`l<0aLG509fMW@1fMWH0
HV9R03Ph>00202l_;`1R08J6QP23Ph<0=cLg03@d=00_;bl0<c<c04A4A01BDU80YZJV08B4Q01>CTh0
PH6108R8R02XZ:P0Fe]K09>CT`1`L700;bl_028R8P0P8200=3@d05=CD`1LG5`08R8R03Xj>P1/K6`0
DE5A06MWI`1DE5@0?Cdm05QHF01ADE40C4a<05ADE01EEED0CDe=03Ti>@0l?3`0De=C08Z:RP2a/K40
QHF50;>c/`2JVYX0a<C40<_;b`32`/80[Jf]07MgM`1ADE40O7al04Y:BP1DE5@0QhN706ATI01CDe<0
JFUY08N7Q`18B4P071`L024Q8@0U9BD09RHV02DU9@1<C4`0F5QH05MGE`1PH600];Bd0<K6aP30`<00
[Zj^061PH01WIfL0:BTY07EeM@2GUiL0IfMW08F5Q@1@D500Ogmo07EeM@1^KVh0Ogmo06i^KP2@T900
VYZJ09fMW@30`<00bl_;03lo?`0c<c<0?clo04e=C@0`<300?Shn06UYJ@13@d<201dM7@0^02PX:00m
?Cd0Q8B40;Ng]`2CTi<0AdM708^;R`34a<@0cLg=09NGU`1PH600Rh^;09JFUP1[Jf/0B4Q804U9B@1?
Cdl0MWIf0;Zj^P33`l<0_[jn0;fm_@2=SHd0LG5a06][J`2;Rh/0OGem08Z:RP32`/80/k>c0:j^[P1`
L700Ogmo0;bl_02OWil0EUIF07EeM@1;Bd/0?clo04I6AP1LG5`0U9BD0;6a/@39bLT0b<S80;>c/`80
SHf=0200YJFU09NGU`2/[:`0/k>c0:^[Z`31`L40d];B0<S8b01kNg/0>c/k02<S8`0L71`06a/K01TI
6@0O7al08B4Q0<W9b@2[Zj/0]kNg08R8R00`<300:b/[02XZ:P0d=3@0>3Ph04U9B@2NWYh0Y:BT0;Jf
]P1NGUh0O7al06i^KP;ooooo0000H`2CTi<0OWin04];B`27QhL0D51@06ATI02@T900IVIV03hn?P1C
De<0CDe=02LW9`1KFe/0ADE508V9R@11@D40@41005YJFP0^;Rh0M7Ad06ATI00P8200De=C04=3@`0S
8b<0<C4a04U9B@0T92@0BDU903/k>`0d=3@0EEEE05ADE01ZJVX0P82003Xj>P0L71`0>CTi06EUI@0j
>SX0De=C02/[:`1<C4`06ATI04I6AP2<S8`0B4Q802/[:`11@D40:b/[055AD@17AdL0;bl_04];B`1]
KFd0CDe=02/[:`0e=CD0IfMW06YZJP15ADD0<C4a04A4A00M7Ad0;2`/03/k>`1HF5P0>CTi03Xj>P1c
Lg<0Bd];02<S8`1FEUH0GEeM01dM7@13@d<0F5QH01XJ6P15ADD0DU9B03Lg=`1]KFd06ATI02l_;`1:
BTX0CDe=0410@00j>SX0VIVI05ADE00l?3`0YJFU09BDU013@d<0CTi>08:2PP2IVIT0?clo03Hf=P02
04M7A`0V03De=@1]KFd0WIfM08R8R02:RXX0/K6a0<;2`P0o?cl0CTi>08^;R`1GEeL0FEUI01dM7@1<
C4`0RHV905=CD`1KFe/0@41001lO7`16ATH0LG5a079bLP1JFUX0?3`l024Q8@1EEED0OGem04Q8B024
Q8@0;bl_02XZ:P1;Bd/0J6QX04];B`1OGel0I6AT03Ti>@1`L70206ATI02X05aLG00g=cL0VIVI061P
H01FEUH0H61P05UIF@2BTY80UiNG07AdM01LG5`0PX:205EEE@0/;2`0EUIF08V9R@0g=cL0H61P0:f]
[@1JFUX0N7Qh0:BTY01OGel0YjNW0<;2`P2:RXX0E5AD05mOG`1iNGT0IfMW07QhN021PH40GemO08F5
Q@23Ph<0GemO059BDP2<S8`0Shn?08B4Q02a/K40_;bl07moO`0o?cl0Shn?0:f][@1lO7`0Bd];08:2
PP2PX:00?3`l08B4Q02KVi/0JVYZ051@D02=SHd0WIfM04e=C@1oOgl0Kfm_02PX:012@T80O7al03lo
?`2WYjL0Ph>304I6AP1_Kfl0HF5Q03/k>`2CTi<0OGem059BDP2=SHd0PH61028R8P1EEED0V9RH02PX
:01fMWH0OWin03<c<`0Y:BT0YjNW075aL@1;Bd/0CDe=055AD@1BDU80@d=303Ph>020P800I6AT05]K
F`0^;Rh0?Cdm05MGE`14A4@0MGEe05=CD`0f=SH0EEEE08J6QP1cLg<0@410075aL@23Ph<0?Cdm030`
<01IFET0NGUi08N7Q`1NGUh0CTi>05aLG01IFET0>c/k06][J`1RHV80JFUY05mOG`1YJFT0?clo03dm
?@13@d<0FUYJ04A4A01BDU80F5QH05UIF@0l?3`0G5aL071`L01_Kfl07QhN03dm?@1QHF40AdM70451
@@19BDT0NGUi07]kN`19BDT0Xj>S06QXJ00l?3`0FUYJ05=CD`1oOgl0CTi>02l_;`1WIfL0D51@034a
<@26QXH0L71`05UIF@1WIfL0ZJVY05UIF@2JVYX0FEUI04m?C`1oOgl0[jn_09bLW022PX80=cLg0P0h
>3P0;@1WIfL0>c/k04a<C02BTY80Ogmo05eMG@1KFe/0GemO04=3@`0d=3@0;bl_03Ph>013@d<0;bl_
02<S8`1HF5P0EUIF03Lg=`0T92@0F5QH04Y:BP0H61P06a/K03De=@1]KFd0DU9B07QhN03>c/h0][Jf
0:2PX02JVYX0WIfM0:b/[039bLT0e=CD0:NWY`1mOGd0Jf][02h^;P0J6QX05ADE01LG5`0I6AT06a/K
01LG5`0301DE5@0301`L700J6QX071`L00807AdM04H07QhN01dM7@14A4@0[Zj^0:2PX02JVYX0V9RH
0<?3``1YJFT071`L03Lg=`0m?Cd0=cLg04E5A@0H61P05ADE01@D500G5aL07alO02LW9`1;Bd/0A4A4
03<c<`1;Bd/0B4Q8024Q8@1EEED0JFUY04m?C`1ZJVX0MgMg06MWI`20P800S8b<05IFEP2JVYX0f][J
0<;2`P1LG5`0<C4a03dm?@1QHF40Q8B409bLW02NWYh0[jn_0<k>cP2QXJ40EeMG0<30`03:b/X0c<c<
0;Fe]@2UYJD0^KVi0=OGe`3MgMd0fMWI0;Vi^@2TY:@0YZJV07]kN`1PH6008b<S02@T901PH600ZZZZ
0;no_`2>SXh0R8R80P22PX80E02?Shl0PX:2069RHP23Ph<0Rh^;0:ZZZP2JVYX0JVYZ05MGE`2o_kl0
XZ:R09^KV`1JFUX0Ph>30;2`/02j^[X0_[jn0;>c/`27QhL0LW9b06a/K02ATI40clo?07IfMP0[:b/0
;bl_038b<P0[:b/0?clo055AD@2SXj<0RXZ:04];B`0o?cl0K6a/0<o?c`2=SHd0NWYj07UiN@18B4P0
AdM704U9B@1ADE40KVi^08^;R`1UIFD0G5aL04m?C`1XJ6P0FUYJ030`<00V9RH0?Shn0410@00U9BD0
:2PX030`<00k>c/0=CDe02TY:@1FEUH0N7Qh06YZJP1jNWX0YjNW09nOW`2GUiL0`<3007IfMP1KFe/0
GEeM0:>SX`2MWId0@d=302`/;01NGUh0Lg=c055AD@1RHV80Q8B405iNGP0L71`07AdM028R8P809BDU
01<0<30`05iNGP18B4P0ATI605QHF02o_kl0HF5Q07AdM01[Jf/0ZJVY0:BTY03@d=00^k^k0<S8b02i
^KT0RXZ:05aLG01<C4`0FEUI0080NGUi04<0Jf][069RHP11@D40PX:20=?Cd`2VYZH0O7al06YZJP12
@T80>c/k03@d=01/K6`0UYJF04m?C`0W9bL0;Bd]06QXJ01NGUh0Kfm_075aL@14A4@0V9RH0;bl_02k
^k/0B4Q802d];@18B4P0QHF508:2PP1]KFd0WIfM0:j^[P2a/K40Ogmo06][J`2ATI40TY:B09JFUP2<
S8`0[Zj^0<30`02ZZZX0WIfM0;>c/`1UIFD0EUIF08j>SP1oOgl0KFe]09NGU`1]KFd0I6AT061PH02A
TI40^k^k0<S8b02o_kl0W9bL08N7Q`24Q8@0QXJ609JFUP2JVYX0^k^k0<_;b`3Hf=P0bLW90080W9bL
00D0_Kfm0:^[Z`2LW9`0NGUi02<S8`0301/K6`0B01lO7`0a<C40VYZJ06QXJ02<S8`0KVi^02`/;00Y
:BT0:2PX034a<@0g=cL0CDe=0:b/[02HV9P0^;Rh05EEE@1`L700@d=30_ooool0000<05YJFP1DE5@0
DU9B07QhN00a<C40>c/k05MGE`1:BTX0>c/k05EEE@0L71`06QXJ0P0k>c/0/P1GEeL05QHF02h^;P1>
CTh0;Rh^06IVIP0e=CD04A4A04U9B@14A4@09RHV02l_;`0l?3`04A4A020P800^;Rh0;Bd]05UIF@0Q
8B407QhN051@D01;Bd/08B4Q04];B`0l?3`05aLG0492@P0Z:RX0C4a<01TI6@0[:b/0AdM703Hf=P0a
<C40FUYJ0451@@12@T80=SHf02@T901OGel0PH6106IVIP1GEeL08B4Q04];B`1BDU80:RXZ04U9B@1h
N7P0Lg=c02h^;P0c<c<0BTY:02LW9`17AdL0SXj>09:BTP0o?cl0L71`04Y:BP0L71`0Bd];07alO00b
<S80CDe=0451@@0j>SX0S8b<069RHP0m?Cd0Hf=S05aLG00B4Q809bLW04m?C`1bLW80E5AD0<?3``37
alL0DE5A02DU9@12@T80De=C0410@00l?3`0E5AD0492@P0U9BD0<c<c05ADE01nOWh0E5AD0;Fe]@39
bLT0Kfm_03Lg=`1bLW80G5aL06QXJ01>CTh0GEeM07=cL`1ADE40EEEE08j>SP1`L700HV9R07=cL`1o
Ogl0Bd];08b<S018B4P0EEEE092@T019BDT0UiNG07IfMP17AdL0Bd];071`L01=CDd0Kfm_08f=S@1<
C4`0NGUi05mOG`1`L700Ph>304I6AP2KVi/0EUIF06EUI@23Ph<0I6AT092@T021PH40EUIF05]KF`2Z
ZZX0SHf=04Q8B01XJ6P0TI6A03De=@12@T80X:2P03lo?`20P800X:2P05ADE01QHF40QHF506UYJ@1S
Hf<0YjNW05iNGP17AdL0KVi^06ATI01aLG40WYjN06ATI01>CTh0LG5a0:BTY02:RXX0Rh^;0<K6aP33
`l<0R8R802TY:@1GEeL0UiNG04m?C`0b<S80I6AT07moO`1BDU8207=cL`1n05QHF019BDT0VIVI08N7
Q`0k>c/0Jf][05MGE`13@d<0MGEe05MGE`0l?3`0QXJ606QXJ00n?Sh0M7Ad075aL@0d=3@0PX:204M7
A`0i>CT0JFUY08Z:RP1;Bd/0B4Q808f=S@0Y:BT0B4Q806EUI@0];Bd0:b/[0;Bd]01aLG40J6QX06UY
J@1RHV80GemO04M7A`1=CDd0Ph>305eMG@1SHf<0;Rh^0492@P1OGel0C4a<07AdM01@D500CDe=04];
B`20P800LW9b03<c<`1[Jf/0M7Ad03Xj>P0o?cl0?Cdm055AD@2>SXh0H61P04a<C01PH600GUiN04=3
@`26QXH0RXZ:0820P019BDT0PH6106e]K@1GEeL0B4Q804e=C@1?Cdl0EUIF05EEE@1PH600BTY:06EU
I@1iNGT0Q8B402<S8`0o?cl0IFEU07inOP1DE5@0DE5A08>3P`2>SXh0FEUI09BDU01iNGT0C4a<069R
HP1LG5`0H61P0410@00V9RH0IfMW05QHF00e=CD0MgMg05EEE@16ATH0HF5Q09bLW01BDU80WYjN05MG
E`1PH600D51@092@T02CTi<0EUIF030`<00c<c<0=cLg07emO@1aLG40=cLg05ADE01ZJVX0=3@d04I6
AP1@D500Ng]k0P1cLg<05`1iNGT0QHF508^;R`2EUID0[Zj^09^KV`2:RXX0YZJV0;Rh^00Q8B40820P
038b<P0W9bL04a<C02LW9`1YJFT0OGem0;Bd]02DU9@0WYjN0::RXP2BTY80Q8B40080]KFe01l0V9RH
09FEU@1]KFd0>SXj028R8P0P82009BDU038b<P0Y:BT05aLG01TI6@0D51@05ADE01/K6`0L71`06a/K
01lO7`0[:b/0F5QH0:BTY02b/[80]kNg09jNWP2YZJT0JVYZ0::RXP1mOGd0@T9203Xj>P1@D5008R8R
00@05ADE00@051@D01DE5@0K6a/0Bd];0P19BDT01@1:BTX0Ph>309RHV01TI6@0C4a<0080@d=303<0
Q8B40<O7a`2:RXX0G5aL0;Fe]@20P800B4Q808Z:RP1kNg/0?Shn02DU9@0Q8B40:RXZ02d];@10@400
MWIf09bLW02o_kl0^;Rh0;Zj^P3@d=00]kNg0:FUY@2g]kL0]KFe0<c<c03Hf=P0clo?0<S8b011@D40
820P051@D00X:2P071`L028R8P1^KVh0alO70;Fe]@1fMWH0I6AT06a/K01eMGD0UiNG0:RXZ027QhL0
PH6109fMW@1YJFT0LW9b0:6QX@3;bl/00P2PX:00L@2JVYX0Ogmo09BDU02=SHd0];Bd0<30`03IfMT0
b/[:0<;2`P2BTY80Shn?0;6a/@17AdL0:b/[02`/;00];Bd0<S8b0451@@2?Shl0LW9b05UIF@1CDe<0
AdM709bLW02h^;P0R8R803hn?P0U9BD07alO02LW9`1VIVH0_;bl0=CDe02TY:@0IVIV065QH@1jNWX0
@41002`/;00[:b/0GEeM04I6AP0W9bL092@T02DU9@0^;Rh09RHV04i>CP1@D500A4A404E5A@1SHf<0
PX:20;6a/@2:RXX0]KFe07YjNP1KFe/0FEUI06e]K@2c/k<0N7Qh05=CD`0k>c/0EUIF055AD@2NWYh0
Lg=c05ADE00[:b/071`L028R8P0U9BD07AdM01`L700[:b/0ATI603/k>`16ATH0UiNG06m_K`29RHT0
VIVI0:RXZ026QXH0Zj^[0<C4a03Cdm<0d];B08^;R`1YJFT0J6QX05QHF01MGEd0IfMW07QhN01>CTh0
NWYj0;Zj^P2/[:`0Ti>C07alO02LW9`0WYjN0:FUY@2SXj<0c<c<0=KFeP3Cdm<0`<300:n_[`2<S8`0
LG5a00<0DE5A01d0^KVi0:JVYP2OWil0;2`/02HV9P0^;Rh0@D5105mOG`21PH40TI6A06=SH`15ADD0
>SXj059BDP1^KVh0MWIf0:BTY01QHF40Z:RX09ZJVP2;Rh/0V9RH08J6QP1OGel0K6a/065QH@1YJFT0
PX:207moO`0208^;R`0P0=SHf03>c/h0[Jf]08J6QP25QHD0QXJ607MgM`1eMGD0IfMW05MGE`0k>c/0
?clo05eMG@2j^[X0aLG509jNWP1]KFd0DU9B06UYJ@1XJ6P0OGem06i^KP1KFe/0;bl_01PH600I6AT0
Kfm_05=CD`1WIfL0YJFU04];B`0Z:RX202h^;P0903Lg=`0e=CD0OGem09JFUP2QXJ40a<C407]kN`1I
FET0>3Ph00;ooooo0000n01ZJVX0@D5103dm?@1aLG40CTi>04=3@`1MGEd08b<S02/[:`1;Bd/0De=C
02TY:@0S8b<0;2`/06UYJ@0e=CD092@T034a<@0G5aL0F5QH04Y:BP0K6a/0ADE502LW9`0G5aL0<30`
05ADE00/;2`09RHV01@D500B4Q80EeMG04M7A`10@400P8200451@@092@T0<C4a05UIF@0a<C40?Cdm
00l?3`16ATH0=CDe04A4A01WIfL09BDU01LG5`0l?3`0GEeM059BDP0N7Qh02`/;024Q8@11@D40Hf=S
06IVIP0W9bL0Hf=S03lo?`0C4a<07QhN0451@@14A4@0;2`/0492@P0m?Cd09bLW01dM7@1:BTX0M7Ad
03hn?P1TI6@0Jf][028R8P0X:2P0JFUY03Xj>P1?Cdl0FEUI01lO7`1`L700EEEE0492@P1UIFD0Jf][
04i>CP0Q8B40EEEE05QHF00b<S80Shn?0;2`/021PH40B4Q805aLG01:BTX0?3`l0410@01LG5`0FEUI
05IFEP1<C4`0GUiN096AT@1DE5@0_[jn0<G5a@1mOGd0@T9206YZJP1ADE40MWIf05iNGP1WIfL0E5AD
04i>CP1^KVh0TI6A06a/K01YJFT0PH6106e]K@1CDe<0T92@04m?C`1@D500KFe]03dm?@2ATI40JFUY
04e=C@1JFUX0IfMW03Ph>01>CTh0NWYj04U9B@2BTY80E5AD05eMG@1UIFD0?Shn09RHV01ADE40A4A4
06MWI`1BDU80S8b<0;:b/P1OGel0?clo071`L01mOGd09RHV05QHF029RHT0IFEU0410@02YZJT0?clo
065QH@1oOgl0J6QX07=cL`1nOWh0Cdm?03/k>`22PX80Kfm_04e=C@1QHF40;Rh^03lo?`1fMWH0IVIV
04];B`0f=SH0YjNW04Y:BP15ADD0OWin09bLW01eMGD0A4A406][J`2FUYH0Ph>304I6AP1UIFD0Rh^;
05aLG01gMgL0LG5a06m_K`10@400WYjN09bLW010@400EEEE051@D00U9BD0>3Ph06=SH`0c<c<0Ph>3
09NGU`1>CTh0G5aL09>CT`0g=cL0LG5a07QhN01FEUH0LG5a09bLW01FEUH0AdM708N7Q`1DE5@0CTi>
07MgM`0m?Cd09bLW0;>c/`1YJFT0S8b<06][J`1]KFd0Fe]K06EUI@1IFET0TY:B04m?C`1lO7`0?clo
03Hf=P1bLW80IfMW07=cL`1VIVH0GUiN05EEE@29RHT0OWin0410@01VIVH0Jf][0P1NGUh0N`0l?3`0
De=C08>3P`1bLW80D51@06MWI`1XJ6P0?Cdm08n?S`2:RXX0IfMW0492@P2PX:00NWYj06ATI01<C4`0
D51@05=CD`1iNGT0Lg=c069RHP12@T80I6AT07MgM`1YJFT0>CTi05mOG`2LW9`0NWYj05ADE01<C4`0
MGEe08>3P`1CDe<0TI6A08n?S`1IFET0HF5Q05QHF01SHf<0?Shn03/k>`28R8P0Ph>303dm?@1fMWH0
DU9B02HV9P17AdL0PX:205EEE@27QhL0KFe]06QXJ01:BTX0IVIV07AdM01@D500=cLg04Y:BP1<C4`0
P820061PH00h>3P0GUiN07EeM@0c<c<0?clo06EUI@1YJFT0F5QH059BDP1CDe<0EUIF055AD@1LG5`0
NGUi05MGE`1PH600PH610:b/[01WIfL0>3Ph030`<00F5QH04A4A05YJFP1[Jf/0EUIF09nOW`1[Jf/0
C4a<07AdM026QXH0MGEe07]kN`2OWil0XZ:R0:JVYP2@T900W9bL07=cL`10@400=CDe02`/;00V9RH0
7alO01XJ6P0E5AD04a<C01TI6@0K6a/0>SXj05iNGP1kNg/0NWYj07alO020P800SXj>065QH@2=SHd0
TY:B07UiN@020:ZZZP0409^KV`0];Bd05ADE01<C4`D05ADE01L05aLG01lO7`1MGEd0/k>c0;Jf]P2e
]KD0TY:B08B4Q01<C4`0AdM704E5A@1gMgL0OGem04a<C028R8P0OWin04E5A@0g=cL0;2`/03Hf=P1X
J6P0Lg=c03`l?00202PX:00[061PH02SXj<0_kno09nOW`2QXJ40V9RH0=KFeP2b/[80[jn_079bLP1R
HV80Ng]k0:>SX`2f][H0[jn_03Ph>00L71`092@T05]KF`0O7al071`L02DU9@2HV9P0Lg=c03Ti>@0j
>SX0?Shn04U9B@2^[Zh0XZ:R096AT@2:RXX0F5QH04m?C`1iNGT0b/[:0<c<c02SXj<0MGEe07alO02j
^[X0[jn_0<30`0020<[:bP260=3@d02OWil0DU9B0451@@0o?cl0KVi^09>CT`10@400;2`/030`<00[
:b/0@41009>CT`1cLg<0CTi>07IfMP25QHD0Hf=S0;Fe]@2SXj<0?Shn055AD@1`L700Kfm_0861P@3K
fm/0V9RH0;Fe]@20P800R8R808Z:RP0[:b/0:2PX0410@01JFUX0@d=302@T900U9BD0;Rh^02DU9@1C
De<0EEEE04Y:BP0T92@08b<S03hn?P1BDU80UYJF0:n_[`1UIFD0>c/k03Hf=P0e=CD0C4a<0:f][@2N
WYh0Fe]K06YZJP1lO7`0U9BD04e=C@1CDe<0CTi>04I6AP0M7Ad071`L01/K6`0J6QX06ATI01/K6`1E
EED0H61P06YZJP2WYjL0/[:b08j>SP2<S8`0Ti>C0:ZZZP2f][H0b/[:0=GEe@28R8P0EUIF051@D01>
CTh0I6AT061PH01aLG40Rh^;09FEU@2WYjL0R8R808N7Q`2][Jd0RHV906a/K01PH600JFUY0861P@2U
YJD0N7Qh06m_K`2PX:00a/K60=WIf@3De=@0a/K60;Vi^@3@d=00_Kfm06EUI@2PX:00;2`/02<S8`0X
:2P0;Rh^03dm?@21PH40EEEE04A4A00n?Sh0CDe=0820P01MGEd0L71`05eMG@1[Jf/0JVYZ08R8R02=
SHd0X:2P05iNGP1[Jf/2069RHP0`04];B`1FEUH0G5aL07AdM02n_[h0d=3@08F5Q@1eMGD0J6QX04I6
AP0i>CT0<S8b03<c<`0f=SH0=3@d03<c<`1>CTh0QhN70;2`/02IVIT0ZZZZ06=SH`0e=CD0C4a<059B
DP1HF5P0>CTi04M7A`1JFUX0Hf=S08:2PP25QHD0C4a<07MgM`2/[:`0@41003De=@0b<S80;2`/02d]
;@0e=CD0][Jf08B4Q02XZ:P0D51@05=CD`2e]KD0SXj>0_ooool0002U06UYJ@1aLG40B4Q807moO`1G
EeL0Bd];07MgM`1GEeL092@T03Xj>P1LG5`0:BTY02LW9`0T92@0De=C051@D00[:b/0@D51014A4@0_
;bl0Fe]K02/[:`1MGEd0<C4a010@400B4Q80<C4a028R8P0X:2P0=cLg01/K6`1>CTh0Bd];0410@029
RHT0>c/k01<C4`0W9bL0:RXZ01hN7P0e=CD092@T038b<P0^;Rh0ADE506i^KP12@T809RHV03lo?`1S
Hf<0?clo059BDP0k>c/0?Shn059BDP1cLg<0Kfm_02h^;P1_Kfl0=3@d028R8P0X:2P0C4a<04M7A`0_
;bl0BTY:04m?C`1LG5`0<30`06MWI`2:RXX0B4Q803lo?`2ATI40@T9202XZ:P1_Kfl0@D5105eMG@1^
KVh0:RXZ07moO`1MGEd0>SXj06QXJ01YJFT0De=C020P801DE5@0JFUY059BDP25QHD0]kNg0820P01:
BTX0FUYJ05UIF@0j>SX0ADE507QhN02FUYH0F5QH04i>CP1@D500N7Qh030`<02PX:00YjNW07QhN011
@D40LG5a04Y:BP1DE5@0De=C06e]K@1/K6`0ADE5055AD@1VIVH0De=C06IVIP2RXZ80L71`0451@@1k
Ng/0BDU905aLG02:RXX0?clo08R8R014A4@0@T9206=SH`1lO7`0D51@05YJFP1LG5`0<C4a07AdM01n
OWh0EeMG03Ti>@0^;Rh0QHF506e]K@19BDT0EeMG03<c<`1CDe<0UiNG07UiN@1>CTh0P82007alO00]
;Bd0GemO09FEU@1DE5@0>c/k0:BTY01_Kfl0J6QX08:2PP23Ph<0PX:20080Kfm_08X0BDU907IfMP1U
IFD0E5AD06i^KP26QXH0HF5Q08B4Q01bLW80HF5Q03Ti>@2DU9@0TI6A07MgM`2l_;`0_kno08N7Q`12
@T80Fe]K0861P@26QXH0C4a<06QXJ029RHT0Jf][061PH01eMGD0NGUi04I6AP2JVYX0Xj>S05QHF01S
Hf<0LG5a03<c<`1?Cdl0NWYj03Ti>@1lO7`0XJ6Q059BDP1FEUH0Ph>302l_;`1QHF40E5AD051@D01[
Jf/0S8b<04m?C`15ADD0U9BD06QXJ018B4P0L71`03lo?`0a<C40_;bl0:VYZ@2CTi<0NGUi08:2PP1W
IfL0NGUi03lo?`2BTY80OGem09jNWP1DE5@0>3Ph071`L01GEeL0N7Qh0820P01OGel0E5AD0::RXP2?
Shl0GUiN08Z:RP21PH40O7al05iNGP0k>c/0BTY:08>3P`1NGUh0ATI606e]K@1eMGD0CTi>08^;R`1o
Ogl0Hf=S04A4A02MWId0NGUi05QHF01@D500ATI603Hf=P1BDU80H61P05ADE00o?cl0L71`08V9R@1/
K6`0<30`03@d=01LG5`0LW9b05ADE01>CTh0LW9b061PH00b<S80EeMG08J6QP1>CTh0HF5Q06EUI@1?
Cdl08b<S01`L701KFe/0Hf=S02PX:01ZJVX0BTY:03@d=01FEUH0MgMg051@D01nOWh0TY:B06EUI@1?
Cdl206][J`0n02TY:@0M7Ad0;2`/0492@P1eMGD0H61P03Ti>@1BDU80Q8B403Hf=P12@T80Q8B405]K
F`1FEUH0DU9B04I6AP10@400?Cdm08N7Q`1dM7@0H61P03hn?P0j>SX0?Shn07moO`25QHD0=cLg01DE
5@0Z:RX0N7Qh03dm?@14A4@0I6AT03Lg=`0];Bd08B4Q03@d=01MGEd0OWin0;6a/@2JVYX0SXj>0:b/
[01/K6`0GemO07EeM@1YJFT0EeMG05EEE@1@D500=SHf02l_;`0/;2`0<30`05MGE`1/K6`0H61P04];
B`1?Cdl0Fe]K06UYJ@2^[Zh209nOW`090;jn_P1oOgl0OWin0=CDe024Q8@0820P014A4@0D51@04a<C
00805ADE0P0F5QH06`0D51@05ADE01lO7`2?Shl0De=C05aLG028R8P0Z:RX092@T01DE5@0BTY:05UI
F@1LG5`0UIFE06EUI@0W9bL09RHV02l_;`0i>CT0?Cdm03Ph>00o?cl0KFe]096AT@2a/K40clo?0:BT
Y00208Z:RP1K08R8R02?Shl0f=SH0<;2`P27QhL0DE5A051@D01FEUH0DE5A09jNWP26QXH0NGUi028R
8P0L71`0EEEE03Lg=`0K6a/071`L05]KF`1]KFd0FEUI03<c<`0_;bl0=cLg08J6QP2VYZH0U9BD08N7
Q`1NGUh0KFe]09fMW@2_[jl0R8R805UIF@12@T80=CDe03/k>`23Ph<0UiNG0:FUY@2^[Zh0ZZZZ079b
LP1BDU80=cLg038b<P0l?3`0QXJ60:f][@1WIfL0<S8b03Lg=`1LG5`0^;Rh0:6QX@1eMGD0Ogmo09:B
TP1fMWH0YJFU0<O7a`2e]KD0PH6106MWI`1GEeL0UYJF08b<S02JVYX0M7Ad0;Ng]`2EUID0Hf=S03`l
?00_;bl0Cdm?05=CD`0o?cl092@T01/K6`0O7al0EUIF05]KF`18B4P08R8R01lO7`0N7Qh0<30`04M7
A`1mOGd0MWIf03/k>`0201dM7@2401hN7P0a<C40De=C09^KV`1BDU80@41005]KF`1UIFD0DU9B04M7
A`1PH600EEEE02l_;`0L71`0820P02d];@11@D40BDU904I6AP1XJ6P0IFEU071`L02j^[X0e=CD0=7A
d@32`/80alO70<30`02CTi<0b/[:061PH00k>c/0;Rh^02d];@0d=3@0CTi>061PH02YZJT0PX:206m_
K`1NGUh0IfMW08b<S02YZJT0EEEE055AD@1NGUh0G5aL08>3P`1gMgL0Jf][0;fm_@3Fe]H0fMWI0<C4
a02i^KT0aLG50>3Ph02n_[h0UIFE0<[:bP1ZJVX0@D5103@d=00`<300@41007MgM`1mOGd0LW9b06MW
I`2:RXX0SXj>0::RXP1mOGd0Cdm?05iNGP1]KFd0SHf=0::RXP1hN7P0FUYJ07EeM@1:BTX0?Shn03/k
>`11@D40DU9B06a/K02n_[h0a<C406EUI@0^;Rh09RHV02DU9@0Z:RX0;bl_03De=@0c<c<0<S8b04m?
C`1TI6@0MWIf0;6a/@2LW9`0B4Q8055AD@1;Bd/0GEeM04i>CP0i>CT0=SHf03Lg=`13@d<0Bd];07Qh
N02ATI40PX:209>CT`2ZZZX0>CTi02/[:`0X:2P0:RXZ038b<P1jNWX0[Jf]09>CT`1]KFd0>CTi07em
O@2QXJ40S8b<0_ooool0000<071`L02ATI40CDe=09VIV@1KFe/0Bd];07emO@1jNWX0=CDe04Q8B01f
MWH0=3@d0P16ATH0o`20P800HV9R02/[:`1BDU80;Bd]03lo?`1gMgL0=3@d059BDP15ADD0=SHf02XZ
:P0i>CT0;Bd]02l_;`0n?Sh09BDU06MWI`1NGUh0?clo08n?S`1LG5`0:BTY03lo?`13@d<0;Bd]03Lg
=`11@D40=3@d04E5A@0b<S80RHV9069RHP0Y:BT0>SXj06ATI010@400MGEe05eMG@12@T80FUYJ06e]
K@1KFe/0<C4a08>3P`1RHV80ATI602l_;`1GEeL0BTY:02`/;01>CTh0De=C05iNGP0`<300KFe]07]k
N`0Y:BT0:2PX08b<S01=CDd08b<S05iNGP0b<S80EUIF06e]K@0];Bd0PX:204U9B@0a<C40IFEU07Ad
M00c<c<09bLW06UYJ@26QXH0L71`05aLG03:b/X0OWin03Xj>P1eMGD0Vi^K05IFEP0i>CT0IFEU065Q
H@1ADE40EeMG07inOP2RXZ80CDe=0<30`02XZ:P0OGem034a<@1gMgL0IVIV04i>CP0[:b/0BTY:0::R
XP1IFET0D51@05]KF`0a<C40?3`l06IVIP24Q8@0CTi>055AD@0R8R80@d=308^;R`11@D40QHF505]K
F`0m?Cd0B4Q806QXJ01TI6@0FEUI07MgM`1BDU80MWIf09NGU`1ADE40MGEe04M7A`1]KFd0L71`04a<
C01VIVH0NGUi04i>CP2DU9@0FUYJ04Y:BP27QhL0Kfm_02d];@1UIFD0V9RH0492@P0b<S80Ti>C06m_
K`1/K6`0Ng]k08b<S02>SXh0WIfM08f=S@1:BTX0QhN707]kN`19BDT0Jf][08f=S@1MGEd0MGEe08F5
Q@1gMgL0@d=309bLW02:RXX0KFe]0:n_[`32`/80Ph>304];B`1IFET0X:2P08n?S`1@D500Hf=S08:2
PP1JFUX0PH610:n_[`2JVYX0ATI608Z:RP2MWId0EUIF071`L01jNWX0>SXj04Y:BP1dM7@0>SXj07Ui
N@2EUID0CDe=05UIF@1/K6`0?3`l07UiN@1^KVh0DE5A06][J`29RHT0<c<c04M7A`25QHD0GUiN0410
@01_Kfl0:RXZ01lO7`1[Jf/0De=C07QhN01dM7@0YJFU079bLP1BDU809bLW05=CD`12@T80NWYj03hn
?P0b<S80Fe]K03Xj>P16ATH0EUIF04m?C`1QHF40YZJV07AdM00[:b/0DU9B05iNGP1;Bd/0@D5103De
=@1>CTh0NGUi06][J`10@400F5QH07QhN015ADD0SHf=09JFUP1nOWh0ADE508:2PP1MGEd0Cdm?05AD
E01SHf<0EUIF05QHF000B01FEUH0Jf][0451@@1KFe/0IFEU07EeM@0h>3P0?3`l06=SH`1ADE40@D51
06MWI`25QHD0MGEe04Q8B00h>3P0OWin02d];@1EEED0IFEU05]KF`13@d<0820P05mOG`1]KFd07AdM
05eMG@1ZJVX0ATI604m?C`1^KVh0;bl_07YjNP1gMgL0IfMW05ADE022PX80NWYj04];B`0W9bL0;2`/
03Xj>P1lO7`0N7Qh03<c<`14A4@0Ogmo02l_;`0c<c<0MWIf04a<C017AdL0Cdm?06e]K@1PH600F5QH
07YjNP1FEUH0Jf][04i>CP13@d<0CTi>03<c<`1:BTX0NWYj08>3P`2RXZ80EeMG04I6AP1fMWH0De=C
02<S8`80:b/[0P0M7Ad08P0a<C40YJFU0:f][@2_[jl0VIVI096AT@1dM7@0J6QX06e]K@1nOWh0MGEe
06QXJ01UIFD0GEeM05ADE01/K6`0G5aL05mOG`1JFUX0F5QH05UIF@1BDU80Bd];07inOP2ZZZX0VYZJ
0<S8b02DU9@0Hf=S0:6QX@1oOgl05QHF01@D500C4a<2014A4@805ADE01405QHF01PH600G5aL05aLG
06m_K`0i>CT0<C4a06m_K`2<S8`0Zj^[0:f][@2CTi<0PX:2092@T01DE5@092@T01`L700201dM7@0K
01lO7`0R8R809RHV03<c<`0e=CD0Xj>S0>3Ph02SXj<0VIVI0;Fe]@2DU9@0HF5Q09jNWP1hN7P0C4a<
069RHP1bLW80B4Q805MGE`1ADE40IfMW08V9R@1cLg<0@41001dM7@0U9BD0FEUI008071`L04`0;bl_
06e]K@1ADE40EUIF04M7A`0k>c/0UYJF07MgM`1BDU80FUYJ09RHV02;Rh/0B4Q806IVIP0i>CT0;Rh^
02d];@0c<c<0:b/[0492@P1lO7`0Q8B409bLW02^[Zh0IVIV07=cL`1JFUX0>SXj038b<P11@D40XZ:R
0;:b/P24Q8@0MWIf0;Jf]P3Lg=`0f][J0:NWY`2_[jl0TI6A06ATI023Ph<0P82005MGE`13@d<0A4A4
09ZJVP1cLg<0AdM707emO@2BTY80IVIV08V9R@1VIVH0EEEE07IfMP1kNg/0O7al0492@P0O7al071`L
04Q8B01DE5@0ATI602@T900M7Ad071`L01hN7P0i>CT0CDe=08B4Q01ZJVX0?3`l01`L700M7Ad08B4Q
0P0W9bL03P0l?3`0SXj>03lo?`1ZJVX0GUiN06a/K00b<S80F5QH05ADE02BTY80EeMG05YJFP1OGel0
H61P0P1LG5`04`1EEED0JFUY08:2PP2NWYh0f=SH0=CDe03<c<`0bl_;09fMW@1eMGD0];Bd05eMG@0f
=SH09bLW02HV9P0d=3@0LG5a0;Rh^02<S8`00P1:BTX0D@0b<S80De=C07inOP2NWYh0FEUI05mOG`1W
IfL0RHV90:JVYP2>SXh0_Kfm0=KFeP3Jf]X0alO70;no_`2TY:@0/k>c0<K6aP38b<P0_;bl0>7Qh@2l
_;`0M7Ad059BDP1@D500GUiN07]kN`21PH40KVi^06ATI01`L700KFe]08J6QP28R8P0N7Qh06][J`1L
G5`0U9BD08j>SP17AdL0>c/k06=SH`1QHF40@4100492@P16ATH0De=C08^;R`37alL0/[:b06UYJ@0/
;2`0<c<c02d];@0_;bl0=SHf04e=C@15ADD0?clo05MGE`1fMWH0Xj>S09>CT`1=CDd0?clo02l_;`1E
EED0E5AD03dm?@14A4@0@d=303Lg=`0`<300;2`/03Lg=`1MGEd0K6a/06QXJ01iNGT0:2PX02TY:@02
02HV9P0903Xj>P2`/;00S8b<0;Vi^@2?Shl0QHF506ATI013@d<0ATI600;ooooo0000D@1^KVh0QhN7
055AD@2i^KT0JFUY04m?C`21PH40MGEe03Lg=`1IFET0Cdm?02l_;`17AdL0@T9207IfMP1ADE40:b/[
05ADE00P8200<c<c06e]K@0I6AT0BDU904A4A00`<300;bl_038b<P0M7Ad0:b/[0492@P0[:b/0KFe]
05MGE`0[:b/0RHV907AdM00g=cL0?clo04Y:BP0[:b/0>SXj04M7A`0_;bl0=CDe01dM7@1aLG40J6QX
02@T9015ADD0B4Q802l_;`1HF5P0>CTi04];B`1_Kfl0L71`059BDP0k>c/0Lg=c05ADE017AdL0=cLg
06i^KP1NGUh0@D5104Y:BP15ADD0=cLg02XZ:P1cLg<0NGUi04E5A@0X:2P0T92@0492@P0a<C40Ogmo
069RHP0l?3`0JFUY02@T900207=cL`0N03@d=01DE5@0Q8B403Xj>P0P8200@D51075aL@1eMGD0CDe=
0;>c/`1ZJVX0?Cdm04M7A`1EEED0DE5A04];B`1bLW80G5aL034a<@0f=SH0BDU9096AT@1GEeL0a<C4
0:f][@2LW9`0BTY:079bLP1[Jf/0Cdm?0P1OGel0YP28R8P0EEEE04a<C01aLG40PH6104];B`1^KVh0
OWin04M7A`1/K6`0FEUI04a<C026QXH0A4A406ATI01nOWh0ADE504Y:BP1LG5`0J6QX05ADE01LG5`0
A4A4079bLP2;Rh/0C4a<06m_K`12@T80N7Qh071`L00l?3`0IfMW07alO014A4@0U9BD055AD@18B4P0
NWYj05mOG`0e=CD0Fe]K08^;R`0n?Sh0;Bd]09:BTP1MGEd0LG5a08F5Q@1EEED0LW9b09NGU`2ATI40
AdM706QXJ01jNWX0FUYJ096AT@24Q8@0E5AD07QhN01lO7`0Hf=S051@D02PX:00T92@075aL@2WYjL0
c<c<07alO00n?Sh0Hf=S09BDU02:RXX0BTY:069RHP2;Rh/0De=C04i>CP1nOWh0Ogmo03Lg=`1`L700
UiNG051@D01QHF40JVYZ03De=@0j>SX0K6a/04i>CP2>SXh0R8R804E5A@1KFe/0LG5a02h^;P1BDU80
PX:205EEE@1WIfL0OWin04];B`0e=CD0JVYZ06EUI@0j>SX0MGEe04E5A@0S8b<0Kfm_055AD@2>SXh0
CDe=08N7Q`1kNg/0H61P04E5A@1UIFD0BTY:08Z:RP0e=CD0?clo06i^KP1UIFD0EUIF06IVIP1>CTh0
JVYZ0;Rh^01mOGd0>SXj06m_K`1MGEd0AdM703Lg=`16ATH0FUYJ08B4Q01iNGT0BDU905UIF@1^KVh0
9RHV05IFEP1mOGd0Jf][03Xj>P1hN7P0MgMg051@D019BDT0BTY:05IFEP1NGUh0F5QH07QhN014A4@0
De=C07=cL`27QhL0ADE503Ti>@1lO7`0OGem06ATI013@d<206IVIP1d0492@P0W9bL0N7Qh065QH@1P
H600KFe]06a/K00d=3@0:b/[07]kN`2BTY80DU9B05ADE01TI6@0<c<c04I6AP20P800G5aL08>3P`25
QHD0EUIF061PH02KVi/0U9BD07MgM`0Z:RX0:b/[03Ti>@1RHV80<S8b030`<01XJ6P0RHV904U9B@0`
<300K6a/04Y:BP13@d<0@D510410@017AdL0UIFE08j>SP1PH600ADE5038b<P0S8b<0:BTY02XZ:P0O
7al0:2PX06YZJP35aLD0B4Q80451@@2?Shl0>CTi01dM7@0R8R80CTi>03/k>`0W9bL0<C4a0861P@1L
G5`0NWYj071`L01<C4`0De=C06m_K`1gMgL0EeMG05]KF`1kNg/0SHf=09bLW02EUID0PH6107=cL`1k
Ng/0MGEe061PH01WIfL0JVYZ08B4Q033`l<0V9RH06IVIP2n_[h0I6AT051@D01>CTh0M7Ad02DU9@0S
8b<071`L01DE5@0D51@06a/K02HV9P0Z:RX08R8R01/K6`0I6AT0;bl_06m_K`0`<300BTY:05EEE@1i
NGT0_[jn0<o?c`2KVi/0MgMg03/k>`0N7Qh301dM7@0/01hN7P0M7Ad07QhN028R8P0[:b/0[Zj^08b<
S01kNg/0/K6a0;jn_P1WIfL0PX:205QHF00V9RH0=cLg02l_;`12@T80Lg=c04U9B@1?Cdl0CTi>06a/
K024Q8@0JVYZ02<S8`0H61P0CDe=02`/;00I6AT07AdM06YZJP0k>c/0B4Q804i>CP1kNg/0Z:RX05MG
E`17AdL0@410055AD@2XZ:P0MWIf03dm?@0T92@202TY:@0`028R8P0S8b<08R8R04a<C01PH600PX:2
0;Jf]P1lO7`0NWYj0:RXZ02a/K40SXj>06UYJ@1GEeL0`l?309fMW@36a/H0`l?308b<S02TY:@0cLg=
0:VYZ@31`L40`l?30<71`@2g]kL0UiNG08R8R02c/k<0OWin06][J`1RHV80JVYZ0:JVYP2k^k/0VIVI
09nOW`2YZJT0^KVi0;Rh^02l_;`0S8b<05aLG01lO7`0MWIf04I6AP0O7al07QhN0P0L71`06P0N7Qh0
>CTi04e=C@2:RXX0IFEU04I6AP0O7al0:2PX02TY:@0W9bL09BDU02/[:`1^KVh0OGem08b<S01SHf<0
EEEE03hn?P1;Bd/0Ng]k0;Fe]@1:BTX0Fe]K05ADE00o?cl0;2`/0P0W9bL0?`0/;2`0?clo0:6QX@3K
fm/0dm?C0<W9b@2h^;P0R8R80:BTY02o_kl0]KFe0:2PX02:RXX0SXj>0:n_[`3;bl/0f][J06i^KP0Y
:BT0HV9R034a<@1:BTX0Ogmo0861P@0Z:RX0:BTY038b<P1KFe/0WinO0;2`/03<c<`0bl_;0<O7a`2_
[jl0YZJV065QH@1TI6@0RXZ:0<[:bP3>c/h0clo?06m_K`1>CTh0A4A40451@@0l?3`0FUYJ08N7Q`1m
OGd0GUiN04a<C013@d<0D51@08V9R@2SXj<0TY:B07QhN02=SHd0?3`l03Ti>@14A4@0GUiN06e]K@03
04I6AP0^04m?C`2OWil0c<c<09fMW@2ZZZX0BTY:03lo?`0j>SX0?clo04i>CP1IFET0HV9R08Z:RP2_
[jl0YjNW0<?3``1CDe<0@41003Hf=P0X:2P09RHV055AD@0T92@0?clo05IFEP2EUID0EeMG03@d=00e
=CD0HV9R07YjNP1:BTX0RHV904I6AP0g=cL0:b/[02XZ:P1mOGd0[:b/0:^[Z`2IVIT0@T9203Ti>@0g
=cL0>SXj04I6AP;ooooo0000GP1JFUX0EEEE04Q8B01kNg/0E5AD03`l?01OGel0@410020P800d=3@0
@d=3024Q8@0T92@0820P06][J`14A4@07AdM04e=C@0M7Ad09bLW061PH00Q8B40>SXj03@d=00E5AD0
9RHV03Ti>@0U9BD071`L02l_;`0F5QH0?clo055AD@0Y:BT0IVIV06a/K00A4A40:b/[03/k>`0W9bL0
:RXZ024Q8@0P8200>c/k024Q8@1aLG40De=C01TI6@0Q8B40ADE502d];@1JFUX0@41003Xj>P12@T80
J6QX06ATI00f=SH0Q8B404e=C@0m?Cd07alO04I6AP1IFET0@T9205=CD`1>CTh0F5QH02LW9`1GEeL0
Ng]k04M7A`0Y:BT0KFe]04I6AP0J6QX0Hf=S06EUI@0e=CD0MGEe038b<P1WIfL0OWin03hn?P1EEED0
OGem06ATI00Z:RX0AdM707AdM01SHf<0@41008n?S`1`L702055AD@3Y04i>CP1DE5@0@d=307UiN@1Q
HF40DU9B04M7A`1EEED0W9bL05eMG@35aLD0][Jf09fMW@1ADE40L71`05eMG@1JFUX0KFe]05YJFP1R
HV80DE5A05UIF@1[Jf/0NGUi04M7A`1dM7@0Hf=S04E5A@1/K6`0IfMW051@D01[Jf/0A4A404e=C@1g
MgL0BTY:04a<C01@D500Fe]K061PH01aLG40BDU9079bLP1lO7`0ATI608>3P`0m?Cd0Lg=c06MWI`19
BDT0M7Ad08:2PP0l?3`0V9RH06ATI017AdL0PX:207alO01>CTh0D51@08j>SP1HF5P0<30`08B4Q01o
Ogl0GemO06YZJP29RHT0MgMg09>CT`2:RXX0?Cdm04m?C`1`L700?Cdm065QH@1/K6`0CTi>07inOP1M
GEd0B4Q805IFEP2NWYh0QHF505UIF@2ATI40aLG508B4Q018B4P0EEEE0861P@2=SHd0C4a<06QXJ02C
Ti<0O7al05eMG@2@T900NWYj04=3@`1jNWX0^[Zj06i^KP1DE5@0EUIF03De=@0b<S80Hf=S03dm?@1V
IVH0Shn?0410@01>CTh0LW9b0492@P1?Cdl0Rh^;05iNGP1XJ6P0VYZJ07QhN011@D40QhN7071`L00i
>CT0RXZ:06QXJ00];Bd0OWin06IVIP2XZ:P0GEeM07moO`1WIfL0R8R803Xj>P1DE5@0FUYJ09BDU01U
IFD0;Rh^07QhN01XJ6P0L71`08n?S`1<C4`0ADE508n?S`2:RXX0Bd];08F5Q@26QXH0O7al065QH@0o
?cl0>SXj06IVIP1eMGD0Cdm?096AT@2DU9@0BDU905MGE`2@T900JFUY0492@P2ATI40T92@059BDP16
ATH0>c/k02l_;`1RHV80KFe]075aL@17AdL0C4a<07MgM`1?Cdl0;bl_03dm?@21PH40OWin05MGE`14
A4@0Fe]K06ATI00k>c/07QhN06QXJ01]KFd0PX:20:>SX`1_Kfl0:b/[01TI6@15ADD0JVYZ04E5A@18
B4P0G5aL03/k>`15ADD0K6a/05IFEP1nOWh0Y:BT071`L01EEED0TY:B09BDU01?Cdl0@T9204e=C@17
AdL0NWYj07=cL`0N7Qh0<S8b0:>SX`1JFUX0;bl_08j>SP1nOWh0HF5Q051@D01EEED0DE5A09RHV02>
SXh0EUIF034a<@0U9BD00P0P8200500c<c<0:2PX01dM7@1CDe<0YJFU07]kN`1dM7@0bLW903/k>`0N
7Qh07alO02HV9P12@T80J6QX08R8R01QHF40CDe=06YZJP2XZ:P0EeMG0P0/;2`02`0h>3P0GEeM065Q
H@1TI6@0C4a<071`L02GUiL0D51@04m?C`19BDT0@D510080Cdm?0200AdM705=CD`1jNWX0VIVI0820
P03@d=00X:2P05IFEP16ATH0EeMG04U9B@0Q8B409RHV01dM7@0J6QX071`L01hN7P0K6a/071`L01/K
6`0G5aL07AdM051@D01nOWh0DE5A04i>CP1;Bd/0GEeM0<G5a@2>SXh0<S8b01lO7`8071`L00@07AdM
01`L700L71`071`L0P0M7Ad0<@1BDU80Ti>C04Y:BP1^KVh0[:b/09FEU@1mOGd0JFUY02PX:00N7Qh0
8B4Q02l_;`0X:2P0>CTi06i^KP1CDe<0D51@05MGE`1fMWH0NGUi05aLG00K6a/0=cLg04i>CP0M7Ad0
92@T09JFUP1TI6@0Cdm?07MgM`2f][H0]kNg09>CT`1YJFT0De=C05MGE`2k^k/0ATI602@T900P8200
8b<S01lO7`0L71`07AdM01lO7`0m?Cd0EEEE06e]K@2i^KT00P3;bl/03@2a/K40QHF505eMG@1jNWX0
KFe]0<G5a@3Fe]H0^KVi06][J`1mOGd0R8R80;2`/034a<@00P2o_kl05`2TY:@0W9bL0::RXP3>c/h0
emOG04e=C@0^;Rh07alO04m?C`2LW9`0Z:RX09VIV@31`L40`/;20:ZZZP1mOGd0P82008R8R02g]kL0
fm_K07UiN@0Q8B407QhN008071`L0P0M7Ad0>00`<300Fe]K08:2PP1JFUX0WinO06=SH`15ADD0@T92
0451@@14A4@0C4a<065QH@2ATI40Fe]K069RHP1JFUX0LG5a0:ZZZP2[Zj/0V9RH0451@@1KFe/0>SXj
02HV9P0N7Qh08R8R020P800Q8B409bLW05MGE`3=cLd0[Zj^09jNWP2h^;P0H61P07YjNP3:b/X0];Bd
08F5Q@1NGUh0EeMG04];B`1XJ6P0a/K607alO00T92@0Fe]K03hn?P16ATH0QhN707inOP0Y:BT09bLW
038b<P1dM7@0>3Ph0P1^KVh0D@2:RXX0];Bd0;6a/@2SXj<0Ph>3075aL@2>SXh0g=cL0>7Qh@21PH40
AdM704E5A@1:BTX0GemO06EUI@23Ph<0S8b<05mOG`0[:b/0?Cdm03Ti>@1GEeL0E5AD075aL@2QXJ40
^[Zj0861P@0Y:BT0<30`04=3@`1OGel0TY:B05iNGP16ATH0BDU904];B`1RHV80alO70;Jf]P2k^k/0
XZ:R08>3P`1kNg/0Rh^;0820P02CTi<0TI6A09bLW02g]kL0`l?309VIV@17AdL0ADE503dm?@0Y:BT0
7alO02HV9P0l?3`0?Cdm04e=C@3?cll0RHV904Q8B00];Bd0EUIF09ZJVP2ATI40]KFe07EeM@1mOGd0
Ph>308Z:RP39bLT0ZJVY0:ZZZP0o?cl0=3@d03Ph>013@d<0A4A405QHF002ooooo`000>L0GEeM08F5
Q@1<C4`0SXj>06m_K`16ATH0Kfm_08V9R@0c<c<0?3`l06a/K00i>CT0:RXZ038b<P1EEED0EeMG02LW
9`1CDe<0:BTY01lO7`1EEED0<c<c03Lg=`1:BTX0:b/[024Q8@0X:2P09bLW01lO7`13@d<0=CDe04M7
A`19BDT0=cLg065QH@1]KFd07alO02/[:`0Z:RX06a/K01lO7`0i>CT06a/K03Lg=`0R8R80Fe]K075a
L@0Z:RX0<S8b04];B`0_;bl0IfMW07EeM@1?Cdl0EEEE07]kN`1mOGd0B4Q803Ti>@1RHV80D51@02DU
9@1?Cdl0ATI60492@P1GEeL0Bd];06ATI00d=3@0EeMG07=cL`1:BTX0=3@d04U9B@1GEeL0820P071`
L01fMWH0;bl_08N7Q`0m?Cd0GEeM07emO@0g=cL0EeMG0820P01KFe/0:2PX04I6AP1ZJVX0DE5A03<c
<`1cLg<0NWYj05aLG01BDU80Bd];05ADE00n?Sh0PX:20:2PX01FEUH0Bd];05YJFP2;Rh/0D51@0:ZZ
ZP2m_Kd0Y:BT04m?C`1`L700DE5A05UIF@1WIfL0E5AD075aL@1:BTX0DU9B06ATI01]KFd0@41006QX
J01]KFd0ADE5079bLP1PH600C4a<06UYJ@0o?cl0Jf][08B4Q01;Bd/0DU9B04m?C`1>CTh0A4A405aL
G016ATH0De=C08b<S018B4P0R8R8051@D01HF5P0QHF503hn?P1JFUX0OWin03lo?`2IVIT0Lg=c03/k
>`1BDU80JVYZ04e=C@0g=cL0NGUi07emO@0n?Sh0QXJ608>3P`1mOGd0Ogmo08N7Q`1SHf<0YJFU08V9
R@0g=cL0DU9B0861P@1;Bd/0LG5a08Z:RP1HF5P0RHV908B4Q02>SXh0CDe=0:ZZZP1hN7P0Fe]K08:2
PP39bLT0SXj>05IFEP1KFe/0MgMg07EeM@0h>3P0I6AT09nOW`24Q8@0GUiN0:^[Z`21PH40<c<c05IF
EP2PX:00Kfm_04a<C01]KFd0>CTi04Q8B026QXH0EeMG06MWI`27QhL0>c/k06MWI`26QXH0@41004U9
B@1kNg/0=CDe05]KF`1oOgl0Kfm_04Q8B02NWYh0U9BD0492@P1QHF40A4A402h^;P1IFET0JFUY096A
T@1HF5P0MWIf06m_K`1oOgl00P0];Bd0U@0d=3@0KVi^065QH@0/;2`0IfMW059BDP11@D40DU9B04m?
C`12@T80UiNG07=cL`0e=CD0BDU905=CD`1QHF40EeMG04];B`0m?Cd0JVYZ075aL@0d=3@0ADE506i^
KP1:BTX0De=C0:b/[01ZJVX0;bl_06a/K01`L700FEUI07IfMP1IFET0@d=304M7A`1EEED0IfMW04E5
A@1TI6@0XJ6Q08:2PP1CDe<08b<S05mOG`1cLg<0Bd];06ATI01mOGd0VIVI05ADE00k>c/0Jf][05YJ
FP1>CTh0FUYJ06IVIP1;Bd/08b<S04I6AP1kNg/0<30`04e=C@1jNWX0C4a<04U9B@1iNGT0>CTi05MG
E`1nOWh0LG5a065QH@1oOgl0Shn?0410@00a<C40A4A407alO02;Rh/0JVYZ01hN7P0f=SH0^[Zj04U9
B@0];Bd0QhN704A4A010@400>3Ph02h^;P0b<S80CDe=05iNGP1HF5P0;Bd]02XZ:P0S8b<08B4Q02d]
;@0a<C40:2PX06ATI02RXZ80/[:b0;Zj^P2ZZZX0RHV902l_;`0P82009BDU02XZ:P0Y:BT0Ph>306YZ
JP17AdL0OWin0;Vi^@2CTi<0NWYj03Hf=P0_;bl08b<S03Ph>01mOGd0LG5a04i>CP2PX:00MWIf07]k
N`1hN7P0LG5a04A4A00^;Rh09BDU038b<P1>CTh0]KFe0<[:bP2`/;00XZ:R0;Jf]P2@T900Hf=S065Q
H@0a<C407AdM02LW9`0L71`06QXJ00806a/K0P0L71`0300I6AT06QXJ04=3@`1XJ6P0_kno09:BTP2A
TI40UiNG0<k>cP2j^[X0G5aL02`/;08071`L01L07AdM01`L700M7Ad071`L01/K6`0M7Ad0QHF505=C
D`14A4@0FEUI08f=S@26QXH0WYjN03dm?@0O7al071`L01dM7@0X:2P09BDU02XZ:P0l?3`0HF5Q05=C
D`0204a<C00_05eMG@1fMWH0EEEE06MWI`2IVIT0Kfm_05ADE01UIFD0O7al08j>SP2PX:00OGem05EE
E@1RHV80N7Qh096AT@2XZ:P0^[Zj06ATI00g=cL0:RXZ024Q8@0J6QX071`L01hN7P0U9BD0@T9208Z:
RP2LW9`0VYZJ07MgM`2^[Zh0ZJVY0:ZZZP2a/K40];Bd0;bl_03De=@0emOG0;fm_@20P800MgMg07Yj
NP2KVi/0^k^k0<W9b@2f][H00P2[Zj/05@2EUID0QhN7096AT@1nOWh0<S8b05IFEP1?Cdl0@d=30;Jf
]P1DE5@0Bd];07alO017AdL0@d=303lo?`10@400K6a/0=;BdP1iNGT06QXJ01/K6`0401dM7@0I02PX
:01YJFT0Jf][051@D01WIfL0>CTi030`<00/;2`09BDU028R8P0T92@08B4Q06][J`22PX80LG5a08b<
S01PH600WIfM071`L01cLg<0@d=303hn?P0U9BD08B4Q01dM7@0301hN7P05024Q8@1TI6@0_[jn06a/
K01dM7@00P1PH600102ATI40c/k>08J6QP0e=CD302HV9P1Q03/k>`2>SXh0VYZJ030`<01>CTh0AdM7
03lo?`1OGel0LG5a02@T900O7al0IFEU0492@P0m?Cd0V9RH0:JVYP1nOWh0GEeM06QXJ014A4@0BDU9
07AdM02a/K40hn?S0=?Cd`1_Kfl0>SXj03dm?@0l?3`0@d=3065QH@2CTi<0Ng]k03hn?P0U9BD0<c<c
03Ti>@1OGel0EUIF08>3P`2KVi/0`/;208:2PP0_;bl0<30`02`/;01NGUh0/K6a0:^[Z`2JVYX0TI6A
08F5Q@2XZ:P0clo?0;bl_02m_Kd0Fe]K04U9B@1ADE40GUiN04a<C01EEED0DE5A075aL@2QXJ40a/K6
0:b/[00e=CD0;Bd]02/[:`0Q8B4071`L01lO7`0X:2P0BDU904Y:BP2m_Kd0CDe=05aLG01@D500Ng]k
09>CT`2GUiL0@d=30410@01IFET0O7al0;no_`33`l<0^;Rh04i>CP0d=3@0=cLg03hn?P12@T80Jf][
0:b/[002ooooo`0001D0EUIF09FEU@1<C4`0WinO071`L019BDT0LW9b09JFUP0l?3`0?Cdm06UYJ@0j
>SX0:b/[04M7A`1RHV80KVi^038b<P1BDU80?3`l02@T901JFUX00P0d=3@0800l?3`0<C4a034a<@0^
;Rh0:RXZ020P800e=CD0<30`04];B`1@D500>CTi05=CD`1_Kfl0:BTY02/[:`0_;bl0:b/[028R8P16
ATH07alO04e=C@0Y:BT0E5AD07UiN@0b<S80:b/[04e=C@0b<S80E5AD06EUI@15ADD0DE5A0P1bLW80
o`11@D4092@T07MgM`17AdL08R8R04E5A@1=CDd0@410055AD@1GEeL0IFEU038b<P1KFe/0NGUi04a<
C00g=cL0>3Ph05mOG`0N7Qh0L71`0861P@0`<300Ng]k04A4A013@d<0Ph>304I6AP1VIVH0WIfM06YZ
JP0b<S80ATI6065QH@1=CDd0<C4a05ADE028R8P0FEUI059BDP18B4P0@41003<c<`1OGel0MGEe05MG
E`15ADD0GUiN07MgM`0h>3P0Ph>309^KV`2MWId0BTY:06EUI@1VIVH0FUYJ06][J`1;Bd/0MgMg05IF
EP1=CDd0JFUY08F5Q@0f=SH0H61P07alO01<C4`0JVYZ071`L013@d<0JFUY05eMG@13@d<0SXj>04];
B`17AdL0C4a<08:2PP1@D500GemO03/k>`1HF5P0V9RH04e=C@1_Kfl0>3Ph05UIF@2EUID0A4A405EE
E@21PH40A4A409FEU@1fMWH0D51@05EEE@2<S8`0FEUI03dm?@2:RXX0MgMg03lo?`1kNg/0?Shn05=C
D`1HF5P0MGEe05]KF`39bLT0Y:BT0410@01LG5`0RXZ:04i>CP1mOGd0HV9R04I6AP29RHT0QhN708R8
R01>CTh0_;bl05eMG@0l?3`0EEEE0;Vi^@2>SXh0De=C06a/K02ATI40RXZ:05EEE@1[Jf/0YjNW06QX
J01QHF40Shn?08J6QP1IFET0VIVI0<_;b`1aLG40IFEU08:2PP0n?Sh0:2PX071`L01ADE40J6QX092@
T019BDT0B4Q8061PH00a<C40FUYJ08Z:RP1IFET0Fe]K08b<S015ADD09RHV061PH01eMGD0>CTi06e]
K@1@D500820P05IFEP1:BTX0VYZJ04E5A@24Q8@0Ph>3071`L017AdL0>SXj051@D01kNg/0CTi>04e=
C@1fMWH0IVIV04i>CP1JFUX0E5AD04=3@`2OWil0PH6104a<C01UIFD0IfMW061PH00n?Sh0C4a<04U9
B@1hN7P0RHV904U9B@1HF5P0M7Ad03/k>`1OGel0UiNG07inOP1?Cdl0P82006ATI00m?Cd0BTY:05mO
G`1SHf<0CTi>05QHF01SHf<0;2`/03Xj>P1`L700Ph>306=SH`0V9RH0GUiN07]kN`1PH600@D51051@
D022PX80FEUI04];B`1TI6@0P82005=CD`1XJ6P0K6a/04Q8B00b<S80ATI606][J`1GEeL0>SXj07=c
L`1RHV80ADE506m_K`1VIVH0KVi^09FEU@1iNGT0K6a/07emO@27QhL0PH6103`l?00W9bL0=3@d06MW
I`00B@1QHF408b<S03/k>`30`<00Q8B403Lg=`1hN7P0=3@d02d];@0Y:BT09RHV028R8P0P8200BDU9
07=cL`1FEUH0ADE503lo?`10@400CDe=04];B`0_;bl0Ogmo0::RXP2VYZH0P82003/k>`1PH600UIFE
059BDP0`<300=SHf03Ti>@1MGEd0BTY:06YZJP2EUID0Q8B409bLW022PX80CTi>04a<C01MGEd0Rh^;
07inOP2^[Zh0UIFE0<30`02/[:`0SHf=07]kN`1bLW80MGEe06IVIP1QHF40Ti>C0<G5a@2DU9@0Vi^K
08f=S@1LG5`0RHV909VIV@2WYjL0SXj>09FEU@17AdL0;bl_02LW9`0L71`07alO01`L700K6a/00P0L
71`03P0J6QX0CTi>08J6QP2l_;`0WYjN08>3P`2OWil0]kNg09jNWP1^KVh0G5aL04a<C00^;Rh07alO
0P0M7Ad02`0J6QX06a/K038b<P1gMgL0AdM7065QH@2^[Zh0ZJVY0:NWY`1[Jf/0;Rh^00<07AdM0P0[
:b/0B`0T92@0;2`/04E5A@2JVYX0Jf][06a/K01nOWh0YjNW07inOP1?Cdl0CDe=0:BTY02c/k<0EEEE
06i^KP2EUID0SXj>07emO@1JFUX0?Cdm03lo?`1:BTX0SHf=0:n_[`29RHT0PH6106EUI@10@400:RXZ
020P800V9RH09BDU05aLG030`<00QXJ605aLG01ADE40WinO0=3@d02l_;`0[jn_0:6QX@2l_;`0g=cL
0<71`@2RXZ80WIfM0:RXZ02ATI40Z:RX04M7A`2RXZ80^[Zj0=?Cd`2/[:`0PH6106m_K`23Ph<0_;bl
07UiN@0X:2P071`L01lO7`2KVi/0CTi>0451@@1@D500FUYJ02@T900W9bL08b<S02PX:02=SHd0VYZJ
020P800201XJ6P0;01`L700K6a/071`L03<c<`1gMgL0QXJ605ADE01HF5P09RHV028R8P0Q8B400P0M
7Ad0400O7al0Bd];09bLW02m_Kd0^KVi0:n_[`1JFUX0J6QX04m?C`21PH40MWIf03Hf=P0P820071`L
01dM7@0L71`201dM7@1B02HV9P21PH40_kno05EEE@1RHV80;2`/02LW9`11@D40Q8B407alO00T92@0
7QhN024Q8@0R8R80;2`/061PH02^[Zh0G5aL04A4A01LG5`0;Bd]03`l?01ZJVX0<30`04Y:BP1QHF40
<C4a08:2PP2EUID0`l?30<;2`P1;Bd/0UYJF0451@@0U9BD0;bl_04A4A02h^;P0a/K607moO`0c<c<0
;bl_03Ph>010@400EeMG08b<S02>SXh0B4Q802@T900d=3@0@41005MGE`1BDU80PX:20;Ng]`1^KVh0
JVYZ075aL@0e=CD0:b/[04];B`37alL0cLg=0=OGe`2HV9P0ZJVY0<[:bP3>c/h0[Zj^0<S8b02YZJT0
Ogmo09:BTP2EUID0WIfM0:^[Z`2_[jl0b/[:0=_Kf`2:RXX0Ng]k04a<C080:RXZ01/08R8R020P800Q
8B40>CTi075aL@2SXj<0`<3005]KF`1MGEd0PX:20;jn_P2^[Zh0N7Qh07=cL`0W9bL0<C4a05EEE@33
`l<0[:b/0;Rh^01JFUX0ATI603/k>`0o?cl0LG5a0:n_[`1oOgl00_ooool0000i065QH@2RXZ80Bd];
09NGU`1DE5@0ATI606e]K@1lO7`0>SXj03Ti>@1?Cdl0<S8b03hn?P1?Cdl0EeMG079bLP0i>CT0AdM7
0451@@0L71`0GemO04M7A`0/;2`0B4Q802l_;`0];Bd0?clo02/[:`0P82009bLW02DU9@16ATH0EeMG
03Ti>@1DE5@0QhN702@T900S8b<0;bl_02HV9P0Y:BT0D51@024Q8@1BDU80;2`/05MGE`2ZZZX0B4Q8
02@T901>CTh0;Rh^05QHF01WIfL0ATI605]KF`1[Jf/0De=C0080?3`l02P0Lg=c06MWI`0d=3@0?Shn
05aLG00[:b/0?clo06IVIP1ZJVX0<S8b065QH@28R8P0=SHf03Ti>@14A4@0GUiN01hN7P1QHF40GemO
03@d=021PH40CTi>03Lg=`1gMgL0<30`0492@P2:RXX0KVi^03@d=00n?Sh0G5aL08B4Q01IFET0@d=3
08>3P`1QHF40De=C04E5A@1DE5@0ADE50P1WIfL0X`1HF5P0ADE505iNGP1gMgL0I6AT09NGU`2`/;00
XJ6Q04a<C01FEUH0Ng]k061PH01VIVH0DU9B06m_K`1CDe<0C4a<05eMG@2<S8`0>SXj05QHF02<S8`0
F5QH06MWI`1`L700@41006e]K@1UIFD0@D51092@T01ADE40BDU905UIF@1fMWH0BTY:05MGE`12@T80
F5QH08^;R`1:BTX0LW9b04m?C`0l?3`0Jf][0492@P1QHF40GemO03Hf=P23Ph<0Lg=c04Q8B017AdL0
Ti>C02/[:`0];Bd0Hf=S07=cL`14A4@0QXJ60820P01[Jf/0IFEU05]KF`0a<C40Kfm_07moO`1PH600
JVYZ08V9R@0m?Cd0LW9b075aL@1CDe<0L71`06e]K@1YJFT0EeMG0<C4a020P800HV9R071`L03:b/X0
X:2P03<c<`16ATH0FEUI06YZJP0V9RH0D51@08J6QP28R8P0Cdm?08^;R`1/K6`0<c<c055AD@1mOGd0
Kfm_04M7A`2ATI40<c<c03dm?@26QXH0?clo079bLP2@T900Fe]K04a<C01PH600<S8b03Ph>02;Rh/0
GUiN05aLG02EUID0GUiN038b<P1OGel0N7Qh04=3@`2CTi<0JFUY028R8P1QHF40DU9B0:ZZZP17AdL0
HV9R065QH@1[Jf/0@d=303Lg=`1RHV80PH6105ADE00a<C40DU9B069RHP17AdL0K6a/038b<P0`<300
J6QX07MgM`15ADD0DU9B06ATI01UIFD07QhN03Ti>@1QHF40L71`08J6QP1;Bd/0C4a<07MgM`1FEUH0
>c/k0:ZZZP2NWYh0CTi>07QhN02ATI400P1JFUX00`1BDU80I6AT04e=C@0205aLG00h03Ti>@1:BTX0
Kfm_08N7Q`1_Kfl09BDU05]KF`26QXH0OWin04e=C@1@D500UIFE065QH@1JFUX0KFe]08N7Q`1FEUH0
M7Ad069RHP0l?3`0=SHf03hn?P21PH40ADE503hn?P1cLg<0FEUI03Xj>P1aLG40EUIF07EeM@2LW9`0
LW9b06][J`2m_Kd0[Jf]09BDU011@D40;Rh^04I6AP1]KFd0Fe]K02l_;`1XJ6P0alO707EeM@0`<300
MgMg04=3@`0b<S80:b/[02PX:00U9BD07QhN02l_;`1<C4`208N7Q`0307]kN`1oOgl0MGEe0080G5aL
04D0[Zj^0;>c/`1oOgl0LG5a04Y:BP0k>c/0DE5A07QhN01dM7@0<30`061PH01FEUH0N7Qh0:^[Z`0a
<C407AdM020P800/;2`08b<S02XZ:P19BDT0OWin08n?S`2@T900Ti>C0<K6aP2:RXX0Cdm?03hn?P0e
=CD0<S8b03/k>`0n?Sh0IfMW0:b/[018B4P0ATI60;Fe]@2BTY80GemO06QXJ02=SHd0WYjN07YjNP1Y
JFT0IfMW069RHP1CDe<0?3`l038b<P0T92@07QhN01`L700l?3`0SHf=09bLW026QXH0IFEU0492@P1D
E5@0QHF507=cL`1>CTh0DU9B04A4A01ADE40FUYJ04a<C00a<C400P0N7Qh0I01[Jf/0EUIF05eMG@28
R8P0[Zj^0<g=c@2OWil0FUYJ02h^;P0M7Ad071`L01dM7@0L71`09BDU02@T900a<C40HF5Q0<K6aP3=
cLd0Y:BT09jNWP2KVi/0N7Qh0492@P1>CTh0PH61092@T01BDU80EUIF061PH01RHV80OWin08^;R`1i
NGT0Bd];04A4A025QHD0cLg=05mOG`1DE5@0KVi^08J6QP1dM7@0@41002/[:`1=CDd0/k>c07moO`1:
BTX0LG5a07emO@2WYjL0`<3009>CT`1NGUh0H61P09bLW03Bd]80[Zj^06IVIP1=CDd0JFUY06IVIP20
P800J6QX08R8R02>SXh0[Zj^06a/K015ADD0B4Q805eMG@21PH40Ng]k01TI6@0K6a/071`L08>3P`1L
G5`0?clo03Ph>01PH600BDU902HV9P0T92@08R8R03dm?@2[Zj/0?clo020P800L71`06a/K01dM7@0b
<S80F5QH0:VYZ@2TY:@0H61P06YZJP0R8R8201dM7@0?01lO7`0j>SX0NWYj07alO01TI6@0EeMG09FE
U@2RXZ80Ph>308j>SP1eMGD0]KFe07moO`0a<C408B4Q00<071`L07407AdM01`L700h>3P0UIFE0;Fe
]@1]KFd0=cLg02HV9P0Q8B40?Cdm06m_K`2EUID0?Cdm01`L700P82007QhN02LW9`0g=cL0U9BD0:ZZ
ZP2FUYH0/;2`03Xj>P0h>3P0Ogmo07AdM02ATI40GEeM08J6QP2BTY80RHV908f=S@2RXZ80/k>c07Qh
N00`<30092@T02LW9`0o?cl0[Zj^0;Rh^039bLT0Jf][03@d=00e=CD0>c/k0451@@1=CDd0MWIf061P
H00[:b/0>c/k05aLG01:BTX0EEEE0;Bd]01IFET0?clo04];B`1SHf<0MWIf05mOG`2=SHd0`/;208F5
Q@2RXZ80[Zj^0;Ng]`2ZZZX0^KVi0:BTY02ZZZX0Y:BT0:RXZ023Ph<0S8b<0861P@1lO7`0Q8B40:ZZ
ZP30`<00`/;208N7Q`1ADE40?3`l02DU9@0R8R80:2PX0451@@1QHF40Jf][09ZJVP2m_Kd0K6a/06AT
I02=SHd0[jn_06EUI@1/K6`0];Bd0861P@1dM7@0/k>c0=OGe`3De=@0X:2P07]kN`2FUYH0XJ6Q0:f]
[@2g]kL0GemO07UiN@02ooooo`000;00EUIF08F5Q@17AdL0WIfM06a/K017AdL0M7Ad08R8R00e=CD0
>CTi04e=C@0];Bd092@T03`l?00n?Sh0De=C024Q8@0o?cl0ATI6020P801SHf<0=CDe030`<01KFe/0
;bl_02LW9`1@D500;Rh^01LG5`0l?3`0=CDe04U9B@1ADE40820P030`<01SHf<0?3`l01lO7`0`<300
;Bd]020P801:BTX06QXJ0492@P0F5QH0;2`/05YJFP0e=CD0820P04A4A00c<c<0EUIF065QH@10@400
EeMG06a/K01]KFd0Jf][034a<@1BDU80IfMW030`<00d=3@0EEEE04A4A00n?Sh0BDU906IVIP0g=cL0
JFUY07alO011@D40<30`02l_;`1?Cdl071`L05iNGP2@T900<c<c07]kN`1MGEd0;Rh^08R8R01CDe<0
BTY:07QhN01fMWH0?Shn04];B`1_Kfl0PH61055AD@0l?3`0R8R8069RHP1GEeL0B4Q805UIF@1<C4`0
Hf=S065QH@1^KVh0C4a<06e]K@2:RXX0KFe]096AT@30`<00];Bd0492@P1GEeL0P82005=CD`1TI6@0
;bl_07]kN`18B4P0DU9B06m_K`1JFUX0>SXj05YJFP1hN7P0EUIF0861P@1IFET0?clo0820P01KFe/0
ADE508B4Q015ADD0>c/k04M7A`1ADE40ATI606QXJ01CDe<0EeMG08>3P`0d=3@0U9BD06MWI`0`<300
H61P03Lg=`1YJFT0QHF504A4A027QhL0H61P03De=@1<C4`0Ogmo04];B`0b<S80IFEU05]KF`0[:b/0
JFUY051@D01]KFd0PH6107moO`1?Cdl0X:2P08f=S@0f=SH0Rh^;0:f][@0o?cl0Bd];05mOG`11@D40
UYJF06EUI@80?clo03P0[jn_04m?C`0E5AD0<S8b09nOW`2IVIT0HF5Q05YJFP1PH600Shn?04];B`17
AdL0RHV908R8R01;Bd/0U9BD07alO013@d<0OGem0:VYZ@24Q8@0Cdm?08n?S`0_;bl0820P06YZJP1I
FET0Bd];08N7Q`1;Bd/0MGEe09RHV01FEUH0@d=308F5Q@0j>SX0FUYJ09:BTP1jNWX0@D5105iNGP29
RHT0;Rh^05ADE01RHV809BDU06=SH`1EEED0YjNW05aLG01/K6`0KVi^08:2PP1GEeL0AdM706e]K@80
PH6108l0ATI605eMG@1jNWX0Cdm?08j>SP1SHf<092@T07=cL`2IVIT0@d=304Q8B01WIfL0HF5Q05QH
F01:BTX0?clo05aLG02>SXh0De=C055AD@21PH40Jf][055AD@2OWil0K6a/0451@@1hN7P0Ogmo05AD
E01^KVh0ADE505EEE@1;Bd/0N7Qh05]KF`0o?cl0AdM706e]K@22PX80KVi^02`/;01XJ6P0PX:207If
MP1HF5P0DU9B08B4Q01KFe/0IVIV08N7Q`2:RXX0CTi>06e]K@1dM7@0;Rh^03@d=01KFe/0Xj>S05AD
E00j>SX0IfMW02/[:`0Z:RX0M7Ad06YZJP1[Jf/0VYZJ07YjNP16ATH0Ph>309FEU@1YJFT0?Cdm05UI
F@25QHD0QhN7038b<P0D51@0>3Ph08b<S01kNg/0:RXZ08>3P`1bLW80CDe=03<c<`0U9BD0820P01hN
7P0R8R80?3`l04Q8B00R8R80:BTY02l_;`1?Cdl0HV9R07QhN02GUiL0^;Rh08F5Q@1`L700Ng]k04];
B`11@D40DU9B06MWI`2SXj<0Z:RX05mOG`13@d<0IfMW02@T900L71`05aLG020P800`<300A4A404e=
C@1YJFT0Kfm_07UiN@13@d<0IVIV07emO@0f=SH0:BTY02LW9`0T92@09bLW02`/;00b<S80OGem06MW
I`0e=CD0H61P0:>SX`1]KFd0I6AT08J6QP2^[Zh0TI6A06m_K`0205UIF@1905aLG01JFUX0EUIF05=C
D`1FEUH0Lg=c0<C4a02SXj<0U9BD08^;R`1iNGT0Fe]K07MgM`1YJFT0JVYZ02`/;01CDe<0I6AT075a
L@1cLg<0OWin08F5Q@1^KVh0O7al0:VYZ@1]KFd0M7Ad0:2PX02VYZH0PX:207moO`26QXH0;Bd]01`L
700K6a/07AdM01lO7`0`<300IVIV0:JVYP2WYjL0PX:208>3P`2GUiL0MWIf05YJFP1nOWh0aLG5071`
L01XJ6P0WIfM04i>CP0b<S80;bl_03Ph>01<C4`0DU9B03lo?`1MGEd0U9BD0<[:bP2OWil0Z:RX07Ad
M014A4@0@d=306e]K@2DU9@0Q8B40;Ng]`2@T900=3@d02h^;P020;fm_@2f09:BTP1^KVh0IfMW06a/
K01UIFD0QHF50=SHf03?cll0Hf=S03De=@18B4P0BDU904e=C@1_Kfl0PH610:BTY01fMWH0:RXZ02@T
900V9RH0<C4a03/k>`1ZJVX061PH01HF5P0G5aL0SXj>0:n_[`14A4@0GUiN02XZ:P19BDT0?clo02d]
;@0[:b/0=3@d0;bl_038b<P0Vi^K07]kN`1ZJVX0O7al08>3P`21PH40_Kfm0:j^[P2WYjL0LG5a0492
@P0];Bd0Bd];06a/K01ZJVX0Cdm?04Q8B015ADD0DU9B08J6QP1ADE40SHf=09NGU`2i^KT0b/[:08R8
R01<C4`07QhN01`L700M7Ad06a/K01dM7@0X:2P0GemO0:2PX02e]KD0L71`02`/;00Y:BT08b<S03dm
?@1PH600R8R8055AD@0Q8B40820P01dM7@0Q8B40<C4a09RHV031`L40_[jn075aL@1/K6`0E5AD08V9
R@3@d=00clo?06e]K@1;Bd/0=SHf02`/;00o?cl0Ng]k08b<S01KFe/08b<S02TY:@0i>CT0M7Ad0<g=
c@2KVi/0Kfm_09NGU`29RHT0=cLg02XZ:P0`<300?3`l07EeM@1_Kfl0;Rh^03De=@1kNg/0F5QH0:JV
YP26QXH09bLW02/[:`1^KVh0Jf][08Z:RP2l_;`0f=SH0<?3``3:b/X0e]KF0<?3``2b/[80YJFU0:b/
[02b/[80`l?30:6QX@2JVYX0YZJV075aL@1>CTh0DU9B04i>CP1GEeL0Rh^;09VIV@2/[:`0YJFU06=S
H`1;Bd/0>CTi04];B`1hN7P0MWIf06EUI@21PH40bl_;08n?S`1nOWh0Q8B40:^[Z`2ZZZX0d=3@0<_;
b`2h^;P0_Kfm0=7Ad@3Hf=P0YJFU0:2PX018B4P0BDU907UiN@33`l<0Ogmo05iNGP2?Shl2ooooo`00
05L0Hf=S09>CT`16ATH0KVi^06QXJ01JFUX0YjNW09nOW`0R8R80;Bd]05]KF`1>CTh0;bl_0451@@0l
?3`0Lg=c04M7A`0l?3`0BDU9024Q8@1QHF40ADE501`L701KFe/0;bl_020P801BDU80Cdm?02HV9P1C
De<08R8R03Hf=P1MGEd0>SXj03Lg=`1^KVh0;2`/01TI6@15ADD0>SXj02/[:`0h>3P04Q8B04];B`0a
<C40<c<c06ATI00Y:BT07AdM04A4A01@D500F5QH03dm?@0];Bd0EeMG06a/K01lO7`0P82003`l?01I
FET0H61P01dM7@11@D40GemO04a<C019BDT0A4A404E5A@0S8b<0IFEU07MgM`16ATH0>SXj02`/;00_
;bl05ADE055AD@23Ph<0<30`06a/K01?Cdl0<30`096AT@1FEUH0BTY:06EUI@1dM7@00P0d=3@0o`1G
EeL0M7Ad04U9B@10@400QHF5055AD@1MGEd0FEUI061PH014A4@0NGUi08f=S@1ZJVX0;Rh^04];B`1d
M7@0D51@06][J`2^[Zh0XJ6Q05ADE017AdL0EeMG038b<P1PH600Cdm?08J6QP12@T80>SXj05IFEP1Q
HF40?Cdm04m?C`1^KVh0;2`/06UYJ@1_Kfl0@D5108b<S00a<C40<S8b07emO@1IFET0C4a<05aLG01;
Bd/0=CDe04];B`19BDT0CTi>09^KV`1KFe/0MGEe05]KF`16ATH0Shn?051@D01=CDd0N7Qh04E5A@2<
S8`0UiNG059BDP0[:b/0K6a/03/k>`0V9RH0O7al09^KV`1MGEd0LW9b02/[:`1:BTX0DU9B07EeM@15
ADD0Vi^K07QhN00e=CD0D51@08n?S`1=CDd0FEUI071`L00W9bL0DU9B061PH01nOWh0BTY:0<_;b`1[
Jf/0@T92069RHP2d];@0Vi^K071`L01HF5P0JFUY08j>SP1FEUH0A4A408^;R`2>SXh0De=C0:6QX@2M
WId0I6AT07QhN02:RXX0T92@05=CD`2:RXX0DE5A01PH601OGel0EeMG04M7A`22PX80>SXj03Ph>01H
F5P0=SHf03De=@1PH600BDU904Q8B01fMWH0HF5Q02`/;01BDU80VYZJ0451@@1TI6@0CTi>02XZ:P1R
HV80Ph>30:ZZZP1SHf<0Ph>308R8R02CTi<0<S8b02TY:@17AdL0@41007alO011@D40CDe=03lo?`0a
<C40K6a/06UYJ@0Q8B40ADE50:BTY00_;bl0@D5107UiN@1hN7P0HV9R04M7A`19BDT0GemO08R8R00d
=3@0HF5Q08f=S@1`L700A4A40:NWY`1cLg<0;bl_05aLG01oOgl0D51@08B4Q01WIfL07AdM030`<01D
E5@0GemO03Ti>@17AdL0LW9b06QXJ00X:2P0;bl_05MGE`1]KFd0EEEE05=CD`1:BTX0QHF502LW9`0j
>SX0JFUY06=SH`1:BTX0PX:206MWI`0[:b/0<C4a03<c<`1oOgl0?3`l03hn?P20P800G5aL02XZ:P1n
OWh0@41005iNGP2PX:00VIVI07AdM02_[jl0XJ6Q05EEE@0a<C408b<S04=3@`1cLg<0JVYZ01lO7`0n
?Sh0];Bd05eMG@0H61P0Ti>C03dm?@1SHf<0KVi^04Q8B00W9bL07alO02@T901BDU80L71`0820P01l
O7`0IVIV06m_K`2@T900OWin05UIF@2EUID0SHf=07QhN01mOGd0PH610492@P0n?Sh0C4a<08^;R`00
4`2SXj<0R8R805]KF`23Ph<0ADE5034a<@0M7Ad06a/K01hN7P1>CTh0MGEe05IFEP0m?Cd0=3@d04m?
C`0g=cL0JFUY03lo?`0Q8B400P0M7Ad0LP0P82009RHV03@d=017AdL0Ogmo04A4A00l?3`0Ng]k0:ZZ
ZP2QXJ40RXZ:05EEE@13@d<0@D51059BDP1PH600F5QH05ADE01JFUX0J6QX05ADE01XJ6P0Z:RX0;bl
_02m_Kd0NWYj09JFUP2i^KT0Ti>C04a<C018B4P07AdM02<S8`0^;Rh0<C4a03Ti>@1DE5@0L71`08B4
Q02MWId0Zj^[0<c<c039bLT0QhN705EEE@1SHf<0CTi>04];B`1mOGd0;Bd]02TY:@1GEeL0KVi^06a/
K01JFUX0=cLg03@d=00/;2`0:b/[03Xj>P1eMGD0XZ:R09:BTP2SXj<0[:b/0:n_[`2o_kl0MWIf03Ti
>@0b<S80:BTY034a<@0i>CT0:2PX05aLG035aLD0/K6a059BDP10@400IfMW07moO`1VIVH0FUYJ05eM
G@33`l<0clo?061PH00];Bd0H61P075aL@1]KFd0O7al05YJFP1@D500E5AD05EEE@1dM7@0bLW90=7A
d@1eMGD0;Bd]04E5A@1@D500CTi>07emO@1RHV80ZZZZ07IfMP0W9bL08B4Q020P800X:2P0:b/[05mO
G`805aLG09d0;2`/0;Bd]03@d=00PH6104M7A`0b<S809RHV061PH01@D500<C4a08:2PP2_[jl0N7Qh
07EeM@1GEeL0MWIf0;2`/02ATI40Y:BT0;:b/P2k^k/0QXJ60:j^[P2a/K40Rh^;061PH014A4@0?Cdm
03Ph>00n?Sh0E5AD07YjNP0d=3@0;bl_06EUI@1JFUX0WYjN0;jn_P2`/;00WIfM08F5Q@1bLW80OWin
0861P@2:RXX0VYZJ0<71`@3;bl/0fMWI079bLP0`<300:RXZ02HV9P0h>3P0EeMG09BDU02f][H0Vi^K
08J6QP1]KFd0N7Qh09:BTP33`l<0a/K60;6a/@1dM7@0R8R808F5Q@2IVIT0Xj>S07]kN`2NWYh0PX:2
06EUI@1DE5@0IVIV0:j^[P2ZZZX0_Kfm09bLW02i^KT0_kno0<k>cP3IfMT0];Bd02DU9@0X:2P0VYZJ
0::RXP14A4@0B4Q807IfMP2m_Kd0Shn?04=3@`0f=SH0YjNW0;Ng]`3Kfm/0^k^k08V9R@1mOGd0Ogmo
07UiN@2LW9`0b/[:0<_;b`2CTi<0Vi^K0=7Ad@1fMWH0VYZJ09VIV@2XZ:P0aLG50;Jf]P2?Shl0AdM7
04a<C019BDT0;bl_03dm?@1ADE40E5AD05eMG@2>SXh0X:2P0:b/[02HV9P0TI6A09nOW`2@T900L71`
06QXJ01IFET0Ng]k0=[JfP2YZJT0E5AD06a/K02k^k/0^KVi0=_Kf`33`l<0a<C40<K6aP3?cll0WinO
08V9R@1ZJVX0NWYj05eMG@1ZJVX0^[Zj07MgM`2KVi/0IVIV00;ooooo00008@1LG5`0R8R804e=C@1e
MGD0ADE503Hf=P1@D500G5aL038b<P0V9RH0@d=303Hf=P0l?3`0820P02PX:01[Jf/0A4A403lo?`0l
?3`030`<05]KF`0l?3`05ADE06ATI00g=cL0:RXZ05aLG016ATH0820P05ADE00b<S80@D5105EEE@02
0410@00M07EeM@0X:2P061PH02HV9P0b<S80;Bd]04I6AP0O7al0@T9203lo?`0g=cL0N7Qh04];B`0Q
8B40?Cdm04];B`0o?cl0BDU9034a<@15ADD0H61P08:2PP1hN7P0BDU9069RHP1fMWH0>c/k03@d=01D
E5@00P1;Bd/0b`1VIVH0K6a/03Hf=P1EEED0LG5a03@d=00l?3`0De=C04i>CP0G5aL0?Shn07QhN00N
7Qh0?clo05ADE00T92@0M7Ad03Ti>@1?Cdl0Q8B406QXJ012@T80=SHf07EeM@1OGel0;bl_03lo?`1d
M7@0FEUI06=SH`1ADE40Bd];02HV9P13@d<0CTi>05EEE@0i>CT0BTY:06e]K@1IFET0E5AD09FEU@2G
UiL0CTi>051@D020P800EUIF05eMG@11@D40TI6A07IfMP12@T80HV9R06i^KP0n?Sh0GUiN09NGU`1U
IFD0Fe]K05mOG`0l?3`0YZJV07]kN`0];Bd0IfMW02`/;00o?cl0GUiN08>3P`17AdL0De=C03dm?@0j
>SX0NWYj061PH01YJFT0CTi>02/[:`1OGel0De=C059BDP1MGEd0=3@d04Q8B01]KFd0FUYJ030`<022
PX80A4A401/K6`1=CDd0Rh^;04=3@`1GEeL0LW9b06a/K01BDU80VIVI04m?C`2FUYH0Shn?05YJFP1M
GEd0YZJV05eMG@1HF5P0QHF506e]K@23Ph<0MWIf08b<S01<C4`0_Kfm0:NWY`2@T900KFe]0<?3``2P
X:00De=C05IFEP25QHD0U9BD05eMG@17AdL0MgMg05IFEP10@400OWin09VIV@1YJFT0Kfm_07IfMP1S
Hf<0CDe=0;:b/P1SHf<07AdM06=SH`1WIfL0AdM7096AT@1KFe/0CDe=05MGE`0b<S80>3Ph07inOP1P
H600Bd];07QhN01SHf<08B4Q05UIF@2@T900?clo06e]K@18B4P061PH03/k>`1>CTh0WIfM03De=@1?
Cdl0K6a/0861P@1CDe<0CTi>09^KV`1eMGD0[:b/05=CD`1nOWh0EEEE04];B`1gMgL0GUiN02h^;P19
BDT0UiNG059BDP0^;Rh0BTY:05YJFP0[:b/0<S8b06EUI@20P800R8R805YJFP1<C4`0LG5a08F5Q@11
@D40^[Zj06YZJP1@D500ADE507inOP1QHF40UIFE069RHP1PH600?Cdm0080EeMG04/0820P05IFEP2E
UID0MWIf05aLG00X:2P0C4a<04M7A`0^;Rh0HF5Q07alO02i^KT0JFUY071`L020P800>SXj03De=@1O
Gel0LG5a06ATI01<C4`0?3`l092@T00Q8B40>CTi08B4Q01MGEd0;Bd]07emO@1@D500CDe=08B4Q02E
UID0I6AT0;fm_@2ZZZX0RHV904a<C00_;bl0CTi>06m_K`1mOGd0;bl_04=3@`2^[Zh0LW9b02XZ:P1[
Jf/0AdM702/[:`0f=SH0Ph>308N7Q`1[Jf/0GemO069RHP1JFUX0E5AD01dM7@0I6AT05aLG01TI6@0M
7Ad09RHV03Ti>@2TY:@0GemO07IfMP2WYjL0/;2`07emO@1hN7P0/k>c06i^KP2QXJ400P2VYZH02@1?
Cdl0;Rh^02TY:@0o?cl0Jf][05EEE@11@D40?3`l02DU9@0202@T900V04U9B@1KFe/0GEeM03dm?@0N
7Qh06QXJ01hN7P0Q8B409RHV03@d=01[Jf/0MGEe05iNGP2VYZH0b<S809RHV01JFUX0ATI603`l?00V
9RH09bLW03De=@0n?Sh0ADE504];B`1ADE40Hf=S0;bl_02RXZ80Y:BT0<O7a`2g]kL0^[Zj07inOP2O
Wil0[Zj^069RHP0L71`201/K6`0/02PX:00Y:BT0:2PX030`<00g=cL0IfMW0:>SX`3EeMD0R8R803@d
=01FEUH0EeMG04];B`0U9BD0>c/k09NGU`1_Kfl0@T9202LW9`0N7Qh0820P028R8P0U9BD092@T02HV
9P0T92@09RHV04Q8B02o_kl0`<300:BTY03IfMT0_;bl09VIV@1MGEd0?Shn034a<@0Q8B40;Bd]06e]
K@2UYJD0Ogmo04I6AP1GEeL2059BDP0h05MGE`1`L700PX:208Z:RP2m_Kd0cLg=096AT@2<S8`0[:b/
06UYJ@1NGUh0?3`l024Q8@0M7Ad0:BTY04=3@`1gMgL0aLG50;Ng]`2ZZZX0GUiN03hn?P14A4@0H61P
09FEU@1hN7P0P82005aLG00`<3007alO020P800V9RH08b<S05QHF00G5aL0;Rh^08V9R@1>CTh0>CTi
08F5Q@1?Cdl0;Bd]02PX:00T92@0F5QH07UiN@2e]KD0UYJF03/k>`0Q8B40H61P0<W9b@2i^KT0ZZZZ
0<;2`P2[Zj/209jNWP0o0;jn_P3?cll0QXJ608F5Q@22PX80MWIf07QhN02ATI40^[Zj034a<@0U9BD0
>SXj07alO01GEeL0@D5105IFEP2n_[h0`l?30:b/[01CDe<0DU9B04a<C01=CDd0EUIF0:6QX@3Fe]H0
f][J09NGU`0[:b/0:2PX02LW9`0d=3@0GUiN0;Ng]`3Ph>00i>CT0>;RhP3:b/X0/k>c079bLP1ZJVX0
PX:209FEU@2f][H0`L710:NWY`37alL0LG5a04Q8B019BDT0J6QX08B4Q02YZJT0[Zj^0<?3``3:b/X0
_[jn09JFUP1TI6@0Ph>30:n_[`3>c/h0Zj^[00807AdM04H0=CDe0=;BdP3EeMD0[jn_09fMW@2QXJ40
WYjN0:6QX@2;Rh/0`L710<g=c@1]KFd0EUIF06YZJP2OWil0X:2P09ZJVP2:RXX0RHV909bLW01<C4`0
?Shn0861P@2RXZ80TY:B06MWI`1OGel0d=3@0<?3``2`/;00QhN707alO01dM7@0Bd];03<c<`0h>3P0
F5QH061PH01VIVH0Kfm_07IfMP1kNg/0UIFE0;:b/P2e]KD0];Bd05eMG@1@D500ZZZZ05UIF@22PX80
alO70<71`@2b/[80e=CD0<g=c@2LW9`0N7Qh07]kN`25QHD0OGem05mOG`10@400D51@075aL@2PX:00
`L710<K6aP1JFUX0:RXZ0_ooool0003o05ADE01nOWh0Bd];08^;R`1oOgl0BDU909JFUP29RHT0@D51
03<c<`19BDT0:BTY01/K6`0b<S80:b/[05]KF`0F5QH0820P03`l?00H61P0FUYJ02l_;`0F5QH0B4Q8
01dM7@0Y:BT0JFUY03dm?@0L71`0?3`l02/[:`0e=CD0GemO02DU9@0O7al0@d=303<c<`0K6a/0<C4a
03Lg=`0E5AD0@T9202@T900n?Sh08R8R01hN7P15ADD0GUiN05aLG01IFET0>SXj02HV9P1EEED0=SHf
04];B`1^KVh0FUYJ03Hf=P0W9bL0=SHf05MGE`0k>c/0=3@d05MGE`0T92@0820P03@d=01=CDd0<C4a
06ATI02>SXh0ATI6028R8P0k>c/0@41001XJ6P1@D500QXJ602`/;00X:2P0>CTi02XZ:P20P800EeMG
02l_;`1DE5@0LW9b01lO7`0^;Rh0KFe]08>3P`1<C4`0BDU908^;R`0Y:BT0ATI6079bLP1aLG40?Shn
05EEE@1@D500ATI6024Q8@17AdL0PX:207alO017AdL0Z:RX0;^k^`1;Bd/0<C4a07YjNP1CDe<0D51@
02d];@1ZJVX0JFUY03`l?01KFe/0D51@024Q8@0a<C40P82006i^KP1EEED0?Shn024Q8@1^KVh0NWYj
02l_;`1_Kfl0EUIF03Hf=P10@400KFe]04A4A01<C4`0E5AD04I6AP2NWYh0LW9b071`L01lO7`0@T92
06=SH`1YJFT0EEEE07]kN`1VIVH0GUiN069RHP1=CDd0?clo08:2PP1HF5P0<C4a05aLG02GUiL0@T92
06e]K@29RHT0IVIV059BDP28R8P0C4a<09jNWP2l_;`0QhN704U9B@2RXZ80C4a<069RHP1aLG40Jf][
07YjNP1_Kfl0AdM703De=@2CTi<0VYZJ07UiN@1YJFT0`/;20::RXP0i>CT0<S8b069RHP1bLW80>CTi
04E5A@2:RXX0RHV9069RHP1hN7P0WIfM05eMG@1TI6@0RXZ:0820P00m?Cd0J6QX055AD@0O7al0DU9B
04m?C`1LG5`0Ti>C06UYJ@19BDT0FUYJ02HV9P0P8200Jf][079bLP12@T80N7Qh075aL@0d=3@0ATI6
09ZJVP0];Bd0HV9R07alO00e=CD0DE5A06IVIP2VYZH0Fe]K06UYJ@1VIVH0JVYZ03Lg=`1BDU80^[Zj
08^;R`2j^[X0@D5104Y:BP24Q8@0EUIF0:FUY@1HF5P08b<S04m?C`1aLG40GemO03Ti>@1RHV80HF5Q
04A4A015ADD0A4A404i>CP1bLW80>3Ph001?06IVIP1hN7P0EEEE034a<@2CTi<0Zj^[05iNGP14A4@0
IfMW02l_;`18B4P0KFe]07IfMP0o?cl0IFEU05aLG00H61P0;Rh^05aLG01]KFd0GEeM02LW9`1<C4`0
Cdm?024Q8@0n?Sh0@T9209>CT`1SHf<0LW9b08F5Q@1aLG40=CDe05IFEP1DE5@0?3`l03Xj>P1:BTX0
X:2P030`<00/;2`0EUIF055AD@0i>CT0S8b<05eMG@1XJ6P0TY:B08V9R@1GEeL0VIVI09BDU01MGEd0
?Shn06][J`2[Zj/0XJ6Q06QXJ00d=3@0IfMW0:f][@23Ph<0<c<c07MgM`1?Cdl0CDe=038b<P0X:2P0
NGUi08^;R`0b<S808B4Q04I6AP1VIVH071`L01HF5P0G5aL05ADE01HF5P0201DE5@0B05QHF02GUiL0
A4A406a/K03AdM40bl_;092@T01nOWh0XZ:R09FEU@1EEED0Shn?06e]K@1TI6@0OWin05aLG00e=CD0
:2PX0P0V9RH0200U9BD092@T024Q8@0b<S80Cdm?079bLP12@T80=cLg0P0L71`0=00M7Ad07alO02TY
:@1<C4`0T92@0<K6aP2CTi<0ZZZZ09^KV`1;Bd/0>SXj03Ph>00_;bl0:2PX02LW9`0b<S80<30`02l_
;`12@T80C4a<06QXJ02_[jl0T92@09fMW@2c/k<0c/k>0:JVYP1kNg/0>CTi051@D00V9RH071`L01TI
6@0O7al0820P02DU9@0/;2`0:b/[02h^;P1JFUX0]kNg075aL@14A4@0EUIF04i>CP1<C4`09RHV01`L
701/K6`0<C4a01`L700K6a/201`L700E020P800U9BD08R8R02DU9@0T92@0>3Ph08>3P`22PX80_;bl
0<K6aP3MgMd0`L710;Bd]02UYJD0K6a/06=SH`24Q8@0P82008F5Q@1QHF409RHV008071`L00l07AdM
02PX:00c<c<0@d=305mOG`2DU9@0b<S80<?3``2`/;00clo?0<g=c@2/[:`0Bd];04m?C`0c<c<00P0O
7al09`0Z:RX0LW9b0<G5a@35aLD0];Bd09RHV01OGel0JFUY092@T02JVYX0[:b/06QXJ01<C4`0BTY:
02PX:00W9bL0:BTY02PX:01OGel0=CDe06m_K`1:BTX0A4A401XJ6P0S8b<0FEUI04a<C00`<300:RXZ
020P801eMGD0^k^k069RHP0M7Ad08R8R04=3@`3EeMD0hN7Q0;2`/00208n?S`2908F5Q@2<S8`0YJFU
0;6a/@1MGEd0MWIf0:2PX02l_;`0b/[:0<O7a`2o_kl0B4Q803De=@0f=SH0J6QX03dm?@0W9bL0>c/k
0<g=c@3;bl/0a<C407MgM`0Y:BT0:2PX02<S8`0];Bd0/K6a0;>c/`1fMWH0`l?304U9B@0S8b<09bLW
03/k>`1lO7`0^[Zj08^;R`1YJFT0Q8B40:^[Z`31`L40Xj>S051@D019BDT0[Jf]0<71`@2CTi<0g=cL
0>3Ph01eMGD0?3`l03Ti>@0o?cl0Bd];06=SH`2MWId0`l?30;6a/@2NWYh0ZJVY06UYJ@1oOgl0XJ6Q
0;jn_P2/[:`0;Bd]03lo?`2IVIT0YJFU096AT@2WYjL0_[jn0:2PX01mOGd0[jn_0=SHf02a/K40R8R8
0861P@1XJ6P0Fe]K05=CD`1/K6`0GemO04Y:BP15ADD0>CTi01<C4`0@41006QXJ04I6AP2GUiL0a/K6
0:^[Z`2CTi<0HF5Q03Lg=`0i>CT0ADE506][J`2CTi<0Z:RX08F5Q@2?Shl0RXZ:08N7Q`1iNGT0KVi^
06YZJP24Q8@0UIFE09:BTP2EUID0EEEE07=cL`2a/K409BDU03Ti>@3Bd]80f][J0=GEe@34a<@0^;Rh
06IVIP1@D500AdM70492@P0o?cl0N7Qh05aLG01_Kfl0Ng]k09^KV`2/[:`0_[jn04Q8B00M7Ad00_oo
ool0002/059BDP1MGEd0<S8b05]KF`1fMWH0ATI60:2PX02>SXh061PH020P801=CDd0@D5102LW9`0U
9BD0:RXZ06i^KP1?Cdl0:RXZ03Ti>@0D51@0CTi>04=3@`0Q8B40ADE502TY:@0G5aL0G5aL059BDP0e
=CD0DE5A01hN7P0W9bL0IFEU05aLG00a<C40DE5A03Ph>00I6AT0De=C04Y:BP0h>3P0A4A401dM7@1@
D500A4A4024Q8@11@D40?clo02XZ:P19BDT0IfMW038b<P1=CDd08b<S04Q8B01[Jf/0I6AT06e]K@13
@d<0>CTi07EeM@0E5AD09bLW061PH01HF5P0<C4a0410@00l?3`03`l?02/[:`1RHV80Fe]K02<S8`15
ADD0=cLg00h>3P0_;bl0IfMW03Lg=`0e=CD0>SXj01DE5@1ADE40EEEE034a<@1LG5`0KVi^03@d=00S
8b<0AdM706m_K`1:BTX0FEUI096AT@11@D40AdM7059BDP1FEUH0@d=3061PH01ZJVX0AdM702PX:00V
9RH0B4Q807EeM@0j>SX0T92@0;bl_01]KFd0@D5107EeM@1CDe<0RHV906QXJ02?Shl0FEUI03`l?01W
IfL0H61P05IFEP12@T80LW9b06=SH`1FEUH0L71`04Q8B02JVYX0Shn?0410@021PH40MGEe0492@P11
@D40EeMG03Ph>01JFUX0I6AT04U9B@2OWil0@T9207]kN`2>SXh0A4A405UIF@0_;bl0@T9207QhN01P
H600E5AD06QXJ011@D406QXJ06ATI01_Kfl0ADE505IFEP29RHT08R8R04e=C@1hN7P0Fe]K075aL@1d
M7@0=3@d06MWI`1iNGT0KVi^03/k>`2>SXh0A4A4051@D080IfMW04/0KVi^05aLG01TI6@0@d=308f=
S@2ZZZX0T92@05iNGP2k^k/0Y:BT07UiN@1>CTh0P82008f=S@0h>3P0@d=307QhN02CTi<0L71`07Qh
N02d];@0>CTi05QHF02BTY80UIFE04i>CP2<S8`0Hf=S02h^;P1VIVH0K6a/03Ph>02@T900Kfm_069R
HP1_Kfl0GUiN02/[:`1bLW80EUIF03lo?`29RHT0Shn?05UIF@19BDT0YZJV03De=@1DE5@0LG5a02TY
:@1>CTh0L71`0::RXP1SHf<0FEUI07IfMP24Q8@0FEUI075aL@3Fe]H0Lg=c0;2`/019BDT0C4a<08Z:
RP1ADE40QhN7075aL@0c<c<0Bd];07moO`1YJFT0>3Ph05eMG@1ZJVX00P1DE5@0:01[Jf/0SHf=0:2P
X013@d<0Bd];05UIF@1[Jf/0<30`08F5Q@26QXH0B4Q805=CD`1[Jf/0ATI6059BDP1PH600AdM703@d
=01lO7`0GUiN02LW9`18B4P0GemO05iNGP12@T80;Rh^05IFEP1DE5@09bLW055AD@1?Cdl0Y:BT055A
D@1<C4`0O7al06EUI@12@T80IfMW06][J`15ADD203@d=011079bLP0i>CT0?Shn07alO00m?Cd09BDU
07IfMP15ADD0?3`l08R8R02;Rh/0J6QX0;Bd]02g]kL0IFEU0410@00S8b<0@T9205IFEP1HF5P0:2PX
03dm?@2EUID0GemO01`L701^KVh0@D5104M7A`1LG5`0PH610:n_[`2f][H0IVIV04I6AP1WIfL0JVYZ
055AD@16ATH0=cLg01XJ6P0C4a<05ADE01@D500K6a/0QhN706ATI01BDU80bLW909NGU`17AdL0>c/k
05]KF`2f][H0N7Qh05YJFP2TY:@0_[jn07MgM`1HF5P0@D5103<c<`0S8b<07QhN01`L700I6AT00P0L
71`05@0];Bd0J6QX05iNGP0e=CD0;bl_02HV9P0Z:RX09BDU038b<P1`L700];Bd0:j^[P1kNg/0NGUi
0;Bd]019BDT0<C4a030`<00/;2`0:2PX024Q8@0202HV9P0R02LW9`0Y:BT0;Rh^0492@P2/[:`0WIfM
0:j^[P2i^KT0Z:RX0;no_`1^KVh092@T02d];@1CDe<09bLW01TI6@0L71`07AdM01lO7`0R8R808B4Q
02DU9@1BDU80_;bl0;jn_P1iNGT0PH6107IfMP1bLW80<30`01`L701VIVH0=cLg01dM7@<071`L03l0
7AdM02LW9`0U9BD08b<S03Xj>P1UIFD0D51@05EEE@2d];@0YjNW0<o?c`2o_kl0bLW90:^[Z`2h^;P0
^KVi0<[:bP21PH40?3`l01hN7P0L71`06a/K01XJ6P0K6a/07AdM01hN7P0X:2P0;Rh^059BDP2b/[80
_Kfm0820P02l_;`0dM7A0;Zj^P1OGel0ADE502d];@0M7Ad092@T02TY:@1bLW80`l?308R8R02JVYX0
_Kfm09fMW@2BTY80Q8B409jNWP1_Kfl0GEeM05EEE@1CDe<0@d=303<c<`0Y:BT09BDU07inOP1bLW80
=cLg01dM7@0L71`00P0J6QX0I`0N7Qh0Bd];04U9B@10@400>c/k06QXJ02l_;`0Ng]k03/k>`1_Kfl0
N7Qh0=WIf@3:b/X0bLW90<g=c@2JVYX0Ph>307MgM`2JVYX0Vi^K0:b/[02ATI40EUIF03hn?P0i>CT0
<c<c0492@P1gMgL0TY:B08R8R01eMGD0@T9203De=@1jNWX0^k^k092@T02YZJT0`L7108>3P`1MGEd0
;2`/07EeM@3Hf=P0S8b<04e=C@2LW9`0UIFE03hn?P0S8b<0=cLg06EUI@2@T900ADE503Ti>@1dM7@0
NGUi09nOW`1lO7`0[:b/09RHV02c/k<0[Zj^0<?3``3QhN40dM7A09jNWP0n?Sh0?3`l0492@P1>CTh0
Hf=S08V9R@37alL0PH6108>3P`27QhL0b<S80;2`/02[Zj/0OGem0:BTY037alL0/K6a05EEE@12@T80
DU9B0410@00f=SH0J6QX09VIV@3Jf]X0dM7A07=cL`1:BTX0@D51051@D01aLG40UIFE09^KV`1kNg/0
GemO03/k>`0C4a<00P0>3Ph03P0@4100;Bd]05QHF02KVi/0bLW905IFEP0n?Sh07AdM01XJ6P0M7Ad0
8B4Q02l_;`2GUiL0<C4a0P0[:b/0800e=CD0>c/k065QH@1gMgL0[Jf]0:n_[`2WYjL0SXj>0=GEe@3M
gMd0b/[:055AD@1mOGd0XJ6Q0<?3``2@T900F5QH02LW9`0[:b/0;Rh^04Q8B01SHf<0L71`05mOG`2G
UiL0R8R80:JVYP2PX:00UiNG07inOP24Q8@0A4A40_ooool0003W05IFEP1[Jf/0CTi>05MGE`1oOgl0
>SXj08Z:RP2HV9P0;2`/024Q8@0m?Cd0ATI602HV9P0J6QX06a/K075aL@1LG5`09RHV03Xj>P0820P0
=3@d065QH@0X:2P0:RXZ04U9B@0A4A40=SHf04];B`0l?3`0GEeM03De=@0U9BD0Bd];04A4A00Z:RX0
?clo03Ti>@0<30`08B4Q03Ph>00g=cL0>3Ph014A4@0d=3@0D51@02<S8`1BDU80<30`01HF5P0Q8B40
Fe]K02TY:@19BDT06QXJ03@d=015ADD0KVi^07IfMP1CDe<0<C4a05ADE00Y:BT0820P03/k>`1@D500
:BTY04a<C01@D500;bl_03Xj>P1SHf<0DU9B02TY:@1?Cdl0Hf=S01XJ6P0`<300MgMg030`<00g=cL0
@T9202HV9P1WIfL0GEeM02d];@1`L700KVi^05=CD`0_;bl0FUYJ06ATI00f=SH0EeMG09ZJVP1]KFd0
FEUI06MWI`17AdL0;Bd]05mOG`2;Rh/0JFUY04A4A00i>CT0B4Q805eMG@0/;2`0Ng]k08n?S`1iNGT0
@T9205]KF`0G5aL0K6a/06m_K`2<S8`0F5QH01TI6@1DE5@0M7Ad05eMG@14A4@0M7Ad03De=@1=CDd0
QHF504I6AP21PH40EEEE02LW9`1SHf<0J6QX03hn?P16ATH0A4A402h^;P0i>CT0GEeM03Ti>@2;Rh/0
C4a<05]KF`1^KVh0>c/k07EeM@1PH600ADE506UYJ@1WIfL0DE5A0:>SX`1FEUH0<c<c06i^KP1FEUH0
:b/[04I6AP2PX:00J6QX05=CD`1/K6`0ATI6071`L028R8P0G5aL07=cL`2DU9@0CDe=04E5A@2FUYH0
LW9b05mOG`1aLG40Bd];06][J`2ATI40Ph>305MGE`20P800ZJVY04E5A@1BDU80`/;20:n_[`20P800
EUIF07=cL`2CTi<0K6a/03Ti>@1/K6`0U9BD07AdM02JVYX0_[jn07moO`1<C4`0O7al079bLP0m?Cd0
P82005eMG@0H61P0FUYJ06e]K@0k>c/0WIfM0451@@0l?3`0I6AT06IVIP0_;bl0N7Qh04Q8B00_;bl0
Kfm_07AdM00W9bL0Cdm?0:^[Z`1=CDd0DE5A06][J`0Z:RX0@D5105=CD`2EUID0ATI606m_K`2HV9P0
Y:BT0080Hf=S06H0aLG506i^KP2MWId0FUYJ07IfMP2OWil0GemO08>3P`1OGel0>SXj06a/K02YZJT0
R8R803Xj>P1_Kfl0Jf][02LW9`0];Bd0@T9204M7A`1SHf<0F5QH04Y:BP1=CDd0LW9b03lo?`2g]kL0
a/K604a<C01;Bd/0LW9b05IFEP1PH600IFEU05iNGP0e=CD0FUYJ05MGE`0_;bl0G5aL09nOW`21PH40
7QhN02d];@1IFET0GEeM030`<01LG5`0PX:20:f][@1VIVH0EeMG07moO`1CDe<0<C4a04i>CP1BDU80
@T9203`l?00_;bl0R8R802HV9P0[:b/0H61P05MGE`0a<C40Ti>C05=CD`0m?Cd0JFUY07IfMP1=CDd0
[jn_0:f][@1gMgL0FEUI03/k>`1CDe<0M7Ad07QhN00f=SH0?clo09VIV@1jNWX0<C4a07UiN@2d];@0
^k^k0;>c/`2][Jd0a/K6092@T02b/[80VIVI05iNGP12@T80@D5103/k>`0l?3`0B4Q803hn?P0T92@2
01DE5@0N03@d=02_[jl0WIfM0=7Ad@25QHD0?Shn05=CD`1`L700FUYJ0492@P1HF5P0UIFE05UIF@1@
D500DE5A05eMG@1UIFD0G5aL05MGE`1FEUH0@41003<c<`0S8b<0820P03Hf=P2YZJT0TY:B08N7Q`2=
SHd0V9RH0P2;Rh/0<P38b<P0`<300<K6aP2d];@0/;2`0<k>cP2j^[X0KVi^03/k>`0S8b<0:2PX02/[
:`0K6a/07QhN03Lg=`1<C4`0GUiN04a<C01iNGT0GUiN04];B`29RHT0RXZ:04m?C`26QXH0?clo02PX
:00Z:RX0ADE501dM7@0E5AD06a/K01`L700T92@0=cLg05]KF`1_Kfl0Zj^[0;fm_@1[Jf/0IfMW05iN
GP1;Bd/0ATI603Lg=`1fMWH0K6a/020P800L71`06ATI0`0L71`04@0];Bd0?Shn05QHF018B4P0E5AD
06ATI01WIfL0NWYj0<S8b02WYjL0YZJV06m_K`1BDU80CTi>0;Ng]`1cLg<08R8R008071`L00@06QXJ
01HF5P0L71`06ATI0P0J6QX01P0R8R80>3Ph09:BTP2QXJ40Rh^;06QXJ080];Bd0100;bl_02HV9P0Q
8B407alO024Q8@16ATH0Ph>30;Fe]@1kNg/0KFe]08j>SP1_Kfl0Jf][06e]K@2BTY80JVYZ0P1BDU80
2`1UIFD0Jf][04m?C`13@d<0GEeM071`L020P80092@T01HF5P0G5aL05ADE00<05aLG05@0=CDe05mO
G`1ZJVX0WYjN06=SH`2OWil0]KFe09FEU@2b/[80NWYj08V9R@1aLG40UiNG06][J`1?Cdl0A4A405EE
E@1fMWH0Shn?08B4Q018B4P0:2PX02DU9@0R8R80<C4a03<c<`1?Cdl0LG5a08V9R@2KVi/0][Jf0=KF
eP2VYZH0C4a<05QHF02QXJ40gmoO0=cLg035aLD0]KFe0=SHf02a/K40DU9B05]KF`3?cll0L71`03De
=@1>CTh0UYJF05iNGP0M7Ad06a/K02LW9`0V9RH09BDU01`L700k>c/0^[Zj0:FUY@3@d=00g]kN0<K6
aP29RHT0V9RH09ZJVP1lO7`0J6QX04a<C011@D40D51@09fMW@2HV9P0X:2P0;^k^`3Jf]X0e]KF05MG
E`1/K6`0c/k>0=KFeP2TY:@0EUIF03Ph>00P820201`L700602/[:`1NGUh0`l?30=3@d02`/;00RHV9
0P1nOWh04@2QXJ40^[Zj0:>SX`2d];@0`L71092@T00i>CT06a/K01LG5`0C4a<0820P065QH@2a/K40
Y:BT06IVIP0a<C407AdM008071`L02H06a/K024Q8@1GEeL07alO01`L700M7Ad08B4Q02@T900d=3@0
JVYZ06m_K`22PX80c/k>0=WIf@3Fe]H0e=CD0<S8b03;bl/0fMWI0:JVYP2_[jl0IfMW02@T900L71`0
7AdM01/K6`0M7Ad07alO03<c<`2TY:@0alO70;2`/02f][H0d=3@0;Bd]022PX80L71`05aLG0;ooooo
0000I@1HF5P0N7Qh06i^KP1HF5P0VIVI03dm?@25QHD0^;Rh071`L00f=SH0DE5A065QH@0[:b/0AdM7
03/k>`1kNg/0FUYJ028R8P11@D40;Bd]04E5A@1eMGD0:BTY01/K6`0T92@04a<C051@D018B4P0?clo
04U9B@0U9BD0?3`l069RHP1EEED09bLW030`<00a<C40:BTY03Lg=`0i>CT0>3Ph03@d=00Z:RX0<c<c
03hn?P0Y:BT0Kfm_06QXJ00k>c/0AdM705eMG@0_;bl0FUYJ04a<C016ATH0E5AD07UiN@1MGEd0B4Q8
02`/;01]KFd0D51@02XZ:P0l?3`0<30`01dM7@1ADE40JVYZ04=3@`11@D40GEeM03De=@0Q8B40DU9B
07QhN00U9BD0:b/[071`L00F5QH07QhN055AD@0^;Rh0Hf=S04=3@`0K6a/0HF5Q07inOP1DE5@0=CDe
07IfMP1kNg/0=cLg05ADE02XZ:P0Fe]K04E5A@1jNWX0GUiN03De=@1<C4`0HF5Q0080>c/k0:H0<c<c
04E5A@1VIVH0?Cdm0;6a/@2PX:00N7Qh03`l?023Ph<0GUiN07EeM@1QHF40Q8B408^;R`12@T80Cdm?
071`L01QHF40@T9206][J`1LG5`0@D5105aLG019BDT0GUiN09>CT`12@T80KFe]075aL@16ATH0Cdm?
079bLP1PH600EUIF04i>CP0T92@0R8R808N7Q`1VIVH0DE5A034a<@1iNGT0M7Ad04i>CP1VIVH08b<S
0410@02XZ:P0NGUi03dm?@1hN7P0MgMg01DE5@0h>3P0S8b<06][J`1HF5P0QhN704Q8B01HF5P0M7Ad
06ATI01RHV80WYjN05mOG`0g=cL0SHf=07AdM01RHV80LW9b04i>CP11@D40LG5a08R8R01OGel0NWYj
0;6a/@18B4P0?Cdm0:n_[`2j^[X0OWin059BDP2RXZ80Zj^[08:2PP0m?Cd0I6AT08^;R`1EEED0LG5a
0:ZZZP2@T900H61P09VIV@20P800E5AD05IFEP24Q8@0:RXZ05=CD`1LG5`0C4a<0:b/[02:RXX0KFe]
07moO`13@d<08b<S07EeM@1LG5`0BTY:0:>SX`2:RXX0@D5103`l?02a/K40@D5106ATI01eMGD0?Cdm
03`l?01=CDd0Xj>S04Y:BP0n?Sh0CDe=0492@P1=CDd0Bd];0;:b/P1eMGD0V9RH03hn?P1;Bd/0J6QX
04];B`2=SHd0EUIF02DU9@0W9bL0CDe=06a/K00i>CT0KVi^05aLG00d=3@0@D5104=3@`18B4P0Ogmo
06IVIP1DE5@0DE5A06][J`0X:2P0DE5A08J6QP1OGel0De=C07inOP0o?cl0FEUI065QH@1YJFT0@D51
0P1GEeL0D00c<c<08R8R04M7A`1GEeL0AdM702LW9`10@400Fe]K01LG5`0_;bl0>c/k08J6QP1XJ6P0
D51@0861P@1hN7P0?clo051@D01TI6@0H61P05ADE00c<c<0K6a/03Xj>P0];Bd0HV9R06EUI@0e=CD0
QhN7071`L01CDe<0Ng]k08J6QP1EEED0^k^k0<S8b02@T900IfMW0410@01JFUX0Lg=c07UiN@0f=SH0
?Shn096AT@26QXH0>c/k07IfMP1jNWX0NGUi09FEU@1XJ6P0UYJF079bLP1HF5P0MgMg09NGU`2RXZ80
JFUY0451@@13@d<0?Cdm02h^;P16ATH0Bd];02LW9`0h>3P0c<c<0<71`@3Bd]80][Jf06a/K01aLG40
KFe]02h^;P0X:2P0@T920:^[Z`26QXH0Bd];0P0c<c<00`0j>SX0ATI605QHF00204a<C00e055AD@1I
FET0EUIF06=SH`2YZJT0MWIf06a/K01ADE40?3`l03Ti>@11@D40Y:BT0;Bd]03AdM40`l?30;6a/@33
`l<0Xj>S0<;2`P2HV9P0KFe]02TY:@0P82009BDU051@D01WIfL0EEEE03Xj>P0W9bL0Cdm?05eMG@0X
:2P0;Bd]07QhN01gMgL0IVIV0861P@15ADD0>3Ph03lo?`19BDT0:RXZ02h^;P1@D500FUYJ05EEE@19
BDT0@T9206][J`2@T900_[jn09BDU02<S8`00P2;Rh/0802<S8`0_Kfm0<W9b@1[Jf/0=CDe020P800L
71`06ATI01PH600R8R80CDe=04Q8B012@T80AdM707inOP1ADE40Ph>30=7Ad@2j^[X0/;2`07IfMP0j
>SX0<C4a06m_K`1ADE408b<S01/K6`0L71`06a/K01`L700I6AT06a/K0P0L71`0300J6QX0:2PX071`
L01_Kfl0Zj^[06ATI02;Rh/0UiNG05mOG`0S8b<07alO03@d=080G5aL00H0@D5105YJFP1iNGT0I6AT
06=SH`10@40203Hf=P150492@P1/K6`0CTi>05]KF`1:BTX0DE5A09:BTP24Q8@0Hf=S03hn?P1DE5@0
DU9B01LG5`0E5AD05aLG01DE5@0H61P06QXJ01LG5`0U9BD0WYjN09FEU@2;Rh/0NWYj0=CDe02k^k/0
MgMg07UiN@12@T80<30`05ADE010@400=3@d0410@00l?3`0?Cdm069RHP1QHF40SHf=08N7Q`1]KFd0
CDe=05EEE@1WIfL0YZJV0;2`/01mOGd0JFUY059BDP30`<00Xj>S04a<C015ADD0FUYJ0<O7a`3Lg=`0
f=SH0;Ng]`3=cLd0g=cL0;jn_P2>SXh0f=SH0;jn_P1dM7@0UYJF08Z:RP10@4005QHF00<05aLG00P0
5ADE01LG5`0N7Qh0EeMG05=CD`3Fe]H0gMgM0:NWY`80IFEU02h0]KFe07YjNP1LG5`0IfMW05aLG01U
IFD0WinO08^;R`1IFET0MGEe07inOP37alL0aLG50<_;b`2_[jl0bl_;0;6a/@12@T809BDU01dM7@0J
6QX06a/K01hN7P1QHF40[Zj^0;bl_02QXJ40DE5A05ADE01UIFD0W9bL0:NWY`2QXJ40Q8B409^KV`38
b<P0_;bl08F5Q@1NGUh0DE5A08J6QP2NWYh0QHF507YjNP1lO7`0:RXZ0P0L71`0100K6a/07AdM02TY
:@0N7Qh2020P800D02LW9`0U9BD08b<S02`/;01LG5`0QhN70:RXZ03Hf=P0`/;20:JVYP2DU9@0KVi^
0<71`@3Lg=`0gmoO0:JVYP1<C4`07QhN01dM7@0L71`401dM7@0905]KF`3<c<`0d];B0<G5a@3Bd]80
d=3@08b<S01DE5@0GEeM00;ooooo0000o`1>CTh0G5aL05YJFP1@D500Kfm_02PX:01IFET0QHF5059B
DP0_;bl0AdM702TY:@0S8b<0A4A403@d=01aLG40:b/[02HV9P1ADE40?clo034a<@1GEeL05aLG02<S
8`0e=CD06a/K03hn?P1;Bd/06a/K04=3@`16ATH0@D5106YZJP0o?cl071`L02d];@1WIfL0FEUI03Lg
=`11@D40:b/[03dm?@1CDe<0;bl_02h^;P0G5aL0?Shn05eMG@0b<S80@T9203@d=00>3Ph0C4a<0451
@@10@400HV9R07=cL`0o?cl0@D5101LG5`1@D500BDU902PX:00n?Sh0BDU902TY:@0n?Sh0B4Q804E5
A@12@T80LW9b069RHP0Q8B40;2`/05eMG@0S8b<0:2PX07alO00a<C407alO03lo?`0W9bL0H61P07Mg
M`0/;2`0GEeM07QhN00Q8B40820P05IFEP1cLg<0De=C06ATI033`l<09bLW02l_;`1YJFT0OWin04A4
A01JFUX0Ti>C03/k>`0Z:RX08B4Q06][J`2;Rh/0B4Q807]kN`2^[Zh0Ph>3020P801UIFD0J6QX06UY
J@1OGel0EUIF08>3P`1:BTX0De=C079bLP0`<300BTY:08R8R023Ph<0EeMG07AdM01HF5P0JFUY0:VY
Z@1BDU80LG5a04E5A@0l?3`0EEEE071`L01MGEd0DE5A04I6AP0[:b/0Hf=S08Z:RP1JFUX0JVYZ04Y:
BP24Q8@0J6QX04e=C@1eMGD0PH6104U9B@2RXZ80De=C0451@@1oOgl0Ph>3055AD@0g=cL0VIVI07Ee
M@0j>SX0JVYZ06IVIP2IVIT0XZ:R06EUI@1RHV80][Jf0861P@0l?3`0VYZJ04U9B@1BDU80KFe]07Ui
N@1ADE40Ph>305MGE`13@d<0D51@092@T01DE5@0;Bd]07alO02ATI40KVi^0451@@2:RXX0U9BD071`
L01@D500Ti>C0;2`/01eMGD0IfMW0:FUY@1cLg<0>c/k05mOG`26QXH0GemO05IFEP1VIVH0=CDe079b
LP1hN7P0=cLg08n?S`1=CDd0DU9B06m_K`1iNGT0;Rh^06i^KP1XJ6P0;bl_05eMG@1lO7`0CTi>03Xj
>P2/[:`0Bd];03/k>`1TI6@0<c<c03Xj>P1:BTX0Xj>S06a/K01<C4`0HF5Q05=CD`1GEeL0IVIV0;Fe
]@23Ph<0VIVI04A4A01HF5P0PH6105aLG021PH40IFEU04Y:BP0X:2P0DE5A07alO016ATH0OWin065Q
H@0f=SH0BTY:0451@@17AdL0S8b<06QXJ000MP1ADE40E5AD07UiN@18B4P0L71`0:ZZZP1;Bd/0AdM7
08R8R01OGel0@d=304Q8B01IFET0ATI605eMG@1<C4`0@41003/k>`1FEUH0GemO034a<@0Q8B40=cLg
05]KF`0X:2P0BDU904];B`2CTi<0NGUi04a<C027QhL0Ogmo04Y:BP1@D500J6QX04i>CP18B4P0=3@d
06i^KP1ADE40>SXj05mOG`1EEED0=CDe09VIV@22PX80CDe=07inOP22PX80=SHf06IVIP2SXj<0Shn?
05mOG`11@D40FUYJ07AdM018B4P0;Rh^06IVIP2][Jd0Ti>C03Xj>P1TI6@0G5aL07IfMP1YJFT0F5QH
09:BTP1MGEd0>3Ph02`/;00_;bl0A4A407moO`2YZJT0EeMG02`/;00b<S80:b/[03<c<`2NWYh0MGEe
0=;BdP3Ph>00Ng]k0820P02UYJD0V9RH05MGE`11@D40OWin0;Vi^@2TY:@0OGem09jNWP2h^;P0TY:B
05EEE@0o?cl0ATI60492@P0h>3P0;Rh^02d];@0_;bl0RXZ:0:6QX@2RXZ80?Cdm04i>CP1KFe/0?Cdm
04U9B@1KFe/0_kno0<g=c@3@d=0209>CT`0909:BTP20P800V9RH0<S8b02VYZH0Ogmo09BDU01SHf<0
<C4a00806a/K03H06ATI028R8P11@D409bLW02DU9@0m?Cd0WYjN06e]K@1TI6@0Ph>303hn?P0e=CD0
CDe=06EUI@1^KVh0GEeM05IFEP1?Cdl0A4A403/k>`13@d<0YjNW0<?3``20P800Kfm_071`L01ZJVX0
CDe=07UiN@1NGUh0GemO07QhN01SHf<0?Shn02TY:@0W9bL0=3@d02DU9@0k>c/0@41005eMG@1hN7P0
BDU90;6a/@3Ti>@0dm?C09JFUP1WIfL0;bl_03/k>`13@d<0CDe=04M7A`0N7Qh201`L700Z01LG5`0J
6QX06a/K01/K6`0G5aL06a/K03dm?@2e]KD0FEUI0:ZZZP35aLD0T92@08^;R`1nOWh0N7Qh05IFEP1Q
HF40@T9202d];@0Y:BT0<30`07IfMP1GEeL0F5QH03Ph>00d=3@0;bl_038b<P1?Cdl0OGem06QXJ02<
S8`0H61P079bLP2;Rh/0@d=3038b<P0j>SX0JFUY02HV9P0H61P05QHF0P0G5aL201PH600902LW9`28
R8P0DE5A08R8R01lO7`0d=3@092@T01TI6@0<C4a00808R8R02H09bLW055AD@0W9bL0:b/[03dm?@11
@D40B4Q80451@@0];Bd0EEEE0:6QX@3Fe]H0clo?0;fm_@3GemL0][Jf05mOG`0h>3P0<S8b08Z:RP1/
K6`0EeMG04Y:BP1?Cdl0alO70<G5a@1JFUX0=3@d03Lg=`1SHf<0PH610:ZZZP3Shn<0gmoO0;Zj^P2o
_kl0J6QX02PX:0@05aLG05<06QXJ01LG5`0K6a/0ATI608J6QP33`l<0dM7A0;:b/P1eMGD0PH610:BT
Y028R8P0DE5A03@d=00R8R80<S8b0:>SX`2?Shl0JVYZ08b<S02NWYh0a<C40<O7a`1lO7`0GUiN0:RX
Z033`l<0ATI602/[:`0J6QX071`L01dM7@0Q8B40Kfm_0;no_`32`/80`L7107MgM`2DU9@0QhN7075a
L@1GEeL0A4A4034a<@0^;Rh0EEEE07inOP0o?cl0IFEU0;Rh^02l_;`0WYjN0:>SX`2>SXh0];Bd05UI
F@0h>3P0:BTY020P800X:2P08b<S01`L700V9RH092@T02DU9@0W9bL08b<S02XZ:P1KFe/0eMGE0<W9
b@38b<P0[Jf]0:2PX02BTY80RXZ:0<g=c@34a<@0clo?06m_K`0X:2P071`L01dM7@0301`L700;028R
8P0d=3@0W9bL06a/K01eMGD0[jn_0;:b/P37alL0];Bd08B4Q01RHV800_ooool0000B07UiN@1LG5`0
ADE5055AD@1mOGd0BDU904M7A`2BTY80<S8b02d];@1GEeL0CTi>02PX:00n?Sh0<30`06YZJP0e=CD0
5QHF0P0g=cL0T`0S8b<0CDe=028R8P0@4100:RXZ01LG5`0n?Sh0E5AD03Hf=P0e=CD0?clo02@T901S
Hf<0C4a<01lO7`0R8R80J6QX04A4A019BDT0Bd];03De=@0b<S80:BTY02h^;P0b<S80A4A406ATI01J
FUX0<C4a04M7A`1QHF40?Shn05=CD`0[:b/0C4a<0861P@1oOgl0Ng]k06QXJ00L71`0IFEU03@d=00Q
8B40F5QH04m?C`0f=SH0E5AD04E5A@0M7Ad0;2`/06i^KP1]KFd0;bl_038b<P1KFe/04A4A02@T901j
NWX0Cdm?02DU9@1YJFT05ADE03Lg=`1cLg<0<S8b059BDP1cLg<0DU9B02`/;017AdL0JVYZ05iNGP1X
J6P0c<c<07MgM`1:BTX0Fe]K04];B`1ADE40Bd];0:6QX@10@400;2`/01PH600f=SH0KFe]03Ti>@1a
LG40/;2`0:2PX011@D40KVi^06e]K@1`L700PH61071`L024Q8@0B4Q805QHF01NGUh0=SHf02`/;01L
G5`0M7Ad05IFEP1ZJVX0;2`/05IFEP2KVi/0DE5A07AdM01KFe/0=cLg04E5A@1HF5P0?3`l05EEE@1D
E5@0ATI6079bLP2<S8`0E5AD0820P01:BTX0Ti>C07IfMP1JFUX0QHF5065QH@1?Cdl0^;Rh07emO@0e
=CD0LW9b08:2PP0[:b/0:RXZ0820P01fMWH0?3`l069RHP14A4@0DU9B06YZJP1KFe/0@d=309RHV002
04Y:BP260:6QX@1TI6@0FUYJ055AD@1GEeL0C4a<08n?S`1hN7P0Cdm?04a<C02`/;00J6QX069RHP2i
^KT0^;Rh07inOP1<C4`0Shn?0:RXZ01QHF40:BTY04Y:BP2HV9P0IVIV05aLG02SXj<0Vi^K04Y:BP1[
Jf/0V9RH07EeM@1CDe<0J6QX02l_;`0a<C40EEEE030`<02?Shl0UYJF05aLG01TI6@0Lg=c03Hf=P1?
Cdl0JVYZ04Q8B01aLG40TY:B05eMG@0j>SX0WinO05mOG`1<C4`0M7Ad04Q8B00g=cL0ATI60;Fe]@1d
M7@0EEEE06m_K`1VIVH0OWin04i>CP2PX:00NGUi09jNWP1HF5P0DU9B09jNWP1iNGT0QHF506QXJ01M
GEd0;Rh^05MGE`26QXH0BDU908f=S@1WIfL0@D5104m?C`0l?3`0@41007=cL`1^KVh0FUYJ05]KF`1`
L700ADE507YjNP2i^KT0De=C04i>CP1mOGd0KFe]04e=C@1BDU80G5aL03dm?@1LG5`0DU9B03@d=00g
=cL0F5QH05]KF`0e=CD092@T03Lg=`1cLg<0:2PX04E5A@1BDU80QhN707MgM`18B4P0XZ:R08N7Q`18
B4P0DE5A06EUI@15ADD0>3Ph05]KF`2_[jl0IFEU034a<@1PH600<c<c020P801_Kfl0IVIV04M7A`1n
OWh205mOG`0:08b<S02VYZH0PH6105aLG011@D40FEUI06][J`1^KVh0<S8b03@d=080NWYj02H0>CTi
069RHP2_[jl0UiNG05iNGP1<C4`0Kfm_09JFUP1MGEd0;bl_02TY:@0W9bL0;bl_03`l?01[Jf/0OWin
04I6AP0[:b/0:2PX04E5A@1hN7P0XJ6Q0<C4a02l_;`0UiNG0;Vi^@3>c/h0a/K60<S8b02BTY80H61P
07alO01WIfL0L71`08b<S03?cll0gMgM0:6QX@80R8R801`0U9BD0:^[Z`2d];@0[jn_0<G5a@1mOGd0
EeMG06YZJP1DE5@0FUYJ03Ph>00c<c<0EEEE0:JVYP2m_Kd0/K6a04e=C@10@400A4A4075aL@2MWId0
aLG50<K6aP3=cLd0b/[:04a<C00P82006a/K0P0L71`08`0I6AT08b<S03Ti>@0L71`09bLW07]kN`2K
Vi/0EEEE07alO02f][H0QXJ608>3P`1bLW80J6QX06=SH`10@400<C4a02`/;00T92@0KVi^092@T02f
][H0U9BD075aL@1TI6@0D51@04m?C`1PH600Kfm_05YJFP1>CTh0Hf=S07emO@1eMGD0PH610080>CTi
0140<30`03Hf=P1<C4`0?3`l06QXJ036a/H0emOG0=;BdP3<c<`0MgMg04I6AP19BDT0<30`0410@01H
F5P0;Rh^01`L700201XJ6P0E01HF5P0J6QX071`L024Q8@0W9bL0Hf=S0=7Ad@3=cLd0YJFU0:JVYP32
`/80];Bd0;bl_03De=@0LG5a03`l?00X:2P07QhN01`L700];Bd0LW9b0080HV9R0140;bl_02`/;00_
;bl09bLW0410@01cLg<0Ogmo06YZJP2JVYX0HF5Q092@T01lO7`0@41003<c<`1GEeL0Kfm_01TI6@02
01DE5@805aLG02H06QXJ065QH@22PX80E5AD051@D01BDU80a<C405IFEP0M7Ad071`L01TI6@0K6a/0
6ATI02XZ:P13@d<0:2PX030`<00i>CT0B4Q803hn?P0W9bL0:BTY03`l?02>SXh0]kNg03hn?P37alL0
b/[:0:JVYP0i>CT0:2PX07UiN@1`L700EEEE05eMG@26QXH0d];B06ATI0<07alO03H09BDU04E5A@11
@D40b<S80>WYj@3Zj^X0eMGE07YjNP0Q8B407AdM01PH600E5AD05QHF01XJ6P0E5AD0:RXZ03lo?`2^
[Zh0clo?0<30`01ADE409BDU02HV9P1LG5`0KVi^01dM7@0N7Qh0?Cdm06a/K01KFe/0Cdm?04U9B@0`
<300Ph>30=GEe@3AdM40De=C03De=@2=SHd0`L710820P00j>SX08R8R01`L700K6a/0:2PX07YjNP2X
Z:P0^k^k0=CDe02ZZZX0AdM7030`<00Y:BT202h^;P0602PX:00W9bL0<S8b069RHP0X:2P0;Rh^0P2W
YjL09P1nOWh0SHf=0;jn_P3Jf]X0_;bl08V9R@21PH40KVi^069RHP0M7Ad08b<S03Hf=P0/;2`0=3@d
0451@@1JFUX0U9BD0;Jf]P2i^KT0^[Zj0<[:bP2d];@0^k^k0<g=c@2/[:`0Vi^K07emO@1jNWX0<S8b
01XJ6P0I6AT071`L01dM7@0L71`07alO04M7A`2ATI40E5AD0P1<C4`01P1jNWX0a<C40;Rh^02CTi<0
Kfm_07alO0;ooooo0000X`1^KVh0GEeM06YZJP0n?Sh0Kfm_05eMG@1<C4`0/k>c03Ti>@0M7Ad0;Rh^
04I6AP0d=3@09BDU01<C4`1RHV80G5aL028R8P10@400820P01HF5P1DE5@0?3`l010@400j>SX03`l?
01dM7@1DE5@0DE5A02l_;`1OGel04a<C03/k>`1MGEd0>CTi034a<@1jNWX0<30`02PX:010@400BTY:
03De=@0[:b/0<C4a04e=C@1@D500MgMg06=SH`0F5QH09bLW05EEE@0m?Cd0Cdm?02DU9@0Z:RX0CDe=
06IVIP1XJ6P0B4Q8024Q8@1VIVH0=SHf01TI6@11@D40C4a<034a<@1>CTh0BTY:03Ti>@0c<c<0CTi>
05iNGP0];Bd0:RXZ06EUI@0S8b<06ATI06ATI019BDT09RHV03`l?00V9RH0?3`l07QhN00c<c<0FUYJ
07alO01_Kfl0>SXj065QH@2>SXh0De=C06=SH`33`l<0RHV906=SH`1nOWh0EUIF05YJFP1BDU80_Kfm
05eMG@19BDT0:b/[05IFEP25QHD0ATI607IfMP2CTi<0P82003Lg=`1kNg/0GEeM05]KF`1bLW80H61P
0:2PX013@d<0B4Q806ATI01DE5@0DE5A09BDU01ZJVX0@D5105eMG@13@d<0GEeM09fMW@0o?cl0I6AT
05=CD`14A4@0M7Ad08B4Q01RHV80BTY:04a<C00Q8B40DE5A08V9R@1;Bd/0H61P034a<@1LG5`0MWIf
05=CD`1RHV80<c<c03De=@1oOgl0GUiN04A4A01`L700SXj>03@d=00U9BD0K6a/07moO`0n?Sh0L71`
07=cL`1_Kfl00P1kNg/0Y017AdL0ZJVY069RHP10@400OGem05]KF`1GEeL0EUIF07alO01>CTh0RXZ:
07moO`1MGEd0BTY:09NGU`2NWYh0PH610<C4a02o_kl0UIFE05=CD`28R8P0TY:B09ZJVP0m?Cd0EUIF
0:j^[P1`L700EEEE09NGU`2OWil0CDe=065QH@2MWId0Ng]k04m?C`1]KFd0>CTi03/k>`1KFe/0<30`
0861P@2PX:00IVIV061PH01iNGT0=cLg04a<C01/K6`0C4a<06EUI@2BTY80EeMG03<c<`2NWYh0HV9R
04E5A@1WIfL0=SHf03De=@1<C4`0^;Rh06MWI`1DE5@0L71`05iNGP1`L700EeMG09jNWP2YZJT0]kNg
06][J`19BDT0VYZJ07MgM`1kNg/0Q8B406a/K00d=3@0E5AD08J6QP1IFET0Rh^;07AdM01GEeL0FEUI
0410@00f=SH0IVIV07alO01FEUH0GemO06e]K@0n?Sh0M7Ad0<?3``1dM7@0E5AD09VIV@1aLG40GEeM
05=CD`1VIVH0AdM7096AT@2DU9@0De=C03Ph>01GEeL0J6QX034a<@0`<300CTi>08b<S01EEED0BTY:
06ATI01aLG40DE5A02l_;`1XJ6P0Ng]k04A4A01LG5`0NGUi03/k>`0N7Qh0;Rh^071`L010@400;2`/
08f=S@15ADD0=SHf07inOP1IFET0?3`l09ZJVP25QHD0L71`08V9R@2WYjL0K6a/0451@@1=CDd0UIFE
09^KV`22PX80=cLg03lo?`29RHT0O7al03Hf=P1aLG40YZJV08R8R01WIfL0BDU9038b<P0c<c<0EeMG
05mOG`0i>CT08R8R0P0O7al04@0R8R80BDU90:NWY`2WYjL0XZ:R07EeM@0n?Sh05aLG03hn?P35aLD0
h>3P0=7Ad@38b<P0_[jn0;Fe]@2TY:@0Xj>S0080UYJF02D0Vi^K08n?S`2QXJ40`L71061PH01@D500
H61P069RHP1_Kfl0QXJ60<;2`P36a/H0G5aL04];B`1<C4`0O7al09>CT`1]KFd0RXZ:092@T015ADD0
OGem09bLW00b<S80;2`/03/k>`1DE5@0^[Zj0;^k^`3<c<`0F5QH0861P@2UYJD0OWin04U9B@0Z:RX0
7AdM00806QXJ02l0>SXj02h^;P0N7Qh0<30`08Z:RP1jNWX0Kfm_0<?3``1jNWX0@d=305IFEP1<C4`0
DU9B075aL@0e=CD08b<S04e=C@1hN7P0HF5Q06a/K01:BTX0De=C05QHF01QHF40GemO06YZJP2ATI40
IfMW07alO01XJ6P0FEUI08B4Q02h^;P0SHf=05YJFP14A4@0@d=3055AD@2IVIT0a/K60<30`02f][H0
^KVi0;jn_P2k^k/0Hf=S06][J`0203lo?`2[04M7A`16ATH07QhN01/K6`0G5aL061PH01XJ6P0Q8B40
:BTY065QH@2NWYh0Ng]k07UiN@1>CTh0J6QX0:n_[`2n_[h0b<S80<[:bP1ZJVX0;Bd]01lO7`0L71`0
820P04E5A@1NGUh0UIFE06IVIP0_;bl0;Rh^030`<00/;2`0;Rh^0410@01oOgl0PH6108>3P`12@T80
?3`l07EeM@1UIFD0?Shn04E5A@1gMgL0>CTi01TI6@0M7Ad0;Rh^04Q8B01EEED0Q8B40<?3``2HV9P0
QhN70:BTY02MWId0;bl_01XJ6P0H61P05aLG01TI6@0G5aL07QhN034a<@12@T80:BTY03<c<`11@D40
C4a<03De=@0Y:BT0;Rh^0410@02NWYh0TY:B08Z:RP0m?Cd0HV9R06][J`0e=CD0EUIF08R8R011@D40
U9BD0:n_[`3@d=00=CDe01lO7`0L71`07alO02LW9`0g=cL0M7Ad0<o?c`3Ogml0eMGE0=[JfP31`L40
Bd];01XJ6P0G5aL05ADE01LG5`0H61P06ATI03`l?01OGel0g=cL0=WIf@28R8P0;bl_024Q8@0R8R80
<30`05MGE`0W9bL0EUIF04i>CP11@D40>c/k03`l?01:BTX0ATI606UYJ@2OWil0M7Ad05ADE00^;Rh0
GUiN0;fm_@2n_[h0DE5A03Lg=`0X:2P0:BTY06ATI015ADD0Q8B407inOP3:b/X0Lg=c02<S8`0W9bL0
:2PX028R8P0O7al071`L01hN7P0T92@0AdM705aLG01/K6`0d=3@0<o?c`1eMGD0=cLg059BDP2c/k<0
AdM7030`<00Z:RX0;bl_034a<@0e=CD0?3`l05aLG01=CDd0GemO07AdM02=SHd0/;2`0080Y:BT00`0
^[Zj0<_;b`3Fe]H0f=SH0=?Cd`2HV9P0PH6108>3P`1YJFT0?Shn01PH600J6QX201/K6`0=01dM7@17
AdL0T92@05mOG`17AdL0@d=304e=C@2<S8`0cLg=0;Jf]P25QHD0HV9R04a<C002ooooo`0000l0K6a/
05]KF`2>SXh0ATI608J6QP22PX80ATI60;Ng]`29RHT0@41004E5A@1GEeL0=cLg0410@00j>SX00P1Q
HF40o`0[:b/0CDe=02XZ:P0H61P0I6AT03dm?@0G5aL0@D5102`/;00P8200EeMG0451@@0V9RH0ADE5
02DU9@1GEeL0JVYZ04A4A00h>3P0HV9R04a<C00c<c<0@T9205IFEP0i>CT0=cLg020P8017AdL0=SHf
08n?S`2>SXh0>SXj03Lg=`1@D500:BTY04i>CP1=CDd0A4A406YZJP1kNg/0@T9202d];@0S8b<0KFe]
04m?C`0[:b/0?clo03hn?P0W9bL0DU9B061PH01LG5`0@D5106IVIP1RHV808b<S02`/;021PH40@D51
02DU9@1dM7@0Bd];030`<00e=CD0=3@d04];B`1kNg/0<30`04a<C01/K6`0ADE5020P800o?cl0CTi>
05QHF019BDT0UiNG051@D00m?Cd0Q8B40861P@18B4P0@4100::RXP14A4@0=3@d01dM7@0^;Rh0Hf=S
059BDP2;Rh/0W9bL096AT@0X:2P0CDe=07QhN01NGUh0N7Qh0492@P22PX80Fe]K04A4A01GEeL0>c/k
03@d=01CDe<0M7Ad04U9B@1EEED0HF5Q04A4A022PX80F5QH06ATI01JFUX0>c/k03dm?@1=CDd0GUiN
04Y:BP1EEED0DE5A06EUI@2DU9@0Bd];079bLP1=CDd0I6AT07]kN`1OGel0NGUi05IFEP16ATH0X:2P
05EEE@17AdL0HF5Q096AT@0f=SH0;2`/06=SH`22PX80?3`l07UiN@1lO7`0NWYj07IfMP2<S8`0BDU9
0:JVYP1lO7`0BDU908F5Q@1eMGD0GEeM06UYJ@2;Rh/0GUiN09nOW`22PX80M7Ad04I6AP2GUiL0TY:B
07IfMP2j^[X0a<C408b<S01@D500SXj>0:ZZZP2KVi/0@D5105ADE02_[jl0JFUY06e]K@30`<00[jn_
04i>CP1JFUX0SHf=07MgM`1HF5P0QXJ603Ti>@0b<S80IfMW03`l?01oOgl0Y:BT06MWI`1]KFd0L71`
03@d=01BDU80Hf=S04Y:BP1HF5P0UiNG055AD@0o?cl0/K6a07emO@0j>SX0N7Qh03De=@0W9bL0Fe]K
0:f][@1ZJVX0D51@09bLW02NWYh0Ph>303@d=018B4P0F5QH08F5Q@1IFET0Hf=S0:VYZ@0l?3`0GemO
08N7Q`1^KVh0>CTi05]KF`20P800>3Ph0861P@1oOgl0EEEE05aLG010@400?Cdm05mOG`10@400@D51
07alO01fMWH0>c/k06i^KP39bLT0Bd];04Q8B01lO7`0Jf][04E5A@1DE5@0GemO03Lg=`1@D500DE5A
05QHF000C00d=3@0MgMg07]kN`0Q8B407AdM02/[:`1]KFd0Bd];0410@01lO7`0Vi^K08^;R`18B4P0
Rh^;07YjNP0Y:BT0CTi>071`L01MGEd0CDe=03Xj>P1dM7@0;bl_01dM7@1^KVh0IfMW0410@01gMgL0
Fe]K02/[:`1MGEd0GUiN071`L02ATI40WYjN0:6QX@1:BTX09BDU04M7A`1JFUX0L71`03De=@12@T80
Ng]k07alO00i>CT0GUiN05YJFP1kNg/0T92@09RHV01jNWX0D51@03De=@0`<300@d=304i>CP0b<S80
;bl_0410@01NGUh0NGUi0:j^[P3@d=00>3Ph01PH600E5AD0:b/[0<30`034a<@0c/k>0<O7a`2HV9P0
>c/k03<c<`0_;bl203<c<`0O04A4A01CDe<0KVi^08Z:RP2QXJ40>CTi04];B`0n?Sh0>c/k03lo?`1T
I6@0`<3007]kN`11@D40D51@09FEU@1fMWH0[Zj^0:>SX`0/;2`06QXJ04=3@`2o_kl0Q8B403Ti>@0e
=CD0GemO06m_K`1^KVh0UYJF07moO`020451@@1b055AD@1^KVh0OGem0820P01PH600?Shn06][J`1e
MGD0HV9R04U9B@24Q8@0e=CD0;Vi^@3>c/h0T92@08V9R@1gMgL0DU9B03De=@0h>3P0NWYj06UYJ@1o
Ogl0CDe=04i>CP0e=CD092@T024Q8@0P82008b<S03/k>`17AdL0CTi>05]KF`1NGUh0KVi^07QhN02D
U9@0V9RH0:ZZZP2g]kL0XZ:R0:n_[`2PX:00MgMg0:n_[`2:RXX0MWIf06QXJ02UYJD0alO7096AT@2Y
ZJT0DU9B05ADE01BDU80FEUI05IFEP0b<S809bLW024Q8@0R8R80@d=308J6QP1jNWX0DU9B07=cL`0Z
:RX07alO02/[:`22PX80`L710<K6aP37alL0PH610410@00N7Qh07alO05MGE`1<C4`0>c/k09:BTP1O
Gel0B4Q804=3@`0f=SH0<c<c03De=@0o?cl0EeMG09ZJVP2YZJT0Hf=S03@d=00c<c<0G5aL06i^KP0h
>3P0@T920;6a/@1RHV80Fe]K05EEE@0n?Sh09bLW02<S8`1dM7@0VYZJ0:VYZ@3AdM40XZ:R030`<00H
61P06ATI100F5QH03@0I6AT0<C4a0492@P0_;bl0@41004e=C@0l?3`0:BTY02XZ:P0l?3`0UIFE09jN
WP0`<3000P0L71`0:00i>CT0IVIV05YJFP2`/;00Jf][07YjNP2n_[h0fMWI03hn?P0c<c<0=3@d03lo
?`1BDU80UYJF0<W9b@32`/80^k^k0<k>cP2n_[h0e]KF09FEU@16ATH06QXJ01DE5@0K6a/0:b/[03De
=@1WIfL0clo?0>GUi@3Ti>@0Ph>301lO7`0M7Ad0820P02XZ:P1`L700K6a/0410@00j>SX203<c<`0H
03Lg=`0i>CT0B4Q809nOW`1oOgl0>CTi0492@P0[:b/0ADE50:n_[`39bLT0HF5Q05ADE01RHV80Ng]k
05QHF00/;2`0NGUi06][J`2MWId0JFUY02@T900S8b<07QhN0P0G5aL0=P0I6AT05ADE01DE5@0I6AT0
=3@d0=GEe@3Fe]H0d=3@09bLW01FEUH0O7al0:FUY@0j>SX0>CTi0410@00k>c/0@T9205aLG023Ph<0
OGem06UYJ@1JFUX0L71`09FEU@2NWYh0VYZJ08b<S01/K6`0Ti>C0=gMg@3;bl/0eMGE0<O7a`0e=CD0
De=C07alO01JFUX06a/K01XJ6P0L71`08R8R05mOG`26QXH0D51@04M7A`10@400ADE505IFEP2l_;`0
W9bL0;fm_@39bLT0Hf=S075aL@;ooooo0000QP1TI6@0DE5A08F5Q@15ADD0Ogmo04a<C00h>3P0Y:BT
08B4Q00l?3`0B4Q804E5A@0/;2`0ADE505ADE01TI6@0BDU902<S8`1BDU80ADE502HV9P1>CTh0;bl_
01DE5@0_;bl092@T01XJ6P1<C4`0=CDe01XJ6P0m?Cd09bLW05=CD`1YJFT0>SXj03hn?P1cLg<0Fe]K
03De=@1HF5P0ATI602d];@19BDT0;Bd]05eMG@0L71`0De=C06YZJP0j>SX0?Shn05QHF011@D40E5AD
03dm?@16ATH0UiNG08f=S@1FEUH0>3Ph02<S8`1/K6`0@41002XZ:P1KFe/0E5AD04A4A019BDT0CDe=
04U9B@0k>c/0Lg=c06EUI@0j>SX07QhN079bLP0];Bd05QHF04M7A`1RHV80<30`03dm?@0W9bL0<30`
06MWI`0k>c/0A4A405iNGP1]KFd0=CDe04I6AP1LG5`0O7al04Y:BP38b<P0Rh^;05=CD`1ZJVX0ADE5
06][J`19BDT0V9RH065QH@1NGUh0<C4a03<c<`1gMgL0I6AT0820P02MWId0YZJV04i>CP1JFUX0SXj>
06IVIP1hN7P0DU9B0:NWY`1]KFd0?clo05QHF01cLg<0?Shn05aLG02;Rh/0BTY:05UIF@20P800BDU9
09RHV01WIfL0IFEU08R8R01GEeL0D51@0P1DE5@0G@1:BTX0AdM704Q8B01QHF40R8R804=3@`1]KFd0
D51@06a/K027QhL0EEEE05eMG@1>CTh0C4a<09ZJVP1SHf<0Bd];03hn?P2JVYX0@T92034a<@1bLW80
TY:B04];B`22PX80OWin06YZJP1aLG40N7Qh05EEE@36a/H0Z:RX04a<C02FUYH0MgMg05IFEP2YZJT0
XZ:R06MWI`2OWil0M7Ad0492@P1:BTX0RXZ:08f=S@1ZJVX0];Bd0=7Ad@1EEED0:2PX06MWI`2=SHd0
VYZJ03`l?019BDT0Y:BT04Y:BP0g=cL0L71`0:2PX01?Cdl0FUYJ08J6QP0h>3P0>SXj06MWI`0h>3P0
:RXZ0492@P10@400QXJ60:f][@1WIfL0P82006][J`0X:2P0EEEE07UiN@1IFET0D51@0:n_[`12@T80
;Bd]08^;R`1_Kfl0>CTi09jNWP1/K6`09bLW03hn?P2k^k/0B4Q802h^;P0204a<C01i06QXJ01:BTX0
BDU906MWI`2DU9@0?3`l0410@02>SXh0Ogmo055AD@23Ph<0;Bd]04E5A@20P800PH6104e=C@1FEUH0
Lg=c0410@00[:b/0@d=306QXJ02:RXX0JFUY04I6AP1HF5P0FEUI028R8P1gMgL0^k^k07IfMP1CDe<0
GemO05EEE@0b<S80K6a/07EeM@1ADE40H61P04m?C`11@D40820P04Y:BP1@D500>SXj02TY:@0];Bd0
JFUY03Hf=P0Q8B40@d=306i^KP27QhL0BTY:08J6QP25QHD0Bd];04m?C`1]KFd0EEEE04A4A00n?Sh0
[jn_04U9B@0];Bd0IVIV051@D00i>CT0Jf][06QXJ013@d<0KVi^05iNGP1MGEd0HF5Q09:BTP2SXj<0
J6QX02h^;P1GEeL0IfMW07YjNP14A4@0D51@08:2PP2FUYH0EUIF06ATI019BDT0Cdm?0451@@1>CTh0
JFUY08N7Q`2<S8`0LW9b05eMG@2MWId0TI6A08n?S`2=SHd0JVYZ04A4A00`<300CDe=08j>SP0X:2P0
5ADE05iNGP2ZZZX0LW9b07moO`2c/k<0M7Ad06ATI00i>CT07alO01dM7@0R8R80;2`/04m?C`0204];
B`0?08Z:RP1nOWh0AdM703Xj>P0c<c<0=CDe03dm?@2KVi/0WIfM0492@P1YJFT0C4a<0451@@1RHV80
Q8B400806a/K02/0=CDe0:RXZ01?Cdl0L71`05IFEP1BDU80EEEE04E5A@0i>CT0ADE5055AD@0g=cL0
<c<c03De=@0o?cl0F5QH069RHP1_Kfl0Rh^;07YjNP1VIVH0NGUi08:2PP2HV9P0eMGE0<W9b@2f][H0
ZJVY05ADE00`<3007alO020P800b<S80XJ6Q065QH@19BDT0CDe=024Q8@0P82007QhN020P800O7al0
8b<S00808B4Q0140<30`0492@P1OGel0M7Ad0;6a/@32`/80WinO0:RXZ03Hf=P0Y:BT04=3@`0g=cL0
K6a/05mOG`1;Bd/0@T9207YjNP020<O7a`1N0<o?c`11@D409RHV02<S8`0W9bL0B4Q804I6AP0m?Cd0
=3@d055AD@1lO7`0I6AT05mOG`1RHV80?3`l028R8P0M7Ad0:RXZ06e]K@3GemL0MGEe0<;2`P2YZJT0
PH6104=3@`0i>CT0GEeM03`l?010@400TI6A06=SH`1;Bd/0A4A4034a<@0^;Rh0:BTY03Ph>01cLg<0
SHf=0:f][@28R8P0G5aL0451@@0_;bl0OGem09FEU@2NWYh0/[:b07QhN00Z:RX071`L01TI6@0K6a/0
7AdM02l_;`1RHV80];Bd0=?Cd`30`<00OWin02DU9@0E5AD05QHF01LG5`0E5AD061PH01HF5P0J6QX0
AdM7055AD@0n?Sh0AdM703lo?`0W9bL0:BTY03Xj>P2OWil0@T9201hN7P0I6AT071`L01dM7@0d=3@0
QhN70<;2`P2ATI40PX:20<g=c@3QhN40TI6A0820P022PX80QhN70:6QX@80Ti>C01X0[Zj^0:VYZ@2_
[jl0Xj>S0;bl_03De=@0W9bL03Ph>00[:b/0@D5105eMG@2CTi<0SXj>09nOW`33`l<0_kno0::RXP13
@d<0:RXZ02@T900_;bl0OGem04Q8B010@400<c<c030`<080;2`/01D0;bl_04a<C02QXJ40Bd];04e=
C@0n?Sh0BTY:059BDP2<S8`0e]KF0;Jf]P2:RXX0LW9b055AD@1?Cdl0>SXj07YjNP1/K6`0N7Qh06=S
H`0];Bd00`0I6AT0=`0J6QX05aLG01PH600E5AD05QHF02LW9`3Kfm/0TI6A09ZJVP2ATI40PX:208J6
QP2[Zj/0I6AT059BDP13@d<0C4a<05eMG@27QhL0TI6A0:2PX01<C4`0QXJ608:2PP1jNWX0H61P05]K
F`1MGEd0G5aL04a<C03<c<`0_kno0<_;b`31`L40;Bd]02DU9@15ADD0LG5a03<c<`0L71`092@T07If
MP1jNWX0CTi>04E5A@17AdL0ADE504a<C02HV9P0d=3@09FEU@1iNGT0QHF50:JVYP1WIfL00_ooool0
0013079bLP1@D500SHf=04M7A`2BTY80Rh^;03lo?`1oOgl0Ng]k03Hf=P1LG5`0KVi^04A4A00l?3`0
@d=306e]K@1HF5P0;bl_04I6AP15ADD09bLW03Xj>P19BDT0820P02l_;`0R8R806QXJ04a<C00j>SX0
7QhN04a<C00I6AT0BDU906EUI@1@D500@d=309:BTP0f=SH09BDU04e=C@1DE5@0=CDe02d];@0G5aL0
@D5102DU9@1JFUX0M7Ad02d];@0Y:BT0AdM7055AD@1EEED0Bd];03dm?@1IFET0H61P05YJFP15ADD0
9bLW07MgM`16ATH05QHF02h^;P13@d<0A4A4051@D00204m?C`1M02h^;P1ADE40JVYZ04m?C`0P8200
HV9R05ADE00J6QX0DE5A05aLG00a<C40=3@d02h^;P0b<S80K6a/03hn?P13@d<0IVIV07AdM00l?3`0
ADE505EEE@1lO7`0BDU90<30`02TY:@0EEEE07alO012@T80K6a/03Xj>P27QhL0Shn?06UYJ@0e=CD0
<S8b06UYJ@1QHF40JVYZ0:2PX02LW9`0GUiN04];B`2<S8`0FEUI08B4Q01DE5@0/K6a071`L014A4@0
De=C07=cL`11@D40GEeM08V9R@16ATH0FUYJ0861P@14A4@0UIFE05UIF@1NGUh0QXJ6059BDP1>CTh0
AdM704E5A@1ADE40HV9R04M7A`1HF5P0TY:B0451@@2ATI40GEeM05mOG`25QHD0@D51079bLP1eMGD0
CDe=08j>SP1nOWh0<S8b04E5A@2OWil0NGUi04];B`1XJ6P0UYJF04A4A01UIFD0NGUi0080HV9R06X0
Kfm_04I6AP28R8P0UYJF0451@@1gMgL0GUiN03@d=01bLW80OWin05MGE`2=SHd0MGEe06EUI@0k>c/0
QHF508b<S01aLG40[jn_0<[:bP2NWYh0IVIV08j>SP2NWYh0Ti>C04=3@`1eMGD0`l?308V9R@0Q8B40
:b/[08^;R`1GEeL0Rh^;0;Rh^01oOgl0Cdm?05eMG@1>CTh0BDU907moO`0l?3`0Jf][0:^[Z`1OGel0
WinO09fMW@1VIVH0DE5A0861P@16ATH0FUYJ0:FUY@1aLG40>CTi07alO01dM7@09BDU071`L01QHF40
<c<c03`l?02k^k/0Shn?06=SH`1RHV80IFEU07emO@1[Jf/0ATI606i^KP2@T900H61P03hn?P2OWil0
W9bL05mOG`2DU9@0I6AT03Xj>P1>CTh0PX:205QHF01QHF40LW9b05=CD`1DE5@0;Rh^02@T901;Bd/0
F5QH03dm?@1MGEd0FUYJ04a<C01JFUX0^;Rh06EUI@1FEUH0FEUI07YjNP0i>CT0@41005QHF012@T80
IfMW0P1@D500<@0c<c<0BDU9061PH00^;Rh07AdM02DU9@1SHf<0Bd];0451@@1iNGT0L71`0820P00m
?Cd0O7al09JFUP1HF5P0FEUI07inOP1OGel0<30`03@d=02EUID0Hf=S03Xj>P1WIfL0?Cdm034a<@1b
LW80Ogmo04=3@`1TI6@0De=C04M7A`0R8R80C4a<07UiN@1WIfL0>SXj05eMG@1NGUh0B4Q801`L701A
DE40R8R80820P01GEeL0HF5Q03/k>`0a<C400P0W9bL06P0X:2P0;Bd]04Q8B01RHV80U9BD0<;2`P3:
b/X0Ti>C02`/;00H61P05aLG01HF5P0H61P0CTi>07UiN@1<C4`0PX:207]kN`1=CDd0;Rh^04=3@`2A
TI40HF5Q075aL@1ADE40;Bd]0P0M7Ad06P0c<c<0@d=3059BDP1BDU80QHF50451@@0Y:BT09RHV01lO
7`0Y:BT0Jf][0<30`01;Bd/0=CDe04M7A`0e=CD0@d=308J6QP0T92@071`L03/k>`27QhL09BDU04A4
A01iNGT0De=C0P0e=CD0N00/;2`0<c<c03De=@1<C4`0@d=302l_;`0n?Sh0B4Q804E5A@0j>SX0@T92
07moO`1DE5@0Bd];04A4A012@T80V9RH0;^k^`2JVYX0MGEe03dm?@0M7Ad07QhN01dM7@0V9RH0R8R8
09fMW@1@D500:RXZ01lO7`0M7Ad09BDU03<c<`12@T80FUYJ028R8P13@d<0CTi>02LW9`0[:b/0GemO
0;Ng]`2i^KT0^;Rh0:6QX@2m_Kd0Y:BT03Ti>@0Q8B40;2`/075aL@15ADD0=CDe07YjNP3:b/X0c<c<
0;:b/P27QhL0Lg=c07emO@21PH40SXj>07AdM024Q8@0NGUi09^KV`1PH600Ng]k069RHP0`<300<C4a
01`L700X:2P0GUiN0;>c/`35aLD0];Bd0<c<c02OWil0UiNG07AdM02BTY80QHF505eMG@1XJ6P0Bd];
05UIF@1LG5`0Cdm?04E5A@0o?cl0GUiN07emO@1JFUX0Hf=S0;^k^`3:b/X0Xj>S09^KV`26QXH0P820
0<G5a@2f][H0`<3003Xj>P0I6AT05QHF01PH600M7Ad06a/K01`L701NGUh0XJ6Q0;no_`2ATI40Z:RX
07]kN`0Y:BT06ATI01DE5@805aLG00h05QHF01DE5@0L71`0GEeM03dm?@0o?cl0CTi>0451@@0];Bd0
@d=30:JVYP0[:b/06QXJ01TI6@8071`L03l07AdM05ADE025QHD0JFUY0;jn_P3Hf=P0_[jn07YjNP1U
IFD0DE5A03lo?`17AdL0Fe]K05mOG`2d];@0Shn?04I6AP1oOgl0KVi^08:2PP3Cdm<0`L710:>SX`33
`l<0VYZJ04m?C`18B4P0GUiN0;Rh^02RXZ80>SXj065QH@1EEED0>CTi061PH01LG5`0:RXZ02DU9@0S
8b<0:2PX02TY:@0W9bL0<C4a065QH@1kNg/0<30`03hn?P1?Cdl0B4Q806ATI024Q8@0`L7108R8R02H
V9P0a/K60:j^[P2RXZ80Rh^;0;^k^`39bLT0aLG509VIV@1DE5@00P0J6QX04P0Q8B405aLG020P800O
7al07AdM01lO7`1iNGT0/K6a05YJFP26QXH0T92@09JFUP2NWYh0/K6a0:n_[`1RHV80F5QH04e=C@80
>SXj02@0?Shn09bLW02/[:`0Hf=S04A4A00j>SX0;2`/04A4A00m?Cd0EUIF08B4Q03Hf=P0e]KF07Ad
M01oOgl0?3`l024Q8@0U9BD0K6a/06UYJ@0f=SH0SHf=079bLP1<C4`0BTY:03lo?`14A4@0C4a<071`
L031`L40OGem02l_;`0^;Rh0=SHf079bLP2RXZ82ooooo`0003P0J6QX04Y:BP1iNGT0>SXj071`L01l
O7`0A4A408N7Q`11@D408B4Q038b<P1>CTh0>SXj02LW9`0`<300?3`l05UIF@0/;2`0>CTi04U9B@0O
7al0H61P05EEE@0W9bL0=SHf01dM7@0I6AT0HV9R04m?C`0T92@0Cdm?02d];@0o?cl0FEUI059BDP15
ADD0NGUi03`l?00X:2P0Bd];05eMG@16ATH071`L01hN7P16ATH07AdM04m?C`1lO7`0ADE503lo?`1?
Cdl0IVIV0492@P1VIVH0De=C07]kN`80KFe]0;@0=CDe028R8P1bLW80ADE502@T9010@400DE5A051@
D016ATH0C4a<06=SH`10@400Hf=S07AdM01DE5@07AdM061PH01OGel07AdM04a<C01_Kfl0=cLg03hn
?P0^;Rh0<C4a07YjNP0l?3`0ADE507EeM@21PH40A4A40492@P1>CTh0I6AT04];B`2n_[h0XZ:R05IF
EP22PX80AdM705iNGP0g=cL0QhN70<[:bP1bLW80@T9203Xj>P1SHf<0BTY:03Ti>@2ATI40ZJVY075a
L@14A4@0N7Qh04=3@`2?Shl0ATI608N7Q`1HF5P0De=C07=cL`1^KVh0@D5105aLG01^KVh0=3@d07Mg
M`1oOgl0@4100861P@0b<S80FUYJ07inOP1:BTX0ADE503lo?`17AdL0=cLg05=CD`1SHf<0@d=308B4
Q011@D40NWYj051@D00k>c/0NGUi04M7A`1>CTh0F5QH05ADE027QhL0PX:204=3@`0_;bl0/[:b07Ad
M01ADE40KFe]09VIV@1NGUh0N7Qh08R8R01GEeL0M7Ad09^KV`1KFe/0QXJ607QhN00g=cL0K6a/07]k
N`1=CDd0YJFU08B4Q01VIVH0XZ:R09^KV`20P800?clo08B4Q01PH6008R8R071`L02e]KD0TY:B05iN
GP2>SXh0S8b<07YjNP0Y:BT0@41009^KV`22PX809bLW04E5A@1VIVH0Bd];04M7A`2RXZ80OGem061P
H01IFET0>3Ph04e=C@1jNWX0>c/k06ATI02IVIT0>3Ph05UIF@1cLg<0EeMG04U9B@1]KFd0:b/[04E5
A@2@T900JVYZ0410@01XJ6P0U9BD03/k>`1ZJVX0MGEe0410@00e=CD0[Zj^08J6QP1TI6@0KFe]05]K
F`2OWil0Rh^;055AD@1mOGd0V9RH079bLP10@40209RHV01M05UIF@2KVi/0OGem0492@P1UIFD0SXj>
06IVIP1WIfL0L71`05QHF01CDe<0=cLg02@T901:BTX0Jf][04=3@`1?Cdl0E5AD0410@01YJFT0`/;2
05aLG01<C4`0De=C08V9R@1<C4`0ATI605aLG00o?cl0HF5Q07YjNP1UIFD0?3`l051@D01^KVh0;2`/
02DU9@15ADD0T92@05mOG`11@D40RHV907MgM`1JFUX08R8R04Y:BP1hN7P0A4A4069RHP28R8P0I6AT
01`L700_;bl0BDU908N7Q`1NGUh0Hf=S03`l?00a<C40?clo04a<C00l?3`0JVYZ05YJFP0h>3P0@D51
07=cL`1nOWh0H61P02h^;P1GEeL0G5aL06m_K`14A4@0>3Ph05YJFP2HV9P0HV9R05QHF00c<c<0:RXZ
02@T900S8b<08R8R01dM7@0L71`07AdM04=3@`28R8P0`L7104M7A`0K6a/05aLG00805ADE00l05aLG
01dM7@1TI6@0bLW908B4Q01:BTX09BDU01dM7@0R8R80DE5A061PH01_Kfl0LW9b06e]K@1IFET00P0[
:b/204A4A01J03@d=019BDT0OWin02PX:00S8b<0820P028R8P0b<S80WYjN08B4Q00[:b/0@d=303Xj
>P0c<c<0SXj>06a/K015ADD0Ng]k08b<S019BDT0@T92038b<P1<C4`0BTY:02`/;00U9BD0:RXZ02`/
;00[:b/0@d=304M7A`0/;2`0;Rh^03De=@0`<300;Rh^079bLP1CDe<0ADE503De=@0_;bl0MgMg09jN
WP1hN7P0QhN702`/;00L71`06a/K01`L700d=3@0N7Qh08b<S01nOWh0U9BD08:2PP1DE5@0Fe]K059B
DP0k>c/0<30`02d];@0h>3P0De=C05aLG00^;Rh0CTi>06EUI@1iNGT0WinO07emO@1nOWh0YZJV06UY
J@0X:2P07alO05ADE01^KVh0JVYZ0:j^[P3@d=00h^;R0=3@d02h^;P0WinO09^KV`2d];@0dM7A0<_;
b`2b/[80c/k>0P2/[:`0=P1JFUX0=CDe03Ph>018B4P0Lg=c0820P02TY:@0MGEe04=3@`1nOWh0/[:b
0;^k^`2UYJD0Fe]K08>3P`2MWId0clo?09^KV`0N7Qh08B4Q07QhN03Kfm/0fMWI0=KFeP39bLT0WinO
08n?S`2;Rh/0Z:RX0;Rh^01VIVH0H61P06IVIP2OWil0c/k>0=CDe03Cdm<0W9bL02<S8`0F5QH05ADE
01PH600N7Qh0?Shn075aL@3AdM40`l?306=SH`10@400E5AD06m_K`0g=cL061PH01LG5`<05ADE00d0
61PH020P801QHF40>SXj0410@00j>SX092@T02LW9`1ADE408R8R01LG5`0I6AT071`L0080820P02D0
D51@08R8R026QXH0^[Zj0:VYZ@1CDe<0A4A40492@P1=CDd0BTY:05=CD`1OGel0Rh^;0<30`02?Shl0
C4a<05IFEP29RHT0HF5Q06=SH`3Lg=`0jNWY0;jn_P1<C4`0B4Q804E5A@1EEED0_kno08f=S@1WIfL0
Jf][08N7Q`2UYJD0/[:b05eMG@0[:b/07alO00806a/K01P07alO02<S8`13@d<0Q8B403/k>`0_;bl0
:RXZ03Hf=P17AdL0OWin0;2`/02][Jd0KFe]05EEE@2?Shl0d];B0;no_`36a/H0fMWI0=GEe@2/[:`0
XJ6Q04U9B@0J6QX201PH600g01DE5@0G5aL05ADE01dM7@1YJFT0]kNg06EUI@1SHf<0GemO0;^k^`2d
];@0UiNG0:JVYP2c/k<0TY:B02PX:00O7al08B4Q02<S8`0Y:BT0[Zj^061PH00e=CD0<30`02d];@10
@400Fe]K08n?S`32`/80fMWI0=oOg`3<c<`0IVIV0492@P1lO7`0:2PX02<S8`1RHV80OWin09RHV01L
G5`0@T9204i>CP1FEUH0Lg=c07]kN`0m?Cd0<S8b055AD@1?Cdl09RHV02PX:00/;2`0=3@d06i^KP02
ooooo`0001h0MGEe04U9B@2DU9@0@T9207UiN@2DU9@0FUYJ07]kN`2>SXh0C4a<03dm?@1HF5P0CDe=
02h^;P1IFET0DU9B07IfMP10@400=3@d06UYJ@0g=cL0>CTi05MGE`0S8b<0>SXj03Lg=`0O7al0IFEU
05IFEP0`<30204m?C`0V05IFEP1RHV80@T9203lo?`29RHT0@D5102LW9`1=CDd0HV9R04M7A`0b<S80
?clo055AD@0`<300B4Q809fMW@1RHV80?Cdm05ADE01IFET0?clo071`L013@d<0K6a/06=SH`1EEED0
:BTY02/[:`1lO7`0H61P03De=@0l?3`0HV9R059BDP17AdL0RHV908:2PP19BDT207EeM@0O04a<C00Q
8B40L71`071`L00T92@0Bd];05MGE`0[:b/0FEUI04m?C`0_;bl0Kfm_02l_;`1:BTX0LW9b08J6QP1:
BTX0?Shn04e=C@0i>CT0:RXZ0820P02=SHd0De=C08B4Q018B4P0BTY:02TY:@13@d<0Y:BT071`L002
04a<C00K06UYJ@1BDU80;bl_07emO@2DU9@0KVi^04A4A025QHD0H61P0820P016ATH0Ng]k08>3P`1<
C4`0H61P07YjNP19BDT0N7Qh08f=S@19BDT0EeMG075aL@18B4P0SXj>07QhN01QHF40Ogmo0080DE5A
02<0O7al07=cL`1EEED0FUYJ03dm?@19BDT0W9bL05eMG@26QXH0=cLg03Ti>@21PH40D51@05QHF00o
?cl0;Rh^07MgM`21PH40F5QH03`l?02d];@0>c/k02DU9@1HF5P0Shn?05UIF@1dM7@0AdM703/k>`1@
D500RHV904i>CP20P800IfMW03De=@0208B4Q01>05ADE02;Rh/0I6AT03Hf=P1mOGd0O7al08>3P`11
@D40PX:208j>SP1lO7`0SHf=0<[:bP27QhL0Hf=S08b<S02g]kL0WYjN06MWI`12@T80WinO08j>SP10
@400GEeM0::RXP1XJ6P0EeMG0:ZZZP23Ph<0DU9B06=SH`1IFET0;Rh^06i^KP0h>3P0DE5A0;Fe]@1_
Kfl0O7al06m_K`18B4P0AdM706UYJ@19BDT0EeMG09ZJVP1TI6@0>3Ph06][J`2ATI40<c<c06UYJ@1_
Kfl0?Cdm05ADE02e]KD0PH6105ADE01OGel0EUIF07emO@0Z:RX0GEeM096AT@2][Jd0Ti>C059BDP2:
RXX0R8R805YJFP2/[:`0RXZ:04=3@`1VIVH0Q8B403De=@1ADE40IfMW0P1XJ6P0@P0h>3P0820P0451
@@1YJFT0@41007]kN`1WIfL0@T9206i^KP30`<00H61P05EEE@27QhL0Shn?04];B`17AdL0Hf=S055A
D@1CDe<0B4Q8069RHP0b<S80CDe=079bLP0O7al04a<C01lO7`1CDe<0HV9R04U9B@24Q8@0MgMg096A
T@12@T80GemO08:2PP13@d<0@T9207UiN@10@4007AdM02l_;`23Ph<0De=C06m_K`2?Shl0ADE504M7
A`1TI6@0J6QX04Y:BP1aLG40FEUI04e=C@0Z:RX0BDU905YJFP16ATH0:RXZ05mOG`1dM7@0MWIf04E5
A@0i>CT0FEUI0:VYZ@80G5aL0P0/;2`0@@0V9RH092@T024Q8@0M7Ad071`L01PH600F5QH0CDe=06e]
K@2OWil06a/K01DE5@0G5aL0ADE504e=C@0o?cl0?Shn0;Zj^P1UIFD0:BTY01/K6`0L71`07QhN01dM
7@1TI6@0ATI606][J`1BDU80CDe=0820P013@d<07alO02@T900g=cL0?Shn05YJFP1?Cdl092@T028R
8P0`<300@D51092@T035aLD0OGem07EeM@1cLg<0J6QX09ZJVP22PX80I6AT0;Zj^P2OWil0?3`l02TY
:@0U9BD06a/K02@T900l?3`0ADE502/[:`0V9RH0:b/[02@T900f=SH0@d=3008071`L00D06a/K028R
8P2:RXX0G5aL02/[:`0202LW9`0605eMG@2;Rh/0De=C09BDU00X:2P06a/K0P0I6AT0N@1OGel0HF5Q
07EeM@1_Kfl0AdM703Xj>P0Z:RX09bLW02HV9P0N7Qh08B4Q020P800Y:BT09BDU03`l?020P800R8R8
05=CD`1@D500X:2P08^;R`2GUiL0M7Ad0:ZZZP19BDT0?Shn04e=C@2[Zj/0`/;20<30`02UYJD0QXJ6
0:b/[02LW9`0QXJ609ZJVP2j^[X0aLG50=WIf@3Zj^X0fm_K0=7Ad@3=cLd0IfMW02h^;P0W9bL0C4a<
0:RXZ02MWId0GemO03Ph>00[:b/0K6a/09NGU`2IVIT0P820092@T021PH40QXJ609RHV02ATI40:b/[
04=3@`24Q8@0Rh^;08B4Q02:RXX0[jn_0:NWY`1jNWX0Ng]k09jNWP2_[jl0P82008^;R`21PH40aLG5
0<W9b@21PH40D51@07inOP2HV9P0?Shn01hN7P0g=cL0EUIF069RHP2DU9@0f=SH0=CDe026QXH0De=C
03Lg=`0e=CD0BTY:03<c<`0Y:BT05QHF01<C4`0E5AD061PH01`L701:BTX0@D5105]KF`0i>CT07alO
02d];@16ATH0;Bd]01TI6@0L71`07QhN024Q8@0Z:RX0AdM70;no_`1RHV80d=3@05eMG@0T92@00P0S
8b<0L00R8R807QhN01lO7`0T92@0>CTi05=CD`2BTY80@T9204];B`1DE5@0VIVI08^;R`36a/H0h^;R
0861P@0n?Sh0>3Ph04Y:BP1nOWh0d=3@0:^[Z`22PX80]KFe0:>SX`2JVYX0/[:b0:^[Z`1iNGT0Bd];
04I6AP1@D500G5aL075aL@2m_Kd0c/k>03@d=00T92@08B4Q03Xj>P1IFET0Ogmo0:VYZ@2m_Kd0MgMg
04=3@`2QXJ40FEUI03Ti>@0m?Cd0OWin09NGU`1DE5@0EeMG05aLG00U9BD0;Rh^02PX:00I6AT061PH
01TI6@1=CDd0ZJVY06YZJP1QHF40NGUi05MGE`2^[Zh0_Kfm0:n_[`37alL0_;bl0;^k^`2NWYh0TY:B
09>CT`2LW9`0[:b/0=SHf02HV9P0T92@09BDU02VYZH0_kno0;>c/`2^[Zh0/;2`0:b/[02[Zj/0Ti>C
0:6QX@11@D40Rh^;08R8R020P800VIVI08F5Q@1IFET0AdM706IVIP2LW9`0a/K60:NWY`16ATH08b<S
01dM7@0R8R80@41002XZ:P0R8R80;Rh^038b<P1:BTX2ooooo`0007`0KVi^04U9B@2ATI40A4A40820
P01iNGT0EUIF09RHV02@T900EEEE03Lg=`15ADD0=CDe04A4A01UIFD0AdM706MWI`0^;Rh0?Cdm08>3
P`1DE5@0IFEU05YJFP0<30`0=cLg05=CD`0h>3P0O7al03/k>`0=3@d0?Cdm055AD@19BDT0GemO01TI
6@0P8200PX:2065QH@0Z:RX0ATI6065QH@0X:2P07QhN03dm?@1<C4`0410@02<S8`1PH600IfMW034a
<@1<C4`08b<S02XZ:P1NGUh0=3@d075aL@2QXJ40<30`02PX:00L71`0ADE507alO00m?Cd0EeMG07Qh
N00a<C408R8R0410@01MGEd0?3`l06=SH`28R8P0@d=301LG5`1DE5@0JVYZ02PX:00o?cl0FUYJ02/[
:`17AdL0F5QH0410@01aLG40E5AD03Ti>@1NGUh0SXj>059BDP1MGEd0QhN709VIV@1<C4`0^KVi0:2P
X00l?3`0SHf=08b<S02:RXX0@d=303dm?@3AdM40K6a/02@T900k>c/0E5AD07EeM@16ATH0/K6a0;^k
^`1UIFD0=CDe07UiN@1HF5P0QhN702l_;`1BDU80NWYj05aLG01KFe/0>CTi02h^;P1>CTh0Kfm_0P1=
CDd0Y@0i>CT0:BTY05]KF`1XJ6P0CTi>06YZJP0c<c<0;Rh^0492@P1KFe/0C4a<05iNGP0o?cl0ADE5
08:2PP1PH600O7al061PH017AdL0SXj>04Y:BP1BDU80EUIF05MGE`1aLG40Ogmo0492@P0a<C40SXj>
05aLG01?Cdl0FEUI07IfMP1;Bd/0De=C07YjNP1ZJVX0IVIV0:2PX01WIfL0Kfm_08b<S018B4P0JFUY
08b<S01KFe/0O7al08n?S`22PX80QhN707emO@1HF5P0?Shn06e]K@27QhL0Kfm_08B4Q02m_Kd0RHV9
0492@P18B4P0L71`08F5Q@1>CTh0?3`l08b<S01GEeL0>SXj07QhN02PX:00K6a/05IFEP2SXj<0CTi>
04m?C`1bLW80GUiN02LW9`1MGEd0Bd];06e]K@2g]kL0Kfm_08J6QP1YJFT0@d=305mOG`1eMGD0F5QH
05=CD`2DU9@0C4a<02`/;01iNGT0SHf=03Hf=P1XJ6P0Fe]K01hN7P0f=SH0KVi^07emO@1VIVH0G5aL
05EEE@1kNg/0?Shn03<c<`1<C4`0IfMW08b<S00m?Cd0O7al05=CD`1BDU80Rh^;08N7Q`0n?Sh0IVIV
07]kN`1GEeL0DU9B04U9B@21PH40MgMg03De=@0M7Ad0>c/k05mOG`0Y:BT0A4A405]KF`1CDe<0GEeM
0;^k^`1fMWH0@d=305ADE01dM7@0C4a<04];B`1JFUX0KFe]06][J`1FEUH0EeMG02h^;P1;Bd/0K6a/
03De=@0I6AT07QhN05MGE`1cLg<0GemO08F5Q@2=SHd0Z:RX04];B`1EEED0Rh^;03dm?@1VIVH0U9BD
061PH00202TY:@0?06=SH`0m?Cd0De=C0:6QX@27QhL0HF5Q07MgM`29RHT0=CDe061PH025QHD0JVYZ
0492@P1OGel0U9BD00805aLG00d0@D5106UYJ@1/K6`0@41003Hf=P1@D500Z:RX01TI6@1DE5@0<c<c
02TY:@0U9BD08b<S00807QhN03@06QXJ01TI6@0L71`08B4Q05YJFP1`L700H61P01LG5`0E5AD0;bl_
05mOG`14A4@0EEEE0<G5a@1dM7@0;2`/02DU9@0N7Qh0820P01lO7`0i>CT0Jf][03Ti>@0V9RH0:b/[
04I6AP1@D5006a/K01XJ6P0M7Ad0J6QX092@T02n_[h0Q8B406][J`1ZJVX0FEUI061PH02c/k<0U9BD
09jNWP2QXJ40[Jf]0:b/[02UYJD0VIVI0<O7a`38b<P0Cdm?01lO7`0K6a/06ATI0P0J6QX0T00P8200
@T9204Y:BP0];Bd09BDU02PX:00f=SH0EUIF04I6AP14A4@0HV9R0<W9b@2[Zj/0;Bd]01dM7@0O7al0
F5QH09NGU`1;Bd/0Lg=c0492@P0O7al05aLG02HV9P1eMGD0CDe=06i^KP0g=cL07alO024Q8@0T92@0
820P028R8P0O7al071`L01hN7P0M7Ad06a/K020P801KFe/0QXJ60:VYZ@1aLG40FUYJ0::RXP2l_;`0
/[:b09ZJVP2VYZH0XJ6Q0;jn_P2j^[X0UIFE07EeM@19BDT0=SHf03hn?P20P800L71`03Ph>011@D40
GemO08j>SP2ATI40f=SH0:FUY@2:RXX0WYjN07EeM@2WYjL0WinO07emO@1JFUX07alO01dM7@0];Bd0
TI6A0:b/[01<C4`0;Bd]059BDP2LW9`0V9RH09bLW032`/80Xj>S07]kN`1nOWh0RHV90:6QX@2m_Kd0
a/K60:f][@1TI6@0CTi>09bLW02c/k<0BDU90451@@1MGEd0b<S808b<S01JFUX0HF5Q05EEE@1cLg<0
aLG50:JVYP1YJFT0Q8B408j>SP1VIVH0I6AT0:VYZ@2][Jd0FEUI05iNGP0f=SH0<S8b03De=@0/;2`0
8R8R01LG5`0H61P05aLG01HF5P0d=3@0MGEe08Z:RP0k>c/0:b/[02l_;`1EEED0>SXj01hN7P0L71`0
7AdM020P800d=3@0PH6107=cL`20P800_Kfm02l_;`807AdM06T07alO01dM7@0Q8B407AdM01lO7`0Q
8B40?Shn0:ZZZP24Q8@0Fe]K04M7A`1dM7@0^[Zj0=;BdP3Jf]X0I6AT05eMG@1nOWh0JFUY03Ti>@1A
DE40e]KF0<[:bP2m_Kd0/k>c0:>SX`2NWYh0[Jf]09>CT`1LG5`0B4Q804=3@`12@T80BTY:08n?S`1o
Ogl0Hf=S024Q8@0Z:RX0?Cdm04M7A`1WIfL0Jf][0=3@d02UYJD0Shn?05MGE`0[:b/07alO01hN7P0Z
:RX0Ogmo051@D01ADE40MWIf02PX:00Z:RX0<30`02d];@0M7Ad0IVIV08j>SP1HF5P0H61P05]KF`2d
];@0TY:B04];B`1LG5`0_Kfm0<k>cP1HF5P0DU9B04=3@`19BDT0J6QX06IVIP1DE5@0`L7108>3P`29
RHT0P82006i^KP1LG5`0H61P04Q8B00k>c/0JVYZ06EUI@1RHV80Lg=c06][J`1UIFD0`L710:b/[01`
L700IfMW059BDP1dM7@0_[jn09nOW`1ZJVX0?clo02HV9P0P82000P0M7Ad202`/;00402LW9`0/;2`0
<S8b06IVIP;ooooo0000o`1/K6`0@T9205eMG@13@d<0UIFE06=SH`0^;Rh0MWIf06YZJP0h>3P0>SXj
0451@@0];Bd0;Rh^051@D014A4@0Hf=S02d];@0U9BD0DE5A02XZ:P1KFe/0FUYJ01PH600Y:BT0;Bd]
02DU9@1`L700K6a/03Hf=P0e=CD0?clo03Xj>P1MGEd0G5aL02LW9`2^[Zh0JFUY02HV9P1GEeL0K6a/
05QHF00d=3@0?clo05ADE01;Bd/0@41006YZJP17AdL09bLW05ADE01NGUh0?Shn06EUI@0J6QX0?Shn
06i^KP1VIVH0HV9R03/k>`1JFUX0SHf=01LG5`0[:b/0GemO05eMG@0k>c/0Bd];04m?C`0U9BD0?Shn
07UiN@1kNg/09bLW05=CD`1RHV80:b/[069RHP20P800@D510492@P1LG5`0?3`l07AdM01]KFd0Bd];
05UIF@1mOGd0:RXZ038b<P1>CTh0Ng]k04E5A@2^[Zh0TI6A02h^;P1;Bd/0A4A406EUI@18B4P0=CDe
0<c<c021PH40D51@03/k>`10@400KFe]04U9B@2MWId0_kno08>3P`17AdL0OWin06UYJ@24Q8@0FUYJ
07emO@2KVi/0GUiN04m?C`1kNg/0Bd];05ADE01jNWX0EeMG04Q8B01MGEd0@41006=SH`1`L700BDU9
07moO`1LG5`0?Cdm04U9B@1CDe<0ATI606m_K`1=CDd0?Cdm08j>SP1MGEd0QHF5075aL@1?Cdl0T92@
04U9B@1XJ6P0KVi^05iNGP1SHf<0SXj>034a<@0^;Rh0RHV906][J`1HF5P0JVYZ07UiN@1DE5@0LG5a
08n?S`1aLG40KVi^08J6QP1LG5`0W9bL0;Fe]@1@D500L71`07emO@0c<c<0N7Qh08N7Q`1fMWH0QXJ6
07YjNP1JFUX0?Shn069RHP24Q8@0P82006e]K@30`<00VIVI08B4Q01BDU80X:2P0:RXZ01_Kfl0<c<c
075aL@2GUiL0F5QH05YJFP2WYjL0KVi^05EEE@2PX:00Lg=c034a<@10@400EUIF028R8P1ADE40=cLg
03dm?@2RXZ80L71`07YjNP1[Jf/0E5AD02l_;`1EEED0CTi>05MGE`2TY:@0IFEU04A4A00m?Cd0TY:B
03Lg=`1PH600QXJ606QXJ00T92@0FUYJ08R8R01bLW80G5aL05mOG`2BTY80I6AT04a<C01dM7@0Kfm_
08f=S@0e=CD0KFe]08N7Q`1:BTX0O7al08N7Q`0n?Sh0GEeM07MgM`1VIVH0CTi>04Y:BP1iNGT0NWYj
03/k>`0K6a/0=CDe08J6QP00?`1@D500DE5A05iNGP1^KVh0<C4a096AT@1WIfL0EeMG06][J`20P800
Bd];04=3@`1/K6`0R8R806MWI`1KFe/0IfMW0451@@1GEeL0MGEe03`l?00O7al08B4Q05ADE01ZJVX0
>3Ph06QXJ02EUID0YZJV04E5A@1BDU80Shn?01dM7@0`<300BTY:05QHF01IFET0:BTY06EUI@0U9BD0
8B4Q03lo?`1aLG40MgMg07QhN02HV9P0<c<c04M7A`1OGel0EeMG0451@@1lO7`0SXj>05EEE@0T92@0
?Cdm04i>CP1aLG40?3`l03lo?`2IVIT0^[Zj0492@P0203`l?00i02l_;`0X:2P092@T020P800L71`0
6ATI01LG5`0F5QH05ADE04M7A`19BDT0TY:B06EUI@0V9RH0=SHf05eMG@1]KFd0S8b<0<k>cP2^[Zh0
Ogmo06][J`1EEED0Cdm?04i>CP1FEUH0MgMg06i^KP1@D50092@T02<S8`10@400?3`l01PH600J6QX0
>c/k07]kN`3>c/h0V9RH096AT@2a/K40bl_;0=GEe@3Lg=`0fm_K0=GEe@3GemL0e=CD0<[:bP2m_Kd0
Vi^K05=CD`2CTi<0O7al02XZ:P0F5QH05aLG00<05ADE01d07AdM04m?C`1jNWX0De=C04Y:BP1RHV80
Q8B40:2PX02a/K40aLG50<_;b`3=cLd0YJFU0492@P0J6QX0HV9R0;no_`1?Cdl0?Shn07QhN00R8R80
5aLG051@D01TI6@0BDU905mOG`0S8b<0820P01dM7@0301`L70807AdM01L06QXJ01`L700K6a/0820P
055AD@1<C4`0O7al09ZJVP21PH40BDU903`l?01gMgL0V9RH0<O7a`3AdM40/[:b08B4Q01>CTh0Bd];
0410@00e=CD0=3@d03Ti>@0207UiN@0603@d=00h>3P0VIVI071`L02n_[h0bLW90P2TY:@0C@2a/K40
W9bL04M7A`0^;Rh0:2PX03dm?@1CDe<0IfMW079bLP2l_;`0FUYJ024Q8@0c<c<0P8200;2`/02^[Zh0
b/[:0=?Cd`2TY:@0PX:2069RHP1WIfL0SXj>07EeM@1[Jf/0CTi>04];B`1iNGT0@d=304];B`1CDe<0
N7Qh0=7Ad@1WIfL0@d=302h^;P0l?3`0S8b<0<71`@3Ph>00b<S805iNGP0n?Sh0?3`l04=3@`16ATH0
T92@06e]K@17AdL0GUiN04E5A@0Z:RX0:2PX02d];@0Z:RX06QXJ01LG5`0K6a/0EUIF0<_;b`3EeMD0
@D5102<S8`0X:2P0C4a<02LW9`0P82007AdM020P800W9bL0C4a<0;Fe]@1=CDd0VIVI08n?S`0O7al0
71`L00807AdM00<07alO01hN7P0M7Ad00P0M7Ad04P11@D40R8R804Y:BP17AdL0Cdm?06ATI02ZZZX0
d];B0=_Kf`2ZZZX0J6QX02`/;00K6a/07AdM06][J`2<S8`0PH610:j^[P80alO700H0]kNg08N7Q`2h
^;P0P82004=3@`0V9RH202DU9@1705QHF01ZJVX0LG5a04M7A`0b<S80?clo04M7A`1/K6`0Vi^K0;Rh
^02RXZ80;Bd]028R8P0K6a/06QXJ01LG5`0J6QX0EEEE07AdM017AdL0CDe=03dm?@0U9BD0<30`07em
O@2HV9P0W9bL05]KF`18B4P0PH6109VIV@35aLD0Lg=c03dm?@1]KFd0[Jf]0<O7a`23Ph<0DU9B04=3
@`0n?Sh09BDU02/[:`1LG5`0_Kfm07=cL`1>CTh0?clo03<c<`0V9RH08R8R01lO7`0N7Qh0<S8b05iN
GP2=SHd0Bd];0861P@1:BTX0YjNW09FEU@23Ph<0MWIf05YJFP1ZJVX0E5AD03De=@0a<C40=SHf02l_
;`0P82000P0M7Ad01P0R8R80;2`/02TY:@0];Bd0>3Ph09nOW`;ooooo0000i01ZJVX0ATI606ATI00a
<C40CDe=079bLP1MGEd0_Kfm061PH00G5aL0;2`/03Xj>P0^;Rh0>CTi03Xj>P0^;Rh0De=C0410@00^
;Rh0Bd];010@400S8b<0ADE502LW9`0c<c<0;Rh^01PH600a<C40?Shn038b<P0];Bd0;Rh^01HF5P0[
:b/0B4Q8020P802c/k<0RHV9010@400P8200>3Ph04M7A`0U9BD08B4Q03De=@16ATH0?clo07emO@10
@4006a/K02h^;P1DE5@0;bl_06MWI`0^;Rh0ADE505iNGP1QHF40BDU9030`<01>CTh0Q8B4034a<@0_
;bl0FUYJ04a<C00i>CT0B4Q804];B`0a<C409BDU06m_K`1LG5`092@T03`l?01XJ6P0:b/[03<c<`1k
Ng/0?clo04=3@`17AdL0<S8b07emO@1hN7P0De=C07YjNP1kNg/0F5QH03Xj>P1DE5@0EUIF03Ti>@2O
Wil0Y:BT05iNGP1ZJVX0Bd];05YJFP19BDT0@4100;Rh^02?Shl0K6a/04M7A`11@D40KVi^03Ti>@26
QXH0];Bd09>CT`1@D500Lg=c03`l?021PH40FEUI07emO@23Ph<0EeMG08J6QP29RHT0E5AD055AD@1W
IfL0@d=305]KF`1RHV80?3`l05eMG@1<C4`0Cdm?07=cL`1<C4`0>SXj04M7A`18B4P0;Rh^04];B`1S
Hf<0@D5108:2PP0o?cl0EeMG07YjNP13@d<0Ogmo05EEE@0m?Cd0EUIF069RHP1EEED0[Jf]059BDP0X
:2P0H61P06UYJ@1KFe/0CTi>08V9R@0o?cl0>3Ph06m_K`1IFET0MWIf06=SH`0h>3P0L71`07alO00h
>3P0FUYJ08:2PP0h>3P0F5QH07=cL`1gMgL0NWYj09VIV@2?Shl0D51@06MWI`24Q8@0CDe=04m?C`2V
YZH0VYZJ08B4Q012@T80]KFe09>CT`1;Bd/0>c/k07UiN@2WYjL0I6AT05mOG`2KVi/0EUIF04i>CP2i
^KT0V9RH04A4A01ADE40J6QX020P801HF5P0IFEU0492@P2h^;P0PH61079bLP1gMgL0Jf][03@d=01J
FUX0B4Q804E5A@2XZ:P0EeMG05]KF`0o?cl0VIVI03Xj>P1IFET0MGEe05UIF@0U9BD0EEEE07YjNP80
Fe]K02P0QXJ60:JVYP1cLg<0AdM707]kN`1RHV80VYZJ03/k>`1UIFD0M7Ad04=3@`1mOGd0Rh^;0492
@P1TI6@0QXJ606EUI@15ADD0D51@059BDP1FEUH0@410024Q8@0];Bd0Ng]k04Q8B01ADE40AdM704a<
C00e=CD0UiNG06ATI01?Cdl0Ng]k07MgM`13@d<0JFUY07YjNP25QHD0G5aL0P1TI6@0300K6a/0>c/k
061PH01EEED0?Cdm02HV9P1bLW80L71`03@d=01ADE40CTi>07alO080DU9B05D0OWin06=SH`12@T80
Ogmo06=SH`1;Bd/0;Rh^09JFUP1HF5P0DU9B04M7A`16ATH0@T9205iNGP1nOWh0DU9B05IFEP2TY:@0
PX:2065QH@1TI6@0WIfM01dM7@0C4a<0@T9206i^KP1gMgL0>SXj02LW9`14A4@0QhN703Ti>@10@400
?3`l03@d=00X:2P092@T020P800L71`06a/K01LG5`0F5QH05ADE02`/;01aLG40@D510::RXP2OWil0
WYjN08Z:RP29RHT0WIfM0;Vi^@1ZJVX0DU9B04i>CP1:BTX0?Cdm03Ti>@0k>c/0?3`l03hn?P11@D40
De=C04E5A@13@d<0Bd];03Lg=`0N7Qh0;bl_03hn?P2EUID0;Bd]02HV9P0g=cL0JFUY0;Bd]03Rh^80
h>3P0=OGe`2KVi/0TY:B08F5Q@1nOWh0=cLg00809bLW02<0M7Ad075aL@0O7al07QhN02<S8`0c<c<0
DE5A07MgM`1[Jf/0H61P08:2PP1aLG40WYjN0:b/[02EUID0LW9b05mOG`1@D500IFEU0:>SX`2j^[X0
QhN70:RXZ03<c<`0YJFU03`l?027QhL0S8b<03dm?@23Ph<0D51@05=CD`0^;Rh07QhN01dM7@0201`L
701A01LG5`0J6QX071`L01`L700M7Ad06QXJ01TI6@0T92@0Cdm?04M7A`1aLG40LW9b0:FUY@28R8P0
QHF509fMW@2i^KT0e=CD0<71`@2d];@0YjNW0:b/[02][Jd0UIFE03Ti>@0Y:BT0:b/[03Ph>029RHT0
Ti>C07EeM@2i^KT0Ogmo06i^KP3?cll0];Bd0<30`03;bl/0/;2`08J6QP1iNGT0I6AT03Lg=`0d=3@0
C4a<055AD@13@d<0Kfm_05UIF@0/;2`0C4a<0<W9b@2h^;P0_;bl0=?Cd`2NWYh0MGEe05IFEP1EEED0
DE5A02d];@0d=3@0@410061PH01bLW80WYjN07=cL`1WIfL0ATI606EUI@1aLG40E5AD04M7A`0S8b<0
Kfm_0::RXP3=cLd0V9RH0492@P0h>3P0:RXZ00806a/K01h09BDU0861P@1QHF40BDU906UYJ@1=CDd0
;2`/02<S8`0h>3P0CDe=07UiN@1kNg/0MWIf0;Rh^03Vi^H0[Jf]06ATI01bLW80UYJF07inOP1WIfL0
GemO079bLP27QhL0a<C40<S8b01nOWh0bl_;06EUI@0L71`301dM7@0O01hN7P0M7Ad071`L01dM7@0O
7al0CDe=03hn?P0V9RH0:2PX02h^;P12@T80O7al0:FUY@3Cdm<0EEEE04M7A`0b<S80;Bd]02l_;`1j
NWX0F5QH04I6AP1@D500UIFE0=7Ad@3Cdm<0QXJ608f=S@2h^;P0@T9202<S8`02020P800_03lo?`1A
DE40Bd];061PH00m?Cd0D51@08f=S@3=cLd0g=cL0=OGe`1iNGT08R8R020P800R8R80>SXj03Hf=P0]
;Bd0=SHf09jNWP1IFET0A4A40820P01JFUX0RXZ:0<C4a02b/[80LW9b04E5A@1?Cdl0De=C0:6QX@38
b<P0UYJF04U9B@25QHD0][Jf05ADE02/[:`0`/;209ZJVP1<C4`0FUYJ055AD@0j>SX0JFUY03`l?00X
:2P00P0U9BD202@T90807AdM00d08B4Q03Xj>P1ADE40HF5Q04e=C@1PH600Q8B40;jn_P2NWYh0LG5a
03dm?@0h>3P0>c/k0080<30`00/0>c/k03<c<`0L71`071`L01dM7@0Q8B409bLW02PX:00c<c<0G5aL
0;2`/002ooooo`0006D0PX:204I6AP1oOgl0DU9B05mOG`2;Rh/0MWIf0<o?c`1eMGD0DE5A02PX:00o
?cl0FUYJ024Q8@13@d<0=3@d07]kN`1KFe/0;2`/04m?C`14A4@0>CTi079bLP0a<C40=3@d03De=@0h
>3P0I6AT05MGE`14A4@09BDU04U9B@15ADD0F5QH06i^KP0W9bL0T92@096AT@0];Bd0<c<c04a<C01@
D5006QXJ02`/;00j>SX0F5QH03hn?P2BTY80H61P03De=@0l?3`0HF5Q03Lg=`1aLG40C4a<06ATI01^
KVh0IFEU0492@P0^;Rh0DU9B08R8R00d=3@0;Bd]05QHF01CDe<0A4A406YZJP1aLG40C4a<02TY:@1k
Ng/0EeMG02HV9P1;Bd/0Rh^;03lo?`0e=CD0T92@02<S8`12@T80J6QX03/k>`22PX80CDe=03Xj>P1E
EED0LG5a05eMG@0h>3P0EEEE04Q8B00S8b<0F5QH0:JVYP1OGel0Hf=S04i>CP1<C4`09BDU02d];@02
09>CT`33065QH@15ADD0>c/k07MgM`0l?3`0JVYZ08R8R02EUID0BDU907AdM01CDe<0Lg=c065QH@1[
Jf/0Ph>304Q8B012@T80KFe]04a<C01@D500I6AT04e=C@0l?3`0D51@03dm?@1GEeL0HF5Q0451@@1j
NWX0EeMG03<c<`14A4@0DU9B04];B`1:BTX0I6AT04i>CP27QhL0Ogmo06QXJ029RHT0E5AD07moO`1]
KFd0E5AD05IFEP1MGEd0B4Q80:j^[P1=CDd0?3`l04U9B@1fMWH0BTY:03lo?`2ATI40DE5A0410@02<
S8`0HV9R08N7Q`23Ph<0JVYZ08>3P`28R8P0<30`059BDP2EUID0GUiN05eMG@1cLg<0D51@06YZJP2Y
ZJT0SHf=055AD@1JFUX0QhN702TY:@1<C4`0O7al096AT@1mOGd0@T920<30`02UYJD0@T9201/K6`10
@400TI6A05mOG`1HF5P0XZ:R06i^KP0i>CT0MWIf071`L013@d<0De=C03Ph>00o?cl0MgMg06IVIP0g
=cL0Zj^[059BDP1DE5@0S8b<06a/K00j>SX0IFEU03lo?`0g=cL0WYjN06m_K`1OGel0>SXj08B4Q00V
9RH0L71`08b<S01FEUH07QhN06EUI@26QXH071`L03/k>`1MGEd0QHF506ATI00o?cl0SXj>06=SH`2T
Y:@0:BTY07emO@1gMgL0@d=307alO01iNGT0BDU908F5Q@2XZ:P0NWYj03/k>`1SHf<0H61P04A4A018
B4P0E5AD05YJFP1oOgl0De=C04M7A`1<C4`0<C4a02XZ:P1dM7@0Ogmo06YZJP1iNGT0LG5a018B4P0f
=SH0BDU9051@D014A4@0L71`06i^KP0h>3P0=SHf04m?C`15ADD05ADE02<S8`1GEeL0KVi^05QHF01k
Ng/0E5AD06m_K`0T92@0@d=307=cL`1EEED0E5AD0:VYZ@2@T900=3@d01hN7P1GEeL0>SXj02d];@1`
L700GemO0080EeMG01/0PH6102<S8`0Q8B40J6QX07]kN`1QHF40N7Qh0:ZZZP0h>3P04a<C01TI6@0a
<C40IFEU04Y:BP0c<c<0EeMG0;Ng]`0H61P08R8R0492@P0e=CD09bLW02<S8`0M7Ad071`L01XJ6P0H
61P00P0E5AD0<00T92@0QHF505eMG@23Ph<0a<C408b<S028R8P0QXJ60<_;b`2GUiL0De=C04A4A00f
=SH0>CTi04=3@`0i>CT0;Bd]02LW9`0Q8B409RHV030`<01BDU80IFEU055AD@1VIVH0CTi>03`l?01O
Gel0Cdm?02/[:`0i>CT0?clo04U9B@1YJFT0`<300=_Kf`36a/H0IVIV08Z:RP37alL0ZJVY038b<P0I
6AT05ADE02TY:@2IVIT0Zj^[08n?S`80NGUi00X0FEUI03Xj>P0W9bL071`L02d];@1<C4`0JFUY09FE
U@1]KFd0@4100P0S8b<0400Q8B40BDU909bLW03De=@0cLg=0:ZZZP2BTY80X:2P09FEU@2<S8`0XZ:R
09fMW@1JFUX0B4Q801lO7`0M7Ad201`L701A01/K6`0I6AT06ATI01TI6@0L71`07AdM01/K6`0G5aL0
>3Ph04Y:BP1PH600IFEU05QHF01JFUX0M7Ad0<;2`P26QXH0M7Ad0<G5a@2/[:`0MGEe0:RXZ034a<@0
d=3@0<C4a01TI6@0B4Q804M7A`0m?Cd0FEUI0<?3``3;bl/0FEUI04i>CP1SHf<0Y:BT0:b/[01fMWH0
XZ:R0;bl_02o_kl0@D5103`l?01=CDd0>SXj02DU9@0R8R80;Bd]03/k>`1`L700Lg=c04I6AP2][Jd0
`/;20<S8b03<c<`0RHV904M7A`0`<300;bl_055AD@1bLW80O7al06UYJ@11@D40ATI60861P@0[:b/0
L71`06QXJ01=CDd0De=C061PH01NGUh0C4a<09nOW`1OGel0ZJVY08^;R`0d=3@06QXJ00<05ADE00@0
5QHF02d];@2?Shl0B4Q80P1IFET06P1RHV80B4Q804m?C`29RHT0Cdm?02`/;00];Bd0VIVI0<k>cP3;
bl/0TI6A065QH@1dM7@0K6a/05MGE`1OGel0O7al0820P02OWil0];Bd0<W9b@3IfMT0OGem024Q8@0I
6AT071`L0P0M7Ad09@0J6QX0820P024Q8@0Q8B40BTY:02XZ:P0Y:BT09bLW02XZ:P12@T80Jf][07Qh
N02ZZZX07QhN01lO7`0/;2`0ATI60820P01DE5@0Hf=S04i>CP1]KFd0Ng]k08b<S02FUYH0WIfM08J6
QP27QhL0UYJF02/[:`0L71`07AdM03lo?`1>CTh0GEeM0:>SX`2WYjL00P3;bl/0202QXJ40Ti>C0;Jf
]P2GUiL0Ph>3061PH01QHF40DU9B0P13@d<06`1CDe<0Q8B409ZJVP1mOGd0_[jn08J6QP1SHf<0Z:RX
09fMW@2=SHd0GemO061PH02>SXh0M7Ad06][J`1oOgl0I6AT09VIV@2JVYX0>3Ph05EEE@2c/k<0emOG
06a/K00/;2`07alO01hN7P0203hn?P0I02LW9`0Y:BT09BDU02DU9@0S8b<08R8R01dM7@0N7Qh0>CTi
0410@01_Kfl0ATI607IfMP1DE5@0ZJVY03hn?P1PH600=3@d03De=@19BDT0;bl_02`/;00d=3@0820P
01TI6@0201`L700601hN7P0S8b<09bLW03@d=02:RXX0YZJV0_ooool0003o06EUI@13@d<0PX:205MG
E`1KFe/0NWYj04=3@`2UYJD0UIFE061PH00^;Rh0@T9204Q8B00X:2P0GUiN03`l?01jNWX08b<S028R
8P1MGEd0D51@03Lg=`1QHF403Ph>02PX:01<C4`0@d=306UYJ@1IFET02`/;01LG5`1QHF40Cdm?069R
HP12@T802`/;06MWI`2LW9`0D51@03Ti>@1GEeL0;bl_020P801?Cdl0<c<c02d];@0M7Ad0LG5a07Ee
M@0e=CD0>CTi04E5A@0G5aL0Fe]K04=3@`1XJ6P0OWin04e=C@0T92@061PH03<c<`1nOWh0B4Q802/[
:`1JFUX0BTY:03Xj>P19BDT0AdM7055AD@0Z:RX0KVi^06=SH`0^;Rh0=3@d07UiN@11@D40;bl_092@
T016ATH0=3@d04E5A@0W9bL0N7Qh08Z:RP16ATH0HF5Q07IfMP1^KVh0=cLg06EUI@1bLW80A4A408V9
R@34a<@0F5QH07IfMP2:RXX0PH6107moO`1BDU80YjNW08f=S@1lO7`0BTY:0492@P2LW9`0IFEU0:NW
Y`2c/k<0Z:RX04M7A`2ATI40JFUY07AdM01KFe/0I6AT0:n_[`1RHV80Cdm?071`L019BDT0Hf=S08V9
R@1_Kfl0CDe=06EUI@1<C4`0K6a/096AT@1?Cdl0QhN705]KF`19BDT0FUYJ071`L01EEED0Cdm?05UI
F@0o?cl0V9RH092@T01DE5@0J6QX051@D02;Rh/0KVi^051@D01<C4`0<c<c051@D02MWId0L71`04U9
B@1OGel0TY:B01lO7`0[:b/0Jf][06ATI00o?cl0WinO028R8P10@400EUIF051@D020P800[jn_034a
<@1FEUH0V9RH05iNGP1PH600M7Ad03Hf=P10@400Jf][08Z:RP1BDU80Jf][08f=S@2<S8`0SXj>0:BT
Y02PX:00@D5103Ti>@2EUID0[:b/0861P@0W9bL0A4A407]kN`0i>CT0JVYZ0:FUY@2BTY80ATI607]k
N`1aLG40De=C07AdM01^KVh051@D03De=@1CDe<0>SXj09^KV`1ADE40<30`04A4A01ZJVX0<S8b07Ad
M014A4@0:RXZ06MWI`1iNGT0EeMG065QH@2LW9`0;Bd]03Xj>P1YJFT0=SHf02PX:01oOgl0PH61051@
D015ADD0FUYJ06=SH`0e=CD09BDU06m_K`1gMgL0Vi^K02`/;017AdL0UYJF0410@02:RXX0MWIf02PX
:00^;Rh0JVYZ061PH00g=cL0PX:2075aL@13@d<0<S8b028R8P0`<300GUiN001603Ti>@1TI6@0R8R8
055AD@0O7al0MgMg065QH@0g=cL0IVIV07emO@0g=cL0DU9B06ATI00h>3P0=cLg059BDP11@D40820P
04E5A@1fMWH0CDe=02@T900L71`0@d=305]KF`0R8R80J6QX0:JVYP2NWYh0Fe]K04U9B@1cLg<05aLG
02TY:@1IFET0L71`07EeM@0c<c<0NWYj02d];@0T92@0A4A405eMG@1UIFD0JFUY07=cL`1=CDd0>SXj
06i^KP1bLW80?3`l07emO@2FUYH0EeMG02XZ:P0T92@0@T9206i^KP1QHF40<S8b05QHF02g]kL0JFUY
0451@@1HF5P0G5aL03<c<`0P82007AdM01`L70806QXJ02<07AdM02LW9`0f=SH0UIFE09>CT`2YZJT0
]KFe0::RXP2FUYH0[Jf]09fMW@2TY:@0De=C03hn?P0b<S80;Rh^02XZ:P0e=CD0;Rh^02<S8`0P8200
;Bd]03Xj>P18B4P0D51@09RHV02SXj<0VIVI06MWI`23Ph<0DE5A05ADE014A4@0<S8b02`/;00207Qh
N00806EUI@1nOWh0Z:RX09:BTP2TY:@0SXj>06QXJ00W9bL201HF5P0808V9R@2DU9@0@41003dm?@12
@T80:2PX01HF5P0G5aL201DE5@0L01HF5P0R8R80Cdm?08f=S@1/K6`0?Shn01`L700I6AT0<S8b0:f]
[@3<c<`0b<S808^;R`1YJFT0JVYZ07EeM@2k^k/0e=CD0:JVYP1iNGT0GemO04];B`15ADD0@410038b
<P0Q8B406QXJ01TI6@805aLG04X06ATI01LG5`0L71`0DU9B05aLG01QHF40?Cdm02d];@0c<c<0Cdm?
07alO02DU9@0AdM7071`L01ZJVX0<C4a04Q8B01gMgL0/K6a096AT@1eMGD0Ti>C0<C4a02m_Kd0ZZZZ
0;Fe]@2ATI40RXZ:06m_K`12@T80CDe=0:n_[`2XZ:P0ZZZZ0;Bd]02WYjL0GemO03dm?@0M7Ad06QXJ
01HF5P0E5AD06ATI02PX:00a<C40GUiN0:BTY024Q8@0RHV90:f][@3EeMD0^k^k06QXJ01_Kfl0LG5a
08R8R01MGEd0=3@d02/[:`0V9RH0:2PX08Z:RP1PH600>SXj03@d=01>CTh0De=C09NGU`1CDe<0Q8B4
09ZJVP1nOWh0RHV907moO`L05ADE00<0<C4a08Z:RP13@d<00P1?Cdl06@1PH600T92@0861P@0a<C40
:BTY06IVIP1BDU80FEUI0:BTY038b<P0YZJV06][J`1JFUX0F5QH06=SH`1CDe<0ADE508J6QP2_[jl0
hn?S0;jn_P2BTY80CDe=02HV9P0K6a/00`0L71`0100M7Ad07alO03Hf=P0j>SX202LW9`0602DU9@0_
;bl0O7al0:VYZ@2MWId0Y:BT0P0M7Ad0:P0J6QX0?3`l079bLP2:RXX0Y:BT0:ZZZP1>CTh0=cLg04e=
C@1>CTh0G5aL07IfMP1ZJVX0UIFE08Z:RP0`<300=cLg06YZJP2SXj<0bLW90<g=c@3De=@0`<3005IF
EP0/;2`0?3`l07EeM@2FUYH0TI6A04];B`13@d<0?clo04=3@`17AdL0ATI604m?C`2PX:00P8200<?3
``26QXH0CTi>0:FUY@80XJ6Q00h0WinO07EeM@1BDU80>CTi04M7A`1SHf<0S8b<0;^k^`22PX80?clo
04=3@`1`L700];Bd038b<P<07AdM00<0<c<c04I6AP0U9BD00P0U9BD07P0R8R808B4Q028R8P0M7Ad0
7QhN02d];@0m?Cd0Hf=S06IVIP1FEUH0H61P08b<S00[:b/0KFe]0451@@0f=SH0@D5102@T900V9RH0
;2`/01dM7@0L71`07QhN01dM7@0O7al09bLW03Hf=P1NGUh0^[Zj0:RXZ0;ooooo0000I@1]KFd0@d=3
06QXJ01LG5`0De=C07EeM@0b<S80I6AT05YJFP1ADE409bLW03Xj>P0O7al06ATI03Ph>00^;Rh0EeMG
01/K6`0B4Q80@D5104E5A@0_;bl0G5aL01XJ6P0M7Ad0;2`/030`<01[Jf/0GEeM03Xj>P0J6QX0BTY:
04A4A01aLG40Hf=S02TY:@15ADD0Y:BT03/k>`0o?cl0HF5Q055AD@0X:2P0BTY:02l_;`1PH600<C4a
06QXJ01DE5@0:2PX04M7A`1PH600>3Ph05QHF00T92@0D51@0861P@1`L700Hf=S03hn?P0h>3P0][Jf
02<S8`0N7Qh0GUiN05aLG01BDU80RXZ:0492@P0W9bL06a/K06IVIP1gMgL0@D51034a<@24Q8@08B4Q
01hN7P27QhL0H61P03dm?@16ATH06a/K05ADE01bLW80@41006IVIP29RHT0AdM702PX:01NGUh0Hf=S
0410@01hN7P0clo?03De=@0i>CT0ATI606ATI01UIFD0@4100080_Kfm0?L0@D5103Xj>P0e=CD0LG5a
05UIF@2OWil0^k^k0;6a/@0c<c<0De=C06UYJ@1/K6`0BTY:04I6AP1fMWH0EeMG05=CD`1ADE40>3Ph
03Lg=`1GEeL0HV9R04A4A01;Bd/0:b/[03dm?@1SHf<0?Cdm079bLP0_;bl0820P02h^;P10@400ATI6
059BDP16ATH092@T06e]K@1aLG40B4Q806][J`10@400KFe]06a/K01?Cdl0IFEU06ATI00i>CT0MGEe
065QH@19BDT0HV9R09JFUP1`L700;bl_06m_K`1=CDd0BDU908b<S01LG5`0GUiN04i>CP0_;bl0JFUY
09ZJVP1DE5@0>SXj09>CT`0j>SX0FUYJ07inOP21PH40@41008^;R`1:BTX0;Bd]04M7A`1cLg<0KFe]
06ATI02a/K40/[:b07emO@12@T80[Zj^0;^k^`1cLg<0<c<c05QHF02DU9@0GEeM0410@01RHV80KVi^
0410@02EUID0NGUi02LW9`0d=3@0FUYJ01dM7@15ADD0<C4a04a<C02:RXX0Q8B404e=C@1KFe/0De=C
02l_;`1dM7@0N7Qh04=3@`2SXj<0SXj>03Ph>00[:b/0HF5Q0451@@1UIFD0UYJF03dm?@0H61P0GUiN
08j>SP0^;Rh0AdM708:2PP2PX:00M7Ad034a<@1_Kfl0EUIF08b<S00L71`0S8b<0;2`/01QHF40Jf][
051@D00O7al0B4Q80:RXZ01_Kfl08B4Q034a<@24Q8@0EeMG0492@P1<C4`0GUiN096AT@0_;bl0>3Ph
04Y:BP16ATH0:b/[09FEU@2DU9@0G5aL05QHF01LG5`09bLW05]KF`1[Jf/0K6a/04=3@`1JFUX0E5AD
01DE5@0K6a/0E5AD07YjNP1NGUh07alO04I6AP1DE5@03Ph>03@d=01GEeL0Q8B405eMG@1FEUH0JFUY
04A4A00a<C40Lg=c04e=C@0/;2`0<30`09>CT`1BDU80DE5A06=SH`1ZJVX0MgMg06YZJP1UIFD0I6AT
04];B`2CTi<0LW9b03Lg=`24Q8@0/;2`04E5A@0W9bL092@T0451@@1[Jf/0ATI602l_;`29RHT0_kno
071`L012@T80Lg=c04e=C@1;Bd/0>c/k02d];@0X:2P0:BTY03De=@0Z:RX092@T02`/;01QHF40^k^k
0<S8b02f][H0/[:b09BDU02c/k<0CTi>08Z:RP1QHF40<C4a02PX:00f=SH0<30`02XZ:P17AdL0>3Ph
020P800R8R80:2PX0080=SHf01`0N7Qh0;6a/@2:RXX0Ph>30;:b/P1<C4`0=CDe02TY:@0b<S80J6QX
04];B`0c<c<0J6QX05YJFP16ATH0L71`0:>SX`1TI6@0ADE505ADE00Y:BT05aLG07YjNP1@D5007alO
02DU9@0R8R806ATI1@0E5AD201HF5P1103@d=02?Shl0V9RH06YZJP1dM7@0[jn_09^KV`27QhL0W9bL
0=;BdP3<c<`0aLG50:NWY`1lO7`0ZJVY0<k>cP34a<@0J6QX03Hf=P0Q8B40:BTY051@D01fMWH0EUIF
04A4A00W9bL06QXJ01TI6@0L71`0?Cdm07moO`1bLW80E5AD03/k>`0Q8B407alO04M7A`1TI6@0OWin
0<K6aP16ATH0CTi>01`L700T92@0>3Ph04e=C@1?Cdl08R8R02h^;P2[Zj/0Ti>C05QHF01`L700=3@d
02PX:00k>c/0/[:b09RHV02LW9`0];Bd08Z:RP2@T900QhN706][J`0n?Sh00`0E5AD201LG5`0P020P
800M7Ad09BDU06ATI02/[:`0WinO0;6a/@3WinL0i^KV0:FUY@1>CTh0?clo04=3@`14A4@0?Shn03Ti
>@0X:2P0<S8b06e]K@0S8b<071`L01dM7@0O7al0<c<c06ATI01fMWH0De=C08>3P`1OGel0IFEU07em
O@0F5QH501DE5@0901HF5P0E5AD0Fe]K08F5Q@11@D40@T9208Z:RP2RXZ80Shn?0080UIFE01D0F5QH
04A4A00[:b/0I6AT08j>SP33`l<0]kNg04m?C`18B4P0;Bd]03dm?@1_Kfl0alO70=;BdP3Hf=P0UIFE
09ZJVP1/K6`0CDe=0451@@0U9BD00P0L71`0B00F5QH09RHV04m?C`0a<C40;Rh^03hn?P1SHf<0M7Ad
07EeM@26QXH0^k^k0:>SX`1[Jf/0=CDe01lO7`1HF5P0AdM705ADE01[Jf/0MWIf03dm?@0Z:RX0C4a<
05=CD`13@d<07alO05QHF01kNg/0XZ:R0<W9b@2`/;00VYZJ0::RXP3?cll0e=CD0=KFeP2@T9007QhN
02l_;`1_Kfl0RXZ:09nOW`2FUYH0Hf=S04m?C`15ADD0?Cdm0492@P1:BTX0E5AD0:>SX`2ZZZX0_Kfm
0;Rh^023Ph<0V9RH0<71`@2f][H0N7Qh03Hf=P0[:b/0?Cdm03hn?P1?Cdl0VYZJ09FEU@1bLW80A4A4
0492@P1LG5`0RXZ:024Q8@<07AdM00<0:RXZ02/[:`0V9RH00P0U9BD0100S8b<08B4Q028R8P0M7Ad2
02DU9@0H03@d=019BDT0UiNG05=CD`2NWYh0a<C4071`L02b/[80D51@03Lg=`0a<C407AdM028R8P0W
9bL07AdM01`L700N7Qh092@T02d];@1@D500S8b<0;Zj^P3@d=00`L710_ooool0000a06YZJP17AdL0
L71`0492@P1JFUX0Vi^K069RHP1fMWH0PH6106a/K00Z:RX0CTi>06ATI00k>c/0>3Ph02@T901HF5P0
BDU902l_;`1;Bd/0=SHf02DU9@1SHf<0?Shn03Ph>00c<c<08B4Q05=CD`1bLW80EeMG01`L700o?cl0
4a<C03`l?01HF5P0=CDe03dm?@2][Jd06ATI024Q8@16ATH0FEUI02DU9@0X:2P05aLG05EEE@0e=CD0
IfMW05IFEP0201dM7@0804=3@`0m?Cd0De=C03lo?`17AdL0EEEE065QH@1BDU8203dm?@110:6QX@0^
;Rh07QhN03dm?@1ADE40EEEE08j>SP1@D500Cdm?01`L701iNGT0M7Ad03hn?P0d=3@0LW9b0451@@0O
7al0NGUi06QXJ00i>CT0Bd];02/[:`18B4P0M7Ad04I6AP1WIfL0LG5a069RHP0^;Rh0EUIF06IVIP0o
?cl0JFUY0=?Cd`1dM7@0H61P05iNGP1KFe/0JVYZ0492@P2DU9@0]KFe07IfMP1=CDd0@D510861P@1S
Hf<0Ogmo0;fm_@2a/K40EUIF06a/K01PH600MgMg05YJFP1OGel0PX:205ADE01fMWH0OWin06e]K@18
B4P0KVi^05aLG01IFET00P1KFe/0Z01CDe<0HV9R034a<@1hN7P0I6AT03Ti>@0l?3`0Cdm?02/[:`1K
Fe/0HV9R0492@P1[Jf/0@T9203Lg=`25QHD0De=C08>3P`1LG5`0?3`l05iNGP1]KFd0ATI609BDU028
R8P09bLW03/k>`2>SXh0K6a/03Lg=`22PX80HV9R03<c<`28R8P0CDe=06UYJ@1hN7P0D51@069RHP1U
IFD0F5QH03Ti>@2HV9P0E5AD04U9B@1FEUH0EeMG03lo?`2PX:00RXZ:05EEE@1IFET0Vi^K01hN7P0O
7al0JVYZ0:VYZ@2FUYH0D51@0<;2`P3<c<`0820P01/K6`1CDe<0QXJ606MWI`12@T80QHF506i^KP0H
61P0De=C08B4Q013@d<0>SXj04Q8B00h>3P0HF5Q06i^KP0h>3P0RXZ:05]KF`0];Bd0XJ6Q092@T00`
<300L71`03hn?P0A4A40MgMg0::RXP1dM7@0:RXZ069RHP0A4A40>3Ph07alO01MGEd061PH06UYJ@2F
UYH07AdM02l_;`1@D500GEeM07emO@1;Bd/0MWIf05MGE`23Ph<0?Cdm0492@P2DU9@0FUYJ071`L01G
EeL0:2PX02LW9`1NGUh0MgMg0410@014A4@0Vi^K04M7A`0K6a/07alO03lo?`1WIfL0GemO03dm?@1@
D500>c/k01dM7@1TI6@0P82006i^KP1;Bd/0LW9b01`L7016ATH0A4A406ATI010@400GemO0492@P0Q
8B40<30`05YJFP1BDU807alO020P8019BDT0EEEE03<c<`1MGEd0G5aL07AdM01MGEd0IfMW07alO01i
NGT0ADE506QXJ01ADE408B4Q01lO7`1EEED0DE5A05iNGP80Kfm_01P0FUYJ04U9B@1oOgl0HV9R04Q8
B02NWYh0HV9R03De=@1aLG40XJ6Q05YJFP0d=3@07AdM03Ph>01^KVh0@d=302`/;02SXj<0/;2`07Ui
N@0m?Cd0Ph>305MGE`1LG5`2061PH00807AdM020P800N7Qh07AdM01gMgL0PH6108Z:RP37alL20<[:
bP0/0=KFeP3;bl/0^;Rh051@D01nOWh0Q8B406ATI01MGEd0C4a<0451@@0f=SH0DU9B03Hf=P0/;2`0
8B4Q030`<010@400Bd];06YZJP1lO7`0Hf=S0:6QX@1aLG40CDe=03hn?P1EEED0I6AT03hn?P16ATH0
DU9B03De=@1iNGT0N7Qh04];B`16ATH0RHV909fMW@1HF5P0BDU9030`<020P800<c<c01hN7P0H61P9
01DE5@1201LG5`0d=3@0_Kfm0<?3``25QHD0B4Q803Ti>@0h>3P0F5QH0<?3``3Hf=P0P82005eMG@1V
IVH0Ti>C0=;BdP2<S8`0Ph>306e]K@1JFUX0<C4a01hN7P0W9bL0;bl_03Ph>01;Bd/0DU9B055AD@1H
F5P0NWYj0:6QX@1_Kfl0BDU9024Q8@0S8b<07AdM01lO7`1:BTX0Cdm?08Z:RP1LG5`0>c/k01dM7@0L
71`0820P03`l?00o?cl0Cdm?03`l?028R8P0FUYJ04Q8B01GEeL09BDU02HV9P0K6a/0IfMW05IFEP1P
H600SHf=06EUI@1JFUX0Jf][04M7A`1@D5006a/K0P0E5AD05@0H61P07alO01`L700H61P071`L0410
@01[Jf/0TI6A07MgM`3GemL0dM7A07QhN00Y:BT0820P02HV9P0U9BD0A4A403/k>`0[:b/0D51@03@d
=00301dM7@0601`L700M7Ad0:BTY08^;R`1OGel0Jf][0P1ADE401028R8P06ATI01DE5@0F5QH201DE
5@805QHF02@05ADE01hN7P2:RXX0EEEE07=cL`2YZJT0QhN70:b/[02ZZZX0Vi^K0:VYZ@2g]kL0HF5Q
06e]K@28R8P0Q8B40:f][@37alL0V9RH0:>SX`2e]KD0a/K60=cLg03Kfm/0gmoO08n?S`2;Rh/0Ph>3
04];B`1MGEd0H61P04I6AP0b<S80;bl_059BDP1LG5`306e]K@0;04U9B@10@400CDe=06ATI02MWId0
];Bd0;Ng]`1=CDd0HF5Q059BDP0d=3@00P1?Cdl0>`1ADE40F5QH038b<P1IFET0M7Ad02@T900I6AT0
8B4Q07YjNP2c/k<0_[jn08b<S02?Shl0RHV909JFUP2:RXX0IfMW08R8R00[:b/0C4a<096AT@2f][H0
cLg=0=SHf039bLT0`L710;2`/02?Shl0K6a/04m?C`1CDe<0]KFe08Z:RP30`<00dM7A08n?S`2k^k/0
fMWI0;fm_@29RHT0EeMG061PH01^KVh0PH6109:BTP36a/H0B4Q8071`L01WIfL0@T9205eMG@2GUiL0
7alO01dM7@0O7al07AdM02XZ:P0L71`08b<S00<09BDU01d08b<S020P800O7al09BDU02PX:00b<S80
HV9R0<_;b`2XZ:P0YjNW0<G5a@2^[Zh0dM7A07YjNP18B4P0<C4a024Q8@0R8R809RHV02TY:@0[:b/0
AdM705ADE028R8P0]KFe0:ZZZP22PX80OGem0<?3``02ooooo`000:80Fe]K04Q8B01/K6`0Bd];03Ph
>01RHV80DE5A06EUI@1bLW80:BTY01XJ6P0T92@0C4a<03Xj>P0`<3006QXJ03Ph>01JFUX0<C4a03hn
?P0g=cL05aLG05YJFP0h>3P0=SHf02/[:`0A4A40<S8b04A4A01DE5@071`L0451@@12@T80De=C05mO
G`1;Bd/0=SHf09:BTP0c<c<0=CDe03lo?`1IFET09BDU04U9B@0R8R80HF5Q04A4A01UIFD0H61P03<c
<`0X:2P0ADE504A4A01JFUX0Fe]K061PH01^KVh0H61P05YJFP1>CTh0BTY:09^KV`14A4@0:BTY04E5
A@1WIfL0Fe]K06QXJ01=CDd0HF5Q02l_;`2>SXh0OWin055AD@0b<S80Shn?05MGE`0Q8B40Ng]k06IV
IP0c<c<0FEUI02l_;`1>CTh0P82004U9B@1jNWX0Vi^K07UiN@0m?Cd0I6AT075aL@0S8b<0@D510:VY
Z@1cLg<0TY:B08J6QP2:RXX0=3@d02DU9@0n?Sh0Q8B40:n_[`22PX80KFe]09nOW`1<C4`0D51@08Z:
RP2PX:00C4a<07alO016ATH0EEEE059BDP1MGEd0SXj>034a<@14A4@0Hf=S04i>CP1IFET0SHf=04A4
A00j>SX0CDe=04Q8B01LG5`0OWin02TY:@1LG5`0CTi>034a<@1DE5@0NGUi051@D014A4@0Fe]K02TY
:@1dM7@0SHf=051@D01]KFd0<C4a08Z:RP2FUYH0CTi>05aLG00b<S80=SHf08n?S`2@T900D51@04a<
C02ZZZX0<c<c02TY:@1_Kfl0H61P038b<P1kNg/20451@@1h05ADE01@D500IfMW05eMG@0d=3@071`L
06i^KP1]KFd0E5AD07QhN00n?Sh07QhN05EEE@1_Kfl0DE5A04U9B@2GUiL0Ng]k08Z:RP2ZZZX0/;2`
09FEU@1OGel0_[jn0<[:bP27QhL0>CTi03Ph>01oOgl0NWYj04Y:BP27QhL0P8200492@P1]KFd0S8b<
069RHP0f=SH0EeMG01TI6@0c<c<0HV9R03Ti>@1hN7P0J6QX02d];@1BDU80JFUY028R8P1GEeL0?Shn
02TY:@1_Kfl0Rh^;05mOG`0/;2`0L71`04E5A@10@400Hf=S03@d=00F5QH0IfMW08f=S@0o?cl0DU9B
075aL@1EEED0Ng]k04=3@`1gMgL0M7Ad07alO01;Bd/0?Shn08n?S`1=CDd0LG5a07QhN01PH600>c/k
08Z:RP1dM7@0=3@d04I6AP2@T900MgMg04m?C`0W9bL0?3`l07moO`1VIVH0>SXj04e=C@1NGUh0<C4a
07AdM021PH40MWIf04Q8B01/K6`0@41006QXJ01:BTX0HF5Q030`<01XJ6P0DE5A03Xj>P0e=CD0J6QX
06IVIP0Y:BT09RHV06][J`24Q8@0DU9B05QHF01/K6`0Lg=c0P0j>SX0F`1SHf<0L71`0492@P1IFET0
>c/k02<S8`0Y:BT0P82005ADE01IFET0EEEE06i^KP0V9RH061PH06MWI`1fMWH0ADE50:>SX`1aLG40
E5AD06YZJP2VYZH0H61P03Ti>@0Q8B40@d=3071`L01QHF4071`L04m?C`2ATI40Hf=S02h^;P1/K6`0
IfMW04i>CP19BDT0BTY:051@D01;Bd/0CTi>04a<C019BDT0GUiN0;6a/@2l_;`0_[jn0;2`/02NWYh0
^[Zj09nOW`2TY:@0YjNW08f=S@1KFe/0G5aL05eMG@1XJ6P0P82004Y:BP0f=SH0;bl_03De=@11@D40
?Shn04Y:BP1lO7`0M7Ad07MgM`2DU9@0=CDe03<c<`1FEUH0GemO04Y:BP1MGEd0B4Q801hN7P0G5aL0
:2PX051@D01EEED0D51@04A4A01WIfL0VIVI0::RXP2QXJ40VIVI02LW9`0I6AT02`0E5AD03`0G5aL0
OGem0:^[Z`1LG5`0GUiN06][J`2?Shl0^k^k0=SHf03Ph>00/;2`0;Fe]@33`l<0HV9R06ATI00208R8
R01D08Z:RP1@D500IfMW05iNGP0Y:BT06ATI01/K6`0M7Ad08B4Q02LW9`1kNg/0W9bL0<K6aP1hN7P0
8b<S01`L700N7Qh07alO028R8P10@400@D5106EUI@2LW9`0<30`01TI6@0E5AD05aLG01TI6@0U9BD0
@T9209ZJVP2ATI40DE5A03hn?P0o?cl07alO02XZ:P0I6AT0BDU902LW9`0];Bd0FEUI05EEE@1=CDd0
GEeM03Ph>014A4@0>CTi01XJ6P0I6AT0820P01dM7@0L71`06QXJ01`L700a<C40FEUI07IfMP2<S8`0
_Kfm09JFUP15ADD0;Rh^01`L700Q8B409BDU02`/;00i>CT0@d=3059BDP0S8b<07AdM01`L700I6AT0
71`L01hN7P0M7Ad0AdM708B4Q01IFET0GEeM051@D02;Rh/071`L1@0E5AD0T00G5aL05ADE01LG5`0o
?cl0`L710;>c/`2FUYH0^KVi09^KV`1gMgL0UYJF0:>SX`2UYJD0D51@07emO@1VIVH0Bd];04Q8B02O
Wil0hN7Q0;fm_@26QXH0PH610;Vi^@2h^;P0c<c<09^KV`1`L700LG5a08j>SP1@D500De=C065QH@1o
Ogl0XJ6Q09NGU`2ATI40L71`04U9B@0Z:RX0=cLg04A4A00h>3P0CTi>07emO@1hN7P0ATI607alO02m
_Kd0?3`l03Ti>@0o?cl0@T9204A4A01VIVH0LG5a0:>SX`1hN7P08B4Q01TI6@0c<c<0WIfM0<;2`P28
R8P0@41003Ph>015ADD0FEUI06UYJ@1MGEd0I6AT09RHV02/[:`0YZJV0;Ng]`33`l<0cLg=09:BTP2<
S8`0OWin09ZJVP34a<@0cLg=0=3@d03AdM40fm_K0>?Sh`3Hf=P0dM7A0<o?c`3QhN40d];B0;bl_02X
Z:P0WinO09NGU`2>SXh0V9RH0;Rh^01BDU80EeMG0861P@1>CTh0IVIV092@T00Q8B407AdM01lO7`0P
82009bLW01DE5@0O7al08R8R02@T900O7al071`L01dM7@0L71`08B4Q02<S8`15ADD0_kno0;Bd]03<
c<`0alO70=;BdP32`/80eMGE08f=S@1@D500K6a/07emO@1nOWh0L71`08F5Q@2i^KT0];Bd0=7Ad@2h
^;P0O7al04e=C@0n?Sh0MWIf0:6QX@;ooooo00004`1EEED0@d=306IVIP1TI6@0@d=308V9R@1ADE40
KFe]08f=S@1kNg/0<c<c03/k>`1EEED0?Cdm04a<C00n?Sh0A4A405YJFP0b<S800P0o?cl0;P0Q8B40
JFUY02TY:@0m?Cd0=CDe02<S8`11@D40Fe]K04A4A00P8200GUiN05aLG01RHV80GEeM04];B`0f=SH0
X:2P04I6AP0e=CD0?Shn061PH00d=3@0I6AT03<c<`1LG5`0=cLg05]KF`2HV9P0BDU902l_;`0n?Sh0
92@T051@D01HF5P0DU9B07]kN`1@D500=CDe034a<@0b<S80QHF505]KF`0[:b/0CTi>051@D00_;bl2
06e]K@2=06YZJP17AdL0[Zj^09JFUP0c<c<0:2PX07emO@1PH600:b/[09NGU`1RHV80;2`/05QHF00e
=CD0EeMG06=SH`0Z:RX0@D5107]kN`1EEED0>c/k07emO@2UYJD0FEUI04i>CP3Bd]80B4Q803lo?`19
BDT0Fe]K06e]K@1JFUX0=CDe0861P@3EeMD0UiNG07emO@1^KVh0L71`08B4Q03@d=00c/k>0410@01<
C4`0L71`06EUI@15ADD0;bl_08J6QP1SHf<0IFEU05eMG@0K6a/0<C4a05]KF`1bLW80BDU9055AD@0I
6AT0<S8b07QhN01CDe<0MGEe04I6AP0N7Qh092@T04Y:BP1OGel0DE5A05]KF`0O7al0Fe]K08Z:RP1B
DU80Kfm_03lo?`1FEUH0MWIf04M7A`1OGel0?clo02<S8`1XJ6P0MgMg04];B`1CDe<0S8b<03`l?00P
8200ATI6061PH00[:b/0Fe]K08^;R`1RHV80JFUY0820P01eMGD0FUYJ06EUI@0j>SX0QhN707emO@1F
EUH0JFUY07emO@0l?3`0R8R808:2PP1TI6@0A4A408^;R`1nOWh0[Jf]0;Zj^P2b/[80TI6A05YJFP2i
^KT0e]KF096AT@0o?cl0>SXj07moO`1ADE40E5AD096AT@2=SHd0CDe=06a/K01gMgL0HV9R02h^;P1S
Hf<08b<S04E5A@1DE5@0<c<c06e]K@2>SXh0EeMG0080IFEU040092@T05eMG@1?Cdl0Bd];08Z:RP2[
Zj/0KFe]03hn?P2BTY80Fe]K04U9B@1jNWX0<30`01XJ6P1ZJVX0VIVI04a<C01@D500KVi^04A4A01[
Jf/0=3@d04A4A01OGel0N7Qh0451@@0a<C40O7al03@d=01nOWh0KFe]04m?C`0i>CT0NWYj06UYJ@0Y
:BT0>CTi07inOP1<C4`0=SHf02PX:00o?cl0PH6104];B`0^;Rh0Bd];08R8R018B4P0Ogmo09>CT`1k
Ng/0D51@0:n_[`1UIFD0MWIf04i>CP1FEUH09BDU07IfMP1iNGT0EUIF02PX:01=CDd0KVi^0P0V9RH0
G01JFUX0OWin06UYJ@19BDT0Q8B407YjNP10@400AdM705iNGP1JFUX0?Cdm071`L01>CTh0=3@d03De
=@1VIVH0J6QX04Q8B01@D500S8b<06ATI00[:b/0E5AD04Y:BP0/;2`0N7Qh0820P01XJ6P0OWin0<G5
a@1dM7@0DU9B01HF5P0M7Ad0DU9B065QH@0Y:BT0T92@0<C4a01HF5P08b<S03Ti>@1QHF40Ng]k0:2P
X02l_;`0];Bd0861P@24Q8@0XJ6Q0:>SX`2VYZH0Y:BT0<71`@33`l<0^k^k07YjNP1/K6`0YZJV09>C
T`39bLT0RHV904Y:BP0f=SH0<C4a03lo?`16ATH0MgMg04M7A`10@400AdM703Ti>@0M7Ad06a/K02/[
:`1WIfL0_[jn06m_K`0b<S80J6QX04U9B@0l?3`0FUYJ04a<C00b<S80;bl_01/K6`0I6AT05aLG01TI
6@0S8b<0CTi>0P1=CDd01@1MGEd0d=3@0:>SX`1ADE407AdM00805ADE038051@D01DE5@0E5AD051@D
01DE5@0C4a<04A4A01DE5@0D51@05ADE06QXJ01]KFd0OWin096AT@2;Rh/0PH6109BDU03;bl/0^[Zj
03lo?`1bLW80@41002TY:@0h>3P0DU9B0:BTY02BTY80Shn?065QH@13@d<0K6a/059BDP0T92@05ADE
01LG5`0Q8B40O7al0;jn_P3@d=00_Kfm08N7Q`1:BTX0<S8b024Q8@0N7Qh0=SHf05YJFP26QXH0^[Zj
03De=@805ADE01P06ATI01LG5`0K6a/07AdM069RHP21PH40CDe=051@D00S8b<04Q8B01<C4`0E5AD0
>CTi020P800T92@0G5aL07QhN01CDe<0E5AD03dm?@0f=SH0?Shn028R8P0W9bL2024Q8@8071`L00T0
6ATI02HV9P1TI6@0TY:B09nOW`2h^;P0SHf=03De=@0`<3000P0L71`201lO7`0A02l_;`1FEUH0B4Q8
024Q8@0O7al08b<S01dM7@0L71`07QhN01dM7@0Y:BT0N7Qh06=SH`26QXH0Q8B40:n_[`0[:b/0100E
5AD0K00A4A405ADE01DE5@0F5QH0@d=30;Rh^02JVYX0_kno096AT@0i>CT0RXZ:08J6QP2ATI40WYjN
0410@00b<S80>CTi05iNGP18B4P0SHf=0=[JfP1PH600=cLg03Xj>P1MGEd0Y:BT0:^[Z`2g]kL0Hf=S
05MGE`2>SXh0I6AT0861P@2RXZ80X:2P08Z:RP2GUiL0PH6105aLG019BDT0?Cdm04i>CP0l?3`0;bl_
05]KF`1gMgL0;Rh^02`/;010@400/;2`0<;2`P3=cLd0KVi^04Q8B01CDe<0TI6A0=SHf03Kfm/0Rh^;
05eMG@0W9bL0KVi^06=SH`2ATI40?clo02l_;`0o?cl0?Cdm0492@P1BDU80M7Ad08J6QP33`l<0MWIf
0:ZZZP33`l<0Q8B408^;R`1fMWH0DE5A03lo?`0k>c/0BDU906EUI@2<S8`0d=3@0<O7a`2KVi/0a<C4
0:b/[02DU9@0c<c<0;bl_02MWId0H61P04A4A00m?Cd0@41004A4A01lO7`0RXZ:04Q8B01CDe<0Ti>C
06i^KP2MWId0:2PX01TI6@807AdM00H06ATI01HF5P0M7Ad07AdM024Q8@0M7Ad301`L700J020P801K
Fe/0^;Rh08b<S01mOGd0e]KF0;Bd]02EUID0S8b<0<;2`P1iNGT0Ph>30:FUY@2IVIT0Xj>S0:FUY@2/
[:`0clo?0<O7a`2>SXh0CDe=03@d=00b<S80FEUI08B4Q02OWil2ooooo`0006d0F5QH04a<C01DE5@0
BTY:0410@026QXH0>CTi03Hf=P11@D40AdM702TY:@1@D500@D51024Q8@0g=cL0>CTi03`l?00P8200
4Q8B020P800j>SX07AdM05mOG`0J6QX071`L02l_;`0Y:BT0GEeM0:NWY`12@T806a/K04e=C@15ADD0
Hf=S06e]K@0U9BD06QXJ05MGE`1DE5@0>3Ph065QH@1LG5`08R8R051@D00^;Rh0CTi>01lO7`0`<300
C4a<030`<00Z:RX0E5AD04M7A`1FEUH0@41006EUI@2XZ:P0MWIf06MWI`19BDT0>c/k09RHV01@D500
71`L05]KF`1PH600@d=304m?C`15ADD0<S8b02`/;02EUID0TI6A04m?C`0O7al0N7Qh03Ph>00R8R80
HV9R06a/K00/;2`0De=C01TI6@0^;Rh0IFEU0410@01HF5P0Ng]k05aLG00U9BD0B4Q805ADE01EEED0
Hf=S0=?Cd`1[Jf/0EUIF05QHF01OGel0JVYZ05EEE@0W9bL0KFe]0;^k^`3Ph>00h^;R07alO02CTi<0
MgMg0080bl_;0580Kfm_05IFEP2?Shl0FUYJ06=SH`1FEUH0UYJF06QXJ01IFET0Jf][07IfMP0n?Sh0
MWIf08b<S01=CDd0DE5A05UIF@17AdL0MgMg03dm?@1KFe/0KFe]04Y:BP0l?3`0E5AD05UIF@1=CDd0
BTY:02h^;P1FEUH0U9BD05]KF`27QhL0Hf=S061PH01ZJVX0@41006][J`1nOWh0C4a<07moO`1lO7`0
>SXj05=CD`1cLg<0Hf=S04=3@`1DE5@0Lg=c02d];@1BDU80OGem06QXJ01VIVH0OWin08:2PP1UIFD0
QHF504Y:BP25QHD0Q8B404e=C@1YJFT0De=C0451@@21PH40O7al065QH@1<C4`0TI6A08f=S@24Q8@0
`L710<[:bP1GEeL0;bl_08F5Q@36a/H0UiNG0410@00e=CD0Kfm_0P0i>CT0Z`1eMGD0QhN704e=C@1R
HV80LW9b05UIF@0e=CD0G5aL02<S8`0o?cl0HV9R03dm?@1nOWh0TY:B05YJFP1cLg<0L71`02d];@1]
KFd0Lg=c05eMG@2>SXh0[Jf]0492@P16ATH0X:2P06MWI`17AdL0NWYj0451@@0W9bL0XJ6Q0<71`@1n
OWh0DE5A06i^KP12@T80KFe]034a<@0n?Sh0Ng]k09>CT`1?Cdl0<30`07AdM00^;Rh0LW9b075aL@1>
CTh0=SHf07UiN@1fMWH0=SHf065QH@2?Shl0ATI603lo?`0U9BD0=3@d07IfMP0`<300=CDe06i^KP1i
NGT0AdM707EeM@27QhL0D51@03Xj>P21PH40H61P07emO@1aLG40K6a/02h^;P1<C4`0De=C03Ph>00R
8R80CTi>079bLP1BDU808B4Q04Q8B01VIVH0<S8b04=3@`2?Shl0SHf=06IVIP1GEeL0QXJ608N7Q`0_
;bl0@D5105ADE01RHV80@T9205eMG@1hN7P0DU9B03Lg=`1_Kfl0MWIf03dm?@1UIFD0Jf][0451@@26
QXH0Ng]k02<S8`0Y:BT0Kfm_07YjNP1BDU806ATI01lO7`1DE5@0:BTY01XJ6P1mOGd0Y:BT07]kN`0k
>c/0;2`/05MGE`3?cll0g=cL0=OGe`2e]KD0S8b<06IVIP1;Bd/0?Cdm03Xj>P0^;Rh0UiNG07inOP1S
Hf<0EEEE08f=S@2?Shl0[jn_0<o?c`3>c/h0Ti>C04Q8B00U9BD07alO01hN7P0U9BD0Bd];05ADE00_
;bl05ADE01LG5`0H61P0820P08^;R`2TY:@0HV9R07emO@16ATH0ADE504a<C00Z:RX0820P02DU9@0d
=3@0@T9201dM7@0301LG5`0@01hN7P0g=cL0EeMG04a<C02BTY80YjNW06IVIP1@D5005aLG01<C4`0A
4A404a<C014A4@0D51@05ADE01@D50804a<C00d051@D024Q8@1jNWX0>CTi02/[:`0m?Cd0<C4a02/[
:`14A4@0Xj>S075aL@0l?3`0=cLg008071`L01/06a/K02DU9@1EEED0ZZZZ05YJFP1]KFd0LG5a03Lg
=`12@T80Jf][04Y:BP1GEeL0SXj>0:VYZ@2FUYH0HV9R065QH@1ZJVX0Kfm_06a/K01XJ6P0IVIV09bL
W039bLT0KFe]09>CT`1^KVh00P0G5aL06`0F5QH05ADE01LG5`0L71`0CDe=05mOG`1:BTX0E5AD01LG
5`0@41005ADE010@400h>3P07alO02<S8`2>SXh0`<3007alO02EUID0Ogmo04E5A@0l?3`0>CTi03`l
?00R8R8071`L01DE5@0201LG5`0Q024Q8@1XJ6P0[jn_0=kNgP3;bl/0TY:B03<c<`0P82005QHF01/K
6`0I6AT08B4Q0492@P0m?Cd0:b/[02TY:@0M7Ad071`L01HF5P0E5AD061PH01XJ6P0Q8B40DE5A08R8
R01/K6`0N7Qh0<c<c01NGUh0AdM7034a<@0I6AT05aLG00805ADE05008R8R05aLG02a/K40U9BD07]k
N`2k^k/0VIVI05QHF01LG5`0>3Ph04m?C`1oOgl07alO020P800T92@0BTY:06ATI02i^KT0Xj>S061P
H00`<300?Shn04Y:BP26QXH0O7al09NGU`1VIVH0C4a<05IFEP1BDU80Kfm_06i^KP1eMGD0PH610820
P016ATH0?3`l04M7A`19BDT0DU9B055AD@0n?Sh0IFEU05UIF@0M7Ad06a/K03`l?02RXZ80dm?C0?3`
l03Vi^H0fMWI0<30`03@d=00fMWI0;Fe]@1cLg<0GUiN07emO@1>CTh0EeMG09^KV`0m?Cd0;Bd]038b
<P0];Bd092@T03hn?P32`/80alO70<C4a01kNg/0J6QX071`L00g=cL0CDe=07]kN`0n?Sh0ATI604=3
@`80<c<c01d0?clo0;2`/034a<@0Kfm_0;Zj^P2DU9@0Hf=S07YjNP2TY:@0GemO034a<@0/;2`0<30`
034a<@0d=3@0BTY:07]kN`1CDe<0A4A408^;R`20P800XZ:R038b<P0K6a/06ATI01`L700I6AT071`L
03<c<`0201lO7`807AdM01`07QhN03<c<`2CTi<0/[:b07emO@1`L700UIFE0;Zj^P2^[Zh0QHF508f=
S@2m_Kd0VIVI08j>SP3Bd]80ZZZZ0;Fe]@3AdM40fm_K0;Fe]@1VIVH0=CDe03dm?@0_;bl0FEUI079b
LP24Q8@0ADE50_ooool0002M05=CD`1<C4`0Fe]K04=3@`0e=CD0EEEE04];B`1EEED0FUYJ03@d=00F
5QH0<C4a04m?C`11@D40=SHf01`L700a<C40AdM702`/;00Z:RX0<S8b00l?3`15ADD0>3Ph02XZ:P0a
<C402PX:01XJ6P12@T80FEUI02@T901:BTX07AdM02TY:@1:BTX0C4a<01XJ6P1TI6@0ADE501HF5P0g
=cL0CDe=03hn?P16ATH061PH03dm?@0l?3`0DU9B06UYJ@0Q8B4051@D02XZ:P1FEUH0A4A403lo?`0]
;Bd0E5AD05eMG@1IFET0@d=3038b<P2JVYX0EeMG01hN7P0d=3@0Bd];03dm?@1HF5P0?clo05=CD`0]
;Bd0P82007YjNP1LG5`08B4Q071`L01MGEd07QhN06MWI`22PX80<S8b04A4A00^;Rh0?3`l08Z:RP0`
<300AdM705IFEP1dM7@0?clo065QH@1nOWh0HF5Q05mOG`3EeMD0R8R8075aL@1`L700DE5A07moO`1@
D5009RHV05=CD`2l_;`0fMWI0>?Sh`22PX80U9BD05EEE@34a<@0clo?06m_K`1?Cdl0UYJF05=CD`1H
F5P0EUIF0:FUY@1VIVH0EEEE06UYJ@1fMWH0?Shn071`L028R8P0CTi>059BDP1CDe<0BDU9071`L00d
=3@0FUYJ06YZJP0n?Sh0@D51059BDP1KFe/0EeMG05EEE@0o?cl0FUYJ09BDU01=CDd0Ng]k06UYJ@1:
BTX0QhN705ADE023Ph<0S8b<04a<C024Q8@0UYJF04Q8B01KFe/0QHF508V9R@0205ADE02g079bLP0n
?Sh0Ogmo08F5Q@1[Jf/0IVIV04i>CP26QXH0^KVi08V9R@0o?cl0MgMg08N7Q`19BDT0VIVI065QH@14
A4@0N7Qh06MWI`0Y:BT0;Bd]075aL@23Ph<0KFe]0;Rh^034a<@0O7al04e=C@2UYJD0dM7A096AT@1C
De<0;2`/06m_K`2;Rh/0B4Q806][J`2@T900DU9B07IfMP2<S8`0<c<c02DU9@1>CTh08B4Q03De=@1B
DU80ATI608F5Q@2MWId0EeMG07QhN01eMGD09BDU051@D01QHF40EUIF08V9R@2UYJD0KVi^03Hf=P22
PX80GemO04a<C02FUYH0ADE501TI6@1^KVh0YjNW05MGE`19BDT0Kfm_06][J`1oOgl0BTY:02LW9`1G
EeL0OWin03lo?`10@400QHF504i>CP1[Jf/0GEeM059BDP0m?Cd0O7al06m_K`0W9bL0KFe]09fMW@1d
M7@0DE5A038b<P17AdL0Q8B4051@D00e=CD0@T9205iNGP0V9RH0KFe]08Z:RP1YJFT0?Cdm07=cL`0l
?3`0DU9B04=3@`1UIFD0?clo07IfMP1OGel0>3Ph024Q8@0g=cL0G5aL03lo?`0Z:RX0LG5a09RHV01E
EED0D51@06e]K@1UIFD05QHF02<S8`1GEeL0R8R804I6AP1ADE40NWYj03Lg=`0Y:BT0WIfM0;6a/@1g
MgL0@T9207IfMP19BDT0:b/[05eMG@2LW9`0Bd];09nOW`1oOgl0DE5A04Q8B01NGUh0QhN706UYJ@0F
5QH08b<S0492@P1UIFD08b<S0492@P26QXH0LG5a04e=C@11@D40QHF50;Bd]01mOGd0MGEe055AD@0f
=SH0:BTY02DU9@0X:2P0>3Ph04U9B@2WYjL0JFUY038b<P10@400B4Q804Y:BP18B4P0/[:b096AT@1Q
HF40RXZ:0080V9RH0100QhN708V9R@2_[jl0_kno08R8R017AdL0@41004e=C@1]KFd0c<c<0=WIf@36
a/H0LG5a03Xj>P0b<S807alO0P0S8b<01P0M7Ad08B4Q02h^;P0S8b<05ADE01LG5`805ADE01l05QHF
02LW9`1WIfL0Ogmo08N7Q`2JVYX0G5aL05iNGP0N7Qh051@D01<C4`0E5AD05aLG01@D500B4Q805ADE
01`L700a<C40Q8B409fMW@0[:b/071`L02HV9P0T92@0:b/[04=3@`2DU9@0Hf=S04Y:BP0O7al06ATI
00806QXJ05d071`L01lO7`19BDT0LG5a03dm?@1GEeL0OGem059BDP0d=3@0OGem0<C4a01fMWH0FEUI
07MgM`1?Cdl0CTi>05mOG`1UIFD0I6AT079bLP1ZJVX0EEEE0820P01fMWH0Z:RX0:JVYP0j>SX06ATI
01DE5@0D51@05QHF01DE5@0f=SH0EUIF05EEE@0^;Rh0:RXZ00h>3P0E5AD051@D03Ti>@0_;bl0SHf=
0;:b/P1KFe/0@d=306QXJ00h>3P0EeMG08f=S@2UYJD0J6QX04Y:BP0`<3005aLG01PH600I6AT0820P
05QHF02j^[X0iNGU0>7Qh@3EeMD0J6QX03Ph>00G5aL0820P02/[:`11@D40?Cdm01hN7P0K6a/06ATI
02HV9P0U9BD071`L01/K6`0J6QX0:b/[0410@00n?Sh0D51@07EeM@2i^KT0h>3P0<G5a@1JFUX0AdM7
02d];@0G5aL071`L04Q8B02@T9000P21PH40801PH600>c/k05aLG02XZ:P0YJFU07IfMP1]KFd0AdM7
07UiN@0U9BD0820P02DU9@0/;2`0H61P07IfMP16ATH0M7Ad01dM7@0P8200<30`04=3@`1BDU80BTY:
05mOG`1ADE40GEeM079bLP16ATH0K6a/07UiN@1IFET0A4A40P0N7Qh0800L71`0:RXZ03Ti>@1<C4`0
GUiN0::RXP1RHV80BDU901XJ6P0^;Rh0TY:B0=7Ad@3?cll0][Jf0:n_[`31`L40b<S80<G5a@11@D40
Cdm?09fMW@1jNWX0MGEe08J6QP2ZZZX0D51@03Hf=P0c<c<09bLW03@d=02JVYX0bl_;0P31`L40602Y
ZJT0PH6102l_;`0S8b<0:2PX05ADE01=CDd0:BTY03`l?01IFET0Ng]k08J6QP2k^k/0d=3@09^KV`2Z
ZZX0CTi>03`l?01;Bd/0QhN704M7A`0i>CT0;2`/02PX:080:b/[00l0=SHf051@D01dM7@0B4Q806QX
J02CTi<0Xj>S04E5A@0K6a/061PH03`l?01[Jf/0@d=307=cL`1LG5`00P0a<C407@0n?Sh0Q8B40::R
XP1mOGd0GEeM06m_K`2JVYX0TY:B0:n_[`2][Jd0ZZZZ07UiN@31`L40YjNW0::RXP35aLD0R8R808J6
QP35aLD0f][J05UIF@1lO7`0MGEe05ADE01gMgL0OGem08b<S00i>CT0KFe]00;ooooo0003055AD@1D
07QhN00j>SX0LW9b05aLG01EEED0OGem06][J`0a<C40>3Ph04M7A`13@d<0:BTY0410@00[:b/0HV9R
03Lg=`0Z:RX0BDU902TY:@1eMGD0DE5A028R8P0U9BD071`L020P8017AdL0HF5Q028R8P0[:b/0BTY:
03lo?`1JFUX0GemO01PH6017AdL0De=C02<S8`0j>SX0EUIF03hn?P0k>c/0@41004I6AP1EEED0D51@
061PH017AdL0<S8b03Hf=P1PH600?3`l06m_K`1BDU80QhN707=cL`1_Kfl0?clo038b<P2HV9P0H61P
02d];@16ATH0>c/k03`l?01KFe/0?Cdm07=cL`15ADD0`<30092@T01hN7P09bLW04a<C01^KVh092@T
05aLG02=SHd0>3Ph04E5A@12@T80>CTi07UiN@0N7Qh0A4A40P1iNGT0o`15ADD0FUYJ07EeM@1;Bd/0
A4A40=CDe02>SXh0JFUY075aL@1CDe<0CTi>02`/;00R8R80=SHf09fMW@3@d=00hn?S0;Zj^P2ATI40
>3Ph0::RXP3=cLd0OGem04A4A02BTY80DE5A07emO@1CDe<0ZJVY06UYJ@1TI6@0OGem07alO012@T80
JFUY08j>SP1?Cdl0K6a/065QH@17AdL0N7Qh03hn?P1RHV80NGUi04];B`14A4@0CDe=05QHF011@D40
KFe]06UYJ@1=CDd0WinO04E5A@23Ph<0IFEU03Ti>@2;Rh/0>CTi06EUI@21PH40BTY:08>3P`2b/[80
@D5102XZ:P1YJFT0P8200410@01QHF40M7Ad02<S8`1cLg<0CTi>05EEE@1lO7`0De=C04A4A01QHF40
OGem04A4A01_Kfl0Ng]k02TY:@1ZJVX0K6a/04A4A01gMgL0UYJF075aL@0m?Cd0U9BD075aL@14A4@0
Shn?0;bl_02CTi<0EeMG0:f][@3De=@0Jf][03Hf=P15ADD0PX:20820P01=CDd0Ng]k09^KV`0[:b/0
DU9B07EeM@1KFe/0@d=305QHF00f=SH0?Shn05iNGP0b<S80BDU909nOW`1MGEd0QXJ608F5Q@0m?Cd0
CDe=06i^KP17AdL0MgMg09FEU@1ZJVX0ADE509fMW@18B4P0@D5108J6QP1GEeL09RHV09ZJVP3>c/h0
JFUY051@D01MGEd0DE5A07AdM01=CDd0@d=307YjNP2PX:00BDU902@T901cLg<0ATI6092@T02ZZZX0
?Shn02d];@1IFET0KVi^03@d=01eMGD0[jn_07UiN@0h>3P08B4Q02LW9`1UIFD0>SXj03`l?024Q8@0
SHf=03lo?`1TI6@0P82005MGE`17AdL0[:b/07]kN`1UIFD0ATI606=SH`0K6a/0De=C079bLP1IFET0
9bLW04A4A01YJFT0820P028R8P1HF5P0Shn?07alO01=CDd0Ng]k07IfMP0i>CT0?Cdm05MGE`1dM7@0
=SHf04Y:BP1nOWh061PH01DE5@1@D500NWYj06YZJP0i>CT0QHF502HV9P0@4100=cLg07moO`10@400
V9RH08^;R`1oOgl0CTi>05=CD`1dM7@0D51@01lO7`0b<S80Fe]K07alO00a<C40DE5A0:b/[021PH40
IFEU05IFEP1>CTh0Cdm?04I6AP13@d<0CDe=04=3@`11@D40>SXj03Hf=P0K6a/061PH01`L701CDe<0
CDe=02PX:00c<c<0QhN708^;R`2`/;00dM7A0861P@0^;Rh0=3@d08V9R@005`3IfMT0b<S80:6QX@1M
GEd0?Cdm03<c<`0V9RH0:BTY038b<P1OGel0]KFe0=;BdP1ZJVX0:b/[028R8P0X:2P092@T02LW9`0R
8R807QhN01TI6@0D51@05QHF00@05ADE00<05aLG03@d=01`L7000P24Q8@0602UYJD0QHF50;:b/P2;
Rh/0IfMW06m_K`1fMWH0NWYj08Z:RP23Ph<0TI6A0;Ng]`3@d=00c/k>05EEE@0R8R8092@T02DU9@0_
;bl0CDe=09ZJVP1BDU80BTY:01`L70806ATI01h05aLG01`L700L71`07AdM05eMG@1SHf<0=CDe04I6
AP1RHV80NWYj07alO02>SXh0ADE504e=C@23Ph<0Ogmo05=CD`0f=SH0:2PX020P800/;2`0=CDe03Xj
>P1gMgL0GemO069RHP2WYjL0Ph>306][J`0a<C4201LG5`0F01`L700m?Cd0EeMG061PH00L71`061PH
010@400E5AD051@D04E5A@2GUiL0VYZJ08>3P`10@400G5aL02XZ:P0I6AT0<C4a055AD@2OWil0`L71
0:n_[`80QXJ60380?3`l02HV9P1IFET0X:2P0=WIf@3Ph>00jNWY0=GEe@3AdM40QHF503De=@0];Bd0
9bLW0451@@0T92@06ATI01`L700J6QX07QhN03Hf=P0O7al0:RXZ034a<@0Z:RX08R8R01lO7`0d=3@0
ZJVY0=kNgP3IfMT0bl_;0<;2`P2i^KT0S8b<07emO@24Q8@0XZ:R08R8R01^KVh0HV9R0492@P0X:2P0
@T9206MWI`1kNg/0RXZ:09VIV@2g]kL0L71`03hn?P809RHV01@0:b/[03De=@0U9BD09RHV05EEE@0I
6AT05QHF01LG5`0R8R80GUiN04U9B@1ADE40Kfm_08J6QP2^[Zh0HF5Q05QHF01^KVh0H61P038b<P80
71`L0P0N7Qh07`0V9RH0=CDe07]kN`2b/[80Rh^;06QXJ00M7Ad0;Bd]09BDU03<c<`0L71`05IFEP1I
FET0NGUi06ATI01IFET0Rh^;06EUI@10@400PH610:ZZZP2d];@0UiNG059BDP18B4P0;Bd]0451@@28
R8P0Shn?07alO034a<@00P2g]kL0A`2SXj<0=CDe02HV9P0Q8B40:BTY05UIF@0/;2`0:BTY03De=@2M
WId0T92@08B4Q02i^KT0Ogmo09ZJVP0l?3`0<S8b03dm?@1CDe<0@41003dm?@0`<300:BTY02XZ:P0/
;2`0=CDe0492@P1KFe/0Rh^;08b<S020P800[Jf]07alO00_;bl0JFUY08J6QP0`<300:2PX02d];@1A
DE40MWIf07YjNP1cLg<0JVYZ069RHP1iNGT0PH610:6QX@2WYjL0Kfm_08Z:RP1cLg<0SXj>07alO02_
[jl0Zj^[08R8R03=cLd0W9bL07YjNP3;bl/0^[Zj0:6QX@2g]kL0_[jn0;bl_02PX:00RHV903Ph>01a
LG40CDe=00;ooooo00002P1ADE40G5aL04i>CP22PX80>c/k07MgM`1]KFd0C4a<07emO@2;Rh/204M7
A`0>05EEE@1:BTX09BDU04Y:BP0e=CD0JVYZ03hn?P0/;2`0BTY:02h^;P1KFe/0ADE501<C4`0Q8B42
01hN7P3o05EEE@1TI6@09bLW03@d=01;Bd/0@d=305UIF@1FEUH06QXJ03Hf=P1]KFd0;bl_04a<C01G
EeL0ADE502`/;015ADD0BDU905]KF`19BDT0E5AD04a<C00l?3`0>SXj06][J`0g=cL0K6a/05aLG01o
Ogl0OWin079bLP13@d<0<c<c08n?S`1@D500<S8b04E5A@1GEeL0<S8b04U9B@1fMWH0O7al03dm?@39
bLT0VIVI05QHF00Z:RX0?clo07=cL`0Z:RX0B4Q8075aL@0d=3@0B4Q804i>CP0g=cL0N7Qh01/K6`1:
BTX0YJFU08V9R@18B4P0G5aL06IVIP0h>3P0;2`/0;Vi^@1iNGT0LW9b07AdM01:BTX0SXj>06=SH`0g
=cL09BDU06i^KP2`/;00g=cL0<K6aP2:RXX0>3Ph06IVIP28R8P0I6AT03`l?024Q8@0>c/k07IfMP1<
C4`0VIVI04];B`0j>SX0K6a/07=cL`0m?Cd0F5QH08Z:RP12@T80JFUY06EUI@12@T80Ng]k04m?C`15
ADD0OWin05UIF@15ADD0DE5A06QXJ010@400AdM705eMG@11@D40YjNW06][J`22PX80F5QH03Xj>P28
R8P0HF5Q05QHF01JFUX0?Shn06m_K`2OWil0EEEE04];B`1@D500KVi^02l_;`12@T80Jf][03De=@2Q
XJ40O7al04M7A`1EEED0IVIV06m_K`1TI6@0Rh^;028R8P1YJFT0UiNG04e=C@1bLW80JVYZ02LW9`1C
De<0Lg=c06MWI`1BDU80YjNW09RHV01;Bd/0RXZ:0<C4a01QHF40:BTY0861P@39bLT0Xj>S05]KF`0]
;Bd0EUIF059BDP1JFUX0RHV909:BTP1XJ6P0@T9205iNGP0V9RH0410@02HV9P0I6AT0;Bd]04e=C@1G
EeL0V9RH0;2`/00h>3P0Bd];05EEE@0n?Sh0OGem08:2PP1EEED0B4Q80:6QX@1JFUX0BTY:0;Ng]`24
Q8@0?clo07moO`0N7Qh05ADE07EeM@2RXZ80QXJ606EUI@1OGel0F5QH079bLP0I6AT03`l?01`L7022
PX80NWYj02PX:01`L7005QHF03lo?`1VIVH0F5QH03De=@1PH600Kfm_028R8P19BDT0UYJF06a/K01I
FET09RHV02DU9@1QHF40ADE501`L700];Bd0HF5Q0410@01JFUX0S8b<03Lg=`0Y:BT0O7al07IfMP1P
H600EeMG05UIF@0E5AD0;bl_04Y:BP1PH600;bl_04E5A@1JFUX08B4Q01LG5`0g=cL0Hf=S05QHF01<
C4`0RHV9001307]kN`2@T900EEEE05eMG@1/K6`0=CDe06YZJP2DU9@0BDU903Hf=P1`L700WinO05MG
E`1>CTh0X:2P07IfMP11@D40BTY:06m_K`0`<300W9bL0:RXZ01hN7P0DU9B0492@P2@T900?clo01/K
6`0^;Rh0ATI606EUI@0[:b/0Ph>30;fm_@29RHT0:RXZ04];B`15ADD0?clo04m?C`1DE5@0EeMG030`
<00L71`05ADE01LG5`0E5AD051@D01<C4`0D51@0AdM704Q8B00h>3P0FEUI05aLG02][Jd0g=cL0=CD
e02e]KD0ZZZZ0:f][@1lO7`0Cdm?04a<C01JFUX0@d=3030`<002034a<@0602DU9@11@D40YjNW0<S8
b02a/K40:b/[0P0L71`02@0I6AT07AdM028R8P0R8R807QhN01TI6@0F5QH05ADE01<C4`0301DE5@0L
01XJ6P1GEeL0Q8B40:n_[`3AdM40Z:RX079bLP1OGel0Cdm?04E5A@11@D40?clo04E5A@1GEeL0Jf][
08F5Q@2ZZZX0cLg=0<30`01IFET09BDU01lO7`0X:2P0FEUI08n?S`1PH600<S8b01PH60<05aLG01<0
5ADE01XJ6P0L71`08B4Q06QXJ01NGUh0<S8b03`l?01SHf<0Vi^K0;Ng]`2;Rh/0Fe]K04I6AP14A4@0
7alO01DE5@0I6AT06a/K00805QHF02P06ATI04=3@`2=SHd0Fe]K06EUI@1]KFd0HV9R0820P01YJFT0
;bl_01XJ6P10@400S8b<05YJFP0O7al0410@00h>3P0E5AD0?clo0820P029RHT0OGem05YJFP1CDe<0
:2PX01DE5@0A4A405QHF030`<01>CTh0ATI609JFUP3Bd]80[Jf]0:2PX02?Shl0`L710<[:bP38b<P0
/K6a0P3Bd]801P31`L40c<c<0:BTY017AdL0Cdm?034a<@<05aLG02T05QHF01TI6@0H61P0=3@d02@T
900H61P071`L01/K6`0O7al0IVIV0=gMg@3QhN40]KFe08^;R`27QhL0TY:B0<O7a`3?cll0c<c<09NG
U`2d];@0/k>c05iNGP0];Bd0=3@d03Lg=`16ATH0FUYJ06UYJ@22PX80E5AD05=CD`1UIFD0CTi>024Q
8@0X:2P0;bl_02`/;00R8R80DU9B01TI6@0201HF5P1h024Q8@0m?Cd0Jf][079bLP2VYZH0^[Zj08f=
S@2j^[X0MWIf075aL@1hN7P0;bl_01hN7P0V9RH0>c/k05EEE@27QhL0/k>c0<[:bP3=cLd0MWIf04Y:
BP1>CTh0Jf][0=;BdP35aLD0T92@09JFUP27QhL0P82008R8R02[Zj/0WIfM08R8R01<C4`0DE5A0;Zj
^P2m_Kd0M7Ad04i>CP1YJFT0Rh^;0:NWY`2EUID0OWin09jNWP35aLD0a<C40:FUY@2WYjL0P82004I6
AP0V9RH08R8R03Ti>@1;Bd/0;Bd]02/[:`1ZJVX0QXJ607]kN`2LW9`0U9BD08R8R00i>CT0=3@d0410
@00i>CT071`L02PX:00h>3P0=CDe030`<00d=3@0:b/[02d];@10@400Lg=c0:BTY02`/;00_Kfm0;Fe
]@2NWYh0QXJ603De=@0`<300@T9206QXJ01cLg<0IfMW07UiN@2IVIT0T92@0820P01/K6`0MGEe096A
T@2JVYX0U9BD08V9R@0f=SH0>CTi06MWI`35aLD0`/;20;:b/P39bLT0dm?C0<g=c@36a/H0IFEU05aL
G01WIfL0Xj>S0:VYZ@2SXj<0KFe]09JFUP1?Cdl0LW9b0_ooool0003o059BDP1ADE40Fe]K092@T011
@D40Lg=c06][J`15ADD0OGem09BDU01;Bd/0B4Q805]KF`1ADE40<C4a04m?C`0c<c<0IfMW03De=@0X
:2P0Cdm?02TY:@1MGEd0>CTi01LG5`0i>CT07alO01dM7@17AdL0EeMG02@T9019BDT0EeMG03/k>`1;
Bd/0DE5A01PH600m?Cd0NWYj034a<@1<C4`0EeMG05aLG00e=CD0Bd];04M7A`1>CTh0@T9207EeM@1Y
JFT0<S8b03Lg=`19BDT0?3`l07EeM@1KFe/0M7Ad08V9R@14A4@08B4Q02DU9@1`L700IVIV034a<@0n
?Sh0EeMG02LW9`13@d<0JVYZ07EeM@0g=cL0^[Zj0;>c/`0/;2`06ATI03Ti>@1QHF40;Bd]04=3@`1l
O7`09BDU055AD@1IFET0=SHf07=cL`0[:b/0;Rh^06YZJP1YJFT0<30`05iNGP1fMWH0OGem03hn?P3=
cLd0KVi^04=3@`1gMgL0GemO08n?S`1CDe<0BTY:03dm?@1hN7P0^KVi0=;BdP20P800UiNG05=CD`2Q
XJ40`L7107inOP0i>CT0T92@05]KF`1gMgL0DE5A08j>SP1lO7`0ATI605IFEP1iNGT0>SXj05UIF@2G
UiL0FEUI06a/K01IFET0@41007inOP1VIVH0@D5107=cL`0e=CD0A4A405aLG01kNg/0D51@05EEE@0l
?3`0>c/k08J6QP1QHF40S8b<05ADE00b<S80GUiN04Q8B021PH40P82005YJFP1LG5`0_;bl055AD@1?
Cdl0KVi^08J6QP1KFe/0De=C06ATI00c<c<0RHV908j>SP1DE5@0KFe]06IVIP18B4P0]kNg0;Rh^01;
Bd/0ATI60820P00j>SX0MgMg08Z:RP1;Bd/0KFe]06EUI@0T92@07AdM05EEE@29RHT0JFUY09ZJVP3@
d=00IVIV02/[:`1ZJVX0`l?30:BTY01VIVH0>CTi05]KF`0[:b/0<S8b04i>CP1WIfL0Jf][0451@@1H
F5P0Kfm_02XZ:P0n?Sh0<S8b028R8P18B4P08B4Q04I6AP2HV9P0K6a/055AD@18B4P0:RXZ03@d=021
PH40KVi^04U9B@35aLD0GEeM01lO7`28R8P0Rh^;03Ti>@23Ph<0?3`l01PH601bLW80IfMW061PH01R
HV80De=C05YJFP1PH600FEUI02TY:@0[:b/0Kfm_06MWI`0];Bd0Jf][06m_K`1bLW80R8R806e]K@0f
=SH0EEEE08B4Q01ZJVX0HV9R0;Jf]P2:RXX0MgMg02XZ:P0_;bl0GEeM001908J6QP1JFUX0BTY:07in
OP0g=cL0CDe=092@T01VIVH0ATI606MWI`1YJFT0BDU905aLG01UIFD0>SXj06=SH`1BDU80D51@030`
<01:BTX0NGUi04=3@`0^;Rh0@d=307alO01:BTX0De=C0;fm_@2^[Zh0Ti>C059BDP1]KFd0KVi^02@T
900g=cL0Shn?03Hf=P0T92@0PH6108Z:RP19BDT0:b/[06a/K01TI6@0@T92055AD@1WIfL0<c<c06a/
K023Ph<0N7Qh04i>CP16ATH0Ti>C07YjNP0L71`06ATI03<c<`1FEUH09RHV04];B`1mOGd0Ph>305MG
E`2FUYH0QHF505eMG@0c<c<08R8R03dm?@0T92@07AdM01HF5P0201DE5@0I01<C4`0@41004A4A010@
4017AdL0EUIF04Q8B01YJFT0/K6a0<C4a03=cLd0_;bl0=[JfP2e]KD0GEeM05iNGP1/K6`0Ng]k07em
O@1iNGT0M7Ad06YZJP1XJ6P0Ng]k08^;R`0209bLW00908n?S`0c<c<0?Cdm02`/;00L71`06ATI01hN
7P0O7al07QhN00807alO00`06ATI01dM7@0G5aL05aLG01/K6`1>CTh0L71`07AdM02a/K40[Zj^08V9
R@1:BTX203/k>`050451@@0_;bl0=cLg04=3@`0i>CT00P0d=3@02`1GEeL0WIfM09:BTP1UIFD0?Cdm
04=3@`1gMgL0SXj>06IVIP0S8b<071`L008061PH03P05QHF01DE5@0G5aL06QXJ01TI6@0Q8B40SXj>
065QH@13@d<0<S8b0::RXP30`<00Rh^;01TI6@0L71`0B4Q802XZ:P0G5aL05QHF01DE5@0J6QX05aLG
01XJ6P0V9RH0AdM709JFUP1XJ6P0Rh^;03<c<`1FEUH0HV9R07inOP29RHT0YJFU09FEU@0b<S804a<C
010@400];Bd0IVIV04];B`0i>CT0VYZJ05aLG01UIFD0?3`l01HF5P0E5AD0410@01@D500G5aL0ATI6
04Y:BP0a<C40Fe]K0<_;b`80e]KF00d0WinO09FEU@1ZJVX0G5aL09VIV@3>c/h0_[jn0;Jf]P2g]kL0
][Jf0;jn_P0K6a/061PH00<05ADE00P05QHF01DE5@0W9bL06ATI01LG5`0J6QX07QhN05YJFP80cLg=
00P0fMWI0;bl_029RHT0W9bL0:^[Z`2][Jd0`<300<g=c@80fMWI05h0SHf=05IFEP0a<C40>c/k0492
@P13@d<0BTY:04a<C00o?cl0Hf=S051@D00l?3`0GemO04a<C00V9RH09BDU02l_;`0Y:BT0GEeM01XJ
6P0E5AD05QHF02/[:`0];Bd0R8R80;no_`2d];@0ZJVY08B4Q01WIfL0W9bL0:NWY`2DU9@0PX:208Z:
RP2SXj<0[Zj^08:2PP1OGel0Cdm?05YJFP2@T900L71`03/k>`2VYZH0/;2`09:BTP2o_kl0P82007=c
L`1ZJVX0EUIF07alO02PX:00Ti>C08V9R@28R8P0Ph>30<71`@35aLD0YjNW07emO@1dM7@0JFUY0<[:
bP2QXJ40KFe]0:VYZ@2PX:00K6a/071`L02KVi/0TY:B075aL@1GEeL0B4Q803De=@1MGEd0@41003@d
=01nOWh0UIFE08b<S02JVYX0/[:b08V9R@0j>SX0<S8b04M7A`0d=3@07AdM01hN7P0/;2`0>c/k0P0b
<S80;P0Y:BT0:RXZ03/k>`2>SXh0_[jn0<S8b03@d=00c/k>0<W9b@1eMGD0RXZ:0:JVYP2QXJ40RXZ:
06=SH`1IFET0GEeM06m_K`2EUID0[jn_0<_;b`3=cLd0eMGE0=SHf03Kfm/0^[Zj08Z:RP2>SXh0]KFe
0<c<c03:b/X0`l?30=7Ad@3De=@0emOG0:NWY`1NGUh0QHF509RHV02f][H0[Zj^0;Jf]P38b<P0_Kfm
0:RXZ02<S8`2ooooo`000?l0D51@0410@00o?cl0OGem04=3@`1iNGT0>3Ph02XZ:P1RHV80IFEU03Ti
>@0n?Sh0De=C020P800e=CD0EeMG02h^;P1<C4`02@T9018B4P16ATH0:2PX05ADE00m?Cd04a<C0410
@00g=cL07QhN04A4A01FEUH07alO059BDP1HF5P0;bl_04Y:BP16ATH03`l?04I6AP20P800?Cdm04a<
C01WIfL0ATI602l_;`0h>3P0@d=302`/;00L71`0CTi>04a<C00O7al0=SHf04=3@`0/;2`0@41003@d
=01YJFT0PX:2059BDP0g=cL08R8R08F5Q@12@T805aLG03Ph>01GEeL0EEEE05=CD`1EEED0CTi>020P
802;Rh/0Ti>C04m?C`0[:b/0>SXj03lo?`0L71`0=SHf08B4Q00l?3`0BDU903/k>`0];Bd0FEUI03dm
?@0i>CT0JFUY07AdM01;Bd/0@T9205IFEP22PX80@T920<c<c02DU9@0AdM706e]K@0l?3`0RXZ:065Q
H@14A4@0=CDe06MWI`2b/[80P820030`<01WIfL0@d=309RHV036a/H0P82002h^;P28R8P0H61P07in
OP0b<S80K6a/07UiN@1FEUH0MgMg04];B`0V9RH0ATI607emO@1@D500Ph>303Hf=P0Z:RX0E5AD04I6
AP1<C4`0SHf=05EEE@0m?Cd0Cdm?059BDP0h>3P0NGUi07EeM@17AdL0XZ:R024Q8@1aLG40PX:203Ph
>01SHf<061PH03dm?@20P800IfMW05IFEP2n_[h0BDU902d];@1FEUH0Lg=c06EUI@1GEeL0LG5a02<S
8`2PX:00MgMg05QHF02ATI40OWin0410@00n?Sh0O7al06IVIP0j>SX0QHF5024Q8@0o?cl0J6QX05=C
D`1FEUH0NGUi07MgM`10@400K6a/09:BTP1ZJVX0U9BD0=;BdP2LW9`0JVYZ09JFUP3Ng]h0Xj>S07Ad
M01/K6`0WinO08^;R`1MGEd0JVYZ08F5Q@1RHV80NWYj08J6QP1nOWh0@41004e=C@0g=cL092@T06AT
I00j>SX0EUIF0:ZZZP1nOWh0EUIF04a<C01FEUH0BTY:09fMW@1eMGD0B4Q80820P01RHV80@410096A
T@1fMWH0?Shn0:FUY@1MGEd08B4Q09FEU@1YJFT0NGUi06ATI01PH600W9bL08f=S@1KFe/0@4100492
@P2:RXX0M7Ad04I6AP2IVIT0SHf=08B4Q02<S8`0IVIV03Hf=P1IFET0S8b<06e]K@1KFe/0/K6a08:2
PP1kNg/0;Rh^03dm?@1UIFD004X0QhN705QHF01@D500OWin04Y:BP1PH600/K6a092@T01LG5`0Kfm_
07EeM@1DE5@0UIFE07emO@1HF5P0JVYZ06QXJ01:BTX08B4Q0451@@1gMgL0I6AT03<c<`0o?cl0SXj>
03lo?`0d=3@0LG5a07=cL`20P800De=C08J6QP2@T900FUYJ04A4A02<S8`0?Cdm03Lg=`29RHT0Q8B4
04=3@`0/;2`0NGUi03Ti>@0];Bd0IfMW08Z:RP1<C4`0QHF50;>c/`1dM7@0<c<c065QH@2WYjL0PX:2
03<c<`1>CTh0KFe]08Z:RP16ATH0A4A408N7Q`2:RXX0EEEE08Z:RP2MWId0=SHf02DU9@0O7al0=SHf
02<S8`0I6AT061PH01LG5`805ADE03D04A4A010@400B4Q8092@T08V9R@2BTY80U9BD06ATI01>CTh0
FEUI0:f][@3:b/X0eMGE07inOP1EEED0GUiN05mOG`15ADD0>CTi03Lg=`12@T80MWIf0<O7a`28R8P0
UiNG09RHV02KVi/0YJFU05iNGP1MGEd0E5AD02<S8`0L71`09BDU02l_;`0Y:BT0:RXZ02LW9`0d=3@0
7AdM01/K6`0L71`0CDe=07EeM@1_Kfl0OWin05]KF`2=SHd0RXZ:04M7A`0j>SX0=SHf02@T900201TI
6@0>01`L700Q8B407AdM01`L701:BTX0UYJF08b<S02GUiL0/;2`09jNWP2@T900IfMW02@T900G5aL2
01DE5@0B01PH600G5aL05ADE01LG5`0J6QX06ATI02`/;02:RXX0EUIF03dm?@1bLW80O7al08F5Q@0I
6AT061PH03`l?00a<C406QXJ0`0E5AD06P0L71`07AdM01DE5@0G5aL0EEEE09NGU`2JVYX0<C4a028R
8P18B4P0EUIF07inOP3>c/h0U9BD02LW9`0_;bl0Hf=S05iNGP0/;2`092@T06a/K03:b/X0XJ6Q07Qh
N00G5aL05ADE0P0A4A405P0D51@04a<C03Lg=`1NGUh0KFe]0492@P1MGEd0e]KF0<[:bP2EUID0HF5Q
03De=@0b<S80CTi>0;Jf]P35aLD0Ti>C08Z:RP2ZZZX0];Bd04=3@`0G5aL501DE5@0V038b<P0I6AT0
6QXJ02l_;`1dM7@0`L7107=cL`2?Shl0ZZZZ07QhN013@d<0HV9R09:BTP2f][H0YZJV0;Zj^P2h^;P0
dM7A08b<S01bLW80ATI604U9B@0c<c<06ATI01dM7@0h>3P07alO01`L7010@400EUIF03dm?@1EEED0
Jf][030`<00^;Rh0<c<c05UIF@0J6QX201LG5`0?02DU9@0S8b<0QXJ60=CDe02DU9@0WinO0<K6aP2K
Vi/0/K6a0<W9b@3:b/X0_;bl08j>SP1NGUh0@4100080;2`/01<0=CDe04I6AP1/K6`0]kNg0:2PX02<
S8`0UIFE0;Vi^@1_Kfl0HV9R05]KF`1JFUX0J6QX07]kN`1oOgl0V9RH0:FUY@2n_[h0Xj>S0080_Kfm
02<0K6a/059BDP1jNWX0`L710<K6aP0g=cL0C4a<07UiN@1?Cdl07QhN028R8P0o?cl0ZZZZ05YJFP1=
CDd0ADE503dm?@1^KVh0Hf=S06YZJP2HV9P0/K6a0<71`@2m_Kd0a/K607]kN`0Y:BT0;Bd]03`l?00d
=3@07QhN01dM7@0Q8B40>3Ph03`l?00202h^;P0A03<c<`15ADD0Ng]k0<?3``3?cll0bl_;0=CDe03H
f=P0VYZJ08F5Q@1iNGT0JVYZ08>3P`2<S8`0UYJF08B4Q021PH400P1hN7P06P1kNg/0UiNG0<C4a02n
_[h0^[Zj0;fm_@2a/K40ZZZZ0<[:bP3Jf]X0jNWY0=[JfP2=SHd0_kno0=CDe03AdM40bl_;0;Rh^02Q
XJ40`<300:j^[P2k^k/0`/;20;jn_P1fMWH0H61P0_ooool0002F04a<C01EEED0B4Q806YZJP0g=cL0
K6a/04];B`0Y:BT0F5QH04Y:BP0I6AT0=3@d05YJFP0c<c<09bLW024Q8@0K6a/0EeMG02d];@0K6a/0
;Rh^014A4@10@400Cdm?01LG5`11@D405ADE01dM7@10@400CTi>02l_;`1@D500=3@d014A4@0b<S80
DU9B01hN7P0P8200I6AT01XJ6P0_;bl0BTY:04E5A@0S8b<07QhN02l_;`1@D500?Shn05eMG@16ATH0
8B4Q02<S8`1CDe<0CDe=06YZJP0j>SX0C4a<06ATI01GEeL0:BTY020P801lO7`0Bd];02XZ:P0T92@0
EeMG05]KF`1UIFD0YJFU0820P00_;bl0IfMW0;Jf]P1IFET0=3@d06e]K@1FEUH0<c<c02l_;`1dM7@0
>CTi0451@@1?Cdl0<30`05MGE`0^;Rh0>SXj0861P@28R8P0GUiN0410@01GEeL0GEeM0451@@31`L40
Z:RX04a<C01kNg/0=CDe02XZ:P0J6QX08B4Q02d];@1_Kfl0LG5a03hn?P0d=3@0H61P03<c<`1gMgL0
]kNg0:FUY@0g=cL0NGUi03@d=02;Rh/0CTi>059BDP19BDT0:b/[05ADE01[Jf/0<30`04E5A@1_Kfl0
820P04E5A@1MGEd0?Shn05eMG@1=CDd0;Rh^06MWI`1JFUX0AdM705UIF@1=CDd0<S8b04a<C01JFUX0
?Cdm0:VYZ@1SHf<0MWIf07=cL`13@d<0L71`05IFEP1ZJVX0J6QX0P1RHV80[`3;bl/0K6a/03Xj>P1A
DE40Q8B403Hf=P1IFET0RHV902/[:`21PH40E5AD04a<C01QHF40KVi^05MGE`1NGUh0R8R805IFEP1A
DE40Ti>C06YZJP1LG5`0MWIf055AD@1LG5`0XZ:R08N7Q`11@D40NWYj0:6QX@11@D40FEUI0;Zj^P24
Q8@0>c/k0:VYZ@3Ogml0VYZJ03lo?`0e=CD0FEUI079bLP1WIfL0VIVI09fMW@1GEeL0@41004m?C`1G
EeL0@d=304E5A@0k>c/0BTY:08f=S@10@400De=C0:JVYP1dM7@0OGem08V9R@1@D500@T9207alO00/
;2`0;Bd]06ATI01RHV80>c/k08b<S01<C4`0?Shn09^KV`1ADE407alO09jNWP1MGEd0NWYj02l_;`0i
>CT0EUIF07AdM01;Bd/0Cdm?05YJFP2;Rh/0HF5Q02LW9`1QHF40I6AT096AT@2_[jl0Bd];02/[:`1Q
HF40RHV906ATI01<C4`0_kno06EUI@0[:b/0<C4a05]KF`1mOGd0N7Qh05EEE@1DE5@0OGem02<S8`12
@T80RHV907alO01BDU80Vi^K09nOW`0m?Cd0HF5Q05aLG00U9BD0EEEE07QhN01[Jf/0=cLg03Ph>01N
GUh0?Shn02XZ:P1UIFD0`l?308V9R@1[Jf/0WYjN0:>SX`1@D500=CDe05mOG`27QhL0CDe=07inOP2T
Y:@0P82006ATI02>SXh0Cdm?05YJFP0l?3`0_Kfm08>3P`1@D500@d=3071`L00Y:BT0NWYj09FEU@1f
MWH0@41005aLG02TY:@0GEeM014A4@0M7Ad0?clo07IfMP0g=cL0>c/k07=cL`1XJ6P09BDU051@D01g
MgL0EUIF02DU9@0N7Qh0<S8b02HV9P0G5aL00`0E5AD201<C4`1401HF5P0N7Qh0<S8b06a/K01jNWX0
IFEU04Y:BP0j>SX0BDU908>3P`3:b/X0dM7A09VIV@0];Bd0@41009ZJVP2;Rh/0Jf][04i>CP1MGEd0
KVi^0;:b/P2c/k<0K6a/04Y:BP1SHf<0Q8B40:VYZ@1PH600BDU90861P@2UYJD0GEeM05=CD`1ZJVX0
W9bL06][J`1HF5P0@D5103De=@0_;bl0GemO08R8R01cLg<0MgMg05eMG@1BDU80>SXj02TY:@0e=CD0
;Rh^03/k>`16ATH0>3Ph038b<P0a<C408b<S02HV9P0`<300Jf][0;Bd]02e]KD0RHV906EUI@2HV9P0
BDU904];B`0I6AT601DE5@0901LG5`0F5QH05aLG04Q8B02DU9@0DE5A04I6AP1WIfL0QXJ600805aLG
00h09BDU03Ti>@0I6AT06QXJ01`L700I6AT07AdM01lO7`0L71`05aLG01dM7@1fMWH0][Jf079bLP80
820P04@0?Shn034a<@1SHf<0alO709jNWP1lO7`0ADE503Ti>@1LG5`0KVi^079bLP1fMWH0^[Zj08:2
PP0/;2`05ADE01@D500C4a<0410@01DE5@0T92@0MGEe0;Vi^@2DU9@0Xj>S0=;BdP3=cLd0OWin03Lg
=`18B4P0@d=306YZJP2=SHd0^[Zj07=cL`1SHf<0Ogmo071`L02UYJD0Lg=c02<S8`0E5AD04a<C01dM
7@0k>c/0GEeM0492@P15ADD0T92@0;Rh^01LG5`0=cLg09bLW01ZJVX0NWYj0;no_`3Ti>@0_;bl08J6
QP2GUiL0VIVI09^KV`37alL0RHV906m_K`1?Cdl061PH01DE5@805aLG03h0=CDe020P800G5aL06ATI
02HV9P19BDT0A4A406EUI@1dM7@0<c<c051@D01^KVh0:2PX01TI6@0K6a/07AdM0451@@2<S8`0SXj>
0:f][@2IVIT0e=CD0;Rh^02/[:`0`/;20<g=c@33`l<0E5AD03De=@0[:b/09BDU02l_;`0b<S80:b/[
02d];@36a/H0^[Zj06a/K028R8P0Ng]k07alO013@d<0>c/k05IFEP1ZJVX0MWIf0:ZZZP2a/K40ZZZZ
0<K6aP3Lg=`0T92@08>3P`2WYjL0^KVi07EeM@1JFUX0RXZ:02TY:@1UIFD0IVIV02d];@8071`L02P0
;Bd]06i^KP14A4@08b<S03hn?P1XJ6P0IfMW08^;R`1kNg/0PH61092@T02LW9`0[jn_0<S8b01fMWH0
>SXj034a<@10@400:b/[01lO7`0L71`06ATI02TY:@0k>c/0E5AD04A4A016ATH0BTY:069RHP2][Jd0
^k^k0;Vi^@3>c/h0d=3@0<O7a`2o_kl0Shn?0820P01XJ6P0DU9B0P12@T807@11@D40Bd];051@D01c
Lg<0SXj>08>3P`29RHT0QhN70451@@1FEUH0]KFe0=gMg@3De=@0f][J0=?Cd`2PX:00YZJV0<g=c@2T
Y:@0Vi^K0:RXZ033`l<0QHF507YjNP2g]kL0][Jf0;fm_@2[Zj/0FEUI00;ooooo00009`1>CTh0BDU9
04m?C`2:RXX0A4A406EUI@1QHF40?Shn08N7Q`25QHD0;bl_030`<015ADD0@D5105QHF01TI6@0:2PX
059BDP0[:b/0;2`/05IFEP0k>c/0DE5A06IVIP0E5AD0CDe=04M7A`0Q8B40?clo04A4A00G5aL0F5QH
06ATI010@400<S8b04Y:BP0Y:BT0@T9209fMW@0203Lg=`0/04Q8B012@T80:b/[03dm?@0[:b/0@D51
04=3@`1mOGd0P82002LW9`0[:b/0<C4a02d];@1SHf<0?clo051@D01?Cdl0Fe]K02l_;`0K6a/0@d=3
05MGE`0h>3P09RHV04=3@`0I6AT0:b/[065QH@1jNWX0@41003lo?`37alL0<C4a01`L701<C4`0LW9b
04Y:BP0Z:RX0L71`02XZ:P0b<S80OWin03Ph>01SHf<201PH603M04E5A@1^KVh0F5QH03Ti>@1JFUX0
@d=302PX:02<S8`0UYJF05MGE`24Q8@0;bl_02XZ:P0S8b<0E5AD0861P@34a<@0MGEe03lo?`0`<300
FUYJ02DU9@1OGel0U9BD08b<S00e=CD0MgMg065QH@1iNGT0DE5A04M7A`20P800ADE504m?C`1eMGD0
?Cdm055AD@23Ph<0FEUI05MGE`1>CTh0@41007=cL`1fMWH0@41007emO@0n?Sh0C4a<069RHP1oOgl0
De=C06ATI01:BTX0;2`/08^;R`1jNWX0Q8B405MGE`0h>3P0KFe]05mOG`1lO7`0K6a/03Hf=P0h>3P0
WYjN06YZJP0k>c/0EeMG08^;R`1ADE40A4A407emO@0_;bl0XZ:R079bLP1YJFT0MgMg08b<S01XJ6P0
SXj>0::RXP19BDT0<c<c08b<S01UIFD0FEUI07inOP14A4@0>c/k06a/K01hN7P0>c/k07]kN`2d];@0
PH6109:BTP3Bd]80NWYj04i>CP21PH40a/K608f=S@1]KFd0<C4a05eMG@1]KFd0C4a<07EeM@2KVi/0
OWin04a<C01BDU80@d=303De=@1NGUh0>CTi02@T901DE5@0ATI606EUI@2SXj<0G5aL04A4A01@D500
<S8b06UYJ@2;Rh/0?Shn03De=@19BDT0G5aL03dm?@2EUID0Jf][04=3@`2GUiL0ADE503De=@2g]kL0
[Jf]09NGU`1[Jf/0C4a<08N7Q`1^KVh0<S8b034a<@12@T80J6QX04i>CP0/;2`0JFUY0451@@1EEED0
Q8B405YJFP0/;2`0Cdm?08j>SP1ZJVX0CDe=0:^[Z`1jNWX0GUiN02h^;P0o?cl0D51@06=SH`0V9RH0
FEUI07UiN@0m?Cd0A4A40;Zj^P1WIfL0>CTi05QHF026QXH0De=C0:6QX@2<S8`0GEeM04m?C`1>CTh0
MgMg034a<@1@D500Vi^K061PH00c<c<0:RXZ06IVIP1:BTX0>3Ph08J6QP2GUiL0QhN705iNGP27QhL0
QXJ603Ti>@15ADD0SHf=08Z:RP1NGUh0_Kfm03Lg=`10@400:b/[07AdM01hN7P0B4Q804Y:BP1gMgL0
DU9B06i^KP2<S8`0Ogmo04E5A@1gMgL00P22PX804P0O7al08b<S02LW9`1gMgL0DU9B03<c<`1_Kfl0
R8R806QXJ018B4P0CDe=07]kN`0[:b/07AdM02`/;00`<3005aLG01HF5P805ADE02H04a<C02h^;P0n
?Sh0@T9204Y:BP0T92@05aLG01/K6`14A4@0F5QH03/k>`1gMgL0a<C40:n_[`38b<P0SHf=05=CD`18
B4P0FUYJ06m_K`1JFUX0>SXj020P800Y:BT0KFe]08V9R@1;Bd/0=CDe03Ph>01NGUh0W9bL0861P@2M
WId0dm?C08n?S`1NGUh0ADE503Hf=P80<30`01l0>3Ph04E5A@1IFET0Ph>30:NWY`2?Shl0P82008N7
Q`1FEUH0820P01dM7@0J6QX06a/K01HF5P0D51@07AdM051@D01^KVh0?3`l03<c<`0g=cL0FUYJ07Mg
M`2CTi<0WYjN08>3P`2@T900?3`l02/[:`18B4P0:BTY00805ADE02L061PH01HF5P0G5aL05aLG01PH
600E5AD06a/K05IFEP1nOWh0DU9B06MWI`1iNGT0;Bd]01LG5`0I6AT0ATI603<c<`0L71`06QXJ01HF
5P0H61P05aLG01/K6`0L71`06ATI034a<@3Lg=`0_;bl04i>CP0T92@09bLW05aLG02YZJT0_[jn0<O7
a`2b/[80`<3009bLW01UIFD00P1iNGT01`1=CDd0;2`/03/k>`1WIfL0>c/k028R8P0H61P00P0C4a<0
3`0H61P0VYZJ0;Jf]P2SXj<0XZ:R0<c<c030`<00Vi^K07moO`2<S8`0V9RH09bLW02KVi/0YJFU06i^
KP02059BDP0S07MgM`2@T900Ti>C0:^[Z`1NGUh0Cdm?03Ti>@0Y:BT09BDU02h^;P22PX80^;Rh05MG
E`1<C4`0MWIf0:ZZZP1OGel0RXZ:0;6a/@3Ph>00]KFe05YJFP10@400@D5106ATI02a/K40Ph>304U9
B@0c<c<05aLG01DE5@0D51@05aLG02l_;`0^;Rh00P0H61P0DP0I6AT08B4Q04a<C01ADE40Hf=S08>3
P`2ZZZX0][Jf07=cL`0e=CD0;2`/03`l?02=SHd0FEUI03/k>`1UIFD0clo?0>7Qh@3?cll0R8R808:2
PP2RXZ80YjNW09ZJVP1@D500>c/k03`l?00];Bd061PH01LG5`0i>CT0[Zj^0<C4a026QXH0IfMW05eM
G@1CDe<0EEEE07inOP2JVYX0VIVI09bLW02OWil0WIfM08:2PP2?Shl0YJFU0<S8b02XZ:P0_[jn09BD
U01EEED0=3@d06a/K00d=3@0O7al05iNGP0N7Qh06ATI01/K6`0/;2`0DE5A06ATI00O7al08b<S08Z:
RP2OWil0YjNW06i^KP0/;2`0:BTY05=CD`2OWil0fMWI0::RXP1MGEd0ADE503De=@0M7Ad07QhN01`L
700K6a/201dM7@0?03dm?@2g]kL0_;bl0:VYZ@2_[jl0bLW90<;2`P2o_kl0`l?30<W9b@2?Shl0GEeM
04=3@`0n?Sh0?3`l0080?clo01h0ADE504];B`1ZJVX0KFe]04Q8B00X:2P0>SXj03Ph>01YJFT0<c<c
0410@02;Rh/0Z:RX07UiN@2CTi<0Jf][0:b/[03Fe]H0b/[:0<k>cP2WYjL0c<c<07IfMP1FEUH0Jf][
08f=S@2ZZZX0N7Qh07inOP0h>3P2ooooo`0002@0CDe=059BDP0n?Sh0NGUi0492@P1/K6`0CDe=02DU
9@0e=CD0BTY:03Ph>00`<300?clo02HV9P0S8b<0F5QH02l_;`1@D500:RXZ00h>3P0h>3P0?Cdm04=3
@`1GEeL02`/;03@d=01>CTh09BDU0451@@18B4P0=CDe02XZ:P18B4P0ATI603`l?01;Bd/201DE5@0>
05aLG00g=cL0>3Ph04Y:BP0o?cl06a/K03@d=00P8200@41003De=@13@d<0EEEE02HV9P0];Bd2051@
D03o07IfMP17AdL0BTY:04e=C@1aLG40FUYJ03De=@12@T80E5AD03Ti>@0Q8B40?Cdm05mOG`0l?3`0
J6QX07UiN@17AdL0;2`/0;2`/01OGel0<C4a04I6AP1PH600CTi>02PX:01ZJVX0GUiN03dm?@1NGUh0
<c<c05mOG`1LG5`0;Rh^05eMG@1/K6`0IVIV055AD@27QhL0V9RH04M7A`2i^KT0Y:BT061PH02NWYh0
ADE503Lg=`0O7al0<30`05MGE`2ZZZX0RHV903Hf=P19BDT0Jf][05eMG@2=SHd0^k^k09RHV00d=3@0
Ph>3075aL@27QhL0ADE504];B`24Q8@0BTY:05IFEP1LG5`0:BTY03hn?P1ZJVX0Hf=S05UIF@1<C4`0
<c<c04I6AP1/K6`0?3`l07UiN@1XJ6P0>SXj04U9B@1YJFT0DE5A05YJFP1aLG40ATI60:6QX@27QhL0
R8R809>CT`16ATH0Rh^;05iNGP1lO7`0M7Ad08f=S@11@D40];Bd07=cL`0b<S80Fe]K0:>SX`1nOWh0
EeMG07QhN00m?Cd0Xj>S07alO01ADE40NGUi08V9R@1DE5@0LG5a0:b/[02TY:@0>CTi09nOW`1_Kfl0
KVi^0820P01QHF40AdM707]kN`0l?3`0:2PX05UIF@1kNg/0MGEe09BDU03AdM40OWin065QH@2<S8`0
f=SH0820P01ZJVX0GemO0::RXP2`/;00Q8B407MgM`2^[Zh0KVi^079bLP2DU9@0NWYj04Q8B00g=cL0
CTi>030`<01KFe/0=CDe059BDP2FUYH0T92@05eMG@1^KVh0BTY:03Hf=P24Q8@0HF5Q051@D01XJ6P0
IfMW0410@02RXZ80P82004U9B@2j^[X0BTY:02l_;`27QhL0C4a<07emO@0i>CT0B4Q809>CT`2<S8`0
Fe]K03hn?P18B4P0N7Qh04i>CP0`<300Rh^;075aL@1SHf<0LG5a04E5A@0f=SH0P8200;Zj^P13@d<0
De=C09bLW01SHf<0@d=303hn?P1/K6`0OGem08:2PP1;Bd/0BTY:07MgM`0I6AT0AdM70:RXZ02PX:00
EeMG06=SH`1aLG40>3Ph05eMG@1]KFd0JVYZ04];B`1<C4`0MWIf03<c<`0];Bd0CDe=05aLG00l?3`0
:b/[071`L01_Kfl0FUYJ08n?S`1gMgL0TY:B07YjNP2NWYh0PH6107=cL`0o?cl0YjNW08b<S01XJ6P0
XZ:R03Lg=`1HF5P0<C4a0820P02;Rh/0E5AD04Q8B027QhL0K6a/08^;R`2MWId0TY:B055AD@26QXH0
OGem000A08J6QP0X:2P09BDU02LW9`1iNGT0GUiN02d];@1gMgL0Xj>S08R8R01FEUH0A4A4059BDP1W
IfL092@T02h^;P0f=SH00P0G5aL01`0E5AD071`L01hN7P1<C4`0FEUI038b<P0I6AT0100E5AD0<@0U
9BD0IVIV09nOW`36a/H0c<c<0<O7a`3>c/h0a<C408^;R`17AdL0@d=306YZJP0/;2`06QXJ01DE5@0M
7Ad0@d=307QhN01?Cdl0CDe=03Ti>@1CDe<0^KVi0=7Ad@2l_;`0S8b<07EeM@24Q8@0I6AT05ADE00e
=CD09BDU028R8P0W9bL0N7Qh07alO029RHT0XJ6Q09^KV`1PH60092@T01`L700J6QX071`L01HF5P0C
4a<04A4A03De=@0N7Qh00P0E5AD04@0N7Qh0:b/[034a<@1DE5@0QHF50:FUY@2ATI40:BTY01PH600Z
:RX0ADE502PX:00H61P05ADE01@D500H61P05aLG00805ADE05<06ATI01`L701gMgL0MWIf07AdM01_
Kfl0IVIV01`L700U9BD0TY:B09NGU`1?Cdl0:RXZ01dM7@0G5aL061PH01XJ6P0K6a/0>3Ph075aL@3M
gMd0eMGE0:j^[P2OWil0WIfM0;Jf]P2NWYh0a/K60=KFeP3;bl/0XJ6Q08b<S01cLg<0>CTi01TI6@0H
61P06a/K01XJ6P0O7al0ADE5069RHP24Q8@0MgMg02h^;P1EEED0TY:B0;^k^`22PX80C4a<0:f][@2P
X:00QhN706IVIP1=CDd0@41003hn?P1XJ6P0Rh^;06i^KP1GEeL0D51@05eMG@2ATI40QXJ607=cL`2l
_;`0/K6a0410@00j>SX0BTY:09NGU`38b<P0KFe]05QHF01cLg<0GemO0861P@1EEED0;Bd]04A4A02e
]KD0LG5a02<S8`0202@T900703Hf=P1UIFD0Shn?059BDP0b<S805ADE01HF5P0201DE5@1B028R8P0/
;2`05aLG01TI6@0H61P06ATI02LW9`2RXZ80`<300<G5a@37alL0VYZJ0:>SX`39bLT0clo?0=3@d02L
W9`0=SHf038b<P1VIVH0/K6a0:NWY`2=SHd0ZZZZ08:2PP1ZJVX0Y:BT08V9R@1gMgL0G5aL04M7A`0m
?Cd0>c/k03Ti>@1<C4`0S8b<0<;2`P2/[:`0E5AD06QXJ01nOWh0Vi^K0861P@1?Cdl0=CDe02HV9P0X
:2P0G5aL03@d=01[Jf/0/;2`0<71`@2VYZH0VYZJ05aLG023Ph<0H61P08>3P`27QhL0JVYZ03De=@0K
6a/061PH01`L700U9BD0@d=306YZJP0k>c/0EEEE07emO@13@d<0>3Ph09BDU021PH40Rh^;0<;2`P3R
h^80hN7Q0=cLg02j^[X0UIFE02d];@806a/K0P0L71`201dM7@0E02d];@1:BTX0@D51055AD@2:RXX0
^;Rh09BDU02][Jd0Y:BT0:j^[P2>SXh0<S8b02`/;00_;bl0>3Ph04Q8B01QHF40F5QH04m?C`0_;bl0
7alO008071`L00<08R8R02l_;`1NGUh00P0m?Cd04`1ZJVX0Ti>C061PH01]KFd0?3`l0861P@32`/80
WYjN0<W9b@3Fe]H0X:2P03@d=00];Bd0=CDe04Y:BP1fMWH0T92@075aL@10@4000_ooool0001m059B
DP1/K6`0A4A408N7Q`16ATH0QXJ608F5Q@18B4P0ADE506=SH`1IFET0;bl_05]KF`1SHf<0?clo075a
L@0d=3@0Jf][05eMG@0J6QX0?Shn04I6AP11@D40Kfm_02DU9@18B4P0EUIF02XZ:P14A4@0D51@05=C
D`0i>CT0FEUI04U9B@0d=3@0E5AD03Hf=P0O7al0PH6103De=@0];Bd0Cdm?05EEE@0k>c/0?Shn028R
8P1NGUh0G5aL06MWI`1HF5P0:2PX03Ph>01TI6@0EEEE06m_K`12@T80DU9B07emO@1nOWh0IfMW03hn
?P0m?Cd0J6QX02XZ:P0k>c/0EeMG05aLG00k>c/0GUiN05EEE@0Z:RX0ATI609^KV`1^KVh0>c/k04i>
CP1WIfL0C4a<03<c<`2<S8`0M7Ad03dm?@1IFET0>SXj07QhN013@d<0>SXj05YJFP1HF5P0:b/[02`/
;01;Bd/0Lg=c04M7A`2n_[h0YjNW04Q8B01dM7@0Ng]k0820P01WIfL09bLW065QH@2ATI40K6a/038b
<P1<C4`0I6AT05mOG`1jNWX0b/[:0:BTY00g=cL0LW9b05eMG@2JVYX0H61P0410@020P800CDe=05mO
G`1mOGd0EeMG03hn?P1aLG400P1TI6@0F01IFET0DE5A05MGE`1TI6@0=SHf08^;R`21PH40ATI604E5
A@1BDU80;Bd]059BDP1TI6@0?Shn0:2PX019BDT0LW9b09^KV`0l?3`0T92@04I6AP1RHV80WIfM08^;
R`13@d<0YZJV06][J`0e=CD0S8b<0;Zj^P23Ph<0FUYJ08J6QP0^;Rh0MgMg05iNGP1BDU80WinO0;Zj
^P1eMGD0E5AD08:2PP2>SXh0A4A40:b/[011@D40D51@06i^KP1`L700AdM70:JVYP1hN7P0B4Q8065Q
H@2NWYh0>c/k03lo?`31`L40WYjN05ADE029RHT0gmoO079bLP1ADE409BDU04M7A`2=SHd0Kfm_06e]
K@2OWil0G5aL03lo?`1<C4`0GEeM04U9B@0d=3@0<c<c059BDP1oOgl0Cdm?03hn?P2HV9P0ATI606i^
KP2>SXh0HF5Q03<c<`2FUYH202<S8`1h061PH01ZJVX0=3@d07moO`1DE5@09RHV07UiN@1CDe<08b<S
0:FUY@1<C4`0Kfm_051@D011@D40KFe]04Q8B01OGel0?clo05=CD`1oOgl0IVIV02`/;01?Cdl0LW9b
07AdM01eMGD0EUIF020P800l?3`0JVYZ061PH00m?Cd0VYZJ06YZJP0j>SX07QhN03Ph>00n?Sh0JFUY
04];B`1:BTX0Lg=c03Lg=`0b<S80ZJVY08N7Q`1FEUH0FEUI04M7A`0h>3P0RXZ:07QhN01iNGT0CTi>
04Q8B01ZJVX0ADE503hn?P1IFET0KVi^04Q8B00U9BD0Jf][07EeM@1bLW80^KVi07QhN02ATI40MgMg
0;>c/`2TY:@0N7Qh03`l?02/[:`0RHV904i>CP1eMGD0>c/k06=SH`0m?Cd0OGem08V9R@1>CTh0C4a<
096AT@1cLg<0QhN708^;R`1hN7P0@D510:b/[02RXZ80SHf=02TY:@0T92@0:RXZ06ATI00S8b<0@410
09ZJVP2MWId0RXZ:07alO01MGEd0BDU905MGE`1iNGT0QHF508^;R`0e=CD0=cLg02TY:@0K6a/061PH
04Q8B00T92@07AdM01LG5`0E5AD051@D0`0E5AD03`0K6a/0TY:B0<K6aP2o_kl0_Kfm0:b/[032`/80
@D5101/K6`0L71`0GEeM09JFUP1MGEd0Bd];04U9B@0203Ph>00N06YZJP1BDU80HV9R05IFEP1RHV80
`<3007AdM00e=CD0:RXZ034a<@0d=3@0@D51061PH01_Kfl0P82007]kN`2j^[X0[Zj^0:>SX`1fMWH0
FEUI05QHF00b<S807AdM01`L700M7Ad06ATI01PH600N7Qh07alO0`0E5AD03@0[:b/0820P01lO7`0R
8R80EUIF0:JVYP2=SHd0>CTi01/K6`0E5AD06ATI03Lg=`0i>CT00`0G5aL201HF5P<05aLG0100:2PX
0:RXZ02:RXX0O7al08:2PP1XJ6P0E5AD05eMG@12@T80CTi>04e=C@1;Bd/0ATI604Q8B01GEeL0Ng]k
0P1iNGT08`2FUYH0]KFe0=3@d03Ogml0i>CT0=KFeP3:b/X0e]KF0<[:bP3<c<`0WYjN04Y:BP0^;Rh0
6ATI01@D500K6a/08R8R01TI6@0E5AD06a/K028R8P1JFUX0U9BD0<C4a02j^[X0WIfM08R8R037alL0
dM7A0<[:bP1_Kfl0<C4a02XZ:P0Q8B4092@T00809RHV024061PH05=CD`1^KVh0EEEE051@D01FEUH0
K6a/03/k>`1/K6`0cLg=0=7Ad@2n_[h0YJFU0=kNgP3De=@0UYJF07emO@14A4@0@d=3079bLP0];Bd0
9BDU02PX:02@T900IVIV03`l?00U9BD0820P02/[:`11@D40V9RH07EeM@0f=SH00P0G5aL301DE5@0l
01lO7`0E5AD05QHF01HF5P0I6AT0D51@08Z:RP30`<00X:2P092@T02VYZH0T92@09^KV`2m_Kd0fm_K
0;Rh^01?Cdl0EeMG08F5Q@2HV9P0EEEE04];B`1VIVH0UiNG09ZJVP2=SHd0GUiN05ADE01GEeL0H61P
02LW9`0Z:RX0?Shn06=SH`1fMWH0MgMg0=SHf02EUID0S8b<06ATI00_;bl071`L01dM7@0I6AT06QXJ
01dM7@18B4P0HV9R05iNGP1^KVh0/;2`09JFUP1@D500GEeM0:6QX@1eMGD0L71`0:ZZZP1WIfL092@T
0`0J6QX0500G5aL09bLW05IFEP2YZJT0OGem03Ti>@0a<C40:BTY0;2`/02h^;P0SHf=08n?S`2^[Zh0
UYJF08R8R01`L700U9BD03Hf=P0K6a/05aLG0P0I6AT03`0K6a/0820P02/[:`15ADD0C4a<04e=C@11
@D40NGUi07alO02IVIT0HV9R04M7A`2UYJD0EUIF04=3@`0205QHF00304];B`0_;bl0820P008071`L
00l07AdM01`L700K6a/07AdM01hN7P10@400<c<c03Ph>00l?3`0Rh^;06m_K`1bLW80EeMG0;Rh^03;
bl/00P2WYjL02P3AdM40TY:B03De=@0f=SH0=cLg04Q8B01RHV80]KFe07inOP1>CTh2ooooo`0002/0
Bd];05]KF`13@d<0MWIf03Hf=P1=CDd0H61P04E5A@17AdL0C4a<024Q8@0/;2`0JFUY055AD@15ADD0
D51@01lO7`1LG5`0@D5101TI6@0R8R80410@03De=@1DE5@07alO03lo?`0a<C407AdM04a<C01MGEd0
C4a<02l_;`0n?Sh051@D02`/;01QHF40=SHf01hN7P2KVi/0>SXj01XJ6P0o?cl0EUIF0080>SXj02X0
;bl_05YJFP1CDe<0IFEU05=CD`0M7Ad0<30`05YJFP1;Bd/0IFEU034a<@0f=SH0F5QH05eMG@19BDT0
@41004a<C01dM7@0ATI601`L700];Bd0DU9B03Ph>01^KVh0GemO03Hf=P0O7al0E5AD06IVIP0h>3P0
<S8b05UIF@0g=cL06a/K04a<C01ZJVX0=3@d05UIF@0b<S80Cdm?03`l?00O7al206MWI`0j06IVIP0i
>CT0D51@05IFEP0Z:RX0S8b<0::RXP1HF5P0J6QX04];B`1]KFd0FUYJ0492@P2>SXh0UIFE06][J`0b
<S80@D5105MGE`0k>c/0BDU90:n_[`2SXj<0@T9206QXJ014A4@0IfMW07AdM012@T80Cdm?038b<P1Z
JVX0P82005QHF010@400Lg=c03dm?@1:BTX0J6QX04m?C`1DE5@0Jf][03@d=01aLG40Kfm_04=3@`1I
FET0N7Qh05eMG@1QHF40DE5A03Ti>@2VYZH0Shn?079bLP2?Shl0C4a<09NGU`80CTi>0;P0NGUi07Ad
M01JFUX0`<3009jNWP0j>SX0C4a<09nOW`0o?cl0DE5A08b<S00a<C40MWIf05iNGP0d=3@0DU9B061P
H01CDe<0DE5A07EeM@1LG5`0@D510:VYZ@1lO7`0GEeM07AdM00_;bl08b<S07IfMP27QhL0?Cdm069R
HP1^KVh0Kfm_08n?S`3Cdm<0QHF505EEE@26QXH0eMGE08n?S`28R8P0=CDe04m?C`2@T900KVi^061P
H02VYZH0RXZ:05aLG01CDe<0IVIV055AD@0/;2`0E5AD02HV9P1oOgl0F5QH0451@@2FUYH0RHV906UY
J@1FEUH0EEEE038b<P1fMWH0<S8b03lo?`1BDU80EEEE03Hf=P1fMWH0HV9R03hn?P29RHT0ADE502<S
8`2UYJD0C4a<06MWI`1<C4`0@41008B4Q017AdL0DU9B03<c<`1DE5@0Ng]k05eMG@0^;Rh0AdM705UI
F@1UIFD0JVYZ05QHF00_;bl0D51@07UiN@1PH600=3@d09>CT`1bLW80CTi>02LW9`1?Cdl0AdM707Ee
M@1;Bd/0ADE506UYJ@1WIfL0?3`l0;Zj^P25QHD0IVIV05IFEP1;Bd/0B4Q80:RXZ01cLg<0KVi^03lo
?`1;Bd/0HV9R04m?C`0g=cL0FEUI04M7A`0c<c<08R8R06EUI@1`L700KFe]0:FUY@1dM7@0Fe]K02LW
9`1YJFT0Xj>S07AdM00_;bl0]kNg06ATI00X:2P0IVIV0::RXP28R8P0?Cdm071`L01kNg/0CTi>05]K
F`2MWId0LW9b0861P@23Ph<0CDe=01LG5`2=SHd0Shn?07emO@0T92@09bLW02l_;`1NGUh0?Shn01hN
7P1HF5P0MWIf06m_K`20P800JVYZ059BDP1SHf<0S8b<07emO@1UIFD0Hf=S055AD@0e=CD08b<S01TI
6@0S8b<06ATI0`0E5AD401<C4`0J010@401LG5`0Vi^K07AdM026QXH0DU9B0:BTY00V9RH06ATI01/K
6`0P8200L71`08F5Q@1dM7@0RHV905UIF@1hN7P0FUYJ06EUI@0j>SX0@D5104M7A`21PH40[jn_04e=
C@0f=SH401DE5@0T01LG5`0[:b/0Ng]k07emO@2_[jl0[Zj^09NGU`13@d<0H61P04Q8B00N7Qh071`L
01/K6`0H61P07AdM02PX:00I6AT05aLG01TI6@0c<c<0PX:203De=@0a<C40=3@d04U9B@2c/k<0WinO
06EUI@0`<3006QXJ01LG5`0H61P09RHV03Lg=`0S8b<05aLG1@0E5AD0800G5aL0B4Q80:f][@2RXZ80
Y:BT08N7Q`0X:2P05QHF01LG5`0M7Ad0;Rh^04I6AP1_Kfl0QhN708Z:RP22PX80K6a/0492@P0K6a/0
:2PX08R8R03MgMd0fm_K0=WIf@3Ph>00clo?0;Jf]P2:RXX0PX:205EEE@0[:b/0820P0P0E5AD00`0J
6QX06ATI01LG5`0201TI6@0b01hN7P0Y:BT0Lg=c0=OGe`3EeMD0KFe]07YjNP2HV9P0emOG08>3P`0M
7Ad0:BTY03`l?00_;bl05ADE01@D500E5AD071`L055AD@1mOGd0Fe]K069RHP2;Rh/0Shn?07QhN03I
fMT0d];B0=KFeP1aLG40`/;20;Fe]@3?cll0EEEE02`/;01dM7@0Hf=S02<S8`0V9RH0:BTY06MWI`1T
I6@0LW9b03Hf=P0_;bl0=CDe03dm?@2=SHd0KFe]05EEE@0Y:BT301DE5@0/01HF5P0G5aL05ADE01LG
5`0K6a/0CTi>08V9R@1SHf<0?Shn075aL@2QXJ40^KVi0=;BdP3IfMT0_;bl0:^[Z`3<c<`0]kNg07em
O@27QhL0Hf=S04];B`0m?Cd0;Rh^03Xj>P1eMGD0KVi^0410@00W9bL0:b/[04E5A@1?Cdl0=cLg03@d
=01IFET0K6a/06ATI03;bl/0c/k>06IVIP17AdL08b<S01`L700M7Ad201/K6`0A01`L700j>SX0XZ:R
069RHP19BDT0CDe=06a/K01iNGT0C4a<061PH02DU9@0[Zj^0<71`@1iNGT06ATI01PH600J6QX00P0G
5aL0AP0M7Ad0;Rh^06QXJ00];Bd07AdM01lO7`1VIVH0VYZJ04m?C`1<C4`0Fe]K07inOP14A4@0;Bd]
04i>CP17AdL0?3`l024Q8@0H61P06ATI01PH600Q8B40@T9205MGE`1RHV80BTY:04E5A@1SHf<0Cdm?
06e]K@2<S8`0Hf=S03/k>`1kNg/0O7al03Lg=`0R8R8071`L01PH600E5AD06QXJ01dM7@0L71`06ATI
01`L700G5aL06a/K01dM7@0c<c<0=3@d0451@@0j>SX0NWYj0<g=c@2ZZZX0QXJ608B4Q02NWYh0QhN7
0=7Ad@3Cdm<0a/K606i^KP0l?3`0?Shn04i>CP1kNg/0UIFE05aLG01?Cdl2ooooo`000?l0De=C06EU
I@14A4@0XZ:R04Y:BP1]KFd0Ogmo0492@P1RHV80MWIf05=CD`0V9RH0@D5104i>CP1<C4`0IVIV03Ti
>@1IFET0?Cdm01`L700`<300;Rh^038b<P1FEUH08B4Q0410@00_;bl07QhN03Lg=`1>CTh08b<S038b
<P1VIVH0@T9203@d=01GEeL08R8R02PX:02NWYh0KFe]02h^;P10@400HF5Q03Hf=P1NGUh0;Bd]05YJ
FP1<C4`0OWin0:>SX`0l?3`0=3@d069RHP16ATH0QhN706UYJ@11@D40L71`05EEE@0f=SH09RHV02DU
9@1RHV80D51@034a<@1PH600=CDe01hN7P1GEeL0L71`06EUI@0Y:BT0CTi>0861P@16ATH0:b/[07Ee
M@1bLW8092@T05MGE`1jNWX0<S8b07moO`1;Bd/0GemO04I6AP0R8R80HV9R07IfMP1[Jf/0?clo07Qh
N02KVi/0AdM709^KV`2VYZH0DU9B08J6QP2RXZ80SHf=04E5A@0[:b/0JVYZ09fMW@1]KFd0CTi>08b<
S02HV9P0I6AT07UiN@35aLD0WYjN03<c<`1]KFd0O7al069RHP1SHf<0AdM708>3P`1=CDd0EeMG07Yj
NP0l?3`0GEeM08j>SP1aLG40ATI604Y:BP0T92@0EEEE08F5Q@19BDT0Jf][03Ti>@0X:2P0?Cdm06e]
K@1LG5`0De=C04e=C@0R8R80Ph>308n?S`1KFe/0L71`03De=@1cLg<0I6AT055AD@1fMWH0=CDe030`
<01hN7P0Ogmo03Ph>01?Cdl0Vi^K06][J`17AdL0Ph>303De=@1iNGT0IVIV069RHP1[Jf/0S8b<07Ee
M@14A4@0Hf=S08^;R`1SHf<0YjNW065QH@1TI6@0EUIF05]KF`0k>c/0UIFE06UYJ@0m?Cd0FEUI06a/
K01HF5P0ZZZZ0=CDe01eMGD0EUIF09ZJVP3Ng]h0JFUY07]kN`0g=cL0CDe=09>CT`1fMWH0KVi^0;Rh
^02BTY80HF5Q05EEE@1WIfL0De=C02/[:`1KFe/0<C4a08N7Q`1XJ6P0BDU90::RXP2MWId0L71`0861
P@1cLg<0<c<c07alO01ADE40FEUI04i>CP1cLg<0?3`l07moO`1jNWX0A4A408N7Q`1LG5`0<c<c0:VY
Z@2CTi<0YZJV07MgM`1>CTh0QXJ604U9B@1CDe<0<c<c065QH@23Ph<0EEEE02d];@0l?3`0CDe=059B
DP1bLW80B4Q803<c<`1KFe/0LG5a05=CD`0T92@0NGUi069RHP0[:b/0:RXZ04m?C`18B4P001l0HF5Q
02LW9`0f=SH0HV9R05iNGP15ADD0/[:b07]kN`1BDU80E5AD06UYJ@1;Bd/0[:b/06a/K01NGUh0=CDe
07AdM027QhL0Hf=S03Lg=`1<C4`0BTY:02`/;011@D40W9bL0:2PX01bLW80WYjN07QhN01bLW80EeMG
0080Ogmo0380@D5102/[:`2WYjL0HF5Q01LG5`0g=cL0JVYZ06i^KP0f=SH0MGEe07IfMP0N7Qh0;bl_
07emO@1WIfL0Ogmo0:JVYP1kNg/0Bd];09bLW02RXZ80J6QX038b<P15ADD0CTi>06i^KP1DE5@07AdM
05]KF`2VYZH0>CTi055AD@1MGEd0D51@05UIF@1fMWH0Shn?07EeM@1VIVH0FUYJ04];B`17AdL07AdM
01<C4`0M7Ad05aLG01@D500@41004A4A01@D50804a<C01d05ADE04];B`25QHD0JFUY06e]K@18B4P0
UYJF03De=@0K6a/051@D010@400C4a<06a/K02d];@0c<c<07QhN02<S8`0E5AD05aLG05YJFP0j>SX0
:BTY034a<@1mOGd0YZJV05ADE00P820061PH01@D500201DE5@0V01@D500i>CT0Fe]K05mOG`2a/K40
a/K607IfMP1BDU80C4a<04I6AP0Q8B4071`L028R8P0/;2`0>CTi02`/;00W9bL08B4Q02DU9@29RHT0
clo?0:JVYP2TY:@0];Bd0<K6aP31`L40M7Ad03Hf=P0K6a/071`L01PH600G5aL06ATI03De=@0[:b/0
5aLG01DE5@0D51@301DE5@0A024Q8@2WYjL0];Bd0;^k^`2[Zj/0Shn?06EUI@24Q8@0PH6107UiN@1K
Fe/0K6a/06MWI`1LG5`0=SHf01dM7@0L71`00P0E5AD08@0O7al0[:b/0<g=c@2[Zj/0d=3@0=;BdP2P
X:00EeMG0820P01/K6`0>CTi03`l?00h>3P0;Rh^02PX:00[:b/0;Bd]02HV9P0S8b<07alO02<S8`1U
IFD0YJFU0;Jf]P1>CTh0ATI60451@@2YZJT0O7al02TY:@0/;2`05QHF010@400201DE5@0S01@D500B
4Q807AdM069RHP2JVYX0]KFe096AT@2n_[h0alO70<K6aP2LW9`0/k>c07EeM@1dM7@0HV9R07inOP28
R8P0PH6104e=C@0V9RH0820P028R8P0U9BD0>c/k07]kN`1aLG40AdM7034a<@18B4P0BTY:05]KF`1d
M7@0Bd];05ADE00W9bL0100E5AD0:@0J6QX0<S8b05mOG`1hN7P0B4Q802PX:00U9BD0?Cdm0:f][@34
a<@0dM7A0=KFeP2g]kL0Zj^[0<W9b@3>c/h0c<c<07AdM00k>c/092@T020P800N7Qh08b<S03lo?`1<
C4`0<c<c01XJ6P0G5aL08R8R03/k>`1QHF40K6a/05iNGP2:RXX0I6AT0:ZZZP1_Kfl0GUiN03@d=00]
;Bd071`L00<07AdM01l0;bl_07IfMP2g]kL0TI6A05]KF`0n?Sh0;Rh^05mOG`1aLG40@d=306][J`2f
][H0_Kfm08j>SP0H61P05aLG01XJ6P0L71`06QXJ01TI6@0P8200?clo01`L700P8200IVIV0<30`01A
DE40Cdm?05UIF@11@D40820P0080@T9201L0;Rh^03Hf=P0n?Sh0=cLg03lo?`0_;bl0>3Ph04i>CP1W
IfL0RHV9061PH013@d<0=cLg06IVIP1MGEd0KFe]06YZJP1^KVh0KFe]0:f][@1HF5P05QHF01LG5`03
01PH600501TI6@0H61P06ATI01/K6`0H61P00P0I6AT05`0N7Qh0;Bd]038b<P0^;Rh0=CDe08N7Q`2f
][H0Z:RX0:2PX01KFe/0O7al0:JVYP3AdM40clo?06][J`2DU9@0UYJF08>3P`1`L700N7Qh02TY:@0R
8R80>SXj00;ooooo0000C01CDe<0CTi>0451@@1]KFd0@41007IfMP1jNWX09bLW03De=@18B4P0BTY:
02l_;`1;Bd/0:2PX02/[:`1DE5@0<S8b06IVIP0M7Ad02`/;02h^;P0m?Cd0=CDe07YjNP0D51@0>c/k
0492@P0b<S80C4a<07moO`0m?Cd07QhN04U9B@0f=SH0@d=3071`L00f=SH05ADE06a/K01XJ6P0:BTY
05QHF01FEUH08R8R05MGE`0b<S80DE5A02LW9`0n?Sh0GEeM02d];@0g=cL0OGem03/k>`1WIfL0ATI6
04i>CP2<S8`0MGEe06IVIP19BDT0<c<c05ADE00U9BD061PH02h^;P1<C4`0=CDe04e=C@1EEED0=CDe
038b<P1WIfL0SHf=034a<@0R8R8204M7A`1k02TY:@1`L700OGem03@d=01OGel0=CDe069RHP1MGEd0
:BTY05EEE@1_Kfl0?Cdm02<S8`10@400JFUY0451@@25QHD0UIFE03Xj>P1;Bd/0@T9206UYJ@1ZJVX0
<c<c05=CD`2LW9`0Bd];02`/;013@d<0Cdm?05eMG@1oOgl0alO70:^[Z`1?Cdl0Hf=S065QH@1<C4`0
LG5a04E5A@22PX80BTY:051@D01eMGD0FUYJ0451@@1/K6`0LW9b03lo?`19BDT0ADE504Q8B01ZJVX0
BTY:05EEE@1^KVh0?3`l03dm?@1NGUh0F5QH04M7A`1ADE40BDU90:6QX@2FUYH0E5AD0861P@1IFET0
Ti>C05]KF`1<C4`0Q8B407=cL`12@T80WinO092@T00d=3@0BDU909NGU`1oOgl0De=C07EeM@1?Cdl0
YjNW0:BTY01ZJVX0HV9R08:2PP1ZJVX0>c/k06UYJ@2?Shl0MGEe09^KV`1BDU80FEUI05aLG01WIfL0
@d=308f=S@1GEeL0@41006EUI@2VYZH0PX:20::RXP3Cdm<0QhN701TI6@1`L700/;2`0;6a/@2OWil0
>SXj04e=C@1YJFT0;Rh^07YjNP31`L40XZ:R069RHP1BDU80J6QX0080DU9B00`0FEUI02l_;`1oOgl0
Kfm_06QXJ02d];@0X:2P06e]K@2DU9@0O7al03Xj>P2=SHd205aLG00R05EEE@1hN7P0<C4a09JFUP2M
WId0@T92079bLP1OGel0>CTi07emO@22PX80[:b/08Z:RP1CDe<0TI6A04];B`1=CDd051@D01/K6`1A
DE40Ti>C03dm?@0d=3@0HF5Q04M7A`2`/;00MGEe03Lg=`1YJFT0OWin05ADE00U9BD0Fe]K05mOG`80
:BTY0600Cdm?0492@P1FEUH09RHV0451@@1nOWh0GEeM0492@P2[Zj/0Fe]K03dm?@2ATI40/k>c04i>
CP2NWYh0OGem03<c<`0H61P0B4Q807IfMP1JFUX0?Cdm069RHP1TI6@08B4Q02DU9@1QHF40I6AT04Q8
B026QXH0WYjN09^KV`1lO7`0QHF508V9R@0c<c<0=SHf09NGU`1hN7P0BDU903De=@1@D500Cdm?02@T
9022PX80U9BD051@D01:BTX0L71`01TI6@18B4P0Kfm_08n?S`1@D500X:2P0<c<c02<S8`0820P01dM
7@0T92@0H61P03Xj>P0/;2`0Ti>C0;Vi^@1HF5P0BDU903Xj>P1<C4`0EEEE06=SH`27QhL0OWin05AD
E01BDU80EeMG02l_;`0R8R80ATI6020P800C4a<05QHF01DE5@0C4a<04Q8B00h>3P0B4Q805ADE051@
D01aLG40LW9b06i^KP17AdL0Ogmo04I6AP0F5QH3010@400N00d=3@0?3`l04Q8B010@400E5AD051@D
01<C4`0I6AT0Fe]K03`l?00T92@0?3`l079bLP2VYZH0CTi>024Q8@0I6AT05aLG01DE5@0C4a<0;bl_
0:FUY@1nOWh0]kNg08f=S@1SHf<0RXZ:08n?S`1KFe/0BTY:0P11@D404@0R8R80:BTY02h^;P0V9RH0
820P04e=C@27QhL0YJFU06EUI@1EEED0IfMW0::RXP2IVIT0ZZZZ06QXJ00e=CD06ATI00807AdM01T0
6QXJ01TI6@0a<C40?Shn02XZ:P0R8R807AdM01`L700_;bl0J6QX06a/K03:b/X0dm?C0<c<c02XZ:P0
H61P07IfMP23Ph<0M7Ad06ATI01EEED0A4A403hn?P0/;2`08B4Q0080820P02006QXJ03Hf=P2ZZZX0
d=3@08R8R02d];@0YjNW05EEE@0S8b<0>3Ph05QHF01nOWh0VYZJ07UiN@1CDe<0DU9B055AD@1CDe<0
E5AD06EUI@1KFe/0PH6108j>SP1IFET0PX:20451@@0Y:BT0>c/k09fMW@1>CTh0=CDe01HF5P80410@
01D05ADE01@D500F5QH04a<C01DE5@0_;bl0P8200<O7a`2BTY80a/K60<c<c02BTY80IVIV06i^KP2I
VIT0EEEE04m?C`1lO7`0`L7108B4Q00O7al00`0M7Ad05P0K6a/08b<S07=cL`1=CDd0EeMG02`/;00i
>CT0D51@04U9B@1bLW80GUiN05=CD`1PH600;bl_01DE5@0M7Ad0;bl_04i>CP1OGel0B4Q803@d=00V
9RH202<S8`0E03hn?P2UYJD0X:2P0:^[Z`2KVi/0[jn_0;Vi^@2_[jl0S8b<0<71`@12@T808B4Q01lO
7`0Q8B407AdM02DU9@0_;bl0ADE503@d=00I6AT06a/K00806ATI00X09bLW05mOG`2/[:`0U9BD05EE
E@1hN7P0@T9206a/K00`<300<c<c0P0K6a/0F`0M7Ad0=3@d05EEE@1]KFd0>SXj03Ti>@1kNg/0J6QX
04];B`18B4P0LG5a096AT@2YZJT0b<S809fMW@2QXJ40@D5101LG5`0H61P07AdM01LG5`0I6AT07AdM
038b<P0S8b<0HF5Q0;^k^`1SHf<0EEEE051@D00[:b/06QXJ01`L700M7Ad0>CTi04M7A`1FEUH0=CDe
0410@01bLW80`<300;Fe]@34a<@0e]KF0=CDe027QhL0AdM703dm?@2PX:00RXZ:0::RXP2h^;P0_[jn
0861P@1=CDd0KFe]01dM7@0E5AD05QHF01TI6@0G5aL06ATI01PH600G5aL06QXJ01hN7P0P820071`L
01dM7@10@400>SXj03@d=01MGEd0YJFU09nOW`31`L40a<C409BDU02LW9`0^KVi0=_Kf`38b<P0L71`
051@D01WIfL0VYZJ08j>SP1PH6007QhN024Q8@11@D400_ooool0003o04];B`1IFET0@d=307MgM`0c
<c<0ATI606IVIP0k>c/0@d=303Hf=P0K6a/071`L03<c<`1=CDd0=CDe03Ti>@0K6a/0BTY:04];B`0I
6AT07QhN01PH600J6QX0G5aL02LW9`0i>CT0<S8b00l?3`0f=SH0EEEE04i>CP0K6a/0@410020P800S
8b<0GUiN04];B`0G5aL0L71`05ADE00D51@0;Bd]059BDP0`<300>c/k02<S8`1JFUX0Bd];055AD@1`
L700;Bd]028R8P1CDe<0?Shn05mOG`16ATH0=SHf065QH@1[Jf/0I6AT04Y:BP0d=3@0?Shn03Xj>P0O
7al0;2`/034a<@0d=3@0?3`l04a<C016ATH0820P02`/;01YJFT0>3Ph01`L700f=SH0D51@01`L7018
B4P0O7al03dm?@1EEED0?clo04Q8B01[Jf/0;bl_04Y:BP1GEeL0K6a/03`l?018B4P0Ng]k04=3@`1a
LG40TY:B055AD@1dM7@0De=C07=cL`1kNg/0A4A407QhN02KVi/0R8R8051@D01EEED0I6AT06YZJP1c
Lg<0alO70:6QX@1FEUH0JFUY07MgM`13@d<0K6a/04Y:BP2QXJ40Fe]K055AD@1dM7@0KFe]065QH@1g
MgL0Kfm_04A4A019BDT0@T92051@D01bLW80AdM705MGE`1/K6`0@T9203`l?01ADE40DU9B05=CD`1L
G5`0@D5108Z:RP2<S8`0C4a<08^;R`1MGEd0SHf=06m_K`1BDU80PH6107moO`19BDT0TY:B09JFUP0j
>SX0Fe]K0;>c/`2TY:@0CTi>071`L00c<c<0LG5a096AT@1?Cdl0GemO08F5Q@16ATH0Fe]K0;:b/P2X
Z:P0I6AT096AT@1TI6@0Lg=c08f=S@27QhL0C4a<08J6QP1GEeL0:BTY05=CD`2[Zj/0TI6A08:2PP3D
e=@0[Jf]05IFEP1lO7`0d=3@06EUI@23Ph<0A4A405IFEP21PH40EEEE05=CD`2CTi<0WYjN065QH@1B
DU80FUYJ01LG5`0U9BD0?Shn01`L701]KFd0ADE506ATI02[Zj/0/;2`05ADE02RXZ80?Shn03`l?02I
VIT0K6a/05YJFP1DE5@0LG5a020P802:RXX0U9BD0410@01]KFd0K6a/02`/;01nOWh0?3`l07YjNP1O
Gel0DU9B0;fm_@28R8P0MWIf03Xj>P16ATH0HV9R08>3P`0o?cl0=CDe05aLG00e=CD0L71`07YjNP0c
<c<0JVYZ07emO@0^;Rh0:BTY08j>SP23Ph<0IVIV03lo?`1ADE40@d=3001@05=CD`0B4Q80;Rh^059B
DP27QhL0?Shn0;>c/`1nOWh0:BTY06IVIP2<S8`0Bd];08F5Q@2MWId0KFe]02l_;`17AdL0HF5Q01TI
6@0L71`0>c/k05UIF@1ADE407alO05IFEP1?Cdl0=CDe05=CD`1?Cdl0MgMg04M7A`1kNg/0];Bd06m_
K`0K6a/0LG5a06YZJP10@400ATI609bLW01aLG40<c<c05]KF`1VIVH0>3Ph05eMG@2TY:@0JFUY04U9
B@1`L700IVIV01LG5`1dM7@0/[:b08:2PP0W9bL0;2`/02DU9@1FEUH09bLW01DE5@1EEED0W9bL06][
J`1_Kfl0G5aL059BDP24Q8@0Jf][08F5Q@1hN7P0?Cdm02d];@19BDT0G5aL030`<00N7Qh06ATI00h>
3P0E5AD2018B4P1o010@400>3Ph03Ph>02TY:@1WIfL0Hf=S09>CT`1gMgL0EeMG06=SH`1fMWH07AdM
018B4P0?3`l03Ph>010@400=3@d03Ph>00d=3@0A4A405ADE018B4P0D51@0=CDe0<?3``2HV9P0Lg=c
08B4Q02@T900ZZZZ071`L00Y:BT07AdM018B4P0G5aL0GUiN0=WIf@3EeMD0cLg=0<?3``2JVYX0WIfM
0;6a/@2YZJT0P82006UYJ@1`L700GUiN04a<C00j>SX0?Cdm075aL@1_Kfl0?Cdm059BDP16ATH0JVYZ
09ZJVP2KVi/0K6a/08J6QP2BTY80Q8B402XZ:P0E5AD05aLG01TI6@0L71`0=cLg09nOW`2JVYX0KFe]
075aL@2EUID0UiNG04=3@`0a<C40/;2`0:VYZ@2`/;00d=3@075aL@0o?cl0=3@d03Hf=P0/;2`0=SHf
0492@P1EEED0H61P06YZJP1gMgL0<C4a05]KF`2:RXX0WYjN0<G5a@2e]KD0_;bl07AdM00d=3@06ATI
024Q8@0V9RH0;2`/03lo?`1iNGT0^k^k08b<S017AdL0<S8b02h^;P0_;bl0Bd];0;2`/02ATI40@D51
055AD@1;Bd/071`L034a<@2@T900>c/k03Hf=P0U9BD051@D01<C4`0201DE5@0Z014A4@0D51@04a<C
01LG5`17AdL0MgMg06i^KP31`L40KFe]03Lg=`0Z:RX08b<S06i^KP1`L700IVIV0492@P1ADE40XJ6Q
0451@@0N7Qh05ADE024Q8@0P82007AdM04I6AP1<C4`0D51@030`<00J6QX0820P028R8P1HF5P0P820
04];B`14A4@0GemO05iNGP1OGel0D51@055AD@1FEUH0;Bd]0P0N7Qh0H00R8R80:b/[06e]K@1XJ6P0
LW9b05iNGP2:RXX0Xj>S0:FUY@25QHD0@d=308b<S01BDU807AdM020P800R8R807AdM02@T900/;2`0
BDU903@d=00K6a/071`L01DE5@0G5aL071`L03lo?`1`L700GUiN05YJFP1WIfL0=3@d05YJFP0k>c/0
92@T02HV9P0M7Ad0<c<c051@D01GEeL0<C4a02@T900S8b<0A4A403lo?`13@d<0Fe]K05iNGP1WIfL0
fMWI0:VYZ@1cLg<0HV9R07UiN@0U9BD05aLG01`L700I6AT071`L02TY:@0/;2`0K6a/0;>c/`1`L700
DE5A0410@00S8b<071`L01TI6@0F5QH071`L01lO7`18B4P0Fe]K08j>SP1MGEd0EeMG0;Ng]`3;bl/0
^k^k0:NWY`2VYZH0]KFe0;Vi^@3:b/X0emOG0<_;b`2ZZZX0/K6a0:b/[019BDT0=CDe03dm?@17AdL0
6QXJ01PH60<05ADE01d061PH01HF5P0P820092@T024Q8@0M7Ad08b<S0492@P15ADD0De=C096AT@29
RHT0EEEE0:j^[P1=CDd0820P03Xj>P2ZZZX0_[jn06][J`2WYjL0P82006m_K`25QHD0OGem02l_;`0M
7Ad07alO04A4A002ooooo`0007`0EeMG06MWI`12@T80Zj^[055AD@1GEeL0TY:B0492@P13@d<0B4Q8
075aL@0_;bl0Cdm?06EUI@0`<300?Cdm0492@P1NGUh0CTi>01lO7`0P82008B4Q02TY:@1FEUH07QhN
03De=@0M7Ad05aLG038b<P1;Bd/0ATI601dM7@0k>c/0;bl_03De=@1NGUh0BTY:01PH601QHF40GEeM
02<S8`0h>3P0C4a<02XZ:P0o?cl0:2PX06MWI`1<C4`0A4A407MgM`11@D40>CTi05MGE`0b<S80K6a/
05iNGP1BDU80MgMg06e]K@1[Jf/0D51@03@d=00m?Cd0@T9202<S8`0`<300;bl_03/k>`0b<S80E5AD
04e=C@0Z:RX0;Bd]06i^KP0];Bd0:BTY05IFEP1RHV808B4Q0492@P1dM7@0<C4a05ADE015ADD0ATI6
05IFEP0_;bl0>c/k05=CD`1TI6@0?3`l04M7A`1`L700@T920820P02ZZZX0L71`08Z:RP1HF5P0KVi^
034a<@0Z:RX0D51@09BDU01gMgL0@D5105]KF`1LG5`0E5AD05UIF@2_[jl0^[Zj06][J`1HF5P0R8R8
059BDP1iNGT0ATI608N7Q`1NGUh0FEUI06MWI`1UIFD0FEUI0P1UIFD0H@1BDU80K6a/04m?C`1@D500
IVIV03De=@1fMWH0UYJF0492@P1:BTX0Cdm?04M7A`14A4@0JFUY055AD@1YJFT0NWYj03Ti>@2HV9P0
GUiN06a/K01cLg<0<c<c09:BTP2UYJD0D51@08Z:RP2;Rh/06a/K03Lg=`2@T900R8R8051@D02<S8`0
DU9B07QhN029RHT0>SXj0820P02VYZH0K6a/02HV9P1DE5@0OGem04Q8B023Ph<0ADE505IFEP2GUiL0
SXj>04];B`2>SXh0O7al04i>CP17AdL0]KFe04=3@`0n?Sh0alO70:^[Z`1GEeL0PX:20=7Ad@1FEUH0
7QhN034a<@1dM7@0WinO079bLP1RHV80Xj>S08>3P`1RHV80V9RH0820P01<C4`0;Rh^05iNGP0L71`0
=3@d05]KF`0k>c/0Q8B409NGU`1FEUH0_[jn05=CD`0a<C40W9bL07AdM01HF5P0M7Ad08^;R`13@d<0
Lg=c08b<S00h>3P00P2CTi<0OP0j>SX0U9BD051@D029RHT0De=C02TY:@1HF5P0GemO06MWI`0n?Sh0
Fe]K08B4Q027QhL08B4Q04e=C@22PX80EUIF096AT@1EEED08b<S06=SH`1eMGD0EEEE034a<@1@D500
QhN704I6AP0/;2`0FEUI06ATI01_Kfl0EEEE0410@01:BTX0<c<c02LW9`1^KVh0Ng]k05eMG@1VIVH0
N7Qh02PX:01IFET0JFUY065QH@0W9bL0IFEU07alO01RHV80:b/[04];B`1ADE40=cLg034a<@27QhL0
[Zj^079bLP1iNGT0BTY:06=SH`18B4P0ADE508B4Q01^KVh0820P07=cL`2IVIT07alO02l_;`2QXJ40
Ti>C04E5A@1RHV80L71`01PH600b<S80MgMg06UYJ@1>CTh0N7Qh05IFEP13@d<0=cLg0;Bd]01RHV80
7alO03@d=00];Bd0EeMG07YjNP0I6AT0@T920:n_[`1kNg/0?clo04A4A01KFe/0D51@09ZJVP2ATI40
I6AT05]KF`0X:2P07AdM03<c<`1DE5@0>c/k01HF5P0A4A405aLG010@400U9BD08R8R01TI6@0e=CD0
V9RH0:>SX`1eMGD0^k^k0820P01ZJVX0L71`0::RXP1_Kfl09bLW01DE5@<03Ph>04@03@d=00h>3P0@
41003`l?018B4P0K6a/0JFUY08Z:RP22PX80UYJF0;Ng]`36a/H0S8b<09BDU02NWYh0Cdm?030`<023
Ph<0a<C40=cLg02o_kl0NWYj04m?C`15ADD0D51@05EEE@1?Cdl0IFEU0861P@1dM7@0GemO071`L01a
LG40Zj^[0;^k^`1eMGD0G5aL065QH@1^KVh0CTi>04M7A`1]KFd0UYJF0;2`/01iNGT0Lg=c09nOW`1;
Bd/0A4A405MGE`1IFET0De=C0410@00c<c<09bLW030`<00m?Cd0C4a<05ADE01oOgl0UIFE092@T02D
U9@0_[jn051@D00L71`0:2PX03/k>`805aLG02P07AdM02PX:00d=3@0=cLg05IFEP2^[Zh0Vi^K04a<
C02QXJ40emOG0=3@d035aLD0DU9B01lO7`0G5aL06ATI01lO7`0K6a/07AdM02HV9P1FEUH0LW9b01/K
6`0E5AD05QHF01DE5@0H61P0Jf][05aLG00U9BD09bLW06ATI00J6QX0;2`/08f=S@0b<S809bLW03`l
?00E5AD04a<C0`0A4A40E00C4a<051@D018B4P0m?Cd0Cdm?075aL@2VYZH0IfMW0820P024Q8@0NWYj
0861P@0d=3@092@T024Q8@0S8b<0>c/k06][J`0j>SX05aLG01/K6`0k>c/09RHV02LW9`1[Jf/0ADE5
05EEE@0M7Ad06ATI02/[:`1IFET0DU9B07UiN@0o?cl0MgMg0;>c/`15ADD0DE5A07EeM@1LG5`07alO
01/K6`0L71`06QXJ03Ph>01eMGD0Lg=c08J6QP1MGEd0A4A403Ph>01KFe/0NWYj055AD@1fMWH0PH61
028R8P0J6QX07alO02DU9@0e=CD0FEUI06EUI@1CDe<0>SXj02DU9@0G5aL06QXJ02h^;P1DE5@0IFEU
06=SH`1DE5@0Hf=S02`/;00n?Sh0EUIF01dM7@11@D40>SXj0492@P1<C4`0;Bd]020P80808B4Q01H0
;Bd]03De=@0X:2P0;2`/03<c<`1FEUH0]KFe05aLG01?Cdl0AdM705IFEP1DE5@06ATI01LG5`0K6a/0
71`L03Hf=P21PH40Xj>S075aL@1DE5@0=SHf0`0L71`201XJ6P0901dM7@0N7Qh0;Bd]07IfMP2LW9`0
GEeM0410@01PH600_Kfm0080Xj>S00h0]kNg0<71`@2`/;00XJ6Q0<G5a@2b/[80ZZZZ08B4Q01ZJVX0
EeMG03hn?P0^;Rh0@d=3038b<P805ADE01l06a/K01DE5@0H61P06QXJ01hN7P0S8b<07AdM020P800T
92@0DU9B04Q8B01oOgl0L71`04I6AP1PH600KFe]01`L700R8R80CDe=0<[:bP1jNWX0E5AD07UiN@2h
^;P0PX:2061PH00g=cL09RHV02<S8`0_;bl0>3Ph00;ooooo0000BP1MGEd0H61P04=3@`2_[jl0FUYJ
04i>CP22PX80@d=308j>SP2PX:00Ogmo03Ph>01=CDd0Fe]K03Ti>@1DE5@0ATI605YJFP1<C4`07alO
038b<P0[:b/0<S8b05]KF`0N7Qh0?Cdm034a<@0S8b<0@D51059BDP18B4P0:RXZ06=SH`0l?3`0=3@d
0451@@0m?Cd08B4Q06=SH`1eMGD0<S8b03Hf=P1CDe<0;Bd]03`l?00c<c<0IFEU04a<C01=CDd0Y:BT
069RHP0o?cl0FEUI03Ph>027QhL0MWIf05MGE`20P800OWin06ATI01HF5P0De=C069RHP1ZJVX0:2PX
02l_;`1<C4`0ADE503/k>`2>SXh0Kfm_03Hf=P0V9RH0OGem0P0P8200G`11@D40LG5a02HV9P0i>CT0
K6a/02l_;`1hN7P0H61P03hn?P1/K6`0:BTY051@D029RHT0Ph>30492@P16ATH0GUiN01`L701IFET0
SXj>05iNGP1mOGd0S8b<08F5Q@1gMgL0C4a<05QHF02UYJD0K6a/04e=C@2=SHd0QhN706e]K@1@D500
MWIf09>CT`1NGUh0BTY:07IfMP11@D40QHF504E5A@1cLg<0<C4a07emO@2<S8`0Kfm_04];B`1GEeL0
EUIF0451@@1gMgL0EEEE04Y:BP1/K6`0C4a<061PH01OGel0ADE505MGE`1[Jf/0Hf=S05ADE017AdL0
8B4Q061PH02;Rh/0BTY:06EUI@0Y:BT0IVIV07]kN`0j>SX0IFEU03lo?`0^;Rh0M7Ad09JFUP1CDe<0
>SXj09:BTP0g=cL0:RXZ06IVIP1`L700WIfM0:6QX@0];Bd0C4a<05=CD`1SHf<0;2`/065QH@1WIfL0
@T920080TY:B03/0H61P07QhN00b<S807QhN04I6AP1oOgl0H61P04Y:BP2`/;00>SXj06EUI@3?cll0
WinO04I6AP27QhL0c/k>07AdM01eMGD0:b/[03lo?`1eMGD0I6AT06i^KP2`/;00RXZ:05IFEP19BDT0
Bd];03lo?`13@d<0ADE502LW9`1GEeL0Kfm_0451@@2WYjL0AdM703hn?P2`/;00O7al03/k>`2TY:@0
<C4a01@D500k>c/0Kfm_0410@01fMWH0QHF502LW9`1BDU80IfMW03<c<`2EUID0XJ6Q0:NWY`24Q8@0
G5aL08Z:RP0204e=C@1g02<S8`1:BTX0JFUY09:BTP11@D40:b/[07UiN@0d=3@0T92@07]kN`0d=3@0
ATI606e]K@0S8b<05aLG04A4A01kNg/0FUYJ02`/;00`<300;2`/04a<C00f=SH0HF5Q08V9R@1`L700
@41008R8R01[Jf/0>3Ph0820P02c/k<0HV9R06i^KP1dM7@0EeMG018B4P0d=3@0IVIV06QXJ00];Bd0
BDU904i>CP0Z:RX061PH04=3@`1YJFT0Jf][08R8R01>CTh0Ph>308F5Q@1>CTh0[:b/06=SH`0d=3@0
QHF509:BTP0k>c/07AdM06IVIP1SHf<0?Shn07]kN`1PH600=SHf04M7A`1aLG40K6a/05aLG02UYJD0
JVYZ05=CD`0a<C40VYZJ07emO@0Q8B40Cdm?05aLG01iNGT0LW9b01`L700m?Cd0_kno065QH@0d=3@0
:BTY02h^;P2<S8`0GEeM08B4Q01MGEd0SXj>03Hf=P0M7Ad071`L02LW9`1NGUh0F5QH02`/;00o?cl0
DU9B05aLG01XJ6P0LW9b071`L02:RXX0dm?C0;Rh^03=cLd0/;2`0:>SX`1JFUX0UIFE0410@00G5aL0
:b/[010@400>3Ph00P0=3@d01`0>3Ph03@d=00l?3`0^;Rh0H61P05ADE00b<S800P0V9RH0?@14A4@0
PH610;6a/@2EUID0VYZJ0<g=c@3Bd]80[Jf]0<71`@3Cdm<0_;bl05mOG`0b<S80;bl_03@d=01KFe/0
?Shn04e=C@1QHF40BTY:02<S8`0T92@0<S8b09nOW`23Ph<0EUIF04A4A012@T80CTi>02PX:00l?3`0
Jf][075aL@2CTi<0T92@08^;R`1aLG40YJFU08n?S`1VIVH0D51@0410@00`<300<S8b03lo?`1@D500
HV9R07EeM@1^KVh0Ti>C08J6QP2m_Kd0X:2P0<c<c02EUID0;2`/02TY:@0G5aL05ADE01<C4`0F5QH0
0P0Q8B403`0b<S809RHV096AT@1bLW80UYJF0:^[Z`2NWYh0b/[:0;^k^`2GUiL07QhN00h>3P0C4a<0
6a/K01lO7`0202LW9`0C02XZ:P1<C4`0BDU901XJ6P0I6AT05ADE01LG5`1JFUX0CTi>024Q8@0K6a/0
Kfm_02TY:@0a<C40[jn_0492@P0N7Qh0=cLg01TI6@0301<C4`0E00h>3P0@41005ADE01@D5014A4@0
>CTi08Z:RP1nOWh0CTi>065QH@0d=3@09RHV02d];@0G5aL07QhN020P800U9BD0;Bd]02/[:`1@D500
BTY:00805aLG01<0>c/k03`l?01ZJVX0B4Q8069RHP1@D50071`L02d];@1TI6@0AdM704Y:BP1jNWX0
WYjN0:j^[P1WIfL0CTi>02d];@0Q8B406a/K00808b<S02/0;2`/07AdM022PX80H61P05mOG`0/;2`0
=CDe02`/;00d=3@0G5aL07=cL`2:RXX0]kNg06ATI00b<S80<30`0451@@1@D500FUYJ06e]K@1GEeL0
D51@0451@@18B4P0DU9B05mOG`1fMWH0G5aL08F5Q@1=CDd0Kfm_02h^;P0`<300HV9R038b<P17AdL0
A4A40451@@0n?Sh08R8R024Q8@0_;bl07AdM00809bLW01L07alO028R8P0V9RH0:b/[0:f][@1GEeL0
>SXj05aLG00U9BD0F5QH06m_K`0J6QX06ATI03<c<`2OWil0T92@06i^KP1]KFd09RHV01LG5`0H61P0
5aLG01PH600201LG5`0J01/K6`0L71`07alO07]kN`2o_kl0E5AD04I6AP1>CTh0YJFU0;Bd]02g]kL0
^KVi0<?3``31`L40^[Zj0:>SX`2KVi/0QhN70;>c/`2MWId0PX:2061PH00l?3`0<C4a04M7A`0Q8B42
01LG5`0N01DE5@0J6QX05aLG020P800N7Qh07AdM02<S8`0[:b/0I6AT07alO01/K6`0>3Ph04];B`2:
RXX09BDU01`L700];Bd0PH6109jNWP1CDe<0BDU9071`L02UYJD0]KFe06a/K00[:b/0=SHf030`<00^
;Rh0=cLg0_ooool0000K05QHF01CDe<0>3Ph07YjNP1@D500BTY:07AdM00b<S80;Rh^05MGE`1]KFd0
:RXZ04Q8B00b<S806QXJ05MGE`11@D40Cdm?01<C4`092@T0>c/k04A4A00];Bd0OGem01@D500d=3@0
GUiN0080?3`l0>00GEeM03Xj>P0H61P0AdM705UIF@10@400>c/k02@T900V9RH0Lg=c092@T00n?Sh0
<C4a05QHF00P8200ATI603De=@14A4@07AdM02XZ:P1VIVH0EeMG034a<@1GEeL0;bl_06IVIP1TI6@0
Cdm?0820P01XJ6P06QXJ02h^;P19BDT0HV9R075aL@0X:2P0B4Q805MGE`0U9BD0820P04];B`1GEeL0
:BTY03Lg=`27QhL0BDU902@T900g=cL0CDe=02HV9P1:BTX0OWin02<S8`17AdL0De=C03/k>`1/K6`0
:RXZ03Hf=P1GEeL0GemO02l_;`1IFET0R8R805EEE@1IFET0[Zj^02@T900b<S80ADE506MWI`1`L700
?Cdm05UIF@2l_;`0EUIF02DU9@0b<S80?3`l05mOG`1lO7`0cLg=0<S8b00f=SH0>CTi07YjNP1ADE40
C4a<02HV9P1UIFD0C4a<04M7A`1LG5`0>CTi04A4A01]KFd0IfMW051@D01fMWH07AdM03@d=01XJ6P0
H61P06EUI@1KFe/07AdM02PX:010@400DU9B05=CD`1IFET0;Rh^0492@P1dM7@0=cLg0861P@0o?cl0
CTi>07MgM`0`<300MGEe05aLG00n?Sh0MgMg09ZJVP1@D500Cdm?09jNWP26QXH0ADE506ATI01HF5P0
IVIV08n?S`1UIFD0KFe]07=cL`1NGUh0=cLg08:2PP2HV9P0DU9B04i>CP1iNGT0MGEe09VIV@1]KFd0
C4a<04Q8B024Q8@0IFEU05iNGP2n_[h0MWIf09nOW`3Ng]h0U9BD02DU9@1`L700`<3008f=S@2@T900
>3Ph05EEE@2>SXh0;Rh^05aLG02UYJD0Xj>S08R8R023Ph<0KFe]03Ph>01DE5@0JVYZ01XJ6P0S8b<0
AdM706UYJ@2l_;`0NGUi04U9B@2GUiL0EeMG03/k>`2[Zj/0F5QH05MGE`1/K6`0O7al01lO7`1hN7P0
WIfM04e=C@1WIfL0H61P01dM7@1MGEd0Cdm?06MWI`1VIVH0De=C07IfMP1:BTX0GEeM02LW9`0k>c/0
BTY:06i^KP0];Bd0:BTY06ATI00T92@0EUIF05YJFP0l?3`0GEeM06i^KP16ATH09BDU02<S8`1PH600
EUIF03`l?080=3@d01/0CTi>00l?3`0V9RH0FUYJ07moO`1>CTh0T92@07inOP0T92@0DE5A07IfMP1T
I6@0HF5Q05aLG01cLg<0>SXj04m?C`1TI6@0IVIV038b<P1;Bd/0Fe]K06QXJ00U9BD0ATI605iNGP1]
KFd00P1jNWX0SP2JVYX0L71`0492@P2c/k<0B4Q801lO7`15ADD0MgMg04Y:BP0Y:BT0Ogmo05aLG00X
:2P0PX:2096AT@1IFET0BTY:06][J`0j>SX0A4A4079bLP1XJ6P0GEeM02h^;P2=SHd0LG5a01hN7P0P
82009BDU04m?C`1VIVH071`L03`l?02h^;P0IFEU03Lg=`0Z:RX09bLW05YJFP1gMgL0E5AD07EeM@2P
X:00TI6A05aLG01NGUh0LW9b08b<S02ATI40MGEe06ATI00o?cl0:RXZ02HV9P19BDT0KFe]08N7Q`2<
S8`0/[:b0=3@d03<c<`0HV9R02LW9`23Ph<0M7Ad01DE5@0B4Q80410@00h>3P0=3@d04Q8B02<S8`0k
>c/0BTY:03dm?@0X:2P0<30`024Q8@0N7Qh07alO02PX:00e=CD0RXZ:065QH@1/K6`0c/k>0=GEe@2Z
ZZX0a<C40=;BdP2>SXh0XZ:R06MWI`0f=SH0>c/k06QXJ01SHf<0H61P069RHP1/K6`0@d=302@T900N
7Qh0@410079bLP0i>CT0<c<c03Ti>@14A4@0EEEE02d];@0P82007AdM03<c<`2ATI40ZJVY0;Zj^P2M
WId0VIVI09^KV`1EEED0@D51059BDP1NGUh0EEEE055AD@1HF5P0JFUY09^KV`33`l<0YZJV08J6QP2d
];@0[Zj^06a/K01IFET0M7Ad05ADE00Y:BT05aLG01DE5@0J6QX201DE5@0?028R8P2TY:@0`l?30;Rh
^01OGel0Fe]K0::RXP2o_kl0Rh^;06YZJP0G5aL05ADE01LG5`0O7al08b<S00809RHV01@0:RXZ03/k
>`1:BTX0;Bd]01/K6`0];Bd0IFEU04Q8B00P82006ATI05mOG`2;Rh/0VIVI0=WIf@2XZ:P0<C4a02`/
;00];Bd051@D01<C4`805ADE02L0410@01DE5@0G5aL0KVi^04e=C@2NWYh0GUiN02DU9@0e=CD06ATI
01`L700c<c<0=CDe02@T900W9bL09RHV02/[:`0a<C40>3Ph065QH@1CDe<061PH01LG5`0f=SH0M7Ad
05QHF029RHT0bl_;09VIV@2DU9@0];Bd0:FUY@1DE5@0YjNW0;>c/`20P800<C4a020P800M7Ad00P0O
7al0A@0R8R80<30`08B4Q02=SHd0JFUY05=CD`1fMWH0:RXZ030`<00[:b/0:BTY03Lg=`1^KVh0_;bl
0<K6aP2XZ:P0UYJF08B4Q01aLG40EEEE04];B`1FEUH0?Shn0410@01LG5`0A4A404I6AP14A4@0HF5Q
0861P@2o_kl0IfMW0;^k^`2KVi/0QXJ609>CT`2h^;P0YJFU08F5Q@2DU9@08b<S01XJ6P0L71`07QhN
01LG5`0M7Ad08B4Q02XZ:P0e=CD0D51@09ZJVP3Ph>00];Bd02l_;`1MGEd0LG5a02<S8`1TI6@0Hf=S
06YZJP2n_[h0PX:207UiN@1TI6@092@T01XJ6P0E5AD06a/K01PH600201TI6@805aLG01`06a/K020P
801IFET0b<S80:FUY@2?Shl0TI6A0;>c/`3=cLd0`L710;Ng]`2/[:`0Vi^K06QXJ01WIfL0KVi^08N7
Q`1SHf<0MWIf08^;R`2ATI40IFEU03@d=00k>c/0ADE501LG5`0F5QH05aLG0P0I6AT06`0U9BD08R8R
020P800X:2P0J6QX0;Fe]@2FUYH0Hf=S04M7A`20P800De=C024Q8@0V9RH0<c<c08j>SP1LG5`0?clo
05ADE01FEUH0W9bL05YJFP2UYJD0RHV905]KF`1TI6@0DE5A05UIF@02ooooo`0002/0CDe=06][J`0m
?Cd0Rh^;0492@P1IFET0VIVI04E5A@1:BTX0@41007alO00`<300Bd];06i^KP0o?cl0C4a<03<c<`1;
Bd/0=CDe01TI6@0O7al07AdM01HF5P1KFe/0:RXZ02d];@10@4003@d=030`<01[Jf/0DE5A02XZ:P0i
>CT0:BTY02d];@1EEED0@T9201XJ6P0i>CT0GUiN020P8010@400Jf][0080=CDe09l0820P05]KF`10
@400<c<c07=cL`0U9BD07alO055AD@1:BTX0LG5a038b<P0/;2`0Lg=c075aL@1OGel0?clo03<c<`1:
BTX06QXJ01@D500d=3@0CDe=04a<C00W9bL0D51@0492@P0>3Ph07QhN04e=C@14A4@0:BTY04E5A@0Y
:BT0410@02HV9P1VIVH0?Shn04];B`0f=SH06QXJ059BDP12@T80<S8b04i>CP1?Cdl092@T02PX:01O
Gel0FUYJ05ADE02b/[80A4A405ADE01MGEd0GUiN04Q8B00b<S80KVi^0;Jf]P2<S8`0De=C051@D00o
?cl0E5AD07IfMP2l_;`0[jn_04Y:BP0f=SH0MgMg055AD@1WIfL0;2`/05IFEP15ADD0FUYJ06m_K`17
AdL0<30`0410@01BDU80ADE508N7Q`0m?Cd0?clo06m_K`15ADD0F5QH06i^KP19BDT0@T9204I6AP0g
=cL0@D5106ATI00k>c/0C4a<06UYJ@0g=cL0S8b<05YJFP1<C4`0Shn?03De=@1]KFd0Ph>3051@D024
Q8@0VYZJ024Q8@0k>c/0MgMg0:>SX`1:BTX0M7Ad04i>CP1FEUH0L71`04Q8B01nOWh0Ogmo05MGE`0M
7Ad0B4Q807EeM@1NGUh0T92@06QXJ01LG5`0WinO09bLW01HF5P0A4A407QhN00S8b<0AdM70:RXZ026
QXH0MgMg0>7Qh@2RXZ80;Bd]05iNGP2BTY80M7Ad0820P01OGel0RHV90;Vi^@1eMGD0Jf][08N7Q`2I
VIT0Ogmo0<30`023Ph<0;Bd]03Lg=`1_Kfl00P0U9BD0X`17AdL0Cdm?08>3P`2ATI40FEUI08R8R01P
H600<30`09jNWP1iNGT0IfMW08R8R02>SXh08B4Q05IFEP2>SXh0?3`l05eMG@1jNWX0=3@d07MgM`1J
FUX0KVi^04i>CP1=CDd0T92@06UYJ@1UIFD0=CDe05YJFP1KFe/0O7al02PX:00a<C40FUYJ03Ti>@1R
HV80>SXj03Lg=`1IFET0Lg=c06EUI@0e=CD09bLW06EUI@1RHV80B4Q803Ph>00d=3@0IFEU06e]K@1:
BTX0B4Q807QhN00n?Sh0UiNG07QhN01UIFD0I6AT079bLP1/K6`0EeMG07moO`2<S8`0GUiN05UIF@1L
G5`0DE5A02`/;01HF5P0O7al07YjNP0Q8B40?clo061PH00k>c/0Bd];04E5A@2>SXh0SHf=04M7A`2f
][H0M7Ad02/[:`19BDT0UiNG05EEE@0];Bd0O7al069RHP1:BTX0O7al07UiN@0o?cl0Bd];06UYJ@1j
NWX0ATI609NGU`1QHF40EEEE02XZ:P2GUiL0KFe]02LW9`0];Bd0;bl_069RHP23Ph<0:2PX03Ph>02`
/;00R8R803Lg=`0];Bd09RHV02PX:027QhL0BDU905mOG`2][Jd0Xj>S09jNWP1LG5`0Cdm?04a<C01e
MGD0QXJ607alO01nOWh0T92@09BDU01CDe<0;2`/02TY:@0a<C40RXZ:0=;BdP33`l<0UIFE07QhN02C
Ti<0[Jf]02TY:@0W9bL0=SHf059BDP1@D500C4a<03Xj>P0X:2P07QhN01lO7`0Q8B407alO01/K6`0N
7Qh07AdM01/K6`0L71`0De=C09>CT`2f][H00P3Ph>00603EeMD0Z:RX06i^KP2QXJ40[Jf]0<30`02J
VYX0Ph>30:BTY02g]kL0Shn?08f=S@13@d<0>c/k04=3@`0g=cL0@D5107AdM01FEUH0BTY:03hn?P0_
;bl0;Rh^01/K6`805ADE04@05aLG055AD@39bLT0_kno0:VYZ@1SHf<0VYZJ0<g=c@1VIVH0>3Ph02/[
:`0Q8B406a/K01TI6@0Y:BT0Kfm_069RHP1jNWX0VYZJ0;bl_02LW9`0D51@020P800V9RH0>c/k05iN
GP1TI6@0Cdm?03Ti>@0_;bl0BTY:09jNWP20P800UYJF0:>SX`1?Cdl0CDe=0;^k^`2YZJT0OWin06m_
K`1KFe/06ATI01/K6`0J6QX0820P02@T900P82009bLW02TY:@0Z:RX0@d=304];B`1hN7P0EEEE03De
=@0I6AT05aLG08>3P`2MWId0/[:b09^KV`33`l<0NWYj05]KF`0/;2`04a<C014A4@80410@0P0C4a<0
700m?Cd0/k>c09NGU`2a/K40Cdm?028R8P18B4P0?Cdm02/[:`0b<S807QhN02XZ:P0O7al0:2PX02DU
9@0V9RH0=SHf03`l?01RHV80Hf=S01HF5P0E5AD0=SHf07inOP2?Shl0b/[:0;^k^`1bLW8205ADE005
06UYJ@2LW9`0XZ:R06a/K01@D5000P1ADE405`1;Bd/0=SHf02h^;P1FEUH0KFe]07IfMP1PH600Y:BT
07alO01<C4`0>c/k03<c<`0b<S80=3@d08R8R03AdM40S8b<05=CD`1ADE40MWIf09fMW@2CTi<0Ng]k
0080BDU902X0?clo04M7A`0c<c<0=cLg03Ti>@1@D500]kNg09ZJVP1^KVh0YZJV08J6QP1cLg<0Shn?
0;Zj^P2GUiL0Ng]k08b<S025QHD0NGUi08:2PP2:RXX0SXj>096AT@2LW9`0^;Rh0=;BdP3Lg=`0iNGU
0=GEe@3:b/X0T92@0820P03De=@0UIFE05IFEP3:b/X0gmoO0;Fe]@2KVi/0JVYZ03De=@0L71`201LG
5`0B01TI6@0F5QH061PH01DE5@0I6AT05aLG01TI6@0b<S80N7Qh0::RXP32`/80eMGE0;Vi^@2OWil0
b/[:092@T01ZJVX0AdM70P0h>3P0:`0b<S80=cLg03hn?P1EEED0IFEU06MWI`1SHf<0JVYZ04=3@`0m
?Cd0ADE5038b<P0K6a/06QXJ01/K6`0P820071`L01dM7@0b<S80Jf][0:2PX02TY:@0]KFe06m_K`29
RHT0N7Qh020P800U9BD09bLW03Xj>P2ATI40AdM703Xj>P1IFET0E5AD05]KF`0h>3P0E5AD0;Fe]@1C
De<0?Shn03/k>`0n?Sh00_ooool0001i05aLG01/K6`0@41008B4Q017AdL0=CDe04i>CP0i>CT0E5AD
04M7A`0a<C407alO03Hf=P1HF5P0?clo03Ti>@0C4a<08R8R04=3@`0X:2P07alO01/K6`0?3`l0<S8b
0451@@0b<S80Bd];010@400I6AT0<C4a04Y:BP0V9RH0;bl_01hN7P0I6AT0<30`055AD@0Q8B40C4a<
07EeM@0>3Ph04Q8B03Ti>@0m?Cd0;Bd]018B4P0o?cl0De=C0410@020P800<30`01LG5`0e=CD0>SXj
061PH017AdL0:RXZ04i>CP1NGUh0Fe]K04M7A`1?Cdl0Fe]K04A4A00X:2P0;Bd]04e=C@1FEUH0<S8b
051@D00k>c/07QhN01XJ6P1MGEd0>3Ph02<S8`1EEED0GEeM02DU9@0/;2`0JFUY03@d=01BDU80EeMG
02PX:01VIVH0@41002`/;01CDe<0IVIV04M7A`0n?Sh0HV9R03/k>`15ADD0Zj^[07=cL`1EEED0Fe]K
06UYJ@0a<C406a/K04m?C`2KVi/0Ph>304i>CP1GEeL0@T9206UYJ@0n?Sh0SHf=0;6a/@1XJ6P0?clo
07emO@17AdL0Xj>S04m?C`23Ph<08R8R04Y:BP0207YjNP300410@01CDe<0CTi>01/K6`29RHT0MGEe
051@D01iNGT0<C4a0451@@24Q8@0EEEE04a<C019BDT0@d=303De=@1NGUh0EUIF04I6AP1lO7`0CTi>
08B4Q01`L700ATI609^KV`1@D500DE5A07=cL`15ADD0OWin09nOW`17AdL092@T05]KF`1^KVh0G5aL
09fMW@1UIFD0Jf][06m_K`15ADD0U9BD0;Ng]`1oOgl0=CDe061PH01aLG40L71`07inOP1iNGT0ADE5
05iNGP29RHT0De=C04m?C`2;Rh/0HF5Q03lo?`2FUYH0>c/k03De=@3?cll0Zj^[04a<C01kNg/0[:b/
05UIF@0f=SH0>SXj06UYJ@2GUiL0Kfm_06a/K02ATI40VYZJ03dm?@2a/K40NGUi03Xj>P12@T80IFEU
03De=@0h>3P0K6a/030`<021PH40Shn?06IVIP1ZJVX0KFe]02d];@2BTY80I6AT051@D02;Rh/0RXZ:
04M7A`1;Bd/0SXj>02h^;P1jNWX0Ogmo03hn?P1hN7P0HV9R06][J`1QHF40<S8b05YJFP1UIFD0L71`
04Q8B01UIFD0HF5Q09jNWP0O7al0BDU908>3P`1<C4`0Kfm_0451@@0Q8B40DU9B07alO01VIVH0?Cdm
02HV9P1`L700?Shn02DU9@0i>CT0FEUI079bLP1`L700DU9B04Y:BP1CDe<06QXJ09BDU02YZJT0IFEU
05UIF@1nOWh0>SXj05aLG02KVi/0Shn?05]KF`1@D500E5AD061PH00`<300B4Q806YZJP1iNGT0:2PX
03dm?@1gMgL0R8R806e]K@1:BTX0Ph>308^;R`1<C4`0`l?30820P00^;Rh0C4a<0:^[Z`1HF5P0:RXZ
09VIV@1bLW80EEEE07moO`20P800FEUI04];B`1iNGT0KVi^04e=C@2OWil0CDe=02l_;`10@400TI6A
07UiN@0f=SH0:b/[03De=@1TI6@0IfMW0P0e=CD00`2VYZH0TI6A03Ph>00202TY:@0R028R8P1DE5@0
VYZJ04e=C@2i^KT0R8R8096AT@2JVYX0Ph>307inOP29RHT0]KFe0<C4a02g]kL0[:b/09:BTP1SHf<0
JVYZ096AT@2HV9P0bLW90=oOg`2@T900JVYZ09JFUP3GemL0fm_K0<W9b@2:RXX0E5AD030`<00K6a/0
61PH01DE5@8061PH01T05QHF01XJ6P0I6AT05ADE01PH600I6AT06QXJ01dM7@1HF5P0`L7109ZJVP38
b<P0alO708F5Q@1;Bd/0@D5107moO`34a<@0dm?C0<;2`P1_Kfl0GEeM0::RXP2FUYH0Shn?0080Q8B4
02<0Kfm_05IFEP0X:2P0FUYJ03Ph>00R8R807AdM02<S8`0M7Ad071`L01DE5@0A4A405aLG05mOG`1]
KFd0VYZJ0<71`@1dM7@0Hf=S08V9R@2JVYX0=CDe01PH600K6a/05aLG01/K6`0o?cl0De=C07=cL`2G
UiL0fm_K0<W9b@15ADD0BTY:01LG5`0201DE5@0E01/K6`0/;2`0?clo05eMG@2TY:@0Zj^[05EEE@1>
CTh0Y:BT08V9R@1iNGT0QhN704Y:BP1UIFD0QXJ609bLW024Q8@0Fe]K020P800J6QX071`L00807AdM
03/08B4Q028R8P0R8R807alO02@T9016ATH0JVYZ03Lg=`0_;bl0HF5Q0;>c/`2^[Zh0@410028R8P1R
HV80RXZ:065QH@1ZJVX0De=C034a<@0K6a/04A4A01`L700o?cl0FEUI05iNGP32`/80a/K605iNGP0j
>SX0A4A407moO`1mOGd0>c/k01DE5@0B4Q808b<S028R8P0T92@09BDU02TY:@0_;bl0@T92069RHP1?
Cdl05aLG034a<@3Bd]80b/[:0;^k^`1iNGT0ATI603lo?`1:BTX0SXj>0:ZZZP2:RXX0DE5A04i>CP02
04];B`1405IFEP1kNg/0Z:RX08:2PP1fMWH0C4a<096AT@1:BTX0>CTi030`<013@d<0BDU904=3@`1W
IfL0ZJVY0::RXP2DU9@0L71`065QH@1=CDd0F5QH0861P@2OWil0SHf=09JFUP13@d<0:BTY02LW9`0/
;2`0>3Ph04U9B@33`l<0S8b<08j>SP2=SHd0RHV906][J`2YZJT0dm?C0<W9b@2UYJD0Vi^K0:FUY@2>
SXh0Lg=c06IVIP1mOGd0O7al07MgM`1bLW80O7al0:b/[03?cll0d=3@08:2PP2b/[80c<c<09nOW`1U
IFD0Ng]k0=_Kf`3Ti>@0cLg=09>CT`0a<C40@41001HF5P0H61P201LG5`<05ADE01T05aLG01HF5P0I
6AT0H61P09>CT`0f=SH0NWYj0<C4a01VIVH0Rh^;0<O7a`26QXH0De=C03De=@0Z:RX0:b/[02XZ:P0_
;bl0;Bd]03Hf=P1=CDd0F5QH069RHP1FEUH0Jf][0080Cdm?01h0N7Qh03lo?`0d=3@0=SHf03Ph>014
A4@0HV9R079bLP1eMGD0Z:RX0;fm_@2g]kL0Shn?0:n_[`1;Bd/0820P02LW9`0^;Rh0EEEE09VIV@19
BDT0B4Q8065QH@1LG5`0A4A403dm?@16ATH0PH6101lO7`0P820201lO7`;ooooo0000O01^KVh0RHV9
04E5A@2JVYX0Jf][0410@01aLG40>CTi05mOG`1kNg/0Fe]K02/[:`0];Bd0BTY:03@d=018B4P0EEEE
03hn?P1bLW80=3@d02DU9@19BDT0:BTY04Y:BP10@400<c<c05iNGP10@4009bLW04U9B@1NGUh0<C4a
03De=@1:BTX0D51@03Lg=`1;Bd/051@D04M7A`1^KVh0<C4a02HV9P18B4P0;Bd]03Lg=`0a<C40CTi>
03lo?`0n?Sh0T92@07=cL`0d=3@0>CTi03De=@1KFe/0MWIf04=3@`1[Jf/0NWYj020P800M7Ad0CDe=
07AdM01WIfL0=3@d038b<P1KFe/0ATI602h^;P1/K6`0LG5a03Xj>P0O7al0HF5Q03Xj>P0L71`0I6AT
08:2PP0d=3@0;Bd]065QH@0[:b/0Bd];06QXJ00M7Ad0KVi^02h^;P0[:b/0KFe]07]kN`16ATH0=CDe
05UIF@0Z:RX0:b/[08V9R@1OGel0E5AD06IVIP1oOgl0PH61061PH01EEED0YjNW07=cL`1BDU80Ng]k
06m_K`1VIVH0BDU905ADE026QXH0Jf][04E5A@22PX80>c/k07emO@18B4P0Ph>303dm?@0c<c<0EEEE
06][J`1:BTX207AdM00C04A4A01kNg/0JVYZ05EEE@29RHT0JVYZ0410@01oOgl0E5AD06i^KP24Q8@0
MGEe04i>CP1UIFD0A4A405MGE`2IVIT0H61P07YjNP0204e=C@3D09RHV01NGUh0HV9R05YJFP0h>3P0
OGem0:6QX@1bLW80:b/[05UIF@1=CDd0=CDe06MWI`1eMGD0IFEU06][J`19BDT0KFe]061PH01RHV80
<C4a04a<C01SHf<0BDU905mOG`2GUiL0GUiN079bLP1EEED0;bl_03Hf=P2:RXX0Ng]k04Y:BP2YZJT0
Ph>306QXJ03Bd]80][Jf05iNGP2ATI40Z:RX09NGU`2FUYH0>3Ph04m?C`2SXj<0QHF506=SH`24Q8@0
Shn?05EEE@2b/[80Ogmo0451@@19BDT0Cdm?02l_;`1FEUH0JVYZ030`<02?Shl0DU9B038b<P1UIFD0
OGem03/k>`2JVYX0H61P03`l?01VIVH0T92@061PH01=CDd0Y:BT04Q8B01UIFD0HF5Q03Lg=`1[Jf/0
L71`06QXJ01dM7@0FEUI05YJFP1HF5P0TY:B05]KF`1gMgL0IVIV0:BTY019BDT0;Bd]08:2PP1CDe<0
IfMW04E5A@0e=CD0Bd];07MgM`1YJFT0A4A402HV9P1RHV80DU9B04=3@`0U9BD0;2`/05aLG01aLG40
DE5A04Q8B01RHV809bLW05aLG022PX80G5aL05EEE@1gMgL0=cLg04=3@`1^KVh0NGUi05mOG`1LG5`0
E5AD08N7Q`17AdL0D51@05iNGP1VIVH0<C4a05YJFP28R8P0MgMg05]KF`1CDe<0Rh^;04I6AP0g=cL0
Shn?06i^KP0m?Cd0De=C0:^[Z`1IFET0;2`/0::RXP2BTY80D51@071`L023Ph<0CTi>0492@P29RHT0
Kfm_04A4A02VYZH0EUIF04A4A00X:2P0O7al07QhN00i>CT0FEUI06UYJ@1^KVh0>c/k024Q8@0_;bl0
Ti>C08:2PP0e=CD0:RXZ02TY:@0U9BD0F5QH0=;BdP3=cLd0`<30055AD@15ADD0JVYZ07YjNP27QhL0
d=3@0=CDe03=cLd0NWYj071`L025QHD0XJ6Q0<?3``2h^;P0`<300<71`@30`<00]KFe09^KV`2c/k<0
PX:206a/K02i^KT0KVi^03Xj>P0P820071`L01PH600I6AT05ADE01hN7P0M7Ad201`L700O01/K6`0I
6AT06ATI01TI6@0];Bd0LW9b07IfMP1;Bd/0a/K60;Rh^02:RXX0G5aL05]KF`1aLG40L71`0<;2`P3?
cll0VYZJ0820P02CTi<0Xj>S0;2`/03;bl/0T92@028R8P0S8b<09bLW03`l?012@T80;Rh^01dM7@02
01hN7P0J01/K6`0O7al08B4Q06EUI@3Cdm<0d];B0:FUY@3Bd]80^[Zj09nOW`2ATI40Xj>S0;:b/P2K
Vi/0Zj^[08b<S022PX80QHF507]kN`1ZJVX0MWIf09FEU@36a/H0K6a/03Xj>P0a<C4401DE5@0[01LG
5`0];Bd0[jn_07IfMP1aLG40XZ:R0<?3``2][Jd0`<3006m_K`0G5aL0:b/[06m_K`2b/[80XZ:R09FE
U@1[Jf/0820P01/K6`0L71`06ATI01LG5`0L71`0820P02d];@0j>SX0Ph>30:b/[01]KFd0NGUi0;>c
/`1/K6`0H61P03Hf=P0L71`08R8R05IFEP1`L700GUiN059BDP10@400CDe=04m?C`0206ATI00T04Q8
B01CDe<0Zj^[0;6a/@2QXJ40Jf][04a<C01bLW80Ph>306QXJ00I6AT05aLG01DE5@0L71`092@T01lO
7`0Y:BT0>CTi05EEE@1;Bd/0Xj>S08B4Q02MWId0Xj>S0861P@1oOgl0S8b<0:^[Z`26QXH0[jn_0<G5
a@3?cll0MWIf05eMG@1lO7`0Ogmo0P1cLg<0AP22PX80a/K60;fm_@11@D40GemO07IfMP0k>c/0FUYJ
02<S8`0Q8B40:b/[03Lg=`2?Shl0PX:203hn?P10@400Ng]k08>3P`1[Jf/0AdM7055AD@1OGel0R8R8
0=GEe@24Q8@0AdM702PX:00T92@0;2`/05EEE@2^[Zh0PX:20:b/[037alL0emOG0<k>cP2n_[h0]kNg
08F5Q@19BDT0ADE505mOG`1ZJVX0D51@02`/;00n?Sh0Bd];055AD@1jNWX0Y:BT0:>SX`1bLW80Hf=S
0:FUY@2TY:@0b<S80:b/[01JFUX0/k>c0>;RhP3@d=00eMGE0<K6aP1YJFT0B4Q801HF5P0E5AD05aLG
01DE5@0G5aL201DE5@0801TI6@0N7Qh0=SHf0:n_[`1RHV80820P05UIF@2YZJT204i>CP0706e]K@0j
>SX0>SXj0451@@1;Bd/0ATI603`l?00202`/;00T030`<00m?Cd0A4A4059BDP1]KFd0H61P071`L02M
WId0a/K60<71`@2KVi/0OWin07IfMP1UIFD0IVIV07inOP2ZZZX0YJFU09nOW`2BTY80/;2`08V9R@0k
>c/0A4A403<c<`0j>SX0M7Ad09FEU@1<C4`0D51@09JFUP1cLg<0Cdm?038b<P16ATH0KVi^100L71`2
ooooo`0000`0H61P06ATI00g=cL0HF5Q05mOG`0i>CT0FUYJ024Q8@0O7al0@d=305mOG`0a<C4203<c
<`0[00d=3@0m?Cd0GUiN03Ph>01;Bd/07alO03Lg=`1KFe/0<c<c04E5A@0];Bd0=3@d08N7Q`1[Jf/0
:2PX04U9B@1NGUh030`<03Hf=P1iNGT0DE5A03/k>`1?Cdl061PH05aLG02GUiL0B4Q802d];@15ADD0
5ADE02XZ:P12@T80@d=3018B4P0M7Ad0FEUI06YZJP0f=SH0>CTi03Lg=`16ATH0LG5a03Xj>P0207Ee
M@1b02d];@0M7Ad0:RXZ03lo?`1=CDd0;2`/03lo?`1mOGd0;Rh^01LG5`16ATH0IfMW04Q8B00U9BD0
O7al04m?C`0E5AD0=SHf05]KF`0g=cL0?clo08^;R`0n?Sh0?Cdm069RHP0W9bL0IfMW03hn?P0G5aL0
>CTi06][J`11@D40ADE507inOP1dM7@0>SXj09fMW@19BDT0>3Ph04a<C01MGEd0Ng]k05]KF`1VIVH0
^KVi05]KF`0f=SH0>c/k03lo?`1[Jf/0PX:20:>SX`34a<@0JVYZ03Xj>P28R8P0De=C06MWI`0`<300
HV9R05aLG01:BTX0J6QX0410@00`<300BDU905mOG`1@D500S8b<04Q8B00a<C40LG5a06UYJ@15ADD0
IfMW03Hf=P0n?Sh0A4A4055AD@17AdL0F5QH0492@P17AdL0OWin05]KF`1^KVh0EUIF03hn?P1nOWh0
EUIF06=SH`1QHF40AdM705aLG02OWil0MGEe02LW9`17AdL0NWYj04U9B@1jNWX0KVi^06EUI@1cLg<0
LG5a09BDU02=SHd0TI6A03Xj>P1?Cdl0G5aL079bLP11@D40Y:BT0P1MGEd0Y@2NWYh0KFe]05UIF@2E
UID0Rh^;04m?C`2OWil0V9RH07MgM`2][Jd0ZZZZ06EUI@2DU9@0/K6a0::RXP2QXJ40@D5105eMG@2O
Wil0P82005]KF`24Q8@0WinO05MGE`2ATI40DE5A03Lg=`14A4@0L71`03De=@0a<C40IFEU02/[:`1b
LW80>c/k04e=C@12@T80Ogmo03Xj>P2>SXh0T92@071`L02WYjL0/K6a06a/K01CDe<0^;Rh05]KF`1d
M7@0Ng]k0410@01TI6@0QHF507=cL`21PH40Hf=S06a/K01EEED0X:2P06ATI01cLg<0Fe]K0:6QX@1<
C4`0:RXZ07]kN`1TI6@0HV9R04M7A`0m?Cd0DU9B07emO@1VIVH0>3Ph01lO7`1YJFT0HF5Q04Y:BP0[
:b/0=CDe06IVIP26QXH0EeMG04M7A`1YJFT0<30`065QH@2f][H0R8R8051@D01nOWh0I6AT051@D01k
Ng/0OWin05EEE@1[Jf/0MGEe08>3P`15ADD0EEEE06EUI@0i>CT092@T03Ph>01ZJVX0H61P04Y:BP1_
Kfl0V9RH07IfMP0l?3`0Y:BT05MGE`0b<S80F5QH092@T01BDU8071`L075aL@1FEUH0?Shn08>3P`2>
SXh0FUYJ03Xj>P28R8P0De=C04=3@`2e]KD0Shn?06=SH`0/;2`0PH6107UiN@0c<c<07AdM02/[:`1D
E5@0IfMW02l_;`0F5QH0Ng]k05iNGP11@D40B4Q805mOG`1VIVH0Jf][09>CT`3AdM40_[jn0:FUY@1S
Hf<0FUYJ08>3P`1lO7`0_;bl0<k>cP35aLD0TY:B08B4Q02HV9P0U9BD07moO`0207UiN@0;05UIF@1V
IVH0/;2`0<;2`P1BDU80@d=303@d=01bLW80@41005]KF`0];Bd00P0N7Qh06@0I6AT06a/K03dm?@18
B4P0Bd];04Q8B01<C4`0DE5A06MWI`1nOWh0^;Rh09FEU@18B4P0ZJVY0=gMg@3Cdm<0Rh^;04M7A`0h
>3P0Cdm?07YjNP2b/[80De=C020P800e=CD00P0/;2`0>@0b<S80@d=308b<S01FEUH08b<S020P8011
@D40?clo04a<C00i>CT0=CDe04Q8B013@d<0HF5Q09^KV`2ZZZX0a/K60;2`/02LW9`0MWIf0820P02?
Shl0ZZZZ0:^[Z`38b<P0`/;207inOP1PH600J6QX05UIF@0n?Sh0?Cdm0410@013@d<0Ng]k08V9R@1A
DE40<C4a01/K6`0C4a<051@D01DE5@0F5QH0DU9B0492@P0U9BD092@T04Q8B01gMgL0GemO05iNGP1d
M7@05aLG01TI6@1?Cdl0WIfM0=WIf@020;Jf]P0306QXJ01>CTh0C4a<0080A4A401X0AdM704i>CP1D
E5@0EUIF06=SH`16ATH0Lg=c0:^[Z`1eMGD0Kfm_0:BTY01?Cdl06a/K01TI6@0L71`0B4Q806a/K01M
GEd0OWin05UIF@1FEUH0KVi^08^;R`2:RXX0]KFe0:FUY@80QHF50180K6a/05IFEP1eMGD0Cdm?03lo
?`19BDT0;Rh^01HF5P0A4A4092@T05iNGP1RHV80MgMg08B4Q01gMgL0WYjN0;no_`2TY:@207UiN@0>
07YjNP24Q8@0MgMg079bLP2k^k/0^KVi0<c<c037alL0L71`0451@@14A4@0BDU906=SH`27QhL20<S8
b00g08^;R`1RHV80;2`/030`<015ADD0?Cdm01/K6`0U9BD0MWIf08>3P`1HF5P0@T9204E5A@1eMGD0
PX:208J6QP1LG5`0>3Ph03/k>`0i>CT0/[:b0;bl_02?Shl0K6a/03hn?P0/;2`0OWin08f=S@1NGUh0
S8b<0=[JfP3=cLd0Zj^[0;Zj^P2d];@0Ph>306=SH`19BDT0BTY:04a<C01KFe/0JFUY05QHF01]KFd0
SXj>0:2PX01QHF40@T9204I6AP20P800fMWI0=7Ad@2NWYh0];Bd0>3Ph0020<_;b`080:2PX02i^KT0
Z:RX0:b/[02ATI40D51@02DU9@0G5aL201DE5@0D01HF5P0N7Qh0CTi>09^KV`3Cdm<0XZ:R02DU9@0f
=SH0KVi^08>3P`1FEUH0F5QH06QXJ010@400<c<c038b<P0X:2P0:RXZ030`<00e=CD203`l?00W02DU
9@0e=CD0BDU906YZJP2FUYH0TI6A0;:b/P2d];@0SXj>08f=S@2PX:00[Jf]0;Bd]02VYZH0]KFe092@
T01UIFD0LG5a0:f][@21PH40KVi^05aLG013@d<0De=C04Y:BP2JVYX0R8R805iNGP1_Kfl0DE5A065Q
H@0k>c/0=SHf0410@01UIFD0820P01/K6`0L71`07AdM00;ooooo0000o`1CDe<0NGUi0451@@1/K6`0
IfMW04=3@`27QhL0DU9B04=3@`1^KVh0Ng]k03Xj>P0^;Rh0FEUI03Ph>00V9RH0ADE5034a<@1=CDd0
7AdM01@D5019BDT09bLW0451@@0/;2`07QhN06EUI@1<C4`08B4Q03Xj>P1YJFT0>3Ph02DU9@1CDe<0
?clo04=3@`1KFe/0:RXZ02d];@1RHV80<c<c02`/;01LG5`0?3`l03Ph>00b<S80DE5A04Y:BP0_;bl0
Fe]K0451@@0L71`0?Shn059BDP1>CTh0FEUI024Q8@1DE5@0F5QH05YJFP11@D40@T9205aLG00a<C40
61PH02TY:@1ADE40FEUI03/k>`16ATH0C4a<01PH600D51@0CTi>04U9B@0K6a/0<C4a04=3@`0G5aL0
8b<S069RHP16ATH0@41004];B`0Q8B40Cdm?05UIF@0X:2P0BTY:06YZJP0Z:RX09BDU04a<C01dM7@0
>c/k09nOW`1UIFD0CDe=05YJFP1BDU80JVYZ071`L022PX80[Jf]08N7Q`1WIfL0C4a<04I6AP26QXH0
UiNG0<_;b`37alL0R8R80451@@2:RXX0Fe]K06QXJ01PH600Rh^;06MWI`1=CDd0GEeM08j>SP19BDT0
EEEE07IfMP1XJ6P0TI6A08B4Q019BDT0P82007UiN@1<C4`0GEeM06=SH`1CDe<0CTi>06IVIP18B4P0
Cdm?04Y:BP1=CDd0MGEe06UYJ@1VIVH0DU9B03lo?`2CTi<0ADE505mOG`1^KVh0EeMG06EUI@2`/;00
PH6102<S8`10@400OWin04a<C01eMGD0LG5a08>3P`1fMWH0H61P096AT@2SXj<0VIVI04E5A@1:BTX0
MGEe08B4Q01BDU80[Zj^06UYJ@1QHF40WIfM071`L01TI6@0SXj>05mOG`1DE5@0YjNW09JFUP1_Kfl0
UIFE0:b/[01;Bd/0G5aL08J6QP2IVIT0RXZ:03lo?`1FEUH0U9BD0410@01LG5`0UIFE09NGU`1IFET0
WIfM05iNGP13@d<0@41007QhN00j>SX0=cLg06=SH`0_;bl0MGEe055AD@1LG5`0?Cdm06IVIP0f=SH0
RHV906=SH`1:BTX0X:2P08Z:RP1DE5@0Jf][0;^k^`1BDU80M7Ad07QhN00a<C40JFUY09JFUP2QXJ40
P82005QHF01iNGT0GEeM09BDU00j>SX0JVYZ079bLP2RXZ80GemO02DU9@24Q8@0G5aL07AdM01_Kfl0
BDU905=CD`1jNWX0KVi^04Q8B00U9BD0KVi^079bLP1SHf<0;Bd]03De=@00>P1WIfL0Q8B406ATI01Y
JFT0KFe]02h^;P1VIVH0Z:RX079bLP1JFUX0/;2`059BDP17AdL0W9bL08F5Q@0^;Rh0ATI604];B`1L
G5`0<c<c06=SH`1kNg/0NWYj03@d=00g=cL0PX:204a<C011@D40EEEE08V9R@1dM7@0ATI60:j^[P1l
O7`0;Rh^03Ph>01fMWH0H61P02/[:`2LW9`0LG5a01/K6`1OGel0PH61065QH@0n?Sh0T92@04Q8B00a
<C40OGem075aL@1;Bd/0CTi>0;Fe]@1oOgl0B4Q8024Q8@0[:b/206QXJ00j04=3@`1<C4`0Rh^;08:2
PP1hN7P0JVYZ05IFEP16ATH0@D5103Ti>@1^KVh0ZJVY0=?Cd`3?cll0/K6a09nOW`1/K6`0][Jf092@
T027QhL0JVYZ04=3@`12@T80?Cdm04A4A01SHf<0Ph>306ATI00c<c<0:b/[0410@01GEeL09RHV0410
@01EEED0L71`07=cL`1jNWX0IfMW059BDP1<C4`0MWIf06IVIP1?Cdl0A4A403Ti>@0a<C40;Bd]02<S
8`0P8200Cdm?07MgM`2a/K40alO707MgM`2VYZH0IFEU04];B`80<30`03@0EeMG07AdM00U9BD05ADE
01HF5P0I6AT06a/K01lO7`0M7Ad0;Rh^06a/K01LG5`0:b/[06=SH`1EEED0Ogmo06MWI`19BDT0E5AD
08V9R@2GUiL0L71`05IFEP14A4@0QXJ60;fm_@25QHD0MWIf071`L01>CTh0CDe=0:ZZZP31`L40WinO
03`l?00n?Sh0CDe=02<S8`0M7Ad07QhN02d];@15ADD0L71`06IVIP1=CDd0>3Ph01lO7`0E5AD061PH
0492@P11@D408B4Q0`0M7Ad04`15ADD0EEEE0451@@1dM7@0:b/[01LG5`1ADE40ZJVY0=7Ad@2b/[80
Ogmo0<W9b@29RHT0Kfm_06EUI@1aLG40JVYZ069RHP1eMGD00P1YJFT01@2SXj<0][Jf09FEU@1XJ6P0
O7al0080TI6A01/0EEEE02HV9P0O7al07QhN04=3@`1oOgl0X:2P0:n_[`2SXj<0UiNG07emO@2;Rh/0
W9bL0::RXP1jNWX0BTY:02`/;00f=SH0I6AT05ADE00V9RH0;Bd]0410@00m?Cd0:b/[03De=@1/K6`0
0P1PH600J`1;Bd/0GemO09bLW02][Jd0SXj>07YjNP1mOGd0GemO02h^;P0S8b<0;bl_06a/K01TI6@0
MGEe09BDU00a<C406ATI02HV9P0g=cL0@d=304a<C02>SXh0];Bd0:n_[`0m?Cd09RHV02d];@0g=cL0
GEeM02`/;01FEUH0MWIf04E5A@0Z:RX09BDU02TY:@0b<S80Hf=S06UYJ@1fMWH0?clo02XZ:P0f=SH0
Kfm_069RHP2SXj<0][Jf0:f][@2YZJT0_;bl08N7Q`2EUID0]kNg0<O7a`1lO7`0Hf=S08F5Q@1fMWH0
Q8B408Z:RP2QXJ40[Zj^0:2PX02JVYX0UYJF0:j^[P3=cLd0d];B04a<C00P8200;Rh^03Ti>@2i^KT0
/;2`09NGU`2`/;00][Jf0=WIf@3Hf=P0[:b/09:BTP1FEUH0M7Ad0;Bd]01kNg/0W9bL09RHV02<S8`0
@D5102XZ:P0g=cL0TI6A07]kN`0`<300IVIV06e]K@0L71`0A4A406m_K`1gMgL0JFUY06i^KP1hN7P0
@D5103Ti>@0o?cl0>CTi0080:2PX02X09bLW020P800U9BD07alO02HV9P18B4P0Kfm_07]kN`2RXZ80
`l?30;Vi^@2b/[80Ph>309bLW02JVYX0ZZZZ0<_;b`2k^k/0FUYJ05EEE@2^[Zh0JFUY04E5A@1SHf<0
QhN709fMW@32`/80b<S809^KV`2m_Kd0R8R802XZ:P0R8R80>c/k04=3@`12@T80=SHf06i^KP0/;2`0
61PH01TI6@0M7Ad2ooooo`0002D0Hf=S06e]K@14A4@0Hf=S04m?C`0_;bl0FEUI04M7A`1CDe<0Fe]K
05YJFP0Y:BT0=cLg06e]K@1<C4`0;2`/02l_;`0S8b<0E5AD038b<P0H61P0:b/[00/;2`0^;Rh0CTi>
02DU9@1MGEd07AdM014A4@0_;bl0E5AD04A4A00U9BD0>CTi014A4@0S8b<0EUIF0080<C4a0600JVYZ
01hN7P0E5AD0?3`l05ADE00f=SH06QXJ03Xj>P1MGEd0?3`l06IVIP16ATH0:RXZ02LW9`1>CTh0@d=3
06a/K00m?Cd0HV9R05eMG@1aLG40C4a<04=3@`1PH600GEeM03/k>`0];Bd0EeMG079bLP1MGEd0A4A4
04M7A`0d=3@06a/K05eMG@13@d<06ATI02d];@10@4009bLW030`<01_Kfl0@41004=3@`1LG5`0:2PX
05aLG01ADE407alO0410@01SHf<0E5AD030`<01DE5@0LG5a03Xj>P2IVIT0HV9R05EEE@1OGel0HV9R
05MGE`0d=3@0Bd];08j>SP1fMWH0EUIF05=CD`17AdL0P82008f=S@3Bd]80dM7A08f=S@17AdL0Q8B4
05aLG01aLG40HV9R096AT@1iNGT0B4Q8069RHP2EUID0E5AD059BDP1TI6@0De=C09RHV027QhL0BTY:
07QhN01fMWH0EEEE04m?C`1PH602055AD@1F05YJFP12@T80FEUI03Ph>01BDU80OWin06=SH`1nOWh0
G5aL03hn?P2KVi/0FEUI0861P@25QHD0I6AT06QXJ02`/;00LG5a03Ph>01HF5P0Ogmo04Y:BP1[Jf/0
F5QH09BDU025QHD0JVYZ08^;R`3<c<`0SHf=05ADE01nOWh0YjNW092@T019BDT0QHF505]KF`2:RXX0
Y:BT079bLP1MGEd0SXj>03dm?@10@400OWin075aL@1JFUX0P8200:FUY@1^KVh0JVYZ07IfMP1PH600
F5QH04Q8B01MGEd0TY:B06YZJP1ADE40R8R806][J`1BDU80W9bL06e]K@0Z:RX0?3`l07YjNP0i>CT0
>3Ph05aLG010@400QXJ604e=C@1<C4`0=SHf04i>CP0g=cL0V9RH06ATI016ATH0Ti>C0:BTY00V9RH0
?clo09>CT`10@40206YZJP2402LW9`16ATH0LW9b05QHF01BDU80@d=306m_K`1RHV80SHf=0410@01K
Fe/0EEEE08n?S`13@d<09BDU079bLP0e=CD0?Cdm051@D00f=SH0EEEE07=cL`17AdL0<C4a04Q8B01f
MWH0Lg=c05=CD`0d=3@0@41006][J`10@400>3Ph04U9B@1VIVH0AdM706][J`2g]kL0De=C03Ti>@23
Ph<0EUIF03`l?028R8P0Q8B4065QH@1^KVh0QXJ607YjNP0c<c<0A4A405UIF@0n?Sh0<30`05IFEP2E
UID0RHV904I6AP1GEeL0Q8B404a<C00];Bd0PH61079bLP0W9bL0>c/k079bLP1NGUh0=CDe09fMW@2K
Vi/0GEeM06QXJ01jNWX0KFe]04a<C02=SHd0GemO03Ti>@22PX80KVi^0451@@0Y:BT0LW9b06=SH`16
ATH07alO02`/;01NGUh0DU9B03Hf=P0T92@0O7al0820P01FEUH0EEEE04];B`0Z:RX07alO01`L700N
7Qh0CTi>0861P@30`<00OGem0:2PX027QhL0NWYj03Hf=P10@400@D5103/k>`0c<c<0;Rh^03<c<`1]
KFd0_;bl06ATI00E5AD04a<C01@D500Z:RX0De=C02d];@15ADD0W9bL07YjNP1oOgl0WIfM07=cL`12
@T80=SHf0P0];Bd05@0^;Rh0;bl_034a<@0f=SH0>3Ph06UYJ@2QXJ40f][J0>7Qh@2OWil09bLW03Ph
>02@T900EEEE02`/;00[:b/0=3@d05EEE@0I6AT03Ph>01<C4`0301DE5@0/01`L700J6QX08R8R059B
DP27QhL0GemO0820P01fMWH0JFUY096AT@2][Jd0JVYZ04U9B@0h>3P0:RXZ038b<P0/;2`0?Cdm071`
L027QhL0GUiN0451@@0`<300MGEe08^;R`2BTY80@T9201DE5@0g=cL09BDU02@T900Q8B4071`L02TY
:@1IFET0L71`06e]K@1KFe/0<c<c02XZ:P13@d<0<C4a02LW9`0I6AT201dM7@0;01lO7`0f=SH0FUYJ
04I6AP0h>3P0UIFE06YZJP0m?Cd0Cdm?0;Rh^03UiND00P3Fe]H00`3<c<`0Xj>S09VIV@02096AT@0d
092@T02OWil0/k>c0=KFeP3@d=00Jf][05aLG01PH600E5AD02DU9@0m?Cd0/K6a0:NWY`1NGUh0JFUY
06ATI01ZJVX0dM7A0;fm_@2KVi/0Shn?075aL@1KFe/0G5aL069RHP0k>c/06ATI01DE5@0J6QX0?clo
05mOG`0d=3@092@T02XZ:P0];Bd0C4a<08J6QP1<C4`0=cLg02DU9@0Z:RX0BTY:0:b/[03?cll0WYjN
09bLW02OWil0M7Ad02/[:`0F5QH07alO02DU9@80=CDe02d0JVYZ07AdM00I6AT06a/K02<S8`0h>3P0
Ph>30<S8b036a/H0KVi^03/k>`0T92@09bLW03Lg=`1HF5P0V9RH07YjNP1>CTh08b<S02LW9`0Q8B40
8b<S020P800i>CT0FUYJ04i>CP1`L700E5AD02l_;`0N7Qh0CDe=04i>CP2j^[X0_[jn0:ZZZP1lO7`0
U9BD0;>c/`3IfMT0M7Ad05UIF@1:BTX0E5AD051@D00_;bl00P0L71`0;`0X:2P0>3Ph04];B`1`L700
Ti>C0:>SX`3;bl/07alO01DE5@0V9RH0P82009:BTP2DU9@0>CTi03Hf=P1^KVh0dm?C0=KFeP1GEeL0
=3@d03dm?@1VIVH0VYZJ04];B`10@400CDe=07=cL`2b/[80b<S80=?Cd`1bLW807QhN020P801;Bd/0
FEUI02TY:@1HF5P0KVi^04Y:BP28R8P0IFEU06MWI`0g=cL0@d=302HV9P0X:2P0820P00807alO0P0M
7Ad09`0P820092@T04Q8B01QHF40PX:20;2`/01`L700S8b<0<o?c`2UYJD0U9BD07IfMP1UIFD0Ph>3
0:VYZ@1CDe<0XJ6Q0::RXP0h>3P0=cLg04A4A01bLW80c<c<08b<S020P800X:2P08b<S00c<c<07AdM
020P800X:2P0EeMG05UIF@12@T80PX:206ATI00_;bl0<c<c04e=C@02ooooo`0002D0Ng]k09:BTP1?
Cdl0D51@07=cL`0e=CD0IFEU05aLG01ZJVX0De=C07moO`16ATH0=SHf05UIF@1KFe/09BDU0492@P0U
9BD0Fe]K03Hf=P0H61P0<30`01hN7P0b<S80@41002HV9P1=CDd0=3@d02d];@0X:2P0EUIF04];B`0V
9RH0@41003Ti>@0d=3@0DE5A0080=3@d00D0LG5a05mOG`0Z:RX0@D5106i^KP0203/k>`0W0410@01a
LG40A4A405IFEP1?Cdl0>SXj02d];@1=CDd0?3`l0820P015ADD0OGem07EeM@23Ph<0D51@04=3@`1M
GEd0J6QX04E5A@0Z:RX0EEEE07=cL`1WIfL0AdM7051@D01?Cdl07alO05UIF@1LG5`09bLW030`<01?
Cdl0<30`02l_;`1^KVh0?Cdm04];B`1EEED0<c<c0080DU9B00/09bLW03lo?`1RHV80EEEE030`<01F
EUH0C4a<02h^;P1dM7@0PH6105IFEP0206IVIP3P08^;R`1gMgL0H61P0;Ng]`1fMWH0EeMG05YJFP1:
BTX0EUIF0492@P1jNWX0XJ6Q08:2PP17AdL0PH6104e=C@1fMWH0F5QH071`L01<C4`0GemO08n?S`28
R8P0BDU9059BDP1IFET0:BTY07emO@23Ph<0BTY:0820P01@D500?clo05=CD`1RHV80Bd];059BDP1?
Cdl0=CDe05=CD`1OGel0De=C0:RXZ00j>SX0IFEU05aLG017AdL0T92@038b<P18B4P0Jf][05YJFP1Q
HF40a<C407=cL`0S8b<0?Shn07EeM@0k>c/0MWIf04m?C`1fMWH0NWYj04E5A@24Q8@0cLg=08>3P`0e
=CD0=SHf05QHF017AdL0FUYJ0;Jf]P1BDU80D51@08^;R`1]KFd0OWin0:JVYP21PH40DE5A09ZJVP1?
Cdl0<C4a065QH@2NWYh0PH6104a<C01aLG40K6a/04=3@`12@T80J6QX08Z:RP1[Jf/0H61P0:BTY01e
MGD0B4Q808J6QP19BDT0<c<c030`<01@D500=3@d03hn?P1>CTh0<S8b05ADE01/K6`0BTY:0410@01W
IfL09bLW06ATI01IFET0=cLg0::RXP2?Shl0EeMG04i>CP2YZJT0B4Q806UYJ@1SHf<0<C4a04A4A026
QXH0De=C0451@@0i>CT0QXJ608:2PP1hN7P0ATI607AdM01BDU80Zj^[02<S8`15ADD0SHf=05=CD`19
BDT0F5QH020P801DE5@0Ng]k05IFEP15ADD0:2PX055AD@1gMgL0820P02l_;`19BDT0HV9R07QhN01G
EeL0DU9B06QXJ00I6AT0C4a<07QhN020P800D51@0::RXP1`L700@41007UiN@1KFe/0EUIF06=SH`1A
DE40Ng]k03dm?@1;Bd/0GEeM05aLG00b<S80<C4a071`L025QHD0DU9B07UiN@1RHV80OGem04i>CP2J
VYX0Ph>303@d=01JFUX0Ti>C0820P00f=SH0Ng]k05aLG01HF5P0K6a/06e]K@1OGel0=SHf07inOP1Y
JFT0A4A409FEU@2NWYh0IfMW03De=@25QHD0LW9b03hn?P0k>c/0CDe=06][J`1FEUH0=cLg02HV9P28
R8P0PH610410@00k>c/0<S8b020P800M7Ad201XJ6P0902DU9@1LG5`0TY:B09FEU@1GEeL0VIVI09RH
V01TI6@0:RXZ00805ADE0P0C4a<01@0A4A405ADE051@D02[Zj/09BDU00804a<C00`04A4A01lO7`1L
G5`0P8200<K6aP2ZZZX0X:2P07QhN01TI6@0FUYJ04m?C`1ADE4205iNGP11055AD@1BDU80RHV909^K
V`3?cll0cLg=0=cLg03Fe]H0`<3004i>CP0W9bL0Ti>C05aLG00c<c<09RHV034a<@1>CTh06QXJ024Q
8@0I6AT04A4A01<C4`0E5AD05aLG01XJ6P0K6a/0820P07alO02VYZH0Ng]k0820P01nOWh0ZZZZ06AT
I00m?Cd0<S8b02l_;`0Z:RX06ATI01XJ6P0M7Ad09RHV05=CD`1MGEd0?Shn02h^;P1WIfL0IVIV0492
@P1IFET0@41002`/;00f=SH07AdM02LW9`0S8b<08B4Q02/[:`1LG5`0BDU905MGE`2>SXh0FEUI02HV
9P0R8R800P0L71`0@`0R8R809RHV02HV9P0^;Rh0GUiN051@D00f=SH0PH6104=3@`0T92@07AdM09jN
WP2o_kl0[jn_0<_;b`3<c<`0G5aL059BDP1FEUH0FEUI05MGE`1NGUh0P82009:BTP3:b/X0Cdm?04Q8
B01:BTX0;Bd]01lO7`0a<C40EUIF07EeM@0J6QX06ATI06EUI@1>CTh0[jn_08R8R01RHV80HF5Q05YJ
FP15ADD0>SXj051@D00m?Cd05ADE01HF5P0E5AD05aLG02`/;00o?cl09BDU03De=@1CDe<0Lg=c059B
DP1;Bd/0;bl_034a<@11@D40NWYj0<o?c`36a/H0O7al07moO`1EEED00P1^KVh05`0];Bd061PH01DE
5@0T92@0=CDe04M7A`2_[jl0HF5Q03Xj>P0f=SH0;Bd]03<c<`1oOgl0Y:BT09BDU01dM7@0@41002TY
:@0_;bl0@4100;Ng]`1ZJVX0;Bd]00<07QhN01/07AdM01lO7`0R8R80BTY:05EEE@1/K6`0UYJF06][
J`1lO7`0W9bL09fMW@22PX80Rh^;0:FUY@37alL0fMWI0=oOg`2^[Zh0IVIV07QhN01GEeL0L71`07em
O@0V9RH071`L01/K6`0J6QX00`0K6a/06`0L71`08B4Q07YjNP1<C4`05aLG07AdM02YZJT0LG5a07=c
L`0P82007AdM034a<@2d];@0d=3@02l_;`0X:2P0;bl_04a<C02_[jl0BTY:028R8P0O7al0:2PX03hn
?P1WIfL0a<C406e]K@0201TI6@0@06MWI`1<C4`0ADE506UYJ@0o?cl0:b/[0;^k^`2IVIT0ATI602XZ
:P0T92@09RHV01`L700N7Qh07alO01`L70807QhN02L08b<S030`<01ADE40Ogmo0;Zj^P2>SXh0MgMg
09nOW`2`/;00/[:b06QXJ02IVIT0`/;20<_;b`3AdM40f][J0=OGe`2;Rh/09RHV02h^;P0a<C40IfMW
07QhN00N7Qh0>SXj096AT@0m?Cd0BTY:02<S8`0N7Qh08b<S06IVIP2ZZZX0Vi^K0;bl_02d];@0SHf=
08B4Q01cLg<00_ooool0000i0820P021PH40EEEE05ADE020P800=cLg06YZJP1TI6@0MgMg075aL@2Q
XJ40IfMW04Y:BP1PH600JFUY028R8P17AdL0:RXZ05QHF00o?cl06ATI03/k>`0i>CT0@D5104i>CP0P
8200GemO04Q8B00m?Cd0<30`04a<C01=CDd0:BTY05aLG01>CTh0<30`04M7A`0f=SH0=3@d08j>SP1c
Lg<0:2PX03dm?@1]KFd0=3@d03hn?P0i>CT0L71`04U9B@1QHF40UIFE03hn?P0e=CD0FEUI04A4A02J
VYX0A4A40080Ogmo0?l0IFEU03lo?`1@D500Kfm_06i^KP1BDU80:BTY059BDP1@D500>c/k061PH02B
TY80FUYJ01lO7`1DE5@0F5QH02<S8`18B4P0IfMW038b<P0/;2`0I6AT03Lg=`1BDU80HV9R03@d=016
ATH0C4a<02HV9P14A4@0IfMW05YJFP0^;Rh0Jf][07alO00d=3@0SXj>0820P00j>SX0MGEe09:BTP27
QhL0Kfm_06EUI@3?cll0JVYZ04I6AP1UIFD0LG5a07IfMP1LG5`0cLg=0=_Kf`2<S8`0BDU909JFUP1G
EeL0JVYZ0410@01EEED0JVYZ04I6AP1GEeL0Hf=S04M7A`1bLW80RHV906ATI02;Rh/0MGEe04M7A`2;
Rh/0Q8B404a<C017AdL0BDU904M7A`1YJFT0KVi^05=CD`1>CTh0B4Q803hn?P2@T900IVIV06EUI@1I
FET0?3`l08>3P`1eMGD0LG5a05YJFP0b<S80Bd];0:>SX`2HV9P0:BTY03`l?01eMGD0B4Q806a/K010
@400LW9b07AdM01@D500JVYZ0<o?c`26QXH0EeMG03dm?@1[Jf/0NWYj05MGE`2>SXh0FEUI075aL@1o
Ogl0ADE505eMG@2SXj<0Jf][04i>CP2NWYh0Ph>308R8R01;Bd/0[Jf]0820P018B4P0P82008N7Q`29
RHT0BDU905=CD`2IVIT0QXJ607alO033`l<0Z:RX04=3@`1hN7P0Kfm_04E5A@0k>c/0EUIF03De=@1Y
JFT0UYJF03`l?01`L700MgMg069RHP1EEED0Jf][03dm?@1hN7P0M7Ad04Y:BP2a/K40[Zj^07UiN@1C
De<0`L7105=CD`1]KFd0OWin04m?C`1:BTX0Zj^[06e]K@1dM7@0CDe=06IVIP1OGel0QXJ604I6AP27
QhL0HF5Q0:j^[P16ATH08B4Q05EEE@17AdL0FUYJ07=cL`0i>CT0Bd];05UIF@1=CDd09BDU03dm?@1i
NGT0KFe]0492@P0W9bL0<c<c05EEE@1WIfL0DU9B08B4Q02:RXX09RHV04I6AP1dM7@0C4a<03/k>`2@
T900PH6104a<C01iNGT0LW9b08F5Q@1iNGT0De=C08^;R`12@T80G5aL08^;R`1dM7@0>c/k02l_;`1P
H600=cLg028R8P15ADD0GEeM07=cL`1<C4`0RHV9059BDP0I6AT0<30`06YZJP1cLg<0>3Ph09JFUP1G
EeL0Cdm?08J6QP2/[:`0TI6A04U9B@2JVYX0O7al03Xj>P1nOWh0Rh^;06MWI`0f=SH0QHF505eMG@0_
;bl05QHF020P801HF5P001@0LW9b03De=@0];Bd0SXj>06EUI@0f=SH0>3Ph02/[:`0M7Ad08B4Q01dM
7@0G5aL06a/K04U9B@24Q8@0[Zj^09bLW01XJ6P0HV9R020P80804a<C01L04A4A010@400>3Ph0410@
01<C4`0B4Q80H61P08F5Q@0P82004a<C014A4@0@4100;Bd]09RHV02IVIT0_[jn09JFUP2XZ:P0Y:BT
05QHF00n?Sh0:b/[020P800201/K6`0P02TY:@0k>c/0;Rh^08R8R01_Kfl0WIfM07moO`2c/k<0`<30
07MgM`2UYJD0Ti>C05ADE00/;2`0>c/k05]KF`0E5AD05aLG01TI6@0>3Ph0410@01<C4`0E5AD07AdM
01XJ6P0M7Ad0C4a<06IVIP1PH600I6AT09NGU`1^KVh204Q8B00403De=@0V9RH06a/K01LG5`805ADE
00L05aLG02LW9`1=CDd0C4a<038b<P1YJFT0K6a/0080>CTi00h0G5aL06ATI01BDU8071`L01TI6@0M
7Ad09BDU02XZ:P15ADD0IVIV04];B`1mOGd0GEeM03Lg=`<07AdM00T07QhN02HV9P0^;Rh09BDU05=C
D`1IFET0@41006YZJP0a<C400P0M7Ad09@1HF5P0J6QX06e]K@2ZZZX0e]KF07moO`1/K6`0EEEE04];
B`15ADD0Cdm?05eMG@1;Bd/0`l?3096AT@0_;bl05ADE01LG5`0T92@0:RXZ03Xj>P1oOgl0@T9203<c
<`1;Bd/0CDe=04Q8B00n?Sh0?clo0492@P0d=3@0:2PX024Q8@0X:2P0BDU901TI6@0H61P00`0E5AD0
A00W9bL0:BTY02TY:@0Y:BT0M7Ad06UYJ@1DE5@0IVIV07moO`2LW9`0bl_;0>CTi03<c<`0OWin04];
B`0Z:RX09bLW03/k>`1oOgl0<c<c01HF5P0_;bl09bLW02/[:`1iNGT0[Zj^069RHP1nOWh0WIfM0;:b
/P2JVYX0SXj>0;Fe]@2NWYh0OGem06EUI@16ATH0IFEU0;:b/P1IFET08R8R01lO7`0P82008R8R02TY
:@0K6a/05QHF02`/;01UIFD0B4Q808J6QP2TY:@0@d=303Ph>01CDe<0?3`l030`<010@400T92@0<71
`@3Ogml0Q8B408N7Q`2EUID0V9RH0:RXZ02PX:00>c/k0P0K6a/0>00M7Ad06a/K01dM7@0I6AT07QhN
01lO7`0a<C40Ph>308J6QP2JVYX0Zj^[0;Rh^01[Jf/07alO01dM7@0V9RH0XJ6Q0<k>cP1lO7`0>SXj
03`l?027QhL0clo?075aL@0S8b<0:RXZ02`/;00Q8B409bLW05IFEP2KVi/0C4a<01lO7`2BTY80=CDe
05MGE`1<C4`0:2PX08:2PP2l_;`0bl_;08Z:RP0Y:BT06QXJ01hN7P0Q8B408b<S01hN7P0M7Ad07QhN
01`L700^;Rh0HV9R08Z:RP2YZJT0TI6A0P2HV9P0801HF5P0De=C0:b/[022PX80?Cdm04I6AP2=SHd0
gMgM0=SHf032`/80a<C408J6QP10@400<C4a06=SH`16ATH071`L04i>CP23Ph<08R8R04E5A@1KFe/0
;2`/03Ph>01^KVh0QHF509JFUP2i^KT0Ph>307=cL`1dM7@0Ogmo0_ooool0000706QXJ01jNWX0?clo
04M7A`1PH600=CDe06ATI00203Ti>@3o04Y:BP1aLG40CTi>03lo?`1LG5`0>CTi03<c<`1EEED09RHV
04Y:BP0X:2P07alO04a<C00g=cL0A4A405UIF@0O7al0Kfm_04M7A`0f=SH0ADE506a/K00f=SH06a/K
04M7A`0l?3`0<S8b04Q8B00L71`07alO05YJFP1FEUH0:RXZ04E5A@16ATH07alO03Ph>00e=CD0>CTi
020P800h>3P0EEEE03<c<`10@400De=C02`/;01QHF40<C4a08B4Q02ATI40D51@03Ti>@0c<c<0@T92
05ADE00k>c/0>CTi06UYJ@1WIfL0GemO03/k>`1CDe<0ADE502<S8`1aLG40KVi^02PX:00[:b/0CTi>
03Lg=`0j>SX0NGUi04e=C@16ATH0FEUI03Hf=P0m?Cd0G5aL02l_;`0n?Sh0KVi^04A4A00Z:RX0E5AD
07AdM00i>CT0RXZ:0:6QX@14A4@0FUYJ05aLG01/K6`0JVYZ06e]K@3EeMD0QHF506=SH`0o?cl0>CTi
0820P02KVi/0_kno0=GEe@2KVi/0>3Ph07EeM@1XJ6P0MGEe06EUI@19BDT0NGUi055AD@1MGEd0NGUi
04Q8B01ADE40IFEU05MGE`2;Rh/0R8R803lo?`1hN7P0QHF504m?C`1<C4`0KVi^04A4A017AdL0L71`
05iNGP1@D500Hf=S04E5A@2?Shl0JVYZ05eMG@24Q8@0A4A408B4Q025QHD0Jf][05QHF01NGUh0ATI6
0;fm_@2:RXX0<S8b04Q8B01WIfL0=cLg069RHP14A4@0WinO08F5Q@1=CDd0@T920<O7a`1oOgl0GEeM
06EUI@28R8P0UYJF05UIF@20P800Bd];07alO02<S8`0MgMg05UIF@2^[Zh0QHF506=SH`2f][H0VIVI
07EeM@0n?Sh0^KVi06e]K@1>CTh0L71`08n?S`28R8P0BTY:06ATI02NWYh0A4A404e=C@2DU9@0Ng]k
04Y:BP2?Shl0PH6104e=C@1FEUH0JFUY03@d=00b<S80FEUI03Ph>01cLg<0KFe]030`<01TI6@0HF5Q
0451@@21PH40KVi^02PX:01gMgL0LW9b03/k>`19BDT0WinO051@D01>CTh0L71`03Xj>P1PH600R8R8
08N7Q`2=SHd0IFEU071`L01ZJVX0SHf=0492@P1kNg/0NGUi0::RXP1[Jf/09RHV069RHP1;Bd/0@D51
05YJFP1:BTX0C4a<05UIF@1aLG40G5aL02d];@16ATH0QXJ605eMG@0X:2P0=cLg05ADE01LG5`0A4A4
04a<C01/K6`0?Cdm0451@@1eMGD0M7Ad000]05EEE@2IVIT0BTY:030`<02<S8`0MgMg07QhN024Q8@0
EeMG06e]K@0P8200A4A406EUI@1ADE40;bl_02`/;01EEED0JFUY05MGE`1PH600@T92079bLP1HF5P0
NGUi05YJFP0c<c<0;Rh^06YZJP1lO7`0?3`l08j>SP1FEUH0?Cdm05QHF01nOWh0LW9b0410@02CTi<0
FUYJ02`/;01WIfL0JFUY04I6AP0k>c/0Q8B40080BDU900/06ATI02HV9P1XJ6P0Ph>304=3@`0Y:BT0
T92@08V9R@0d=3@0=SHf02/[:`0202@T900@02l_;`0e=CD0=SHf02LW9`1GEeL0SHf=0:2PX032`/80
De=C01DE5@0D51@04A4A00d=3@0C4a<0410@014A4@80410@00h05aLG09JFUP1aLG405aLG014A4@0@
41007alO08B4Q020P800[jn_05MGE`1PH600Bd];01LG5`804a<C01D051@D01DE5@0E5AD05aLG01HF
5P0G5aL07QhN03De=@0l?3`0JFUY05ADE02@T900c/k>0>7Qh@35aLD0IVIV04e=C@19BDT0O7al01TI
6@0G5aL00P0>3Ph0200A4A404a<C01DE5@0G5aL06QXJ03<c<`14A4@0QhN70P2RXZ801P2@T900F5QH
0451@@10@4008B4Q01HF5PD05ADE04P08R8R030`<00f=SH0DE5A06IVIP1RHV80?Shn030`<00g=cL0
IFEU0:FUY@1=CDd0=cLg03De=@0o?cl0FEUI06=SH`2=SHd0T92@0:6QX@1fMWH0H61P04a<C00l?3`0
=3@d03Ti>@0f=SH0ADE504i>CP1iNGT0H61P04Q8B01ZJVX0;bl_01`L7012@T80AdM702HV9P0d=3@0
HV9R0=7Ad@2JVYX0NWYj06][J`1VIVH0HF5Q06YZJP2;Rh/0Ogmo0:NWY`2^[Zh0@d=301@D500C4a<0
5aLG03De=@16ATH0I6AT0;no_`2_[jl0MgMg06m_K`1QHF40=cLg01/K6`0L71`08B4Q01`L700G5aL0
6ATI04=3@`0b<S8301LG5`0K01DE5@0Y:BT0?clo051@D01SHf<0QHF50;>c/`2MWId0V9RH07inOP2[
Zj/0/;2`09FEU@2ZZZX0KVi^02@T900L71`07QhN01TI6@0/;2`07alO01TI6@0Y:BT08B4Q02XZ:P1^
KVh0>CTi00805ADE02X08B4Q06][J`2PX:00b/[:0>GUi@3Ph>00^[Zj0:JVYP2YZJT0`l?307moO`2[
Zj/0LW9b07moO`1cLg<0IfMW061PH00O7al05aLG01TI6@10@400AdM708^;R`1OGel0>CTi01dM7@0n
?Sh0AdM702/[:`0Y:BT0AdM708n?S`3?cll0S8b<06e]K@18B4P0@T92075aL@2?Shl0G5aL01hN7P0I
6AT201lO7`@071`L02L09RHV05QHF035aLD0IfMW07MgM`3De=@0RXZ:02<S8`0K6a/0B4Q809VIV@13
@d<0AdM706UYJ@1?Cdl0IVIV055AD@1SHf<0EEEE02/[:`0W9bL0<C4a03Hf=P0e=CD0IFEU0;>c/`2H
V9P0^;Rh04a<C01;Bd/0FEUI09BDU01iNGT0PX:20;^k^`2UYJD0R8R806YZJP0`<3000P0L71`02`0W
9bL07QhN01lO7`0e=CD0NGUi08n?S`2@T900Vi^K09VIV@1jNWX0ADE50080<c<c01h0De=C08V9R@1X
J6P0BDU90;fm_@39bLT0Rh^;079bLP1mOGd0/;2`0:j^[P28R8P0OWin05=CD`0[:b/0QXJ60:BTY00/
;2`08B4Q061PH02HV9P0QHF504Y:BP1MGEd0ZZZZ05eMG@0d=3@0;2`/03<c<`17AdL2ooooo`000640
J6QX06EUI@1MGEd0AdM706e]K@0^;Rh0EeMG065QH@1HF5P0GEeM08n?S`1IFET0ADE508F5Q@1NGUh0
8b<S02d];@0U9BD0FEUI03Hf=P0D51@09RHV00d=3@0[:b/0HV9R020P801GEeL0;bl_01TI6@0V9RH0
AdM7051@D00P8200=CDe01TI6@0U9BD0EUIF04e=C@0L71`0FUYJ0492@P0R8R80AdM706YZJP0k>c/0
92@T03Ti>@1XJ6P0ATI603`l?01RHV80:b/[02PX:016ATH0=cLg07MgM`14A4@0HF5Q06ATI01`L700
DU9B05IFEP1^KVh0JFUY03Xj>P0T92@0ADE5071`L01^KVh0?clo06=SH`0m?Cd05aLG03lo?`1JFUX0
92@T02h^;P1=CDd0820P02LW9`1MGEd0Fe]K05=CD`1?Cdl0820P03hn?P1KFe/0=3@d03dm?@1CDe<0
FEUI02DU9@1WIfL0PX:204I6AP2:RXX0][Jf0080Jf][0?00JVYZ06ATI00c<c<0EEEE0:ZZZP24Q8@0
Fe]K04Y:BP0l?3`0S8b<09>CT`36a/H0c/k>092@T013@d<0Ogmo07AdM024Q8@0Lg=c04];B`22PX80
D51@06=SH`2;Rh/0GemO05aLG01]KFd0P82008N7Q`2OWil0BTY:07UiN@1kNg/0Cdm?05IFEP1[Jf/0
ATI604m?C`1/K6`0HF5Q071`L01dM7@0@41009:BTP1JFUX0MGEe06QXJ012@T80PH6103Ti>@1HF5P0
Kfm_05YJFP16ATH0_[jn05aLG00[:b/0?Shn06e]K@0f=SH0IVIV03Ph>01bLW80PH6104Y:BP0g=cL0
/K6a08B4Q01>CTh0?3`l07EeM@24Q8@0C4a<0861P@1TI6@0ZZZZ09bLW01hN7P0De=C0:>SX`1GEeL0
B4Q808B4Q01]KFd0ADE50410@02RXZ80U9BD05ADE027QhL0ZJVY06a/K011@D40OWin09jNWP22PX80
Lg=c0<?3``1eMGD0<c<c08Z:RP1LG5`0<C4a02d];@1@D500=cLg03hn?P1RHV80>3Ph08B4Q01bLW80
@41005aLG00n?Sh0:RXZ04m?C`1ADE409bLW09bLW02KVi/0FEUI03dm?@2ATI40@D5105IFEP1/K6`0
<30`0410@026QXH0ADE5075aL@1QHF40Fe]K06e]K@25QHD0Hf=S07]kN`1LG5`0WYjN06][J`0b<S80
EEEE05MGE`1:BTX0JFUY05mOG`11@D40Cdm?075aL@1[Jf/0>3Ph04=3@`2NWYh0IVIV02/[:`0e=CD0
C4a<08V9R@1SHf<0H61P08>3P`1[Jf/0BTY:0;6a/@2MWId0Jf][09JFUP1DE5@0=3@d08>3P`1mOGd0
L71`07AdM01JFUX0RHV905]KF`11@D40G5aL04a<C00c<c<09RHV05eMG@28R8P0LW9b07UiN@1CDe<0
Q8B405YJFP2>SXh0R8R803`l?00d=3@0Jf][06MWI`0e=CD0U9BD05IFEP1NGUh0K6a/092@T01eMGD0
?Cdm08B4Q017AdL0>c/k06MWI`1hN7P0I6AT05QHF02b/[80IVIV04I6AP0F5QH092@T06YZJP1=CDd0
<C4a04i>CP2NWYh0T92@030`<00g=cL0<30`02DU9@16ATH0@d=303Xj>P0V9RH07AdM04U9B@2LW9`0
JFUY0;Vi^@29RHT0:b/[01<C4`0@41003Ph>01<C4`0@4102014A4@0X00h>3P0A4A40:b/[0:6QX@1:
BTX04a<C014A4@0U9BD0JFUY08b<S024Q8@0N7Qh03/k>`0o?cl04a<C014A4@0@41005ADE018B4P0D
51@05ADE01<C4`0@41005aLG02TY:@0i>CT0GUiN06i^KP1DE5@0IVIV0;Rh^03Hf=P0T92@0:^[Z`32
`/80_;bl04m?C`0Z:RX05aLG00h>3P8051@D00`04A4A01<C4`0d=3@0De=C038b<P2EUID0Lg=c08n?
S`1_Kfl0BTY:04];B`0T92@301DE5@0301@D500E5AD05ADE00805ADE05/09BDU02<S8`0c<c<0Fe]K
06UYJ@10@400ADE503<c<`0o?cl0Shn?07inOP19BDT0ATI605=CD`1gMgL0TI6A0:RXZ034a<@0b<S8
09^KV`1VIVH0>c/k04U9B@1IFET0IVIV07AdM025QHD0U9BD0:>SX`1hN7P0AdM706YZJP0/;2`0?Shn
06MWI`12@T8092@T02XZ:P0m?Cd0[Zj^02<S8`0];Bd0:BTY02@T900m?Cd0IFEU0492@P0J6QX0IVIV
06MWI`21PH409bLW01<C4`0D51@0HF5Q07inOP2_[jl0`<3006EUI@1CDe<0MGEe0:f][@1YJFT06a/K
028R8P0d=3@09RHV02TY:@0K6a/0;2`/07YjNP0/;2`071`L01HF5P0E5AD09bLW051@D01mOGd0QXJ6
07emO@2h^;P0Ng]k08n?S`2UYJD0NWYj051@D01gMgL0[jn_08b<S00_;bl05ADE008071`L00P05QHF
01/K6`0H61P0:BTY02`/;00[:b/0L71`01`L70805ADE01805aLG028R8P1^KVh0GEeM0:2PX023Ph<0
CDe=0492@P0k>c/0LG5a059BDP2ZZZX0De=C034a<@0X:2P07alO01dM7@0N7Qh201lO7`0G02/[:`19
BDT0W9bL04e=C@13@d<07AdM03Ti>@1SHf<0?Cdm0451@@19BDT0N7Qh0<O7a`2QXJ40?clo03/k>`0c
<c<0@d=305iNGP2;Rh/0D51@01`L700H61P00P0P8200E`0S8b<07AdM02<S8`0b<S80Fe]K0:RXZ01I
FET0Rh^;06e]K@1KFe/0K6a/07IfMP25QHD0LG5a03De=@1>CTh0KFe]07MgM`0f=SH0;Bd]03<c<`16
ATH0EeMG0451@@0V9RH0=CDe04E5A@1IFET0YJFU0>7Qh@3Ph>00e=CD0;:b/P2:RXX0Fe]K04];B`2B
TY80Ti>C03Ti>@1DE5@0P82009FEU@23Ph<0EUIF02l_;`0o?cl0EEEE07QhN02ATI40YZJV09fMW@1e
MGD0OWin03/k>`0R8R80<c<c05UIF@0Y:BT092@T07MgM`3;bl/0X:2P06MWI`1FEUH0HF5Q04E5A@1Y
JFT0QHF50:RXZ032`/80UiNG0;2`/03De=@0`l?30:BTY02MWId0W9bL09:BTP1/K6`0UIFE0:>SX`2K
Vi/0;2`/024Q8@0[:b/0BTY:071`L002ooooo`0009/0RXZ:079bLP1aLG40CTi>09RHV00i>CT0@410
05IFEP1@D500Ti>C0:2PX00g=cL0;Bd]04e=C@1SHf<0;2`/02l_;`0L71`0EEEE04U9B@0G5aL0;2`/
01dM7@0];Bd0HF5Q01dM7@1HF5P0:2PX01dM7@0Z:RX0BDU905YJFP0T92@0<c<c02h^;P0[:b/0ATI6
05MGE`0I6AT0AdM706][J`0Z:RX0:2PX06YZJP0c<c<0@d=303Hf=P1iNGT0EEEE03dm?@23Ph<0Bd];
03<c<`1GEeL0A4A407QhN01ADE40Kfm_06EUI@1@D500?clo03Hf=P16ATH0H61P04m?C`0S8b<0A4A4
04m?C`0i>CT0D51@092@T01FEUH08b<S0451@@1GEeL0:2PX05EEE@1eMGD0=3@d024Q8@1MGEd0BDU9
05EEE@1cLg<0CTi>034a<@1YJFT0>CTi04Q8B01OGel0Ng]k02d];@1YJFT0EeMG02l_;`1_Kfl0UIFE
05=CD`1]KFd0M7Ad08:2PP1]KFd0Hf=S0=7Ad@1ZJVX0>3Ph06i^KP20P800V9RH04M7A`2DU9@0^[Zj
08V9R@0j>SX0LW9b03lo?`1nOWh0Lg=c04Y:BP1VIVH0D51@08J6QP29RHT0DE5A05QHF01YJFT0EeMG
06m_K`2BTY80BTY:07IfMP1LG5`0ADE5055AD@1MGEd0ADE506a/K01dM7@0>c/k04e=C@1MGEd0AdM7
0:ZZZP1JFUX0GEeM0492@P0i>CT0RXZ:06m_K`1FEUH0DU9B04Q8B01RHV80`/;208^;R`0203@d=02d
071`L00a<C40LW9b04=3@`23Ph<0OWin03lo?`18B4P0Y:BT08n?S`1^KVh0=cLg05IFEP1eMGD0BDU9
08V9R@1FEUH0IFEU0861P@1KFe/0G5aL0:n_[`2<S8`0De=C09ZJVP1RHV80<c<c04Y:BP2DU9@0TI6A
06EUI@29RHT0Shn?07YjNP19BDT0HV9R08n?S`1oOgl0Lg=c0<G5a@1aLG40=cLg08b<S01GEeL0<30`
03/k>`1@D500>SXj07IfMP2EUID0=3@d05iNGP1fMWH0ADE507MgM`1CDe<0?Cdm03lo?`1@D5007alO
0:n_[`2YZJT0HV9R03Hf=P24Q8@0@T9207=cL`1fMWH0>SXj03dm?@2:RXX0BDU907YjNP1>CTh0KVi^
08>3P`2IVIT0I6AT07moO`1LG5`0TI6A04U9B@16ATH0RHV904M7A`18B4P0IfMW04U9B@1IFET0Ogmo
06MWI`1SHf<0=3@d04E5A@29RHT0=3@d03<c<`1GEeL0K6a/07]kN`1CDe<0DE5A05eMG@0o?cl0=cLg
0:JVYP27QhL0FUYJ092@T022PX80I6AT07EeM@1hN7P0Q8B406e]K@1SHf<0Rh^;05UIF@17AdL0O7al
079bLP13@d<0<C4a07IfMP2=SHd0JFUY08^;R`2=SHd0De=C03Ph>02>SXh0RXZ:03dm?@0l?3`0LW9b
07AdM00k>c/0Y:BT0;2`/01VIVH0Hf=S08j>SP1/K6`0=cLg08N7Q`1mOGd0Bd];06QXJ02/[:`0IfMW
0451@@1nOWh0DU9B04a<C00W9bL0;Bd]05eMG@1ADE40=SHf02HV9P1eMGD0PH6103@d=01?Cdl0Lg=c
0492@P0n?Sh0=cLg02<S8`0M7Ad0?Shn05MGE`1HF5P0NWYj08^;R`1fMWH0HF5Q02DU9@0E5AD04A4A
0P0C4a<0>00@41003Ph>00l?3`0A4A404a<C03Xj>P2[Zj/0?3`l01@D5010@400Kfm_0;bl_01QHF40
NGUi03dm?@10@40061PH010@400A4A4051@D01DE5@0I6AT07alO028R8P0T92@0:RXZ034a<@1CDe<0
KVi^092@T024Q8@0LW9b07inOP3Ng]h0i>CT0=3@d034a<@0Vi^K06m_K`1XJ6P0HV9R03Xj>P0^;Rh0
71`L01HF5P0E5AD0@D5108^;R`1ZJVX0/K6a05YJFP2][Jd0TI6A05EEE@12@T805aLG0P0C4a<0100E
5AD0410@01<C4`0C4a<201DE5@1K01TI6@0K6a/071`L04m?C`2][Jd0HF5Q04];B`24Q8@0UIFE0;6a
/@1dM7@0ATI604M7A`0n?Sh0BTY:07=cL`20P800Vi^K0:VYZ@2j^[X0VYZJ04E5A@0[:b/0<30`03Lg
=`11@D40@T9204A4A017AdL0GEeM08^;R`2e]KD0PH6107alO01@D500=cLg02/[:`0_;bl0KVi^08V9
R@0I6AT07QhN04I6AP1VIVH0H61P02TY:@0O7al0<C4a04E5A@1iNGT0Hf=S08F5Q@0O7al061PH04E5
A@1aLG40KVi^07AdM02WYjL0QhN706YZJP1:BTX0IFEU03Hf=P10@400AdM704A4A00X:2P0<C4a020P
801GEeL0Lg=c01lO7`0J6QX07AdM04E5A@1EEED0H61P055AD@1ZJVX0`/;209bLW02:RXX0IVIV059B
DP1<C4`0;Bd]04e=C@1GEeL0Kfm_01TI6@0201/K6`8071`L00H05aLG01`L700d=3@0=3@d07=cL`0G
5aL301DE5@0F01lO7`2ATI40?Shn03lo?`1]KFd0BDU904Q8B014A4@0Kfm_05mOG`1kNg/0=3@d01hN
7P0H61P06QXJ01/K6`0J6QX07QhN01/K6`0Q8B40GemO0861P@80@d=300/0<S8b05]KF`1XJ6P0?Cdm
02/[:`0b<S80TI6A0=KFeP2MWId0A4A402h^;P0203@d=00404];B`29RHT0XJ6Q03<c<`806ATI0280
<S8b03Hf=P0i>CT0@T9204M7A`1TI6@0V9RH06YZJP2QXJ409bLW02DU9@0b<S80LG5a08R8R02[Zj/0
V9RH0;>c/`1BDU8092@T05ADE018B4P0>c/k03Xj>P1=CDd0Bd];055AD@0d=3@0<C4a061PH02i^KT0
h^;R0=cLg02ATI40MWIf0P11@D40301=CDd0_[jn0:ZZZP0^;Rh08b<S02TY:@0k>c/0IVIV09ZJVP2^
[Zh0R8R8075aL@80]kNg02H0Rh^;06EUI@2IVIT0De=C028R8P0T92@0=CDe01hN7P0L71`07AdM07em
O@3>c/h0U9BD04i>CP1?Cdl0EeMG065QH@0h>3P0ADE5079bLP1nOWh0bLW90<k>cP22PX80=CDe03Lg
=`1?Cdl0IfMW07EeM@2RXZ80/k>c0<?3``2=SHd0=3@d04A4A01RHV80GUiN07alO0;ooooo0000l01i
NGT0J6QX04M7A`0o?cl0L71`03Lg=`0n?Sh0DU9B03Ti>@16ATH0K6a/04m?C`0^;Rh0DE5A04E5A@12
@T80IFEU02PX:01=CDd0@D5101dM7@11@D40:2PX024Q8@1DE5@06QXJ061PH00e=CD0;bl_02d];@11
@D40A4A402LW9`1FEUH0=SHf02/[:`0n?Sh0=cLg01/K6`1QHF40Ogmo034a<@0K6a/0IVIV02d];@1B
DU80=cLg061PH01:BTX0D51@0:ZZZP1EEED0:b/[03lo?`0Q8B40HV9R051@D01UIFD0KFe]06YZJP1S
Hf<0@41004a<C01cLg<0BTY:01hN7P11@D40Jf][075aL@17AdL0IFEU06][J`0V9RH0@T9206QXJ00f
=SH0;2`/05]KF`1;Bd/0820P05mOG`1@D500>CTi05]KF`1FEUH0<C4a06IVIP0^;Rh0@41007EeM@1/
K6`0;2`/07alO01[Jf/0>3Ph07inOP2MWId0<c<c05eMG@1^KVh0IFEU05mOG`1YJFT0f=SH06a/K01>
CTh0<30`03Ph>01hN7P0D51@0;fm_@33`l<0S8b<0492@P2KVi/0JVYZ05]KF`1VIVH0FUYJ092@T01;
Bd/0F5QH06YZJP16ATH0IFEU07alO01OGel0JFUY07MgM`0h>3P0NWYj08J6QP1>CTh0E5AD0492@P0`
<300DU9B06=SH`1ADE40De=C04i>CP0e=CD0OWin06MWI`1MGEd0A4A403@d=01gMgL0Jf][06EUI@1H
F5P0Cdm?03Xj>P2NWYh0QhN7038b<P0e=CD0Ng]k03dm?@1FEUH0?clo07inOP1[Jf/0GemO04A4A01S
Hf<0IFEU06=SH`0i>CT0F5QH03dm?@14A4@0Ph>306YZJP1hN7P0MGEe034a<@0f=SH0VIVI07inOP1@
D500WIfM08N7Q`1ZJVX0FEUI0:j^[P1GEeL0ATI608J6QP2IVIT0Ogmo04Y:BP1aLG40TY:B05QHF01V
IVH0]KFe08B4Q00n?Sh0R8R806i^KP0c<c<0?Shn04m?C`0g=cL0<30`06IVIP0g=cL0IFEU07QhN00[
:b/0FUYJ065QH@17AdL0D51@06UYJ@0Y:BT0Ogmo09VIV@1OGel0@D5109RHV018B4P0A4A406IVIP15
ADD0Cdm?09jNWP2?Shl0WIfM05UIF@1?Cdl0GUiN07MgM`1XJ6P0OWin06YZJP2ATI40@d=302XZ:P80
ADE506<0>c/k05aLG00d=3@0<S8b04=3@`1_Kfl0EEEE02`/;019BDT0LW9b01XJ6P0N7Qh0<30`0410
@01WIfL0<C4a04M7A`1IFET0?3`l03Lg=`2i^KT0QXJ604M7A`25QHD0UYJF07EeM@1iNGT0MgMg04];
B`1@D500PX:208F5Q@1BDU80ATI607AdM01FEUH0;bl_02d];@1?Cdl0IVIV04U9B@29RHT0VIVI08B4
Q01LG5`0VIVI07MgM`0j>SX0ATI607=cL`1[Jf/0=CDe07YjNP2ATI40DU9B06EUI@2WYjL0G5aL02LW
9`1jNWX0SHf=04Y:BP14A4@0OWin08J6QP2CTi<0^k^k06][J`0m?Cd07AdM02d];@1OGel0FEUI03hn
?P0Z:RX0Q8B4079bLP1/K6`0Jf][051@D01EEED0=SHf02HV9P0S8b<0C4a<0492@P0G5aL06a/K06QX
J01PH600EeMG05QHF01GEeL08B4Q01DE5@0A4A404a<C014A4@0>3Ph00P0@41001P0C4a<05aLG04e=
C@2HV9P0C4a<0861P@80Vi^K00P0=CDe038b<P1dM7@0QXJ6079bLP0h>3P0=CDe03Lg=`80?Cdm01H0
?clo0492@P15ADD0B4Q804I6AP19BDT0DE5A05YJFP1aLG40RXZ:0<30`03MgMd0^KVi0;Zj^P35aLD0
[jn_09NGU`1]KFd0FEUI04a<C01>CTh0De=C0P1GEeL02P1ADE40QXJ609RHV02i^KT0a<C40=7Ad@2n
_[h0W9bL02@T900E5AD201@D50@04a<C00T05ADE01<C4`0E5AD06ATI02/[:`2LW9`0S8b<0;Bd]01m
OGd00P2HV9P0E02WYjL0F5QH03Ph>00c<c<0@d=3059BDP1>CTh0IFEU08:2PP2UYJD0WIfM07inOP2F
UYH0Q8B403hn?P0N7Qh0820P024Q8@0W9bL0=SHf061PH02d];@0`/;20:>SX`2FUYH0Ph>309FEU@24
Q8@0MGEe0;Bd]02YZJT0EeMG03<c<`1:BTX0Cdm?01hN7P0T92@08b<S02d];@0_;bl0MGEe04U9B@1P
H600TI6A065QH@15ADD0GUiN07]kN`2d];@0gMgM0<o?c`1KFe/0;2`/030`<01PH600@d=3030`<00n
?Sh0Cdm?02/[:`0T92@0<C4a0;2`/02SXj<0RHV909BDU01lO7`0XJ6Q09^KV`1^KVh0TY:B0=CDe03>
c/h0HF5Q02XZ:P0H61P06ATI01/K6`0J6QX0;Rh^06=SH`1HF5P07QhN01TI6@8071`L00H07AdM01XJ
6P0o?cl0ATI6096AT@0G5aL301DE5@1N01dM7@1WIfL0;2`/03`l?01TI6@0?3`l04=3@`0j>SX0M7Ad
07=cL`1PH600BDU90410@00f=SH0;Bd]02`/;00];Bd08B4Q02<S8`0n?Sh0UiNG06QXJ01;Bd/0O7al
05IFEP18B4P0KFe]0451@@1>CTh0YZJV0=7Ad@3EeMD0`/;206UYJ@0^;Rh0;2`/02h^;P10@400AdM7
071`L02j^[X0Ph>3061PH025QHD0Q8B406MWI`1/K6`0Hf=S08n?S`2l_;`0RXZ:030`<00O7al092@T
04i>CP2OWil0RXZ:075aL@22PX80Bd];01LG5`0F5QH07QhN05IFEP1ZJVX0>3Ph0410@01<C4`0AdM7
069RHP16ATH0FUYJ0:RXZ03=cLd0_Kfm09jNWP1DE5@0C4a<069RHP1`L700TY:B07MgM`1GEeL0@d=3
02l_;`0O7al08R8R03/k>`1hN7P0a<C40<G5a@2`/;00Q8B406=SH`80Ti>C02<0@d=302PX:00S8b<0
7AdM01XJ6P0M7Ad0A4A40:f][@2OWil0bl_;0:JVYP2FUYH0Rh^;05IFEP18B4P0BTY:05MGE`1WIfL0
QhN70:VYZ@0o?cl0:2PX028R8P0Y:BT0OWin05UIF@2=SHd0Rh^;0;6a/@2ATI40QHF507QhN01WIfL0
JFUY03`l?002ooooo`0003/0JFUY06m_K`1mOGd0?clo07UiN@0m?Cd0>c/k07alO022PX80NGUi0:JV
YP1fMWH0;2`/04e=C@15ADD08R8R03lo?`0R8R80@d=301/K6`0J6QX0@D5103hn?P0];Bd0GemO01@D
501;Bd/0@410028R8P1>CTh0JVYZ05iNGP0S8b<0?3`l03/k>`0U9BD0B4Q805UIF@0F5QH0<c<c06][
J`0/;2`05QHF04i>CP0U9BD0?Cdm02XZ:P14A4@0<S8b02l_;`1KFe/0>c/k034a<@1CDe<0>SXj06AT
I00o?cl0MGEe0:FUY@0205eMG@0X04Q8B01>CTh0DU9B030`<00M7Ad0IfMW07UiN@1kNg/0AdM7071`
L01>CTh07QhN05EEE@21PH40ATI6034a<@1:BTX0:b/[02d];@1eMGD0Jf][04];B`1JFUX0@41003`l
?01lO7`0=3@d03Xj>P1QHF40CDe=02PX:025QHD0P82003Ph>01ZJVX0[Jf]03hn?P1OGel0E5AD04e=
C@80IFEU02T0emOG06m_K`1UIFD0B4Q80492@P1gMgL0Kfm_0<k>cP39bLT0Kfm_02<S8`1KFe/0G5aL
04e=C@1<C4`0?3`l05aLG017AdL0GEeM07=cL`11@D40BTY:05IFEP1=CDd0C4a<09BDU013@d<0K6a/
08f=S@1?Cdl0E5AD06IVIP16ATH0CDe=06=SH`1;Bd/0EEEE06IVIP16ATH0YZJV07YjNP0206MWI`3o
059BDP25QHD0S8b<06YZJP1OGel0Jf][04E5A@2ZZZX0J6QX03Hf=P0d=3@0L71`03Lg=`1SHf<0@410
06i^KP1HF5P0HF5Q03hn?P1HF5P0MWIf06i^KP0f=SH0DU9B06ATI014A4@0Lg=c06MWI`1eMGD0Lg=c
05MGE`10@400XZ:R06QXJ01;Bd/0VYZJ08n?S`1]KFd0H61P09jNWP2?Shl0Ph>308b<S02MWId0QHF5
05MGE`1VIVH0UYJF096AT@1SHf<0a<C409^KV`0n?Sh0M7Ad08n?S`0o?cl0EEEE06QXJ00m?Cd0=3@d
07AdM011@D40JVYZ07emO@0o?cl0EEEE05QHF00c<c<0>CTi06QXJ00n?Sh0_;bl0;jn_P1HF5P0>c/k
07AdM01GEeL0B4Q807MgM`0m?Cd0;Bd]06MWI`0g=cL0OWin06a/K01NGUh0OWin09FEU@1PH600MgMg
09VIV@2XZ:P0JVYZ03Hf=P12@T80AdM703`l?01bLW80ATI603Hf=P1ADE40PX:203`l?00_;bl0GemO
06ATI00V9RH0:2PX0492@P19BDT0FEUI01dM7@1QHF40PH6104e=C@0Y:BT0Vi^K0:f][@0g=cL0KVi^
08:2PP17AdL0KFe]07=cL`1LG5`0E5AD05YJFP1lO7`0=cLg04m?C`22PX80O7al04I6AP0X:2P0HV9R
03/k>`0j>SX0Lg=c0:>SX`19BDT0:RXZ07moO`1MGEd0@D5104i>CP1hN7P0K6a/01`L701VIVH0PX:2
06][J`16ATH0PH6104I6AP0O7al0LG5a096AT@1LG5`0DE5A0;Bd]021PH40HV9R09>CT`1QHF40EEEE
03Ph>00n?Sh0L71`06=SH`0e=CD0=3@d09FEU@27QhL0[jn_05EEE@14A4@0=CDe02TY:@0/;2`0EUIF
03@d=00F5QH051@D030`<01cLg<07alO03lo?`15ADD0Bd];059BDP0O7al04a<C01DE5@0C4a<04Q8B
01@D500>3Ph04a<C018B4P0A4A40FEUI09FEU@2VYZH0Xj>S06MWI`0R8R80;Rh^08R8R02LW9`0K6a/
05MGE`12@T80<C4a02PX:00M7Ad06a/K02DU9@0n?Sh09BDU01dM7@0e=CD0IFEU03Lg=`0T92@0BTY:
0<?3``3Cdm<0ZZZZ08F5Q@2EUID0Bd];05ADE032`/80`<3006e]K@18B4P0@T9204];B`1ADE40IFEU
07inOP2TY:@0aLG508^;R`1oOgl0d=3@09jNWP0L71`04A4A01DE5@0A4A404a<C014A4@0E5AD06a/K
00806ATI00D05ADE05eMG@2g]kL0`/;20::RXP02061PH00X0:b/[03>c/h0dM7A09jNWP1nOWh0Fe]K
05EEE@1<C4`0AdM706][J`32`/80VYZJ079bLP1dM7@0JVYZ06UYJ@2LW9`0IVIV04U9B@17AdL0Kfm_
07AdM020P800][Jf0<G5a@3:b/X0U9BD07emO@28R8P0OWin08Z:RP0i>CT0<30`05aLG02=SHd0C4a<
01LG5`0C4a<04A4A010@40806ATI02@0DU9B03Ph>00U9BD0OWin059BDP0O7al0EeMG0:2PX02g]kL0
clo?0;>c/`2ZZZX0?Cdm02XZ:P0T92@0F5QH0492@P0[:b/0>CTi0410@00S8b<09RHV09ZJVP3;bl/0
T92@08N7Q`1FEUH0WYjN07UiN@26QXH0WinO09BDU02YZJT0Ng]k01LG5`0D51@301LG5`0>01/K6`0c
<c<0JVYZ04m?C`0J6QX071`L01XJ6P0M7Ad08B4Q05iNGP1/K6`0/[:b01<C4`0@410201DE5@0>01LG
5`0g=cL0;Rh^02`/;01RHV80>3Ph03De=@0/;2`0NGUi0820P00h>3P0:2PX02LW9`0/;2`202l_;`09
03De=@0l?3`0ADE505QHF02PX:00UiNG0820P01YJFT0@d=30080=SHf0280TI6A0:2PX01lO7`0UiNG
09fMW@2a/K40aLG509RHV00_;bl0:2PX03@d=00Y:BT0=cLg0<k>cP2JVYX0?Cdm03@d=00k>c/0H61P
09VIV@3AdM40Z:RX0;Fe]@1EEED07AdM02LW9`1@D500PH610:FUY@1jNWX0820P05ADE00R8R805aLG
0P0E5AD0A00G5aL0CTi>07]kN`0^;Rh0>3Ph03`l?01^KVh0YjNW0;Vi^@36a/H0`L710<g=c@25QHD0
BDU907inOP2UYJD0Hf=S02`/;00O7al0?3`l065QH@14A4@0>3Ph03dm?@1KFe/0Rh^;0:JVYP2g]kL0
^;Rh06][J`1NGUh0>c/k051@D01;Bd/0:RXZ01`L700I6AT06a/K0451@@1iNGT0EEEE092@T01;Bd/0
<C4a03De=@13@d<0BDU909BDU01aLG40D51@03/k>`1lO7`0FUYJ059BDP1SHf<0Jf][08f=S@1UIFD0
B4Q80:BTY02ZZZX0A4A403`l?01JFUX0LG5a051@D00Z:RX06QXJ0_ooool0003d071`L01EEED0KVi^
03Xj>P1KFe/0;Bd]02TY:@1?Cdl0Jf][06e]K@2DU9@0FEUI03Ph>01dM7@0P82004M7A`1;Bd/0=3@d
06EUI@1WIfL09BDU03De=@0>3Ph07QhN06IVIP0U9BD0@d=30410@00R8R809BDU034a<@1EEED0:2PX
04U9B@0R8R80:BTY061PH01RHV806a/K030`<01PH6008b<S01dM7@1SHf<0>3Ph02d];@0f=SH0Kfm_
05EEE@0n?Sh0Jf][01lO7`0L71`0>CTi03<c<`1RHV80;Rh^03Hf=P1BDU80H61P059BDP12@T80Cdm?
06IVIP0K6a/05aLG0451@@1JFUX0E5AD03Ph>01cLg<0ADE501dM7@0k>c/0GemO02LW9`0V9RH0ADE5
02HV9P0J6QX0ADE504];B`11@D40FEUI0492@P0M7Ad0I6AT02PX:00h>3P0D51@05IFEP0S8b<0Hf=S
08V9R@0e=CD0DU9B0<?3``1WIfL0KVi^05UIF@1MGEd0EUIF06][J`3?cll0S8b<06a/K01=CDd0AdM7
07YjNP1QHF40`L710;>c/`18B4P0=CDe07UiN@1RHV80FUYJ071`L01IFET0MgMg04Q8B01IFET0Shn?
06EUI@1SHf<0LW9b06m_K`16ATH0X:2P04m?C`1^KVh0SHf=04m?C`1FEUH0PX:204m?C`1CDe<0MGEe
05mOG`1HF5P0Ng]k04m?C`2CTi<0NGUi0820P01RHV80CTi>0861P@2<S8`0IfMW059BDP1JFUX0@D51
0:^[Z`1JFUX0=SHf03Ti>@1eMGD0?Shn05QHF00h>3P0QhN709BDU01bLW80C4a<03Ph>01oOgl0L71`
03/k>`1HF5P0GEeM04U9B@28R8P0Lg=c08F5Q@2<S8`0MWIf03hn?P2KVi/0L71`04i>CP2:RXX0SHf=
06IVIP1gMgL0/k>c08n?S`24Q8@0SXj>0:ZZZP2?Shl0FEUI07AdM02YZJT0T92@061PH036a/H0QhN7
04A4A01mOGd0W9bL03Xj>P0^;Rh0D51@03Xj>P0];Bd0KVi^03`l?01LG5`0KVi^0492@P1BDU80GUiN
04=3@`0j>SX0KVi^04E5A@2CTi<0];Bd08>3P`17AdL0R8R805QHF01>CTh0VIVI05ADE00`<300MGEe
03/k>`1eMGD0B4Q805UIF@21PH40UYJF06IVIP1[Jf/0K6a/07inOP1=CDd0=CDe05]KF`15ADD0;Rh^
05IFEP80=SHf05l0JFUY09>CT`1^KVh0ADE504e=C@1LG5`05aLG02PX:01DE5@0Fe]K069RHP0_;bl0
?clo05eMG@19BDT092@T08F5Q@2b/[80@D51065QH@1`L700ATI6065QH@1]KFd0Cdm?05IFEP23Ph<0
Shn?05=CD`0o?cl0H61P05IFEP0[:b/0<C4a051@D01ADE40BTY:06m_K`2ZZZX0QHF505ADE02<S8`0
GemO03<c<`0g=cL0GEeM075aL@0f=SH0LW9b08:2PP1fMWH0E5AD09RHV01DE5@0;2`/05QHF021PH40
<C4a02XZ:P24Q8@0VIVI07emO@37alL0MWIf03lo?`0I6AT0:RXZ05iNGP1GEeL0:2PX02<S8`1NGUh0
KVi^096AT@1kNg/0Kfm_05ADE01FEUH0LG5a03<c<`0J6QX05aLG02TY:@1gMgL0Rh^;01dM7@0G5aL0
>SXj04=3@`19BDT0DU9B024Q8@0C4a<04A4A01<C4`0200h>3P0:010@400>3Ph04A4A05EEE@3;bl/0
ZJVY0:6QX@17AdL07QhN03Hf=P80BTY:00<0:b/[01XJ6P0E5AD00`0C4a<0100E5AD05aLG01TI6@0I
6AT201/K6`0?02h^;P1[Jf/0EeMG02`/;02c/k<0YZJV071`L01cLg<0HF5Q061PH012@T80UYJF08J6
QP1OGel0F5QH00<0FUYJ01D0KVi^06UYJ@1]KFd0NGUi09bLW02][Jd0/K6a08Z:RP1CDe<0=cLg03dm
?@12@T80?clo03Hf=P0i>CT0?Cdm03Ph>00e=CD0;bl_03De=@1OGel00P2^[Zh0B`14A4@09RHV09jN
WP36a/H0aLG50<O7a`2?Shl0L71`06a/K01YJFT0GEeM03hn?P0a<C40E5AD04E5A@0i>CT0ATI607]k
N`1jNWX0X:2P08V9R@2NWYh0TY:B0;Fe]@2m_Kd0clo?0<71`@2m_Kd0X:2P08Z:RP2CTi<0][Jf04];
B`1>CTh0IfMW04I6AP0m?Cd0Fe]K061PH016ATH07AdM01<C4`0D51@04a<C02`/;01SHf<0=cLg09>C
T`25QHD0Fe]K07]kN`1^KVh0Ph>309JFUP2:RXX0IVIV07IfMP1EEED0:b/[02LW9`1OGel0@D5103<c
<`0M7Ad0:RXZ01dM7@1oOgl0A4A402h^;P0d=3@0Fe]K0820P02JVYX0UiNG08:2PP0202TY:@0304U9
B@1?Cdl08R8R00805ADE0P0F5QH02@0M7Ad0?3`l06IVIP10@4006ATI024Q8@0U9BD0;2`/04a<C002
0<[:bP0@04Q8B00P82006ATI03Ph>00/;2`0;Rh^02@T900W9bL0C4a<03lo?`0U9BD0<c<c08^;R`2P
X:00Fe]K06=SH`80IfMW01`0GEeM05YJFP1aLG40R8R809bLW02l_;`0c/k>07inOP15ADD0@D5102`/
;00R8R80:BTY0:>SX`2<S8`0IfMW03Lg=`10@400W9bL0:ZZZP2e]KD0MgMg02TY:@0P82006a/K0492
@P30`<00B4Q80P0G5aL0400E5AD08R8R05MGE`2GUiL0Q8B40:BTY00n?Sh09bLW06i^KP1jNWX0>c/k
03@d=01VIVH07alO038b<P0S8b<401DE5@0@01LG5`10@400QHF50410@00k>c/0?Cdm0:^[Z`3EeMD0
f=SH0<k>cP3Kfm/0]KFe0;no_`3=cLd0I6AT02<S8`8071`L03407alO02XZ:P16ATH0JFUY08B4Q02N
WYh0Shn?0:JVYP2c/k<0TI6A0492@P0N7Qh06ATI02TY:@0a<C40>3Ph01/K6`0N7Qh0=CDe06e]K@1N
GUh0NGUi05eMG@0M7Ad0:BTY02PX:00k>c/0IFEU0:JVYP2GUiL0?Shn034a<@1<C4`0>CTi0492@P1B
DU80M7Ad0;Bd]01mOGd0L71`07emO@1[Jf/0Xj>S092@T02DU9@0Ti>C096AT@2BTY80PH6100;ooooo
0000o`2IVIT0GEeM09:BTP0j>SX0Lg=c05mOG`0_;bl0L71`03dm?@1KFe/0O7al03De=@0N7Qh0>3Ph
04m?C`0g=cL0;Rh^01DE5@1;Bd/0G5aL02<S8`0a<C40=3@d02DU9@1^KVh0:b/[03Ph>018B4P0ADE5
03Ph>00m?Cd0JVYZ02/[:`0k>c/0<c<c03Ti>@1CDe<0I6AT01/K6`0X:2P0FEUI020P800E5AD0BDU9
02l_;`0T92@08B4Q05EEE@1>CTh0>CTi06m_K`1>CTh0;bl_0410@00j>SX0GemO06QXJ01BDU80IfMW
07IfMP1XJ6P0?clo05UIF@1]KFd0FEUI02l_;`0o?cl0MgMg06][J`10@400GEeM03lo?`0V9RH0@D51
069RHP0U9BD09bLW04E5A@0W9bL07AdM04M7A`1CDe<0>SXj05MGE`1WIfL09bLW07moO`0c<c<0>3Ph
05UIF@1/K6`0<S8b06ATI022PX80>3Ph03lo?`30`<00IfMW08B4Q01cLg<0KFe]05eMG@1HF5P0a/K6
06=SH`1QHF40EeMG04Q8B021PH40BDU90:^[Z`3:b/X0LG5a03`l?01jNWX0EeMG04a<C01cLg<0G5aL
07UiN@15ADD0Lg=c08Z:RP1WIfL0G5aL07MgM`1aLG40C4a<09VIV@1<C4`0IVIV07UiN@18B4P0HF5Q
06YZJP1?Cdl0JFUY08>3P`1:BTX0Fe]K06ATI00g=cL0WIfM051@D01RHV80C4a<0451@@22PX80L71`
05EEE@1_Kfl0EUIF059BDP2k^k/0PH6103@d=00m?Cd0L71`030`<01TI6@0@T9206UYJ@1kNg/0F5QH
0492@P11@D40TI6A059BDP15ADD0JVYZ059BDP1;Bd/0UiNG05mOG`1XJ6P0NWYj05QHF016ATH0W9bL
08^;R`1EEED0TI6A07moO`1=CDd0GemO08b<S01jNWX0HF5Q07emO@2f][H0Jf][03Hf=P1OGel0QXJ6
07QhN01IFET0^k^k07=cL`0a<C40HV9R07moO`0c<c<0<S8b04e=C@0k>c/0BDU909:BTP1:BTX0I6AT
07IfMP0f=SH0FUYJ051@D014A4@0=CDe05QHF00e=CD0UiNG0:NWY`1XJ6P0@41008b<S01DE5@0?Shn
06m_K`1MGEd0;bl_07IfMP0l?3`0Ng]k06][J`14A4@0L71`09NGU`1hN7P0MgMg0820P02BTY80MGEe
04E5A@0m?Cd0GEeM04Q8B01VIVH0HV9R02/[:`1>CTh0SHf=0861P@1ADE40EEEE06e]K@12@T809BDU
02h^;P00EP13@d<0J6QX02/[:`1?Cdl0K6a/069RHP0a<C40Q8B40<K6aP19BDT0CDe=08V9R@1XJ6P0
KFe]06m_K`1QHF40BDU905EEE@1kNg/0FUYJ04A4A01[Jf/0RXZ:05EEE@0M7Ad0@d=303lo?`0R8R80
EeMG0:RXZ021PH40DE5A08f=S@1XJ6P0ATI603Ph>01KFe/0RHV90410@01KFe/0RHV904m?C`0e=CD0
Lg=c05ADE00[:b/0GEeM07YjNP1BDU80=3@d0:ZZZP2ATI40Kfm_0<_;b`1^KVh0GEeM01dM7@0Q8B40
Fe]K055AD@0`<3009bLW07alO01dM7@0[Jf]06ATI01?Cdl0De=C06i^KP1aLG40>c/k04i>CP1KFe/0
FEUI04m?C`1TI6@0DU9B028R8P0C4a<0:RXZ04E5A@1<C4`0FEUI01TI6@0B4Q80410@0P0A4A4200h>
3P0<04=3@`2e]KD0eMGE0<C4a02e]KD0TI6A03dm?@1VIVH0;2`/02/[:`0D51@04a<C0P0@41001@0A
4A4051@D01XJ6P0K6a/06QXJ00805aLG02005ADE01TI6@0O7al0B4Q809VIV@37alL0GUiN02h^;P0n
?Sh0OGem08j>SP2FUYH0<c<c034a<@0H61P06QXJ024Q8@0^;Rh0>SXj06ATI01WIfL0WinO0:RXZ02N
WYh0bLW905EEE@0W9bL0OGem038b<P0N7Qh06ATI01HF5PP05ADE00/0?clo04Y:BP1RHV80@T9205IF
EP35aLD0TY:B07UiN@0O7al06a/K01PH600301DE5@16014A4@0H61P0V9RH06YZJP1HF5P0E5AD09fM
W@2`/;00_kno09BDU02>SXh0WinO0:j^[P2k^k/0bl_;0861P@1KFe/0NWYj051@D01_Kfl0;2`/020P
800l?3`0HF5Q030`<00K6a/071`L02LW9`0o?cl0A4A402LW9`0C4a<09RHV0:FUY@2GUiL0[:b/0:JV
YP1HF5P0HV9R05iNGP1UIFD0=SHf04=3@`1IFET0A4A405ADE01PH600?3`l02DU9@1`L700AdM7030`
<01>CTh0JVYZ09BDU01LG5`0EUIF05=CD`2FUYH0HV9R04A4A01CDe<0<30`01<C4`0E5AD061PH02@T
901VIVH0I6AT02XZ:P805ADE02H06ATI02DU9@12@T80M7Ad03/k>`0i>CT0=cLg05YJFP2TY:@0e]KF
0:BTY01OGel0U9BD05]KF`1hN7P0@41002TY:@0R8R8092@T04I6AP2/[:`0Q8B40;Ng]`3;bl/0clo?
07UiN@1^KVh0HF5Q05]KF`1BDU80D51@05=CD`1MGEd0K6a/0820P02c/k<0[:b/04=3@`80:BTY00L0
92@T08N7Q`2HV9P0FEUI028R8P0K6a/0<S8b0080_kno01X0^[Zj0<;2`P2`/;00Ph>303Hf=P11@D40
UiNG0492@P0K6a/0:RXZ03Xj>P10@400?Cdm03Xj>P1VIVH0][Jf0861P@1bLW80De=C01dM7@0E5AD0
7QhN04Q8B00[:b/07AdM038b<PD05ADE00l05QHF04Y:BP2=SHd0A4A4038b<P1iNGT0d=3@0<;2`P2[
Zj/0TI6A0=3@d03=cLd0IVIV01dM7@0E5AD00P0K6a/0<@0M7Ad08R8R02h^;P10@400NGUi09jNWP1C
De<0H61P08Z:RP1YJFT0;2`/01TI6@0F5QH071`L01/K6`0g=cL0@T92034a<@1@D500Ng]k06QXJ02B
TY809bLW02`/;00b<S80@410051@D01oOgl0TY:B09NGU`1<C4`0<C4a06YZJP0g=cL0>3Ph04e=C@1a
LG40Zj^[08Z:RP1TI6@08B4Q02LW9`2>SXh0XZ:R04a<C00f=SH0<S8b03<c<`1PH6000_ooool0000S
08n?S`1DE5@0Ti>C03Ph>01fMWH0MGEe03Lg=`2>SXh0@T9206][J`2FUYH0Kfm_03<c<`17AdL0IFEU
03Ph>013@d<0=3@d055AD@1FEUH09RHV02TY:@0R8R809BDU06IVIP0U9BD0<c<c04=3@`0d=3@0?Cdm
0410@01KFe/0;Rh^03/k>`15ADD00P1BDU801`1FEUH06ATI02TY:@1BDU80?Cdm01LG5`1@D5000P0l
?3`01`0g=cL0GemO05YJFP18B4P0T92@06][J`0l?3`00P18B4P04@1GEeL0M7Ad051@D01TI6@0GEeM
03dm?@0d=3@0GemO071`L01BDU80:BTY04E5A@1MGEd0?Cdm03`l?01[Jf/0GemO0080=cLg01X0MWIf
03hn?P0e=CD0HV9R05MGE`0P8200A4A4069RHP10@400KVi^07YjNP0X:2P0M7Ad02/[:`0e=CD0Lg=c
07]kN`0d=3@0IfMW08B4Q00f=SH0<C4a0:BTY01:BTX0KVi^0820P080IVIV0:`0RXZ:0=CDe01IFET0
ATI606ATI01eMGD0TI6A05mOG`2e]KD0^KVi0861P@0d=3@0O7al061PH016ATH0EEEE051@D01kNg/0
=3@d04Q8B01QHF40ADE5065QH@26QXH0GUiN03Lg=`1_Kfl0?Shn06QXJ02:RXX0CTi>04a<C01>CTh0
=CDe05]KF`1WIfL0BDU905=CD`1QHF40=CDe06QXJ01dM7@0NWYj04U9B@1;Bd/0KFe]0861P@1DE5@0
EUIF04M7A`0h>3P0R8R805mOG`0e=CD0<30`06a/K00_;bl0EeMG055AD@1eMGD0NGUi07]kN`19BDT0
8R8R06e]K@1cLg<0=3@d05=CD`1FEUH0@d=30820P01gMgL0N7Qh0861P@1PH600=SHf08V9R@1oOgl0
De=C08Z:RP1eMGD0IVIV07moO`2i^KT0LG5a055AD@1KFe/0];Bd06MWI`19BDT0F5QH09NGU`1kNg/0
DE5A0;fm_@2=SHd0Bd];07emO@2LW9`0@d=302l_;`1;Bd/0@410030`<01`L700AdM705YJFP1kNg/0
;bl_0410@01MGEd0AdM703<c<`1IFET0ATI609jNWP2PX:00HV9R0492@P23Ph<0G5aL0410@01_Kfl0
DU9B03hn?P2EUID0IfMW08N7Q`1JFUX0=cLg06IVIP1bLW80GEeM06ATI02>SXh0S8b<08>3P`17AdL0
=CDe05ADE00X:2P0G5aL06i^KP0c<c<0DE5A08Z:RP1>CTh0>c/k04Y:BP1WIfL0Kfm_02h^;P0e=CD0
B4Q806QXJ00T92@0?3`l04m?C`1WIfL0?clo05QHF02MWId0@T9203hn?P1`L700B4Q806MWI`1dM7@0
Kfm_05aLG01ZJVX0Ph>30P1MGEd0E@2?Shl0UYJF05EEE@0R8R80?Shn03Ti>@0[:b/0@D510;fm_@22
PX80H61P07alO01]KFd0?Shn04];B`1kNg/0V9RH04=3@`1<C4`0S8b<06QXJ00o?cl0T92@075aL@0h
>3P0EeMG075aL@1DE5@0@T9209RHV026QXH0J6QX0<[:bP1_Kfl0GUiN024Q8@0W9bL0De=C03hn?P0a
<C40;Rh^075aL@27QhL0YZJV07=cL`1YJFT0TI6A0;Fe]@0g=cL0WYjN065QH@0d=3@08R8R01`L700H
61P08b<S04A4A00g=cL061PH02@T9017AdL0?clo059BDP0G5aL03`l?00h>3P0C4a<09BDU05=CD`2O
Wil0TY:B07IfMP1gMgL0ZZZZ0::RXP2IVIT0C4a<0492@P0I6AT05ADE01<C4`0A4A403`l?010@400G
5aL00P0E5AD0100G5aL061PH01HF5P0G5aL201TI6@0;01XJ6P1@D500b/[:05]KF`0Z:RX0=3@d05eM
G@1^KVh0EEEE075aL@0Z:RX00P0F5QH04P0O7al0:RXZ03Hf=P1DE5@0LW9b0;jn_P3@d=00/k>c06a/
K01kNg/0<c<c04a<C00D51@05ADE014A4@0E5AD04a<C01DE5@8051@D100E5AD0200F5QH07alO03Ph
>022PX80I6AT0:JVYP1TI6@0?Shn1@0E5AD07@0D51@04A4A02LW9`1KFe/0<c<c02/[:`0d=3@0Ti>C
06UYJ@2=SHd0F5QH05YJFP26QXH0Z:RX09>CT`2>SXh0NWYj04i>CP1;Bd/0>SXj03Ti>@1FEUH061PH
02<S8`1NGUh0=3@d024Q8@0I6AT07AdM00806a/K0240;Rh^04=3@`1^KVh0WinO0:FUY@2/[:`0^;Rh
05YJFP1ADE40@T9202HV9P0J6QX071`L02PX:00i>CT0A4A404];B`1EEED0A4A404a<C02SXj<0F5QH
069RHP2YZJT0MWIf05=CD`21PH40WinO055AD@0G5aL0=CDe05EEE@0G5aL00P0C4a<201DE5@1A028R
8P1]KFd0P820034a<@0M7Ad06ATI01dM7@0o?cl0JFUY0:>SX`2:RXX0Ph>30;>c/`2m_Kd0MWIf08>3
P`1VIVH0Fe]K071`L02NWYh0W9bL07moO`1GEeL0?clo08F5Q@3Ogml0a/K607emO@2LW9`0fMWI04U9
B@0g=cL0>CTi03@d=00a<C40:RXZ02h^;P0c<c<0=3@d03/k>`1lO7`0UiNG07YjNP0d=3@0<S8b08V9
R@2GUiL0EEEE01LG5`0E5AD05aLG07UiN@1ADE40JFUY0:2PX02d];@0UiNG08f=S@35aLD0/;2`0;^k
^`2:RXX0@D5103De=@0a<C40>SXj0410@01jNWX0T92@0:f][@3Fe]H0Vi^K028R8P0I6AT05QHF01XJ
6P1DE5@0AdM701XJ6P10@4005aLG00@05ADE02404a<C01DE5@0o?cl0Z:RX05QHF01dM7@0^k^k0:NW
Y`2FUYH0bLW90;Ng]`2YZJT0OWin04A4A00K6a/06QXJ01/K6`0S8b<0@T9206UYJ@1KFe/0DE5A09NG
U`1XJ6P0=cLg07=cL`1GEeL0;2`/01`L700G5aL06ATI01LG5`0R8R800P1EEED07`2;Rh/0K6a/0;6a
/@0/;2`0=CDe06QXJ01=CDd0EeMG07AdM01EEED0>SXj04E5A@1FEUH0J6QX092@T00o?cl0<C4a04=3
@`1gMgL0XJ6Q09:BTP0f=SH071`L02HV9P1_Kfl0<C4a01TI6@0G5aL06ATI02<S8`1]KFd00_ooool0
002R07emO@1DE5@0KVi^03Xj>P1QHF40CTi>03dm?@2DU9@0<c<c04Q8B023Ph<0FEUI03De=@1?Cdl0
CDe=02LW9`1IFET0<C4a04M7A`0i>CT08b<S03Ph>00P820071`L06=SH`0P8200<30`0451@@0Y:BT0
@d=304Q8B01CDe<06a/K04A4A00n?Sh0?3`l06=SH`1>CTh05QHF03hn?P1UIFD0?clo01hN7P12@T80
9RHV03Xj>P0^;Rh0Bd];02h^;P0b<S80EEEE04Y:BP0d=3@0D51@04A4A00j>SX0GemO0492@P20P800
Fe]K051@D00f=SH0De=C069RHP0V9RH07alO051@D01VIVH0DE5A03De=@13@d<0De=C02h^;P1:BTX0
NGUi034a<@0L71`0>SXj04e=C@0W9bL0G5aL07AdM00b<S80Bd];05ADE00];Bd0MWIf03`l?00_;bl0
FEUI06=SH`0Y:BT0HV9R0861P@1<C4`09BDU08V9R@1KFe/0IfMW06QXJ01EEED0IVIV09:BTP3MgMd0
RHV9069RHP19BDT0AdM7071`L01IFET0c/k>0<K6aP1eMGD0<C4a071`L01lO7`0ADE505MGE`1CDe<0
MgMg03/k>`1DE5@0Jf][061PH018B4P0L71`075aL@0f=SH0Shn?04e=C@1GEeL0QHF505ADE01=CDd0
G5aL04Q8B01<C4`0K6a/04];B`1=CDd0I6AT04=3@`1^KVh0NWYj07]kN`1]KFd0LW9b07EeM@2;Rh/0
GEeM05EEE@1NGUh0?3`l08b<S01cLg<0=SHf02d];@20P800@41005aLG01TI6@0KVi^0P1kNg/0AP1B
DU8092@T04];B`1NGUh0=CDe05MGE`1TI6@0@41008^;R`1jNWX0MGEe08f=S@1iNGT0>3Ph08R8R01m
OGd0EEEE08n?S`1mOGd0MgMg08B4Q032`/80RXZ:06QXJ01:BTX0b/[:07moO`1RHV80FEUI09FEU@2;
Rh/0DU9B0=_Kf`2XZ:P0Cdm?07alO02WYjL0FUYJ03De=@1aLG40BTY:02XZ:P1jNWX0EEEE06][J`1a
LG40<C4a03dm?@1EEED0>CTi0451@@1@D500C4a<09fMW@2`/;00CTi>03/k>`2<S8`0MGEe03lo?`20
P800?Cdm02@T901[Jf/0;Bd]05aLG01IFET0?clo07UiN@1dM7@2069RHP0^08N7Q`1gMgL0J6QX03Hf
=P1HF5P0Kfm_03lo?`1/K6`0E5AD03De=@1@D500QXJ608Z:RP1TI6@0EeMG06=SH`1EEED0>SXj03dm
?@11@D40Ogmo04a<C014A4@0DU9B08:2PP14A4@0EeMG0;>c/`1XJ6P0?Cdm08n?S`1WIfL0NWYj096A
T@1ZJVX0IFEU06i^KP1cLg<0>SXj03Lg=`1EEED0SHf=05YJFP0Q8B40>c/k03Lg=`80=SHf0180`<30
09:BTP1XJ6P0KVi^08V9R@1FEUH0?Cdm05YJFP1kNg/0=cLg03dm?@2>SXh0O7al0492@P2ATI40Fe]K
03<c<`1BDU8208^;R`0905ADE01_Kfl0O7al05]KF`3=cLd0ZZZZ06i^KP0W9bL0;2`/0080GEeM02h0
D51@02PX:01fMWH0OWin0;:b/P1TI6@0Cdm?04A4A01LG5`0EeMG08>3P`0`<30071`L01TI6@0G5aL0
4a<C014A4@0B4Q8092@T0492@P0b<S809RHV04];B`1@D500GUiN02/[:`0g=cL0C4a<059BDP13@d<0
@41004Y:BP0Y:BT0F5QH0:6QX@2BTY80YJFU09FEU@1jNWX07alO01@D500E5AD04Q8B01<C4`0>3Ph0
4a<C0`0E5AD201HF5P0P01DE5@0H61P05ADE01HF5P1aLG40IVIV03Xj>P0F5QH05aLG02LW9`17AdL0
F5QH0:f][@2=SHd0GUiN04e=C@1RHV80IFEU05YJFP1FEUH0MgMg051@D01ADE40[Jf]0:2PX01^KVh0
]kNg09:BTP0I6AT05ADE01<C4`0E5AD201<C4`H05ADE0P0A4A401P0J6QX0JFUY0:ZZZP2YZJT0V9RH
03Xj>P805ADE0P0C4a<0:`0E5AD04A4A01DE5@1?Cdl0=SHf01dM7@0T92@0BTY:07UiN@0m?Cd0PX:2
0451@@0U9BD0;bl_04a<C01aLG40EeMG07MgM`1bLW80GEeM04e=C@0m?Cd0HF5Q02/[:`13@d<092@T
01XJ6P0i>CT0<c<c02HV9P0S8b<08B4Q01dM7@0b<S80W9bL06ATI01QHF40Ogmo0<o?c`29RHT0JVYZ
06i^KP1HF5P00P1BDU804`1?Cdl0EeMG05EEE@1ADE40DU9B04];B`1@D500Y:BT0:JVYP2RXZ80T92@
0<W9b@2^[Zh0Jf][03`l?00M7Ad05aLG03Ti>@0^;Rh00P0C4a<0E00@41004a<C01@D500I6AT0<30`
05]KF`1nOWh0>c/k01`L700O7al0D51@05]KF`2DU9@0d];B0<g=c@35aLD0Q8B402d];@0O7al0G5aL
0:BTY01gMgL0Ti>C08B4Q02NWYh0`<300=KFeP3Ogml0bLW905iNGP1@D500WinO0<C4a02_[jl0D51@
0492@P0i>CT0;2`/02LW9`0[:b/09bLW02d];@0d=3@0HF5Q0:2PX01MGEd0WIfM0:j^[P2?Shl0EUIF
02`/;00L71`05aLG04a<C013@d<0=3@d02PX:01HF5P0VYZJ0;Jf]P1cLg<0]kNg0<G5a@2j^[X0VYZJ
06=SH`19BDT0FEUI07IfMP26QXH0b/[:0=gMg@3Bd]80VYZJ0:JVYP2`/;00TY:B08B4Q02<S8`0a/K6
09nOW`0a<C40@41002XZ:P@05ADE01d04Q8B01<C4`0E5AD0OGem0<;2`P2e]KD0eMGE0=cLg034a<@0
];Bd07IfMP10@400@D5106=SH`1aLG40=CDe02HV9P1TI6@0KFe]03lo?`0/;2`0:BTY04E5A@23Ph<0
CTi>06IVIP1?Cdl0<c<c01/K6`0201TI6@0S01`L700Q8B40Bd];08N7Q`1jNWX0[Zj^06ATI00W9bL0
De=C08^;R`23Ph<0GUiN03/k>`0b<S80;Rh^034a<@13@d<0UYJF0;^k^`1TI6@0BTY:079bLP2][Jd0
QHF505aLG00m?Cd071`L034a<@1SHf<06ATI01@D500E5AD05QHF024Q8@1dM7@00_ooool0000[09RH
V01<C4`0Ogmo0410@01ZJVX0Ng]k04];B`2TY:@0AdM705ADE01lO7`0G5aL02l_;`0k>c/0AdM702XZ
:P14A4@09BDU04A4A010@4006a/K02/[:`0S8b<071`L071`L00d=3@09BDU03/k>`0I6AT0=SHf04A4
A01MGEd0;bl_0410@00[:b/08B4Q04M7A`19BDT07QhN02HV9P1@D500;Bd]028R8P0203`l?02^028R
8P0K6a/0Cdm?04a<C011@D40GUiN03@d=00X:2P0?3`l04m?C`0i>CT0EUIF0410@01UIFD0D51@05UI
F@0f=SH0DU9B04M7A`0/;2`09BDU03Lg=`1QHF40C4a<02TY:@1@D500DE5A034a<@0/;2`0H61P02h^
;P0O7al0>SXj03<c<`0L71`0=CDe05MGE`0X:2P0D51@04m?C`0J6QX0GemO038b<P0a<C40E5AD07If
MP0d=3@0F5QH08B4Q01CDe<08B4Q07emO@1_Kfl0KFe]05=CD`1FEUH0@D51092@T03Fe]H0Shn?06AT
I01DE5@0C4a<0820P01jNWX0clo?0<?3``1/K6`0?3`l07=cL`1mOGd0DU9B05]KF`1HF5P0QHF504E5
A@1FEUH0MWIf06IVIP1>CTh0MWIf07]kN`0f=SH0QXJ605YJFP1LG5`0MWIf05EEE@1>CTh0FEUI04M7
A`1?Cdl0P82006QXJ01@D500MgMg04i>CP1[Jf/0LG5a08:2PP1iNGT0Lg=c07UiN@1gMgL0F5QH06YZ
JP1DE5@0?Shn09BDU01/K6`0<S8b04=3@`29RHT0@T92061PH01?Cdl0NGUi0:b/[01eMGD0B4Q802l_
;`13@d<0De=C030`<01LG5`0Fe]K03dm?@2ATI40IVIV05YJFP1oOgl0Kfm_03Hf=P2ATI40FUYJ05EE
E@2JVYX0MgMg075aL@24Q8@0a/K607inOP1;Bd/0B4Q80=OGe`2HV9P0J6QX061PH02KVi/0HF5Q0451
@@1cLg<0K6a/0451@@2EUID0/;2`04e=C@0O7al0?Shn03`l?00g=cL0Jf][0451@@1YJFT0Kfm_034a
<@14A4@0Jf][02DU9@0f=SH0Bd];03Xj>P2;Rh/0Shn?0P0];Bd0K021PH40EUIF0492@P2=SHd0ADE5
02LW9`1bLW80;Bd]05YJFP11@D40DU9B09:BTP2:RXX0MWIf06m_K`2EUID0PH6107YjNP0n?Sh0=cLg
06m_K`17AdL0L71`05UIF@0i>CT0GemO07inOP1iNGT0E5AD05iNGP1HF5P0Hf=S0410@01HF5P0IFEU
08J6QP1ADE40?Cdm0492@P1SHf<06a/K05mOG`2XZ:P0Jf][03/k>`26QXH0EEEE06=SH`1`L700NGUi
06ATI01cLg<0KVi^06=SH`0j>SX0FUYJ08f=S@1DE5@07alO03hn?P1MGEd0B4Q803/k>`2h^;P0UIFE
069RHP1LG5`0TI6A05UIF@11@D40HV9R08Z:RP1EEED0<c<c08j>SP1kNg/0C4a<08N7Q`1UIFD0>c/k
069RHP2LW9`0WIfM05]KF`2e]KD0N7Qh05]KF`32`/80/K6a07=cL`0X:2P0:RXZ06i^KP1IFET0>SXj
03Ti>@2:RXX0PX:20<K6aP1HF5P0>CTi02h^;P0`<300Z:RX09RHV00`<30071`L01HF5P805ADE0P0A
4A405`0>3Ph05ADE03Xj>P1HF5P0J6QX06m_K`24Q8@0GemO02`/;00U9BD09RHV02`/;00[:b/08R8R
01HF5P1[Jf/0QhN70:^[Z`2IVIT0LG5a09>CT`1?Cdl07alO00@05ADE00@05QHF01DE5@0E5AD051@D
0P0E5AD07P0C4a<05ADE01DE5@0M7Ad0M7Ad04I6AP0g=cL06ATI01DE5@0G5aL0820P0410@02b/[80
X:2P07=cL`1OGel0J6QX055AD@0g=cL092@T038b<P1`L700;Bd]03Lg=`2KVi/0OGem0<g=c@33`l<0
FUYJ01dM7@805ADE00<04Q8B01DE5@0E5AD00`0E5AD201<C4`0901DE5@0_;bl0CTi>0:VYZ@33`l<0
YZJV0::RXP0m?Cd05QHF00<04a<C01l04Q8B01<C4`0e=CD0IfMW020P800N7Qh07AdM02l_;`1_Kfl0
?clo096AT@1CDe<0:b/[02TY:@0d=3@0BTY:07moO`1iNGT0ZJVY07QhN010@400FUYJ05=CD`11@D40
9RHV018B4P0C4a<06a/K03De=@0Y:BT08R8R0080820P00T0;2`/08j>SP1eMGD0Fe]K07alO01oOgl0
>SXj06YZJP0W9bL00P0E5AD03`0D51@061PH02PX:00k>c/0<c<c04I6AP1FEUH0O7al0:JVYP3Cdm<0
e]KF0<[:bP39bLT0Cdm?02@T900201TI6@0302`/;012@T805aLG00<05ADE05D04a<C018B4P0A4A40
6a/K030`<01>CTh0RHV903dm?@0K6a/0DE5A06QXJ02n_[h0hN7Q0=KFeP1oOgl0A4A4034a<@1;Bd/0
?3`l06e]K@2g]kL0XJ6Q09FEU@26QXH0YZJV0=CDe03Ng]h0]KFe04I6AP1XJ6P0>SXj02`/;01`L700
_;bl07=cL`0o?cl0>c/k03dm?@0i>CT0=3@d03`l?01HF5P0SHf=09ZJVP2YZJT0bl_;0;Vi^@1;Bd/0
9bLW020P800W9bL0AdM704a<C00`<300;bl_02HV9P0U9BD0JVYZ0<g=c@32`/80W9bL0:>SX`2YZJT0
/[:b0:j^[P31`L40YZJV0410@01MGEd0d];B0:b/[02@T900FUYJ0451@@1KFe/0PX:209>CT`2GUiL0
aLG50<k>cP1mOGd0I6AT03Ti>@0F5QH04a<C00805ADE02X04a<C01DE5@0H61P0DU9B0>7Qh@3Rh^80
h>3P0>7Qh@39bLT0MgMg03dm?@0V9RH0;2`/02h^;P1ADE40QHF50:f][@1jNWX0<S8b02@T900W9bL0
7alO02h^;P0i>CT0Ti>C08J6QP14A4@0=3@d01/K6`0I6AT06a/K03De=@16ATH0L71`09NGU`2k^k/0
P820038b<P1/K6`0Vi^K0;>c/`1WIfL202h^;P0F02/[:`0^;Rh0;Rh^03Hf=P29RHT0a<C40<;2`P31
`L40XZ:R0;Jf]P15ADD0FUYJ06][J`0S8b<0H61P0410@00F5QH05ADE01LG5`0I6AT06QXJ05iNGP;o
oooo0000b`2g]kL0CTi>09NGU`0l?3`0IFEU0:BTY01^KVh0YJFU04M7A`1MGEd0SHf=08N7Q`10@400
?3`l04m?C`0b<S80?Shn03Ph>012@T80H61P02TY:@0/;2`09RHV01hN7P1UIFD0<30`01dM7@0o?cl0
<S8b03@d=00f=SH0IVIV034a<@0n?Sh0>c/k03hn?P13@d<0Cdm?028R8P0P8200@D5103hn?P0U9BD0
>CTi04U9B@0X:2P08b<S05UIF@1OGel0BDU905aLG01;Bd/0>3Ph04A4A01NGUh0@d=306UYJ@1:BTX0
LW9b05eMG@1XJ6P0<c<c05eMG@1XJ6P0B4Q803Hf=P0l?3`0KVi^03hn?P0_;bl0K6a/05=CD`0X:2P0
:RXZ06e]K@0f=SH0<S8b051@D00Y:BT071`L03De=@1JFUX09BDU051@D01GEeL08B4Q06IVIP0U9BD0
<C4a05aLG01gMgL0;Bd]055AD@2>SXh0GemO02XZ:P1eMGD0PH6105iNGP1bLW80LG5a05YJFP28R8P0
eMGE0861P@1ADE40K6a/08J6QP2JVYX0Fe]K0<K6aP39bLT0Rh^;04A4A01cLg<0I6AT065QH@1oOgl0
IFEU07moO`16ATH0HF5Q07YjNP1MGEd0CDe=07inOP1NGUh0?Cdm08j>SP1IFET0GemO08V9R@18B4P0
De=C06ATI012@T80CDe=07IfMP1>CTh0DE5A07UiN@14A4@0SXj>04i>CP1OGel0IFEU05YJFP1jNWX0
L71`05=CD`1ADE40=CDe04Q8B02YZJT0Ogmo03Xj>P0[:b/0L71`02PX:01ZJVX0HV9R05EEE@1[Jf/0
LG5a04Q8B00h>3P0FUYJ055AD@0m?Cd0IFEU06a/K012@T80VYZJ0820P01WIfL0OWin06ATI00n?Sh0
Ti>C07moO`1GEeL0Rh^;05UIF@1VIVH0ZJVY0<W9b@1kNg/0>c/k04E5A@2h^;P0YZJV069RHP22PX80
`/;206][J`12@T80UiNG08>3P`0l?3`0NGUi08V9R@13@d<0820P0080@d=307l0Cdm?08:2PP18B4P0
EUIF08:2PP0R8R80D51@07MgM`0i>CT0:BTY04E5A@0Q8B40O7al08R8R01<C4`0>SXj07YjNP19BDT0
EeMG08^;R`1=CDd08B4Q07MgM`0_;bl0EEEE02TY:@12@T80NWYj06IVIP1[Jf/0GemO09bLW027QhL0
OGem03hn?P0f=SH0IVIV04];B`1/K6`0IVIV0451@@1>CTh0LW9b07moO`1NGUh0DU9B05UIF@1OGel0
:b/[034a<@10@400Kfm_03`l?00Z:RX0>c/k05iNGP0X:2P0DU9B08^;R`1DE5@0@41006YZJP11@D40
Jf][07UiN@1hN7P0JVYZ075aL@1nOWh0Jf][03Ti>@1>CTh0R8R805=CD`0O7al0?Shn05UIF@0h>3P0
=cLg0:b/[01mOGd0EUIF07EeM@2=SHd0EEEE03hn?P1NGUh0Ogmo04Y:BP0g=cL0/K6a092@T01@D500
Ogmo05]KF`0Z:RX0N7Qh0;>c/`2<S8`0IVIV0<C4a01SHf<0>SXj0;2`/02ATI40GUiN02XZ:P0_;bl0
Hf=S03<c<`0A4A40=cLg07]kN`1lO7`0LW9b06ATI00o?cl0>c/k09:BTP2:RXX0IVIV05ADE00l?3`0
5aLG01<C4`0E5AD051@D00<04a<C01T06ATI08>3P`2=SHd0Rh^;07IfMP2d];@0NWYj03`l?00/;2`0
;Bd]01/K6`0X:2P0FUYJ0;fm_@3=cLd0b/[:07emO@0l?3`0Hf=S08b<S01?Cdl0<S8b01TI6@0E5AD0
4Q8B00D05ADE020051@D01<C4`0E5AD05ADE03hn?P1WIfL0?3`l02/[:`0H61P051@D01<C4`0G5aL0
>SXj06IVIP1FEUH0MWIf030`<00O7al071`L01XJ6P0F5QH06a/K03lo?`1CDe<09bLW04M7A`1gMgL0
^;Rh0;bl_01hN7P0DU9B01PH60805ADE01804A4A01DE5@0K6a/07QhN01XJ6P0U9BD0A4A4071`L026
QXH0Q8B40::RXP3AdM40_kno0;Zj^P2;Rh/0<C4a01hN7P0G5aL201DE5@0H01/K6`1fMWH0?Cdm01`L
700Q8B407AdM03dm?@1`L700Cdm?04M7A`18B4P0C4a<03Lg=`16ATH0H61P09BDU02BTY80VYZJ08N7
Q`0n?Sh0:RXZ03Ph>01UIFD05aLG0P0@41003P0C4a<05QHF02d];@0h>3P0=CDe03dm?@1RHV80Shn?
09BDU01ZJVX0R8R803Xj>P1KFe/0A4A40P0D51@05`0C4a<04A4A01<C4`0E5AD07AdM02PX:00P8200
:RXZ024Q8@0^;Rh0f=SH0<O7a`2SXj<0GEeM01lO7`0F5QH05ADE02<S8`1?Cdl0?3`l01DE5@0C4a<0
5aLG00@05ADE07004a<C01hN7P0W9bL0GEeM09>CT`0k>c/0OGem0<;2`P3Fe]H0b/[:0=GEe@1VIVH0
E5AD05mOG`1iNGT0Ng]k08>3P`1YJFT0LW9b07AdM02][Jd0`/;207IfMP2o_kl0`<3005eMG@0R8R80
71`L01/K6`0O7al0;bl_0:6QX@2/[:`0IFEU03Ti>@0d=3@0?3`l055AD@2][Jd0Xj>S0;Vi^@2d];@0
UYJF08R8R01MGEd06a/K028R8P1OGel0DU9B03Hf=P0a<C40:b/[02@T900M7Ad0DE5A0:j^[P26QXH0
Ogmo06m_K`1VIVH0FUYJ05aLG02RXZ80^[Zj0::RXP3Bd]80SXj>04];B`0c<c<0BDU906YZJP1=CDd0
Bd];07IfMP2BTY80W9bL07emO@1XJ6P0MWIf08Z:RP19BDT07AdM020P800];Bd0=cLg04a<C00i>CT0
a/K60=[JfP3?cll0hn?S0>GUi@2j^[X0CDe=01PH600K6a/09BDU02TY:@0^;Rh0BTY:0:NWY`0o?cl0
:RXZ02<S8`0P820071`L01lO7`0R8R80GUiN08>3P`0k>c/0=cLg0P0F5QH0800K6a/0>c/k06i^KP2D
U9@0Zj^[0;Zj^P2GUiL0XJ6Q08n?S`1MGEd0=CDe04e=C@1^KVh0@d=302DU9@0X:2P0:RXZ05mOG`2[
Zj/0[Zj^03Xj>P13@d<0Ng]k0:^[Z`16ATH0E5AD0;Ng]`26QXH0[:b/02l_;`0E5AD05QHF0P0E5AD0
0`0J6QX0C4a<ooooo`01ooooo`000<L0Vi^K04a<C01gMgL0=cLg05iNGP26QXH0R8R80;Bd]00l?3`0
Kfm_09bLW02:RXX0>c/k03lo?`1FEUH0=CDe04I6AP17AdL0@D5106ATI00a<C409bLW02l_;`0O7al0
IVIV038b<P0J6QX0ATI603/k>`0n?Sh0?3`l061PH00C4a<0?clo04m?C`0n?Sh0=CDe04i>CP0O7al0
;Bd]05IFEP1;Bd/0;Bd]03De=@17AdL0;bl_02h^;P1?Cdl0CDe=05EEE@1aLG40IfMW03hn?P13@d<0
AdM70492@P27QhL0?Shn08B4Q01`L700C4a<02DU9@16ATH0Fe]K03lo?`0W9bL0ADE506UYJ@1WIfL0
=cLg04];B`1ADE408B4Q030`<01kNg/0DE5A01/K6`0g=cL0CTi>02XZ:P0a<C40FEUI02@T901QHF40
IVIV020P801VIVH0>3Ph02TY:@1HF5P0LW9b02h^;P19BDT0Shn?04U9B@0R8R80EUIF06YZJP1@D500
GemO05ADE01aLG40QHF50=WIf@29RHT0DU9B03hn?P1?Cdl0Ogmo05ADE02][Jd0_Kfm09RHV010@400
LW9b06e]K@1:BTX0GemO05eMG@2EUID0EeMG055AD@1IFET0=cLg05MGE`2IVIT0S8b<04E5A@1mOGd0
@41006MWI`2=SHd0FEUI04m?C`1GEeL0<c<c06YZJP29RHT0FUYJ04Y:BP1PH600<C4a09nOW`1MGEd0
FEUI05QHF015ADD0Ng]k08b<S01HF5P0De=C0492@P0d=3@0SXj>07MgM`0m?Cd0;Bd]08B4Q00j>SX0
EUIF06=SH`1IFET0Lg=c07YjNP1KFe/0EEEE06UYJ@1^KVh0:RXZ05IFEP1:BTX0>3Ph0861P@1hN7P0
IfMW06][J`1aLG40<30`0861P@23Ph<0DE5A07alO01XJ6P0HV9R075aL@2[Zj/0MgMg04e=C@0[:b/0
WinO0::RXP15ADD0H61P0:2PX01jNWX0AdM709jNWP2?Shl0I6AT0080UYJF05h0I6AT02@T9011@D40
D51@02d];@1bLW80DU9B051@D02:RXX0;Rh^04E5A@21PH40?clo02h^;P1;Bd/0C4a<07emO@2<S8`0
@T9203dm?@1dM7@0JFUY03hn?P1XJ6P0@41002<S8`1^KVh0<S8b05IFEP10@400BDU906YZJP1?Cdl0
FUYJ05aLG02][Jd0M7Ad0820P00`<300=SHf04m?C`0d=3@0JFUY06QXJ01FEUH0BTY:08:2PP2@T900
Lg=c04i>CP1;Bd/0IFEU0410@00f=SH0@T9207MgM`1GEeL0:BTY0492@P1jNWX0=3@d05iNGP2DU9@0
O7al055AD@1[Jf/0MgMg06e]K@1mOGd0QHF505iNGP22PX80S8b<07AdM00g=cL0AdM708b<S01BDU80
8B4Q04i>CP1LG5`0>c/k03@d=02DU9@0MgMg01LG5`1>CTh0VIVI06a/K00m?Cd0FEUI06i^KP0c<c<0
9RHV0P1iNGT06`1:BTX0MWIf055AD@0D51@0EEEE09:BTP21PH40M7Ad0<G5a@20P800ADE50:n_[`2M
WId0GUiN02LW9`0c<c<0E5AD0492@P0g=cL0:BTY06m_K`28R8P0Fe]K04a<C01KFe/0/K6a09ZJVP02
05mOG`05030`<00i>CT0>c/k02DU9@0H61P00P0E5AD201<C4`0H01HF5P1OGel0K6a/05ADE02DU9@0
YjNW09BDU02l_;`0W9bL08F5Q@1oOgl0QhN709^KV`3<c<`0_Kfm0;Ng]`2f][H0De=C038b<P1KFe/0
KFe]02@T900M7Ad05QHF2P0E5AD0401IFET0HF5Q03Lg=`0/;2`05ADE01<C4`0@41009RHV06EUI@0i
>CT0>SXj04M7A`0V9RH071`L01XJ6P0I6AT201`L701901TI6@0];Bd0:2PX01lO7`19BDT0UiNG0:6Q
X@2;Rh/0K6a/05IFEP0M7Ad05ADE01/K6`0U9BD0;bl_0410@01DE5@0F5QH05EEE@12@T80;Bd]01/K
6`0k>c/0Y:BT0;Rh^037alL0SXj>07moO`1JFUX0I6AT0492@P0U9BD0Fe]K05=CD`0W9bL08B4Q02d]
;@0/;2`0GEeM04m?C`0e=CD071`L01DE5@0V9RH0FUYJ07=cL`28R8P0[Jf]0;2`/022PX80KFe]06YZ
JP1PH600JFUY0;>c/`1dM7@0?Cdm0492@P0d=3@0<C4a04=3@`1XJ6P0GemO0492@P1IFET0M7Ad0:j^
[P2[Zj/0X:2P04i>CP1SHf<05aLG014A4@0201DE5@0D01@D500C4a<04a<C01<C4`0K6a/0;Bd]028R
8P0W9bL0:b/[0;Ng]`1hN7P0Fe]K06UYJ@0e=CD06a/K01DE5@0R8R80EeMG034a<@0D51@201LG5`0f
01DE5@0F5QH05ADE014A4@0B4Q806ATI020P800];Bd0Ph>30=;BdP2j^[X0TY:B08f=S@1TI6@0][Jf
092@T01VIVH0PX:2096AT@24Q8@0GEeM06UYJ@2PX:00[jn_0:b/[02GUiL0^;Rh0<[:bP3=cLd0:b/[
01DE5@0H61P06QXJ04e=C@1CDe<0BDU908j>SP39bLT0^k^k06m_K`1BDU80JVYZ0;:b/P33`l<0Ti>C
09bLW01JFUX0De=C071`L017AdL0LG5a06EUI@10@400=SHf0P0/;2`0500Q8B409BDU04a<C02BTY80
GemO06a/K01ADE40@d=30410@00k>c/0GUiN0<g=c@37alL0JFUY03<c<`0X:2P0;2`/03De=@13@d<0
JFUY0P24Q8@06P1CDe<0<C4a03Ti>@1GEeL0Jf][075aL@2n_[h0TY:B05]KF`14A4@0?Shn06i^KP32
`/80ZZZZ09BDU02n_[h0a<C40=cLg02a/K40Z:RX024Q8@0E5AD092@T05=CD`15ADD0@D510P1gMgL0
:`16ATH0;bl_01dM7@0L71`07AdM01/K6`0U9BD0MgMg05iNGP0m?Cd05QHF01LG5`0O7al0@d=307Mg
M`2k^k/0`L7108n?S`35aLD0a<C404U9B@0R8R80820P02DU9@0j>SX0De=C04A4A00[:b/0C4a<07Qh
N02>SXh0MGEe02`/;00Y:BT0<S8b06=SH`1NGUh0Cdm?0::RXP3De=@0cLg=05EEE@0L71`00`0E5AD0
0`0F5QH0=3@dooooo`01ooooo`0000@0UiNG04];B`1aLG40?clo0P1GEeL0X`1YJFT0ZJVY04=3@`1A
DE40GEeM04e=C@0e=CD0I6AT06=SH`0P8200ADE504A4A00m?Cd0@41002<S8`0`<300Bd];02@T9024
Q8@0AdM7010@400e=CD08b<S03lo?`1QHF40L71`03Ti>@0W9bL0=3@d02DU9@1?Cdl0CTi>02@T900J
6QX0EUIF04M7A`0k>c/0BTY:03Lg=`0^;Rh0;Bd]05UIF@1:BTX0AdM7055AD@1<C4`0AdM706IVIP1U
IFD0?Cdm069RHP0`<300LW9b075aL@1WIfL0=SHf0410@01DE5@0=3@d02/[:`0g=cL0IfMW06EUI@0b
<S80Bd];06ATI00h>3P0820P07AdM01GEeL0820P030`<016ATH09bLW04a<C01YJFT0?Shn051@D016
ATH07AdM06YZJP1MGEd0;Bd]055AD@1[Jf/0:2PX05ADE028R8P0KFe]02HV9P1QHF40M7Ad05mOG`1W
IfL0C4a<05]KF`1JFUX0e]KF08f=S@1QHF40?Shn051@D01VIVH0F5QH0<O7a`3De=@0ZZZZ03Ph>01h
N7P0Jf][04];B`1?Cdl0BDU908:2PP1VIVH0EUIF05EEE@19BDT0@d=306][J`1kNg/0?Shn07AdM012
@T80D51@07]kN`1EEED0CDe=05=CD`0h>3P0BDU906EUI@1FEUH0@41005mOG`0n?Sh0K6a/05YJFP1D
E5@0JVYZ05QHF01WIfL0OWin05YJFP1LG5`0DE5A03hn?P2DU9@0O7al03Ph>00a<C40Ogmo04E5A@1S
Hf<0NGUi05IFEP1VIVH0G5aL0451@@1<C4`0EUIF05iNGP0Z:RX00P1DE5@02`0j>SX0P820075aL@1L
G5`0KFe]06i^KP0m?Cd0S8b<08N7Q`1EEED0PX:20080LW9b07@0N7Qh0;Rh^01_Kfl0E5AD03hn?P2/
[:`0]KFe06EUI@1RHV80Y:BT08f=S@1FEUH0_[jn0<71`@1_Kfl0XZ:R09ZJVP1iNGT09BDU0451@@1J
FUX0:b/[079bLP1TI6@0D51@0820P00l?3`0BTY:07AdM00d=3@0;Rh^04m?C`1JFUX0JFUY08b<S01]
KFd0Bd];07]kN`1mOGd0?clo06MWI`1CDe<0=cLg08N7Q`24Q8@0UIFE07UiN@1BDU80Q8B405QHF01T
I6@0DU9B0<k>cP2/[:`0VYZJ0451@@0e=CD0Cdm?0410@01iNGT0Ogmo061PH01=CDd0KVi^08n?S`1`
L700A4A404I6AP1UIFD0C4a<03@d=012@T80KFe]05ADE00a<C40Bd];08R8R00];Bd0IfMW07moO`1l
O7`0DU9B071`L01IFET0H61P08Z:RP1/K6`0Hf=S09bLW02FUYH0LG5a034a<@11@D40K6a/02PX:00W
9bL0IVIV06a/K00d=3@0;bl_079bLP1jNWX0EeMG06MWI`2XZ:P0JFUY03Ti>@1_Kfl0Ph>306EUI@0`
<300[:b/07]kN`1:BTX0J6QX06UYJ@80MgMg0400[Zj^09BDU01lO7`0eMGE0::RXP18B4P0UYJF0:^[
Z`1GEeL0D51@05=CD`1/K6`0MGEe05QHF00];Bd0O7al09VIV@2HV9P0^KVi0=?Cd`2e]KD0S8b<07Mg
M`1_Kfl0?3`l02h^;P0_;bl0=CDe02/[:`0E5AD03Ph>00l?3`0O7al0<S8b02DU9@0I6AT071`L04Q8
B020P800SXj>096AT@2WYjL0/;2`071`L01KFe/0GEeM08B4Q029RHT0a/K60<71`@2LW9`0H61P028R
8P26QXH0S8b<05YJFP1<C4`0>CTi02l_;`0W9bL071`L01LG5`0C4a<051@D0P0E5AD01P0Q8B40Fe]K
04i>CP0c<c<08B4Q01PH60805ADE01H0AdM705mOG`0U9BD0:BTY03dm?@0[:b/05aLG01HF5P0G5aL0
;bl_01lO7`0E5AD04a<C014A4@0E5AD06a/K0820P01fMWH0U9BD08>3P`22PX80UYJF0P1PH6001P1>
CTh0?Shn03<c<`0P820061PH01HF5P805ADE01@06a/K03Hf=P1]KFd0/[:b09bLW02KVi/0QHF509NG
U`25QHD0MWIf09bLW02ZZZX0EEEE04I6AP0i>CT0=SHf03Xj>P12@T807AdM01TI6@805ADE01`0:b/[
03hn?P1`L700Rh^;09ZJVP2g]kL0RHV9079bLP2n_[h0UiNG0:>SX`2ZZZX0LG5a065QH@1OGel0FUYJ
07EeM@1]KFd0P82009NGU`2ZZZX0ZJVY09^KV`2^[Zh0_[jn0<G5a@2EUID0<C4a0P0E5AD05@0A4A40
5ADE01<C4`0A4A40410@014A4@0E5AD08b<S04A4A00W9bL0:b/[09jNWP1jNWX0Fe]K0;:b/P2YZJT0
L71`059BDP1CDe<0K6a/02XZ:P0201DE5@0O01PH600E5AD05aLG01DE5@0C4a<05ADE01HF5P0M7Ad0
:2PX079bLP33`l<0G5aL05=CD`1ADE40@T920:^[Z`3MgMd0e=CD0;fm_@2TY:@0/[:b08j>SP1mOGd0
GUiN04m?C`13@d<0;Rh^09VIV@2m_Kd0aLG503hn?P0201/K6`1O024Q8@0[:b/0<c<c03lo?`1FEUH0
PX:20;Bd]02DU9@0<S8b06MWI`2f][H0Jf][08R8R01XJ6P0Fe]K079bLP2FUYH0bLW90:FUY@2JVYX0
YZJV0:>SX`2g]kL0XJ6Q07EeM@1SHf<0RHV90:2PX02ATI40=SHf01hN7P0L71`0:b/[03@d=00e=CD0
Zj^[07=cL`0];Bd0:BTY02HV9P0/;2`0<S8b02h^;P1?Cdl0NWYj0492@P0S8b<092@T0451@@1]KFd0
LG5a08R8R025QHD0YJFU0<O7a`2FUYH0T92@0<S8b02UYJD0MgMg096AT@1jNWX0`l?30<c<c02g]kL0
W9bL0861P@0U9BD05ADE02@T9011@D40Kfm_0:NWY`2UYJD0L71`02/[:`0L71`06a/K01PH600L71`0
7QhN051@D01RHV80>c/k01LG5`0J6QX0;Rh^04];B`25QHD0_;bl09NGU`26QXH0K6a/08n?S`0N7Qh0
0P0M7Ad06@0Q8B407AdM02XZ:P0^;Rh0@d=305mOG`1HF5P0TY:B05UIF@0/;2`0:RXZ03@d=015ADD0
LW9b05UIF@2n_[h0eMGE0<c<c037alL0NWYj02DU9@0C4a<05ADE01/K6`0X:2P00_ooool0000m0;Vi
^@1<C4`0RHV904=3@`1KFe/0MgMg075aL@2m_Kd0BDU905mOG`1RHV80Jf][02l_;`11@D40IfMW034a
<@0_;bl0:BTY04U9B@1HF5P0;Bd]01lO7`0T92@05QHF06e]K@19BDT05ADE03dm?@0M7Ad07QhN02l_
;`1OGel0>c/k02<S8`0[:b/061PH02d];@1IFET0<c<c01`L701?Cdl0>c/k02LW9`0h>3P0@D51028R
8P0M7Ad0C4a<05=CD`1=CDd0FUYJ03De=@0g=cL0AdM706EUI@0o?cl0EEEE03Ph>01UIFD0IfMW06i^
KP0203`l?01]04m?C`1>CTh0@T9203Ph>01NGUh0EeMG02XZ:P14A4@0DE5A02TY:@0L71`0KFe]04E5
A@0P8200;Bd]04Q8B00S8b<0;bl_04m?C`0Y:BT0Cdm?04e=C@0P8200FEUI05QHF00W9bL0EEEE061P
H00b<S80?3`l07IfMP1YJFT0:RXZ06ATI01jNWX0Kfm_06a/K01?Cdl0EEEE04M7A`3<c<`0WIfM06YZ
JP0l?3`0FEUI07inOP1TI6@0X:2P0=7Ad@2GUiL0@D5105eMG@1aLG40C4a<05]KF`1FEUH0P82006a/
K01CDe<0Cdm?04];B`1<C4`0Ogmo08f=S@12@T80NGUi05]KF`1FEUH0O7al069RHP12@T80Cdm?03dm
?@1BDU80O7al06EUI@0o?cl0GUiN04e=C@1eMGD0H61P04m?C`1dM7@0IFEU06IVIP1lO7`0Hf=S05QH
F00_;bl0<30`07UiN@1WIfL0;2`/02l_;`1jNWX0>SXj061PH01eMGD0HV9R09JFUP1ZJVX0BDU904M7
A`1KFe/0ADE505IFEP2MWId0Ogmo03/k>`020861P@2S05ADE01kNg/0Q8B403De=@1WIfL0HV9R05MG
E`2GUiL0T92@06ATI01fMWH0a<C406MWI`11@D40=cLg07moO`2VYZH0I6AT06IVIP2PX:00KVi^02DU
9@1VIVH0Rh^;059BDP2OWil0S8b<05aLG00b<S80IVIV06ATI00U9BD0G5aL04Q8B02EUID0Shn?03Lg
=`1>CTh0HF5Q02`/;01IFET0IfMW051@D013@d<0O7al05eMG@11@D40S8b<06MWI`0_;bl0NGUi04E5
A@0k>c/0MgMg069RHP1oOgl0Hf=S04i>CP2@T900MGEe04e=C@0I6AT0@d=306EUI@2MWId0Jf][03hn
?P1?Cdl061PH065QH@29RHT0EEEE04i>CP1SHf<0KFe]04=3@`1?Cdl0Ogmo08f=S@1ADE40=cLg04A4
A01UIFD0<30`03dm?@1`L700PX:202d];@1gMgL0Ng]k04m?C`17AdL0QHF505eMG@1FEUH0T92@06=S
H`1?Cdl0Zj^[0:2PX01`L7009BDU03lo?`1WIfL0:b/[01hN7P0n?Sh0ATI6024Q8@0d=3@0N7Qh0820
P01NGUh0JVYZ0:j^[P0e=CD0:RXZ05MGE`2?Shl0K6a/03<c<`2`/;00GEeM03`l?01lO7`0NGUi09FE
U@2<S8`0];Bd05eMG@28R8P0d=3@09VIV@10@400Vi^K0:f][@15ADD09bLW0410@01[Jf/0MgMg055A
D@0i>CT0Ph>30820P01<C4`0_;bl0:FUY@1UIFD0KFe]079bLP1[Jf/0CDe=03hn?P0/;2`09BDU038b
<P1@D500DU9B03Hf=P0V9RH071`L01LG5`0201DE5@0_01PH601OGel0]kNg0:BTY02UYJD0Zj^[0:2P
X01iNGT0Hf=S0:f][@3:b/X0Ogmo09jNWP24Q8@0QhN708>3P`1XJ6P0Jf][05UIF@1DE5@0Bd];04a<
C01@D500EUIF04i>CP0j>SX09BDU018B4P0A4A40Bd];051@D00m?Cd0;2`/02DU9@0H61P05ADE02HV
9P1VIVH0?Shn01lO7`0M7Ad0ATI602LW9`0I6AT07AdM04A4A00Q8B400P0E5AD03P0A4A4051@D01DE
5@0G5aL0Q8B4055AD@26QXH0WinO05IFEP2`/;00XZ:R02HV9P0E5AD051@D0`0E5AD201<C4`0d01LG
5`0i>CT0IfMW08N7Q`0^;Rh0;Bd]04E5A@1HF5P0MWIf08:2PP2b/[80c/k>0<_;b`2_[jl0Rh^;051@
D01KFe/0Bd];020P800Y:BT0820P01TI6@0V9RH0>SXj038b<P0k>c/0Ng]k079bLP1oOgl0SHf=0;2`
/02g]kL0VIVI07EeM@1JFUX0CTi>04e=C@1:BTX0=SHf04m?C`1FEUH0JFUY07MgM`2FUYH0bLW90;Rh
^02QXJ40T92@0:FUY@31`L406a/K01@D50<05ADE0P0>3Ph04@0A4A404a<C01<C4`0E5AD0ATI605mO
G`0_;bl0YjNW08j>SP1YJFT0`<3006m_K`1gMgL0Q8B40:VYZ@2_[jl0:b/[00H05ADE02l051@D01DE
5@0F5QH07AdM02DU9@1PH600U9BD04E5A@1<C4`0?Cdm03lo?`2HV9P0aLG509fMW@2BTY80SXj>038b
<P0N7Qh06a/K01TI6@0N7Qh0?Cdm05ADE01/K6`0XZ:R0<30`02YZJT0<c<c03`l?00X:2P07alO02<S
8`0T92@0:RXZ03dm?@1VIVH0TY:B061PH01oOgl0LW9b07alO02MWId0CTi>04Y:BP2EUID0dm?C0>7Q
h@020>[ZjP030>KViP3/k>`0mOGe0080l?3`0540i^KV09jNWP2=SHd0TI6A028R8P0L71`06a/K024Q
8@0a<C40=CDe0:BTY012@T809bLW02DU9@0Y:BT09bLW02d];@0c<c<0EEEE030`<01>CTh0HF5Q05]K
F`1lO7`0EEEE04Y:BP16ATH0JFUY08n?S`2a/K40g=cL0=_Kf`2@T900H61P071`L02HV9P0XJ6Q07Ui
N@2DU9@0KFe]0;6a/@2<S8`0QXJ602DU9@0G5aL07alO02LW9`0o?cl0QXJ604I6AP0Q8B407AdM01`L
700I6AT071`L01lO7`1XJ6P0Ph>3059BDP0T92@09bLW055AD@1GEeL0ZZZZ0;:b/P1CDe<0Lg=c04M7
A`1ZJVX07QhN01dM7@0L71`07QhN01dM7@0R8R80>c/k05UIF@13@d<0Jf][0:2PX01CDe<00P0^;Rh0
200c<c<0@T9206ATI02LW9`0[Zj^09fMW@1LG5`0IVIV0P26QXH0101=CDd06a/K01DE5@0O7al2oooo
o`0008L0YjNW04];B`22PX80@D5105IFEP2;Rh/0LG5a0<K6aP1?Cdl0EeMG04i>CP25QHD0C4a<03/k
>`1CDe<0=3@d02PX:00a<C40=3@d04I6AP0U9BD07alO02HV9P0J6QX0GUiN0451@@0B4Q80:BTY02<S
8`0[:b/0;bl_06ATI00n?Sh0820P02l_;`0^;Rh0:RXZ04a<C00h>3P07AdM0410@01IFET0=SHf02TY
:@1@D5009BDU03@d=010@400HF5Q04a<C01PH600A4A403@d=01;Bd/0MgMg03lo?`1:BTX0A4A406m_
K`1/K6`0M7Ad03lo?`0`<300CTi>05ADE017AdL0=3@d069RHP1YJFT0?3`l04e=C@1?Cdl08b<S01`L
701gMgL0DE5A02LW9`0/;2`0?clo02<S8`0i>CT0Fe]K03Xj>P1ADE40E5AD020P801BDU80EUIF02DU
9@1CDe<0GUiN03@d=00j>SX0Ng]k06a/K00l?3`0MWIf09^KV`1aLG40MWIf06EUI@1=CDd0?3`l0<;2
`P35aLD0RHV903`l?01PH600R8R804];B`2:RXX0g=cL0;Zj^P1OGel0F5QH06ATI01CDe<0UiNG05UI
F@2>SXh0HF5Q06YZJP1MGEd0=SHf0492@P1YJFT0T92@04i>CP2RXZ80KFe]061PH02BTY80De=C04Y:
BP1iNGT00P1FEUH0_`25QHD0A4A404=3@`1kNg/0ATI606i^KP15ADD0HF5Q08J6QP1LG5`0EeMG06][
J`1ADE40P82004=3@`0f=SH0R8R807IfMP0o?cl0De=C09VIV@1?Cdl0JFUY04];B`0h>3P0EEEE07=c
L`1>CTh0C4a<05EEE@1ADE408B4Q03hn?P1WIfL0>SXj08Z:RP1SHf<0=CDe08n?S`25QHD0<S8b07al
O00U9BD0:2PX05ADE01lO7`0M7Ad06IVIP32`/80QXJ607UiN@0i>CT0EEEE0<?3``1dM7@0JVYZ0:6Q
X@2;Rh/0ADE50:2PX02XZ:P0HF5Q09:BTP2/[:`0M7Ad01lO7`0l?3`0?Shn01lO7`1@D500F5QH04a<
C01bLW80>c/k04i>CP1aLG40=CDe02/[:`1=CDd0?3`l03/k>`2:RXX0MGEe04Y:BP1`L700IVIV03@d
=02=SHd0D51@02LW9`1bLW80>SXj061PH00e=CD0?Shn08R8R02>SXh0N7Qh04Q8B01/K6`0GUiN08N7
Q`0i>CT0EeMG07MgM`0a<C40Bd];05aLG016ATH0De=C08V9R@1SHf<0=3@d02/[:`1ADE40N7Qh0451
@@19BDT0F5QH07moO`0a<C408B4Q03`l?01VIVH0@d=308n?S`2KVi/0C4a<02/[:`1YJFT0PX:205UI
F@2_[jl0JFUY03Ph>01RHV80L71`04E5A@0_;bl0DU9B07alO01:BTX07AdM0492@P1FEUH0<S8b02HV
9P1NGUh0Ti>C07QhN01/K6`0^KVi0861P@11@D40EUIF08R8R01PH600:b/[0;fm_@1_Kfl0=cLg061P
H01UIFD0QHF508Z:RP2f][H0JFUY06e]K@3EeMD0J6QX051@D02BTY80WinO04e=C@0Y:BT0=CDe06EU
I@16ATH0:BTY04e=C@2PX:00QhN706m_K`2DU9@0De=C04];B`1<C4`0AdM702d];@0S8b<0<c<c0080
@T9203H0=3@d03Ti>@20P800EEEE01`L700G5aL04a<C01DE5@0_;bl0Fe]K059BDP1SHf<0B4Q804I6
AP15ADD0KFe]0<k>cP31`L40UiNG0=;BdP2=SHd0EEEE0:RXZ02RXZ80[:b/09^KV`1@D500:b/[03<c
<`0k>c/0ATI6051@D019BDT0AdM70492@P1NGUh0G5aL05EEE@2>SXh0ATI602<S8`0V9RH0:RXZ01PH
600L71`0JVYZ05UIF@0T92@071`L01dM7@1bLW80<30`01LG5`0E5AD201@D50805ADE00d04A4A01DE
5@0D51@0;bl_0;Bd]01QHF40F5QH0:2PX01[Jf/0LG5a09VIV@0M7Ad05aLG00805ADE00P05aLG01TI
6@0Q8B40=SHf07=cL`2LW9`0Shn?024Q8@805ADE02h06a/K02/[:`12@T80MGEe0<K6aP20P800JVYZ
08J6QP2QXJ40/k>c07moO`13@d<0DE5A04U9B@0Y:BT0:b/[03Ph>010@400H61P05]KF`1NGUh0PH61
08B4Q02][Jd0_[jn0<71`@2<S8`0<S8b02d];@0m?Cd0De=C06e]K@1@D500C4a<05UIF@2BTY80UIFE
092@T02MWId0SXj>092@T03<c<`0MWIf08J6QP0R8R805ADE0P0C4a<05`0D51@0410@014A4@0@4100
4a<C014A4@0E5AD0DE5A0=3@d02LW9`0emOG0<;2`P2DU9@0/;2`03Lg=`0[:b/0>SXj09>CT`2HV9P0
BTY:02TY:@0I6AT051@D00<05ADE00h051@D01DE5@0H61P07AdM02`/;01hN7P0JFUY0410@01?Cdl0
Bd];05iNGP2OWil0YZJV03`l?080Jf][00@06a/K01LG5`0L71`05QHF0P0J6QX06P1HF5P0GemO06QX
J02d];@0TI6A09BDU00h>3P0820P02<S8`0Y:BT0<S8b02PX:00R8R80;bl_05=CD`2HV9P0b<S804];
B`16ATH0K6a/05YJFP1OGel0V9RH0<g=c@3Ogml0oooo0P3emOD20>[ZjP180?;blP3<c<`0[jn_08F5
Q@1oOgl0KFe]01hN7P0F5QH06a/K01dM7@0/;2`0@T9209fMW@0e=CD092@T02/[:`0X:2P0:BTY02d]
;@1CDe<08b<S01hN7P0V9RH0RHV90<S8b02][Jd0PH6107AdM01oOgl0J6QX0::RXP2o_kl0a/K60=?C
d`2?Shl0KFe]0451@@1PH600E5AD034a<@0l?3`0LG5a07IfMP2b/[80PH6109>CT`0e=CD05aLG01lO
7`0X:2P0GEeM06i^KP0];Bd09RHV02/[:`0U9BD0>CTi05UIF@2YZJT0W9bL06=SH`1[Jf/0OWin05]K
F`2?Shl0_[jn06=SH`1EEED0I6AT04E5A@1RHV80;Bd]0`0M7Ad0600O7al0BTY:04m?C`0a<C40?3`l
09BDU02n_[h0Fe]K0451@@0d=3@0@T9205ADE02MWId0Zj^[0;Rh^01PH600BTY:04];B`1:BTX0De=C
07=cL`1eMGD0<c<c01`L70;ooooo00007@2`/;00CTi>06YZJP0k>c/0Hf=S08:2PP1ZJVX0b<S805MG
E`1^KVh0Fe]K08Z:RP1GEeL0=cLg04];B`0e=CD0;2`/04I6AP0j>SX0FEUI030`<00T92@0A4A402TY
:@1_Kfl0De=C01hN7P0a<C40=SHf0080>3Ph0800HV9R03hn?P0S8b<0ADE503@d=00`<300@D5103Hf
=P0R8R80C4a<061PH00g=cL0:2PX05]KF`0Z:RX0?clo03dm?@1UIFD0D51@06QXJ01SHf<0;bl_04];
B`1kNg/0?3`l06YZJP1;Bd/0IfMW06YZJP1oOgl0CTi>02`/;01@D500EEEE04];B`0_;bl0IVIV07Ui
N@1NGUh0HF5Q06=SH`0g=cL071`L0820P01`L700:b/[03@d=01CDe<0?3`l03lo?`1JFUX0;Bd]06a/
K01`L7008B4Q04A4A01MGEd0;bl_071`L01mOGd0>SXj03/k>`1gMgL09RHV02XZ:P25QHD0VIVI05mO
G`22PX80IVIV02PX:00N7Qh0O7al07YjNP1ZJVX0=SHf05EEE@1]KFd0<S8b055AD@2MWId0VYZJ04m?
C`1DE5@0ADE503@d=01XJ6P0CTi>08N7Q`0V9RH0?Shn05iNGP18B4P0>CTi061PH01ZJVX0B4Q808n?
S`1PH600FUYJ08^;R`0d=3@0;Bd]05]KF`1;Bd/0FEUI07=cL`0f=SH0;2`/05UIF@0n?Sh0Hf=S03/k
>`0h>3P0FEUI05=CD`1DE5@0MWIf055AD@1TI6@0Cdm?038b<P28R8P0QHF503@d=00^;Rh0IVIV04I6
AP80M7Ad04`0GEeM08^;R`1hN7P0GUiN05=CD`1SHf<0Lg=c030`<018B4P0EEEE03dm?@2:RXX0Ph>3
04Y:BP1IFET0M7Ad02`/;01[Jf/0HF5Q0410@01UIFD0I6AT07MgM`1[Jf/0`L7108j>SP1kNg/0?3`l
04I6AP2j^[X0MGEe07moO`2n_[h0Y:BT04U9B@2PX:00[:b/051@D01oOgl0SHf=06m_K`0Y:BT0CDe=
05]KF`0[:b/0IVIV06QXJ01IFET0PH6103Hf=P1EEED0QXJ605=CD`0[:b/0FEUI03dm?@0c<c<0Ng]k
075aL@1=CDd0NWYj065QH@0U9BD0DU9B04i>CP0Z:RX0I6AT03dm?@1JFUX0GUiN04Y:BP2DU9@0Kfm_
07AdM01ADE40XJ6Q0P1aLG40I01ADE40<30`05QHF016ATH0PH6106QXJ01?Cdl0?3`l05UIF@22PX80
JFUY03De=@1@D500B4Q802LW9`0c<c<0A4A4071`L01LG5`0:RXZ04];B`1`L700;2`/07EeM@1nOWh0
Kfm_03Hf=P1YJFT0Jf][04E5A@29RHT0OGem05iNGP2<S8`0Ogmo06QXJ00W9bL0?3`l07alO01JFUX0
8B4Q04U9B@1?Cdl0;2`/02PX:01IFET0U9BD04Q8B011@D40WinO061PH010@400Cdm?0861P@0l?3`0
:2PX09jNWP1nOWh0@d=30861P@1`L700Lg=c09FEU@2g]kL0Jf][061PH03@d=00K6a/04I6AP1iNGT0
YJFU04U9B@1BDU80JFUY07AdM017AdL0:RXZ03<c<`21PH40QXJ60:JVYP1TI6@0De=C04m?C`1BDU80
<30`02/[:`0V9RH0:2PX02HV9P0R8R80>3Ph06ATI02EUID0RXZ:04e=C@0O7al09bLW04a<C01IFET2
04e=C@0l038b<P0Z:RX09RHV024Q8@0S8b<0SXj>02h^;P0E5AD0:2PX09BDU02l_;`0M7Ad09RHV02Y
ZJT0XZ:R09ZJVP0];Bd08b<S01lO7`0R8R80:BTY03Lg=`1;Bd/0BTY:04Q8B014A4@0SXj>0;Bd]01d
M7@0Fe]K05ADE01XJ6P0D51@06ATI01nOWh0=3@d02l_;`10@400DE5A08J6QP16ATH05QHF01DE5@0@
41004Q8B010@400C4a<0410@01DE5@1CDe<0VIVI069RHP1ZJVX0EUIF0:n_[`37alL0VYZJ0;jn_P2>
SXh0L71`0P1gMgL0C@1iNGT0S8b<09fMW@2l_;`0clo?0=cLg021PH406ATI01LG5`0A4A405aLG05IF
EP23Ph<0S8b<0;Rh^02MWId0Cdm?04E5A@1KFe/0Zj^[08N7Q`28R8P0TI6A05UIF@0/;2`0=CDe05=C
D`1HF5P0>c/k01`L700E5AD05aLG08R8R02f][H0`L7109RHV01eMGD0EEEE051@D01DE5@0DU9B03lo
?`0f=SH0;bl_028R8P0S8b<09RHV02PX:01ZJVX0[jn_092@T02OWil0N7Qh05=CD`1[Jf/04a<C01@D
500E5AD04a<C010@400>3Ph0410@014A4@0E5AD0=CDe05aLG00o?cl0Ng]k0=CDe03Bd]80a<C40<c<
c026QXH0@D5105IFEP2`/;00YjNW0080ADE500@0=cLg038b<P0Z:RX07AdM100E5AD0;`0Q8B40<c<c
075aL@1LG5`0DE5A065QH@20P800Ng]k0:ZZZP2NWYh0K6a/03/k>`0E5AD06QXJ01dM7@0G5aL05QHF
01LG5`0S8b<0EeMG051@D013@d<0X:2P07AdM023Ph<0UYJF03De=@0S8b<0<30`059BDP1IFET0@T92
03/k>`0h>3P0=CDe08>3P`0i>CT0:b/[04Q8B02>SXh0RXZ:08R8R034a<@0e=CD0<W9b@35aLD0`<30
0080clo?03h0dm?C08n?S`1oOgl0B4Q808F5Q@1fMWH08b<S01LG5`0J6QX092@T03Ph>01IFET0T92@
03`l?00Z:RX0:BTY02h^;P0/;2`0CTi>02/[:`0M7Ad07QhN028R8P1=CDd0V9RH051@D00o?cl0?Shn
05YJFP0[:b/0MWIf06YZJP2ZZZX0]kNg03<c<`0P8200AdM706][J`10@4009BDU02TY:@1IFET0P820
09ZJVP2MWId0GemO09^KV`1ADE406QXJ024Q8@0e=CD0PX:206][J`1kNg/0TY:B07moO`1XJ6P0Xj>S
09RHV02RXZ80Jf][08F5Q@<0YjNW0280W9bL038b<P1XJ6P0JFUY0451@@1OGel0EUIF01`L700K6a/0
7alO04Q8B01=CDd0?Shn04E5A@26QXH0Kfm_09>CT`22PX80De=C06a/K02d];@0alO70<30`03:b/X0
_[jn07IfMP1]KFd0DU9B069RHP1VIVH0>SXj04];B`1hN7P0Rh^;0_ooool0000/0:RXZ01BDU80FEUI
02/[:`13@d<0Fe]K05=CD`2KVi/0;Bd]05EEE@1[Jf/0Lg=c04];B`0a<C40>3Ph020P800k>c/0EeMG
03Ti>@1ADE408B4Q03lo?`1YJFT0>CTi06e]K@1FEUH071`L0451@@1OGel0?clo0451@@1WIfL05aLG
02DU9@1JFUX0@d=302h^;P0h>3P092@T02h^;P1OGel0HV9R02/[:`10@402034a<@3o03Hf=P0g=cL0
;Rh^02LW9`1MGEd0Lg=c02HV9P10@400FUYJ02`/;01ZJVX0?Cdm051@D01YJFT0E5AD034a<@16ATH0
M7Ad05aLG019BDT09bLW05mOG`0d=3@08R8R05mOG`1jNWX0?Cdm01/K6`1dM7@0?Shn03dm?@1NGUh0
I6AT04M7A`0n?Sh0F5QH024Q8@1VIVH0Kfm_02DU9@0l?3`0ADE5020P8017AdL0J6QX03De=@17AdL0
N7Qh051@D00X:2P0EeMG07]kN`1NGUh0X:2P06][J`1QHF40@41008R8R027QhL0I6AT02h^;P1BDU80
Hf=S059BDP2>SXh0c<c<0:JVYP0d=3@0EEEE06IVIP1>CTh0FUYJ04E5A@2=SHd0Bd];04Q8B01BDU80
@D5102d];@1LG5`0UIFE05ADE02FUYH0MWIf05=CD`23Ph<0E5AD03Ph>01GEeL0CDe=06m_K`2DU9@0
HF5Q03`l?01PH600?3`l07EeM@1HF5P0CTi>06IVIP14A4@0JVYZ08B4Q01RHV80Jf][0492@P0h>3P0
Q8B40820P017AdL0>CTi092@T01>CTh0GEeM06ATI01DE5@0X:2P065QH@13@d<0IFEU07inOP1mOGd0
=cLg04a<C01=CDd0@T9208b<S029RHT0E5AD05mOG`26QXH0<C4a06e]K@1hN7P0@d=305eMG@1LG5`0
Fe]K06YZJP2b/[80R8R806a/K00j>SX0?Shn0;Jf]P0i>CT0EUIF09RHV020P800?3`l09VIV@2`/;00
NGUi0861P@2IVIT0Rh^;02XZ:P1=CDd0JFUY028R8P1UIFD0I6AT04a<C02>SXh0<C4a04Y:BP1/K6`0
EUIF02/[:`1NGUh0G5aL0492@P29RHT0MWIf04M7A`1TI6@0O7al03Lg=`1]KFd0GUiN02DU9@1UIFD0
A4A405YJFP1NGUh0Cdm?0861P@1_Kfl0R8R805IFEP2_[jl0P82008F5Q@1SHf<0;Rh^05IFEP1<C4`0
IFEU06i^KP1XJ6P0=SHf055AD@2EUID0Ng]k03Xj>P1ADE40GEeM04E5A@0[:b/0@T9207MgM`13@d<0
:BTY061PH01iNGT0?clo06a/K02=SHd0NWYj03hn?P1fMWH0N7Qh05iNGP2FUYH0GEeM05iNGP2FUYH0
OWin07IfMP0i>CT0@d=306][J`1@D500<c<c06QXJ01UIFD0:BTY03Lg=`1kNg/0WIfM06e]K@1ADE40
YjNW02XZ:P0e=CD0Jf][0:JVYP1`L700<S8b0:b/[01YJFT0;2`/08J6QP2ATI40@T92000>07emO@2d
];@0@d=308N7Q`37alL0S8b<04=3@`1mOGd0UiNG0492@P0U9BD0>c/k05UIF@1OGel203Lg=`0N09ZJ
VP1bLW80XZ:R04];B`15ADD0EeMG05aLG00`<3009BDU02HV9P0O7al071`L020P800`<300J6QX07Ad
M02UYJD0U9BD09VIV@1jNWX0EUIF0451@@0d=3@0=SHf02TY:@0V9RH09bLW01hN7P0X:2P0Jf][0`0C
4a<07P0I6AT0BDU90;bl_02SXj<0R8R809nOW`2:RXX0VYZJ03/k>`0O7al071`L01lO7`0R8R80;Bd]
038b<P0g=cL0>SXj0:n_[`1kNg/0FEUI06ATI01fMWH0XZ:R0;Jf]P36a/H0YZJV0861P@1LG5`0<S8b
028R8P807AdM03805QHF01@D500D51@05ADE01<C4`0E5AD071`L05eMG@1SHf<0:BTY01hN7P1CDe<0
Cdm?08n?S`3EeMD0/[:b07inOP1/K6`0FEUI05ADE01UIFD0Jf][06=SH`1jNWX0[jn_0<K6aP3Bd]80
a/K606IVIP0R8R8051@D01DE5@0R8R80?3`l08N7Q`3AdM40hn?S0:^[Z`1SHf<0UIFE09>CT`17AdL0
E5AD06YZJP2XZ:P0T92@05EEE@0R8R805ADE01<C4`<05ADE04<0Hf=S05IFEP2<S8`0Lg=c09NGU`1`
L700BTY:03lo?`0c<c<0;bl_02d];@0Y:BT092@T01lO7`0S8b<0CDe=07=cL`2WYjL0TI6A05UIF@1M
GEd0CDe=08F5Q@14A4@05ADE014A4@0C4a<05ADE014A4@0C4a<06QXJ04U9B@1=CDd0:2PX05aLG02d
];@0TY:B0;Vi^@3Fe]H0`l?30::RXP2k^k/0d=3@0:b/[01^KVh0E5AD03Xj>P0f=SH0?Cdm02d];@0d
=3@0@d=303/k>`0V9RH051@D024Q8@1BDU80PH61069RHP1LG5`0R8R809:BTP1RHV80`L7105UIF@1`
L7008b<S00805ADE014051@D01<C4`0F5QH05aLG01/K6`13@d<0EeMG04M7A`2?Shl0M7Ad04m?C`21
PH40YJFU03hn?P1GEeL0@D5102DU9@0201LG5`0Z01HF5P0G5aL0@41006QXJ015ADD0C4a<08J6QP28
R8P0][Jf09bLW039bLT0UYJF07MgM`2;Rh/0WinO08f=S@24Q8@0UIFE0:b/[01dM7@0^KVi0;>c/`1;
Bd/09bLW01dM7@0Q8B40:RXZ07inOP1MGEd0ADE503<c<`0T92@09RHV03hn?P1?Cdl071`L01hN7P0M
7Ad08B4Q04i>CP1jNWX0=SHf0P0a<C40A`0/;2`092@T05EEE@10@400Lg=c06a/K00L71`08b<S06EU
I@0d=3@092@T028R8P0S8b<0<30`06MWI`2=SHd0PH61079bLP1LG5`0[Jf]07inOP0];Bd0=SHf09nO
W`2_[jl0RHV9075aL@2;Rh/0RXZ:03hn?P0];Bd0D51@0:b/[02FUYH0_;bl0=OGe`3Cdm<0IfMW03Hf
=P1`L700De=C038b<P1JFUX0IfMW02d];@0P8200C4a<04e=C@0j>SX0ADE509BDU01PH600;bl_08N7
Q`2k^k/0H61P08N7Q`1hN7P0_kno0<g=c@2j^[X0_Kfm030`<00Q8B409BDU03`l?01OGel0I6AT04m?
C`1;Bd/0IfMW00;ooooo0000602FUYH0DE5A071`L00o?cl0A4A406EUI@1BDU80YZJV05mOG`1>CTh0
F5QH075aL@1;Bd/0=CDe03Xj>P0I6AT06a/K0410@00a<C40C4a<01TI6@0F5QH0@T9201hN7P80IFEU
01@061PH03<c<`15ADD0;Bd]034a<@1JFUX0=CDe01LG5`0h>3P0;Rh^028R8P18B4P0AdM701`L700k
>c/0?Cdm01/K6`1;Bd/0BDU9028R8P80:BTY0440@D5103De=@1@D500EUIF01`L700g=cL0J6QX03hn
?P1ZJVX0AdM703dm?@1cLg<0JFUY03<c<`0X:2P0>SXj04Y:BP0j>SX0=CDe06MWI`1LG5`0=CDe05iN
GP1=CDd092@T01XJ6P1QHF40@T9202h^;P0Z:RX0ATI602l_;`13@d<0HV9R02d];@1<C4`0EEEE02LW
9`0n?Sh0G5aL03<c<`1UIFD0H61P02@T900n?Sh0KVi^061PH013@d<0KFe]0820P00m?Cd0PH6106EU
I@1MGEd0?Shn08f=S@2m_Kd0Lg=c0451@@1XJ6P0L71`05YJFP2FUYH0]KFe0<_;b`0203lo?`1e06m_
K`1=CDd0De=C03lo?`1UIFD0FEUI04A4A01ZJVX0>CTi02l_;`1gMgL0SXj>04i>CP24Q8@0C4a<055A
D@2IVIT0I6AT04U9B@1SHf<0>3Ph04Q8B01[Jf/0LG5a0492@P1TI6@0AdM707inOP1LG5`0C4a<07mo
O`1IFET0E5AD08:2PP1XJ6P0OWin04i>CP0Z:RX0NGUi05eMG@0Y:BT0=3@d09BDU01IFET0IFEU07]k
N`1MGEd0];Bd06IVIP1EEED0Bd];05YJFP1KFe/0<c<c0451@@19BDT0<C4a092@T02:RXX0DU9B06AT
I01QHF40<C4a07UiN@1_Kfl0@T9205eMG@1eMGD0EUIF05]KF`2l_;`0HF5Q0451@@18B4P0Ph>30<c<
c01iNGT0H61P09NGU`23Ph<0?Cdm0:6QX@2i^KT0N7Qh07YjNP2LW9`0Vi^K03<c<`1?Cdl0M7Ad01dM
7@1JFUX0L71`04a<C029RHT0?clo05=CD`1/K6`0EeMG03Lg=`1eMGD0KVi^04A4A01fMWH0NWYj03<c
<`1_Kfl0P820038b<P1`L700JFUY02XZ:P1YJFT0LG5a07]kN`1`L700B4Q80080GEeM07<0MgMg03dm
?@1bLW80JVYZ07QhN01JFUX0<C4a05ADE00a<C40LW9b08F5Q@1SHf<0>3Ph051@D021PH40BTY:04];
B`1bLW80QHF505=CD`0^;Rh0AdM707inOP1TI6@0<30`04Y:BP21PH40=cLg06i^KP2DU9@0DE5A0451
@@20P800EUIF055AD@2>SXh0EeMG04m?C`2OWil0R8R806m_K`0d=3@0H61P07]kN`15ADD06a/K04E5
A@0j>SX03@d=02<S8`1NGUh0WinO06EUI@1JFUX0_Kfm04=3@`0U9BD0>CTi06m_K`1:BTX0EeMG0=;B
dP2TY:@0>c/k04A4A01VIVH0Hf=S08R8R02QXJ40<C4a03/k>`2GUiL0CDe=0410@02OWil0UiNG05aL
G00V9RH0=SHf05eMG@1=CDd0@D5107]kN`2f][H0MgMg0<[:bP2PX:00T92@08j>SP1QHF40ATI603Xj
>P0l?3`0>c/k030`<00O7al06a/K03@d=01OGel0@D5109RHV02UYJD0?3`l02HV9P0X:2P0?clo03Xj
>P0[:b/0:BTY01/K6`0F5QH0CTi>03`l?00@41004A4A00805ADE00/05QHF051@D02BTY80/K6a08j>
SP2OWil0V9RH0:JVYP1WIfL0?Cdm030`<00202d];@0D02TY:@0b<S80Vi^K0::RXP1XJ6P0PX:207Ad
M02DU9@0][Jf07inOP1KFe/0OGem09BDU02^[Zh0UiNG08J6QP1VIVH0?3`l03De=@0L71`301DE5@0?
02h^;P1]KFd0HF5Q02@T900F5QH05ADE020P802MWId0YZJV0;Fe]@2b/[80XZ:R09fMW@23Ph<0O7al
00<0N7Qh01T0Vi^K0<K6aP2o_kl0Ng]k08j>SP2_[jl0R8R804U9B@0M7Ad071`L02<S8`1DE5@0/;2`
0>?Sh`3WinL0dm?C0<30`02XZ:P0GemO05]KF`11@D40@d=306e]K@0V9RH051@D00@05ADE00T08R8R
07=cL`10@400L71`04A4A01;Bd/09bLW02<S8`0V9RH00P0Z:RX0>@0`<300>c/k038b<P13@d<0IFEU
05YJFP1KFe/0L71`055AD@1HF5P0EEEE079bLP1XJ6P0VYZJ02d];@0I6AT05ADE010@400A4A40=SHf
04E5A@0i>CT08b<S04E5A@2EUID0EEEE059BDP2j^[X0eMGE0<C4a02/[:`0UiNG0<[:bP1CDe<06a/K
01lO7`0i>CT0Bd];04A4A00Y:BT071`L01/K6`0Q8B40:b/[03Ti>@1TI6@0/[:b0:VYZ@1nOWh0VYZJ
09BDU01iNGT0IFEU0:BTY01SHf<0D51@01DE5@0201@D500@00h>3P0A4A404a<C01PH600L71`08R8R
05mOG`1<C4`0W9bL0:^[Z`1>CTh0@410075aL@2a/K40;bl_01DE5@804a<C0`0E5AD0L@0f=SH0Ogmo
034a<@0Y:BT0GemO09:BTP2b/[80UiNG0<S8b02ATI40MGEe09>CT`1KFe/0A4A403dm?@1IFET0[Jf]
0<[:bP3AdM40Zj^[08>3P`2HV9P0De=C02/[:`0b<S80R8R803De=@0];Bd092@T024Q8@0b<S80QHF5
03Hf=P0N7Qh07AdM01/K6`0S8b<0Fe]K07UiN@0g=cL0;Bd]01XJ6P0H61P0=3@d079bLP0];Bd0M7Ad
04=3@`0R8R80?clo04=3@`0R8R807alO024Q8@0U9BD09bLW03Lg=`2DU9@0NGUi09JFUP1gMgL0BTY:
0:>SX`2o_kl0W9bL08N7Q`2m_Kd0ZJVY0:6QX@1VIVH0;2`/024Q8@0Z:RX0?3`l05ADE02^[Zh0eMGE
0>7Qh@3<c<`0?Shn03Xj>P2BTY80B4Q802/[:`17AdL0GEeM05=CD`1NGUh0Bd];03De=@1KFe/0QhN7
05UIF@27QhL0Ti>C06MWI`26QXH0X:2P07EeM@29RHT0[Zj^0=CDe02i^KT0_kno0451@@0i>CT08b<S
01lO7`0U9BD0PH610:NWY`2UYJD0_;bl00;ooooo0000Q02^[Zh0EUIF07UiN@12@T80@41005aLG00n
?Sh0IVIV05IFEP1JFUX0JFUY07inOP16ATH0@d=306ATI014A4@0;2`/05ADE00c<c<0E5AD02PX:00S
8b<0>CTi01TI6@1QHF40Fe]K01XJ6P0e=CD0>3Ph02LW9`0m?Cd0G5aL04U9B@0L71`0<c<c024Q8@0_
;bl0GUiN04Y:BP0S8b<0@41003hn?P0E5AD0BTY:04i>CP0V9RH09bLW034a<@1QHF40?Shn05mOG`19
BDT06a/K04E5A@1`L700@T9206=SH`0_;bl0>3Ph08b<S01hN7P0BTY:02`/;019BDT0GUiN04m?C`0I
6AT0BTY:061PH015ADD0MgMg059BDP0K6a/06ATI06UYJ@1DE5@0=SHf038b<P11@D4092@T04I6AP1_
Kfl0<S8b04E5A@1;Bd/06ATI038b<P1JFUX0;bl_06a/K01MGEd0=cLg02@T901VIVH0MgMg05ADE01[
Jf/0XZ:R06=SH`2IVIT0Fe]K04i>CP0^;Rh0IVIV09FEU@1]KFd092@T0410@01OGel0HF5Q08b<S02d
];@0bl_;05IFEP12@T80Lg=c04];B`1iNGT0Cdm?08:2PP1UIFD0ATI607AdM010@400;Rh^05QHF02>
SXh0EeMG08J6QP1SHf<0@d=308F5Q@80GUiN07D0LW9b04i>CP1LG5`0Ng]k06EUI@0o?cl0GUiN04=3
@`1hN7P0CTi>05EEE@2DU9@0EeMG04m?C`25QHD0ATI607moO`1EEED0>SXj07AdM01nOWh0;2`/04I6
AP2MWId0G5aL06IVIP1JFUX0@d=30:>SX`1dM7@0HV9R04E5A@1OGel0De=C03@d=014A4@0DU9B03Ti
>@1`L700Rh^;04i>CP1]KFd0Kfm_03De=@1[Jf/0B4Q8038b<P11@D40Bd];069RHP1XJ6P0aLG508V9
R@1CDe<0<C4a04U9B@2OWil0MgMg061PH02<S8`0VIVI059BDP31`L40d=3@07AdM01XJ6P0V9RH0:2P
X011@D40NWYj071`L00O7al0A4A406QXJ01RHV80WinO03/k>`1ADE40JVYZ05ADE00^;Rh0G5aL061P
H01HF5P0KFe]07alO01<C4`0IfMW08J6QP0^;Rh0UYJF075aL@0e=CD0J6QX06=SH`1gMgL0JVYZ04M7
A`2YZJT0P82006m_K`1:BTX0T92@06EUI@2BTY80?Cdm04a<C01iNGT0GemO051@D01NGUh0;Bd]04E5
A@1_Kfl0Shn?06IVIP0f=SH00P1LG5`0F00F5QH0?Cdm06YZJP2=SHd0I6AT03Ti>@13@d<0IVIV028R
8P1dM7@0UiNG07QhN00g=cL0K6a/04a<C01>CTh0Shn?08f=S@1[Jf/0U9BD08N7Q`0c<c<06a/K03Lg
=`1XJ6P0G5aL01`L701;Bd/0CDe=02LW9`0V9RH0FUYJ08j>SP19BDT0ATI60;>c/`1cLg<0=CDe03hn
?P1dM7@0IVIV03@d=02OWil0Ph>304m?C`1_Kfl0L71`06i^KP2QXJ40/k>c05MGE`12@T80UIFE04I6
AP0_;bl0LG5a08j>SP1@D5009RHV03<c<`1DE5@0C4a<024Q8@0h>3P0KFe]06=SH`3Bd]80d=3@0:n_
[`27QhL0GemO05=CD`1?Cdl0@D5102`/;00Y:BT0<C4a02l_;`0m?Cd0NGUi08N7Q`2>SXh0NWYj04Q8
B016ATH0@T9205IFEP0n?Sh203dm?@0401hN7P0Q8B40JFUY02<S8`804A4A01405ADE01<C4`0C4a<0
=SHf03/k>`1NGUh0X:2P0:BTY02RXZ80_;bl0=WIf@2f][H0X:2P09NGU`2SXj<0^KVi0=KFeP020=OG
e`0D0;Jf]P28R8P0WinO0;Ng]`2OWil0Y:BT09fMW@1fMWH0@T9203Ph>00k>c/0DE5A07=cL`2IVIT0
WinO08:2PP1HF5P0>SXj061PH01_Kfl202@T90805ADE01@05aLG02l_;`2HV9P0[Zj^09JFUP2<S8`0
Jf][06a/K019BDT0<C4a02XZ:P0Y:BT0;Rh^03@d=01JFUX0/[:b07]kN`1PH600E5AD05mOG`80Kfm_
00`0DE5A04e=C@2MWId0clo?0=[JfP3Ti>@0f][J07alO01CDe<0J6QX08B4Q02DU9@208J6QP0?05aL
G01<C4`0B4Q804Q8B01;Bd/0CDe=08b<S02b/[80Hf=S06m_K`15ADD0BTY:01DE5@0I6AT05aLG0080
5ADE02L05aLG02PX:01iNGT0QHF505]KF`0e=CD0?3`l02`/;00G5aL06QXJ04A4A00k>c/0Jf][0:JV
YP2TY:@0Fe]K04A4A00a<C40@d=303De=@0X:2P09BDU0492@P2=SHd0C4a<04m?C`1>CTh0[Jf]0<K6
aP2^[Zh0/;2`0;Jf]P2m_Kd0@T9201LG5`0I6AT071`L01hN7P0d=3@00P1=CDd0FP0k>c/0820P01dM
7@0`<300HV9R0:RXZ02][Jd0clo?0;Fe]@21PH40H61P09BDU02TY:@0BTY:01XJ6P0B4Q804a<C01DE
5@0C4a<05ADE010@400A4A405aLG01dM7@1dM7@0BDU90<g=c@2i^KT0Vi^K09:BTP2:RXX0Ph>30451
@@0[:b/08b<S01lO7`0Q8B40;Bd]055AD@2PX:00_Kfm06UYJ@0m?Cd0Hf=S04I6AP1kNg/0IFEU0:VY
Z@2@T900AdM703/k>`0m?Cd0Fe]K08j>SP37alL0bl_;0:2PX02GUiL0@T9204a<C01_Kfl0_;bl0;Fe
]@2TY:@0UYJF02`/;00O7al071`L02l_;`1eMGD0XZ:R05=CD`0N7Qh07alO01dM7@0[:b/0HV9R06YZ
JP0b<S807alO038b<P1VIVH0RHV908N7Q`1iNGT0MWIf03/k>`0G5aL0@d=3028R8P808B4Q01408b<S
02@T900Q8B40;2`/05IFEP2?Shl0I6AT0:NWY`2VYZH0Jf][09bLW03>c/h0`/;20;:b/P2^[Zh0Lg=c
06ATI00204E5A@0Y04Q8B00n?Sh0@T9205EEE@3AdM40gmoO0<c<c02CTi<0Zj^[0:f][@2c/k<0Kfm_
04E5A@1EEED0[Jf]096AT@23Ph<0YZJV0=GEe@2>SXh0QHF5051@D00_;bl071`L02l_;`2BTY80X:2P
0:f][@2^[Zh0WYjN0:BTY01GEeL0Bd];051@D013@d<0DU9B079bLP2CTi<0WIfM0<[:bP3Cdm<00_oo
ool0000D0:>SX`1<C4`0IVIV04I6AP18B4P0NWYj04=3@`1cLg<0NGUi051@D01[Jf/0N7Qh03lo?`0`
<300EeMG0410@00U9BD0>CTi02DU9@1:BTX202<S8`0U03Hf=P0E5AD0JVYZ06QXJ00O7al0@41003lo
?`0L71`0:b/[04M7A`0g=cL06a/K030`<00M7Ad0820P04Y:BP0g=cL08B4Q0492@P1EEED07QhN04e=
C@1MGEd09BDU03lo?`0V9RH0GUiN03Ti>@1YJFT0CDe=01lO7`0S8b<0FEUI04=3@`1LG5`0EEEE03@d
=00206EUI@3o03`l?00k>c/0KVi^06e]K@1RHV806a/K04i>CP1PH600De=C08Z:RP1UIFD0=SHf01DE
5@1YJFT0Hf=S03Ti>@0f=SH0IFEU05EEE@0h>3P0L71`030`<014A4@0B4Q802LW9`0a<C40GemO02HV
9P1SHf<0LW9b04e=C@0P8200HV9R06MWI`1CDe<0O7al0::RXP1NGUh0X:2P065QH@1jNWX0EUIF05UI
F@2SXj<0GemO034a<@1;Bd/0KVi^04I6AP1QHF40Z:RX0<K6aP1KFe/0B4Q806][J`12@T80Ng]k04];
B`2NWYh0@41003`l?01fMWH0EeMG03Lg=`1ZJVX0P82003/k>`1oOgl0D51@03hn?P23Ph<0C4a<04I6
AP1IFET0BTY:06MWI`2HV9P0DE5A04Q8B01eMGD0@T9206i^KP1;Bd/0BTY:08>3P`1KFe/0CDe=09ZJ
VP1bLW80NGUi059BDP11@D40SHf=07inOP10@400<c<c08f=S@1GEeL0G5aL06m_K`16ATH0`L7106UY
J@1QHF40@T9207=cL`1FEUH0@D5105EEE@1SHf<0?3`l06m_K`23Ph<0AdM708>3P`25QHD0?3`l07Ad
M01iNGT0DU9B04I6AP1XJ6P0B4Q8079bLP33`l<0Vi^K05mOG`11@D40C4a<09nOW`1RHV80MWIf0;no
_`2NWYh0<c<c09>CT`2[Zj/0GEeM07QhN03:b/X0ZZZZ03Hf=P1ADE40HF5Q03Lg=`1LG5`0DE5A04E5
A@1dM7@0<30`069RHP2;Rh/0Lg=c030`<01gMgL0>SXj02HV9P1IFET0Ti>C05=CD`1UIFD0Rh^;024Q
8@1eMGD0SXj>03`l?01NGUh0Lg=c071`L01BDU809RHV04e=C@1iNGT0IfMW0451@@1cLg<0EUIF07If
MP0m?Cd0:BTY06m_K`1bLW80FUYJ06IVIP1MGEd0<30`04M7A`23Ph<0JVYZ04Q8B01bLW80KFe]03De
=@0Q8B40>c/k079bLP1OGel0=cLg04Q8B01UIFD0:RXZ04m?C`24Q8@0J6QX02h^;P1iNGT0ATI603Hf
=P1mOGd0Ogmo05iNGP2NWYh0QhN707QhN00b<S80?clo07EeM@1]KFd07alO05EEE@1[Jf/0=SHf02/[
:`1WIfL0SHf=065QH@1HF5P0`l?307EeM@0g=cL0>SXj06UYJ@1cLg<0;bl_08^;R`2ZZZX0EeMG06i^
KP1[Jf/0Bd];07inOP2:RXX0BTY:0410@027QhL0Hf=S03/k>`2;Rh/0TI6A04=3@`0S8b<0=cLg061P
H01NGUh0?Cdm000J0410@02j^[X0Ph>308Z:RP1kNg/0V9RH0<G5a@26QXH0EUIF04e=C@1GEeL0HF5Q
06EUI@10@400<30`04m?C`1dM7@0TY:B0:BTY027QhL0ADE503Hf=P0V9RH0=SHf038b<P0`<30202/[
:`04030`<01@D5006QXJ01<C4`805aLG04/04a<C01DE5@0b<S80?Cdm02DU9@0o?cl0[Zj^0<c<c03J
f]X0`L7109BDU020P800NWYj092@T02d];@0e=CD0=KFeP3Ogml0fMWI0<g=c@2MWId0FEUI04];B`1f
MWH0X:2P08>3P`0i>CT0:BTY024Q8@0T92@0:BTY03Xj>P1=CDd0>SXj05IFEP2IVIT0alO703/k>`0M
7Ad05QHF01DE5@0D51@061PH0492@P1LG5`0AdM704];B`20P800N7Qh06][J`1PH600A4A403Ti>@0^
;Rh0:b/[02DU9@0/;2`0MWIf09FEU@1]KFd0EeMG04U9B@16ATH0B4Q804m?C`1;Bd/0U9BD0=KFeP3C
dm<0`/;208>3P`2e]KD0LW9b04Y:BP1=CDd00P1PH6003P1hN7P0DU9B03lo?`0h>3P0=SHf02XZ:P0e
=CD0ATI608f=S@2/[:`0[jn_0:>SX`1hN7P06a/K0P0E5AD02@0D51@05ADE01<C4`0G5aL0@41003@d
=00_;bl0>SXj034a<@0201DE5@0L01LG5`0W9bL0IFEU03De=@1iNGT0Ti>C079bLP2RXZ80JFUY03dm
?@0e=CD0=SHf061PH02IVIT0E5AD05IFEP1ADE40Ph>308:2PP20P800Lg=c06YZJP2c/k<0YZJV06][
J`0Q8B405aLG01TI6@8071`L01<07alO03De=@1BDU80AdM705QHF01CDe<0VIVI0<O7a`2l_;`0aLG5
0<S8b01<C4`0T92@0<k>cP38b<P0HF5Q020P800G5aL04A4A00805ADE04P03Ph>01@D500A4A403Ph>
01hN7P1^KVh0OWin0:>SX`1WIfL0MWIf05mOG`1GEeL0N7Qh08Z:RP21PH40MgMg071`L01cLg<0LW9b
06EUI@1BDU80YjNW0<30`02n_[h0T92@04e=C@1:BTX0Bd];096AT@23Ph<0BDU905ADE025QHD0`<30
0;Jf]P28R8P0M7Ad03dm?@1YJFT0Kfm_03<c<`10@400K6a/09bLW03Hf=P0Y:BT03Ph>00k>c/0EUIF
069RHP0d=3@0:BTY04U9B@1iNGT0>3Ph01hN7P0[:b/0G5aL08f=S@1ADE40MgMg06EUI@14A4@0=SHf
03@d=01nOWh0a/K604m?C`0E5AD05aLG024Q8@0M7Ad202@T900302LW9`0[:b/0@T920080<30`03H0
QXJ609nOW`34a<@0W9bL0:>SX`2n_[h0dm?C0=cLg02EUID0L71`06UYJ@1TI6@0IfMW07inOP1oOgl0
Shn?0:JVYP2g]kL0fm_K0<?3``2_[jl0MgMg05MGE`2:RXX0a<C40<S8b036a/H0]KFe09JFUP2DU9@0
/K6a04A4A00Y:BT08R8R02<S8`0b<S80=CDe03Ti>@1aLG40[:b/09NGU`1mOGd0VIVI0<C4a02FUYH0
M7Ad07emO@1[Jf/0NWYj07MgM`2/[:`0_;bl08b<S01fMWH2ooooo`0001d0/[:b05eMG@1VIVH0>3Ph
03lo?`1`L700A4A406YZJP1bLW80D51@08j>SP2JVYX0HF5Q03Lg=`1XJ6P0DE5A02d];@1RHV80<C4a
065QH@0^;Rh09RHV051@D00W9bL0F5QH075aL@0L71`0DE5A051@D002030`<03B061PH00^;Rh0:2PX
04Y:BP0^;Rh0:BTY04m?C`13@d<07alO04=3@`1GEeL0820P05IFEP1UIFD08B4Q0492@P0U9BD0IFEU
038b<P24Q8@0SHf=02h^;P0d=3@0HV9R03Hf=P1JFUX0I6AT03<c<`1WIfL0LW9b055AD@0];Bd0DE5A
04];B`1>CTh08B4Q05EEE@1JFUX0?Shn05=CD`1XJ6P0EUIF01LG5`1cLg<0NWYj03hn?P1CDe<0KFe]
05QHF016ATH0TY:B03Hf=P0k>c/0DE5A03De=@0f=SH0De=C02TY:@1VIVH0PX:205QHF00f=SH0OWin
05QHF00a<C40NWYj092@T01FEUH0V9RH09FEU@25QHD0C4a<03/k>`2XZ:P0?3`l03/k>`1gMgL0QHF5
06a/K01UIFD0X:2P0=7Ad@0g=cL0DE5A0:6QX@1CDe<0F5QH01dM7@1/K6`0MGEe04A4A01dM7@0=3@d
03De=@1_Kfl0QhN705UIF@2;Rh/09bLW02d];@2ATI40N7Qh05=CD`1RHV808B4Q055AD@2=SHd0Shn?
04i>CP1ZJVX092@T07EeM@1jNWX0Cdm?07AdM01ZJVX0FEUI09nOW`1WIfL0O7al03@d=00H61P0HV9R
07IfMP1IFET0=3@d08J6QP0o?cl0LG5a08^;R`0o?cl0`/;207IfMP1JFUX0LG5a08^;R`1NGUh0>CTi
03dm?@16ATH0@T9208>3P`2?Shl0BTY:065QH@1OGel0=SHf09>CT`2;Rh/0H61P065QH@26QXH0>SXj
03hn?P2<S8`0Lg=c04Y:BP0V9RH0C4a<08f=S@1=CDd0>c/k06=SH`2:RXX0ADE50:NWY`34a<@0FUYJ
03lo?`1HF5P0QhN703lo?`1PH600DE5A02LW9`1HF5P0JVYZ0451@@2CTi<07QhN03<c<`1OGel0JVYZ
02h^;P1TI6@0G5aL05mOG`1SHf<0VYZJ05YJFP1HF5P0QhN7034a<@1OGel0GEeM03Ti>@1eMGD0V9RH
09BDU01IFET0@T9209:BTP1HF5P0NWYj04=3@`2PX:00I6AT07=cL`1@D500;Rh^0P1SHf<0Q`1IFET0
Q8B406MWI`0h>3P0ADE507IfMP0a<C40>c/k05YJFP1jNWX0Cdm?02TY:@10@400MgMg05EEE@1=CDd0
Q8B40861P@0f=SH0JVYZ09VIV@29RHT0@d=307=cL`1QHF40Fe]K07QhN01aLG40GUiN0:NWY`2=SHd0
KVi^03<c<`17AdL0KVi^05YJFP0S8b<0M7Ad07EeM@0i>CT0:RXZ05UIF@2IVIT0M7Ad05aLG030`<00
T92@03Lg=`0f=SH0KFe]07IfMP16ATH0FUYJ0;^k^`1SHf<0KFe]07UiN@2DU9@0RHV90::RXP1BDU80
>SXj07YjNP1XJ6P0?clo09FEU@2ATI40@D5102LW9`0h>3P0IVIV075aL@0f=SH0>c/k0<30`02CTi<0
Ng]k06m_K`17AdL0KFe]06a/K01nOWh0N7Qh05ADE01@D500HF5Q08Z:RP27QhL0MGEe08N7Q`2VYZH0
f=SH0<;2`P2CTi<0AdM70451@@1CDe<0A4A403lo?`0e=CD0=cLg07alO00U9BD06QXJ018B4P0H61P0
:RXZ02PX:00R8R80<c<c051@D00d=3@07AdM051@D03Bd]80dm?C0<_;b`2d];@0NGUi0410@00g=cL0
=3@d03Hf=P2PX:00g]kN0=_Kf`2_[jl0KFe]04Y:BP1>CTh0EEEE09jNWP26QXH0?3`l02h^;P0202@T
900n03Hf=P1BDU80D51@0410@011@D40;Rh^04a<C01ZJVX0KVi^07AdM01FEUH0ATI605QHF01[Jf/0
ADE503Lg=`1TI6@0LG5a02l_;`0V9RH0?3`l03lo?`1IFET0<c<c01lO7`0Q8B4071`L02LW9`2?Shl0
Ng]k06IVIP0j>SX0=CDe02TY:@0Z:RX08b<S07IfMP35aLD0bLW909VIV@1NGUh0P82009RHV028R8P0
ATI604Q8B00n?Sh0DU9B06ATI00f=SH0;bl_02h^;P0k>c/0@d=306IVIP2;Rh/0`l?308j>SP2FUYH0
MGEe04E5A@0M7Ad401DE5@0601/K6`11@D40=CDe0410@00f=SH05aLG0P0E5AD02P0F5QH09bLW03Xj
>P0X:2P0HV9R096AT@1JFUX0UIFE0=3@d038b<P20<c<c00A0=[JfP2a/K40H61P04e=C@1^KVh0Xj>S
02@T900G5aL0BTY:051@D02[Zj/0KVi^06MWI`1iNGT0@410028R8P0J6QX00P0L71`0900M7Ad09BDU
02d];@1FEUH0R8R806UYJ@3;bl/0bLW90=OGe`3EeMD0c/k>08B4Q01ZJVX0L71`08Z:RP1mOGd0Kfm_
03lo?`0U9BD06ATI018B4P0C4a<0410@014A4@0C4a<0=cLg08Z:RP1TI6@0BTY:03hn?P1ADE40HF5Q
0410@00_;bl0<30`03De=@80=3@d05T0>CTi0451@@15ADD0WIfM08n?S`3=cLd0c<c<0;2`/01CDe<0
LG5a02LW9`28R8P0Zj^[09RHV02KVi/0O7al06][J`1JFUX0EeMG0492@P14A4@0S8b<06EUI@0g=cL0
@D5105IFEP2e]KD0YZJV0<k>cP25QHD0=cLg01PH600J6QX071`L01hN7P0h>3P0TI6A07=cL`1KFe/0
]kNg0:b/[026QXH0FEUI03De=@0V9RH08B4Q02TY:@1>CTh0ZZZZ0;bl_00`<3006ATI024Q8@0S8b<0
8R8R02<S8`0W9bL0Bd];0451@@0M7Ad071`L05YJFP2h^;P0]KFe0:b/[02BTY80PX:20;bl_035aLD0
GEeM01hN7P0I6AT07AdM020P800c<c<0EeMG09bLW02k^k/0R8R80<S8b023Ph<0HV9R0>3Ph03Hf=P0
bLW90;^k^`33`l<0b/[:0<;2`P020;Ng]`0H0410@00Q8B40<S8b05EEE@22PX80ZJVY09bLW01QHF40
SHf=0:ZZZP2`/;00a/K60<O7a`2g]kL0TY:B05UIF@1XJ6P0Kfm_09BDU02TY:@0Lg=c03Ph>00];Bd0
>3Ph0_ooool0003I08Z:RP15ADD0M7Ad04Y:BP10@400BTY:03Ti>@1XJ6P0GemO03Hf=P15ADD0DU9B
03Hf=P0b<S80RXZ:04I6AP0l?3`0A4A4034a<@1mOGd0<C4a03@d=01>CTh0;bl_09VIV@25QHD07alO
04i>CP13@d<0;2`/06IVIP21PH40ADE501XJ6P0a<C40820P04];B`1IFET07alO02DU9@1LG5`0De=C
024Q8@1QHF40J6QX01hN7P0b<S80;bl_05ADE00L71`0H61P05QHF00U9BD0GUiN07alO01;Bd/0DU9B
04E5A@0d=3@0Ph>307QhN01GEeL0<C4a05=CD`1LG5`071`L030`<01VIVH0MGEe05QHF01ZJVX0CTi>
03@d=00R8R80KVi^07MgM`0^;Rh0<S8b04Q8B00K6a/0@410071`L01NGUh0A4A403dm?@0D51@0;Rh^
06e]K@0i>CT0G5aL06QXJ00O7al09bLW03Ph>01TI6@0>CTi061PH02<S8`0@41005mOG`15ADD0M7Ad
05EEE@0a<C40ZJVY05UIF@0U9BD0:RXZ0410@01;Bd/0JVYZ09BDU03>c/h0AdM702l_;`1EEED0@T92
055AD@0f=SH0FEUI055AD@0i>CT0H61P055AD@0U9BD0BDU907=cL`1ADE40NWYj069RHP0_;bl0Kfm_
06EUI@1GEeL0HV9R05MGE`11@D40QXJ607emO@1<C4`0GEeM03hn?P1UIFD0Jf][04e=C@1SHf<0G5aL
05YJFP2GUiL0KVi^07moO`1@D500>3Ph07=cL`1MGEd0=SHf0410@02YZJT0DU9B05QHF01_Kfl0EeMG
0<_;b`1kNg/0@410030`<018B4P0EeMG03Lg=`11@D40Bd];02<S8`16ATH0PX:204Q8B01WIfL0IVIV
034a<@28R8P0NGUi03Ti>@1EEED0HF5Q069RHP1EEED0_[jn0820P01@D500=cLg03/k>`27QhL0RXZ:
04Q8B01TI6@0RXZ:03<c<`2@T900`L7107moO`1DE5@0LG5a0861P@10@400QXJ606EUI@0X:2P0>CTi
065QH@0k>c/0OGem030`<01CDe<0Jf][06m_K`0Z:RX0DE5A04U9B@02079bLP2009RHV01IFET0E5AD
0:JVYP19BDT0IVIV06ATI00];Bd0BDU906e]K@1IFET0G5aL0492@P2EUID0E5AD07=cL`0^;Rh0H61P
059BDP26QXH0E5AD03Ti>@1JFUX0=SHf04E5A@1BDU80Cdm?034a<@11@D40NWYj05eMG@0g=cL0GUiN
09FEU@1>CTh0:b/[04I6AP1eMGD0CDe=02PX:01GEeL0MWIf03<c<`1ZJVX0OGem069RHP1DE5@0T92@
059BDP0o?cl0Jf][071`L01LG5`0_[jn0;2`/01nOWh0>SXj04];B`1SHf<0?Cdm01XJ6P1<C4`0H61P
04e=C@0Y:BT0IFEU07alO01@D500E5AD0;jn_P1hN7P0?Shn04Y:BP2?Shl0QXJ604=3@`2;Rh/0T92@
05mOG`13@d<0O7al09RHV01iNGT0XJ6Q04];B`1RHV80UIFE07YjNP0j>SX0U9BD09ZJVP0l?3`09bLW
04Y:BP1aLG40GEeM03dm?@0n?Sh0Ph>309RHV02^[Zh0OWin05eMG@1OGel0GUiN03Ti>@1?Cdl0NGUi
06ATI01mOGd0P8200::RXP3Jf]X0]KFe096AT@2=SHd0`<3006e]K@1dM7@0OWin08:2PP1=CDd0ADE5
04U9B@20P800U9BD02<S8`0d=3@203<c<`0?04m?C`0h>3P0<30`03lo?`1dM7@0>SXj03Hf=P1dM7@0
Ogmo08R8R035aLD0SXj>024Q8@0B4Q806ATI00806a/K01`0?clo09jNWP2o_kl0I6AT04];B`1]KFd0
Ogmo08N7Q`34a<@0dM7A0:^[Z`1fMWH0IFEU06e]K@2[Zj/0ADE502h^;P0Y:BT0JVYZ05mOG`1=CDd0
EUIF05=CD`1RHV80Ph>30;Fe]@3Ng]h0UiNG0P0a<C40<01fMWH0AdM702DU9@0K6a/05aLG01`L700V
9RH0?clo0451@@0O7al05ADE01LG5`17AdL0Ng]k06e]K@1KFe/0CTi>03lo?`0X:2P0820P09^KV`32
`/80^k^k0451@@0Q8B40@d=305]KF`2f][H0J6QX079bLP2NWYh0/;2`09^KV`1RHV80De=C051@D01:
BTX0AdM7030`<00T92@0QHF508n?S`1XJ6P0Kfm_05EEE@12@T80>3Ph02l_;`80:BTY00D0<C4a030`
<00g=cL0>3Ph01HF5P0401DE5@0Z02PX:00e=CD05aLG03De=@2YZJT0QhN708b<S02GUiL0^KVi0:ZZ
ZP2d];@0`L710:b/[02BTY80WYjN09>CT`2DU9@06ATI01DE5@0V9RH0FUYJ07IfMP1ZJVX08R8R0410
@01eMGD0MWIf0451@@0W9bL0820P01`L700K6a/08R8R03Ti>@2_[jl0a<C40=WIf@1DE5@0MWIf0:>S
X`2^[Zh08b<S0P0O7al0R`0/;2`0:2PX03<c<`0h>3P0FUYJ05aLG01PH600DU9B0451@@0c<c<0<30`
04I6AP1kNg/0>CTi04A4A00V9RH08B4Q03Ph>020P800JVYZ04A4A00d=3@09bLW02d];@0a<C40=3@d
04I6AP28R8P0Ng]k08R8R02UYJD0bl_;0<O7a`1^KVh0E5AD096AT@2=SHd0N7Qh05ADE01]KFd0FEUI
06YZJP1OGel0Cdm?04i>CP1KFe/0UiNG04M7A`11@D40BTY:0:FUY@1JFUX0]kNg02DU9@0I6AT05ADE
01LG5`0R8R8071`L01hN7P0d=3@0MgMg0:b/[029RHT0IfMW0:FUY@2@T900KFe]069RHP1LG5`0KFe]
0:>SX`3>c/h0YZJV09RHV01ADE40=cLg02XZ:P0N7Qh08R8R03<c<`0/;2`071`L01/K6`0N7Qh0A4A4
07YjNP0i>CT0EUIF09>CT`33`l<0a/K609BDU022PX807AdM01HF5P0I6AT071`L024Q8@0S8b<0@d=3
08N7Q`1DE5@0]KFe0;Bd]02UYJD0QhN706m_K`2=SHd0[jn_0;jn_P3EeMD0fMWI0<o?c`2:RXX0IFEU
059BDP1PH600IFEU06QXJ022PX80Lg=c08J6QP24Q8@0O7al0=;BdP3EeMD0]kNg0:BTY01/K6`07alO
03De=@0g=cL0De=C05MGE`0e=CD0;2`/030`<00e=CD00_ooool0003o09>CT`1JFUX0IFEU05QHF00o
?cl0Q8B403`l?018B4P0NWYj04E5A@19BDT0Bd];030`<00K6a/0=SHf04A4A00W9bL0=SHf01`L701E
EED0=CDe02@T900n?Sh04A4A05MGE`1MGEd08B4Q06i^KP0o?cl06ATI02HV9P14A4@0?Shn01/K6`0/
;2`04A4A01dM7@1CDe<0B4Q801dM7@10@400ATI601<C4`0g=cL0EUIF024Q8@0N7Qh06a/K05ADE00b
<S80KFe]055AD@0L71`08R8R04A4A00o?cl0@4100451@@0O7al0?Shn05QHF01EEED0<C4a04e=C@1V
IVH0D51@01LG5`0i>CT0KVi^05IFEP1`L700Bd];04Q8B00?3`l0CDe=05mOG`0g=cL0=SHf079bLP1@
D500;bl_05UIF@0[:b/0<c<c0410@00b<S809RHV05QHF00W9bL0DE5A05EEE@17AdL05QHF04i>CP1k
Ng/0=cLg059BDP2=SHd0Kfm_09JFUP1FEUH0MWIf05YJFP0i>CT0`L7108R8R00g=cL0?Shn05IFEP14
A4@0Jf][08j>SP3:b/X0E5AD03Ph>01SHf<0ATI605aLG00g=cL0IFEU03hn?P0e=CD0JFUY05=CD`0X
:2P0E5AD08F5Q@1QHF40LW9b06UYJ@0a<C40N7Qh06EUI@1gMgL0V9RH05aLG01?Cdl0Shn?06a/K016
ATH0GUiN03`l?01^KVh0Hf=S055AD@1cLg<0EeMG06IVIP2EUID0FEUI0820P01FEUH0>c/k08:2PP1f
MWH0;Bd]02<S8`1fMWH0FUYJ05eMG@1CDe<0=3@d07YjNP1eMGD0GEeM03Xj>P1NGUh0@d=304Y:BP1O
Gel0LG5a0492@P13@d<0OWin03De=@24Q8@0QHF504];B`24Q8@0M7Ad06MWI`1lO7`0@D5104M7A`1I
FET0`L7108J6QP0j>SX092@T04];B`2KVi/0SXj>04M7A`1OGel0TI6A03hn?P2GUiL0`L7108V9R@1E
EED0JFUY08R8R014A4@0@T92051@D00S8b<0>3Ph07=cL`1=CDd0UYJF0451@@1;Bd/0T92@05mOG`0d
=3@0L71`04e=C@1hN7P0K6a/0861P@0a<C40A4A409FEU@10@400FUYJ06UYJ@0a<C40EeMG08B4Q01E
EED0@d=302/[:`28R8P0OGem08F5Q@15ADD0WYjN05]KF`2KVi/0EeMG03Hf=P1OGel0Q8B405IFEP1V
IVH0FUYJ03@d=016ATH0QhN706e]K@0n?Sh0GEeM07AdM00n?Sh09RHV002a0410@01gMgL0LG5a0492
@P1RHV80Rh^;02TY:@1GEeL0LW9b05EEE@0_;bl0HF5Q04e=C@0k>c/0IVIV05YJFP0f=SH0TY:B07al
O01jNWX0=3@d0410@01`L700H61P01dM7@1>CTh0EUIF03dm?@0c<c<0PH6107EeM@1?Cdl0Bd];0;jn
_P1aLG40<C4a02XZ:P1YJFT0Ng]k03Xj>P2][Jd0M7Ad04Q8B00e=CD0PX:208N7Q`1TI6@0Q8B402@T
900k>c/0KFe]06a/K00l?3`0Vi^K08J6QP16ATH092@T03<c<`1CDe<0Fe]K03<c<`0e=CD0^;Rh08:2
PP1fMWH0KVi^071`L01bLW80M7Ad08>3P`1HF5P0@d=307EeM@21PH40XZ:R09fMW@2d];@0TY:B038b
<P0R8R80>CTi08f=S@1?Cdl0Kfm_05QHF01SHf<0GemO069RHP1kNg/0Ti>C05eMG@1RHV80HF5Q04];
B`11@D40AdM703<c<`0T92@0>CTi05aLG01iNGT0OWin04Y:BP0k>c/0T92@0451@@0F5QH071`L01@D
500>3Ph03@d=00h>3P0E5AD0IVIV03De=@0O7al07QhN024Q8@1OGel0[jn_05aLG00U9BD06ATI01DE
5@0G5aL0BTY:030`<00R8R808B4Q04];B`0F5QH05aLG01lO7`0Q8B409bLW034a<@1CDe<0_Kfm09BD
U00/;2`0?Shn05EEE@0[:b/06a/K01LG5`0C4a<04Q8B01DE5@0H61P07alO03Xj>P0k>c/0:b/[02DU
9@19BDT0LW9b08f=S@1^KVh0Ng]k09BDU02@T900`L7108R8R01hN7P0E5AD01`L700U9BD0L71`0<O7
a`30`<00RXZ:06][J`1VIVH0MgMg03`l?00P820071`L00<06ATI03h071`L02@T901UIFD0GEeM07in
OP33`l<0Ti>C07QhN01]KFd0JVYZ071`L02=SHd0Shn?096AT@1KFe/05QHF01TI6@0F5QH05ADE01LG
5`0R8R80<30`01LG5`0k>c/0F5QH02DU9@1NGUh0K6a/05YJFP2UYJD0emOG09bLW021PH40Fe]K03De
=@0^;Rh0NGUi02XZ:P0E5AD07QhN06YZJP1NGUh0EeMG020P800M7Ad07alO03/k>`1nOWh0O7al03lo
?`0Q8B4071`L02h^;P2YZJT0OWin07YjNP2EUID0TI6A04e=C@2UYJD0[jn_020P808071`L02X08R8R
02d];@0Y:BT06QXJ01DE5@0S8b<0:BTY02l_;`0j>SX0HF5Q09bLW034a<@0UiNG01/K6`0R8R809RHV
020P800S8b<0ATI609ZJVP22PX80?3`l03De=@0a<C40=cLg065QH@1XJ6P0MGEe07=cL`22PX80MWIf
0:^[Z`2g]kL0bl_;0:ZZZP1/K6`0<C4a03Ph>01RHV80W9bL0<c<c03QhN420=[JfP0:0<71`@2BTY80
Zj^[09:BTP1ZJVX0PH610:2PX00n?Sh0LG5a02HV9P805ADE00P05aLG01TI6@10@400EeMG04m?C`1i
NGT0XJ6Q06m_K`80_kno0480YJFU069RHP1_Kfl0Ph>309fMW@2BTY80WYjN09ZJVP1DE5@0MWIf07Mg
M`0Y:BT07alO02LW9`0U9BD06QXJ01/K6`0M7Ad092@T05MGE`1?Cdl09RHV02/[:`0l?3`0Y:BT0<K6
aP2VYZH0TY:B04I6AP0H61P06QXJ01TI6@0K6a/071`L04m?C`1/K6`0RXZ:0=;BdP3=cLd0HV9R01LG
5`0H61P06QXJ02d];@1EEED0PH610:RXZ02WYjL0T92@09FEU@28R8P0IfMW05MGE`17AdL0ADE50410
@014A4@0FUYJ08:2PP2d];@0PX:204A4A012@T80K6a/01LG5`0H61P201`L700505MGE`1SHf<0De=C
03Ph>00i>CT00_ooool0000;0:RXZ01^KVh0IFEU05ADE018B4P0U9BD0451@@19BDT0SXj>04I6AP15
ADD00P1[Jf/0j00[:b/0ATI6055AD@0U9BD0HF5Q02/[:`1RHV80>3Ph02LW9`1?Cdl0<c<c05ADE01I
FET07AdM05IFEP1NGUh0?clo04I6AP1?Cdl0=cLg01PH600/;2`08B4Q02/[:`1FEUH0CDe=01hN7P0m
?Cd0FEUI03Hf=P0g=cL0GemO02<S8`0h>3P0820P05]KF`14A4@0IFEU069RHP10@400>CTi04U9B@13
@d<0?Cdm07IfMP0h>3P0De=C06=SH`1RHV80;2`/04U9B@1PH600KVi^024Q8@0k>c/0MgMg05UIF@1e
MGD0?3`l04i>CP0A4A40EeMG07moO`19BDT0EEEE07=cL`1OGel0=SHf05YJFP0U9BD0<C4a04I6AP0`
<300;Bd]05]KF`0X:2P0A4A405IFEP1IFET06ATI05=CD`1cLg<0>SXj05]KF`28R8P0KVi^0:6QX@1P
H600IfMW03Ti>@0M7Ad0RXZ:06UYJ@0a<C40>CTi069RHP0m?Cd0D51@096AT@3:b/X0HV9R03Hf=P1>
CTh0<c<c06QXJ00g=cL0Hf=S03Ti>@0X:2P0JVYZ05mOG`0/;2`0E5AD07IfMP0g=cL0LW9b05mOG`0e
=CD0Q8B404U9B@11@D40Fe]K05MGE`15ADD0SXj>04I6AP17AdL0M7Ad03Ph>01PH600?clo05EEE@1k
Ng/0GUiN069RHP2OWil0EeMG06][J`12@T80>3Ph08j>SP1`L700@d=302TY:@2<S8`0Bd];05iNGP1Y
JFT0>3Ph0;Bd]01kNg/0HV9R04Q8B01TI6@0@T9202l_;`0k>c/0EEEE04I6AP0e=CD0R8R804=3@`1k
Ng/0MgMg055AD@1/K6`0IFEU06][J`2SXj<0>SXj04i>CP1DE5@0/[:b09VIV@1HF5P0?3`l02`/;026
QXH0OGem04e=C@1oOgl0YjNW04m?C`2EUID0alO706YZJP1GEeL0S8b<08:2PP1CDe<0FEUI04];B`0V
9RH0<30`04e=C@11@D40LW9b04Y:BP0e=CD0WinO04Y:BP0Q8B40GemO06MWI`1cLg<0DE5A079bLP1@
D500?Cdm08^;R`11@D40IfMW08R8R00h>3P0EUIF08R8R019BDT0?Shn02<S8`1`L700E5AD07YjNP0l
?3`0VYZJ05aLG02NWYh0A4A40492@P1eMGD0Ogmo069RHP1YJFT20451@@2206a/K02CTi<0Lg=c04A4
A01KFe/0NGUi0492@P0e=CD0EUIF08R8R01ZJVX0BTY:05mOG`1hN7P0<S8b05=CD`23Ph<0SXj>0410
@01_Kfl0HV9R04a<C01BDU80FUYJ05QHF02c/k<0SHf=0861P@0k>c/0EUIF075aL@19BDT071`L04U9
B@1ADE40:2PX028R8P1[Jf/0RHV9071`L015ADD0`/;2096AT@10@400?Cdm07QhN01iNGT0>3Ph0:^[
Z`1SHf<0Fe]K0492@P1oOgl0Rh^;05QHF01oOgl0D51@03`l?01`L700A4A4034a<@2GUiL0NWYj055A
D@0S8b<0<30`069RHP1=CDd0820P03hn?P36a/H0V9RH04i>CP19BDT0C4a<04i>CP16ATH0A4A406QX
J02;Rh/0]kNg0:FUY@1]KFd0Hf=S079bLP29RHT0B4Q802<S8`0N7Qh0@D5106MWI`1FEUH0LG5a0451
@@12@T80C4a<09ZJVP1jNWX0EeMG03Lg=`0W9bL071`L01dM7@0/;2`071`L014A4@0N7Qh0CDe=08f=
S@1oOgl0ATI603Lg=`21PH40>SXj01DE5@0_;bl0<S8b01<C4`0@41003@d=010@4019BDT0D51@01XJ
6P0K6a/05aLG01hN7P1dM7@0?clo02TY:@<05ADE00H06ATI03<c<`0d=3@0=SHf02HV9P0G5aL201DE
5@0:01TI6@0G5aL06QXJ020P801]KFd0XJ6Q034a<@1EEED0;2`/01DE5@<04A4A00<05ADE01HF5P0F
5QH00P0E5AD06@0S8b<0Fe]K05ADE01YJFT0GemO051@D013@d<0=cLg02TY:@0o?cl0QHF5059BDP1U
IFD0N7Qh020P800/;2`0I6AT08R8R00i>CT0;2`/02TY:@0[:b/0AdM701LG5`0F5QH00`0E5AD0AP0F
5QH05ADE01DE5@0c<c<0C4a<07=cL`2_[jl0Y:BT0861P@1IFET0C4a<05YJFP1hN7P0G5aL02HV9P0_
;bl0E5AD02LW9`0F5QH05ADE01LG5`0K6a/09BDU01PH601@D500=3@d01PH600^;Rh0<30`04=3@`1I
FET0_Kfm09>CT`1FEUH0Bd];03<c<`0V9RH0B4Q8065QH@0U9BD0?Cdm0492@P1IFET0CTi>01`L700H
61P06QXJ01/K6`0R8R80@D5109:BTP1nOWh0GUiN09ZJVP2c/k<0EUIF03Xj>P0g=cL0N7Qh0:BTY033
`l<0UYJF02TY:@0V9RH07AdM01lO7`0U9BD0:b/[02<S8`0J6QX201LG5`0L01PH600M7Ad0=cLg06][
J`33`l<0Zj^[0410@00O7al0:b/[028R8P0S8b<0=CDe065QH@18B4P09RHV02TY:@0W9bL0De=C06i^
KP1/K6`0YJFU07EeM@1BDU80Hf=S03Hf=P1VIVH0cLg=04=3@`808b<S00<0;2`/024Q8@2ZZZX00P2b
/[80302n_[h0_kno0;bl_030`<00alO70=?Cd`3@d=00a/K60;Ng]`12@T80RXZ:030`<0<05ADE01T0
61PH03Ti>@1@D500Vi^K09nOW`2a/K40[Zj^0<g=c@3<c<`0Rh^;07EeM@27QhL0EeMG02TY:@0M7Ad0
8R8R08>3P`1[Jf/0De=C055AD@1UIFD0;bl_01hN7P0L71`06QXJ00806a/K03L0;Bd]06=SH`0];Bd0
820P02PX:00_;bl0Ogmo04U9B@2<S8`0/;2`092@T00l?3`071`L02@T9011@D40J6QX0:n_[`2XZ:P0
/[:b08B4Q02<S8`0BTY:01LG5`0K6a/05aLG01`L700_;bl0J6QX07moO`2_[jl0UiNG05aLG00b<S80
:BTY024Q8@0L71`08B4Q02@T900i>CT0GemO0;Vi^@2=SHd0CDe=03lo?`0f=SH0G5aL03@d=00I6AT0
5aLG01lO7`0Y:BT0;2`/04M7A`1eMGD0CDe=00;ooooo0000o`2<S8`0I6AT05eMG@0l?3`0?Shn079b
LP0k>c/0BTY:079bLP1FEUH0PX:208b<S01ZJVX0:BTY0410@01BDU80:BTY06QXJ00[:b/0GUiN0451
@@0b<S80EeMG03<c<`1<C4`0DU9B024Q8@1CDe<0Fe]K03Xj>P1:BTX0AdM7034a<@0X:2P0Bd];020P
800];Bd0E5AD04m?C`0R8R80BTY:06UYJ@0n?Sh0<c<c06=SH`0T92@0@d=302PX:01GEeL0B4Q8079b
LP2BTY80>SXj030`<01:BTX0;2`/04m?C`1oOgl0?3`l05eMG@1=CDd0=3@d03Ti>@1PH600IfMW05aL
G00W9bL0>SXj05aLG011@D40F5QH06ATI01RHV805QHF04=3@`1SHf<08b<S03lo?`1WIfL0G5aL034a
<@1GEeL0;bl_03dm?@1SHf<0?Cdm02XZ:P1KFe/0<C4a069RHP1lO7`0GEeM01TI6@1>CTh0H61P0410
@01cLg<0Shn?05iNGP2IVIT0KVi^07UiN@1RHV808B4Q08V9R@1[Jf/0?Shn05ADE01TI6@0@41006QX
J01ZJVX0^[Zj04i>CP0d=3@0E5AD04=3@`1GEeL0>SXj06IVIP1PH600<S8b05eMG@1NGUh0<C4a061P
H02:RXX0EEEE07EeM@1?Cdl0@41008V9R@1WIfL0DE5A06e]K@1CDe<0B4Q809NGU`1XJ6P0EEEE05eM
G@0`<300EEEE05IFEP1@D500HV9R04];B`0k>c/0Ph>306EUI@1/K6`0=CDe02`/;01nOWh0LW9b04e=
C@0];Bd0Shn?05UIF@1JFUX0PX:20410@02ZZZX0PH6104e=C@1BDU80PX:205QHF016ATH0?clo05IF
EP14A4@0=SHf07moO`12@T80QXJ607IfMP1ADE40KFe]07EeM@1lO7`0^k^k05eMG@16ATH0IfMW0;Bd
]02DU9@0GemO03lo?`0d=3@0Q8B406m_K`0n?Sh0CDe=08R8R01:BTX0RXZ:0<C4a02>SXh0GUiN06QX
J01_Kfl0H61P05aLG01:BTX0;Bd]03Ph>01/K6`0?clo071`L00`<300:BTY08F5Q@1?Cdl09BDU05mO
G`1ADE40Hf=S05QHF02g]kL0KFe]03Ti>@2IVIT0?3`l04a<C01XJ6P0?clo05=CD`2>SXh0ADE505QH
F00b<S80P82005YJFP23Ph<0ADE509^KV`1IFET0UiNG04E5A@0W9bL0GEeM06YZJP1RHV80Kfm_04I6
AP0X:2P0EUIF0820P01FEUH0>c/k04i>CP1jNWX0>c/k02<S8`003P0i>CT0IFEU06UYJ@15ADD0GemO
07UiN@0U9BD0HV9R09FEU@24Q8@0?clo06a/K01>CTh0:b/[0P1XJ6P0G`1BDU80alO70;6a/@1lO7`0
9BDU03dm?@1QHF40JVYZ02TY:@1DE5@0K6a/04I6AP0S8b<0DU9B0861P@0l?3`0BTY:0:^[Z`2DU9@0
@D510492@P1WIfL0LG5a028R8P1oOgl0E5AD04m?C`16ATH0LW9b04m?C`1`L700[Zj^06MWI`10@400
Ng]k04a<C00h>3P0U9BD08j>SP1^KVh0;Rh^0492@P1dM7@0IfMW02`/;00_;bl0XZ:R08^;R`13@d<0
<c<c04E5A@0_;bl0;Bd]02LW9`0Y:BT0C4a<08:2PP1bLW80Zj^[05mOG`1FEUH0EeMG06YZJP0];Bd0
7alO01<C4`18B4P0AdM70820P01?Cdl0@T9205]KF`2[Zj/0E5AD028R8P0J6QX0410@01LG5`0F5QH0
4a<C00d=3@0@41007alO05]KF`1aLG40CDe=05QHF00b<S80Ph>303Hf=P0C4a<05ADE03<c<`0E5AD0
3Ph>00803@d=00X09bLW09bLW019BDT071`L01LG5`0K6a/0EEEE069RHP0Z:RX05ADE0P0D51@0100J
6QX05ADE01DE5@0F5QH201DE5@0@014A4@0F5QH06ATI01TI6@0L71`07AdM04A4A021PH40@41005QH
F00Q8B404a<C014A4@0D51@04A4A01@D50<04A4A0P0E5AD05`0@410061PH02DU9@1MGEd0ADE502XZ
:P0b<S808b<S01LG5`1JFUX0?3`l04a<C02BTY80Ng]k07=cL`1/K6`0GEeM01XJ6P0P8200:RXZ02d]
;@0`<3005QHF00<05ADE01804a<C01DE5@0E5AD05ADE01TI6@18B4P0@d=3075aL@1[Jf/0CDe=051@
D01lO7`0/[:b07moO`0i>CT08B4Q01hN7P0_;bl205eMG@0J02HV9P0G5aL06a/K02TY:@0J6QX0DE5A
01dM7@0G5aL08B4Q01lO7`0P8200@D510::RXP1/K6`09bLW038b<P1;Bd/0EEEE0451@@1bLW80CTi>
079bLP0_;bl0<c<c05YJFP0R8R8201/K6`0k01XJ6P0L71`071`L02DU9@1cLg<0fMWI0;fm_@12@T80
71`L02HV9P0W9bL0<C4a08J6QP3Cdm<0XJ6Q051@D00/;2`08b<S01lO7`0T92@0;Rh^02d];@0P8200
6QXJ01TI6@0N7Qh0:BTY04A4A01^KVh0c/k>0;Vi^@1>CTh0;Bd]06YZJP0a<C40:BTY03<c<`1RHV80
5aLG01@D500Q8B40De=C07emO@1_Kfl0QHF507UiN@2JVYX0Zj^[06i^KP0U9BD0>3Ph09bLW00T92@0
9BDU02l_;`11@D40De=C04M7A`0g=cL00P0f=SH06`0h>3P0@D5105UIF@25QHD0YJFU059BDP16ATH0
F5QH055AD@2KVi/0BTY:01TI6@0E5AD05aLG02@T901;Bd/0MGEe08R8R02YZJT0^;Rh0;jn_P3Bd]80
_kno0:BTY01IFET09bLW01dM7@0201lO7`1301`L701_Kfl0WYjN07MgM`0j>SX0ADE504Y:BP0L71`0
6ATI01HF5P0J6QX07alO04U9B@1SHf<07alO01dM7@0X:2P0;2`/05aLG00e=CD0;bl_096AT@3Fe]H0
]KFe05iNGP1PH600M7Ad06i^KP2?Shl0LG5a08j>SP1/K6`0DE5A075aL@0d=3@07AdM01TI6@0J6QX0
7alO09ZJVP26QXH0IFEU05IFEP0L71`06QXJ01/K6`0I6AT06QXJ01dM7@0Q8B40<C4a06a/K02f][H0
H61P04=3@`0i>CT0>3Ph04e=C@1UIFD05ADE01/K6`0Y:BT0:b/[02DU9@0Y:BT0@D51051@D002oooo
o`000?l0T92@07EeM@1MGEd0H61P0451@@1mOGd0?Cdm05ADE01KFe/0<c<c04=3@`1IFET0EEEE028R
8P13@d<0;Rh^02XZ:P1QHF40:2PX05IFEP0S8b<0=cLg065QH@12@T80CTi>04];B`0D51@0@d=305AD
E00f=SH0EUIF05UIF@0Y:BT07QhN03`l?00N7Qh0?3`l05iNGP0J6QX09BDU06m_K`1]KFd0?Shn03Ti
>@1OGel09bLW04I6AP0P8200=cLg01`L701>CTh0IVIV03dm?@0/;2`0ATI6038b<P0d=3@0KFe]02h^
;P1TI6@0IfMW04m?C`0[:b/0<C4a04a<C019BDT0=3@d04I6AP1XJ6P0Bd];05ADE00d=3@0BTY:01DE
5@0g=cL0L71`03dm?@0f=SH0OWin06=SH`0Z:RX0BDU902TY:@0Z:RX0B4Q803Ti>@0^;Rh0FEUI02DU
9@0c<c<0EeMG055AD@0O7al0IVIV05YJFP0/;2`0EeMG07emO@1EEED0SHf=06m_K`1aLG40IfMW01lO
7`24Q8@0H61P02/[:`0g=cL0Fe]K04M7A`1]KFd0QXJ60;Zj^P1GEeL0<30`05YJFP12@T80Cdm?02/[
:`1?Cdl0HV9R02d];@1>CTh0I6AT02l_;`0o?cl0Ogmo05iNGP1SHf<0J6QX04];B`27QhL0GemO04m?
C`1_Kfl0FEUI03De=@1/K6`0IVIV06EUI@1WIfL0EEEE065QH@0o?cl0DU9B06e]K@1NGUh0@d=309FE
U@1_Kfl0LW9b04a<C010@400RHV906i^KP0e=CD0;Bd]08F5Q@1JFUX0G5aL06m_K`0m?Cd0/k>c08F5
Q@1UIFD0@41005QHF019BDT0?3`l03hn?P1DE5@0CDe=03dm?@2@T900Bd];08F5Q@1]KFd0DE5A07em
O@1fMWH0JVYZ0;jn_P1]KFd0BDU905MGE`2NWYh0TI6A05EEE@0g=cL0=SHf0861P@2@T900Bd];059B
DP2CTi<0F5QH0861P@39bLT0V9RH069RHP1ZJVX0LG5a071`L01RHV80ATI6038b<P1HF5P0Q8B403lo
?`1cLg<0<c<c02h^;P2<S8`0IfMW03@d=01WIfL0ADE503@d=010@400VIVI05YJFP0j>SX0OGem04e=
C@1GEeL0IVIV03lo?`1>CTh0WinO04i>CP1DE5@0;bl_07IfMP1KFe/0Ng]k04i>CP2JVYX0DE5A09RH
V01GEeL09bLW06=SH`1fMWH0IVIV07AdM01SHf<0<30`061PH021PH40>c/k04A4A01]KFd0VIVI05YJ
FP0W9bL005/0>c/k06YZJP0b<S80;Rh^07moO`28R8P0<S8b04m?C`1_Kfl0Hf=S04A4A025QHD0AdM7
02DU9@1CDe<0ATI603Ph>02@T900IfMW06QXJ00Y:BT0@D5105MGE`0e=CD0820P05EEE@1eMGD0?clo
02`/;01SHf<0K6a/03lo?`0g=cL0T92@06EUI@0e=CD0CTi>09JFUP1nOWh0<c<c07MgM`1VIVH0B4Q8
04e=C@24Q8@0L71`05QHF02>SXh0@41007IfMP2UYJD0IVIV03Xj>P2IVIT0[Jf]03Hf=P0X:2P0=cLg
06EUI@1cLg<0=CDe024Q8@2d];@0OWin03`l?00`<300>SXj02HV9P0O7al071`L01TI6@0`<300BTY:
04M7A`1MGEd0QHF505EEE@16ATH0K6a/03`l?00X:2P05ADE01PH601aLG40UiNG0:BTY02=SHd0_[jn
0=?Cd`1JFUX07alO00<05ADE01h03@d=00h>3P0=3@d04A4A04A4A01NGUh09BDU01TI6@0i>CT0=CDe
08B4Q00f=SH04A4A01<C4`0B4Q803`l?010@400=3@d03`l?01`L702ATI40RHV902<S8`0K6a/06ATI
03<c<`2ATI40?Cdm014A4@0@4102014A4@0E01<C4`0D51@051@D01<C4`0D51@04a<C020P800Q8B40
5QHF01`L700M7Ad0D51@06ATI01ADE40B4Q801dM7@0E5AD03Ph>014A4@0@410051@D00805ADE01@0
4A4A01HF5P0A4A40410@00d=3@0A4A40@D5104m?C`0b<S807AdM01hN7P0E5AD0EEEE0410@00V9RH0
FUYJ0<o?c`36a/H0GUiN02@T90807QhN00<0:RXZ03@d=00Z:RX02@0E5AD0:P15ADD0>SXj06][J`24
Q8@0MWIf04a<C01PH600_kno05IFEP15ADD0:2PX024Q8@0R8R80;Rh^04Q8B01dM7@0IFEU034a<@14
A4@0:BTY0492@P0K6a/05QHF01lO7`0T92@07QhN02`/;029RHT0I6AT02@T900M7Ad06QXJ020P8012
@T80MWIf06YZJP0h>3P0;2`/02LW9`1>CTh0>c/k01`L70807AdM00H07alO01dM7@0M7Ad0=SHf0<_;
b`28R8P201TI6@0b02LW9`0`<300=SHf0:^[Z`2DU9@0G5aL05=CD`1KFe/0>CTi04a<C01KFe/0C4a<
05eMG@1:BTX0?Cdm028R8P0V9RH0<30`03Ti>@1`L700gmoO0>3Ph025QHD0=SHf034a<@1GEeL0=SHf
05=CD`2:RXX0EUIF06YZJP1VIVH0@d=302HV9P1ZJVX0N7Qh04E5A@1WIfL0@d=309>CT`1lO7`0J6QX
0:JVYP14A4@0ATI607YjNP1GEeL0<C4a01LG5`0N7Qh301dM7@0K024Q8@0_;bl0ATI607MgM`1CDe<0
=3@d03Hf=P1VIVH0Xj>S0:^[Z`1GEeL07AdM03Hf=P1KFe/0DU9B04Q8B01SHf<0UIFE0;Zj^P2<S8`0
]kNg0;Rh^01PH600=3@d028R8P0N7Qh09BDU0080?Cdm02`0XZ:R05QHF01IFET0Hf=S03@d=00j>SX0
8b<S01/K6`0G5aL06ATI02PX:01FEUH0>SXj01`L700N7Qh09BDU03Ti>@0l?3`09BDU02HV9P1GEeL0
eMGE07IfMP0O7al06a/K028R8P0_;bl0JFUY06MWI`2>SXh0De=C04m?C`1`L700D51@04e=C@0n?Sh0
8R8R02l_;`1gMgL0BTY:04a<C01OGel0820P01HF5P805ADE01@06a/K01dM7@0U9BD0?Shn0;Jf]P2<
S8`0BTY:03<c<`0`<300<c<c0492@P1^KVh06QXJ020P800];Bd08R8R024Q8@0T92@0:BTY055AD@;o
oooo0000V`2CTi<0LW9b061PH01DE5@0@D5107IfMP0o?cl0AdM708>3P`0n?Sh0FEUI05EEE@11@D40
<c<c06e]K@1JFUX09BDU05UIF@0^;Rh0GUiN051@D00[:b/0EUIF03De=@1MGEd0L71`02l_;`11@D40
H61P02DU9@0l?3`0DE5A04Y:BP0I6AT0:b/[01DE5@0N7Qh0De=C04I6AP0M7Ad0@D5105QHF00[:b/0
A4A407MgM`0b<S80>CTi02@T901RHV80CDe=05QHF01RHV809BDU038b<P1;Bd/0@T9203Ph>01^KVh0
:BTY051@D01QHF40I6AT034a<@0d=3@0FUYJ02l_;`0S8b<0ATI606ATI01DE5@0JFUY03Lg=`0j>SX0
6QXJ04A4A01mOGd0?3`l02d];@1[Jf/0=cLg02l_;`19BDT0D51@0451@@15ADD05QHF03De=@1OGel0
>3Ph04Y:BP1FEUH0BDU901HF5P0o?cl0Jf][03hn?P1TI6@0Ph>304e=C@2ATI40GemO075aL@1SHf<0
;Bd]0:^[Z`27QhL0>3Ph03hn?P1GEeL0<c<c04m?C`2SXj<0][Jf059BDP0`<300IfMW04M7A`1KFe/0
@D5106UYJ@1bLW80>CTi04m?C`1_Kfl0?clo04I6AP25QHD0GemO06][J`1`L700Hf=S0:ZZZP1NGUh0
@T9206e]K@1WIfL0AdM706i^KP1aLG40I6AT06YZJP1LG5`0Cdm?05ADE01IFET0MGEe06m_K`1<C4`0
Vi^K06EUI@2BTY80@d=3038b<P28R8P0FEUI0080;2`/03X0P820059BDP1GEeL0MGEe03Hf=P2UYJD0
QHF506i^KP1?Cdl0L71`0492@P0g=cL0@41005QHF019BDT0@D5108V9R@17AdL0RHV9075aL@12@T80
GemO05ADE01FEUH0]KFe08N7Q`1HF5P0FUYJ07alO02TY:@0@D5103dm?@1dM7@0YJFU0:JVYP1BDU80
E5AD092@T01IFET0OGem0=CDe02/[:`0JFUY09RHV02JVYX0KVi^096AT@1cLg<0=3@d03De=@25QHD0
A4A407MgM`1SHf<0;Rh^08V9R@1EEED0<C4a0P1kNg/01`1RHV80Fe]K0:>SX`1@D500EUIF09BDU01N
GUh00P1CDe<01P0i>CT0KVi^0:BTY024Q8@0J6QX038b<P80K6a/08<0I6AT04U9B@2e]KD0VYZJ09BD
U01RHV80;Rh^05IFEP18B4P0H61P096AT@1OGel0<30`06=SH`20P800DE5A03/k>`15ADD0Rh^;05YJ
FP0o?cl0EEEE07]kN`1bLW80@D51051@D029RHT0>c/k06UYJ@2=SHd0I6AT02h^;P1RHV80J6QX0492
@P1LG5`0EeMG05UIF@2YZJT0J6QX06ATI00j>SX0GemO07QhN01HF5P06a/K03`l?01:BTX05ADE02<S
8`20P800QhN705iNGP0e=CD0Ogmo06m_K`0b<S80<C4a061PH01/K6`0;2`/05iNGP1OGel0?clo02DU
9@1gMgL0M7Ad065QH@1gMgL07QhN03Ti>@1dM7@0@T9203Hf=P2OWil0Jf][05QHF00R8R80;2`/05eM
G@1OGel092@T01lO7`2UYJD0V9RH03Hf=P0c<c<0=cLg02DU9@0O7al06QXJ01TI6@0T92@0D51@03hn
?P0e=CD0=SHf09BDU012@T80O7al06m_K`0/;2`08b<S02@T902k^k/0b<S80=?Cd`32`/80emOG0:b/
[02EUID0QHF505MGE`1NGUh0?clo02l_;`0X:2P07QhN02`/;01RHV809bLW01DE5@0C4a<06a/K02`/
;022PX80?Cdm01/K6`0H61P04Q8B01@D500200h>3P0>014A4@0I6AT0IVIV0:ZZZP0k>c/05aLG01XJ
6P1PH600b/[:06YZJP0Q8B404A4A010@400C4a<2014A4@0601<C4`0D51@05ADE01DE5@0I6AT0>3Ph
0P0J6QX02`0L71`0KVi^08b<S01gMgL0<c<c01LG5`0E5AD0410@01<C4`0A4A40410@00@05ADE00P0
4A4A010@400>3Ph0410@01`L701IFET0>CTi01dM7@806QXJ00l0EEEE0492@P0`<300;bl_09ZJVP2:
RXX07AdM01TI6@0K6a/0820P02/[:`0`<300:BTY01DE5@0F5QH01`0E5AD07`0o?cl0?Shn055AD@0c
<c<0;Bd]03<c<`0m?Cd0Kfm_03<c<`0W9bL08B4Q02<S8`0W9bL092@T02XZ:P14A4@0I6AT08n?S`2L
W9`0Ogmo038b<P0G5aL05ADE01dM7@0];Bd07AdM024Q8@23Ph<0S8b<02h^;P0H61P00P0L71`0300N
7Qh0=3@d059BDP17AdL0;bl_01lO7`0];Bd0PX:2020P800H61P06a/K028R8P807alO02@0@D5108n?
S`1^KVh07AdM01DE5@0U9BD0=3@d04];B`28R8P0CDe=09ZJVP0n?Sh0;Bd]04A4A01JFUX0V9RH0:JV
YP2MWId0aLG509:BTP0[:b/09BDU02/[:`0m?Cd0WYjN0=cLg03Rh^80clo?07inOP0^;Rh0HF5Q07in
OP1NGUh0M7Ad07YjNP0f=SH201LG5`0j01PH601_Kfl0CDe=05YJFP1kNg/092@T02DU9@1/K6`0_[jn
0:n_[`1IFET0@4100451@@0Q8B406a/K01XJ6P0L71`07AdM02<S8`0W9bL0:2PX02l_;`15ADD0_kno
0=3@d02IVIT0PH6108F5Q@3AdM40h^;R0;Jf]P2LW9`0Jf][04U9B@1:BTX0F5QH06i^KP1PH600^[Zj
08n?S`1IFET0SXj>09fMW@1mOGd0BDU904A4A01OGel0P82009bLW02n_[h0IfMW05ADE01dM7@0SXj>
059BDP1DE5@0>SXj02XZ:P80;Bd]00d0I6AT024Q8@0Q8B408b<S03@d=01kNg/0@41003Lg=`0];Bd0
Ng]k09VIV@0^;Rh06QXJ00806a/K02P0A4A406a/K01nOWh0FEUI03dm?@0f=SH0F5QH06ATI00];Bd0
?3`l06YZJP2WYjL0HF5Q03/k>`0j>SX0MWIf04e=C@0Q8B40:b/[03Xj>P1MGEd0QXJ60:ZZZP3De=@0
emOG0;>c/`0m?Cd0:RXZ03Xj>P0c<c<0=cLg07QhN00a<C408b<S02HV9P0N7Qh07AdM01lO7`0[:b/0
Lg=c0_ooool0001g08f=S@1FEUH0DU9B05]KF`12@T80S8b<03hn?P1;Bd/0Shn?04A4A01>CTh0GUiN
04a<C00R8R80ATI605ADE00W9bL0=SHf028R8P1BDU80De=C02HV9P1FEUH0A4A403dm?@1ZJVX0<C4a
03<c<`1IFET0>CTi03dm?@19BDT0=cLg01TI6@0/;2`05aLG02/[:`1HF5P0E5AD024Q8@10@400Kfm_
04e=C@0W9bL0LW9b03@d=00o?cl06ATI05UIF@1NGUh0E5AD061PH00b<S808R8R03hn?P1EEED0=SHf
08Z:RP0n?Sh0H61P05eMG@1fMWH0?Shn034a<@1RHV80MWIf02TY:@0j>SX0Lg=c04m?C`1GEeL0;Rh^
04a<C00O7al0;Rh^07YjNP1>CTh07AdM07EeM@1GEeL0;2`/03/k>`0_;bl0;Rh^03`l?00];Bd0=3@d
05iNGP0c<c<0D51@05iNGP1JFUX05QHF05=CD`1cLg<0ADE507MgM`2NWYh0L71`08n?S`1eMGD0JVYZ
04I6AP0L71`0JFUY05YJFP0e=CD0ADE506=SH`11@D40BDU90;Fe]@30`<00Lg=c03`l?01bLW80<c<c
08>3P`1ADE400P1YJFT04@0e=CD0NWYj06][J`10@400ATI608R8R01?Cdl0R8R806YZJP1LG5`0b<S8
05UIF@1HF5P0PX:206a/K014A4@0LW9b0080Jf][00<0S8b<05iNGP15ADD00P1ADE40d`2KVi/0MgMg
03/k>`2UYJD0@D5105UIF@1BDU80>3Ph08J6QP2<S8`08R8R03<c<`2KVi/0NWYj06IVIP1gMgL0@410
0:FUY@2GUiL0K6a/061PH02ATI40FUYJ03Xj>P1KFe/0Q8B4069RHP0e=CD0Rh^;03hn?P2EUID0Ph>3
04];B`1JFUX0Cdm?03Ti>@2VYZH0ZZZZ08:2PP1LG5`0UiNG0<S8b01NGUh0=CDe03Lg=`1oOgl0N7Qh
05MGE`22PX80ZZZZ05]KF`18B4P0][Jf07EeM@16ATH0LW9b061PH013@d<0ATI605=CD`0f=SH0BTY:
05EEE@1<C4`0Rh^;07UiN@0a<C40Shn?04];B`0U9BD0GEeM05]KF`1LG5`0IFEU0:FUY@1bLW809bLW
071`L01@D500N7Qh092@T00o?cl0?Cdm09RHV016ATH0HF5Q02h^;P1bLW80OWin08>3P`10@400K6a/
04m?C`2>SXh0FUYJ05EEE@1lO7`0A4A403lo?`1MGEd0>CTi04=3@`2ATI40TY:B075aL@0n?Sh0AdM7
07YjNP0Q8B40=SHf04A4A01[Jf/0LG5a0410@01<C4`0RXZ:01TI6@1HF5P0UiNG08V9R@0k>c/0Lg=c
071`L00`<300Ogmo08F5Q@1QHF40[:b/096AT@15ADD0:RXZ0492@P1RHV80HF5Q01dM7@0l?3`0ATI6
03Hf=P0R8R80DU9B08:2PP1@D500<30`06e]K@1cLg<0ATI604A4A01SHf<0N7Qh03Hf=P0n?Sh0De=C
04e=C@0];Bd0SHf=08b<S01HF5P0PH6103Lg=`15ADD0Rh^;04a<C00h>3P0YJFU08>3P`1RHV809bLW
034a<@1LG5`0H61P02XZ:P0[:b/0X:2P09NGU`0g=cL0@410034a<@0S8b<07AdM01XJ6P0G5aL0:RXZ
030`<01hN7P0De=C02`/;035aLD0b/[:0<C4a031`L40Ph>3075aL@1PH600b<S80<k>cP36a/H0e=CD
0;bl_012@T80LW9b04U9B@1IFET0Hf=S075aL@1/K6`0Shn?08b<S02k^k/0OGem01LG5`0D51@00P0E
5AD06`0^;Rh0Q8B404Q8B00L71`06ATI01/K6`0k>c/05aLG00l?3`0E5AD07QhN05IFEP2g]kL0AdM7
03hn?P2ATI40c/k>0=oOg`3Hf=P0]KFe0820P01OGel0<C4a01`L700C4a<05ADE01@D500201<C4`0>
01LG5`0i>CT0=cLg01lO7`0Z:RX0T92@0:b/[01cLg<0:b/[01LG5`0C4a<04A4A010@400C4a<301DE
5@0301HF5P0A4A40410@00<0410@00@05ADE05aLG015ADD09BDU0P0K6a/01P1GEeL0E5AD02/[:`0h
>3P0Z:RX07MgM`<071`L00@07AdM02<S8`0d=3@0;2`/200E5AD01P0L71`0ADE504U9B@1?Cdl0>c/k
02TY:@806a/K07h0>SXj05]KF`0Z:RX0:BTY03Hf=P0d=3@0=CDe038b<P0o?cl0I6AT05MGE`1nOWh0
^KVi04I6AP0J6QX05aLG03De=@0k>c/0820P02<S8`29RHT0b/[:07emO@0U9BD061PH01XJ6P0K6a/0
9bLW02l_;`1=CDd0B4Q8024Q8@0T92@0YZJV08Z:RP11@D407alO01dM7@0O7al08b<S06e]K@1`L700
NWYj04=3@`0I6AT08B4Q03<c<`1aLG40CDe=03@d=01bLW80>c/k03@d=00b<S80;2`/03Lg=`1`L700
XZ:R0<30`02OWil0D51@0410@01:BTX0YZJV0<c<c034a<@0U9BD0:JVYP3;bl/0[Zj^06m_K`2@T900
O7al05mOG`2LW9`0>CTi02TY:@0Q8B40;Bd]09BDU01:BTX0SXj>059BDP15ADD0;2`/02HV9P2TY:@0
^k^k09BDU00e=CD0;bl_01/K6`0I6AT06a/K01dM7@0V9RH0=3@d05IFEP1=CDd0L71`08R8R02o_kl0
a/K6065QH@1>CTh0Xj>S0>CTi037alL0`l?30;Ng]`1kNg/0PX:206EUI@1QHF40A4A4079bLP3;bl/0
ATI601LG5`1aLG40dm?C0<30`02`/;00Ti>C06EUI@10@40203`l?00L04m?C`1eMGD0UYJF0<30`02h
^;P0][Jf0<C4a02UYJD0[:b/0;:b/P2NWYh092@T02HV9P15ADD0P820096AT@1DE5@0De=C05MGE`2G
UiL0G5aL01DE5@0I6AT06a/K038b<P1?Cdl0O7al07UiN@809bLW01L0:BTY0410@01hN7P0CDe=02XZ
:P0k>c/0De=C06QXJ01ADE40:b/[092@T03Jf]X0`<300<[:bP3>c/h0a<C40<W9b@2^[Zh0]KFe0:FU
Y@1iNGT0?clo04=3@`0203lo?`0304=3@`1UIFD0HF5Q00807AdM00D06a/K01lO7`0f=SH0DU9B0;6a
/@02ooooo`000?X0YjNW08:2PP1BDU80?Cdm04Y:BP21PH40?Shn03dm?@1MGEd0BDU907=cL`23Ph<0
Lg=c02@T900o?cl0Cdm?04U9B@1XJ6P0ADE505=CD`1BDU80<30`06ATI01CDe<0@T9205aLG00[:b/0
C4a<069RHP14A4@0>SXj04I6AP0T92@0:BTY04a<C00R8R80:b/[05QHF01ADE409BDU03dm?@1/K6`0
EEEE02d];@1aLG40;2`/03Hf=P0K6a/0GEeM06e]K@1@D500GemO05=CD`15ADD0BDU906UYJ@0`<300
VYZJ04A4A01OGel0DE5A06][J`15ADD0<c<c06EUI@1gMgL0;bl_03hn?P1gMgL0DE5A05MGE`14A4@0
LG5a038b<P0_;bl0Rh^;06=SH`0M7Ad0QhN70861P@0h>3P0CTi>04I6AP14A4@0HV9R03Ti>@0e=CD0
HF5Q02h^;P1CDe<0Kfm_059BDP0E5AD0Fe]K059BDP0b<S80L71`09:BTP1[Jf/0TI6A07=cL`1dM7@0
KVi^02@T901mOGd0IFEU03Ph>01;Bd/0HF5Q03dm?@0^;Rh0TY:B08b<S01EEED0:b/[04i>CP0S8b<0
DU9B03De=@1`L700M7Ad02TY:@0o?cl0G5aL04=3@`1JFUX0UIFE03`l?01aLG40NGUi06EUI@3Cdm<0
DE5A03Hf=P1HF5P0HF5Q05mOG`2FUYH0I6AT04a<C01MGEd0@T9205=CD`1NGUh0CDe=07EeM@1CDe<0
BDU909>CT`1cLg<0JFUY04E5A@0_;bl0UiNG08B4Q017AdL09RHV07]kN`1MGEd0GUiN08:2PP0/;2`0
Q8B4079bLP0m?Cd0GEeM08N7Q`1JFUX0?3`l04U9B@1BDU80EUIF051@D02<S8`0:b/[07YjNP2HV9P0
DE5A08J6QP1mOGd0Cdm?09ZJVP2g]kL0A4A404E5A@2IVIT0/K6a08F5Q@1=CDd0=CDe07AdM029RHT0
D51@05QHF021PH40NWYj03Ph>034a<@0UYJF07AdM01nOWh0M7Ad07EeM@15ADD0?Cdm02l_;`23Ph<0
JVYZ03/k>`1OGel0@T9203De=@2PX:00IVIV030`<01UIFD0FUYJ02@T9018B4P0QHF506MWI`0T92@0
LW9b03Xj>P16ATH0GemO04U9B@13@d<0ZZZZ04M7A`1`L700>3Ph04m?C`1RHV80LW9b03lo?`1oOgl0
DE5A0:FUY@1:BTX0:2PX06=SH`1OGel0EeMG06YZJP1UIFD0;bl_06][J`2HV9P0Lg=c0P11@D403P1/
K6`0>CTi02h^;P0o?cl0JVYZ07MgM`0o?cl0D51@07]kN`0m?Cd0CTi>07MgM`1^KVh0:BTY0P1OGel0
CP0`<300J6QX04Y:BP16ATH0Zj^[08>3P`1VIVH0;bl_0451@@1FEUH0IVIV028R8P0g=cL0DU9B030`
<00V9RH0CDe=079bLP1:BTX0<c<c07alO01PH600Bd];04U9B@1IFET0I6AT04=3@`0j>SX0NGUi06MW
I`1FEUH0Z:RX08N7Q`1MGEd0WIfM05EEE@19BDT0QHF504E5A@14A4@0XJ6Q09JFUP1XJ6P09RHV02l_
;`1NGUh0ADE5018B4P0`<300Kfm_08j>SP12@T80B4Q802d];@0R8R807alO01`L700K6a/0@41003lo
?`1RHV80Z:RX0<_;b`3Fe]H0UIFE0:BTY02VYZH0VIVI0;Jf]P3EeMD0fMWI0;>c/`3EeMD0gmoO09>C
T`0S8b<0Cdm?030`<0807AdM00P06QXJ01TI6@0U9BD06ATI04m?C`2WYjL0FUYJ01PH60805ADE00@0
6a/K08^;R`1?Cdl06a/K0P0E5AD08`0H61P06a/K01<C4`0L71`07AdM075aL@2e]KD0cLg=0<O7a`3>
c/h0d];B0=CDe03Bd]80`/;20;fm_@30`<00^[Zj09fMW@1nOWh0JFUY04i>CP0c<c<0<S8b04I6AP2?
Shl0YZJV04m?C`1<C4`0Y:BT08B4Q01HF5P08B4Q01<C4`0E5AD0410@00804a<C00@051@D01DE5@0E
5AD05ADE0`0?3`l05`0>3Ph04A4A00d=3@0j>SX0KVi^02<S8`0P82005aLG06UYJ@1[Jf/0Bd];0:2P
X03De=@0O7al04i>CP0k>c/06ATI01`L700M7Ad0;bl_034a<@0E5AD051@D00@05ADE02D04a<C01DE
5@0G5aL0Jf][09BDU01dM7@0;Rh^03<c<`0N7Qh05QHF01`L701hN7P0P82005UIF@1DE5@0Bd];04a<
C01IFET0JFUY09:BTP2TY:@0^[Zj0<K6aP1jNWX0CDe=04i>CP23Ph<0VYZJ02l_;`1QHF40/k>c0:2P
X02SXj<0MgMg03Hf=P0L71`05aLG00807QhN01H0=3@d05UIF@0/;2`07alO069RHP16ATH0P82008n?
S`17AdL0<S8b02l_;`1YJFT0H61P06MWI`1ADE406QXJ020P801DE5@0Ogmo04Q8B00^;Rh0GEeM0P0E
5AD0H`0V9RH0CDe=03lo?`0o?cl0D51@06][J`2OWil0VIVI08^;R`2l_;`0PH61055AD@2_[jl0Ti>C
09ZJVP2NWYh0Xj>S0=7Ad@2c/k<0SXj>08n?S`1FEUH0L71`08F5Q@28R8P0/[:b0<71`@1NGUh0_;bl
03Ti>@0S8b<071`L0492@P2?Shl0WIfM05=CD`1IFET0IFEU01XJ6P0G5aL06a/K01XJ6P0M7Ad0AdM7
04m?C`15ADD0@41005aLG02>SXh0UIFE0;Zj^P37alL0XZ:R0:n_[`39bLT0`l?30<[:bP3IfMT0c<c<
09:BTP1OGel0TI6A07MgM`2/[:`0:BTY01dM7@24Q8@0Fe]K038b<P0`<300;2`/04=3@`1ZJVX0KFe]
05aLG017AdL0JFUY0;:b/P2KVi/0JFUY05IFEP1LG5`0R8R808n?S`1GEeL0VIVI06a/K010@400RXZ:
05QHF00Z:RX0ADE5055AD@2=SHd0XJ6Q04E5A@0K6a/05aLG02`/;00204U9B@0W079bLP1HF5P07alO
01`L700O7al0=CDe04i>CP2GUiL0?Cdm04U9B@14A4@0F5QH03<c<`14A4@0]kNg0=KFeP2f][H0YjNW
0:VYZ@2MWId0Q8B408>3P`2ZZZX0Cdm?07EeM@1XJ6P0?Cdm01hN7P0/;2`0@D51059BDP2=SHd0;2`/
02h^;P0i>CT0B4Q8059BDP1dM7@0VIVI00;ooooo0000]@1eMGD0GemO05IFEP1EEED0>c/k061PH015
ADD0GEeM06IVIP10@400;Bd]05ADE01WIfL0:BTY04Y:BP0i>CT07AdM04e=C@0g=cL0HV9R028R8P0S
8b<0IfMW06QXJ013@d<0Fe]K01LG5`0K6a/0ADE503dm?@0e=CD0BDU902@T900C4a<0<C4a030`<00[
:b/0H61P01/K6`0M7Ad0A4A406a/K01CDe<0<C4a092@T00U9BD0C4a<028R8P0l?3`0;Bd]05ADE01m
OGd0F5QH03Lg=`1HF5P0?3`l02d];@27QhL0ATI6069RHP1WIfL0D51@03@d=013@d<0MWIf06][J`0l
?3`0IFEU06YZJP0a<C40>3Ph03Lg=`1`L700;Rh^038b<P2CTi<0=CDe01dM7@1fMWH0O7al0410@01`
L700CTi>04I6AP13@d<0<c<c03lo?`1`L7008b<S04=3@`1mOGd0H61P020P801XJ6P0NWYj03/k>`1Z
JVX0SXj>05ADE02VYZH0ZZZZ09VIV@1`L700820P09BDU01VIVH0<c<c071`L01oOgl0?clo04=3@`36
a/H0ZJVY06YZJP0^;Rh0K6a/03`l?01@D500;Bd]0410@01aLG40>c/k04M7A`1BDU80<C4a04a<C01`
L700Fe]K071`L012@T80HV9R0;^k^`1WIfL0ATI605MGE`0i>CT0CDe=05UIF@1]KFd0DE5A05UIF@0k
>c/0>CTi05aLG01IFET0Lg=c05YJFP17AdL0Ph>306YZJP1PH600<S8b02@T9021PH40KVi^02PX:00V
9RH0NGUi071`L01IFET0Ph>303Ti>@2<S8`0W9bL06][J`1CDe<0LW9b06=SH`17AdL0BTY:04i>CP16
ATH0<C4a07inOP1>CTh0Ph>307AdM00c<c<0F5QH06m_K`1IFET00P2IVIT0/`1QHF40EEEE08N7Q`2R
XZ80Ti>C06ATI00i>CT0OGem09VIV@1DE5@0Fe]K08F5Q@1/K6`0BDU90<O7a`2ZZZX0LG5a09>CT`1l
O7`0Lg=c04I6AP0n?Sh0;Rh^04M7A`1kNg/0@T92065QH@13@d<0<C4a08F5Q@1EEED0;2`/06EUI@1I
FET0ATI606QXJ028R8P0Hf=S02LW9`1^KVh0C4a<05iNGP1[Jf/0@41003hn?P2m_Kd0G5aL06QXJ00i
>CT0IVIV075aL@29RHT0ADE508J6QP1_Kfl0SHf=06][J`0g=cL0I6AT06m_K`1EEED0IFEU07QhN00d
=3@0KFe]09ZJVP24Q8@0ADE50410@022PX80HV9R03<c<`13@d<0NGUi07YjNP10@400CTi>08>3P`16
ATH0HV9R08Z:RP1aLG40<C4a059BDP1/K6`0ATI607YjNP1<C4`0DE5A0;Zj^P2>SXh0H61P03Xj>P14
A4@0F5QH06UYJ@0T92@0Bd];06i^KP0k>c/09BDU0492@P1YJFT0:b/[03/k>`1bLW80Ph>304m?C`1=
CDd0FEUI05iNGP0O7al0GUiN0;Zj^P1cLg<0ADE50:b/[013@d<0De=C09VIV@1DE5@0AdM708Z:RP0j
>SX0>c/k0:b/[02GUiL0M7Ad02PX:00];Bd0Fe]K06e]K@0g=cL071`L05UIF@2?Shl0GemO07YjNP0o
?cl0;2`/028R8P0O7al06a/K02l_;`0Q8B409bLW03Lg=`3:b/X0dm?C0;Ng]`1dM7@0<C4a02l_;`0m
?Cd0c/k>0:j^[P2b/[80^;Rh0:ZZZP35aLD0<c<c03dm?@0l?3`0820P01hN7P0L71`092@T03lo?`0N
7Qh05aLG05=CD`2RXZ80H61P01LG5`0E5AD0;bl_0;no_`1^KVh06QXJ00805aLG02805ADE02/[:`1P
H6006ATI02`/;02[Zj/0h>3P0<_;b`32`/80TI6A06e]K@14A4@0>CTi03/k>`1>CTh0G5aL065QH@1`
L700NGUi08V9R@2=SHd0VIVI09jNWP2OWil0/;2`0;^k^`30`<00emOG0<_;b`1lO7`0IVIV030`<00A
4A40410@0P0>3Ph07P0E5AD03Ph>01DE5@0E5AD04Q8B00h>3P0@41004Q8B00h>3P0@41004A4A02XZ
:P2WYjL0;Rh^024Q8@0L71`0NGUi08F5Q@1oOgl0[:b/0=oOg`2n_[h0E5AD03De=@1@D500@41002d]
;@0d=3@0@41001DE5@804a<C100E5AD0200O7al0GEeM0<71`@35aLD0W9bL05=CD`0a<C40:b/[0P0I
6AT0:`1iNGT0DU9B03Hf=P0i>CT0@T9204i>CP1QHF40Jf][0:FUY@2SXj<0Ti>C0<S8b02i^KT0HF5Q
03Lg=`0i>CT0KVi^09VIV@2YZJT0B4Q802@T901=CDd0QHF506IVIP1KFe/07alO01`L700M7Ad0<30`
03Ph>01UIFD0;2`/05EEE@0N7Qh0JFUY0<[:bP38b<P0bl_;0;:b/P2VYZH0RXZ:08F5Q@2`/;000P2D
U9@0CP3Hf=P0Ogmo03@d=00a<C40D51@01DE5@0H61P05ADE01TI6@1:BTX0];Bd0:VYZ@1@D500>c/k
0:>SX`36a/H0EeMG03<c<`16ATH0G5aL0:j^[P23Ph<0^;Rh0;>c/`3<c<`0SXj>0:BTY013@d<092@T
02DU9@0^;Rh0<S8b04a<C03;bl/0`/;20>3Ph02ATI40ADE502`/;01CDe<0N7Qh09fMW@0n?Sh0=SHf
04E5A@0K6a/05aLG01XJ6P0G5aL071`L02PX:00V9RH0<30`05EEE@19BDT0Jf][0<W9b@3@d=00MGEe
04I6AP17AdL0d];B0=[JfP3GemL0clo?0=7Ad@3MgMd0aLG504E5A@0M7Ad0WYjN03lo?`1ZJVX0GUiN
03<c<`0M7Ad06ATI01PH60805aLG01008R8R04Q8B02g]kL0]KFe0:2PX02DU9@0IfMW05=CD`1QHF40
OWin0:f][@2>SXh0T92@0<?3``2/[:`0CTi>0P0O7al0300U9BD0H61P0;Bd]01mOGd0=CDe02l_;`0U
9BD0C4a<038b<P1?Cdl0L71`034a<@<071`L02807alO03@d=02<S8`0QXJ603dm?@10@400Bd];03/k
>`2BTY80`/;20:BTY01LG5`0CDe=05YJFP0o?cl0:b/[02@T900o?cl0EEEE05QHF01gMgL0C4a<02DU
9@0/;2`0<S8b06QXJ02e]KD0OWin055AD@1BDU80KFe]06YZJP13@d<0<c<c0_ooool0002e079bLP1O
Gel0BDU904m?C`0i>CT0EeMG02LW9`0j>SX0Jf][04a<C010@400G5aL05YJFP0h>3P0QhN706QXJ00/
;2`0@D5103<c<`1PH600C4a<020P801>CTh0@T92059BDP1bLW80>CTi03<c<`0i>CT07QhN02l_;`1?
Cdl0>3Ph01PH600g=cL09BDU03<c<`1EEED0Bd];020P800/;2`0C4a<01LG5`0V9RH0GEeM01dM7@0S
8b<0820P04i>CP19BDT0ADE504i>CP0U9BD0@41007AdM01HF5P08b<S065QH@0U9BD0De=C075aL@1Q
HF40=CDe02`/;02KVi/0=cLg02DU9@14A4@0J6QX04Y:BP1>CTh0<30`051@D00R8R80AdM708N7Q`1R
HV805QHF0820P00c<c<0;2`/069RHP1/K6`0BDU90410@00O7al0>c/k07moO`14A4@0@d=307MgM`1D
E5@06ATI05UIF@1gMgL0BDU906i^KP29RHT0@d=3059BDP14A4@0IfMW06IVIP0M7Ad0JFUY05UIF@0^
;Rh0@T9204a<C010@400A4A40;Vi^@2a/K40GEeM02l_;`1LG5`0;Rh^04m?C`0l?3`0E5AD07MgM`0g
=cL0A4A406ATI01>CTh0Cdm?08J6QP1MGEd0Fe]K08>3P`25QHD0c<c<06UYJ@14A4@0C4a<06MWI`1A
DE40Fe]K07emO@1>CTh0Fe]K03Ti>@17AdL0CTi>05ADE01UIFD0GemO05MGE`2EUID0LG5a05]KF`10
@400:b/[08B4Q01gMgL0?Shn02DU9@22PX80QXJ607MgM`1mOGd0@41008J6QP2YZJT0JFUY055AD@1b
LW80De=C03dm?@1;Bd/0EeMG05UIF@0c<c<0TI6A055AD@1kNg/0LW9b055AD@1DE5@0Cdm?04Y:BP02
09:BTP2e051@D01?Cdl0Ogmo07alO02>SXh0C4a<061PH02BTY80VYZJ05IFEP1OGel0QXJ604e=C@13
@d<0][Jf0:6QX@1SHf<0P82007=cL`1<C4`0DU9B06e]K@0d=3@0@4100820P01=CDd0PH6106QXJ013
@d<0O7al06][J`0l?3`0O7al069RHP1OGel0IFEU09^KV`1KFe/0?3`l08F5Q@1NGUh0IFEU07MgM`0a
<C40H61P09RHV02JVYX0RXZ:04=3@`1ZJVX0L71`07IfMP0d=3@0Ph>309:BTP2LW9`0IVIV03De=@1I
FET0Bd];04M7A`1]KFd0IVIV03`l?01YJFT0TI6A07UiN@12@T80B4Q808n?S`1NGUh0<30`0451@@1g
MgL0LW9b04U9B@1bLW80VIVI05eMG@1IFET0SXj>05aLG012@T80QHF508Z:RP19BDT0QHF506=SH`0g
=cL0U9BD096AT@1UIFD0;Rh^04=3@`1FEUH0<30`02PX:016ATH0JVYZ065QH@0S8b<0?Shn06e]K@1<
C4`0:b/[06QXJ02BTY80ATI6059BDP29RHT0MGEe02PX:00c<c<0QHF505EEE@0V9RH0Vi^K07UiN@14
A4@0Ti>C02<S8`1XJ6P0WIfM05iNGP13@d<0[Zj^0:f][@0c<c<0:RXZ04M7A`1bLW80OGem03Xj>P0S
8b<0H61P08f=S@1JFUX0PX:204m?C`0Z:RX092@T01dM7@0S8b<0;Rh^02HV9P0M7Ad0MGEe06m_K`11
@D40M7Ad08n?S`2DU9@0H61P09jNWP2e]KD0?Cdm024Q8@0/;2`0H61P09FEU@2KVi/0=cLg05QHF011
@D40<S8b02d];@0l?3`0:2PX028R8P0O7al0>SXj07YjNP2[Zj/0<c<c01TI6@1?Cdl0eMGE0:b/[00Z
:RX061PH01LG5`0201DE5@0;059BDP1LG5`0YJFU0;:b/P1iNGT0a/K60=7Ad@2DU9@0E5AD03Ti>@0X
:2P00P0P820201lO7`0C02PX:00f=SH0>CTi03/k>`1?Cdl0FEUI06YZJP1jNWX0QHF507moO`37alL0
e]KF0=[JfP2ATI40MWIf01/K6`0B4Q804A4A018B4P02014A4@0I01<C4`0Z:RX05ADE010@400?3`l0
4Q8B014A4@0?3`l04A4A02`/;036a/H0UiNG05QHF01LG5`0[Zj^0;Rh^038b<P0a/K60>[ZjP3De=@0
QXJ605mOG`0];Bd0=SHf065QH@020861P@0E01hN7P0E5AD05ADE01PH600K6a/0;bl_055AD@2CTi<0
RHV90:NWY`34a<@0][Jf09>CT`1BDU80BTY:02DU9@0K6a/0GemO02TY:@0E5AD05aLG00806ATI02h0
6QXJ01hN7P0o?cl0V9RH0;2`/02RXZ80alO70<[:bP26QXH0>CTi07]kN`32`/80Kfm_028R8P0M7Ad0
7QhN02d];@1nOWh0Cdm?06ATI00k>c/07AdM03De=@19BDT0Cdm?08>3P`2GUiL0L71`065QH@0h>3P0
:2PX04I6AP31`L40S8b<09RHV02_[jl0fm_K0<K6aP3<c<`0d];B08B4Q00j>SX0;Bd]05=CD`0E5AD0
5QHF0P0E5AD09@0S8b<0P82005ADE012@T80?Cdm08f=S@2VYZH0D51@04a<C016ATH0BDU909ZJVP38
b<P0/k>c08^;R`2UYJD0X:2P05QHF01NGUh0=cLg02TY:@0`<300>c/k04e=C@2f][H0dm?C0;Bd]01]
KFd0FEUI06ATI01ADE40CTi>09RHV00m?Cd0>SXj02LW9`0K6a/00P0F5QH04@0K6a/09bLW02TY:@13
@d<0Fe]K04m?C`2QXJ40/;2`0:2PX035aLD0Xj>S0:VYZ@33`l<0gMgM0=KFeP3Cdm<0a/K60080cLg=
00X0_;bl01`L700L71`0Shn?07EeM@1_Kfl0:b/[02LW9`0K6a/061PH0P0G5aL04@0E5AD05QHF02l_
;`2FUYH0_;bl09>CT`2LW9`0Rh^;08b<S00e=CD0CDe=065QH@25QHD0UIFE0<71`@2DU9@0;bl_0080
7AdM00L0:RXZ09FEU@2JVYX0Bd];03lo?`1@D500G5aL0080:BTY01<0IVIV08:2PP0U9BD071`L01/K
6`0I6AT06QXJ01hN7P1ADE40U9BD07YjNP0d=3@0F5QH08B4Q031`L40VIVI04m?C`0`<300:BTY0080
7QhN01<07alO024Q8@0R8R80E5AD05iNGP1^KVh0Ph>304m?C`1LG5`0Ph>30:NWY`26QXH0MWIf06IV
IP1DE5@0>3Ph02<S8`0P82008b<S00;ooooo0000/P1VIVH0Rh^;059BDP1TI6@0>CTi07moO`18B4P0
@D5106e]K@13@d<0A4A405ADE00];Bd08B4Q05IFEP1LG5`0;Bd]020P800V9RH0L71`05YJFP0W9bL0
FUYJ0492@P0e=CD0KFe]034a<@0P8200>SXj02TY:@0S8b<0>SXj02d];@0E5AD0=cLg03hn?P0O7al0
HF5Q06=SH`0Y:BT0;Bd]05IFEP1HF5P09bLW065QH@0T92@08R8R01LG5`1;Bd/0G5aL055AD@1IFET0
<C4a02d];@0e=CD0BDU9020P801dM7@0BDU905QHF01=CDd0H61P04a<C00_;bl0W9bL065QH@0a<C40
@41007MgM`1RHV80B4Q8038b<P15ADD0;Bd]02HV9P26QXH0LG5a01hN7P1PH600GEeM03`l?01BDU80
<30`0492@P0l?3`0@d=303<c<`1oOgl0>c/k0410@01NGUh0MgMg02PX:01ZJVX0N7Qh04=3@`1bLW80
S8b<07MgM`1nOWh0E5AD05eMG@11@D40:b/[0820P01cLg<0=SHf05IFEP1GEeL0<C4a02d];@2OWil0
_kno05MGE`0f=SH0IFEU02PX:01ADE40>c/k059BDP22PX80@41004m?C`1kNg/0EUIF05MGE`2;Rh/0
J6QX07IfMP2:RXX0MgMg0;bl_01YJFT0Bd];06UYJ@1dM7@0I6AT05]KF`1dM7@0FEUI071`L012@T80
EUIF06m_K`1UIFD0RHV907QhN01VIVH0YJFU07=cL`22PX80Jf][03`l?023Ph<0Kfm_03Ti>@0m?Cd0
UIFE09BDU01WIfL0LW9b04=3@`28R8P0Xj>S06ATI018B4P0JVYZ0451@@0k>c/0OWin09nOW`1LG5`0
:b/[07UiN@1:BTX0Zj^[08N7Q`1GEeL2059BDP0[03Ph>020P800WinO0820P01>CTh0QXJ606][J`24
Q8@0F5QH03Lg=`1WIfL0WIfM05aLG01PH600QXJ608>3P`18B4P0`/;209RHV01[Jf/0KVi^07QhN01e
MGD0:b/[0410@00N7Qh09bLW05EEE@0c<c<0HF5Q06a/K00a<C40KVi^06EUI@0R8R80IfMW07inOP1i
NGT0HV9R09>CT`1FEUH0;Bd]07=cL`0204i>CP2007]kN`17AdL0=cLg09VIV@16ATH0HV9R04U9B@1_
Kfl0MgMg08>3P`1CDe<0J6QX04a<C01kNg/0Hf=S02/[:`1DE5@0?Shn0451@@2=SHd0GemO03De=@1S
Hf<0Q8B403De=@19BDT0Lg=c08V9R@1?Cdl0;bl_04E5A@1[Jf/0@D51034a<@1:BTX0L71`04I6AP1O
Gel0TY:B04];B`0R8R80G5aL079bLP0e=CD0Ogmo05eMG@16ATH0WIfM07YjNP1DE5@0?Shn05mOG`1m
OGd0IfMW01lO7`0k>c/0Fe]K03@d=00Z:RX0LG5a07emO@1DE5@0>c/k09FEU@24Q8@09RHV02`/;01M
GEd0OGem04U9B@0k>c/0PX:204M7A`0O7al0GemO07MgM`1<C4`0Rh^;0451@@0i>CT0U9BD0451@@0o
?cl0`/;209RHV01OGel07alO028R8P1<C4`0M7Ad03Xj>P0U9BD0I6AT09JFUP2<S8`0IFEU08Z:RP0k
>c/092@T01`L700b<S809bLW03De=@1LG5`0Cdm?02PX:016ATH0:2PX01PH600`<300820P06UYJ@1N
GUh0=SHf01hN7P0F5QH06ATI04a<C028R8P0ZZZZ0<C4a036a/H0UIFE07moO`2>SXh0P82003/k>`0V
9RH2051@D005096AT@2^[Zh0TY:B0<O7a`39bLT00P2`/;003@1OGel09bLW01TI6@0P8200H61P0;Ng
]`2WYjL0EEEE05iNGP1mOGd0_Kfm09bLW014A4@00P12@T80200l?3`0?clo03Lg=`0O7al06QXJ01LG
5`0E5AD04Q8B0P0E5AD04`0O7al0<30`04m?C`0U9BD0:RXZ06MWI`2c/k<0`/;20<g=c@2IVIT0MgMg
04i>CP0i>CT0=CDe030`<014A4@0XJ6Q05]KF`1DE5@00P0@4103018B4P0U04E5A@1UIFD0Shn?08F5
Q@2FUYH0fMWI0=GEe@2JVYX0bl_;0:j^[P2BTY80];Bd06IVIP1YJFT0CTi>02DU9@1bLW80cLg=092@
T01fMWH0NWYj08>3P`2;Rh/0QhN706=SH`1=CDd0NWYj05MGE`2MWId0Vi^K07=cL`24Q8@0H61P0451
@@14A4@0L71`01`L700401DE5@0]01LG5`0V9RH0?Shn09RHV01TI6@0UYJF0;Rh^02UYJD0d=3@0<W9
b@2ZZZX0Ti>C0:JVYP0b<S806QXJ01LG5`0J6QX0;2`/06YZJP17AdL0G5aL079bLP1OGel0WYjN04U9
B@2][Jd0UIFE08f=S@1lO7`0NGUi06e]K@2KVi/0bl_;065QH@11@D40LW9b08f=S@0_;bl0>c/k05=C
D`1eMGD0FEUI04I6AP1XJ6P07AdM00<05ADE04<0<C4a04=3@`0M7Ad06QXJ02PX:02@T900LW9b02TY
:@0g=cL0Bd];09ZJVP2e]KD0bLW9071`L01CDe<0D51@09nOW`1ADE40>CTi0820P027QhL0Cdm?05=C
D`2KVi/0eMGE0:BTY01jNWX08B4Q03Lg=`2CTi<0KFe]071`L030`<00DE5A04M7A`0X:2P061PH01DE
5@0K6a/071`L024Q8@1@D500GEeM06MWI`2[Zj/0OGem06YZJP1`L700>3Ph04I6AP1MGEd0Kfm_0<30
`03<c<`0e]KF0=kNgP3IfMT0V9RH0;2`/01ADE40CTi>065QH@2DU9@0;Bd]02@T900S8b<05ADE0080
5QHF03T05aLG01PH600n?Sh0I6AT09jNWP1jNWX0CTi>05=CD`2SXj<0TI6A03lo?`1QHF40QhN70:FU
Y@30`<00_Kfm0:RXZ02FUYH0Bd];03<c<`25QHD0][Jf07YjNP0M7Ad0<c<c09nOW`1<C4`0:RXZ03lo
?`2XZ:P0Xj>S02l_;`0K6a/05QHF01LG5`0E5AD06a/K02TY:@15ADD0SHf=0:6QX@2UYJD0[jn_0:RX
Z01[Jf/0?Shn02d];@0O7al06a/K024Q8@0P82007AdM02<S8`0Y:BT0GEeM04A4A01YJFT00`2^[Zh0
2@2TY:@0RHV9059BDP0S8b<07alO01dM7@0N7Qh09BDU02l_;`02ooooo`0002L0IFEU08b<S01DE5@0
KVi^03/k>`27QhL0Cdm?0492@P1iNGT0>c/k05=CD`1ZJVX0OWin03Lg=`1BDU80GUiN034a<@14A4@0
GemO09FEU@1PH600;bl_05aLG01TI6@0?Cdm075aL@0c<c<07AdM04E5A@1EEED0=SHf03hn?P0M7Ad0
51@D03hn?P1SHf<0;2`/06=SH`1bLW800P0e=CD0b01WIfL0IFEU02/[:`1NGUh09BDU02h^;P0M7Ad0
DE5A06][J`12@T80F5QH03`l?018B4P0Bd];05aLG00Z:RX0R8R8069RHP1MGEd0Cdm?05QHF01?Cdl0
?Shn0:RXZ01ADE40;bl_03hn?P1hN7P0HF5Q04A4A012@T80EeMG03Lg=`0Y:BT0V9RH07emO@0Q8B40
GemO06e]K@0l?3`0FEUI04E5A@0h>3P0ATI602l_;`0l?3`0M7Ad034a<@0j>SX0IFEU05IFEP0K6a/0
M7Ad079bLP1;Bd/0P8200:6QX@1bLW80H61P04m?C`1HF5P0GUiN02DU9@1SHf<0B4Q802@T901CDe<0
GEeM02HV9P0L71`0KFe]09JFUP1jNWX0A4A406e]K@0T92@0Fe]K05MGE`14A4@0N7Qh03<c<`1TI6@0
JFUY04I6AP1CDe<0QXJ603De=@1dM7@0O7al065QH@1lO7`0CTi>0451@@1MGEd0HV9R055AD@1?Cdl0
K6a/04A4A01CDe<0DE5A05UIF@1OGel0AdM707IfMP1^KVh0ADE508f=S@0m?Cd0CTi>05UIF@0l?3`0
PX:207YjNP0T92@08R8R06i^KP1jNWX0E5AD071`L00k>c/0K6a/07emO@1<C4`0=cLg05YJFP1BDU80
:BTY03`l?01EEED0BTY:02<S8`1NGUh0;Bd]05YJFP1aLG40Bd];059BDP1dM7@0EeMG07AdM01bLW80
M7Ad06IVIP2@T900RXZ:09ZJVP1fMWH0@T9206QXJ02CTi<0FUYJ0820P02YZJT0Vi^K04m?C`30`<00
_;bl051@D02OWil0_[jn07EeM@0i>CT0A4A401LG5`0K6a/0F5QH04A4A01MGEd0AdM702LW9`15ADD0
EUIF02/[:`1NGUh0BDU906][J`1VIVH0[jn_06e]K@0e=CD0NGUi04a<C01ZJVX0YJFU05IFEP0i>CT0
b<S8051@D01jNWX0EUIF08B4Q02/[:`0[Jf]06YZJP25QHD0Kfm_09JFUP1HF5P09BDU0P1fMWH0J@1A
DE40IFEU03dm?@0`<300R8R809BDU01SHf<0@41004e=C@1iNGT08R8R04a<C01_Kfl0UiNG07alO019
BDT0CTi>07emO@0Z:RX0GUiN0;:b/P1eMGD0B4Q806][J`1eMGD0>c/k09>CT`1bLW80D51@0;fm_@2Z
ZZX0EUIF01dM7@0i>CT0EUIF05EEE@0S8b<0A4A405eMG@0W9bL06ATI03Ti>@1TI6@04Q8B01dM7@1D
E5@0Rh^;05IFEP0n?Sh0IVIV08R8R01DE5@0@4100;6a/@1aLG40:BTY059BDP1XJ6P0@D510:NWY`1S
Hf<0?3`l09fMW@0j>SX0;Bd]09BDU02OWil0IVIV02DU9@0W9bL0GemO06=SH`0G5aL0;Rh^08j>SP2D
U9@0Cdm?06e]K@1DE5@0S8b<04];B`0O7al0ADE505IFEP1fMWH0C4a<02d];@13@d<08b<S01LG5`0E
5AD071`L01/K6`0E5AD0;Rh^03Ti>@0R8R805aLG01HF5P0E5AD0CDe=08N7Q`39bLT0iNGU0>WYj@02
0?Gem@0K0>?Sh`2XZ:P0OWin07YjNP1MGEd0S8b<0=GEe@36a/H0OGem04A4A018B4P0@T9208j>SP31
`L40Xj>S0<;2`P3Lg=`0/k>c08b<S022PX80ADE5038b<P14A4@0];Bd04a<C00M7Ad0820P00808R8R
00@0:2PX01hN7P0N7Qh05aLG0P0C4a<0?`0A4A405ADE01LG5`0I6AT0KVi^0:>SX`1hN7P0CDe=0;no
_`33`l<0];Bd08V9R@1^KVh0FEUI06ATI01/K6`0XJ6Q0<_;b`3Fe]H0IVIV05UIF@0O7al09BDU03De
=@1@D500IVIV09VIV@2ZZZX0YJFU0<S8b03Bd]80i^KV0>CTi03MgMd0^KVi04];B`0n?Sh0GUiN0:RX
Z01^KVh0HV9R09FEU@2d];@0_[jn0:JVYP25QHD0FUYJ04a<C01;Bd/0AdM705YJFP1lO7`0[Zj^04=3
@`2KVi/0RXZ:0410@01IFET0QHF508J6QP2>SXh0NWYj02@T900201DE5@805aLG03d06a/K03Lg=`13
@d<0TI6A06ATI01ZJVX0C4a<05=CD`2SXj<0e=CD09VIV@1GEeL0XJ6Q07moO`0^;Rh071`L01TI6@0L
71`08B4Q06i^KP1iNGT0Q8B40;Rh^02a/K40YJFU0:j^[P2RXZ80YJFU08R8R01bLW80D51@04I6AP2V
YZH0aLG507inOP2<S8`0;bl_01HF5P0M7Ad09RHV065QH@1`L700IVIV092@T01oOgl0:b/[01LG5`0J
6QX0CDe=03@d=00J6QX05ADE02/[:`2g]kL0Lg=c034a<@0_;bl0>SXj08f=S@1/K6`0BTY:0080G5aL
01/0?clo06=SH`2ATI40@T92038b<P2UYJD0fm_K0=SHf03Lg=`0clo?09FEU@2<S8`0C4a<09nOW`1o
Ogl0I6AT0;Vi^@3Ti>@0Shn?05IFEP17AdL0:b/[038b<P1DE5@0@d=306i^KP1WIfL00P23Ph<0101R
HV80MWIf05YJFP0N7Qh2028R8P0@02LW9`0i>CT0YJFU0;:b/P2TY:@0[Zj^08B4Q01hN7P0];Bd0<S8
b01iNGT0@d=30;Ng]`0^;Rh07alO01hN7P<05QHF02d06ATI04Q8B01PH600K6a/061PH00e=CD0?Cdm
06=SH`10@400B4Q807YjNP1=CDd0EEEE05ADE01cLg<0[Zj^0:>SX`2k^k/0f=SH0=GEe@3Cdm<0bLW9
08b<S00O7al06a/K05aLG00l?3`0JVYZ09jNWP2:RXX0TY:B08J6QP0e=CD06QXJ01PH600I6AT061PH
02/[:`0/;2`0@d=309NGU`37alL0W9bL08J6QP0`<3000P0M7Ad00`0R8R80;Rh^01lO7`0201dM7@0;
01hN7P0P8200=3@d069RHP1<C4`0N7Qh0;Jf]P20P800Z:RX07YjNP0O7al00P0L71`0100P82008B4Q
02PX:01BDU82ooooo`000280Q8B408j>SP1CDe<0D51@03`l?01^KVh0@T920410@01?Cdl0<C4a06m_
K`23Ph<0Lg=c03/k>`1;Bd/0FUYJ03hn?P1JFUX0Cdm?06][J`1=CDd0:b/[05eMG@1JFUX0>SXj06UY
J@0i>CT0=cLg06MWI`1GEeL0@41003hn?P0c<c<07QhN0P1NGUh08@0X:2P0FEUI05YJFP0f=SH0Cdm?
07inOP1YJFT0:RXZ069RHP0g=cL0Bd];02HV9P1GEeL0IVIV04E5A@28R8P0EeMG05UIF@1;Bd/0CDe=
024Q8@1QHF40BDU904e=C@1TI6@0AdM7030`<00R8R80L71`04i>CP0_;bl0<S8b069RHP0203@d=03o
05EEE@1HF5P0;bl_02/[:`2<S8`0ADE502DU9@1[Jf/0L71`02`/;01JFUX0@T9204=3@`1/K6`0>SXj
03`l?01cLg<0820P04U9B@1gMgL0FEUI02DU9@1MGEd0EeMG02DU9@1VIVH0U9BD07MgM`1JFUX0F5QH
06YZJP1bLW80:BTY0820P01EEED0<30`06m_K`1fMWH0DE5A04U9B@23Ph<0[Jf]07=cL`0c<c<0MGEe
03`l?01=CDd0C4a<03Ph>01jNWX0?clo04];B`1?Cdl0DU9B051@D02DU9@0IVIV04a<C022PX80GEeM
07inOP1SHf<0F5QH05]KF`1PH600D51@05eMG@1lO7`0L71`07QhN01?Cdl0I6AT06e]K@1SHf<0PH61
05]KF`0n?Sh0R8R8079bLP1FEUH0=SHf02PX:01bLW80MWIf03hn?P0_;bl0NWYj071`L01]KFd0RXZ:
04M7A`1cLg<0W9bL04A4A01CDe<0P820051@D012@T80C4a<06i^KP1BDU80<C4a07alO01DE5@0Ph>3
079bLP1QHF40MGEe08>3P`1/K6`0Ng]k09:BTP1XJ6P0>SXj08J6QP2VYZH0S8b<05mOG`15ADD0IFEU
08J6QP0e=CD0?clo06][J`1<C4`0ATI60<O7a`3=cLd0GemO05EEE@1bLW80GUiN04E5A@1:BTX0;Rh^
06=SH`1KFe/0@41005mOG`1JFUX0?3`l07IfMP1_Kfl0=CDe079bLP1PH6009BDU03Xj>P2ATI40K6a/
03@d=02>SXh0?3`l03De=@1eMGD0Hf=S04Y:BP31`L40YJFU0;2`/019BDT0?clo05iNGP1kNg/0>c/k
08b<S02j^[X0][Jf05iNGP0O7al0BTY:06m_K`1KFe/0UYJF02/[:`0L71`0ADE506UYJ@0g=cL0Bd];
07alO02;Rh/0=CDe028R8P0h>3P0H61P05EEE@1<C4`0P82008f=S@0];Bd0<30`05YJFP1GEeL0BDU9
07UiN@26QXH09BDU075aL@1QHF40?3`l0;Jf]P34a<@0Ph>303/k>`0m?Cd0DU9B04M7A`0P8200E5AD
0820P01[Jf/08b<S04Q8B01lO7`0@d=302`/;01MGEd0QXJ605ADE017AdL0IfMW06e]K@0C4a<0<S8b
0;Ng]`1mOGd09RHV04a<C00f=SH0:2PX08j>SP1=CDd0IfMW0<;2`P1QHF40<S8b09^KV`2LW9`0C4a<
03hn?P13@d<0J6QX06UYJ@0X:2P0;Bd]06UYJ@26QXH0WIfM0820P01`L700Fe]K096AT@21PH40/[:b
00050:VYZ@1HF5P0EEEE055AD@0Y:BT00`0E5AD0<00X:2P0820P01lO7`1HF5P0XJ6Q06a/K00n?Sh0
<c<c02@T900F5QH0Cdm?0:6QX@3Jf]X0k^k^0?Gem@3WinL0clo?0<?3``2TY:@0U9BD0861P@23Ph<0
_[jn0:b/[00/;2`06ATI01LG5`0S8b<0<C4a0451@@3Bd]80hN7Q0>3Ph03Bd]80clo?08:2PP0];Bd0
8R8R01LG5`1eMGD0Shn?02LW9`0J6QX06ATI01LG5`0E5AD071`L01/K6`805ADE00l05aLG01DE5@0G
5aL09RHV02`/;00a<C40>SXj07alO03EeMD0aLG50:^[Z`30`<00]KFe0:^[Z`23Ph<00P1iNGT0402A
TI40Xj>S0:f][@2IVIT0H61P06UYJ@1LG5`0Bd];03lo?`0f=SH0Hf=S09VIV@2][Jd0UIFE0<C4a02m
_Kd20=_Kf`2i09ZJVP1YJFT0=CDe030`<01IFET0Z:RX0820P02@T900d];B04];B`0U9BD0=CDe03lo
?`16ATH0AdM703Xj>P0];Bd0@41006UYJ@1XJ6P0a<C406IVIP0f=SH0<C4a04i>CP1WIfL0]kNg08:2
PP0_;bl07alO01LG5`0J6QX07alO02TY:@0n?Sh0CTi>065QH@2:RXX0LG5a02HV9P0I6AT0=SHf0:JV
YP2QXJ40;Rh^03dm?@2NWYh0OGem02`/;00U9BD07QhN024Q8@0T92@0OGem0:f][@2UYJD0]kNg0=[J
fP3Fe]H0Ogmo04i>CP0l?3`0<30`03@d=00l?3`0D51@0<71`@3?cll0V9RH01dM7@0O7al0BDU905UI
F@16ATH0VYZJ08n?S`35aLD0QHF507]kN`1hN7P0Xj>S08N7Q`0V9RH05aLG01DE5@0P8200[:b/03Ph
>00R8R80EEEE07=cL`0];Bd06ATI01LG5`0M7Ad0=SHf04a<C01:BTX0Kfm_07moO`0c<c<0C4a<0<W9
b@3Lg=`0T92@05ADE02<S8`0EeMG0;Jf]P2TY:@0EeMG07MgM`3EeMD0/k>c0;Bd]02n_[h0[:b/092@
T02HV9P0ZZZZ0<k>cP1eMGD0Ogmo08:2PP1EEED0NGUi04U9B@0N7Qh071`L01lO7`0P82009RHV03<c
<`1hN7P0e]KF08V9R@1`L700AdM70;:b/P2YZJT0YZJV0;Ng]`22PX80Shn?06][J`12@T80:b/[01@D
500E5AD07alO04];B`1JFUX0De=C055AD@0h>3P0C4a<04=3@`0P82005aLG01lO7`1KFe/0UYJF06EU
I@2HV9P0^;Rh0<O7a`36a/H0ZZZZ0;6a/@36a/H0];Bd09NGU`2k^k/0J6QX030`<01TI6@0R8R80:VY
Z@1QHF40:BTY02h^;P1XJ6P0LW9b06i^KP0U9BD00P0J6QX0200Q8B40<30`03lo?`1eMGD0YJFU09FE
U@0`<3007QhN0P0M7Ad0100O7al0=cLg02l_;`0N7Qh201dM7@0:01hN7P0V9RH0Jf][05eMG@1VIVH0
Rh^;07]kN`16ATH0PX:201/K6`8071`L00@08R8R02PX:013@d<0S8b<0_ooool0001/065QH@1IFET0
E5AD051@D00b<S80EeMG034a<@1?Cdl0QhN704I6AP1:BTX0Bd];05iNGP0/;2`0BDU902/[:`0];Bd0
FEUI03@d=01TI6@0;2`/01lO7`1dM7@0IVIV03Lg=`1hN7P0;Rh^02/[:`1@D500DU9B03Ti>@1;Bd/0
EEEE01PH600j>SX0BDU902TY:@1BDU80:BTY01PH600f=SH0Hf=S05aLG00S8b<0KVi^01/K6`0m?Cd0
6a/K04i>CP0c<c<0:BTY05EEE@16ATH0CTi>04M7A`1/K6`0?3`l08B4Q01CDe<0Fe]K06m_K`1XJ6P0
H61P03Lg=`1kNg/0H61P03hn?P0m?Cd0Ogmo05mOG`16ATH0@T9203/k>`0M7Ad08b<S07]kN`1ADE40
8B4Q051@D01BDU80<30`06e]K@13@d<0?clo04=3@`0h>3P0?3`l07YjNP0e=CD0@T92075aL@1FEUH0
7QhN065QH@2JVYX0C4a<07AdM02MWId0?clo03Xj>P0g=cL0C4a<03Lg=`0Y:BT0WYjN0820P00N7Qh0
<c<c0P1DE5@0g@14A4@0TY:B0;bl_01cLg<09RHV071`L00l?3`0C4a<02l_;`0^;Rh0NGUi04I6AP1A
DE40De=C02LW9`17AdL0Jf][06=SH`1?Cdl0@41003dm?@1cLg<0FEUI05YJFP1TI6@0>SXj04E5A@1L
G5`0JFUY06EUI@20P8009RHV05UIF@1XJ6P0Fe]K07moO`1DE5@0<S8b07YjNP17AdL0K6a/05EEE@0]
;Bd0IfMW0861P@0J6QX0:2PX08j>SP1jNWX0Bd];07QhN00e=CD0N7Qh0;>c/`1DE5@09bLW04];B`1G
EeL0<30`06e]K@2][Jd0DU9B038b<P1@D500GUiN08f=S@21PH40<C4a05EEE@1UIFD0EEEE06QXJ02@
T900FUYJ05aLG01lO7`0]KFe07]kN`1ADE40GEeM09ZJVP2c/k<0H61P03lo?`1]KFd0AdM703Xj>P2;
Rh/0WinO071`L01PH600QHF5051@D00f=SH0IFEU02DU9@0R8R80AdM70492@P1kNg/0PX:202XZ:P16
ATH0DU9B01lO7`1aLG40Jf][05YJFP1_Kfl0YJFU04U9B@0b<S80TY:B06=SH`14A4@0KVi^01TI6@0k
>c/0VIVI04a<C01_Kfl0GUiN04Y:BP25QHD0PH6102h^;P0d=3@0?3`l07YjNP2=SHd0=cLg059BDP13
@d<0>CTi09BDU01XJ6P0<C4a04i>CP21PH40;bl_02`/;019BDT0Kfm_04];B`0U9BD0ADE506][J`0/
;2`07AdM07QhN02@T900GEeM04a<C02JVYX0EEEE01lO7`1cLg<0P82004=3@`23Ph<0Jf][02LW9`1n
OWh0W9bL07MgM`0i>CT0DE5A06UYJ@0h>3P051@D034a<@1DE5@09BDU01DE5@1@D500YZJV092@T00f
=SH0J6QX05=CD`0F5QH0?clo09nOW`2?Shl0?Cdm02/[:`2:RXX0HV9R02/[:`1WIfL0J6QX05ADE02?
Shl05aLG05EEE@2a/K40L71`03Xj>P2OWil0W9bL01<C4`0H61P0ATI608j>SP23Ph<0?3`l028R8P1E
EED0NWYj0;:b/P2RXZ80VYZJ08>3P`28R8P0cLg=09JFUP2=SHd0S8b<06YZJP1VIVH0:2PX00805ADE
01X07AdM05=CD`12@T80Cdm?05MGE`16ATH0>c/k05QHF01VIVH0GemO0451@@0a<C40Vi^K0=SHf03M
gMd0gmoO0<W9b@1nOWh0D51@038b<P0U9BD0<S8b03dm?@12@T80UiNG05YJFP<05ADE01X05aLG03Ti
>@3AdM40hN7Q0=OGe`38b<P0ZJVY09fMW@1bLW806a/K01<C4`1KFe/0c<c<0:RXZ01kNg/0O7al075a
L@1dM7@0Jf][06EUI@1EEED0<C4a020P800G5aL06ATI02@T90806a/K01806ATI02XZ:P32`/80bl_;
09FEU@3De=@0f=SH0<o?c`2RXZ80L71`055AD@19BDT0CDe=06QXJ01iNGT0P82004=3@`0Q8B4201`L
700C02l_;`12@T80ATI609bLW02EUID0Y:BT0;jn_P3Fe]H0c/k>0:f][@1>CTh0Lg=c07EeM@1YJFT0
L71`0;^k^`1WIfL0OWin05aLG00301`L701a01dM7@0O7al07QhN02DU9@0f=SH0GEeM0:JVYP3IfMT0
V9RH0861P@1gMgL0I6AT08J6QP39bLT0OWin065QH@0T92@09RHV03Hf=P0g=cL0B4Q805mOG`1^KVh0
Fe]K0820P01DE5@0:b/[01XJ6P0I6AT0@D510:ZZZP1]KFd0;Rh^05EEE@32`/80YjNW05MGE`1<C4`0
Fe]K05iNGP1dM7@0Q8B408j>SP26QXH0dM7A0=?Cd`2YZJT0GemO05QHF01EEED0B4Q804e=C@1KFe/0
QHF50:FUY@2d];@0JVYZ03`l?01:BTX0I6AT07alO02VYZH0RXZ:0:FUY@1VIVH0=SHf0492@P1bLW80
XZ:R03Xj>P0E5AD05QHF02`/;01YJFT0>3Ph06m_K`1ADE40:BTY01HF5P0H61P05ADE01HF5P0J6QX0
8R8R04E5A@22PX80HF5Q092@T00];Bd0I6AT08Z:RP0];Bd09RHV0410@01MGEd0U9BD071`L01VIVH0
a<C40:FUY@1ADE40B4Q805EEE@0j>SX0;bl_04e=C@23Ph<0_[jn0=WIf@2^[Zh0DE5A07EeM@1HF5P0
0P0L71`0@P0M7Ad08B4Q02LW9`0a<C40JFUY0<W9b@2`/;00Zj^[061PH02IVIT0WYjN06YZJP2m_Kd0
f=SH055AD@0^;Rh0>c/k05MGE`1[Jf/0EUIF03Ti>@1OGel0DE5A05ADE01HF5P0ADE504U9B@0S8b<0
71`L01HF5P0E5AD06ATI02HV9P1;Bd/0>c/k0<O7a`2^[Zh0^k^k0;Rh^01jNWX0=cLg04A4A01eMGD0
EUIF06IVIP30`<00];Bd09^KV`22PX80@T9201lO7`0M7Ad07QhN02/[:`1CDe<0IfMW07QhN01WIfL0
AdM704Q8B01UIFD0QhN70:2PX02d];@0Ph>301lO7`8071`L00@07QhN01dM7@0W9bL0>SXj100M7Ad0
3`0T92@0Fe]K08f=S@28R8P0VYZJ05UIF@0U9BD0G5aL03Ph>00L71`07AdM02<S8`0b<S80OGem07Ui
N@02ooooo`0004L0JFUY05iNGP1:BTX0FEUI03`l?01iNGT0>c/k02d];@1WIfL0@D5105iNGP1WIfL0
?Cdm030`<01YJFT0H61P03/k>`0j>SX09BDU06IVIP12@T808B4Q04i>CP0o?cl0?3`l07inOP17AdL0
A4A406a/K00[:b/0;Rh^05=CD`1MGEd092@T0451@@0];Bd09bLW04M7A`18B4P08b<S03hn?P1]KFd0
=3@d02d];@1XJ6P0:b/[03/k>`0M7Ad0JFUY06ATI00k>c/0JVYZ03Hf=P0o?cl0K6a/06IVIP0];Bd0
L71`028R8P13@d<0Fe]K051@D013@d<0@D5106a/K00g=cL09BDU04m?C`1bLW80EUIF03dm?@0204];
B`0?01TI6@0i>CT0OWin05eMG@0Y:BT0IFEU02TY:@0R8R80HF5Q05MGE`15ADD0Cdm?01XJ6P0h>3P0
QhN70080?3`l04`0OWin05]KF`0E5AD0BTY:07=cL`1=CDd0Rh^;0;Vi^@2ATI40E5AD02l_;`1:BTX0
5aLG01dM7@1cLg<0MWIf03`l?01@D500Kfm_03<c<`0e=CD0YjNW0<30`02=SHd0ATI606m_K`0Y:BT0
JVYZ05UIF@0g=cL0Q8B403@d=01^KVh0Lg=c05UIF@11@D40JFUY05EEE@1bLW80NGUi05aLG01]KFd0
ADE504Q8B022PX80LW9b055AD@1GEeL0H61P03dm?@2EUID0HF5Q07]kN`1]KFd0@410092@T020P800
DU9B0:^[Z`0P8200BDU906a/K017AdL0LG5a092@T00H61P09BDU07]kN`29RHT0G5aL07alO00J6QX0
EEEE0:VYZ@1]KFd0?Shn0P1aLG40ZP0I6AT0>SXj06QXJ01]KFd09RHV04m?C`12@T80a<C40::RXP1Y
JFT0DU9B069RHP10@400F5QH0;^k^`28R8P0KVi^08R8R02i^KT0LW9b01LG5`11@D40O7al0:>SX`1V
IVH0ATI609ZJVP2FUYH0?Shn09NGU`2MWId0IVIV07IfMP2][Jd0LW9b02DU9@1DE5@0=3@d030`<01?
Cdl0<S8b08:2PP2IVIT0Cdm?04U9B@1DE5@07alO065QH@1^KVh0LG5a06m_K`38b<P0EUIF02DU9@21
PH40KFe]05QHF02DU9@0@41003`l?02e]KD0EeMG0820P012@T80MWIf09:BTP21PH40@T92092@T01[
Jf/0SXj>05mOG`0g=cL0De=C04U9B@0k>c/0JVYZ03dm?@0/;2`0DU9B07inOP1UIFD0@d=3051@D01`
L700<S8b02HV9P19BDT0IFEU06MWI`15ADD0AdM707IfMP1KFe/0De=C0;bl_01RHV80:b/[05aLG01l
O7`0?3`l07alO01bLW80Fe]K0;fm_@2IVIT0I6AT02<S8`1UIFD0Zj^[07inOP0L71`0>c/k05iNGP0O
7al061PH03@d=01/K6`0EEEE030`<01SHf<0L71`03lo?`0Z:RX0ATI605iNGP1?Cdl0;Bd]0:>SX`0i
>CT08R8R07moO`1ZJVX0Lg=c09FEU@0b<S80<C4a0:FUY@0o?cl0<S8b09RHV022PX80>SXj01PH600P
8200A4A406i^KP0n?Sh0:RXZ06YZJP29RHT0BTY:09RHV02_[jl0N7Qh0;^k^`2m_Kd0Q8B40<K6aP2b
/[80WIfM0:NWY`1kNg/0B4Q803hn?P0b<S80@41003`l?015ADD0;Rh^0`0U9BD09`0R8R80<c<c04e=
C@1nOWh0e=CD0<W9b@3Ogml0b/[:0;Bd]00W9bL06a/K01`L700G5aL08B4Q02/[:`0U9BD0ATI607If
MP0O7al05ADE01<C4`0B4Q809bLW0<W9b@2h^;P0a<C40;Bd]02@T900K6a/05EEE@0@41003@d=030`
<01ADE40=cLg02`/;00m?Cd0?3`l03hn?P0302d];@0_02h^;P0_;bl09bLW02d];@0c<c<0<S8b02PX
:00_;bl0MWIf0;fm_@2WYjL0G5aL0=KFeP3Ogml0R8R805UIF@1JFUX0F5QH05]KF`17AdL0=CDe04e=
C@1aLG40[:b/0:FUY@1SHf<0=CDe038b<P0o?cl0H61P05ADE01/K6`0b<S80::RXP2<S8`0V9RH08R8
R027QhL0>CTi08j>SP1TI6@0FUYJ0820P02][Jd0EUIF065QH@0T92@00`0M7Ad09P0L71`07alO028R
8P1SHf<0^;Rh0<G5a@2^[Zh0ZZZZ08>3P`24Q8@0]KFe0<o?c`3Rh^80T92@09JFUP1hN7P0JFUY0;6a
/@2ATI40O7al07UiN@23Ph<0N7Qh04a<C01BDU80?3`l01lO7`0K6a/0>SXj09jNWP2OWil0CDe=03De
=@1^KVh0c/k>0;:b/P2UYJD0M7Ad0`1XJ6P00`25QHD0dm?C0=7Ad@020::RXP0N08:2PP28R8P0RHV9
055AD@0l?3`0:b/[038b<P2UYJD0Ph>309FEU@1<C4`0Cdm?051@D01SHf<0/k>c0:VYZ@1[Jf/0QXJ6
06UYJ@1`L700J6QX05ADE01PH600ATI602DU9@1_Kfl0WinO06i^KP0];Bd07QhN0P0G5aL301DE5@0:
01HF5P0G5aL05aLG03/k>`25QHD0SHf=09BDU00g=cL0C4a<02DU9@808B4Q00h0GemO0:2PX021PH40
]KFe0:n_[`1IFET0Bd];0451@@0a<C409RHV02TY:@13@d<0A4A404I6AP80[Jf]0280Hf=S04=3@`0L
71`07alO028R8P0Y:BT0;2`/03Lg=`27QhL0WYjN038b<P0I6AT0FUYJ08Z:RP1TI6@0b/[:0=CDe02f
][H0alO70451@@0Q8B407QhN02<S8`0V9RH0CDe=0;:b/P1RHV80ADE504i>CP1OGel0>3Ph01TI6@0E
5AD05QHF0P0E5AD0900G5aL07QhN03Lg=`0d=3@0Ng]k055AD@24Q8@0`l?30=7Ad@1eMGD0HV9R0;>c
/`2JVYX0XZ:R0<?3``3Jf]X0KVi^059BDP0S8b<09RHV028R8P0S8b<0;Rh^04a<C02DU9@0Ng]k06EU
I@1_Kfl0MgMg06i^KP2>SXh0YZJV0=CDe030`<00@d=301hN7P807alO01H07AdM01`L700c<c<0<30`
01hN7P0O7al09bLW02PX:021PH40bLW90;no_`28R8P0;bl_02h^;P0a<C40Ogmo02@T900R8R80<c<c
05QHF02;Rh/0;bl_0_ooool0001B07IfMP2DU9@0DU9B03hn?P0k>c/0KFe]0492@P10@400FUYJ03De
=@2DU9@0/;2`06m_K`0^;Rh0>3Ph05IFEP0d=3@0Cdm?02/[:`1EEED0?Shn02HV9P1KFe/0EUIF030`
<01IFET0;Rh^04i>CP29RHT0De=C02DU9@13@d<0De=C01TI6@1IFET0Fe]K02XZ:P13@d<0EEEE02LW
9`18B4P0LG5a0410@00P8200D51@01dM7@0W9bL04Q8B03De=@15ADD0=SHf07emO@17AdL0;bl_03Ti
>@1GEeL0:BTY07IfMP1IFET0EUIF04m?C`1EEED0D51@04Q8B02UYJD0Cdm?03Ph>00[:b/0Kfm_069R
HP0j>SX0AdM705]KF`0g=cL08B4Q07QhN01_Kfl0<S8b06MWI`1LG5`0<c<c065QH@80Bd];05@0IFEU
02LW9`0k>c/0SHf=02d];@0d=3@0R8R806][J`0c<c<0EeMG07IfMP0K6a/0FEUI09VIV@21PH40Ogmo
08n?S`1aLG40Hf=S02PX:01^KVh0A4A402LW9`1?Cdl0KVi^02TY:@0V9RH0FUYJ07UiN@2BTY80AdM7
07QhN00B4Q80C4a<069RHP0k>c/0KVi^01<C4`13@d<0MgMg05iNGP12@T80MgMg01DE5@1GEeL0Vi^K
079bLP1kNg/0ADE5030`<016ATH0KVi^04a<C01OGel0EeMG02/[:`1KFe/0KVi^09>CT`24Q8@0<c<c
05UIF@1ZJVX0G5aL0;:b/P1`L700BTY:055AD@1:BTX0S8b<096AT@0Q8B406QXJ05QHF01fMWH0JVYZ
09^KV`19BDT0JFUY0;>c/`0`<300ATI606UYJ@1kNg/204A4A02Y05YJFP1:BTX0Cdm?07QhN00X:2P0
OGem08n?S`1`L700DE5A08b<S00H61P0=CDe08F5Q@2>SXh0PX:2092@T03@d=00UIFE051@D00j>SX0
H61P08^;R`18B4P0LG5a0:6QX@2ZZZX0=SHf09^KV`2WYjL0FEUI0451@@1IFET0HF5Q02d];@1LG5`0
?3`l05MGE`1UIFD0:b/[04a<C01mOGd0C4a<07]kN`22PX80=CDe06e]K@1WIfL0?3`l06][J`2h^;P0
R8R803<c<`25QHD0@d=305ADE01hN7P0Jf][0451@@2i^KT0H61P0861P@1JFUX0@D5105ADE01LG5`0
B4Q809>CT`1WIfL0`l?303hn?P0k>c/0UYJF07AdM01IFET0OWin05QHF00b<S80De=C07inOP1QHF40
?Shn05EEE@1`L700>CTi04E5A@29RHT0YZJV08:2PP1=CDd0BTY:08^;R`0T92@0FUYJ09JFUP20P800
GEeM06IVIP1]KFd06a/K07AdM02VYZH0I6AT0;^k^`2FUYH0Fe]K01`L7012@T80Fe]K06EUI@0M7Ad0
>c/k06ATI00n?Sh09BDU03dm?@1aLG40;bl_02HV9P21PH40NWYj05ADE011@D40I6AT06a/K00W9bL0
=3@d0;Rh^01CDe<07QhN07YjNP1CDe<0J6QX0;fm_@1ADE40>c/k0:VYZ@1<C4`0:2PX07]kN`2;Rh/0
Bd];02<S8`0Y:BT0CDe=06MWI`0g=cL0:BTY06=SH`23Ph<0Bd];07AdM02FUYH0ZJVY0<_;b`3<c<`0
TY:B07EeM@31`L40_kno0;fm_@1iNGT0EeMG04M7A`0^;Rh0:b/[01TI6@0P82007AdM01TI6@0201dM
7@0C01`L700M7Ad09RHV04e=C@2o_kl0]kNg0<o?c`3>c/h0a<C4071`L01CDe<0HF5Q0492@P0L71`0
6a/K02l_;`0U9BD0BDU904Q8B00201LG5`0G01PH6011@D40b/[:08n?S`2f][H0cLg=0;Zj^P1`L700
820P014A4@0D51@0@D5101@D500>3Ph04A4A01DE5@0C4a<05ADE010@400B4Q804a<C018B4P0A4A40
0P0B4Q8201LG5`1<01/K6`0[:b/0GEeM0:b/[01CDe<0IVIV0<;2`P2b/[80=SHf02LW9`0X:2P0?Cdm
04i>CP1<C4`0A4A40410@01MGEd0UYJF0=CDe02o_kl0IfMW05YJFP1=CDd0?clo07EeM@2QXJ40ATI6
01XJ6P0k>c/0HF5Q0:ZZZP2XZ:P0VYZJ03De=@0T92@05QHF01LG5`1DE5@0YJFU07AdM01>CTh08B4Q
01hN7P0M7Ad06a/K028R8P1TI6@0]KFe0;Bd]01ZJVX0G5aL05YJFP27QhL0Ogmo0820P01hN7P0XZ:R
0;Rh^030`<00alO709BDU036a/H0RXZ:06QXJ01/K6`0V9RH0:RXZ01:BTX0@T9208F5Q@1IFET0;bl_
03Lg=`1HF5P0YjNW0:BTY080FEUI02T0cLg=07IfMP0h>3P0?Cdm04I6AP0k>c/09RHV05YJFP2n_[h0
alO70:f][@2`/;00SHf=059BDP15ADD08b<S01`L700^;Rh0Bd];08b<S02FUYH0Ph>308:2PP0W9bL0
71`L01XJ6P0a<C40T92@08>3P`1_Kfl0L71`065QH@12@T80?clo0451@@1=CDd0Vi^K0;Bd]01mOGd0
>SXj01/K6`0801DE5@0i01@D500G5aL0;bl_09^KV`2SXj<0W9bL05UIF@11@D40DE5A030`<00o?cl0
/k>c0=?Cd`36a/H0HF5Q07=cL`29RHT0Ti>C08F5Q@1bLW80CTi>059BDP2QXJ40WYjN07AdM01/K6`0
Cdm?01`L700M7Ad08R8R02XZ:P0];Bd0@4100:6QX@1ZJVX071`L01DE5@0F5QH061PH07=cL`1fMWH0
ZZZZ0<c<c02d];@0fMWI09jNWP1DE5@0?Shn0492@P1<C4`0GemO0;bl_01eMGD0Bd];061PH00S8b<0
6ATI00805ADE02P061PH01LG5`0I6AT05QHF024Q8@18B4P0Shn?05UIF@1gMgL0Q8B40;:b/P2f][H0
N7Qh07alO03=cLd0b/[:0<O7a`39bLT0b<S80;Ng]`1?Cdl09bLW02XZ:P0g=cL0EUIF05aLG00o?cl0
;Rh^034a<@16ATH0FEUI0820P02a/K40_;bl0=CDe03?cll0^k^k09fMW@0Z:RX07QhN0P0M7Ad05@0S
8b<092@T04=3@`0X:2P08B4Q02d];@1EEED0ZJVY0<S8b036a/H0X:2P05=CD`0g=cL0<c<c06ATI01K
Fe/092@T05IFEP2TY:@0B4Q802PX:002ooooo`0004L0I6AT08:2PP1BDU80EUIF03`l?01^KVh0?clo
04M7A`1SHf<09RHV03hn?P1FEUH0IfMW03<c<`10@400<S8b01lO7`1MGEd0>c/k06][J`0R8R8051@D
05QHF01cLg<0?3`l079bLP0J6QX09RHV05mOG`1dM7@0=CDe03lo?`1:BTX04Q8B0410@01DE5@0?3`l
04Q8B00K6a/04A4A04];B`23Ph<0M7Ad02TY:@1YJFT061PH04M7A`0O7al0B4Q803Xj>P0n?Sh0UIFE
07EeM@0k>c/0B4Q804U9B@0=3@d0NWYj06YZJP1DE5@0JVYZ04U9B@0J6QX07alO06QXJ01dM7@0>c/k
030`<01QHF40:RXZ03Ti>@0206m_K`3f03lo?`0W9bL0QHF506EUI@0c<c<0Q8B407QhN00f=SH0KVi^
05MGE`0l?3`0Ng]k04m?C`17AdL0U9BD01@D500[:b/0Jf][07]kN`16ATH0Bd];09JFUP0];Bd0EeMG
0::RXP1YJFT0B4Q804e=C@1NGUh0FUYJ020P801YJFT0BTY:02h^;P2;Rh/0X:2P0492@P1EEED0/k>c
0;6a/@1ZJVX0?3`l092@T015ADD0BTY:04I6AP0j>SX0VIVI05ADE00l?3`0EUIF03Hf=P1PH600Ti>C
061PH01CDe<0D51@05]KF`2/[:`0L71`05YJFP1LG5`0Fe]K07AdM02i^KT0Q8B405IFEP1RHV80<S8b
05MGE`2>SXh0GemO05iNGP12@T80>3Ph07MgM`1`L700EUIF03dm?@0L71`0O7al09bLW01>CTh0;2`/
06m_K`1aLG40De=C09JFUP0k>c/0IVIV092@T01>CTh0;2`/04Y:BP18B4P0A4A404];B`1RHV80=SHf
01dM7@1EEED0Bd];08j>SP25QHD0G5aL07]kN`2JVYX0LG5a04e=C@1jNWX0Shn?03dm?@1cLg<0b<S8
09VIV@1]KFd0=cLg05eMG@26QXH0E5AD030`<01_Kfl0UYJF03<c<`25QHD0VYZJ07EeM@1IFET0L71`
0820P00e=CD0DE5A02DU9@1;Bd/0PH610410@01>CTh0Jf][024Q8@1FEUH0NWYj034a<@1YJFT0F5QH
0451@@1=CDd0PH6106QXJ00c<c<0OWin059BDP1=CDd0JVYZ069RHP0h>3P0YjNW075aL@1iNGT0Ph>3
05]KF`1aLG40M7Ad06MWI`2VYZH0IFEU0:^[Z`1WIfL0:BTY05EEE@1hN7P0EEEE08:2PP13@d<0>CTi
08f=S@2UYJD0NGUi04E5A@1EEED0Lg=c02TY:@0O7al0@d=306UYJ@1_Kfl0BTY:04];B`1oOgl0EeMG
04M7A`2:RXX0R8R806ATI01`L700JFUY02@T901DE5@0Fe]K03lo?`2RXZ80PH6104Q8B00o?cl0EUIF
069RHP1JFUX07alO055AD@1gMgL0GUiN02HV9P17AdL0PH6106=SH`0Z:RX0JFUY08Z:RP1ADE40>CTi
05IFEP1XJ6P0@D5102DU9@2LW9`0HV9R01lO7`1iNGT0@41006EUI@2k^k/0@T9203Ph>02ZZZX0CTi>
02LW9`1cLg<0TY:B03Ph>00N7Qh09RHV04M7A`1_Kfl0B4Q802HV9P1WIfL0T92@0P1IFET07@1aLG40
OWin0;bl_02i^KT0SHf=0820P034a<@0_Kfm0:2PX021PH40HV9R04A4A010@400:RXZ028R8P0X:2P0
9bLW02d];@0R8R806ATI01LG5`0M7Ad0820P07]kN`2<S8`0][Jf0<30`03EeMD0b<S80080HV9R01H0
NGUi08b<S01BDU8061PH01TI6@0h>3P0D51@09jNWP1[Jf/0GEeM075aL@28R8P0`L7109JFUP35aLD0
a/K60;Vi^@2IVIT0JVYZ055AD@1jNWX0>c/k0P0>3Ph01@0A4A404a<C01DE5@0D51@03Ph>00804A4A
0P0>3Ph0E`0=3@d03Ph>00h>3P0?3`l03Ph>010@400A4A40EeMG02<S8`12@T80W9bL08>3P`0B4Q80
3Ph>014A4@0@41005ADE01TI6@0M7Ad04a<C00l?3`0U9BD0H61P08J6QP2a/K40^KVi0:>SX`2HV9P0
LW9b02LW9`0B4Q804A4A01<C4`0K6a/0<c<c0:VYZ@1kNg/0JVYZ04M7A`0N7Qh05ADE01TI6@1VIVH0
Zj^[08j>SP1<C4`09bLW03@d=01CDe<0WIfM0<c<c034a<@0EEEE03dm?@11@D40ATI606IVIP2<S8`0
OGem06YZJP24Q8@0R8R80:f][@2PX:00WIfM0<71`@2QXJ40IVIV04I6AP0h>3P0Bd];07alO02=SHd0
TI6A07]kN`1cLg<0HF5Q07moO`1jNWX0e=CD0820P02EUID0ZJVY05UIF@1CDe<0>c/k024Q8@0201XJ
6P0R08B4Q030`<00BTY:06][J`2LW9`0KVi^08j>SP1iNGT0FEUI05ADE01?Cdl0<c<c03De=@1CDe<0
BDU905aLG01gMgL09RHV024Q8@0N7Qh0E5AD04M7A`2BTY80JVYZ02l_;`0X:2P0:b/[06QXJ02ZZZX0
]kNg0<;2`P1VIVH0GUiN01hN7PX05ADE00L09bLW04U9B@2IVIT0^[Zj0;no_`3Fe]H0jNWY0080d];B
01P0hN7Q0=7Ad@3Cdm<0V9RH06IVIP13@d<0>3Ph03Hf=P0m?Cd0J6QX0:j^[P3Jf]X0^[Zj04A4A00R
8R80@d=303@d=00R8R80:2PX02HV9P15ADD0WYjN04m?C`0G5aL301DE5@0301HF5P0`<300dm?C0080
dM7A00`0c/k>0;Ng]`1JFUX0HV9R06][J`1aLG40Kfm_07emO@2>SXh0]KFe09fMW@0`<30201DE5@0M
01HF5P0I6AT05aLG01XJ6P0E5AD06ATI030`<01UIFD0MgMg07emO@1jNWX0M7Ad09jNWP1EEED0ADE5
06e]K@1dM7@0Vi^K0<[:bP2ZZZX0Z:RX09:BTP1^KVh09bLW04M7A`1_Kfl0De=C02l_;`0V9RH00P0W
9bL0100_;bl0DU9B08R8R02ZZZX20=SHf00L0=WIf@2YZJT0Vi^K06e]K@0M7Ad07QhN020P800S8b<0
92@T04Q8B01XJ6P0EUIF08N7Q`2e]KD0YZJV0:FUY@3Bd]80a/K609nOW`2GUiL0UIFE09ZJVP34a<@0
RHV90:>SX`2IVIT09bLW05mOG`;ooooo0000:@1QHF40IfMW05IFEP1^KVh0@41006IVIP0V9RH0?clo
07emO@17AdL0EUIF06a/K01aLG40@d=305YJFP1XJ6P0:2PX04Y:BP0k>c/0FEUI04i>CP0Y:BT0@D51
06IVIP0g=cL0K6a/0451@@0W9bL0Jf][07MgM`0j>SX0Bd];06ATI00Q8B40@41005IFEP18B4P0ATI6
04U9B@0M7Ad0;Rh^0080IfMW00P0:BTY07]kN`0?3`l0AdM7028R8P1=CDd0;bl_02HV9P80E5AD05/0
;bl_04M7A`1XJ6P0<C4a06m_K`1EEED0D51@079bLP1XJ6P0IfMW05IFEP1GEeL0G5aL04A4A015ADD0
LG5a038b<P0R8R80;Rh^069RHP1?Cdl0:BTY08J6QP19BDT04A4A06][J`1UIFD0;Rh^07]kN`1QHF40
>CTi04e=C@0_;bl0I6AT0:6QX@1=CDd0<C4a06i^KP1`L7009BDU04Q8B02>SXh0E5AD06=SH`2UYJD0
Ph>309BDU01<C4`0CDe=075aL@0X:2P0JFUY055AD@0I6AT0>SXj061PH01KFe/0GEeM0:f][@2c/k<0
LW9b01hN7P1iNGT0Cdm?03lo?`0/;2`07AdM06UYJ@15ADD0?Cdm05QHF00e=CD0<C4a069RHP1bLW80
B4Q805mOG`0e=CD0@d=305ADE01?Cdl0FEUI04=3@`0[:b/0Bd];06IVIP1>CTh0GUiN04I6AP1FEUH0
Jf][0080FEUI05<0L71`05MGE`1WIfL0HV9R05iNGP0d=3@06a/K04Q8B01aLG40?clo02/[:`1_Kfl0
P82004m?C`2FUYH0@41004Y:BP2NWYh0K6a/03@d=01FEUH0K6a/04a<C017AdL0Jf][05YJFP0/;2`0
IFEU05IFEP2TY:@0Lg=c02TY:@1@D500RHV907EeM@1<C4`0SHf=096AT@1;Bd/0CTi>0;bl_02EUID0
KVi^03Hf=P1SHf<0WinO06ATI00i>CT0O7al08V9R@0d=3@0SXj>0;>c/`1_Kfl0Fe]K079bLP26QXH0
>c/k059BDP0e=CD0:BTY05MGE`0g=cL0Cdm?07EeM@18B4P0ATI605=CD`0V9RH0G5aL04e=C@1<C4`0
OWin0:j^[P1KFe/0=3@d07moO`1<C4`0DE5A08F5Q@19BDT0?Cdm09NGU`0207moO`1i08F5Q@1WIfL0
LW9b06ATI019BDT0VYZJ0:JVYP2JVYX0MGEe03`l?01HF5P0EUIF04M7A`1mOGd0EUIF02h^;P1FEUH0
QhN706e]K@19BDT0EUIF08Z:RP1GEeL0:BTY04];B`1SHf<0De=C04m?C`1`L700UIFE079bLP1RHV80
L71`08:2PP1eMGD0PH6108V9R@1:BTX0F5QH07UiN@1KFe/0]kNg0;Bd]01jNWX0?clo06=SH`1mOGd0
FUYJ01dM7@0k>c/0GemO06][J`0];Bd0Fe]K09fMW@1kNg/0<C4a06m_K`2:RXX0C4a<03De=@1nOWh0
QhN704a<C00`<300WinO05EEE@0W9bL0R8R806ATI01bLW80clo?02h^;P1HF5P0^[Zj07alO00^;Rh0
E5AD0:JVYP0_;bl08R8R03De=@1UIFD0LG5a03Ph>00R8R80DE5A0820P012@T80=cLg03/k>`0m?Cd0
NWYj09BDU01GEeL0S8b<0;bl_02b/[80^k^k0<o?c`29RHT0CTi>04E5A@0[:b/08R8R02DU9@0W9bL0
;bl_03<c<`0g=cL0?Shn04I6AP1/K6`0aLG50:FUY@2l_;`0/k>c0;bl_01kNg/0=SHf04=3@`02061P
H00F04m?C`0k>c/0:b/[05IFEP2GUiL0HF5Q02TY:@0L71`08b<S02XZ:P2JVYX0SHf=0;Rh^035aLD0
alO706YZJP0K6a/07AdM02XZ:P1DE5@07AdM00h>3P80410@0P0A4A401P0>3Ph0410@01@D500@4100
3@d=00h>3P803`l?0P0>3Ph02@0@41009BDU04=3@`0I6AT0@d=3096AT@1cLg<04a<C00l?3`0300h>
3P0>010@400C4a<03Ph>00d=3@0>3Ph04a<C06i^KP2MWId0[Jf]0=SHf02@T9005ADE014A4@0D51@2
010@401J01<C4`0P8200?3`l05eMG@0H61P0B4Q806i^KP0];Bd05QHF04A4A01TI6@0_kno08j>SP12
@T80LG5a09jNWP2c/k<0TY:B09>CT`1OGel0CTi>04Y:BP0l?3`0820P01dM7@0d=3@0D51@079bLP1/
K6`0PH6108n?S`3Fe]H0bLW90;jn_P1^KVh0=3@d034a<@0[:b/0G5aL0:f][@1LG5`0<c<c0451@@1>
CTh0SHf=09jNWP34a<@0_;bl07YjNP2DU9@0R8R806=SH`0R8R807QhN02HV9P0n?Sh0Y:BT0:6QX@1o
Ogl0@D5106a/K00_;bl0@D51096AT@3Fe]H0UYJF01hN7P0T92@0<30`01hN7P1[Jf/0GEeM05QHF01O
Gel0<C4a02@T901;Bd/0=3@d03hn?P2JVYX0Q8B404m?C`1eMGD0/;2`0=CDe02o_kl0VIVI06EUI@1P
H6006a/K0`0E5AD0100D51@05ADE01DE5@0G5aL301DE5@0R01TI6@1?Cdl0XJ6Q0=KFeP3Ti>@0iNGU
0=OGe`3Rh^80jNWY0>;RhP3Jf]X0f=SH06YZJP0a<C405aLG01DE5@0D51@05ADE01PH6011@D40[:b/
09:BTP0c<c<0820P02/[:`1OGel0=cLg02TY:@0i>CT0YJFU051@D00G5aL05ADE01LG5`805ADE0180
5aLG02LW9`2k^k/0a/K60;Rh^02n_[h0Cdm?04U9B@1?Cdl0?Shn04M7A`1?Cdl0G5aL06=SH`2IVIT0
Ph>305MGE`0M7Ad301DE5@0;01LG5`0E5AD05ADE01HF5P0U9BD0GEeM06UYJ@23Ph<0P82008j>SP23
Ph<00P12@T80<P0h>3P0Cdm?05]KF`2DU9@0PX:208B4Q02GUiL0V9RH07inOP1kNg/0@T9203Ti>@0c
<c<0@D51051@D01EEED0LG5a06m_K`1]KFd0clo?0=SHf03Fe]H0^KVi0:n_[`25QHD0]KFe05aLG00S
8b<09bLW038b<P1EEED0EeMG04m?C`2IVIT0[Jf]0:VYZ@2a/K40WYjN0;>c/`1DE5@0EEEE06i^KP26
QXH0WIfM0=CDe02i^KT0dM7A07inOP1]KFd0PX:20_ooool0000<06ATI015ADD0AdM705iNGP0n?Sh0
N7Qh03hn?P0l?3`0R8R804=3@`1DE5@0F5QH0P0X:2P0_`1gMgL0NGUi03Xj>P1;Bd/0?clo07MgM`1a
LG40=SHf04Y:BP1JFUX0?Cdm09NGU`19BDT09bLW05MGE`12@T80<c<c065QH@1[Jf/09BDU03Ph>00P
8200;Rh^06IVIP1NGUh0;Rh^03dm?@1jNWX0:RXZ01hN7P26QXH0=cLg03dm?@0S8b<0JFUY06m_K`0e
=CD0Lg=c0492@P0f=SH0OGem08N7Q`10@400IVIV02l_;`0i>CT0Fe]K08F5Q@1SHf<0C4a<06UYJ@0l
?3`05aLG051@D01iNGT0H61P03lo?`17AdL0KVi^02l_;`0m?Cd0MWIf079bLP0c<c<0Ph>301/K6`0:
2PX0EUIF075aL@1=CDd0DE5A02DU9@0Y:BT0LW9b051@D00g=cL0Kfm_06i^KP0R8R80<C4a09RHV01C
De<0Fe]K0:6QX@23Ph<0Ti>C07EeM@17AdL0B4Q802d];@1lO7`0HF5Q01TI6@1;Bd/0J6QX03Ph>00k
>c/0^[Zj0;Vi^@0h>3P08b<S06EUI@0^;Rh0BTY:03Xj>P0_;bl0QHF504a<C010@400HF5Q03dm?@11
@D40PH6107AdM014A4@0RXZ:06=SH`1WIfL0IVIV05ADE01ADE40MGEe04i>CP1YJFT0MgMg051@D01B
DU80@T92055AD@25QHD0DU9B061PH01^KVh0HF5Q08j>SP1_Kfl0IFEU04U9B@0j>SX0FEUI096AT@10
@400;bl_07QhN02BTY80H61P0:FUY@14A4@0EEEE0:VYZ@1kNg/0@41006m_K`29RHT0?clo05MGE`2N
WYh0M7Ad03Ph>01]KFd0GEeM0820P01XJ6P0M7Ad05IFEP1HF5P0I6AT04i>CP2HV9P0UiNG07MgM`1S
Hf<0dM7A0:6QX@1IFET0DE5A08N7Q`2IVIT0EeMG06m_K`2f][H0V9RH03Lg=`1jNWX0ZZZZ05=CD`1/
K6`0X:2P08^;R`0o?cl0GUiN0080>3Ph07T0EEEE03Hf=P1DE5@0QhN705mOG`1ADE40Hf=S02`/;01]
KFd0LG5a05YJFP2:RXX0aLG505aLG00c<c<0R8R805=CD`1BDU80ZZZZ05MGE`0i>CT0RHV907EeM@21
PH40HF5Q07IfMP2XZ:P0OWin03<c<`1gMgL0GUiN08Z:RP1JFUX0A4A407emO@18B4P0@d=309bLW01l
O7`0Bd];08:2PP2QXJ40De=C03hn?P1OGel0KVi^02LW9`14A4@0Lg=c07moO`1WIfL0FEUI05eMG@1f
MWH0Kfm_05YJFP1bLW80KFe]03`l?02<S8`0UYJF05]KF`1RHV80SXj>05iNGP2OWil0W9bL06UYJ@0N
7Qh0Cdm?06e]K@1OGel07QhN03/k>`1EEED0820P024Q8@1EEED0J6QX06EUI@0c<c<0IVIV04i>CP0H
61P08B4Q05UIF@1^KVh0EeMG030`<02NWYh0>CTi01TI6@1VIVH0KFe]04M7A`3=cLd0Bd];034a<@2M
WId0Ph>302DU9@17AdL0RXZ:05YJFP0[:b/07alO03Ph>01UIFD0<c<c02PX:01>CTh0R8R803Lg=`0]
;Bd0:BTY0451@@1XJ6P0SXj>02d];@0V9RH0G5aL0080IVIV00L0TI6A0451@@0P82004Q8B010@400>
3Ph0820P00D04A4A01<051@D034a<@2PX:00C4a<05UIF@1hN7P0MGEe06e]K@0M7Ad05aLG034a<@0S
8b<07alO02`/;00c<c<0GUiN06ATI011@D40>CTi0080;bl_01P0;Bd]09bLW02^[Zh0KVi^0<_;b`2l
_;`0CDe=02<S8`0I6AT051@D01lO7`0g=cL04Q8B00h>3P0=3@d0410@01<C4`0=3@d03`l?00h>3P0@
41003Ph>010@400?3`l200h>3P0900d=3@0>3Ph07alO0410@00K6a/0@41008n?S`1kNg/061PH0080
3Ph>00<04a<C014A4@0@41000P0@4100300=3@d03Ph>00h>3P0i>CT0O7al04a<C02SXj<0E5AD014A
4@0@41003Ph>014A4@803Ph>04406ATI02LW9`1LG5`05aLG01DE5@0];Bd0MGEe04i>CP0h>3P0A4A4
061PH03GemL0f=SH0;bl_02JVYX0B4Q804A4A01DE5@0G5aL01hN7P0I6AT06a/K01LG5`0E5AD0>c/k
06a/K01`L700/[:b0;bl_02g]kL0d];B0<g=c@2KVi/0IVIV04I6AP0X:2P09RHV03hn?P1TI6@0J6QX
05=CD`0g=cL09bLW07emO@1_Kfl0Y:BT0<K6aP2h^;P0R8R807AdM01fMWH0H61P0451@@0c<c<0?clo
07inOP1;Bd/0I6AT09bLW01TI6@08b<S024Q8@0`<300/k>c05mOG`0201LG5`0F01DE5@0H61P0;2`/
07UiN@1cLg<0O7al05ADE00k>c/0LW9b05UIF@0g=cL0^[Zj0<K6aP1^KVh0IfMW0:b/[03;bl/0_kno
0:ZZZP14A4@0@d=304E5A@@05ADE00<04a<C01DE5@0E5AD00P0E5AD0800G5aL0@d=308F5Q@2o_kl0
cLg=0=CDe02`/;00B4Q8065QH@3Ph>00g]kN0>OWi`2/[:`0GUiN04m?C`1;Bd/0=SHf028R8P0E5AD0
5aLG03Ph>01TI6@0GemO03/k>`0U9BD0:2PX04];B`1nOWh0@D5108j>SP1EEED05QHF1@0E5AD0500G
5aL0>3Ph0;6a/@2][Jd0bl_;09VIV@1eMGD0BDU9059BDP2=SHd0MGEe05QHF00e=CD0:BTY030`<020
P800JFUY03dm?@0E5AD04a<C1@0E5AD0>`0P8200B4Q806IVIP1oOgl0N7Qh08B4Q01SHf<0@d=303Ti
>@0R8R80>SXj051@D02CTi<0HF5Q0<;2`P2^[Zh0Z:RX0<;2`P1TI6@0HV9R06EUI@25QHD0WinO079b
LP1ADE40<C4a03<c<`2^[Zh0_kno0;2`/02/[:`0OGem0:BTY02d];@0/[:b0=;BdP2TY:@0WIfM0;Vi
^@2o_kl0UIFE09BDU01jNWX0[:b/0=SHf02k^k/0b/[:07YjNP0[:b/09RHV030`<00h>3P0GEeM0;Ng
]`2IVIT0^[Zj0<O7a`1/K6`0DE5A00;ooooo0000o`1QHF40IVIV04M7A`1?Cdl0?clo08N7Q`17AdL0
@d=307YjNP0b<S80GUiN08>3P`1HF5P09bLW03`l?01ADE408b<S02`/;00I6AT0@T9204e=C@0V9RH0
B4Q802h^;P0F5QH0G5aL038b<P0L71`0?clo04U9B@0S8b<0<30`055AD@0L71`0<30`01/K6`0O7al0
>c/k05EEE@0_;bl0=CDe06IVIP1>CTh08B4Q05IFEP0Q8B40<30`01<C4`1CDe<0HF5Q03<c<`1mOGd0
71`L01<C4`0h>3P0G5aL03Xj>P1OGel0;2`/04m?C`1@D500Lg=c05]KF`18B4P0QXJ606MWI`0l?3`0
92@T05QHF018B4P0>c/k04];B`1WIfL08R8R01lO7`1bLW80NGUi03Hf=P1gMgL0EUIF02d];@1lO7`0
JVYZ03hn?P1>CTh0B4Q803Ti>@2JVYX0CDe=02h^;P1XJ6P0KVi^03lo?`0m?Cd0YZJV04e=C@1RHV80
]KFe08^;R`25QHD0Zj^[05mOG`1JFUX09RHV06m_K`10@4008R8R08B4Q02JVYX0?3`l03hn?P2PX:00
a<C403/k>`0`<300PH6103Lg=`1QHF40AdM703Lg=`2ATI40EEEE05MGE`1ZJVX0D51@04U9B@2GUiL0
O7al04i>CP2HV9P0IfMW07=cL`1aLG40CDe=06m_K`26QXH0D51@071`L01mOGd0CTi>065QH@1GEeL0
G5aL0:>SX`1ADE40N7Qh05aLG01ADE40YZJV07UiN@1CDe<0EEEE03hn?P1fMWH0];Bd05IFEP0];Bd0
Ng]k07AdM01VIVH0Xj>S03<c<`1@D500W9bL03hn?P0];Bd0Bd];05QHF013@d<0AdM706m_K`1:BTX0
@T9208B4Q01HF5P0PX:208>3P`1cLg<0NGUi08R8R01TI6@0BTY:0:^[Z`2NWYh0?Cdm06IVIP3:b/X0
YJFU07=cL`0f=SH0F5QH09^KV`1>CTh0=CDe06i^KP2PX:00@D5107QhN02ATI40GemO0410@01?Cdl0
J6QX02`/;01<C4`0<S8b06=SH`1hN7P0;bl_05ADE01hN7P0?3`l069RHP1dM7@0>SXj06IVIP1ZJVX0
5QHF02`/;02HV9P0NWYj03Hf=P2>SXh0De=C03@d=01cLg<0Fe]K03Ti>@25QHD0OGem0820P01ZJVX0
Bd];06QXJ01cLg<0Bd];09BDU01fMWH0`/;204Q8B00R8R80GEeM07QhN01?Cdl0QHF5030`<00N7Qh0
CDe=07YjNP1WIfL0>CTi04m?C`1NGUh08b<S02HV9P006P13@d<0AdM705]KF`1@D500GEeM06m_K`0Z
:RX0=SHf07UiN@1[Jf/0Cdm?08^;R`24Q8@06QXJ04M7A`1gMgL0?3`l09JFUP1mOGd0FEUI03Ph>01:
BTX0H61P06ATI00P8200?Cdm0P1NGUh0>00^;Rh0EUIF07]kN`1IFET0:RXZ06=SH`1;Bd/0>c/k038b
<P1cLg<0Rh^;079bLP0_;bl0]KFe07EeM@0Z:RX0MGEe0861P@1>CTh0d=3@08^;R`17AdL0UIFE08J6
QP0N7Qh0EeMG092@T01YJFT0<30`02TY:@11@D40JVYZ04m?C`0Y:BT0DU9B08f=S@0e=CD0:RXZ02HV
9P1hN7P0c<c<0<[:bP1RHV808B4Q0410@01<C4`0BDU906=SH`0];Bd05aLG00d=3@0:2PX03@d=01PH
600>3Ph03@d=0P0>3Ph02P0A4A403Ph>01LG5`1OGel0=3@d03Xj>P1MGEd0;Rh^061PH00G5aL300h>
3P80410@01P04a<C04i>CP0X:2P07AdM02PX:00/;2`0:b/[03@d=02@T900^;Rh06e]K@39bLT0`<30
0;Jf]P2CTi<0CTi>02d];@0I6AT08b<S024Q8@0A4A403@d=00h>3P0?3`l600h>3P04014A4@0=3@d0
3@d=00h>3P80410@00P0B4Q802XZ:P17AdL0W9bL07AdM00E5AD0410@00h>3P80410@00d03Ph>014A
4@0>3Ph03@d=014A4@0>3Ph0:b/[06YZJP0W9bL0Kfm_05IFEP0C4a<03Ph>00804A4A0P0>3Ph09@0B
4Q809RHV03`l?00X:2P04a<C01DE5@0R8R80QHF50;6a/@1nOWh0XZ:R0=kNgP3Rh^80RHV9055AD@1;
Bd/0>3Ph01dM7@0X:2P0=SHf01lO7`0H61P071`L02h^;P0i>CT0<c<c038b<P1@D500ZZZZ0:6QX@2O
Wil0/k>c0:JVYP0o?cl0CTi>05QHF00m?Cd00P1FEUH02P1ADE40ATI60451@@1XJ6P0[Jf]0:6QX@2R
XZ80YJFU0:2PX02=SHd207]kN`0?03<c<`0M7Ad071`L01dM7@1FEUH0B4Q804M7A`1^KVh0Ti>C02`/
;00X:2P09RHV05mOG`1fMWH06ATI00805ADE01H061PH01dM7@0M7Ad0@d=307moO`29RHT0D51@05mO
G`1iNGT0][Jf0:2PX023Ph<0ADE503Ti>@1MGEd0U9BD0<K6aP2ZZZX0Fe]K03@d=018B4P0>CTi0`0E
5AD0900D51@05ADE014A4@0C4a<0:RXZ055AD@11@D40GUiN09NGU`3<c<`0eMGE0<30`01SHf<0T92@
0<;2`P2d];@0gMgM0<O7a`1ADE40>c/k03De=@0_;bl0>3Ph0492@P1<C4`0UYJF05mOG`1<C4`0EeMG
02l_;`0W9bL0=cLg05mOG`2IVIT0P82001<C4`H05ADE01<06QXJ05UIF@2>SXh0Z:RX0<30`02b/[80
^[Zj06ATI01bLW80W9bL03<c<`0U9BD08b<S024Q8@0U9BD0BDU9079bLP1XJ6P0?clo00@05ADE02D0
51@D01LG5`0T92@0?Cdm04];B`1WIfL0JFUY07MgM`0g=cL0<c<c04U9B@0[:b/0=CDe06YZJP25QHD0
Y:BT0>7Qh@3Fe]H0_Kfm07YjNP0e=CD0MGEe08j>SP1YJFT0@D5102<S8`0L71`0>SXj0:f][@2YZJT0
JFUY05YJFP22PX80UYJF08n?S`2VYZH0/k>c0080d];B00P0cLg=0;fm_@2b/[80UYJF06MWI`1hN7P0
]KFe0=cLg080e=CD00`0JVYZ04E5A@10@400H61P0:>SX`2e]KD0g]kN0>7Qh@3UiND0hN7Q0<?3``2o
_kl2ooooo`0009@0HF5Q07alO01>CTh0EUIF03lo?`1iNGT0?Shn055AD@2EUID0AdM70492@P1BDU80
LG5a04A4A01;Bd/0KFe]02XZ:P18B4P0AdM705IFEP1;Bd/0:RXZ04A4A01DE5@0<C4a05IFEP0a<C40
7AdM03Ti>@1`L700@D5104e=C@1BDU807QhN04E5A@0g=cL0:RXZ04E5A@1EEED0;Bd]04I6AP1ZJVX0
EUIF02@T901aLG4092@T03lo?`0^;Rh0LG5a079bLP0h>3P0Vi^K05iNGP0W9bL0ADE506a/K00i>CT0
EUIF04U9B@1`L700PX:2075aL@14A4@0>CTi06=SH`1IFET0@d=303`l?01ZJVX0>CTi02DU9@15ADD0
Cdm?034a<@1>CTh0WinO071`L00Y:BT0MgMg05iNGP0`<300RHV906MWI`0i>CT0Kfm_051@D01<C4`0
[Zj^04];B`0k>c/0QhN707QhN012@T80CDe=0:n_[`0g=cL0@4100:j^[P1YJFT0FEUI08B4Q01SHf<0
G5aL024Q8@20P800Cdm?014A4@0e=CD0JFUY05EEE@1=CDd0YjNW0;>c/`1=CDd08R8R06MWI`1?Cdl0
BDU903Ph>00N7Qh0LW9b051@D017AdL0E5AD02d];@18B4P0SXj>06e]K@1;Bd/0G5aL03lo?`1iNGT0
IFEU05IFEP1GEeL0Cdm?030`<01PH600OGem05=CD`1DE5@0=SHf03@d=02DU9@0HV9R05UIF@16ATH0
;Bd]0P1TI6@0?P1SHf<0?clo01lO7`0l?3`0NWYj03<c<`0V9RH0Jf][0820P018B4P0VIVI03`l?01K
Fe/0Ogmo06m_K`0j>SX0F5QH0:2PX01QHF40C4a<06a/K016ATH0;Bd]06EUI@1QHF40S8b<06m_K`0n
?Sh0CTi>07EeM@1GEeL0ATI60::RXP26QXH0JVYZ07=cL`39bLT0Y:BT06a/K00m?Cd0JVYZ0;6a/@1W
IfL0@410079bLP2;Rh/0@41009RHV03;bl/0K6a/05QHF01]KFd0T92@02h^;P17AdL0<S8b030`<01>
CTh0=cLg051@D027QhL0>3Ph0P17AdL0;00];Bd0J6QX05MGE`0o?cl0JVYZ0;:b/P1QHF40:RXZ0861
P@1CDe<0EUIF096AT@1DE5@0?Cdm08>3P`28R8P0LG5a08N7Q`1lO7`0OGem0861P@1?Cdl0YZJV08:2
PP2QXJ40KVi^03hn?P1QHF40DE5A04a<C027QhL0IVIV03lo?`1PH600WIfM07EeM@0o?cl0BTY:061P
H011@D40;bl_04i>CP17AdL0IVIV0P1GEeL0B@1RHV80NGUi04a<C01jNWX0R8R80451@@28R8P0QHF5
038b<P1<C4`0ADE502DU9@2MWId0MGEe03lo?`0l?3`0C4a<05aLG01RHV80820P059BDP1hN7P0IfMW
03Lg=`1HF5P0I6AT05IFEP0W9bL0QHF507IfMP1?Cdl0?Cdm06UYJ@1mOGd0:b/[02LW9`2[Zj/0M7Ad
02/[:`1hN7P0Bd];02`/;02ZZZX0P82005]KF`2l_;`0Rh^;02/[:`0h>3P0SHf=04U9B@0o?cl0I6AT
07YjNP1UIFD09BDU034a<@1nOWh0SHf=034a<@0Z:RX0<S8b04U9B@2ZZZX0cLg=0<k>cP1oOgl0?Shn
05YJFP1:BTX0HF5Q020P800E5AD01@0=3@d00`0:2PX03Ph>00h>3P0200h>3P09014A4@1=CDd0=SHf
03/k>`2ATI40;bl_02TY:@0E5AD0410@00803Ph>00D03@d=00h>3P0O7al092@T01DE5@02014A4@0A
01@D500@41004A4A02d];@2[Zj/0f=SH0;Rh^022PX80SXj>06a/K01cLg<0KVi^05MGE`0];Bd0;2`/
01PH600=3@d00P0>3Ph01`0=3@d03Ph>00h>3P0@41003Ph>00l?3`0A4A400`0>3Ph02@0?3`l03Ph>
030`<012@T80N7Qh0<o?c`36a/H0C4a<010@400200h>3P0300d=3@0?3`l03Ph>00803@d=00P0410@
00h>3P0O7al0IFEU02HV9P13@d<0GemO010@40804A4A01@03Ph>00d=3@0@41004a<C028R8P0T92@0
@d=300h>3P0@41004A4A01`L702b/[80gmoO0>OWi`3Kfm/0ZZZZ0;jn_P18B4P07alO01LG5`8061PH
00H06a/K02h^;P0I6AT06a/K038b<P0U9BD202HV9P1002d];@1PH600>c/k06EUI@1JFUX0T92@07=c
L`0e=CD0@d=305QHF01`L700C4a<04I6AP1JFUX0MWIf07YjNP1LG5`0NGUi0;Fe]@37alL0SHf=0861
P@1NGUh0DE5A03dm?@0G5aL05ADE01LG5`1GEeL0AdM703/k>`17AdL0QHF502l_;`0W9bL0;Bd]03/k
>`1eMGD0:RXZ01TI6@0S8b<07AdM01TI6@0M7Ad071`L03De=@2BTY80^[Zj09JFUP2OWil0VIVI05iN
GP0f=SH0AdM7051@D02NWYh0XJ6Q06EUI@1PH600RHV9065QH@10@400Bd];02HV9P<05ADE00P05QHF
02LW9`11@D40?3`l020P801?Cdl0T92@07EeM@80/k>c01T0ADE503Ph>01KFe/0clo?0<O7a`2j^[X0
alO706m_K`1HF5P0KVi^07IfMP1iNGT0LW9b05]KF`28R8P0/K6a07inOP1FEUH0ATI602l_;`0g=cL0
GUiN0;no_`0j>SX0410@00<04a<C00X05ADE01HF5P0O7al0>c/k08Z:RP1nOWh0/[:b09FEU@1oOgl0
KFe]0P0K6a/0B`1MGEd0>3Ph02<S8`0S8b<07alO02DU9@0V9RH0FEUI06ATI01NGUh0DU9B02LW9`0E
5AD051@D01DE5@0M7Ad0@T9204U9B@1<C4`0Cdm?06=SH`0h>3P0=3@d08^;R`1ZJVX0GUiN0820P02Y
ZJT0bl_;0;Rh^02^[Zh0Zj^[0<?3``2k^k/0MWIf05=CD`0V9RH071`L01/K6`0L71`0=3@d0:BTY029
RHT0CDe=02TY:@0a<C40PX:2079bLP1VIVH0[Zj^0;Rh^03Hf=P0e]KF0=7Ad@3Lg=`0h^;R0=3@d02g
]kL0c<c<0=7Ad@3Ogml0fm_K0:VYZ@1bLW80WIfM09FEU@2g]kL0_Kfm07alO024Q8@0hn?S0=;BdP3H
f=P0MgMg075aL@02ooooo`000?l0GemO04m?C`19BDT0C4a<03`l?01bLW80=cLg03/k>`24Q8@0A4A4
05MGE`1HF5P0:RXZ03Lg=`1nOWh0Kfm_02DU9@19BDT0<c<c05eMG@1BDU8092@T05UIF@19BDT0<c<c
07YjNP0n?Sh08B4Q03hn?P0f=SH0;Bd]061PH01QHF40820P0451@@0R8R808B4Q06EUI@1ADE407QhN
02l_;`1RHV80<30`01XJ6P1dM7@08B4Q02h^;P0Y:BT0JFUY034a<@0];Bd0Vi^K03Ti>@0/;2`0H61P
05mOG`0`<300DE5A01hN7P1>CTh0KVi^07IfMP1FEUH0ATI605eMG@1GEeL0820P02l_;`1GEeL0DE5A
02`/;00g=cL0A4A4018B4P0R8R80FEUI05mOG`0U9BD0L71`030`<00G5aL0Cdm?04e=C@0c<c<0BTY:
02LW9`0V9RH0PH61055AD@0k>c/0NGUi06a/K00I6AT0<30`07alO012@T80@4100:b/[01jNWX0Hf=S
0;Zj^P1HF5P0GUiN02PX:02?Shl0T92@02l_;`1<C4`0RHV905=CD`10@400`<300<C4a01ADE40=3@d
07=cL`1<C4`0ADE504a<C00d=3@0QXJ606i^KP18B4P0G5aL051@D013@d<0U9BD08N7Q`1LG5`0PH61
05QHF01OGel0FEUI05]KF`1HF5P0P82004A4A01UIFD0J6QX055AD@1=CDd0C4a<059BDP2MWId0H61P
05UIF@1UIFD0ADE507alO01EEED0LG5a04E5A@0j>SX0AdM708R8R00a<C408B4Q061PH02:RXX0GUiN
09bLW00l?3`0De=C0:^[Z`27QhL0?Shn051@D02KVi/0GEeM04U9B@1jNWX0EUIF03`l?022PX80Ng]k
096AT@1XJ6P0Ng]k06MWI`1NGUh0@T9204i>CP2^[Zh0PH6108>3P`2:RXX0^[Zj0:>SX`1FEUH0Fe]K
08^;R`2[Zj/0L71`03lo?`1iNGT0UIFE0410@01ZJVX0Ti>C065QH@1DE5@0IFEU09>CT`0d=3@0ADE5
03dm?@0j>SX0JFUY03Ph>01BDU80UIFE061PH01CDe<0G5aL03@d=01SHf<0IVIV05ADE02JVYX0ZJVY
05YJFP0a<C40JVYZ0492@P1EEED0Shn?04=3@`0e=CD0MWIf08B4Q02;Rh/0SHf=07AdM01ZJVX0KVi^
04I6AP2g]kL0alO709FEU@1fMWH0ATI6061PH018B4P0@d=308n?S`1MGEd0>c/k05aLG02@T900KFe]
04Y:BP1YJFT0QhN704i>CP0f=SH00@1EEED104Y:BP80Fe]K01d0R8R807]kN`2<S8`0F5QH05]KF`28
R8P0F5QH08:2PP2?Shl0@T9205]KF`1BDU80>3Ph0:>SX`2k^k/0HF5Q04M7A`19BDT0FEUI03dm?@0I
6AT0J6QX07moO`1YJFT0=CDe05YJFP1MGEd0=cLg024Q8@0205]KF`0[03Ti>@0j>SX0PH6106a/K01H
F5P09RHV0;2`/01`L700;bl_06QXJ01YJFT0<c<c08:2PP0j>SX0>CTi09:BTP1gMgL0=cLg04E5A@2A
TI40G5aL01lO7`0J6QX0@D5105EEE@0e=CD061PH04Q8B023Ph<0>c/k03lo?`17AdL0I6AT08B4Q01Z
JVX0IFEU09BDU02g]kL0P82006m_K`1bLW80=SHf014A4@0300d=3@1100`<300=3@d04A4A00l?3`0A
4A4051@D01lO7`0a<C40IFEU08V9R@2ZZZX0/K6a0:ZZZP1mOGd0@41001dM7@0A4A403Ph>010@400Q
8B40<C4a01HF5P0E5AD04a<C00l?3`0@41004A4A01@D500a<C40QhN709nOW`2m_Kd0[Zj^0::RXP1R
HV80DU9B05ADE01GEeL0E5AD0410@00h>3P0:b/[010@400=3@d03Ph>018B4P0I6AT08B4Q02@T900P
82006QXJ01DE5@0A4A403@d=014A4@0@4100?Shn08j>SP2HV9P0QhN707inOP1lO7`0EeMG03dm?@0C
4a<00P0>3Ph02P0@41003Ph>00h>3P0>3Ph03@d=01lO7`1BDU808R8R030`<01LG5`2010@400C00h>
3P0=3@d03Ph>00d=3@0@41006ATI01/K6`1EEED05aLG01<C4`0@41004a<C08b<S03Rh^80j^[Z0=SH
f032`/80Z:RX02HV9P0401DE5@0R01LG5`0L71`0=SHf020P8010@4009BDU02LW9`0Z:RX0<S8b069R
HP0X:2P0C4a<092@T02>SXh0WYjN05UIF@1ADE40IVIV07inOP1kNg/0OWin06a/K01CDe<0>c/k03Ti
>@15ADD0UIFE0<[:bP1VIVH0BTY:06e]K@1iNGT0EUIF02l_;`805aLG03P0CDe=04I6AP0d=3@0>3Ph
08Z:RP2IVIT0LW9b05mOG`1WIfL0QhN705YJFP0c<c<0<S8b02@T900S8b<07AdM01hN7P0Q8B40@410
0;fm_@3EeMD0Z:RX07EeM@1VIVH0HV9R08J6QP2KVi/0fMWI08V9R@0N7Qh0<30`05eMG@1cLg<0L71`
055AD@1FEUH08B4Q01/K6`0e=CD0AdM704=3@`0Y:BT09bLW07MgM`2>SXh0M7Ad08N7Q`1SHf<0IfMW
07alO00k>c/0G5aL0;2`/02e]KD0^KVi08Z:RP<05ADE02406ATI02@T900e=CD0CTi>08b<S02`/;00
_;bl0:f][@2?Shl0Cdm?075aL@2f][H0Rh^;07MgM`0N7Qh05QHF01DE5@0O7al0;Bd]03Ti>@15ADD0
TI6A0;>c/`2RXZ80]kNg0:VYZ@1jNWX0A4A401LG5`0K6a/0<S8b08>3P`10@400100T92@0A00/;2`0
KVi^05EEE@15ADD0De=C04i>CP0a<C408b<S04];B`1@D500B4Q80451@@18B4P0FEUI04U9B@21PH40
H61P03De=@0a<C40;bl_03`l?01dM7@0Bd];06e]K@20P800WIfM0=oOg`2l_;`0KVi^03/k>`0[:b/0
8B4Q02/[:`2/[:`0MgMg03/k>`0Y:BT0820P02HV9P1KFe/0=cLg06e]K@2VYZH0]kNg0;^k^`3Bd]80
c/k>0=3@d03?cll0g=cL0<O7a`2o_kl0bLW90;Rh^02=SHd0S8b<05ADE02EUID0LW9b04Q8B01lO7`0
^;Rh0<c<c02i^KT0b/[:0;no_`2FUYH0EeMG0_ooool0003^05iNGP26QXH0BTY:05QHF00n?Sh0TI6A
05EEE@17AdL0UIFE05UIF@1EEED0D51@06e]K@12@T80@410069RHP0a<C40=SHf024Q8@0^;Rh0@410
02LW9`14A4@0>CTi01hN7P1RHV80@T9201`L700c<c<0Cdm?02TY:@16ATH0@d=301/K6`0e=CD0=SHf
02<S8`18B4P0I6AT034a<@0h>3P0IVIV05iNGP0N7Qh0GEeM01LG5`0m?Cd0<c<c05IFEP1<C4`0@410
0;Vi^@1ADE40<S8b03De=@1?Cdl0ATI603`l?00P8200MWIf06YZJP1[Jf/0DU9B04];B`1JFUX0L71`
04Y:BP0T92@0IFEU05mOG`0c<c<0>SXj04e=C@0h>3P0@T9209BDU024Q8@0:2PX07=cL`1:BTX0;2`/
05]KF`0i>CT0=3@d04e=C@0o?cl0:b/[09JFUP17AdL0>c/k071`L01BDU80=3@d03De=@2][Jd0De=C
03Xj>P2][Jd0S8b<04Q8B01HF5P0XJ6Q0410@00M7Ad0MgMg04Q8B00W9bL0Cdm?09JFUP1DE5@05aLG
07]kN`2[Zj/0EUIF03@d=01iNGT0?Shn06ATI01DE5@0;2`/07UiN@1LG5`0D51@06EUI@1BDU80@d=3
09jNWP25QHD0FEUI08b<S01LG5`0EeMG05mOG`1DE5@0EEEE08Z:RP1ADE40KFe]079bLP1EEED0De=C
04];B`1dM7@0WYjN069RHP1nOWh0MGEe04Y:BP2QXJ40CDe=08Z:RP1dM7@0ATI604A4A02PX:00<30`
01lO7`1MGEd0Shn?06ATI02JVYX0=3@d05iNGP2VYZH0P82003hn?P1JFUX0Q8B405eMG@1BDU80T92@
04m?C`0c<c<0Q8B407]kN`2:RXX0K6a/07QhN01/K6`0E5AD05]KF`1LG5`0_kno0:b/[026QXH0LW9b
0;Rh^02LW9`0DU9B03Ph>01QHF40[Jf]07IfMP11@D40Q8B409^KV`1CDe<0PH610:j^[P1/K6`0Cdm?
08b<S02/[:`0@d=3059BDP0k>c/0=cLg065QH@0f=SH0De=C092@T01MGEd0BTY:05=CD`0Y:BT0Hf=S
075aL@1eMGD0VIVI0;Vi^@1aLG40@d=30:JVYP1[Jf/0CDe=0820P01@D500<c<c05iNGP1hN7P0L71`
06UYJ@21PH40KFe]069RHP0g=cL0N7Qh06YZJP80N7Qh00T0A4A406UYJ@0e=CD0AdM709JFUP1RHV80
=cLg05eMG@1mOGd00P0/;2`01@1>CTh0JFUY03Hf=P0g=cL0E5AD0080ADE504d0<30`05]KF`1hN7P0
PX:205]KF`1TI6@0Q8B403@d=01eMGD0YjNW051@D01aLG40P820038b<P1oOgl0PX:206YZJP18B4P0
FEUI06IVIP1PH6007QhN03Hf=P1GEeL0EEEE03/k>`2BTY80Shn?07EeM@0X:2P0Kfm_0492@P0I6AT0
<30`08^;R`27QhL0GemO02`/;02UYJD0GUiN02@T9024Q8@0SHf=05=CD`1PH600MWIf065QH@2LW9`0
RHV903Xj>P1QHF40[Zj^065QH@0];Bd0820P03Xj>P1TI6@0<c<c01dM7@1ADE40RHV904U9B@0l?3`0
=3@d02LW9`0R8R80EEEE04m?C`19BDT0H61P09RHV02l_;`0WinO02XZ:P0A4A403@d=00`<300200d=
3@0401<C4`1JFUX0GUiN04];B`80?Shn00l0@41006e]K@2?Shl0I6AT04A4A01HF5P0KFe]07EeM@1f
MWH0KFe]06=SH`1UIFD0L71`01TI6@0C4a<00P0@41006@0A4A403Ph>014A4@0K6a/0I6AT04E5A@0X
:2P0YjNW0;Zj^P1mOGd0TY:B07]kN`1CDe<0FEUI05eMG@1DE5@0DE5A04Y:BP0o?cl08R8R00h>3P0E
5AD06a/K01dM7@0P82000P0Y:BT04@0k>c/0@D5102d];@0[:b/0Hf=S07emO@1kNg/0FEUI07=cL`1J
FUX0E5AD04M7A`1HF5P0H61P02<S8`0@41003Ph>0080410@00T03Ph>018B4P0c<c<0@410024Q8@0U
9BD0F5QH01<C4`0>3Ph00P0@410200h>3P0=010@400I6AT07AdM04M7A`0c<c<05ADE01HF5P17AdL0
^KVi0=_Kf`3WinL0_;bl0:f][@0206m_K`03024Q8@0E5AD04a<C00805ADE00/05aLG02/[:`16ATH0
>c/k01/K6`0T92@0:b/[038b<P1SHf<0@D5106][J`0205QHF01?06UYJ@1nOWh0BDU9059BDP19BDT0
QHF509RHV02>SXh0TI6A08^;R`27QhL0T92@06YZJP1gMgL0CTi>055AD@1CDe<0Fe]K06][J`1?Cdl0
?Cdm01TI6@14A4@0MGEe03/k>`0h>3P0LW9b03Xj>P0o?cl0F5QH07MgM`2=SHd0T92@07alO01oOgl0
Hf=S05aLG01/K6`0KVi^06ATI02:RXX0bLW90>7Qh@3Hf=P0b<S80<30`02>SXh0MgMg059BDP27QhL0
YjNW05MGE`0Q8B40>c/k05QHF01EEED0JFUY07=cL`2PX:00GEeM03Xj>P0^;Rh09BDU03Ph>029RHT0
N7Qh06QXJ01nOWh0A4A402DU9@0c<c<0HV9R0:2PX02i^KT0DE5A05]KF`1[Jf/0N7Qh01LG5`0501DE
5@0c01PH601UIFD0Cdm?07=cL`20P800[jn_0<k>cP2ZZZX0=SHf01lO7`1`L700?Cdm03De=@19BDT0
BTY:05aLG01iNGT0R8R80;Bd]03>c/h0emOG08B4Q023Ph<0QhN7051@D00K6a/092@T034a<@2ATI40
_;bl079bLP0o?cl0;Bd]02@T900V9RH0CDe=07inOP1:BTX0AdM704];B`1RHV80TY:B09FEU@1DE5@0
=SHf0451@@1UIFD0VIVI07UiN@19BDT07alO00806a/K00H071`L020P801JFUX0C4a<07inOP2MWId2
0;fm_@0Y0:f][@31`L40/k>c08B4Q02LW9`0^KVi07YjNP0e=CD0;2`/028R8P0O7al0=CDe03Hf=P0/
;2`0N7Qh0;fm_@2GUiL0Zj^[0<g=c@36a/H0e=CD0<g=c@3EeMD0a/K607inOP25QHD0KFe]03dm?@0n
?Sh0FEUI03Ti>@1nOWh0Ogmo06e]K@2o_kl0b<S80:VYZ@2ZZZX0BTY:04E5A@1RHV800_ooool0001D
06ATI02EUID0CDe=04A4A010@400NWYj04Q8B01:BTX0P82004E5A@2@T900WinO08n?S`1@D500B4Q8
07QhN00l?3`0>c/k04I6AP1:BTX0=SHf02<S8`19BDT0G5aL03Lg=`1]KFd0;Bd]01HF5P0a<C40K6a/
03`l?01BDU80A4A401PH600i>CT0Bd];03@d=01<C4`0GUiN03Lg=`0i>CT0J6QX06ATI00[:b/0Fe]K
01LG5`12@T80@41005IFEP1<C4`0BDU90;jn_P1NGUh0ATI604M7A`1IFET0DE5A03Lg=`0K6a/0Ph>3
075aL@1XJ6P0D51@04U9B@2<S8`0R8R803lo?`0V9RH0HV9R05EEE@0c<c<0?3`l05eMG@1<C4`0CTi>
0:6QX@23Ph<09RHV08^;R`1YJFT09bLW07EeM@1DE5@0>CTi0P1ADE40;@0Y:BT0WIfM05MGE`0j>SX0
Jf][06a/K01GEeL0<c<c0:b/[017AdL0ADE50;Fe]@2CTi<0BTY:06m_K`24Q8@0I6AT030`<027QhL0
?Shn01dM7@0o?cl0N7Qh04a<C00K6a/0CTi>0;2`/01JFUX0C4a<09VIV@0c<c<0Bd];05YJFP0`<300
N7Qh02/[:`1aLG40QHF506MWI`18B4P0/K6a05YJFP1;Bd/0TY:B05iNGP0206ATI00805QHF027QhL0
T92@055AD@1_Kfl0PX:204i>CP1WIfL205mOG`2d08f=S@1>CTh0IfMW06YZJP1CDe<0SXj>05MGE`1V
IVH0GEeM05QHF01;Bd/0]kNg02h^;P0`<300QXJ609JFUP1JFUX0Ti>C02DU9@1aLG40Xj>S07emO@0b
<S80J6QX07IfMP0g=cL0LW9b096AT@1QHF40=3@d08:2PP1<C4`0QhN709NGU`22PX80I6AT061PH017
AdL0?Cdm09VIV@25QHD0LW9b05QHF02YZJT0YJFU05iNGP0i>CT0Jf][0:FUY@1?Cdl0G5aL09bLW02X
Z:P0GEeM08Z:RP2o_kl0GUiN02LW9`1EEED0N7Qh02d];@0a<C40?3`l0451@@1`L700A4A4071`L02F
UYH0EUIF04=3@`1JFUX0<c<c07=cL`23Ph<0G5aL08B4Q02n_[h0Fe]K03<c<`29RHT0K6a/04E5A@25
QHD0D51@03hn?P1bLW80S8b<07AdM01EEED0O7al09nOW`2?Shl0D51@09nOW`2BTY80VIVI07]kN`15
ADD0IVIV03Ph>00o?cl0Ogmo061PH00h>3P0FEUI08F5Q@1YJFT0?clo05=CD`1QHF40?Cdm04Q8B01g
MgL0C4a<07emO@19BDT0DU9B06a/K02;Rh/0C4a<06i^KP20P800=cLg05YJFP2<S8`0=3@d06i^KP1<
C4`0:RXZ09FEU@24Q8@0AdM703De=@1]KFd0RXZ:06m_K`0P8200>3Ph051@D00[:b/07QhN0410@01N
GUh0De=C02l_;`2DU9@0Hf=S04m?C`0Q8B40FEUI069RHP1>CTh0?3`l0;fm_@1WIfL05QHF06=SH`0i
>CT0DE5A0820P021PH40KVi^0<30`02PX:00<c<c0492@P2DU9@0Hf=S03Xj>P0W9bL0@41005YJFP0U
9BD09RHV07QhN02ATI40>3Ph030`<00/;2`09BDU0P0O7al0801:BTX0UIFE0820P01`L700SHf=09:B
TP0];Bd04a<C00d=3@061PH02PX:01<C4`0?3`l071`L02HV9P0b<S80=CDe03dm?@1[Jf/0];Bd07Qh
N01LG5`0FEUI05YJFP1VIVH0?Shn02l_;`0`<300?Shn07inOP2<S8`0BDU90P0C4a<0600>3Ph0410@
014A4@0D51@0De=C03Ph>00M7Ad05ADE065QH@1CDe<05aLG02DU9@1>CTh0Rh^;07alO01:BTX0FEUI
055AD@1;Bd/0=SHf03lo?`19BDT0<S8b01dM7@@06ATI0180820P03`l?01hN7P0P820065QH@1BDU80
FUYJ05UIF@1YJFT0/k>c071`L00e=CD08B4Q02/[:`1>CTh0DE5A03@d=00F5QH2010@400701/K6`1?
Cdl0;2`/01`L700N7Qh0BTY:01PH600200h>3P0D018B4P0>3Ph03Ph>010@400Z:RX0CTi>04E5A@2F
UYH0NGUi07=cL`1KFe/0YjNW0;Bd]02m_Kd0c<c<0;:b/P1^KVh0DE5A071`L00l?3`201@D500W01DE
5@0D51@08b<S03Ph>014A4@06ATI01DE5@0G5aL0=CDe0861P@1EEED0ATI602l_;`0O7al0@d=305EE
E@0F5QH08b<S059BDP1XJ6P0G5aL05UIF@1QHF40Ng]k0;2`/02h^;P0Lg=c01dM7@0C4a<06QXJ04A4
A01OGel0NGUi07IfMP1ADE40Jf][07MgM`2o_kl0U9BD0080PX:203H0:2PX02h^;P0i>CT0QhN70:BT
Y02LW9`0SXj>06UYJ@1[Jf/0FUYJ04A4A010@400ADE5065QH@32`/80f][J09^KV`21PH40Bd];02HV
9P0P82008b<S02XZ:P1YJFT0[jn_07]kN`18B4P0E5AD06=SH`1WIfL0DU9B09>CT`28R8P09bLW03@d
=01JFUX0LG5a09:BTP1`L700LW9b03Ph>00d=3@0=CDe03dm?@1<C4`0XJ6Q0;no_`0^;Rh0?Shn06EU
I@1BDU805ADE01@D500C4a<301DE5@0<01lO7`26QXH0Fe]K04E5A@16ATH0B4Q806a/K01iNGT0:2PX
02`/;013@d<0GEeM0P1fMWH0F01oOgl0A4A403Xj>P1?Cdl0_Kfm0:JVYP1oOgl0QHF505MGE`2m_Kd0
[:b/06e]K@1mOGd0QHF507MgM`1bLW80Rh^;09bLW02MWId0MWIf05iNGP1QHF40Xj>S08>3P`1_Kfl0
Ng]k08J6QP1mOGd0/;2`07IfMP1?Cdl0L71`09BDU01[Jf/0Ogmo02LW9`0K6a/06QXJ01/K6`0L71`0
;Bd]079bLP1_Kfl0[Zj^0<71`@2LW9`0PX:20820P01cLg<0LW9b08N7Q`2SXj<0bl_;03@d=00Y:BT0
8R8R01dM7@0Q8B40ADE502d];@1KFe/0Lg=c0:j^[P2UYJD0[Jf]0<S8b033`l<0b<S80;Ng]`2n_[h0
S8b<028R8P0O7al0=CDe06YZJP1CDe<0HV9R07AdM01`L700FEUI0492@P2CTi<0/K6a0;Vi^@1eMGD0
<C4a03@d=01<C4`2ooooo`000800M7Ad08N7Q`1@D500De=C03dm?@2;Rh/0CDe=04U9B@2@T900BTY:
04E5A@1@D500KFe]04Q8B013@d<0Lg=c0410@00n?Sh0Bd];04i>CP0l?3`0:BTY04e=C@1PH600=3@d
06QXJ00_;bl05aLG034a<@1MGEd0@41004a<C01;Bd/07AdM05ADE01CDe<0;Rh^04a<C010@40071`L
059BDP1gMgL0EEEE02DU9@1HF5P07alO04i>CP1ADE40F5QH06ATI014A4@0/K6a06YZJP11@D40A4A4
069RHP1FEUH0DE5A03@d=01gMgL0OGem06UYJ@0[:b/09RHV04m?C`1dM7@0ADE504I6AP1aLG40:2PX
02DU9@1=CDd0I6AT04Q8B01DE5@0Y:BT06YZJP0P8200Vi^K07UiN@0[:b/0R8R806MWI`0n?Sh0N7Qh
06YZJP0/;2`0/k>c0410@01;Bd/0SHf=08N7Q`1JFUX0?Cdm0;no_`1@D500=CDe0:NWY`1gMgL0AdM7
0;Ng]`1ZJVX0E5AD02PX:02;Rh/0@41001HF5P14A4@0N7Qh04a<C00M7Ad0<30`09RHV00l?3`0A4A4
065QH@1;Bd/0CTi>04m?C`0[:b/0RXZ:06=SH`1@D500EEEE030`<01ADE40V9RH071`L080Bd];0=X0
:BTY079bLP1hN7P0=SHf04m?C`1TI6@0@41008j>SP2DU9@0De=C04m?C`19BDT0MGEe0:f][@1iNGT0
MGEe03dm?@0j>SX0PH6104i>CP1/K6`0EEEE02PX:01OGel0X:2P05YJFP0Y:BT0F5QH07AdM01SHf<0
Shn?02d];@1bLW80XZ:R07IfMP0h>3P0OGem075aL@1WIfL0BDU907alO011@D40=CDe08J6QP1kNg/0
Ph>306a/K01iNGT0H61P05aLG01@D500HF5Q0;2`/02QXJ40PH6105QHF02[Zj/0]KFe08j>SP16ATH0
OGem0:6QX@19BDT0=SHf05aLG01iNGT0B4Q809FEU@3:b/X0MgMg03hn?P1HF5P0R8R803<c<`1;Bd/0
=cLg0820P02JVYX0>SXj05EEE@25QHD0C4a<06i^KP1bLW80>CTi051@D01eMGD08B4Q04E5A@34a<@0
PH610492@P2MWId0BDU9055AD@2g]kL0E5AD0492@P1gMgL0SHf=08V9R@0g=cL0IfMW06EUI@2>SXh0
DE5A0;fm_@2ATI40ZJVY06m_K`18B4P0TI6A06=SH`1FEUH0Rh^;069RHP0o?cl0P8200:RXZ01oOgl0
@T9205=CD`1WIfL09BDU03`l?01mOGd0TI6A08^;R`1HF5P0EEEE075aL@2<S8`0ATI60:>SX`2;Rh/0
Cdm?065QH@2HV9P071`L07EeM@1iNGT0Fe]K0:JVYP28R8P0EEEE03Xj>P15ADD0D51@05=CD`0/;2`0
K6a/08V9R@1NGUh092@T04U9B@1JFUX09bLW01lO7`1cLg<0PX:206YZJP0O7al0KVi^065QH@0f=SH0
:BTY07emO@1RHV80<S8b055AD@1FEUH0@d=307moO`1NGUh0D51@0=GEe@2VYZH0JVYZ05QHF02][Jd0
>CTi03Ph>01HF5P0L71`05eMG@11@D4071`L0492@P1jNWX0<S8b02`/;00V9RH09BDU020P800L71`0
Bd];0<[:bP35aLD0QXJ60:n_[`2[Zj/0Ng]k03lo?`0];Bd061PH0451@@0/;2`06a/K02d];@0h>3P0
?clo051@D01QHF40FUYJ05mOG`2?Shl0PH61071`L080J6QX01@0<30`02@T900Y:BT0B4Q804I6AP0e
=CD0Q8B403Lg=`0B4Q80410@01@D500E5AD0AdM704U9B@0Q8B405aLG01DE5@0j>SX0ADE5014A4@80
3Ph>02X061PH059BDP1jNWX0DE5A04M7A`18B4P0Fe]K05ADE01ADE40GEeM05]KF`11@D408R8R01TI
6@0Y:BT0Jf][07inOP1/K6`0IFEU05aLG00c<c<0?3`l07IfMP1IFET0Vi^K07=cL`1DE5@0?Cdm02PX
:00g=cL0<S8b03hn?P1BDU80F5QH04=3@`1?Cdl0MgMg02HV9P0G5aL06a/K04=3@`0[:b/300h>3P03
00l?3`0>3Ph04Q8B0080;Bd]02/0VIVI0:j^[P1OGel0AdM707inOP1gMgL0YZJV0:b/[03?cll0S8b<
06a/K026QXH0GEeM06MWI`1JFUX0>3Ph02d];@0M7Ad0>c/k02d];@0T92@07AdM01DE5@0N7Qh0M7Ad
0;^k^`2KVi/0MgMg06][J`1/K6`0QhN706QXJ00k>c/0<c<c06e]K@0g=cL0B4Q8034a<@0h>3P0?Cdm
05MGE`26QXH0:BTY00805ADE01@04a<C01LG5`0j>SX0EEEE06YZJP2_[jl0UYJF079bLP11@D40Ng]k
0820P01dM7@0T92@08j>SP2HV9P0XZ:R0:f][@2NWYh0Rh^;06e]K@80KVi^00D0Ng]k0861P@1fMWH0
YjNW0:ZZZP0209FEU@0T06a/K00g=cL08R8R01dM7@0e=CD0;2`/02DU9@2=SHd0`L7109RHV01bLW80
EeMG04i>CP1lO7`0NWYj07AdM02<S8`0U9BD065QH@1eMGD0S8b<05aLG011@D40E5AD05]KF`1TI6@0
F5QH069RHP2e]KD0Y:BT03`l?00[:b/0Jf][06ATI00I6AT05ADE0P0G5aL0A`0Y:BT0>3Ph03lo?`16
ATH0P82006a/K01JFUX0EUIF03lo?`1NGUh09BDU01/K6`0U9BD0L71`0:JVYP2BTY80QXJ607MgM`2B
TY80`L710=;BdP1[Jf/0JFUY09FEU@16ATH0UiNG051@D012@T80Bd];05MGE`1>CTh0Cdm?0410@016
ATH0EEEE06YZJP26QXH0UiNG05ADE01bLW80UiNG0<O7a`3;bl/0]kNg0<S8b037alL0WinO08f=S@1`
L700P82008Z:RP1TI6@0>SXj024Q8@0S8b<092@T04];B`2YZJT0Rh^;09RHV02PX:00K6a/0;>c/`1^
KVh0>3Ph03Ti>@13@d<0DU9B0:RXZ01CDe<0:RXZ008071`L01l0BDU903<c<`1:BTX0F5QH06][J`2X
Z:P0U9BD0;bl_02m_Kd0JFUY05UIF@1BDU80KVi^07YjNP0T92@07QhN03/k>`33`l<0Vi^K06m_K`2]
[Jd0`<3009jNWP1FEUH0_[jn09nOW`2`/;00>c/k038b<P0k>c/0=SHf00;ooooo0000o`1UIFD0E5AD
04a<C01DE5@0@41006][J`0m?Cd0FEUI0::RXP1GEeL0EUIF06MWI`23Ph<0@d=303`l?010@400;2`/
06a/K017AdL0BDU905MGE`0e=CD0Lg=c07UiN@0g=cL0JVYZ04A4A00V9RH0?clo059BDP0c<c<0Bd];
05ADE00U9BD0?3`l055AD@0W9bL0HV9R06ATI00f=SH0<c<c05eMG@1BDU808b<S06a/K00K6a/0C4a<
03/k>`20P800E5AD03dm?@2i^KT0Ogmo04M7A`1:BTX0De=C02XZ:P1BDU80=cLg06UYJ@2>SXh0JFUY
04M7A`0n?Sh0Cdm?08F5Q@0X:2P0;Rh^05aLG01CDe<0<c<c02d];@1HF5P0?Cdm05ADE02[Zj/0K6a/
01/K6`27QhL0D51@02TY:@1gMgL0Hf=S03Ph>014A4@0>SXj02XZ:P2BTY80EEEE03Hf=P1^KVh0QHF5
02l_;`0Z:RX0Q8B405=CD`0i>CT0ZJVY08f=S@1:BTX0^[Zj051@D016ATH0:b/[096AT@1^KVh07AdM
0451@@1jNWX0Q8B403`l?00o?cl0YjNW07=cL`2MWId0Vi^K04A4A01OGel0J6QX02/[:`1SHf<0DU9B
06IVIP1dM7@0D51@03Hf=P2<S8`0NWYj051@D026QXH0EUIF05MGE`1[Jf/0@d=306a/K01lO7`0?Shn
05aLG01eMGD0F5QH07UiN@14A4@0ADE508n?S`1HF5P0VYZJ079bLP17AdL0WYjN02h^;P1DE5@0LW9b
04A4A00m?Cd0ZZZZ038b<P0[:b/0LG5a06UYJ@1OGel0ZZZZ0492@P1gMgL0XJ6Q0410@00T92@0JVYZ
0861P@1UIFD0Fe]K092@T013@d<0;Bd]079bLP1mOGd0Y:BT07moO`1?Cdl0JFUY09ZJVP1^KVh0J6QX
0:JVYP2BTY80Jf][05]KF`34a<@0`L7107MgM`1UIFD0V9RH0;Ng]`1bLW80=cLg05UIF@22PX80@410
071`L02PX:00Kfm_0410@01:BTX0U9BD04I6AP1XJ6P0E5AD03De=@1gMgL0Bd];06i^KP2FUYH0=SHf
06a/K026QXH0>SXj05EEE@1UIFD0@T92051@D02SXj<0JFUY04=3@`2[Zj/0>CTi030`<01NGUh0GemO
04A4A01bLW80Shn?07QhN018B4P0Ng]k05eMG@1fMWH0BDU90;Jf]P2ATI40QXJ605mOG`0e=CD0D51@
04E5A@18B4P0Vi^K05]KF`0`<300Cdm?08^;R`1`L700Bd];071`L01[Jf/0>SXj02XZ:P00KP0o?cl0
DE5A05iNGP1=CDd0UYJF0;6a/@0n?Sh08B4Q09>CT`2?Shl0DU9B07=cL`2IVIT0<30`05YJFP1EEED0
?3`l09>CT`33`l<0IFEU04E5A@18B4P0BDU903Hf=P0G5aL0?Shn05aLG01HF5P09RHV051@D01oOgl0
JFUY03@d=02@T900RXZ:06i^KP0N7Qh0OGem06i^KP1cLg<0>SXj09>CT`1CDe<07alO05IFEP1RHV80
ADE508^;R`0f=SH0@4100:f][@2TY:@0GemO06MWI`2YZJT0G5aL02l_;`0P8200De=C07EeM@0n?Sh0
7AdM04a<C02HV9P0=3@d02XZ:P0U9BD09bLW03Ph>01IFET0GUiN0492@P1UIFD0YZJV09BDU01UIFD0
H61P06a/K02<S8`0I6AT06YZJP0Z:RX061PH02DU9@0a<C40;bl_02@T900M7Ad07QhN03<c<`0d=3@0
ADE507QhN02KVi/0Rh^;05UIF@0a<C40;bl_05]KF`12@T80;2`/03Ph>02DU9@0AdM701DE5@0C4a<0
?Cdm069RHP0[:b/05aLG0P0E5AD01@0W9bL0E5AD014A4@0@41004Q8B00803Ph>02H08b<S06MWI`1Y
JFT0ATI606MWI`0`<300B4Q806QXJ01/K6`0KVi^07IfMP2>SXh0TY:B075aL@1bLW80EUIF05=CD`1B
DU80Lg=c07IfMP2PX:00G5aL07emO@1JFUX0HV9R05=CD`15ADD0Bd];05EEE@11@D40<c<c034a<@0e
=CD0?clo09BDU01<C4`06ATI01DE5@80>CTi01l0410@00h>3P0=3@d03@d=00l?3`0I6AT0:BTY01hN
7P1oOgl0QHF504i>CP2;Rh/0KVi^05=CD`1`L700^k^k08N7Q`1IFET0K6a/04i>CP1WIfL0GUiN06IV
IP1fMWH0L71`07]kN`2e]KD0E5AD03Lg=`0/;2`0=cLg0080R8R804X0CDe=07EeM@1/K6`0Hf=S07Ee
M@0k>c/09BDU03<c<`1HF5P0Lg=c05QHF01>CTh0C4a<03/k>`0b<S808R8R07moO`1lO7`0>c/k01@D
500A4A405ADE024Q8@13@d<0Rh^;0:6QX@1NGUh0?Shn01XJ6P0H61P0:b/[09RHV02m_Kd0VIVI06MW
I`1XJ6P0MgMg06m_K`1LG5`0<C4a02TY:@0X:2P0>SXj07YjNP1EEED0J6QX04i>CP1:BTX0MGEe06MW
I`0m?Cd09bLW020P8015ADD0<S8b02TY:@0g=cL0PH610<_;b`2<S8`0P82007IfMP2MWId0N7Qh04e=
C@2<S8`0[Zj^07MgM`2?Shl0I6AT051@D012@T808R8R01LG5`805ADE02P06QXJ04i>CP1aLG40L71`
02l_;`1:BTX0EeMG01lO7`0K6a/0;2`/03Ti>@0`<3007AdM024Q8@0R8R80;Rh^059BDP1LG5`0@d=3
03@d=01CDe<0CDe=01LG5`0M7Ad0T92@096AT@2NWYh0W9bL055AD@17AdL0ADE507YjNP2OWil0P820
0;Zj^P1iNGT0IVIV020P800M7Ad0820P0P0N7Qh0B@0P82009BDU02LW9`0W9bL0:BTY07=cL`23Ph<0
OGem07YjNP1^KVh0P82009ZJVP2WYjL0_;bl0;Fe]@3GemL0a<C406e]K@1=CDd0BDU904a<C01QHF40
JFUY061PH01JFUX0V9RH0<;2`P33`l<0d=3@09fMW@2TY:@0R8R808^;R`1RHV80?clo03De=@10@400
PH6108V9R@0j>SX0<30`05IFEP1>CTh0;Bd]02h^;P10@400C4a<0:JVYP2][Jd0Z:RX0;6a/@2EUID0
OWin05YJFP1HF5P0R8R802l_;`14A4@0TY:B06=SH`1NGUh0K6a/08:2PP2^[Zh0/k>c0<K6aP34a<@0
^KVi07alO00];Bd0<C4a02`/;00X:2P00_ooool0002F06UYJ@1aLG40AdM7051@D011@D40T92@04M7
A`13@d<0O7al04M7A`1JFUX0F5QH03`l?012@T80P82008f=S@0n?Sh0ATI603Lg=`1MGEd0K6a/02XZ
:P18B4P0DE5A02<S8`29RHT0NGUi02HV9P0d=3@0;Rh^00T92@0R8R80EeMG03Ti>@10@400=cLg00X:
2P0X:2P0I6AT03De=@0h>3P0MgMg03De=@0C4a<0DE5A02LW9`12@T80A4A40861P@0];Bd08R8R08^;
R`1MGEd0@D5107=cL`1OGel0C4a<05MGE`0R8R80C4a<06ATI010@400=3@d03hn?P1=CDd0P82003dm
?@0Y:BT0JVYZ05mOG`0b<S80>CTi059BDP0];Bd0=3@d07alO01/K6`07QhN09BDU01CDe<09bLW04e=
C@0f=SH0@41004Y:BP1CDe<08B4Q09BDU01BDU80=CDe06QXJ02:RXX0F5QH03<c<`2NWYh0H61P03dm
?@2WYjL0WinO04i>CP2^[Zh0LW9b038b<P0S8b<0Shn?08N7Q`0^;Rh0AdM708>3P`1@D5007QhN04];
B`1aLG40UYJF0:6QX@30`<00;bl_03Ph>01MGEd0;bl_06QXJ00P8200BDU907EeM@1TI6@0>3Ph08>3
P`0g=cL09bLW07inOP1IFET0EUIF051@D00d=3@0JFUY08R8R01ADE40LW9b071`L00Y:BT0CDe=069R
HP1BDU80RXZ:03Ph>01hN7P0KVi^05=CD`23Ph<0CTi>0P1GEeL00`1;Bd/0@4100<30`002038b<P2f
0861P@27QhL0D51@08V9R@0d=3@0Ph>30;Jf]P1bLW808B4Q06i^KP1TI6@0;Rh^06=SH`2LW9`0PX:2
02h^;P1UIFD0@41009jNWP2g]kL0De=C03dm?@23Ph<0QHF506ATI02YZJT0^k^k08B4Q014A4@0[Zj^
09nOW`10@400ADE506QXJ02/[:`0FEUI03`l?01EEED0TY:B04e=C@26QXH0`L7108B4Q010@400?Cdm
08F5Q@0c<c<0@D5103`l?00^;Rh0Hf=S038b<P21PH40V9RH04];B`1LG5`0IfMW02@T901]KFd0QHF5
06QXJ01kNg/0V9RH04e=C@1QHF40`L71055AD@16ATH0M7Ad04e=C@0b<S80IfMW0:BTY02?Shl0EUIF
08B4Q01KFe/0N7Qh03dm?@2OWil0/k>c0:ZZZP1gMgL0>3Ph065QH@10@400CTi>0:2PX020P800>SXj
04a<C023Ph<0>c/k03Ti>@1BDU80JFUY04M7A`0_;bl0CTi>06e]K@1;Bd/0;Bd]05MGE`1eMGD0Kfm_
03Xj>P2LW9`0Hf=S02h^;P1GEeL0M7Ad051@D01OGel0Ogmo03`l?01dM7@0VIVI06QXJ019BDT0CTi>
065QH@1aLG409RHV03Lg=`1@D500@d=3034a<@1[Jf/0Kfm_05QHF00c<c<0Lg=c07QhN00`<3009BDU
07emO@1aLG40CDe=038b<P2;Rh/0Hf=S038b<P1=CDd0JVYZ05ADE02`/;00FUYJ04E5A@2=SHd0V9RH
03De=@1mOGd0/[:b05iNGP0/;2`08R8R0492@P1fMWH0@d=3030`<01UIFD0UIFE03<c<`0d=3@0B4Q8
06EUI@1JFUX0=SHf03Lg=`16ATH0CTi>065QH@24Q8@0Ph>307IfMP2SXj<0/[:b07MgM`2OWil0?Shn
02/[:`0K6a/201DE5@0401<C4`0E5AD05ADE01DE5@805aLG00`092@T06ATI01_Kfl0EEEE04M7A`0Y
:BT0?Shn0451@@0b<S8092@T04e=C@2[Zj/2059BDP0408:2PP0k>c/07AdM01HF5P805aLG00<06ATI
05=CD`0B4Q800P0@4100@P0C4a<03Ph>00h>3P0?3`l0BDU90820P02o_kl0MgMg05QHF01/K6`0QHF5
0:b/[03:b/X0e=CD0<G5a@2MWId0QHF506EUI@1>CTh0@41003hn?P1EEED0Rh^;06i^KP0b<S806ATI
02d];@1MGEd0IFEU05MGE`0o?cl0>SXj059BDP1OGel0Cdm?01hN7P1@D500JFUY03@d=00M7Ad0=cLg
06i^KP0G5aL06ATI02@T900b<S80>3Ph03Ti>@1ADE40Ph>308b<S01ADE40R8R8096AT@1ZJVX0Hf=S
061PH02EUID0@T9201lO7`0_;bl0De=C04U9B@13@d<0IVIV07YjNP80XZ:R03D0WYjN09BDU01cLg<0
Rh^;08>3P`1aLG40ATI605IFEP1=CDd0HV9R05iNGP0_;bl0<c<c02XZ:P0M7Ad0820P0451@@1bLW80
NWYj06a/K019BDT0;2`/05QHF02GUiL0BDU905=CD`1PH600C4a<02<S8`0E5AD0=SHf0;Bd]02XZ:P0
R8R804];B`0d=3@0?Shn03Ti>@29RHT0]KFe092@T011@D40FEUI05=CD`19BDT0Hf=S051@D00_;bl0
7AdM01`L700Q8B40Kfm_07AdM002034a<@0H05YJFP1nOWh0MGEe03hn?P0f=SH0=3@d02`/;00Y:BT0
;Rh^03Ti>@1cLg<0VYZJ0:>SX`2EUID0TY:B08R8R00n?Sh0X:2P09RHV02_[jl0GEeM02XZ:P0G5aL0
51@D0P0E5AD0400D51@05ADE01LG5`0/;2`0FUYJ07]kN`13@d<0>SXj061PH017AdL0<S8b02<S8`0P
82008R8R024Q8@0S8b<202HV9P1502d];@0f=SH0@d=304E5A@0m?Cd0J6QX030`<01_Kfl0MGEe079b
LP1cLg<0Q8B402d];@0d=3@0?clo04i>CP2HV9P0`<300=[JfP3:b/X0@T9201`L700M7Ad06QXJ01TI
6@0H61P071`L01hN7P0[:b/0A4A406QXJ018B4P0?3`l04a<C01iNGT0WYjN09BDU02PX:00_;bl0<G5
a@2QXJ40PX:209^KV`1<C4`0DE5A05aLG01[Jf/0NWYj09nOW`2VYZH0];Bd0;>c/`2k^k/0eMGE0=OG
e`2/[:`0BDU906ATI01RHV80Ph>308j>SP1cLg<0EEEE05eMG@2ZZZX0UIFE09nOW`2ZZZX0ATI60080
;bl_01`0=cLg06][J`2o_kl0[jn_09:BTP3@d=00h>3P0;Jf]P1SHf<0IFEU0:JVYP2RXZ80IVIV0492
@P0e=CD0>SXj04M7A`1cLg<0Jf][0:FUY@3>c/h0c<c<0=KFeP1kNg/0;bl_02PX:00];Bd0AdM70_oo
ool0000307alO02JVYX0C4a<0080@T9208L0MgMg04Q8B01:BTX0Jf][030`<01lO7`0V9RH07AdM00`
<300;Rh^05ADE00h>3P0Fe]K024Q8@0_;bl0GemO03<c<`1@D500FEUI014A4@1ADE40De=C02h^;P1=
CDd0GUiN02PX:00P8200?clo01TI6@1:BTX0I6AT020P800e=CD0EUIF02LW9`0o?cl0P82006ATI00O
7al0GUiN01lO7`12@T80B4Q804e=C@1;Bd/0=cLg09BDU01YJFT0=cLg03lo?`0n?Sh0@d=306EUI@0i
>CT0IVIV06EUI@1=CDd0=SHf03`l?01OGel0PH6103Hf=P0X:2P0IFEU05aLG00C4a<08B4Q06EUI@0n
?Sh0<c<c08:2PP1aLG408B4Q07]kN`1aLG40<c<c059BDP1DE5@0ADE5061PH01OGel08b<S09RHV01M
GEd0ADE509FEU@2NWYh0JFUY02/[:`23Ph<0=cLg03dm?@24Q8@0RXZ:04U9B@2ATI40CDe=03Hf=P0Q
8B40P82004m?C`0M7Ad0@T9207alO01eMGD08b<S05IFEP1ADE40WYjN0<g=c@2JVYX0ATI604Q8B01N
GUh0<C4a061PH01IFET0ADE505iNGP1PH600>3Ph06e]K@1eMGD0FEUI09NGU`1MGEd0G5aL04m?C`0^
;Rh0AdM7075aL@1ADE40KVi^06YZJP1<C4`00P1JFUX0``1LG5`0W9bL06EUI@1`L700LW9b04];B`2;
Rh/0JVYZ071`L01FEUH0?Shn04Q8B02j^[X0:RXZ02<S8`1ZJVX0LG5a04E5A@1lO7`07QhN06UYJ@29
RHT0JVYZ01`L701@D500KFe]05ADE016ATH0J6QX06ATI00g=cL0Kfm_0410@01UIFD0MWIf0861P@1O
Gel0OGem05=CD`0b<S80Lg=c08N7Q`2CTi<0F5QH0:f][@2QXJ40G5aL04e=C@1UIFD0/;2`061PH019
BDT0LG5a09bLW01BDU80RHV90:ZZZP22PX80Bd];07moO`2?Shl0@T9205EEE@1DE5@0:2PX05EEE@0g
=cL0G5aL08B4Q01:BTX0EEEE06][J`0V9RH0A4A407UiN@1YJFT0MGEe0;:b/P1>CTh0>SXj0:NWY`1k
Ng/0A4A407EeM@1<C4`08R8R03De=@2NWYh0Xj>S05ADE02HV9P0Zj^[096AT@0i>CT0M7Ad06=SH`24
Q8@0QXJ604Q8B01lO7`0P820079bLP2GUiL0O7al04I6AP1EEED0UYJF07IfMP16ATH0E5AD06i^KP1=
CDd0>SXj071`L024Q8@0QXJ604e=C@1cLg<0Ng]k03Lg=`16ATH0];Bd08Z:RP1:BTX0JVYZ08R8R01M
GEd0MGEe07MgM`1FEUH0Shn?0:JVYP1NGUh0=CDe06=SH`24Q8@0Kfm_02DU9@0k>c/0B4Q804E5A@0P
8200AdM7071`L01WIfL0;bl_06a/K027QhL0IVIV01/K6`1]KFd0EeMG04=3@`0m?Cd0ZZZZ08:2PP0h
>3P0JFUY03lo?`0P8200IFEU05eMG@0d=3@0T92@09JFUP13@d<0GUiN09jNWP1?Cdl0;bl_02TY:@10
@400IFEU01hN7P0E5AD0E5AD08>3P`1QHF40M7Ad05]KF`0n?Sh0?Cdm0410@00f=SH09BDU01TI6@0H
61P0>SXj04Q8B00g=cL0QhN70;bl_02KVi/0^KVi030`<00201TI6@0401DE5@0G5aL05ADE01@D5080
61PH01@0:BTY03Ph>018B4P0J6QX04A4A019BDT0EEEE051@D01HF5P0CTi>03/k>`0i>CT09bLW05=C
D`3Bd]80bl_;04a<C00T92@05aLG014A4@<05ADE00<0D51@01TI6@0>3Ph00P0=3@d0400@41003Ph>
00d=3@0E5AD0BTY:0<k>cP1nOWh0=CDe03<c<`15ADD0KFe]0<C4a026QXH0O7al05ADE00K6a/201DE
5@1O010@400U9BD0GemO02h^;P0U9BD0CDe=02@T900I6AT0:2PX03Hf=P1JFUX0IVIV04I6AP0^;Rh0
8R8R02TY:@0W9bL0:RXZ04A4A01VIVH0NWYj09^KV`3>c/h0M7Ad069RHP1JFUX0CDe=04a<C019BDT0
D51@07EeM@2BTY80RHV906IVIP1;Bd/0AdM705aLG01KFe/0OGem03Xj>P0/;2`07QhN01`L700k>c/0
E5AD055AD@1WIfL0O7al09VIV@2j^[X0c/k>0;fm_@2KVi/0Ti>C04i>CP0d=3@0@d=308F5Q@1UIFD0
;2`/02HV9P0U9BD0;Bd]01LG5`0F5QH0;Rh^065QH@1gMgL0M7Ad06][J`20P800CTi>03Ph>014A4@0
=3@d038b<P17AdL0KFe]07moO`2RXZ80QXJ609JFUP1mOGd0Q8B404E5A@0a<C409RHV07=cL`22PX80
TY:B06QXJ00g=cL0C4a<059BDP1<C4`00P0a<C40700_;bl07AdM01`L701<C4`0QhN7028R8P0/;2`0
L71`0;Fe]@33`l<0XJ6Q065QH@1@D500?clo04E5A@12@T80;bl_01TI6@0_;bl0JFUY0:NWY`2?Shl0
cLg=0;fm_@2/[:`0TI6A05QHF00G5aL701DE5@0?01HF5P0Q8B40G5aL05eMG@1NGUh0E5AD07IfMP1E
EED08R8R024Q8@0U9BD0:RXZ02HV9P0P82006ATI00805aLG01d06ATI04M7A`0m?Cd0<c<c03Ph>02c
/k<0[:b/07inOP2WYjL0V9RH09nOW`0o?cl0A4A404Q8B01=CDd0W9bL0;Rh^02l_;`0JFUY07QhN01I
FET092@T01LG5`0I6AT06a/K02<S8`14A4@0GemO04Y:BP0202XZ:P0Z02<S8`0T92@0:b/[03Ph>02E
UID0c<c<0;no_`2;Rh/0d];B09VIV@3@d=00Shn?09nOW`2CTi<0RHV9079bLP1KFe/0EUIF09FEU@2F
UYH0Fe]K092@T033`l<0ZJVY08f=S@1EEED0PX:20:6QX@2i^KT0a/K60;Jf]P2/[:`0d];B0<k>cP2T
Y:@0Xj>S08n?S`27QhL0S8b<09>CT`2;Rh/0GEeM0P1XJ6P05`30`<00OWin08j>SP2QXJ40YjNW0<S8
b02>SXh0EUIF04Y:BP10@400ATI604a<C01QHF40CTi>0;Zj^P3Jf]X0fm_K0=[JfP2f][H0I6AT04E5
A@1ADE40O7al00;ooooo0000o`1PH600Rh^;04a<C00k>c/0=cLg06][J`18B4P0ADE506][J`0N7Qh0
;Rh^04U9B@1ZJVX0?Cdm038b<P0`<3003`l?051@D011@D40>c/k04E5A@0D51@0MGEe08B4Q00l?3`0
HV9R02l_;`0D51@0=3@d05aLG00c<c<07alO0451@@0<30`09RHV05YJFP0X:2P0=3@d04Q8B00410@0
6a/K05EEE@1SHf<09RHV07MgM`0A4A40ADE504M7A`16ATH07alO01@D501iNGT0QHF504U9B@1>CTh0
?clo00l?3`19BDT0DE5A05]KF`1NGUh0F5QH01LG5`0E5AD0G5aL07inOP11@D408b<S065QH@17AdL0
8b<S03Ph>01XJ6P0<C4a03Lg=`20P800Bd];01XJ6P1`L700Jf][03Hf=P1FEUH0H61P02PX:01]KFd0
I6AT028R8P20P800=CDe030`<01LG5`0PX:205=CD`0R8R80UYJF05mOG`0_;bl0UIFE08Z:RP1JFUX0
RXZ:06UYJ@16ATH0;Bd]09RHV018B4P08R8R04m?C`22PX80M7Ad03De=@16ATH0@D510;Jf]P28R8P0
GemO03Xj>P1@D500FUYJ02TY:@1QHF40G5aL04i>CP1PH600GemO03dm?@29RHT0TI6A06=SH`2UYJD0
HF5Q055AD@1VIVH0BDU906QXJ028R8P0BDU905EEE@1dM7@0I6AT079bLP1YJFT0D51@09ZJVP1jNWX0
Ogmo06m_K`0c<c<0Ogmo05UIF@1aLG40DE5A03Ph>01;Bd/0`<30028R8P0V9RH0K6a/07]kN`14A4@0
T92@03`l?02:RXX0U9BD06EUI@0O7al0I6AT07alO01[Jf/0AdM706a/K01JFUX0>3Ph06UYJ@1]KFd0
];Bd07QhN01mOGd0FUYJ08>3P`1dM7@0Jf][0:6QX@2GUiL0IFEU05MGE`2/[:`0UiNG06][J`17AdL0
GemO09^KV`0k>c/0EEEE08f=S@2@T900AdM708:2PP2h^;P0HF5Q020P801=CDd0Ogmo04];B`1XJ6P0
EEEE02PX:01LG5`0B4Q806e]K@2CTi<0F5QH04m?C`1bLW80>SXj04Q8B01/K6`0;bl_05UIF@2_[jl0
IVIV03`l?02[Zj/0Cdm?059BDP1oOgl0J6QX0451@@1?Cdl0^KVi09FEU@0a<C40FEUI06m_K`1fMWH0
Cdm?0;Zj^P26QXH0YjNW05iNGP0T92@0JVYZ08R8R01dM7@0VIVI05IFEP0c<c<0LW9b0:BTY01cLg<0
A4A405QHF01UIFD05aLG01lO7`00B@0e=CD0MWIf0820P01=CDd0KFe]07MgM`1MGEd0A4A409BDU01X
J6P0?Shn061PH01bLW807QhN051@D01aLG40D51@08N7Q`2l_;`0T92@034a<@1@D500H61P06i^KP0[
:b/0EUIF06m_K`1RHV80:BTY04Q8B025QHD0IVIV03Lg=`2XZ:P0WinO07EeM@0P8200K6a/05MGE`0J
6QX07QhN061PH01SHf<0>CTi06e]K@1ZJVX0;bl_08Z:RP1SHf<0?clo0;Fe]@2PX:00NWYj08J6QP2m
_Kd0MgMg03De=@0[:b/0@T9207QhN01<C4`0;2`/04a<C02@T900Jf][04a<C01:BTX0>SXj02TY:@0M
7Ad071`L01XJ6P0G5aL00P0E5AD01@0M7Ad0JFUY09NGU`2TY:@0PX:20080NGUi0280@d=3034a<@0a
<C40D51@04i>CP0i>CT0?Cdm04e=C@1WIfL0IFEU05IFEP1UIFD0Cdm?02DU9@0Y:BT0ATI605eMG@1b
LW80FEUI03lo?`0f=SH0;bl_0<71`@3=cLd0ATI601TI6@0E5AD04A4A010@400C4a<06QXJ05QHF01=
CDd04a<C0P0>3Ph05@0?3`l04a<C00l?3`0G5aL0>SXj0;Vi^@2BTY80OWin07MgM`1oOgl0YjNW075a
L@1hN7P0QhN707EeM@0O7al04Q8B01DE5@0S8b<0IVIV02l_;`0200h>3P0o024Q8@10@4006a/K01`L
700G5aL04a<C02DU9@1GEeL0IfMW04=3@`0Y:BT0;bl_0451@@17AdL0alO70:ZZZP2PX:00`/;207If
MP1CDe<0F5QH059BDP0g=cL0:b/[02HV9P1NGUh0Q8B40:2PX027QhL0F5QH03lo?`0];Bd0;2`/06a/
K00H61P05aLG01dM7@0P82009bLW03Ph>01ZJVX0EEEE04=3@`14A4@0NWYj0<71`@32`/80/K6a06MW
I`1;Bd/0Cdm?05UIF@0n?Sh0@d=304M7A`0T92@08b<S02PX:00`<3006a/K01LG5`10@400J6QX0080
S8b<00H0Cdm?01`L700H61P0<c<c03/k>`0l?3`2038b<P0^06EUI@36a/H0NGUi07UiN@2CTi<0XJ6Q
06a/K01TI6@0?Shn08:2PP20P800Ph>308J6QP1EEED0CTi>06][J`0`<3007alO01dM7@0U9BD0<c<c
034a<@1OGel0MGEe024Q8@0j>SX0MGEe09jNWP2o_kl0a<C409>CT`2SXj<0QhN709BDU02?Shl0GEeM
061PH01dM7@0Kfm_0492@P11@D40F5QH0;2`/02QXJ40EUIF03<c<`<05ADE00<04a<C01@D500E5AD0
0`0E5AD0LP0L71`0DE5A03lo?`1=CDd0ATI606m_K`2RXZ80DE5A03`l?00c<c<0<S8b02d];@0T92@0
7alO01hN7P0I6AT05ADE01TI6@0c<c<0B4Q803Ti>@2[Zj/0LG5a065QH@2^[Zh0]kNg0;no_`1_Kfl0
K6a/05eMG@1oOgl0UiNG0;no_`2>SXh0C4a<04m?C`19BDT0Hf=S05YJFP0`<300:RXZ06EUI@1NGUh0
;Rh^01dM7@0V9RH0<30`01lO7`0N7Qh07AdM028R8P1eMGD0`L710:2PX01`L700emOG0=;BdP3GemL0
WIfM04Y:BP0_;bl0>3Ph04A4A01DE5@0FUYJ07moO`1MGEd092@T02XZ:P1SHf<0Fe]K0<W9b@2f][H0
Y:BT08j>SP1lO7`0OGem08:2PP2FUYH0/;2`0;fm_@2JVYX0QHF506e]K@1aLG40Ogmo0<S8b01IFET0
Cdm?05UIF@2ATI40HV9R0492@P0g=cL0FUYJ09RHV036a/H0_Kfm08R8R01NGUh0I6AT04];B`1=CDd0
I6AT09nOW`3IfMT0f][J0<G5a@2g]kL0a/K60<30`02LW9`0ZZZZ05]KF`;ooooo00002P1QHF40VYZJ
04e=C@1KFe/0@D51096AT@19BDT0CDe=0:6QX@1ADE42059BDP1Y08B4Q013@d<0=CDe05ADE00U9BD0
?3`l0451@@0j>SX0B4Q8010@4012@T80KVi^03Ti>@1PH600@D5101TI6@0Y:BT0C4a<03De=@0N7Qh0
>CTi02/[:`0b<S80I6AT03hn?P0[:b/0C4a<02XZ:P0R8R80Fe]K05mOG`0U9BD0N7Qh01TI6@16ATH0
;Bd]05EEE@1=CDd0>SXj07YjNP1gMgL0B4Q804i>CP1:BTX0A4A405EEE@1CDe<0@d=304];B`1HF5P0
C4a<024Q8@0`<300MGEe04=3@`0Z:RX0JVYZ04E5A@0Z:RX0=CDe04m?C`0^;Rh0=CDe07MgM`1]KFd0
=3@d05UIF@1OGel0>3Ph05QHF011@D40=CDe05IFEP1RHV8092@T08:2PP1JFUX0BDU908N7Q`26QXH0
=CDe024Q8@2FUYH0I6AT03@d=02HV9P0U9BD038b<P24Q8@0QHF504e=C@0/;2`0Shn?0451@@0Q8B40
ATI6075aL@1]KFd0=3@d05EEE@0f=SH0];Bd03dm?@1UIFD0Cdm?0080CTi>0=008B4Q07MgM`1MGEd0
BTY:069RHP0k>c/0?Shn08F5Q@2<S8`0Fe]K08j>SP1@D500NGUi07AdM01:BTX0J6QX08>3P`18B4P0
JVYZ08j>SP1UIFD0N7Qh05aLG01PH600X:2P06a/K01iNGT0DU9B034a<@2@T900Ogmo06IVIP1JFUX0
820P065QH@2m_Kd0Fe]K03Ti>@1WIfL0O7al065QH@2QXJ40@41008N7Q`2LW9`0C4a<03<c<`1`L700
MgMg069RHP18B4P0IVIV04];B`14A4@0IFEU07=cL`2EUID0PX:206e]K@1GEeL0YjNW07UiN@1PH600
Vi^K0861P@1jNWX0B4Q80;Fe]@2RXZ80Hf=S04M7A`1]KFd0];Bd04Q8B00j>SX0IVIV08J6QP0f=SH0
RHV90<_;b`1dM7@0?Cdm05mOG`2<S8`0CDe=05IFEP0a<C40@d=308V9R@17AdL0IVIV08b<S00d=3@0
ATI608f=S@12@T80A4A407YjNP0T92@0Cdm?0;Fe]@1FEUH0<C4a09JFUP1?Cdl0CDe=07inOP1KFe/0
B4Q804m?C`30`<00QhN7051@D01]KFd0IVIV07=cL`17AdL0]kNg09NGU`2PX:00KVi^03Xj>P1LG5`0
L71`06i^KP2CTi<0KFe]030`<019BDT0R8R806QXJ00o?cl0B4Q806EUI@1:BTX0;Rh^04M7A`1mOGd0
Ng]k04I6AP1aLG40M7Ad05aLG01QHF40XZ:R08Z:RP1GEeL0KVi^07emO@1?Cdl0GEeM06i^KP0m?Cd0
PX:20=OGe`2MWId0DU9B05EEE@1VIVH0@T9201lO7`1QHF40PX:205aLG00V9RH0CTi>06YZJP0b<S80
71`L07=cL`27QhL0Kfm_02LW9`1/K6`0Cdm?07AdM00d=3@0M7Ad06QXJ015ADD0WIfM08j>SP0h>3P0
Rh^;04Y:BP0Y:BT0PH610:NWY`1UIFD0Z:RX0<G5a@1YJFT0>CTi038b<P1;Bd/0Kfm_059BDP0[:b/0
DE5A09bLW01eMGD0B4Q8038b<P0Y:BT092@T01/K6`0I6AT05aLG0P0E5AD0@@0C4a<0410@038b<P2I
VIT0X:2P09NGU`29RHT0Lg=c03dm?@0`<300;bl_02`/;00V9RH07AdM01PH600I6AT0;Rh^02TY:@0N
7Qh06QXJ02/[:`0m?Cd0:b/[01/K6`0Y:BT0Fe]K06YZJP1aLG40L71`08b<S038b<P0g=cL0:JVYP1S
Hf<0>c/k02TY:@0X:2P0;Bd]0492@P1YJFT0Ogmo05eMG@18B4P0<c<c01lO7`0@410051@D02TY:@1W
IfL0Bd];01DE5@0S8b<0?3`l079bLP2XZ:P0LW9b061PH01;Bd/0CDe=05UIF@0V9RH0GEeM06m_K`0X
:2P03Ph>00<03@d=06H0?3`l04U9B@0E5AD051@D01<C4`0>3Ph03@d=01`L7014A4@0N7Qh0820P01h
N7P0/k>c0::RXP2:RXX0Zj^[05ADE01;Bd/0DU9B03hn?P19BDT0C4a<04M7A`2BTY80FEUI05EEE@1o
Ogl0PX:206e]K@0k>c/071`L02PX:029RHT07AdM01DE5@0D51@05ADE02/[:`0M7Ad09BDU05iNGP1[
Jf/0DE5A09FEU@31`L40aLG508>3P`1WIfL0K6a/05mOG`0U9BD04a<C010@400^;Rh0DU9B034a<@0L
71`0:BTY0410@00g=cL0:2PX07YjNP2?Shl0JFUY05=CD`0Z:RX05ADE01HF5P0I6AT092@T03dm?@13
@d<0Rh^;0;6a/@2XZ:P0?3`l0:2PX03Kfm/0emOG0:^[Z`24Q8@0Vi^K08f=S@25QHD0KVi^075aL@1n
OWh0Fe]K03Ph>00c<c<0;bl_02h^;P0f=SH0@41009FEU@28R8P0EEEE071`L01LG5`0Lg=c08j>SP2L
W9`204E5A@0?0451@@0h>3P0ATI60410@00o?cl0>3Ph03Ti>@17AdL0EUIF03De=@1kNg/0X:2P05=C
D`0^;Rh05ADE00<04a<C1@0E5AD03`0K6a/0Fe]K06ATI01EEED0<30`04Y:BP2JVYX0^k^k075aL@2?
Shl0PH61061PH01:BTX0<c<c02d];@0202HV9P1J01TI6@0L71`0Fe]K08B4Q02h^;P0OGem07alO03A
dM40k>c/0=GEe@1_Kfl0FUYJ04M7A`1MGEd0XZ:R07moO`1aLG40KVi^055AD@1?Cdl0Bd];05QHF02G
UiL0`/;208>3P`0P820071`L01lO7`0Y:BT0:b/[01hN7P0Q8B409BDU03Lg=`1KFe/0X:2P08F5Q@2E
UID0a/K606i^KP2h^;P0HF5Q03Xj>P18B4P0Bd];04m?C`1YJFT0O7al04=3@`0o?cl08R8R01/K6`0a
<C40IVIV096AT@1DE5@0FEUI04m?C`16ATH0DU9B05iNGP1lO7`0IfMW0861P@2=SHd0R8R804m?C`11
@D40HF5Q0:>SX`1cLg<0GEeM07AdM02EUID0G5aL051@D00j>SX0@41006m_K`2JVYX0O7al09NGU`2h
^;P0/[:b0:^[Z`2XZ:P0]kNg0;no_`2n_[h0_Kfm0P34a<@01@35aLD0e]KF0=SHf02>SXh09bLW00;o
oooo00008@1XJ6P0Kfm_04i>CP1DE5@0@D5106IVIP0U9BD0ADE507AdM01:BTX0FUYJ04i>CP1WIfL0
Bd];05EEE@1mOGd0?Cdm04=3@`1;Bd/0>CTi05YJFP0`<300Bd];0861P@0e=CD0De=C0410@00W9bL0
=CDe05EEE@0^;Rh0=CDe05IFEP0203Hf=P2`05YJFP0[:b/0>c/k055AD@0m?Cd092@T075aL@1XJ6P0
8b<S07alO00_;bl0B4Q802LW9`1DE5@0Hf=S0451@@1kNg/0KVi^04E5A@1^KVh0?Shn03<c<`1NGUh0
EEEE04=3@`1ZJVX0MgMg079bLP0[:b/0=cLg07moO`0N7Qh0<C4a071`L01TI6@0@T9204Y:BP1NGUh0
;2`/04e=C@2@T900LW9b04];B`1ADE40H61P03Ti>@1mOGd0De=C04I6AP1KFe/0@d=302h^;P1dM7@0
HF5Q03/k>`29RHT0WIfM0492@P0Y:BT0OGem051@D00Y:BT0U9BD0:RXZ00f=SH0KVi^06QXJ01EEED0
;bl_08N7Q`1PH6005aLG02DU9@1EEED0KVi^059BDP0k>c/0GemO08F5Q@0_;bl0F5QH0410@018B4P0
CTi>024Q8@1PH600B4Q803Ph>01SHf<0C4a<02TY:@1GEeL0JFUY0492@P1ZJVX071`L04e=C@1VIVH0
AdM706MWI`1OGel0>SXj06EUI@22PX80C4a<06][J`1@D500BTY:08^;R`1QHF40O7al06EUI@0m?Cd0
OGem05=CD`1RHV80GEeM04E5A@0o?cl0ZZZZ04i>CP0_;bl0HF5Q06a/K018B4P0S8b<03hn?P20P800
Shn?04Y:BP10@400Q8B406e]K@1OGel0BTY:06YZJP1>CTh09BDU04];B`1CDe<0KFe]09VIV@1@D500
DU9B09nOW`28R8P0MgMg09nOW`2BTY80LW9b05ADE02e]KD0VYZJ03dm?@11@D40PX:20;Vi^@1mOGd0
@D5106EUI@2ATI40@d=3061PH02OWil0Q8B405UIF@24Q8@0SXj>03`l?01^KVh0>SXj03De=@1JFUX0
@D5106MWI`2KVi/204A4A01d08N7Q`0`<300DE5A07alO01KFe/0IfMW0;^k^`1>CTh0=3@d0:6QX@1E
EED0@D5105iNGP1<C4`0EUIF08>3P`3EeMD0V9RH06MWI`2?Shl0E5AD06MWI`0/;2`0QhN7092@T02C
Ti<0P82003`l?01[Jf/0G5aL06IVIP2h^;P0QhN704i>CP1BDU80X:2P05QHF019BDT0HF5Q09BDU01c
Lg<0<S8b04Q8B02@T900>SXj034a<@29RHT0T92@05mOG`1MGEd0][Jf0451@@0];Bd0GUiN07YjNP1R
HV80CTi>08>3P`0W9bL0IfMW0;>c/`1jNWX0A4A407]kN`2a/K40NWYj02<S8`0^;Rh0EUIF069RHP0S
8b<0B4Q806MWI`1_Kfl0;bl_08:2PP1TI6@0EUIF06ATI02^[Zh0U9BD07MgM`0g=cL0MgMg04a<C00^
;Rh0[Jf]0820P00k>c/0V9RH06ATI00Y:BT0LG5a0:BTY01FEUH0]kNg0<O7a`1JFUX0=CDe05=CD`1a
LG40O7al04];B`0a<C40Cdm?09BDU029RHT0?Cdm03Hf=P0[:b/09bLW01dM7@0L71`05ADE01HF5P0E
5AD201<C4`0801/K6`2@T900Vi^K08:2PP1ADE40De=C04Q8B00C4a<2010@4005014A4@0>3Ph03Ph>
018B4P0E5AD0100H61P0;00X:2P0?3`l02l_;`0N7Qh0:BTY0492@P18B4P0Q8B40<K6aP3Jf]X0fm_K
0;:b/P27QhL0K6a/06e]K@1cLg<0H61P05IFEP1<C4`0;Bd]02HV9P0l?3`0ADE504e=C@1:BTX0EUIF
0820P02>SXh04a<C010@400>3Ph05QHF06MWI`27QhL0E5AD0:BTY02DU9@0K6a/0:NWY`2NWYh0^k^k
07=cL`0?3`l03Ph>0`0=3@d01`0];Bd0T92@02d];@0G5aL04a<C014A4@0@41000P0E5AD0H`0U9BD0
R8R80<30`031`L40Ogmo0:ZZZP20P800VIVI0:BTY030`<00RHV902TY:@0E5AD04a<C071`L00W9bL0
7QhN03`l?01WIfL0CTi>05=CD`0U9BD0A4A406EUI@1=CDd0CTi>034a<@0S8b<0<30`02TY:@0I6AT0
71`L09>CT`3:b/X0[Zj^0<K6aP3>c/h0Zj^[07moO`15ADD09RHV024Q8@0M7Ad061PH00h>3P0I6AT0
AdM704Y:BP0S8b<0>CTi04i>CP1NGUh0@D5104M7A`1XJ6P0FUYJ04m?C`0W9bL071`L01lO7`0L71`0
<C4a05MGE`37alL0Y:BT0:j^[P21PH40Shn?0;2`/01JFUX0F5QH079bLP2k^k/0Ogmo061PH01UIFD0
N7Qh0492@P1iNGT0GemO05]KF`1MGEd0IfMW07moO`2FUYH0dM7A0<W9b@24Q8@0Lg=c04U9B@1SHf<0
G5aL09jNWP16ATH0DE5A02l_;`0L71`05aLG01/K6`02024Q8@0:02<S8`0T92@0>c/k04i>CP2@T900
ZZZZ08B4Q01;Bd/08B4Q02TY:@805ADE01D04a<C01LG5`0I6AT08B4Q03/k>`1DE5@0LW9b06IVIP1@
D500B4Q8071`L02VYZH0D51@02<S8`0_;bl0?Shn065QH@22PX80QHF50861P@1`L7000P17AdL02@0l
?3`0QhN70:j^[P26QXH0Shn?0:JVYP3Hf=P0i>CT0>;RhP0207inOP0=06a/K01]KFd0=SHf02h^;P1G
EeL0Ogmo05MGE`1YJFT0HV9R08F5Q@2HV9P0U9BD07inOP0201/K6`807AdM01008b<S02h^;P16ATH0
Cdm?03Hf=P1TI6@0HV9R0451@@2SXj<0/k>c07alO02k^k/0MgMg08Z:RP1lO7`0BTY:0P0d=3@0;01@
D500;Bd]034a<@0e=CD0820P028R8P1aLG40Ogmo04];B`15ADD0ATI60410@019BDT0HV9R06e]K@1;
Bd/0K6a/05EEE@1_Kfl0OGem06a/K021PH40RHV908^;R`1>CTh0UiNG065QH@10@400DE5A06IVIP1]
KFd0QHF506m_K`1JFUX0?clo05=CD`2d];@0b/[:0<S8b02TY:@0QhN707emO@2CTi<0DE5A0P1fMWH0
102CTi<0`<3009FEU@1PH602ooooo`000<80HF5Q061PH015ADD0Cdm?0410@021PH40?clo03hn?P1j
NWX0B4Q805UIF@1=CDd0>CTi01HF5P0e=CD0GemO03Hf=P0i>CT0;2`/059BDP1[Jf/0>SXj04m?C`1a
LG40<C4a07UiN@1RHV80<S8b03@d=01<C4`03Ph>018B4P0m?Cd0?3`l034a<@11@D402PX:02@T901B
DU80>SXj02HV9P1]KFd0>SXj00h>3P1RHV80>3Ph02h^;P0D51@0Cdm?079bLP0h>3P0LW9b04];B`0N
7Qh0@d=304Y:BP0o?cl0FUYJ03@d=00R8R80=3@d05mOG`1ZJVX0;Bd]03De=@1lO7`0=cLg01/K6`1F
EUH0Cdm?04Q8B01DE5@0DE5A01@D5016ATH0Lg=c06EUI@1GEeL0?clo05UIF@0_;bl0CDe=04Y:BP0m
?Cd0Kfm_04=3@`0R8R80Lg=c04E5A@0i>CT0Y:BT0:n_[`1EEED07alO0:RXZ00f=SH0?clo0;6a/@2K
Vi/0G5aL065QH@1YJFT0:2PX01/K6`1iNGT0Shn?04E5A@0e=CD0F5QH06EUI@0U9BD0CTi>0:VYZ@1]
KFd0ADE5061PH00V9RH0B4Q806QXJ00_;bl0K6a/03/k>`10@400KFe]06][J`0f=SH0HF5Q07YjNP1A
DE40VIVI055AD@1KFe/0De=C0451@@20P800PH6103dm?@15ADD0K6a/02HV9P1UIFD0MWIf05eMG@2C
Ti<0?3`l09>CT`2<S8`0BTY:09nOW`0i>CT0Cdm?0861P@1RHV80Cdm?0<_;b`1@D500?Shn08f=S@2E
UID0Bd];08F5Q@10@400Q8B40;bl_01YJFT0;Bd]06][J`1RHV80?Shn069RHP2b/[80PX:203Lg=`1O
Gel0BTY:07]kN`2VYZH0Hf=S04i>CP2RXZ80LG5a04M7A`2>SXh0X:2P08n?S`1OGel0bLW90:ZZZP18
B4P0@41006=SH`2ZZZX0EEEE0861P@80X:2P07d0B4Q806m_K`2j^[X0IfMW03<c<`2@T900VIVI0410
@013@d<0?clo024Q8@1LG5`0A4A407emO@2DU9@0FEUI05ADE02ATI40820P04M7A`1]KFd0H61P07Yj
NP30`<00CDe=02<S8`25QHD0MGEe06YZJP2SXj<0Fe]K03Xj>P2OWil0e]KF0:n_[`1CDe<0TI6A05QH
F029RHT0A4A409FEU@1TI6@0TI6A06m_K`0n?Sh0JFUY05]KF`10@400G5aL0820P01?Cdl0Fe]K0:FU
Y@15ADD0=SHf03hn?P1hN7P0KVi^02l_;`19BDT0R8R806ATI00h>3P0GEeM07AdM01JFUX0D51@0:VY
Z@1dM7@0?clo069RHP1VIVH0Fe]K05iNGP24Q8@0EeMG08N7Q`2f][H0UIFE0492@P14A4@0Fe]K06UY
J@0W9bL0>CTi05MGE`0Z:RX0;Rh^05]KF`1]KFd0KVi^03<c<`2>SXh0GemO03Xj>P0Q8B40ATI6051@
D01QHF40>CTi08N7Q`1dM7@0GEeM0;Ng]`1CDe<0?Cdm0:ZZZP24Q8@0AdM707EeM@2h^;P0;bl_09>C
T`2j^[X0SXj>03Ph>00^;Rh0ATI6071`L00h>3P0ADE508N7Q`2TY:@0TI6A04I6AP020451@@0403@d
=00O7al07AdM01TI6@805ADE0P0C4a<03@0`<300RXZ:09VIV@2YZJT0J6QX05QHF01;Bd/0<30`00l?
3`0>3Ph0410@00h>3P0C4a<01`0E5AD08`0P8200@D51038b<P0L71`0>SXj05eMG@2l_;`0b<S80<o?
c`2NWYh0H61P04Q8B00g=cL0?clo04m?C`1HF5P0LG5a06m_K`1KFe/0EeMG03lo?`0d=3@0;Rh^05=C
D`1YJFT0^;Rh05]KF`0m?Cd0>SXj03Ph>01;Bd/0ADE508:2PP1RHV80>CTi0080<S8b0280TI6A0=KF
eP32`/80S8b<02LW9`0E5AD0410@00d=3@0:2PX03`l?05]KF`2YZJT0NWYj030`<00K6a/05ADE014A
4@0O7al0?clo07inOP2][Jd0clo?0=_Kf`2_[jl0>c/k02HV9P0J6QX0<30`04i>CP0>3Ph03@d=00h>
3P1CDe<0:b/[0P0M7Ad2061PH01?05ADE01NGUh0QHF501LG5`0D51@07alO03Xj>P1TI6@0NWYj075a
L@1/K6`0J6QX08B4Q010@400BTY:0:FUY@2h^;P0W9bL03@d=00_;bl0>CTi02XZ:P0P82007QhN01`L
700C4a<0410@02`/;022PX80VYZJ0;2`/00`<3006ATI03Hf=P1fMWH0YJFU08b<S02;Rh/0IFEU05UI
F@1CDe<0G5aL07]kN`34a<@0Z:RX0<_;b`3@d=00a/K60;no_`2a/K40VYZJ08f=S@2CTi<092@T024Q
8@0R8R80Kfm_09nOW`2k^k/0V9RH0:n_[`24Q8@0NGUi06IVIP1]KFd0T92@0<C4a02_[jl0P82006IV
IP1?Cdl0Fe]K0<_;b`1nOWh0@41001hN7P0O7al07AdM01/K6`0201`L700I01/K6`0N7Qh0:BTY04I6
AP2h^;P0SXj>0:2PX01UIFD0CDe=04E5A@0H61P06a/K030`<00g=cL0>SXj03De=@0V9RH0820P02DU
9@1bLW80U9BD09ZJVP2TY:@0]KFe02HV9P0201DE5@0T01LG5`0F5QH05aLG01TI6@0];Bd0CTi>08^;
R`2_[jl0X:2P0:RXZ03;bl/0a<C40<[:bP2UYJD0TI6A0=7Ad@3@d=00_;bl034a<@0S8b<07AdM01hN
7P0d=3@0EeMG05=CD`0l?3`0Fe]K092@T01KFe/0Bd];055AD@1UIFD0EUIF01dM7@0E5AD05aLG0P0I
6AT0@P0[:b/0>SXj03/k>`1^KVh0ATI606a/K02OWil0CTi>04A4A029RHT0ADE503Hf=P14A4@0820P
01dM7@0Q8B40>SXj02PX:00];Bd0=SHf02d];@0R8R80IfMW07emO@1UIFD0=cLg0492@P1EEED0FUYJ
06IVIP1CDe<0QHF509^KV`1gMgL0DE5A05]KF`28R8P0C4a<03dm?@22PX80VIVI06m_K`1>CTh0=cLg
0451@@1HF5P0RHV909VIV@1bLW80JVYZ04A4A016ATH0EEEE07]kN`31`L40K6a/06e]K@1nOWh0C4a<
0492@P15ADD0BTY:079bLP2WYjL0GUiN07inOP;ooooo00009`1UIFD0WIfM04a<C017AdL0@d=30820
P017AdL0A4A407MgM`0e=CD0JVYZ075aL@1jNWX0?3`l02/[:`1RHV80>3Ph0410@00O7al08b<S065Q
H@0f=SH0DE5A06=SH`0I6AT0EeMG04A4A00^;Rh0Bd];06YZJP14A4@05aLG03dm?@0];Bd0?3`l06m_
K`0o?cl0=CDe05IFEP0203Lg=`1o079bLP1EEED09bLW075aL@0[:b/0@T9203De=@1;Bd/0H61P034a
<@1kNg/0JFUY04A4A019BDT0;Rh^01hN7P20P800DU9B03hn?P19BDT0F5QH03Hf=P0Z:RX0E5AD09NG
U`1KFe/09BDU05EEE@0M7Ad0<c<c06a/K01kNg/0<S8b02d];@28R8P0CDe=03De=@19BDT0Ogmo04];
B`1UIFD0G5aL028R8P1RHV80IVIV02DU9@29RHT0820P01XJ6P1PH600Shn?05iNGP0];Bd0aLG504=3
@`0M7Ad0MgMg08Z:RP1KFe/0De=C06ATI00M7Ad051@D071`L016ATH0:b/[034a<@18B4P0KFe]01XJ
6P0S8b<0MWIf06UYJ@1;Bd/0KFe]02XZ:P0k>c/0NGUi04Y:BP2DU9@0>3Ph02h^;P1MGEd0NGUi0492
@P1eMGD0DE5A01lO7`2;Rh/0GUiN06QXJ00m?Cd071`L05IFEP2=SHd0A4A4051@D01[Jf/061PH03/k
>`1lO7`0G5aL0:FUY@0h>3P0E5AD05iNGP16ATH0VYZJ065QH@1>CTh0Fe]K03`l?01nOWh0clo?0492
@P0P8200Fe]K0820P019BDT0QHF502PX:00i>CT0UIFE05mOG`1=CDd0TY:B08^;R`0203Xj>P2U05QH
F01MGEd0BDU908R8R01?Cdl0B4Q807YjNP29RHT0DE5A09jNWP1aLG40AdM708J6QP1iNGT0K6a/0492
@P2_[jl0Ti>C04U9B@1:BTX0I6AT0:NWY`13@d<0?Cdm05aLG022PX80?clo08>3P`2n_[h0PH6104a<
C01RHV80VIVI04E5A@1FEUH0?clo04m?C`24Q8@0Bd];05EEE@23Ph<0?Cdm05UIF@2@T900@D5104M7
A`1nOWh09BDU0410@02@T900FEUI02TY:@1nOWh0?Shn03`l?01QHF40H61P03Xj>P0n?Sh0b<S809FE
U@1VIVH0^;Rh0:j^[P1aLG40@d=30:j^[P1oOgl0/;2`05]KF`15ADD0Y:BT075aL@1TI6@0NWYj08:2
PP1LG5`0UIFE0;>c/`2>SXh0CDe=05EEE@1gMgL0EEEE03lo?`1SHf<0U9BD08R8R016ATH0I6AT06YZ
JP0c<c<0JFUY0:n_[`24Q8@0@410061PH01MGEd0820P03Hf=P1FEUH0;2`/096AT@30`<00NGUi05mO
G`1BDU80KFe]07YjNP0Y:BT0?Shn06EUI@1IFET08b<S04Y:BP1bLW80<30`02@T902CTi<0Shn?05QH
F00Y:BT0O7al08^;R`0^;Rh0:BTY0:6QX@2;Rh/0EeMG0;jn_P0n?Sh08B4Q06MWI`0f=SH0;Rh^06EU
I@2h^;P0GUiN08V9R@3;bl/0HF5Q03Lg=`1YJFT0SXj>07AdM00O7al06a/K04];B`2CTi<0SXj>06=S
H`0m?Cd0>CTi03Lg=`0e=CD0:2PX028R8P0H61P05ADE01<C4`0N7Qh0@T9204E5A@2MWId0W9bL0080
Jf][00@0F5QH04A4A00[:b/04A4A0P0>3Ph00`0E5AD05QHF01DE5@0201DE5@0A01PH600E5AD05ADE
01HF5P0H61P0?Cdm03De=@24Q8@0dM7A0;Zj^P2?Shl0`L710:RXZ02EUID0Jf][05MGE`1<C4`00P1L
G5`0?`1UIFD0JVYZ05]KF`1ADE40EEEE06ATI01aLG40`L710=CDe02e]KD0>3Ph038b<P0P820071`L
04];B`0m?Cd0VIVI04];B`0c<c<071`L02h^;P2CTi<0[:b/08R8R02`/;00]KFe092@T01HF5P0<C4a
01PH600A4A407AdM0=3@d02n_[h0Rh^;071`L01FEUH0LW9b09RHV02XZ:P0alO70<C4a03Hf=P0g]kN
0<;2`P0c<c<04Q8B01<C4`0H61P0@41000l?3`0>3Ph0410@07QhN023Ph<0CTi>04m?C`1gMgL0Z:RX
0:JVYP39bLT0ZJVY03/k>`0201HF5P1601DE5@0Q8B40?3`l02d];@0f=SH0N7Qh06=SH`0k>c/0M7Ad
0;>c/`2ZZZX0Ph>301@D500B4Q806ATI03De=@0a<C40:2PX02XZ:P0g=cL0>3Ph04i>CP1fMWH0UYJF
0;Rh^00a<C407alO02TY:@1SHf<0alO70;Rh^02<S8`0>CTi02d];@0[:b/0820P03<c<`2HV9P0]KFe
0;no_`1lO7`0P8200;Rh^02@T900@T9203Ph>018B4P0DU9B02@T901QHF40[:b/0=;BdP2a/K40IFEU
04U9B@0j>SX0>c/k04I6AP15ADD0IVIV07moO`2j^[X0]kNg07inOP1MGEd0GUiN06YZJP0o?cl0L71`
04e=C@80820P00<07alO02<S8`0[:b/00P0O7al03@0_;bl0J6QX0<[:bP2[Zj/0_Kfm08Z:RP1nOWh0
DU9B03Ph>00V9RH06QXJ01/K6`0L71`00P0H61P02P0G5aL06QXJ02l_;`2PX:00[jn_0:f][@32`/80
:b/[01PH600A4A4201HF5P0301<C4`0A4A404a<C00805ADE01`0:b/[07YjNP3>c/h0d=3@0:NWY`29
RHT0;bl_02d];@1LG5`0LG5a0=[JfP1bLW80?clo02/[:`0O7al0<30`06m_K`1]KFd0SHf=075aL@16
ATH0CTi>03dm?@0n?Sh0>c/k04E5A@1OGel092@T0`0E5AD0=00I6AT0>3Ph07moO`2VYZH0QXJ60;Fe
]@1OGel0:2PX030`<01SHf<0FUYJ02DU9@12@T80;2`/01dM7@0O7al0:2PX03@d=00];Bd0<S8b0451
@@17AdL0GemO092@T01YJFT0>CTi055AD@1aLG40WinO0:^[Z`2/[:`0ZZZZ06a/K01SHf<0NWYj05MG
E`1cLg<0D51@04a<C02BTY80RHV9055AD@13@d<0>CTi03Ph>01=CDd0EUIF07IfMP1`L700EeMG03`l
?016ATH2069RHP0<0;fm_@2WYjL0R8R803<c<`0/;2`0;Bd]02/[:`0^;Rh0De=C09bLW011@D40G5aL
0_ooool0001=05YJFP27QhL0De=C0492@P0d=3@0DU9B0410@01?Cdl0F5QH01LG5`0g=cL0CTi>0820
P01<C4`0=3@d03`l?00G5aL0IfMW05EEE@0n?Sh0JFUY034a<@1lO7`0QHF504I6AP1bLW80=CDe01`L
700n?Sh0Kfm_061PH00O7al0>CTi02XZ:P0O7al0EeMG0451@@0j>SX0?Shn00h>3P0D51@0EEEE079b
LP0Y:BT0MGEe018B4P1;Bd/0FEUI04Y:BP0C4a<0410@07alO01mOGd0Bd];06][J`1:BTX03Ph>05QH
F01SHf<0@T9207EeM@1gMgL0>c/k01LG5`0Y:BT0JVYZ0451@@1BDU80Q8B402XZ:P0S8b<0?3`l05iN
GP0_;bl0@41008F5Q@0m?Cd00P0V9RH0GP1[Jf/0BTY:06][J`1DE5@0:BTY06][J`1^KVh0<30`09BD
U01?Cdl0:RXZ05eMG@2:RXX08R8R02<S8`2DU9@0FUYJ02@T902EUID0][Jf05mOG`1jNWX0Ti>C03De
=@0U9BD0RXZ:03hn?P0Y:BT0De=C06UYJ@27QhL0Bd];02LW9`1dM7@0FEUI03/k>`1hN7P0DU9B03De
=@19BDT092@T06e]K@1XJ6P0<S8b05mOG`0m?Cd0<c<c05YJFP1]KFd0CDe=08V9R@0m?Cd0PH6107Ee
M@1:BTX0I6AT07UiN@1@D500O7al08B4Q01HF5P0Fe]K05=CD`13@d<0UIFE06ATI01ZJVX0FEUI03Lg
=`2ATI40Cdm?05YJFP1IFET0;bl_04E5A@2PX:00BDU903@d=01/K6`0MgMg06a/K02JVYX0?clo04Q8
B02e]KD0BTY:02d];@1cLg<0RXZ:06a/K017AdL0G5aL05eMG@0`<30204];B`1M08:2PP1/K6`0KFe]
04Y:BP2][Jd0UIFE06EUI@2FUYH0R8R807MgM`1FEUH0]kNg0<30`01<C4`0AdM7061PH02XZ:P0Cdm?
04Y:BP1_Kfl0Q8B404I6AP29RHT0d=3@0:2PX01WIfL0LW9b09nOW`1KFe/0KFe]03dm?@0Z:RX0J6QX
04Y:BP1EEED0Ph>303Ph>01BDU80Rh^;04M7A`1<C4`0LG5a04Y:BP1_Kfl0_;bl05QHF00b<S80Rh^;
04M7A`1=CDd0HF5Q04a<C01:BTX0D51@0<W9b@1bLW80@410061PH01IFET0HF5Q03lo?`2a/K40S8b<
09:BTP18B4P0:2PX069RHP1KFe/0EeMG079bLP0o?cl0<C4a06IVIP2IVIT0Jf][04M7A`1CDe<0JVYZ
03<c<`0Q8B40DU9B07moO`2=SHd0I6AT06IVIP1aLG40@41005UIF@2XZ:P0Lg=c038b<P1JFUX0EeMG
0080?Cdm04`0FEUI02l_;`2=SHd0bLW909NGU`1QHF40FUYJ06=SH`1:BTX0:2PX05mOG`1oOgl0Fe]K
03@d=026QXH0XZ:R04=3@`0K6a/0D51@07moO`0a<C40>SXj09BDU02VYZH0Bd];01dM7@1SHf<0?3`l
02d];@1lO7`0MgMg03Hf=P2=SHd0JVYZ03lo?`1VIVH0Jf][04E5A@21PH40clo?06ATI00f=SH0:RXZ
03hn?P1WIfL0>CTi02`/;01IFET0UIFE07YjNP2:RXX0@d=303/k>`0b<S80;Bd]02TY:@0X:2P08b<S
01TI6@0N7Qh0?Cdm02h^;P0o?cl0=cLg04m?C`1MGEd0GemO069RHP1;Bd/0AdM701DE5@0=3@d03Ph>
01@D500E5AD04a<C0P0@41007P0D51@06ATI03/k>`10@400@d=304a<C01SHf<0bl_;0;Rh^01IFET0
?Cdm08>3P`3AdM40`l?3069RHP1<C4`0Fe]K04A4A00e=CD0<c<c03Ti>@14A4@0HF5Q08Z:RP2a/K40
b/[:0=OGe`3Hf=P0`<3002l_;`805ADE00d0:b/[05UIF@2BTY80e=CD0;bl_01PH600;Bd]04e=C@1l
O7`0=CDe024Q8@0X:2P0EUIF0080KFe]04L0Jf][069RHP1HF5P0K6a/0=;BdP2m_Kd0TY:B08F5Q@22
PX80Ph>307inOP1kNg/0LW9b07EeM@2RXZ80OWin0:^[Z`2MWId0?Cdm01DE5@0K6a/0?Shn01HF5P0a
<C40D51@07MgM`1oOgl0S8b<08V9R@2PX:00`/;20:2PX024Q8@0KFe]06=SH`1RHV80Cdm?03<c<`0S
8b<0?Shn03De=@0j>SX0Hf=S0;Vi^@1XJ6P0GUiN09:BTP2YZJT0/;2`03Ph>00b<S80@D5104U9B@1I
FET0FUYJ05iNGP1<C4`0=CDe028R8P0M7Ad0<c<c092@T020P800NGUi06QXJ02TY:@0RXZ:06a/K01k
Ng/06QXJ01PH600201DE5@0901`L701FEUH0^KVi0;6a/@2PX:00Z:RX0<;2`P1]KFd08b<S00805aLG
01X0CDe=08j>SP28R8P0QHF508V9R@2_[jl0JVYZ03De=@0_;bl0;2`/0492@P0f=SH0>SXj04Y:BP2=
SHd0_Kfm0;2`/021PH40U9BD059BDP0N7Qh04Q8B04A4A01_Kfl09bLW01HF5P8071`L01007QhN02PX
:016ATH0R8R80=?Cd`3:b/X0X:2P05YJFP1NGUh0ADE5020P800G5aL06ATI01dM7@0I6AT05aLG0`0J
6QX01`0K6a/0M7Ad0;>c/`2[Zj/0`<3002h^;P0O7al01P0E5AD0;`0F5QH05ADE01TI6@13@d<0YZJV
08f=S@1lO7`0ATI601`L700M7Ad0<C4a04U9B@38b<P0Lg=c07moO`2?Shl0R8R80861P@2OWil0JVYZ
05UIF@1;Bd/08R8R02<S8`13@d<0BDU902`/;00[:b/0;2`/05aLG00Y:BT05aLG02PX:01HF5P0LG5a
06][J`1nOWh0a/K60<o?c`10@400:2PX02TY:@1<C4`0EeMG02@T900^;Rh0?Cdm00807QhN02`07alO
04Y:BP0^;Rh0=cLg04I6AP26QXH0OWin0=3@d030`<00Ogmo09BDU02JVYX0Shn?0820P01nOWh0FEUI
04A4A00i>CT0AdM707EeM@2<S8`0K6a/0:BTY01aLG40HF5Q038b<P0X:2P0:b/[034a<@0i>CT0ATI6
05YJFP1/K6`0?clo03Lg=`1IFET0IfMW08V9R@1iNGT0UIFE06YZJP0`<300;Bd]02TY:@80:b/[00@0
?Cdm07inOP0a<C40IFEU0_ooool0001k05YJFP1HF5P0@T9204E5A@0h>3P0B4Q803Hf=P1MGEd0MWIf
03Hf=P0j>SX0@d=306IVIP1<C4`0IfMW059BDP0C4a<0?clo0492@P0o?cl0>SXj00P8201RHV80P820
0410@020P800@d=301PH600g=cL0IVIV05YJFP17AdL0EEEE03Xj>P0^;Rh0E5AD03Lg=`1QHF40FEUI
0492@P0V9RH0Cdm?05MGE`0O7al0MWIf02`/;01;Bd/0AdM7069RHP16ATH06QXJ06=SH`0h>3P0;Bd]
04U9B@14A4@0:BTY051@D00g=cL0:2PX04];B`1?Cdl0G5aL03Ph>00_;bl0LG5a024Q8@0O7al0EeMG
055AD@16ATH0EeMG05]KF`0c<c<0MWIf09fMW@1YJFT0FEUI034a<@1PH600?clo0:FUY@1gMgL0>SXj
07IfMP10@400:BTY09JFUP1VIVH0<30`061PH01bLW80HF5Q024Q8@2l_;`0H61P02LW9`28R8P0U9BD
04I6AP15ADD0Lg=c04e=C@0R8R80RXZ:03`l?00I6AT0;bl_0451@@1/K6`0HF5Q02`/;020P800@d=3
02XZ:P1[Jf/0?clo03hn?P1:BTX0<30`07alO01PH600;bl_0080E5AD03d0;Bd]05]KF`28R8P0HF5Q
08V9R@1ADE40F5QH05UIF@14A4@0GUiN07alO00n?Sh0ATI606i^KP1UIFD0EEEE04];B`1FEUH0Y:BT
06UYJ@1bLW80JFUY04];B`2FUYH0K6a/06=SH`1XJ6P0E5AD05mOG`37alL0BDU9034a<@1YJFT0Ph>3
04e=C@2?Shl0@410059BDP2WYjL0Jf][038b<P1gMgL0TY:B06i^KP17AdL0I6AT05eMG@0m?Cd0Kfm_
0451@@1PH600K6a/07IfMP1>CTh0PX:208R8R01VIVH0WIfM092@T027QhL0LG5a0080[Zj^01@0F5QH
05ADE01]KFd0^KVi06i^KP1KFe/0PH6107=cL`0];Bd0I6AT0:ZZZP2NWYh0DE5A07AdM02CTi<0;bl_
06e]K@1GEeL0=3@d07moO`80GEeM07d0RHV9055AD@1YJFT0YZJV05UIF@2;Rh/0R8R806e]K@2<S8`0
d=3@069RHP0T92@0MWIf07EeM@1DE5@0LG5a04Q8B00e=CD0HF5Q0<_;b`2<S8`0G5aL08B4Q01]KFd0
GemO0410@02j^[X0_;bl09^KV`1NGUh0?clo06MWI`19BDT0G5aL07MgM`1CDe<0CDe=06QXJ02QXJ40
IVIV0492@P1/K6`0N7Qh05YJFP0_;bl0N7Qh08j>SP0i>CT0@d=30:2PX02JVYX0E5AD06EUI@34a<@0
MWIf03Ph>01dM7@0QXJ605QHF014A4@0SXj>03/k>`1_Kfl0e=CD0:b/[01KFe/0KVi^08J6QP1HF5P0
6ATI034a<@1>CTh0820P024Q8@1FEUH0OWin07YjNP0_;bl0FUYJ08J6QP1?Cdl0820P061PH01[Jf/0
K6a/02d];@1lO7`0FUYJ02/[:`1<C4`0IfMW03@d=028R8P0Ng]k04U9B@29RHT0F5QH03@d=01jNWX0
[:b/04i>CP12@T80?Shn05QHF023Ph<0?Cdm02HV9P1TI6@0UIFE07EeM@2?Shl0DU9B03De=@0/;2`0
9bLW02@T900U9BD0:RXZ04U9B@1EEED0ATI603Ph>00J6QX04Q8B01dM7@020492@P0906=SH`1VIVH0
CTi>03lo?`0B4Q803Ph>00d=3@0>3Ph051@D00806ATI00h07QhN02TY:@0d=3@0<C4a02d];@1oOgl0
`/;20::RXP16ATH0:BTY03Ph>01XJ6P0^KVi092@T080TI6A02L0HF5Q03Ti>@0P820071`L01dM7@0U
9BD0Bd];059BDP1ADE40HF5Q06m_K`2/[:`0alO70;bl_023Ph<0N7Qh08F5Q@1mOGd0OWin08J6QP2j
^[X0W9bL09^KV`2XZ:P0P82003`l?00Y:BT07AdM01hN7P0d=3@0DE5A04=3@`0/;2`09BDU07=cL`2U
YJD0>3Ph02@T900b<S800P0i>CT0400j>SX0?Cdm04];B`2DU9@0XJ6Q06=SH`0h>3P0LG5a0;Ng]`29
RHT0G5aL06ATI01EEED0Fe]K03@d=00e=CD203Hf=P0A04M7A`1LG5`0IFEU08Z:RP1YJFT0IFEU02`/
;00T92@0;Bd]04M7A`1/K6`0LG5a06e]K@1DE5@0CTi>0:FUY@1kNg/00P1<C4`01P20P800g=cL0:f]
[@1_Kfl0ATI603Ti>@80@T9200l0?Cdm03De=@0^;Rh07QhN01/K6`0U9BD0K6a/05QHF01YJFT0^KVi
0;2`/02:RXX0PX:208V9R@0L71`00P0G5aL0A`0L71`0:BTY07=cL`2e]KD0Z:RX0:f][@3=cLd0MgMg
03Ph>01KFe/0A4A401lO7`0K6a/0NWYj04A4A01TI6@0?3`l09>CT`2][Jd0BTY:0451@@0f=SH0:2PX
02DU9@0Z:RX0=CDe0410@025QHD0YjNW0:JVYP39bLT0UiNG02/[:`0B4Q804a<C01TI6@1RHV80GEeM
020P800[:b/09RHV03/k>`1iNGT0Z:RX0:FUY@3EeMD0clo?09>CT`1dM7@0Jf][04e=C@10@400=3@d
02<S8`0J6QX06a/K01`L700H61P06ATI02l_;`1OGel0RHV908n?S`36a/H0ATI602TY:@0V9RH061PH
01DE5@0A4A404a<C00805ADE01X05aLG020P800[:b/0W9bL09JFUP2g]kL0GemO020P800L71`09bLW
05aLG01/K6`07alO024Q8@0Y:BT0EUIF08F5Q@1oOgl0;2`/06][J`1@D5008B4Q01/K6`0Q8B40ATI6
059BDP809RHV0240<c<c06e]K@1GEeL0HF5Q05QHF023Ph<0][Jf0;Zj^P2/[:`0cLg=05aLG00Q8B40
:b/[0410@01OGel0:2PX024Q8@0o?cl0=CDe01`L700P8200De=C05ADE012@T80K6a/0:2PX02c/k<0
clo?0<O7a`1^KVh0NWYj08f=S@1jNWX00P27QhL08`0h>3P0:2PX030`<00f=SH0?3`l0:n_[`2n_[h0
W9bL04e=C@1gMgL0FUYJ03De=@0a<C40<c<c03Xj>P0n?Sh0Cdm?07]kN`0d=3@0GEeM05ADE02=SHd0
Q8B405ADE00k>c/0EeMG03/k>`0m?Cd0@41003lo?`0g=cL0>CTi07IfMP11@D40L71`00;ooooo0000
C01RHV80UiNG04e=C@1FEUH0?3`l079bLP13@d<0ADE508>3P`12@T80CTi>051@D00i>CT0:2PX04=3
@`1UIFD0<30`03Lg=`0l?3`0LW9b07AdM00`<300EUIF04U9B@0_;bl0KVi^051@D00T92@0De=C03lo
?`0P82006QXJ03Lg=`0_;bl0;Rh^04i>CP0N7Qh0:b/[04Y:BP0e=CD0<S8b05iNGP0k>c/04Q8B05EE
E@0m?Cd0>CTi02HV9P1>CTh0De=C01/K6`1/K6`0CTi>03Lg=`1@D500=CDe028R8P1>CTh0A4A40410
@01nOWh0M7Ad07emO@12@T80<S8b07inOP15ADD09BDU06YZJP1MGEd0D51@05aLG01XJ6P0:BTY03Hf
=P1MGEd205MGE`0M0451@@18B4P09bLW05MGE`1VIVH0?Cdm07moO`1^KVh0<c<c09^KV`1ZJVX0<30`
061PH01eMGD0IVIV028R8P2n_[h0IfMW02TY:@2:RXX0LW9b05]KF`0o?cl0Rh^;03Hf=P0O7al0QXJ6
04i>CP19BDT00P0i>CT0@P24Q8@0GemO034a<@1lO7`0F5QH04=3@`1cLg<0;2`/03hn?P17AdL0<S8b
07alO01MGEd0=CDe05=CD`1EEED0=SHf06m_K`2LW9`0JVYZ08F5Q@1XJ6P0K6a/06IVIP15ADD0F5QH
08b<S01@D500Fe]K06m_K`1`L700FUYJ061PH01GEeL0YjNW06e]K@1bLW80Ng]k04e=C@25QHD0BTY:
05ADE02:RXX0I6AT05eMG@36a/H0@41003Xj>P2<S8`0R8R805aLG025QHD0AdM7071`L02d];@0MGEe
030`<01PH600QXJ602l_;`1MGEd0[Zj^08^;R`10@400Lg=c04];B`80GemO03/0VIVI05]KF`21PH40
QXJ605iNGP2OWil0Ph>308j>SP1dM7@0Vi^K0:j^[P1CDe<0G5aL08j>SP2h^;P0O7al08Z:RP2c/k<0
Z:RX05aLG01oOgl0aLG508>3P`1GEeL0S8b<0:f][@0k>c/0CTi>04a<C00c<c<0MGEe04];B`29RHT0
WIfM059BDP1dM7@0QXJ602XZ:P1OGel0VYZJ07emO@1oOgl0_;bl08>3P`0i>CT0PX:2069RHP1;Bd/0
Ogmo07UiN@1?Cdl0@4100:JVYP1mOGd0FUYJ09jNWP1QHF40GemO02TY:@0207emO@1N08b<S02?Shl0
ADE506][J`0k>c/0;Rh^06QXJ01kNg/0D51@0861P@2b/[80=cLg02`/;01?Cdl0Lg=c04e=C@0n?Sh0
QhN708f=S@1JFUX0=SHf04m?C`1aLG40?Cdm075aL@3@d=00GEeM01<C4`1;Bd/0IfMW05]KF`1MGEd0
Xj>S03Ti>@1[Jf/0[jn_05IFEP0b<S80L71`08R8R01hN7P09BDU03/k>`1MGEd0BTY:02LW9`27QhL0
Xj>S06a/K00m?Cd0G5aL08b<S01@D500:2PX07=cL`2BTY80Q8B403lo?`1nOWh0L71`03/k>`1?Cdl0
NWYj03<c<`2JVYX0NGUi04Q8B02GUiL0IfMW04U9B@25QHD0UiNG06m_K`18B4P0AdM706YZJP2;Rh/0
?Shn02`/;01VIVH0VIVI06ATI023Ph<0^KVi06][J`11@D40>SXj02h^;P0e=CD0Fe]K07UiN@1@D500
@D5101LG5`804A4A01003Ph>01HF5P12@T80<C4a07EeM@1YJFT0GemO038b<P0C4a<04A4A01@D500I
6AT05aLG01DE5@0N7Qh07alO0P0U9BD0^@1@D500Y:BT09>CT`1hN7P0JFUY03/k>`1[Jf/0IVIV06QX
J00E5AD05aLG02PX:01PH600O7al079bLP10@4008b<S024Q8@0_;bl0=CDe03<c<`0o?cl0>3Ph05EE
E@37alL0f=SH09ZJVP1MGEd0C4a<03Xj>P0n?Sh0BDU905]KF`2QXJ40Ph>30:FUY@29RHT0L71`06][
J`1IFET0EEEE04E5A@1>CTh0?clo03Lg=`0`<300W9bL04E5A@0k>c/0A4A40492@P18B4P0AdM704A4
A013@d<0AdM7079bLP2][Jd0GemO04m?C`0W9bL0DU9B0:>SX`3Kfm/0X:2P07]kN`0O7al061PH01lO
7`0_;bl051@D010@400W9bL0FUYJ0861P@1jNWX0OGem08>3P`1GEeL0EUIF05]KF`1SHf<0GEeM06=S
H`2JVYX0QXJ608b<S02`/;00UYJF0;>c/`33`l<0e]KF08>3P`21PH40CDe=03hn?P0l?3`0?clo05AD
E01ZJVX0EeMG02XZ:P0M7Ad0=3@d06i^KP1IFET0Lg=c08:2PP2e]KD0Ti>C0;Jf]P2a/K408b<S01dM
7@0T92@0F5QH06i^KP2EUID0Ti>C0:f][@2WYjL0UYJF05EEE@0M7Ad0:b/[04U9B@0[:b/07alO061P
H01KFe/0CTi>038b<P23Ph<0U9BD04Y:BP1@D500G5aL06EUI@1JFUX0IVIV05ADE00j>SX0HV9R0:ZZ
ZP3=cLd0_kno0<30`01gMgL0ADE5024Q8@0B4Q805aLG04=3@`2?Shl0>SXj02d];@1nOWh0W9bL07Ee
M@2HV9P0eMGE0<30`01KFe/0>SXj03@d=01GEeL0KVi^07QhN01fMWH0KFe]05EEE@0d=3@0820P01XJ
6P0k>c/0J6QX0410@02e]KD0e=CD0;^k^`1XJ6P0:b/[03hn?P0S8b<05ADE00807alO00d0;2`/03<c
<`1<C4`0U9BD0=oOg`3=cLd0E5AD02h^;P1;Bd/0:b/[024Q8@1ZJVX0:b/[008071`L02D092@T03Lg
=`1iNGT0Jf][04I6AP1CDe<0I6AT02PX:00S8b<06a/K02DU9@1eMGD0Rh^;0820P02=SHd0/[:b08n?
S`20P800X:2P07QhN01>CTh0@41005EEE@2f][H0MgMg03Lg=`0Y:BT0>3Ph07IfMP0V9RH071`L02LW
9`16ATH0:RXZ02h^;P1YJFT0T92@0080S8b<0240X:2P0;Jf]P2n_[h0e]KF09jNWP25QHD0WYjN0:b/
[02n_[h0a/K605QHF00U9BD09bLW02d];@0l?3`0ZJVY0:>SX`1]KFd0WIfM08Z:RP2=SHd0`<300:6Q
X@21PH40NGUi07inOP2PX:00/;2`05mOG`1ADE40K6a/09jNWP1IFET00P0/;2`02P23Ph<0GUiN04=3
@`11@D40ADE504I6AP1RHV80U9BD04i>CP1cLg<2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 639}, {319, 0}} -> {-0.504772, -0.00160002, 1.00314, \
1.00314}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute all test image probabilities", "Subsection"],

Cell[CellGroupData[{

Cell["Define filter (same as used during training)", "Subsubsection"],

Cell[BoxData[
    \(\(db4 = DaubechiesFilter[4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute probabilities for all test images and all histogram \
models\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(time1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(probs = \(AnalyzeOneImage[#, testOffset, db4, centroids, hist, 
              bandMap] &\)\  /@ \ testData;\)\), "\[IndentingNewLine]", 
    \(AbsoluteTime[] - time1\)}], "Input"],

Cell[BoxData[
    \(354.790295`9.001516725045763\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize individual histogram classifications of test images\
\>", \
"Subsection"],

Cell["\<\
The graphics below illustrate the classification of each test image \
by band (HL1, LH1, HH1, HL2, LH2, HH2) down the columns.\
\>", "Text"],

Cell[BoxData[
    \(\(results = 
        Map[VisualizeResults[#, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ 
          probs, \ {2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresults = Map[Last, results, {2}];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Transpose[gresults]], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.51364 
%%ImageSize: 640 968.727 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.036039 0.238095 [
[ 0 0 0 0 ]
[ 1 1.51364 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.51364 L
0 1.51364 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.036039 0.261905 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .4908 L
.2381 .4908 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .4908 L
.2381 .4908 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01919 L
.71429 .01919 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01919 L
.71429 .01919 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11993 L
.95238 .11993 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11993 L
.95238 .11993 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF80000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF80000000FFFF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF00000000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF00000000FF0000FFFF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF8000FF8000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FF
FF8000FF80000000FFFF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000FF0000FF0000FF8000
FF80000000FFFF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FF
FF8000FF8000FF0000FF80000000FF
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF00000000FFFF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.036039 0.5 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .0123 L
.2381 .0123 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .32477 L
.47619 .32477 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .32477 L
.47619 .32477 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .28931 L
.71429 .28931 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .28931 L
.71429 .28931 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01543 L
.95238 .01543 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01543 L
.95238 .01543 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
00FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00FF000000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF
0000FF00FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FFFF800000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FFFF80000000FF
0000FF00FF000000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
00FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000FF8000FF0000
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FFFF80000000FF
FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FFFF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF
00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
00FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF00FF000000FF0000FF
00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FFFF8000FF0000
0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
00FF000000FF00FF000000FF00FF00
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00FF000000FF00FF00
00FF000000FF00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.036039 0.738095 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01981 L
.2381 .01981 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01981 L
.2381 .01981 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .11159 L
.47619 .11159 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .11159 L
.47619 .11159 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .48058 L
.71429 .48058 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .48058 L
.71429 .48058 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02982 L
.95238 .02982 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02982 L
.95238 .02982 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF00000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF00000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF0000
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF8000FF8000FF0000
FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF80000000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF8000
FF800000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF00FF00
0000FF0000FF0000FF0000FFFF00000000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF80000000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF00
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF8000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF0000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF00000000FF0000FFFF0000
00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF00000000FFFF80000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FFFF0000
FF00000000FF00FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF00000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FFFF80000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF00FF00
0000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF00000000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FFFF00000000FFFF800000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
FF800000FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FFFF00000000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF00FF000000FF00FF00
0000FFFF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.036039 0.97619 0.276299 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .14329 L
.2381 .14329 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .14329 L
.2381 .14329 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01209 L
.47619 .01209 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01209 L
.47619 .01209 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .06862 L
.71429 .06862 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .06862 L
.71429 .06862 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .41779 L
.95238 .41779 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .41779 L
.95238 .41779 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF80000000FF0000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000
FF8000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF00000000FF0000FF0000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF00000000FFFF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF0000FF8000FF80000000FFFF8000FF8000FF00000000FFFF8000FF8000FF0000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FFFF8000FF0000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF80000000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF0000
FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF80000000FFFF80000000FF
FF80000000FF0000FFFF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF0000FF8000
FF80000000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
0000FFFF0000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF80000000FFFF80000000FF
FF80000000FF0000FF0000FFFF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF8000
FF80000000FF0000FFFF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF8000
FF80000000FFFF80000000FF0000FF0000FFFF8000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF0000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FF0000FFFF8000FF0000
FF0000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF80000000FF
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000
0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FFFF8000FF0000FF0000
FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF00000000FFFF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF80000000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000
FF0000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF0000FF0000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
0000FFFF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF00000000FF0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF80000000FFFF00000000FF00FF000000FF0000FF
FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000
FF0000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF00000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF80000000FF
0000FFFF8000FF0000FF0000FF8000FF0000FF0000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF00000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF00000000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF80000000FF0000FFFF8000
FF8000FF0000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FFFF80000000FF
FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000
FF80000000FF0000FFFF0000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF00000000FF
FF8000FF0000FF0000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000
FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF00000000FF
FF8000FF8000FF8000FF00000000FF0000FFFF00000000FFFF8000FF8000FF8000FF0000
FF0000FF80000000FFFF8000FF8000FF0000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF80000000FF0000FFFF8000FF8000FF0000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF80000000FFFF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF0000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF0000FF0000
FF0000FF80000000FF0000FF0000FFFF0000FF0000FF0000FF8000FF8000FF8000FF0000
FF8000FF80000000FFFF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF00000000FFFF80000000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF0000
0000FFFF80000000FF0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF00000000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF00000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000
0000FF0000FFFF80000000FFFF00000000FFFF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF00000000FFFF8000FF8000FF0000FF00000000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.276299 0.261905 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .46285 L
.2381 .46285 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .46285 L
.2381 .46285 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .06779 L
.47619 .06779 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .06779 L
.47619 .06779 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .05652 L
.71429 .05652 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .05652 L
.71429 .05652 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05465 L
.95238 .05465 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05465 L
.95238 .05465 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000
00FF0000FF00FF00000000FFFF0000FF00000000FF0000FFFF80000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF80000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF8000FF0000FF80000000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF000000FF00FF00000000FFFF0000FF00000000FFFF0000FF80000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF8000FF0000FF800000FF00
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF8000FF0000FF8000
FF0000FF000000FF00FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000FF0000
FF0000FF0000FF80000000FF00FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF80000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF8000FF00000000FFFF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FF0000FFFF0000FF8000FF0000FF000000FF00
00FF0000FF0000FF00FF00000000FFFF8000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF000000FF0000FF0000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF000000FF00FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000FF8000FF00000000FFFF0000
FF00000000FFFF00000000FFFF00000000FF0000FFFF0000FF8000FF0000FF000000FF00
00FF00FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF8000FF0000FF000000FF00FF00000000FF
FF0000FF000000FF0000FF0000FF00FF0000FF0000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000FF00000000FF
0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FFFF80000000FF0000FFFF0000FF8000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF8000
00FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF00000000FF
0000FFFF0000FF8000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF8000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF00000000FFFF8000FF00000000FF
0000FFFF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF8000
FF0000FF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF8000FF0000
0000FF0000FFFF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000
FF000000FF0000FF00FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF8000FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF000000FF00FF0000
FF000000FF000000FFFF00000000FF0000FFFF0000FF8000FF0000FF00000000FF00FF00
FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF00FF00FF0000FF000000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF00FF0000
FF000000FF00FF0000FF0000FF0000FF8000FF0000FF80000000FFFF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF00FF0000
FF00000000FF00FF00FF0000FF00000000FFFF0000FF80000000FF00FF00FF0000FF0000
FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FF
0000FFFF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF000000FF00FF00000000FF
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF000000FF000000FF0000FFFF0000FF8000FF0000FF000000FF0000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF00FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF000000FF0000FF00FF0000FF00000000FFFF0000FF0000
FF0000FF000000FF00FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF00000000FFFF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF00FF00FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00
FF0000FF00000000FFFF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF000000FF00FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF8000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00
FF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF00000000FF
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF800000FF00
FF000000FF00FF0000FF0000FF8000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF800000FF00FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF000000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF00000000FFFF000000FF00
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF80000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF0000FF0000FF0000
FF8000FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000
FF000000FF00FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000
0000FF00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF0000
FF0000FF00000000FF00FF00FF0000
00FF00FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF0000FF0000
00FF00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF00000000FFFF0000FF0000FF8000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF8000
FF0000FF0000FF8000FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
00FF00FF00000000FF00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF00000000FFFF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.276299 0.5 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .15372 L
.2381 .15372 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .15372 L
.2381 .15372 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .40611 L
.47619 .40611 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .40611 L
.47619 .40611 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .05319 L
.71429 .05319 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .05319 L
.71429 .05319 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02878 L
.95238 .02878 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02878 L
.95238 .02878 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00
00FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000
0000FF0000FFFF8000FF80000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF8000FF80000000FF
FF8000FF800000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF80000000FF
FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000
FF0000FF8000FF8000FF80000000FF
00FF00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00
FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
FF000000FF00FF000000FF0000FF0000FF0000FF000000FF0000FF0000FFFF8000FF0000
0000FFFF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF800000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF8000FF0000
0000FF0000FFFF80000000FF0000FF
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF0000FF0000FF00FF0000FF000000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00
FF8000FF800000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00
FF000000FF0000FF0000FF00FF000000FF0000FF000000FFFF0000FF80000000FFFF0000
0000FF0000FFFF00000000FF0000FF
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF0000FF800000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF00FF0000FF0000FF8000FF80000000FFFF0000FF000000FF00FF8000
FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FFFF0000
0000FF0000FFFF8000FF80000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF8000FF00000000FFFF0000FF000000FF00FF0000
FF0000FF0000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF00000000FFFF0000
0000FF0000FFFF80000000FFFF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF000000FF0000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF80000000FFFF8000FF8000FF0000
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF8000FF800000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FF0000FF0000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF8000
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FFFF8000FF800000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000
00FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF00
FF000000FF0000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF000000FF00
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF00FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000
FF0000FF800000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF800000FF0000FF00FF0000FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000
0000FF00FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000
0000FFFF000000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
00FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00000000FF
0000FFFF000000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF8000FF000000FF0000FF00FF8000FF00000000FF
FF8000FF000000FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF00FF0000FF8000FF0000FF8000
FF8000FF8000FF000000FF0000FF00FF00000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF800000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF00FF0000FF8000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF800000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF800000FF0000FF00
00FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF000000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00
0000FF00FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000
0000FF00FF0000FF0000FF0000FF00
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF8000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000
FF000000FF0000FF00FF0000FF8000FF0000FF0000FF800000FF0000FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
FF0000FF0000FF0000FF0000FF8000
00FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000
FF000000FF000000FFFF00000000FFFF0000FF0000FF800000FF0000FF00FF000000FF00
00FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00
FF000000FF0000FF00FF0000FF8000
00FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF00FF0000FF8000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00
00FF00FF000000FF00FF0000FF8000
FF0000FF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF8000
FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF80000000FFFF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF8000
FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF000000FFFF00000000FF0000FFFF80000000FF00FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF8000
FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF00FF00000000FF00FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
00FF0000FF00FF0000FF0000FF8000FF8000FF0000FF000000FF00FF000000FF0000FF00
FF0000FF0000FF8000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.276299 0.738095 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .25864 L
.2381 .25864 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .25864 L
.2381 .25864 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .10658 L
.47619 .10658 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .10658 L
.47619 .10658 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .15498 L
.71429 .15498 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .15498 L
.71429 .15498 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .1216 L
.95238 .1216 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .1216 L
.95238 .1216 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF00000000FF0000FFFF8000FF8000FF0000
FF000000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF8000
FF8000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF00000000FFFF00000000FFFF80000000FF0000FF0000FFFF000000FF00FF0000
FF00000000FF0000FF0000FF0000FFFF0000FF80000000FFFF80000000FF0000FFFF0000
FF8000FF0000FF00000000FF0000FF
00FF0000FF0000FF00FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000
0000FFFF0000FF0000FF0000FF000000FF00FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF00000000FFFF8000FF8000FF8000FF0000FF0000FF80000000FF0000FF0000FFFF0000
FF80000000FF0000FFFF80000000FF
00FF0000FF00FF0000FF0000FF0000FF0000FF00000000FFFF000000FF0000FF0000FF00
FF0000FF0000FF000000FF00FF0000FF000000FF000000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF000000FF00FF0000FF000000FF00FF000000FF00FF0000FF0000
0000FFFF8000FF0000FF000000FF00FF00000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF00000000FFFF80000000FF0000FFFF8000FF8000FF00000000FFFF00000000FF
0000FF0000FFFF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
0000FF0000FF0000FFFF80000000FF
FF8000FF800000FF0000FF0000FF0000FF00FF0000FF80000000FFFF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF000000FF00FF0000FF000000FF00FF0000FF00000000FFFF0000
0000FFFF8000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF00000000FF0000FF0000FFFF8000FF8000FF8000FF00000000FFFF00000000FF
0000FF0000FF0000FF00FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF0000FF80000000FFFF0000FF80000000FF
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FF0000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF8000FF00000000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF0000FF8000FF8000FF0000FF8000FF80000000FFFF00000000FF0000FF0000FF
0000FFFF8000FF0000FF000000FF0000FF00FF0000FF8000FF8000FF0000FF80000000FF
FF0000FF8000FF8000FF8000FF8000
FF80000000FF00FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF8000FF00000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF
0000FFFF00000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
0000FF0000FFFF0000FF000000FF000000FF0000FF0000FF0000FFFF8000FF80000000FF
FF0000FF00000000FF0000FFFF8000
FF80000000FF00FF0000FF0000FF000000FFFF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF80000000FF
0000FFFF80000000FFFF8000FF80000000FF0000FFFF8000FF80000000FFFF000000FF00
FF00000000FF0000FFFF00000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF0000FF00000000FF0000FF0000FF
FF8000FF800000FF0000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF80000000FF
0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FFFF0000FF80000000FFFF0000FF0000FF8000FF80000000FF0000FF0000FF
00FF00FF00000000FF0000FF0000FF
FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF00000000FFFF0000FF8000FF8000FF8000FF8000FF0000
FF80000000FFFF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000
0000FFFF80000000FF0000FFFF8000FF00000000FFFF80000000FF0000FFFF8000FF8000
FF800000FF00FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF000000FF00
00FF00FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF80000000FF
FF0000FF00000000FFFF80000000FF
00FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00
00FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF80000000FFFF800000FF00FF0000FF0000FF0000FF000000FF0000FF000000FF0000FF
0000FFFF8000FF80000000FFFF0000FF0000FF00000000FF0000FF0000FFFF8000FF8000
FF000000FF0000FF00FF0000FF0000FF80000000FFFF8000FF8000FF0000FF0000FF0000
00FF00FF0000FF00000000FFFF000000FF00FF0000FF80000000FF0000FFFF8000FF8000
FF000000FF00FF8000FF0000FF8000
00FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF80000000FF0000FFFF80000000FF
FF8000FF80000000FF00FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF8000FF0000FF0000FF000000FF0000FF000000FF0000FF0000FF0000FFFF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF000000FF0000FF00FF0000FF00000000FFFF00000000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF8000FF0000FF0000FF000000FF00FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF000000FF0000FF00FF00000000FFFF80000000FFFF8000FF0000
FF80000000FFFF0000FF0000FF8000FF00000000FFFF0000FF80000000FFFF0000FF0000
00FF00FF0000FF0000FF0000FF8000
0000FFFF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000
FF0000FF8000FF0000FF000000FF00FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF8000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF80000000FF0000FFFF0000FF8000FF80000000FFFF8000FF80000000FFFF8000FF0000
00FF00FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
FF00000000FFFF000000FF00FF0000FF0000FF0000FF0000FF80000000FF0000FFFF0000
0000FFFF0000FF8000FF0000FF000000FF0000FF0000FF00FF0000FF00000000FFFF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF0000
FF0000FF00000000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000FF8000FF0000
FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF8000FF0000FF0000FF0000
FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF00000000FFFF8000FF0000FF8000FF800000FF00FF8000
FF0000FF0000FF8000FF0000FF0000FF80000000FFFF0000FF8000FF00000000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF000000FF0000FF00FF000000FF00FF0000
FF00000000FF00FF00FF0000FF00000000FFFF00000000FFFF8000FF8000FF8000FF8000
0000FF00FF00FF00000000FFFF00000000FF0000FFFF8000FF8000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
00FF00FF000000FF0000FF00FF0000FF0000FF8000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF80000000FFFF0000FF8000FF8000FF0000FF8000FF00000000FFFF8000
0000FF0000FF0000FF0000FFFF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF8000FF0000FF80000000FFFF8000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF80000000FF
FF0000FF000000FF0000FF0000FF00FF0000FF8000FF8000FF8000FF800000FF0000FF00
0000FF0000FFFF80000000FF0000FFFF0000FF8000FF0000FF80000000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF800000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF00000000FFFF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF8000
FF8000FF8000FF8000FF80000000FF
00FF00FF000000FF0000FF0000FF0000FF00FF8000FF0000FF8000FF800000FF00FF0000
FF0000FF0000FF8000FF00000000FFFF00000000FFFF0000FF0000FF00000000FF0000FF
0000FF0000FFFF8000FF8000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00
FF0000FF8000FF0000FF80000000FF00FF00FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF00000000FF0000FF
0000FF0000FFFF8000FF000000FF00FF0000FF000000FF00FF000000FF000000FFFF0000
FF8000FF80000000FF0000FF0000FF
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FF
0000FFFF8000FF8000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00
FF00000000FF0000FFFF800000FF00FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF00000000FF0000FF
0000FFFF8000FF80000000FFFF0000FF0000FF8000FF000000FF0000FF00FF0000FF8000
FF8000FF80000000FF0000FF0000FF
FF00000000FFFF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
0000FFFF8000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FFFF8000FF8000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF80000000FFFF8000FF8000FF00000000FFFF0000FF0000FF00000000FF0000FF
0000FFFF80000000FFFF0000FF0000FF80000000FFFF800000FF0000FF00FF8000FF8000
FF8000FF80000000FF0000FF0000FF
00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF800000FF0000FF00FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF800000FF0000FF00FF0000FF0000FF000000FF0000FF000000FF
0000FFFF8000FF8000FF0000FF000000FF00FF00000000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF80000000FF0000FF
FF0000FF8000FF8000FF00000000FF0000FFFF8000FF8000FF0000FF0000FF00000000FF
FF00000000FF0000FF0000FFFF8000
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000
FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00000000FFFF8000
FF8000FF8000FF00000000FF00FF0000FF00FF0000FF0000FF000000FF0000FF000000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF8000FF8000FF0000FF80000000FFFF8000FF80000000FFFF0000FF00000000FF
FF8000FF8000FF8000FF8000FF8000
FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF000000FF
0000FF0000FFFF00000000FF00FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF00FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF80000000FFFF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF000000FF00FF0000FF00000000FFFF8000FF00000000FF
FF8000FF8000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF000000FF000000FF
0000FF0000FFFF00000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF8000FF0000FF0000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF0000FF0000FF000000FF00FF0000
FF0000FF0000FF8000FF0000FF000000FF0000FF00FF0000FF0000FF8000FF0000FF8000
FF8000FF80000000FF0000FF0000FF
00FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF
0000FF0000FFFF00000000FF00FF0000FF0000FF00FF000000FF00FF000000FF000000FF
0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00000000FF0000FFFF8000FF8000
FF80000000FFFF80000000FF0000FF
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF00FF0000FF0000FF0000FF000000FF0000FF0000FF000000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF00FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF8000FF0000FF0000FF0000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF0000FF8000FF8000FF000000FF0000FF00FF00000000FF
FF00000000FFFF0000FF000000FF00FF000000FF0000FF00FF00000000FF0000FFFF8000
0000FF0000FFFF8000FF80000000FF
0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF0000FF0000FFFF8000
0000FFFF8000FF80000000FF00FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF000000FF000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF0000FF0000FF80000000FFFF000000FF0000FF00FF00000000FF
FF00000000FF0000FFFF000000FF0000FF0000FF00FF0000FF80000000FF0000FFFF8000
0000FFFF0000FF8000FF80000000FF
0000FFFF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000
00FF0000FF0000FF000000FFFF0000FF000000FF00FF0000FF00000000FFFF8000FF8000
FF8000FF8000FF80000000FFFF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF80000000FF00FF0000FF00FF0000FF000000FF000000FF0000FF0000FFFF8000
FF0000FF8000FF8000FF0000FF00000000FFFF0000FF000000FF00FF0000FF00000000FF
FF0000FF8000FF8000FF8000FF000000FF00FF0000FF0000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF00000000FF
FF8000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FF0000FF0000FFFF000000FF0000FF00FF0000FF0000
FF00000000FFFF80000000FFFF000000FF0000FF0000FF00FF0000FF000000FF00FF0000
0000FFFF00000000FF00FF00FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF
FF0000FF8000FF8000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000
00FF00FF000000FF000000FF0000FF0000FF0000FFFF000000FF000000FF00FF000000FF
FF00000000FFFF80000000FFFF000000FF00FF0000FF0000FF0000FF000000FF00FF0000
0000FFFF00000000FF00FF00FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF00000000FFFF8000FF80000000FF
0000FFFF8000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FF0000FF0000FFFF000000FF00FF8000FF00000000FF
FF0000FF8000FF80000000FF00FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000
FF0000FF80000000FFFF0000FF0000FF0000FF80000000FFFF8000FF8000FF8000FF0000
FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FFFF8000FF000000FF00FF0000FF00000000FFFF8000FF00000000FF
FF0000FF8000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF00000000FF
FF8000FF8000FF80000000FFFF0000FF000000FF00FF000000FF0000FF0000FF00FF0000
FF0000FF0000FF0000FF8000FF00000000FFFF80000000FFFF8000FF80000000FF0000FF
FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF8000FF00000000FF
0000FF0000FFFF80000000FFFF000000FF00FF0000FF00000000FFFF000000FF000000FF
0000FFFF8000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF800000FF00FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF00000000FF0000FFFF0000FF8000FF0000FF00000000FF0000FFFF0000
FF80000000FFFF00000000FF00FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF80000000FFFF8000FF80000000FFFF00000000FFFF8000FF0000
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF000000FF00FF00000000FF0000FF00FF00FF00000000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF
FF8000FF0000FF00000000FF00FF0000FF00FF000000FF00FF0000FF000000FF00FF0000
FF000000FF00FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF80000000FF
0000FFFF8000FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00000000FF
0000FF0000FFFF8000FF8000FF8000FF0000FF00000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF00000000FF0000FFFF80000000FFFF8000FF0000
FF80000000FFFF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF8000FF0000FF00000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FF0000FFFF8000FF8000FF0000FF0000FF0000FF0000FF000000FF0000FF000000FF
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF0000FF0000FF800000FF00FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FF0000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000
FF8000FF80000000FF00FF0000FF00FF00000000FFFF0000FF0000FF0000FF000000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF80000000FFFF8000FF00000000FF0000FF
FF80000000FFFF000000FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF
0000FF0000FFFF80000000FFFF000000FF00FF0000FF0000FF000000FF0000FF0000FF00
FF0000FF0000FF80000000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.276299 0.97619 0.516558 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .12911 L
.2381 .12911 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .12911 L
.2381 .12911 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .04255 L
.47619 .04255 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .04255 L
.47619 .04255 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0949 L
.71429 .0949 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0949 L
.71429 .0949 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .37524 L
.95238 .37524 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .37524 L
.95238 .37524 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF000000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF00000000FFFF0000
FF8000FF0000FF0000FF8000FF8000FF80000000FFFF0000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF0000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF00000000FF0000FF00FF00FF00000000FF0000FFFF8000
0000FFFF8000FF00000000FFFF0000FF0000FF0000FF8000FF8000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF00000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF00000000FF0000FF00FF00FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
0000FFFF00000000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF0000FF00000000FF0000FF00FF00FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF00000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF00000000FF00FF00FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000
FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF0000FF0000FF8000FF8000FF8000FF00000000FF0000FFFF80000000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF00000000FFFF8000FF8000FF80000000FFFF0000FF000000FF00FF0000FF0000
FF0000FF80000000FFFF8000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000
FF80000000FFFF8000FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF00000000FFFF8000FF00000000FF0000FF0000FFFF8000FF8000
00FF00FF0000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF000000FF00FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF0000FF8000FF00000000FF0000FF0000FF0000FF
0000FFFF8000FF0000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF0000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000
FF80000000FF0000FFFF8000FF8000FF00000000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
00FF00FF0000FF0000FF8000FF0000FF800000FF00FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF00FF00FF8000FF8000FF00000000FFFF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000
00FF00FF0000FF0000FF8000FF0000FF8000FF8000FF800000FF00FF0000FF8000FF8000
0000FF0000FFFF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF0000FF800000FF00FF8000FF8000FF0000FF0000FF00000000FFFF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF80000000FFFF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF0000FF80000000FFFF0000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000
FF8000FF800000FF00FF0000FF0000FF00000000FFFF0000FF80000000FFFF8000FF0000
00FF00FF8000FF8000FF8000FF80000000FF00FF00FF0000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF00000000FFFF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF00000000FFFF8000FF8000
FF8000FF800000FF00FF0000FF0000FF8000FF80000000FFFF8000FF00000000FFFF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF00000000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF00000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000
0000FFFF8000FF0000FF0000FF80000000FFFF8000FF8000FF0000FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
0000FFFF80000000FFFF80000000FFFF80000000FF0000FFFF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF80000000FFFF80000000FFFF8000FF0000
FF8000FF80000000FF0000FFFF8000
FF0000FF8000FF8000FF0000FF000000FF00FF0000FF0000FF8000FF8000FF8000FF8000
0000FFFF800000FF0000FF00FF0000FF0000FF8000FF8000FF000000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
0000FF0000FFFF80000000FFFF8000
FF0000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000
0000FFFF000000FF0000FF00FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000
FF800000FF00FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF80000000FFFF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF00000000FFFF8000FF800000FF00
FF8000FF8000FF80000000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF0000FF80000000FF0000FF0000FF00FF00FF8000FF00000000FF
FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF800000FF00FF0000FF0000FF000000FF0000FF00
FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF00000000FF
FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FF00FF00FF8000FF0000FF8000
FF0000FF00000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF80000000FF0000FFFF80000000FFFF8000FF0000FF00000000FF
0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF00000000FF00FF00FF8000FF000000FF0000FF0000FF00
FF0000FF8000FF0000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF800000FF000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF8000
FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
0000FFFF80000000FFFF00000000FFFF80000000FFFF80000000FFFF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF00000000FFFF0000
00FF000000FFFF8000FF8000FF8000
0000FF00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FF0000FF
FF00000000FF0000FFFF0000FF8000FF80000000FFFF8000FF0000FF8000FF0000FF8000
0000FFFF0000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF8000
0000FFFF80000000FFFF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF00FF00
00FF00FF8000FF8000FF8000FF8000
0000FFFF800000FF00FF0000FF8000FF8000FF8000FF800000FF00FF80000000FFFF8000
FF8000FF80000000FFFF0000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF80000000FFFF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF00000000FF00FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF80000000FFFF0000FF0000FF800000FF000000FF00FF00
00FF000000FFFF8000FF8000FF8000
FF0000FF000000FF00FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF00000000FFFF80000000FF0000FFFF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF8000FF00000000FFFF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FF00FF0000FF00FF8000FF0000FF0000FF0000FF80000000FF0000FFFF0000
FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF00FF00FF000000FF0000FF00FF0000FF0000FF8000FF8000
FF8000FF80000000FFFF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF0000FF0000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF00000000FFFF8000FF0000FF000000FF00FF0000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF800000FF00FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF0000FF8000FF8000FF0000FF000000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF000000FF00FF0000FF0000FF80000000FFFF80000000FFFF0000FF8000FF8000
FF8000FF8000FF800000FF00FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00FF0000FF00000000FFFF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF00000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF00000000FFFF00000000FFFF80000000FFFF8000
0000FFFF0000FF800000FF00FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF800000FF0000FF00FF80000000FFFF8000FF8000FF8000FF0000
FF80000000FFFF8000FF8000FF00000000FFFF8000FF00000000FFFF8000FF80000000FF
FF0000FF00000000FF0000FF0000FF
FF0000FF0000FF8000FF0000FF8000FF00000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF000000FF0000FF00FF0000FF0000FF800000FF00FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF00000000FFFF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF0000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
FF800000FF000000FFFF80000000FF
00FF00FF0000FF8000FF8000FF8000FF00000000FFFF0000FF80000000FF0000FF0000FF
FF8000FF800000FF0000FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF800000FF0000FF00FF0000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF00000000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FFFF800000FF00FF0000FF0000FF80000000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF00FF00FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF000000FF00FF8000FF8000FF8000FF8000FF8000
0000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000
0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF00FF00FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF00000000FFFF8000
0000FFFF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000
FF800000FF0000FF00FF00000000FF0000FFFF80000000FFFF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF00FF00FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF00FF0000FF00FF8000FF8000FF80000000FF0000FF00FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF0000FF0000FF0000FF800000FF0000FF00FF00000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF000000FF00FF0000FF0000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF800000FF00FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF000000FF0000FF00FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF0000FF00FF0000FF800000FF00FF00000000FF0000FFFF0000FF8000
FF8000FF80000000FFFF8000FF8000
FF000000FF00FF000000FF00FF800000FF000000FFFF80000000FFFF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF80000000FFFF0000FF8000
FF8000FF80000000FFFF0000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.516558 0.261905 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .48058 L
.2381 .48058 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .48058 L
.2381 .48058 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .0269 L
.47619 .0269 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .0269 L
.47619 .0269 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .10137 L
.71429 .10137 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .10137 L
.71429 .10137 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03295 L
.95238 .03295 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03295 L
.95238 .03295 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FF0000FFFF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF00000000FFFF00000000FF0000FF
FF0000FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF00000000FF0000FF
0000FFFF00000000FFFF0000FF8000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
0000FFFF000000FF00FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF00000000FFFF00000000FFFF00000000FF0000FFFF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF000000FF00
FF00000000FF0000FFFF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF00FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF000000FFFF0000FF0000FF0000FF0000FF00000000FF00FF00FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF8000FF8000FF0000
00FF0000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FF00FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF8000FF8000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF00000000FFFF0000FF000000FF000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF0000FF00FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF0000FF00000000FFFF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF8000FF0000FF0000
00FF000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF00000000FF0000FF
FF00000000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
00FF000000FFFF00000000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF8000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FFFF0000FF0000FF8000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00000000FF
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF000000FF0000FF000000FF0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF8000FF0000FF00000000FF
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF000000FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF8000FF0000FF0000FF00000000FF
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF00000000FFFF00000000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF00000000FFFF0000FF0000FF000000FF000000FFFF0000FF00000000FF
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF8000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000
00FF00FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
0000FFFF0000FF00000000FF0000FFFF0000FF000000FF00FF0000FF0000FF0000FF0000
0000FFFF0000FF8000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000FF0000
FF00000000FFFF00000000FF00FF00FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF00000000FF0000FF
0000FF0000FF00FF00FF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF
0000FFFF00000000FF0000FFFF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF0000FF0000FF
FF0000FF000000FF000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF
0000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000
0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF0000FF000000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
00FF000000FF00FF00FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000
FF0000FF00000000FFFF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
0000FFFF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FFFF0000
00FF0000FF00FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF000000FF00FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FF0000FFFF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF0000FF000000FF00FF0000FF0000FF000000FF000000FF0000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF000000FF00FF0000
FF0000FF000000FF0000FF00FF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF00000000FF
FF0000FF00000000FFFF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF0000FF
0000FFFF00000000FFFF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000
FF0000FF0000FF000000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.516558 0.5 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .09991 L
.2381 .09991 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .09991 L
.2381 .09991 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .36377 L
.47619 .36377 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .36377 L
.47619 .36377 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .16394 L
.71429 .16394 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .16394 L
.71429 .16394 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01418 L
.95238 .01418 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01418 L
.95238 .01418 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF00000000FF0000FFFF00000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF00000000FFFF000000FF00
0000FF0000FF00FF000000FF0000FF0000FFFF0000FF8000FF0000FF0000FF00000000FF
0000FF0000FFFF00000000FF0000FF0000FFFF00000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FFFF00000000FF0000FF0000FFFF000000FF000000FF00FF0000FF00
0000FF00FF0000FF000000FFFF00000000FF0000FFFF0000FF0000FF00000000FF0000FF
0000FFFF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000FF0000FF0000FF000000FF00
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FFFF00000000FFFF00000000FF
FF00000000FFFF0000FF0000FF000000FF00FF00000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FFFF0000FF00000000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FFFF00000000FF0000FFFF0000FF0000FF00000000FF
FF0000FF000000FF00FF000000FF00
FF000000FF000000FF0000FFFF00000000FF00FF000000FF00FF0000FF0000FF00FF0000
0000FF0000FFFF000000FF0000FF0000FF000000FFFF0000FF000000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF000000FF0000FF00
FF00000000FFFF0000FF0000FF000000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF
00FF0000FF000000FF00FF000000FF0000FFFF00000000FF0000FFFF0000FF00000000FF
0000FF0000FF00FF0000FF00FF0000
FF0000FF00000000FFFF0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FFFF0000FF0000FF000000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FFFF000000FF00FF000000FF0000FF00
FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FFFF0000FF00000000FFFF0000FF00000000FF00FF00
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF0000FF00
FF00000000FFFF0000FF0000FF00000000FFFF000000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FFFF000000FF000000FF00FF0000FF000000FF0000FFFF0000FF000000FF0000FF00
00FF0000FF0000FF00FF00000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FFFF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
FF00000000FF0000FFFF00000000FF0000FFFF00000000FF00FF0000FF00FF00000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FFFF000000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF000000FFFF00000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FFFF000000FF0000FF000000FF0000FF0000FFFF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF000000FF0000FF0000FF000000FF00FF00FF00000000FFFF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF00FF00000000FF
0000FF0000FFFF000000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FFFF0000FF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
00FF0000FF000000FF0000FF00FF0000FF000000FF0000FFFF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF00000000FF
00FF00FF000000FF000000FF0000FFFF00000000FF0000FF0000FF00FF000000FF0000FF
0000FFFF0000FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FFFF0000FF000000FF0000FF00
00FF000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF000000FF00
00FF0000FF000000FF0000FF0000FFFF000000FF000000FF0000FFFF00000000FF0000FF
0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF00000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF00FF00000000FF00FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF8000FF8000FF8000FF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF00FF000000FF0000FFFF00000000FFFF0000FF00000000FF
FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF00000000FFFF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF0000FF000000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF
0000FFFF00000000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF00000000FF
FF0000FF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF000000FF0000FF0000FF000000FF0000FF0000FF00FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF0000FF0000
0000FF00FF0000FF0000FF000000FF0000FFFF00000000FFFF00000000FFFF0000FF0000
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF00FF0000FF0000FF0000
FF0000FF00000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF0000FF000000FF0000FF000000FF00FF000000FF0000FFFF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF000000FF000000FF00FF00
FF00000000FF00FF0000FF0000FF0000FF00FF00000000FFFF0000FF00000000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF00FF000000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF00000000FF
FF0000FF0000FF00000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FFFF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
0000FF0000FF00FF000000FF0000FF0000FFFF00000000FF0000FFFF0000FF000000FF00
00FF00FF000000FF0000FF0000FF00FF00000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FFFF00000000FF
0000FFFF0000FF00000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF00FF00FF00000000FF0000FFFF0000FF000000FF0000FF00
00FF00FF00000000FF0000FFFF0000FF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF0000FF00000000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FFFF00000000FF
0000FFFF000000FF0000FF0000FF000000FFFF00000000FFFF0000FF000000FF0000FF00
00FF000000FFFF00000000FFFF00000000FF00FF0000FF0000FF00FF00000000FF0000FF
FF000000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF0000FF00000000FF0000FF
FF0000FF00000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FFFF0000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FFFF00000000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF
0000FFFF00000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF00
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF0000FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
0000FFFF000000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FFFF0000FF0000FF000000FF00
00FF00FF000000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000
FF00000000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
FF00000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00FF00000000FFFF0000FF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FFFF0000FF000000FF0000FF00
0000FFFF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FFFF000000FF0000FF000000FF0000FF0000FFFF0000FF000000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF000000FF0000FF0000FF000000FF
0000FFFF000000FF0000FF000000FF0000FF0000FFFF0000FF000000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF
00FF00FF000000FF000000FFFF0000FF000000FF00FF000000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FFFF00000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FFFF000000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF00000000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FF
FF00000000FF00FF00FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF000000FF000000FFFF00000000FF0000FFFF0000
00FF00FF00000000FF0000FFFF00000000FF0000FFFF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FFFF00000000FF
FF00000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF000000FF0000FF0000FF000000FF
00FF0000FF00FF00000000FF0000FFFF0000FF0000FF00000000FF0000FFFF000000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF00
FF00000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF000000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000
0000FFFF0000FF0000FF8000FF8000FF0000FF0000FF000000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000FF000000FF00
00FF000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF000000FF0000FF
00FF00FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF8000FF8000FF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF00000000FF0000FFFF00000000FF0000FF0000FF00FF00FF000000FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
0000FF0000FFFF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FFFF00000000FF00FF0000FF000000FF0000FF00FF000000FF
FF00000000FFFF0000FF8000FF80000000FFFF0000FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF00FF00000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF00000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000
00FF000000FFFF00000000FFFF0000FF8000FF0000FF0000FF000000FF0000FF0000FF00
0000FF0000FFFF000000FF0000FF00FF00000000FF0000FFFF000000FF0000FF000000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF000000FF0000FF0000FF00
0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF0000
FF00000000FFFF0000FF0000FF00000000FFFF00000000FF0000FFFF00000000FF00FF00
00FF000000FFFF00000000FF0000FF0000FF0000FF0000FFFF000000FF0000FF000000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF
00FF0000FF000000FF0000FF0000FFFF00000000FFFF0000FF0000FF0000FF000000FF00
00FF00FF00000000FF0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.516558 0.738095 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .11534 L
.2381 .11534 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .11534 L
.2381 .11534 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .31809 L
.47619 .31809 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .31809 L
.47619 .31809 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .19607 L
.71429 .19607 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .19607 L
.71429 .19607 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .0123 L
.95238 .0123 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00FF00000000FF
00FF00FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF00000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FFFF00000000FFFF0000FF00000000FF0000FF
0000FFFF00000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FFFF000000FF0000FF00
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FFFF000000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF0000FF0000
0000FFFF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF00FF00
FF00000000FFFF0000FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF00000000FF00FF000000FF0000FF0000FFFF0000
0000FFFF00000000FF00FF00FF00000000FFFF0000FF0000FF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF00000000FFFF00000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF
0000FF00FF0000FF0000FF0000FF00
FF00000000FFFF0000FF00000000FF00FF0000FF0000FF0000FF000000FF0000FFFF0000
FF00000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FFFF000000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF00FF00000000FF0000FFFF000000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF00FF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FF00FF0000FF0000FF0000FF00
FF00000000FFFF0000FF00000000FF0000FF00FF0000FF00FF00000000FF0000FFFF0000
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000FF00000000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF00000000FFFF0000FF0000FF00000000FF
00FF0000FF000000FF0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF00FF00
FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000
0000FF0000FF0000FF00FF00FF000000FF0000FF00FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF00FF00FF000000FF00
00FF000000FF00FF00FF000000FF000000FF0000FF0000FF0000FFFF0000FF000000FF00
00FF000000FF0000FF0000FFFF0000FF000000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
00FF0000FF00FF000000FF0000FF00
0000FFFF0000FF000000FF0000FF00FF000000FF000000FF0000FF0000FFFF0000FF0000
FF000000FF0000FF0000FF000000FF00FF000000FFFF00000000FF0000FFFF00000000FF
00FF00FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FFFF00000000FF0000FFFF0000FF0000
00FF000000FFFF00000000FF00FF0000FF0000FF000000FFFF000000FF000000FF0000FF
0000FF0000FFFF0000FF00000000FFFF00000000FF0000FFFF00000000FF00FF0000FF00
00FF00FF00000000FF00FF00FF0000
0000FFFF000000FF0000FF0000FF000000FF0000FF00FF00FF00000000FF00FF00FF0000
0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF00FF0000
0000FF0000FFFF0000FF00000000FF00FF000000FF00FF000000FFFF000000FF00FF0000
FF00000000FF0000FFFF0000FF000000FF00FF00000000FFFF0000FF00000000FFFF0000
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF00000000FF
0000FFFF00000000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FFFF000000FF0000FF0000FF000000FF00FF0000FF0000FF00FF0000
0000FF0000FFFF000000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
FF00000000FF00FF0000FF0000FF0000FF00FF00000000FFFF00000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FFFF0000FF00000000FF0000FF0000FF0000FFFF00000000FFFF0000FF000000FF00
0000FFFF00000000FF0000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FF00FF0000FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF00000000FFFF00000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00FF00000000FFFF0000FF0000FF0000FF00000000FF
00FF0000FF000000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF00000000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF00FF000000FF0000FF0000FF0000FF0000FF000000FF00FF000000FFFF0000
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF00FF0000
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF00FF00000000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF00FF00000000FFFF000000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF0000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FFFF0000FF00000000FF0000FFFF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FFFF000000FF00FF0000
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FFFF00000000FFFF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FFFF0000FF000000FF00
FF000000FF0000FF0000FF0000FF000000FF00FF000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF000000FF0000FF
0000FFFF00000000FF0000FF0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF00
FF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000FF0000
0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF0000FF0000FF00000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF00000000FFFF0000FF0000
FF000000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
0000FF0000FFFF00000000FF00FF00
0000FF0000FF0000FF0000FFFF00000000FFFF000000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
00FF00FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000FF0000FF000000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FFFF000000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000FF00000000FF
FF00000000FFFF0000FF0000FF0000
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FFFF00000000FF0000FFFF000000FF0000FF0000FF000000FFFF00000000FF
FF0000FF000000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF
0000FFFF000000FF00FF000000FF0000FF00FF00000000FFFF0000FF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF
0000FFFF00000000FFFF0000FF0000
0000FFFF00000000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
0000FFFF0000FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF00FF0000
0000FF0000FFFF0000FF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF000000FF00FF000000FF0000FF000000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
FF00000000FFFF00000000FFFF0000FF00000000FFFF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
00FF00FF00000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FFFF0000
0000FFFF0000FF00000000FF0000FFFF000000FF000000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FFFF0000FF0000FF00000000FF
00FF0000FF00FF000000FF0000FF0000FF000000FF0000FFFF00000000FFFF00000000FF
FF00000000FF0000FF0000FF0000FFFF00000000FFFF000000FF000000FF00FF0000FF00
FF00000000FFFF0000FF0000FF0000
00FF00FF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FFFF00000000FFFF0000FF000000FF0000FF0000FF00FF00000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF00000000FF00FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FFFF000000FF00
00FF000000FF0000FFFF0000FF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
FF00000000FFFF00000000FFFF0000FF000000FF00FF00000000FFFF00000000FFFF0000
FF8000FF0000FF8000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF00000000FF0000FF00FF000000FF0000FF0000FF0000FFFF000000FF000000FF
0000FF00FF0000FF00FF00000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FFFF00000000FFFF00000000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FFFF00000000FF0000FF00FF0000FF0000FF000000FFFF0000FF00000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FFFF00000000FF0000FF00FF000000FFFF00000000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00FF00000000FF00FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FFFF000000FF00
00FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF0000
FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000
0000FF0000FF00FF000000FF00FF0000FF00FF00000000FFFF0000FF000000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FFFF00000000FFFF0000FF000000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF000000FF00FF0000FF00000000FF00FF0000FF0000FF000000FF00FF000000FFFF0000
FF00000000FFFF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF00000000FFFF0000
0000FF0000FFFF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF00FF00
00FF0000FF0000FF000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF00000000FFFF0000FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FFFF0000FF000000FF00
00FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF
0000FFFF000000FF0000FF0000FF0000FF00FF00000000FF0000FFFF000000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF00FF000000FF00
0000FF00FF0000FF0000FF0000FF00
0000FFFF000000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FFFF000000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF000000FF0000FF0000FF0000FF000000FF00FF000000FFFF00000000FFFF0000
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00FF000000FF00
00FF000000FF0000FFFF00000000FF
0000FFFF000000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF00FF000000FF0000FF
0000FFFF000000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF00FF0000FF000000FF00FF00FF00000000FF0000FF00FF0000FF00
00FF000000FF00FF00FF000000FF00
0000FF0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF00FF000000FF0000FFFF0000FF000000FF0000FF0000FF00FF00000000FF
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF00FF00000000FF00FF00FF000000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF00
FF0000FF0000FF00000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF000000FF0000FF0000FF00FF00000000FF00FF00FF000000FF0000FF0000FF000000FF
FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF00FF00000000FF00FF00FF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF00FF00FF00000000FF00FF00FF00000000FF0000FF
0000FF0000FFFF000000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FFFF0000FF000000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00FF00000000FF0000FF
FF00000000FF0000FFFF000000FF00FF00000000FF0000FFFF000000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF
FF00000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FFFF0000
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
FF00000000FF0000FFFF000000FF000000FF0000FF0000FFFF000000FF0000FF000000FF
0000FFFF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF00000000FF
FF000000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF
00FF000000FFFF00000000FFFF0000FF000000FF000000FFFF0000FF00000000FFFF0000
FF00000000FF0000FF0000FFFF0000
0000FF0000FFFF000000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF00
0000FF0000FF00FF00FF000000FF000000FF0000FF00FF00FF000000FF0000FF00FF0000
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FFFF0000
FF000000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FFFF0000FF0000
00FF000000FF0000FFFF00000000FF
00FF0000FF00FF00000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF00000000FF0000FFFF000000FF0000FF0000FF0000FF0000FF00
FF00000000FF00FF00FF000000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FFFF00000000FF0000FFFF0000
00FF000000FF0000FFFF00000000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000
0000FF00FF000000FF00FF0000FF000000FFFF00000000FF0000FFFF0000FF0000FF0000
0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FFFF000000FF0000FF000000FF00FF0000FF00
FF00000000FF00FF00FF000000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF000000FFFF0000FF00000000FF0000FF0000FFFF0000
FF000000FF000000FF0000FF0000FF0000FFFF000000FF0000FF000000FF0000FFFF0000
00FF0000FF0000FF0000FF0000FF00FF00000000FFFF00000000FFFF0000FF00000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF0000FFFF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF00000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FFFF000000FF00
00FF0000FF0000FF00FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FF
0000FF00FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.516558 0.97619 0.756818 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .05047 L
.2381 .05047 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .05047 L
.2381 .05047 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01439 L
.71429 .01439 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01439 L
.71429 .01439 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .56506 L
.95238 .56506 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .56506 L
.95238 .56506 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000
FF0000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF0000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.756818 0.261905 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .56944 L
.2381 .56944 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .56944 L
.2381 .56944 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01251 L
.47619 .01251 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04797 L
.95238 .04797 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04797 L
.95238 .04797 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF800000FF00FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.756818 0.5 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02127 L
.2381 .02127 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02127 L
.2381 .02127 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .31204 L
.47619 .31204 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .31204 L
.47619 .31204 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .18856 L
.71429 .18856 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .18856 L
.71429 .18856 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .11993 L
.95238 .11993 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .11993 L
.95238 .11993 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF00FF800000FF0000FF000000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FFFF80000000FF00FF00FF8000FF8000FF8000FF800000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FFFF80000000FFFF8000FF8000FF8000
0000FF0000FFFF800000FF00FF0000FF0000FF0000FF80000000FF00FF0000FF0000FF00
FF8000FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
0000FF0000FF0000FFFF8000FF800000FF00FF8000FF800000FF00FF800000FF000000FF
FF80000000FFFF8000FF800000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF00FF00FF8000FF80000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF000000FFFF8000FF8000FF0000FF80000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF00FF8000FF8000FF0000FF8000FF000000FF00FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF00000000FFFF8000FF8000FF800000FF0000FF00
FF80000000FF00FF000000FFFF8000
FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF
FF0000FF8000FF0000FF8000FF80000000FFFF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF80000000FF
0000FFFF8000FF8000FF800000FF00
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF0000FF80000000FFFF80000000FF0000FF00FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF800000FF000000FF
00FF000000FF00FF00FF8000FF800000FF0000FF000000FF00FF0000FF0000FF00FF8000
FF800000FF00FF800000FF00FF8000
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FFFF80000000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF00FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF000000FF0000FF0000FF
FF800000FF0000FF00FF800000FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF8000
0000FFFF80000000FF0000FF00FF000000FF0000FFFF800000FF0000FF0000FF00FF8000
FF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000
FF80000000FFFF800000FF000000FF
0000FF0000FFFF80000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF00FF800000FF00FF8000FF8000FF80000000FF0000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF00FF8000FF800000FF0000FF0000FF000000FF00FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF00FF00FF8000FF8000FF8000FF8000FF800000FF000000FF00FF00
0000FF00FF000000FF00FF0000FF0000FF00FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF800000FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF800000FF00
FF8000FF8000FF800000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF00FF00FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF0000FF8000FF000000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF8000FF800000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF80000000FFFF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF00FF000000FF00FF00
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF00FF800000FF00FF800000FF000000FF0000FFFF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF800000FF00
0000FFFF80000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF80000000FF00FF00
00FF0000FF00FF8000FF80000000FFFF800000FF0000FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF000000FF00FF0000FF00FF8000FF0000
FF0000FF8000FF80000000FF00FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF800000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF0000FF8000FF80000000FF0000FF00FF00
0000FFFF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF000000FF
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00
FF0000FF8000FF8000FF80000000FF0000FF0000FF00FF0000FF0000FF00FF80000000FF
FF80000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF80000000FF0000FFFF800000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF00000000FF0000FFFF8000
FF8000FF8000FF800000FF0000FF000000FF0000FFFF80000000FF0000FF0000FF00FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
FF80000000FFFF80000000FF00FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF00FF8000FF80000000FFFF8000FF8000FF8000FF00000000FF0000FF0000FF
00FF00FF8000FF8000FF800000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF800000FF0000FF0000FF0000FF00FF80000000FF0000FF
FF8000FF800000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FFFF8000
00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FFFF8000FF80000000FF00FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FFFF8000FF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF80000000FFFF8000FF800000FF0000FF000000FF
00FF000000FF00FF0000FF00FF80000000FF0000FFFF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
0000FFFF800000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00FF8000
00FF00FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF00FF000000FF
FF0000FF8000FF0000FF0000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF
0000FFFF8000FF80000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF800000FF000000FF0000FFFF0000FF8000
FF8000FF80000000FFFF8000FF8000FF800000FF000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF800000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FF
0000FFFF80000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00FF80000000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
FF8000FF8000FF0000FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FFFF8000FF80000000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
FF80000000FF00FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FFFF80000000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FFFF8000FF800000FF0000FF000000FF
0000FF0000FFFF8000FF8000FF80000000FF00FF00FF80000000FFFF800000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FFFF80000000FFFF800000FF000000FF
0000FF00FF000000FF0000FFFF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF00FF80000000FF0000FFFF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF8000FF8000FF8000FF0000FF8000
00FF0000FF00FF8000FF800000FF000000FFFF8000FF0000FF800000FF00FF8000FF8000
0000FFFF0000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF00
FF8000FF80000000FF00FF000000FF
0000FF00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FFFF800000FF00FF80000000FF0000FF0000FF
0000FFFF8000FF0000FF8000FF80000000FFFF0000FF00000000FFFF80000000FF0000FF
FF80000000FFFF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF00FF80000000FF0000FF00FF0000FF00FF800000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF00FF80000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FFFF800000FF000000FF0000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF00FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
00FF000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FFFF800000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF00FF800000FF0000FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF000000FF
0000FF0000FFFF00000000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF80000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF00FF000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF80000000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF00FF800000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF00FF8000
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF00FF8000
FF8000FF80000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
FF800000FF00FF800000FF0000FF00
00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF00FF800000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF800000FF0000FF000000FF0000FFFF0000FF8000FF80000000FF
0000FFFF800000FF0000FF00FF8000FF000000FF00FF800000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FFFF8000
00FF0000FF00FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF80000000FFFF8000FF8000FF8000FF8000FF800000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
FF800000FF0000FF0000FF0000FF00
0000FFFF80000000FF00FF0000FF000000FF0000FF00FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00FF8000FF8000FF8000
FF8000FF80000000FF00FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF000000FF0000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF
0000FFFF800000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FFFF8000FF8000
00FF0000FF000000FF0000FFFF8000FF8000FF8000FF800000FF00FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF00FF00FF8000FF800000FF00
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00
0000FFFF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF80000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF00FF000000FF00FF000000FF0000FF00FF000000FF00FF0000FF00FF0000
FF8000FF8000FF800000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.756818 0.738095 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01189 L
.2381 .01189 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .20775 L
.47619 .20775 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .20775 L
.47619 .20775 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .37191 L
.71429 .37191 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .37191 L
.71429 .37191 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .05027 L
.95238 .05027 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .05027 L
.95238 .05027 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF800000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF800000FF00
FF8000FF80000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF800000FF000000FFFF80000000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF800000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF00
FF800000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00FF8000
0000FF0000FF0000FF0000FFFF80000000FF00FF0000FF00FF80000000FFFF80000000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF80000000FF
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF00FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FFFF80000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF00FF00
FF800000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF00FF000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000
FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF00FF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00
FF80000000FF0000FF0000FF0000FF
0000FFFF800000FF0000FF000000FF0000FF00FF00FF800000FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FFFF8000FF800000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FFFF8000
FF8000FF80000000FF0000FF00FF00
0000FF00FF000000FF00FF000000FF00FF000000FF00FF000000FF0000FF00FF0000FF00
00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF800000FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FFFF80000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000
0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00FF80000000FFFF80000000FF0000FF0000FFFF8000
00FF0000FF000000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF000000FFFF80000000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FFFF80000000FF0000FF00FF0000FF00FF8000FF8000
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FFFF80000000FF0000FF
0000FF00FF0000FF000000FF0000FFFF80000000FF00FF0000FF0000FF00FF80000000FF
0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF00FF8000FF8000FF800000FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF00FF000000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF80000000FF
00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FFFF80000000FF00FF000000FFFF800000FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF8000FF800000FF000000FF0000FFFF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FFFF80000000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FFFF80000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF00FF000000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF00FF80000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FFFF800000FF000000FFFF80000000FF
0000FFFF800000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00FF800000FF00FF8000
00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FF
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.756818 0.97619 0.997078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .10179 L
.2381 .10179 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .10179 L
.2381 .10179 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .10533 L
.47619 .10533 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .10533 L
.47619 .10533 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .08844 L
.71429 .08844 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .08844 L
.71429 .08844 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .34625 L
.95238 .34625 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .34625 L
.95238 .34625 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF800000FF0000FF00FF0000FF8000FF80000000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF00FF0000FF00FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF0000FF8000FF800000FF00FF8000
FF8000FF000000FF00FF800000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF800000FF0000FF0000FF00
FF8000FF8000FF0000FF8000FF800000FF00FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF8000FF800000FF000000FF
FF000000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00
FF8000FF0000FF0000FF8000FF800000FF000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF000000FF0000FF000000FFFF800000FF0000FF0000FF0000FF0000FF00
FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF0000FF8000FF8000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF00000000FFFF800000FF000000FF00FF00FF8000FF80000000FF
FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF8000FF800000FF000000FF0000FFFF8000FF80000000FF0000FF
00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF0000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF0000FF80000000FF
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF000000FF00
FF0000FF0000FF8000FF800000FF00FF800000FF0000FF00FF80000000FFFF80000000FF
FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF80000000FFFF800000FF00FF8000FF8000FF0000FF0000
FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF000000FF00FF8000
FF800000FF000000FF0000FF00FF00FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF800000FF000000FF00FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF00FF000000FF0000FFFF8000FF80000000FFFF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF0000FF00
00FF00FF0000FF8000FF800000FF00FF80000000FF00FF000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF8000
FF8000FF0000FF8000FF800000FF0000FF0000FF00FF8000FF0000FF0000FF8000FF8000
00FF00FF80000000FFFF8000FF800000FF00FF800000FF0000FF00FF8000FF0000FF8000
FF8000FF000000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF8000FF8000FF8000FF80000000FF
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF0000FF0000FF000000FF0000FF00FF00FF8000FF8000FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF8000FF8000
FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000
00FF00FF0000FF0000FF0000FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00
FF8000FF800000FF00FF8000FF8000FF80000000FF00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF0000FF0000FF0000FF0000
FF00000000FF0000FFFF800000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF0000FF8000FF8000FF800000FF0000FF000000FF0000FF00FF000000FF00FF00
FF8000FF80000000FF00FF00FF8000
FF8000FF0000FF8000FF0000FF800000FF0000FF0000FF000000FF0000FFFF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF800000FF00FF800000FF0000FF000000FF0000FFFF800000FF00FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000FF8000
FF8000FF800000FF000000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
FF0000FF0000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF00FF00FF8000
FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF0000FF8000FF8000FF80000000FF0000FF00FF0000FF0000FF000000FF
FF8000FF80000000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FF00FF00FF8000FF8000FF000000FF0000FF00FF800000FF00FF8000FF8000
0000FFFF8000FF0000FF00000000FF0000FF0000FF00FF00FF8000FF0000FF8000FF8000
FF800000FF000000FFFF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF00FF00
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000
FF800000FF00FF8000FF0000FF8000
00FF000000FFFF8000FF8000FF80000000FFFF800000FF0000FF000000FF00FF00FF8000
FF8000FF800000FF00FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00
FF8000FF0000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF000000FFFF80000000FFFF8000FF0000FF8000FF0000
00FF000000FF00FF0000FF0000FF00FF8000FF80000000FF0000FF0000FF00FF0000FF00
FF8000FF800000FF0000FF00FF0000
0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF80000000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF800000FF00FF0000
00FF00FF800000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000
0000FFFF8000FF0000FF8000FF0000FF000000FF00FF800000FF000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF000000FF000000FF00FF0000FF0000FF00FF8000
FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF00000000FF00FF00FF800000FF00
FF8000FF8000FF80000000FFFF8000FF800000FF0000FF000000FFFF8000FF80000000FF
FF0000FF0000FF8000FF0000FF800000FF00FF0000FF8000FF0000FF8000FF80000000FF
FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF0000FF8000
FF0000FF800000FF0000FF000000FFFF8000FF800000FF00FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF000000FF00FF00
0000FF00FF0000FF00FF8000FF8000
00FF00FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF800000FF0000FF00FF8000FF80000000FF0000FFFF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000
FF000000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00FF8000
0000FF00FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000FF800000FF00FF800000FF00
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF8000FF000000FF0000FF00
00FF00FF0000FF0000FF8000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF0000
FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF80000000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
00FF00FF8000FF0000FF800000FF00
FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF0000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF800000FF00FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF800000FF00
00FF0000FF00FF0000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF80000000FFFF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
00FF00FF00000000FFFF8000FF8000FF8000FF80000000FFFF8000FF0000FF8000FF8000
FF8000FF8000FF80000000FF0000FF00FF00FF00000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF800000FF00FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000
FF80000000FFFF80000000FF0000FFFF0000FF8000FF0000FF0000FF8000FF00000000FF
00FF00FF80000000FF00FF00FF800000FF00FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FFFF8000
FF80000000FFFF8000FF800000FF000000FFFF000000FF00FF800000FF00FF8000FF8000
FF80000000FF00FF0000FF000000FFFF8000FF8000FF0000FF8000FF0000FF800000FF00
FF8000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FFFF8000FF0000FF8000FF800000FF00FF0000FF8000
FF80000000FFFF8000FF800000FF000000FF0000FFFF80000000FF0000FF00FF00FF8000
FF8000FF8000FF800000FF00FF8000
0000FFFF8000FF8000FF8000FF800000FF00FF800000FF00FF0000FF800000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF000000FF00FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF0000FF00000000FF0000FFFF8000FF80000000FFFF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF000000FF0000FF0000FFFF800000FF0000FF00
0000FFFF80000000FFFF8000FF8000
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF80000000FF0000FF00FF000000FF00FF00FF8000FF8000FF8000FF0000FF8000FF8000
FF000000FF00FF0000FF0000FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF00
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF80000000FFFF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF800000FF00FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000
0000FF00FF0000FF00FF80000000FF00FF00FF800000FF00FF8000FF8000FF800000FF00
FF8000FF80000000FF0000FF0000FFFF8000FF800000FF00FF8000FF800000FF00FF8000
00FF00FF8000FF8000FF0000FF8000FF80000000FFFF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF000000FF00FF800000FF00FF800000FF00FF8000
0000FF0000FF0000FF0000FFFF8000FF800000FF00FF8000FF80000000FFFF8000FF8000
FF8000FF80000000FFFF80000000FF00FF000000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF0000
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF000000FF00FF8000
FF0000FF8000FF0000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF80000000FF0000FFFF8000FF80000000FF0000FF00FF0000FF00FF0000FF0000FF0000
FF0000FF80000000FFFF800000FF00FF8000FF80000000FF00FF00FF800000FF000000FF
00FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF00FF800000FF0000FF000000FFFF0000FF8000FF8000
FF00000000FF0000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF00FF00FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF0000FF0000FF0000FF0000FF00FF800000FF00FF0000FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF800000FF000000FF0000FF0000FFFF800000FF00
FF8000FF0000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF00FF00FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF0000FF0000FF80000000FFFF8000FF800000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF0000
FF8000FF8000FF000000FF00FF800000FF0000FF000000FF00FF0000FF0000FF00FF0000
FF8000FF0000FF0000FF0000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF80000000FF00FF00FF8000FF8000FF0000
FF80000000FFFF800000FF00FF8000FF80000000FF00FF00FF8000FF8000FF0000FF8000
FF80000000FFFF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF0000
FF8000FF0000FF8000FF800000FF00
FF8000FF00000000FFFF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000
FF800000FF0000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF000000FF00FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF0000FF0000FF8000FF8000FF0000FF800000FF00FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF0000FF8000FF80000000FF0000FFFF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000
FF0000FF80000000FFFF8000FF0000FF8000FF0000FF8000FF800000FF000000FF00FF00
FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF800000FF00FF0000FF800000FF00FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF0000FF8000FF8000FF00000000FFFF80000000FFFF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00FF80000000FF0000FF
FF80000000FF0000FFFF8000FF8000FF800000FF00FF80000000FFFF8000FF800000FF00
0000FF00FF000000FF00FF0000FF000000FFFF800000FF0000FF00FF8000FF0000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF0000
FF8000FF8000FF0000FF8000FF0000FF000000FF00FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF8000FF000000FF000000FFFF0000FF8000FF0000
FF0000FF8000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF80000000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF800000FF000000FF00FF000000FFFF8000FF8000
FF8000FF800000FF0000FF000000FF00FF0000FF000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF000000FF0000FF0000FF0000FF00FF8000
0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF0000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF800000FF000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF00FF8000
0000FF0000FF0000FFFF8000FF8000FF800000FF0000FF0000FF000000FFFF8000FF8000
FF8000FF80000000FF00FF0000FF0000FF0000FF00FF80000000FFFF8000FF8000FF8000
FF8000FF800000FF00FF0000FF8000FF8000FF80000000FF00FF00FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF800000FF0000FF00
FF8000FF0000FF0000FF8000FF800000FF0000FF0000FF000000FFFF8000FF8000FF8000
FF800000FF0000FF000000FFFF8000FF8000FF80000000FF0000FF0000FF00FF00FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FFFF80000000FF
0000FFFF8000FF8000FF0000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF0000
FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF0000FF0000
FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF800000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF00FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF800000FF000000FF00FF000000FF00FF00FF8000FF0000FF8000FF0000
FF0000FF8000FF8000FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF800000FF0000FF00FF8000FF0000FF0000FF0000FF8000FF80000000FF00FF00
00FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF800000FF00FF80000000FFFF80000000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF0000FF8000
FF8000FF0000FF8000FF00000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF0000FF0000FF8000
FF80000000FFFF80000000FFFF0000FF8000FF0000FF0000FF8000FF800000FF000000FF
FF8000FF8000FF8000FF8000FF0000
FF80000000FF0000FFFF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000
FF0000FF0000FF0000FF000000FF0000FF0000FF000000FF00FF00FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
0000FF0000FFFF80000000FFFF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF0000FF0000
FF8000FF800000FF0000FF00FF80000000FFFF8000FF8000FF8000FF80000000FF00FF00
0000FF0000FF00FF000000FF00FF000000FF0000FFFF80000000FF0000FFFF8000FF8000
FF8000FF0000FF0000FF8000FF0000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF000000FF00FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF8000FF0000
FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF0000FF8000FF0000
FF8000FF8000FF0000FF0000FF0000
FF8000FF8000FF800000FF000000FF0000FF0000FF00FF00FF8000FF800000FF000000FF
00FF00FF000000FF0000FF0000FF0000FF000000FF00FF00FF80000000FFFF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF0000FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
FF8000FF0000FF8000FF0000FF0000
0000FFFF8000FF800000FF0000FF000000FFFF8000FF8000FF8000FF800000FF00FF8000
FF8000FF0000FF000000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF800000FF00FF800000FF0000FF0000FF00FF0000
FF8000FF8000FF800000FF000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF80000000FFFF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.997078 0.261905 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .50999 L
.2381 .50999 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .50999 L
.2381 .50999 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .02857 L
.47619 .02857 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .02857 L
.47619 .02857 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .07509 L
.71429 .07509 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .07509 L
.71429 .07509 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02816 L
.95238 .02816 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02816 L
.95238 .02816 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF000000FF00FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FFFF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF00FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF000000FF00FF0000FF80000000FF0000FF00FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF00000000FFFF0000FF0000FF000000FF00FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF00FF00FF0000FF8000FF0000FF000000FF00FF00000000FFFF0000
FF0000FF8000FF000000FF00FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FF
FF00000000FF0000FFFF0000FF0000FF8000FF0000FF00000000FF0000FF0000FFFF0000
00FF00FF8000FF000000FF00FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF000000FF00FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF80000000FFFF00000000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FFFF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF00000000FFFF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
0000FF0000FFFF0000FF0000FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF8000FF0000
FF80000000FFFF00000000FFFF0000FF0000FF0000FF00000000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FFFF000000FF00FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000FF0000
0000FFFF0000FF00000000FF0000FFFF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FF0000FF00000000FFFF00000000FFFF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
00FF0000FF0000FF0000FF00FF0000
FF00000000FFFF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF8000FF8000FF0000FF000000FF00FF0000FF8000FF000000FF0000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF00000000FFFF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF0000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000
FF00000000FFFF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF00000000FFFF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF00000000FF0000FFFF00000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF000000FF00
0000FF00FF0000FF00FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF000000FF00
0000FFFF800000FF00FF8000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF80000000FF0000FF
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF00000000FF0000FFFF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF80000000FF0000FF
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF00FF8000FF80000000FFFF0000
FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FFFF0000FF00000000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF00FF8000FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF00000000FF00FF000000FF0000FFFF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF000000FF000000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF000000FF00FF0000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
00FF00FF0000FF0000FF0000FF0000
FF80000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF0000
00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FFFF00000000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF80000000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF8000FF0000FF0000FF0000FF0000
0000FF00FF000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF00000000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF000000FF
FF8000FF000000FF00FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.997078 0.5 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02419 L
.2381 .02419 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02419 L
.2381 .02419 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .32518 L
.47619 .32518 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .32518 L
.47619 .32518 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .10971 L
.71429 .10971 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .10971 L
.71429 .10971 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .18272 L
.95238 .18272 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .18272 L
.95238 .18272 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00FF800000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF80000000FF00FF0000FF000000FF00FF00FF0000FF000000FF00FF8000FF800000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000
00FF000000FFFF8000FF800000FF00
FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FFFF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF00FF80000000FF00FF00FF0000FF0000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF000000FF00FF000000FF
00FF00FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF80000000FF00FF0000FF00FF000000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF00FF800000FF00
FF8000FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF80000000FF00FF000000FF
00FF000000FFFF800000FF00FF8000FF80000000FF0000FF00FF000000FF00FF00FF8000
FF80000000FF00FF00FF80000000FF00FF000000FF0000FF0000FFFF8000FF800000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF00000000FFFF8000FF800000FF00
00FF00FF8000FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF00000000FF0000FF
0000FF0000FFFF800000FF00FF80000000FF0000FF00FF000000FF0000FF00FF00FF8000
FF80000000FF00FF000000FF0000FF00FF0000FF000000FF0000FF00FF00FF800000FF00
00FF000000FF0000FF0000FFFF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF800000FF00
00FF00FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF00000000FF0000FF
0000FF0000FFFF800000FF0000FF00FF00000000FF00FF000000FF0000FF00FF00FF8000
0000FF0000FFFF00000000FF0000FF00FF0000FF0000FF000000FF00FF00FF800000FF00
00FF000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF800000FF00FF800000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF800000FF00FF8000FF00000000FF00FF000000FF0000FF0000FFFF8000
0000FF0000FFFF00000000FF00FF000000FF0000FF0000FF0000FFFF8000FF800000FF00
00FF000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF80000000FF0000FF
0000FFFF8000FF80000000FFFF8000FF00000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF00000000FF0000FF0000FF0000FF00FF000000FF00FF00FF8000FF8000
00FF000000FF0000FF0000FFFF800000FF0000FF00FF8000FF8000FF8000FF800000FF00
00FF000000FF00FF0000FF00FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF00FF000000FF0000FF00FF000000FF00FF0000FF0000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000
00FF000000FFFF000000FF0000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF800000FF00FF800000FF0000FF00FF8000FF800000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF000000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF0000
00FF000000FFFF8000FF8000FF800000FF000000FF00FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF000000FF00FF000000FF0000FF
00FF000000FFFF0000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
00FF000000FFFF8000FF8000FF800000FF000000FF00FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FFFF8000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF000000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF00FF80000000FF00FF000000FFFF0000
0000FF0000FF0000FFFF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF0000FF8000FF0000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF00FF800000FF00FF800000FF000000FF0000FFFF00000000FF0000FF0000FF
00FF00FF8000FF80000000FFFF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FF0000FF00FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF000000FF
FF00000000FF00FF00FF800000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF80000000FF0000FF
0000FF0000FF00FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF80000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FFFF00000000FF00FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FF0000FF00FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF80000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FFFF00000000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00FF800000FF00FF00000000FFFF8000FF800000FF00
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF8000FF8000
00FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF80000000FF0000FF0000FF
00FF00FF800000FF000000FF0000FF0000FFFF00000000FF0000FF00FF0000FF00FF0000
0000FF0000FF00FF000000FF0000FF00FF0000FF00FF80000000FFFF0000FF800000FF00
FF80000000FF00FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF
00FF00FF800000FF000000FF0000FF0000FF0000FF00FF00FF000000FF0000FF00FF8000
0000FF0000FF00FF000000FF00FF0000FF0000FF00FF8000FF800000FF00FF800000FF00
FF80000000FF00FF000000FFFF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
0000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF80000000FF0000FF00FF00
0000FFFF800000FF000000FF0000FF0000FF0000FF0000FFFF000000FF0000FF000000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00
FF80000000FF00FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00
0000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF80000000FFFF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF00FF00FF00000000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FFFF8000FF800000FF0000FF00FF8000FF800000FF0000FF00
FF80000000FF00FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF80000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF00000000FF0000FFFF00000000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF800000FF00FF800000FF00FF800000FF0000FF00
FF80000000FF00FF0000FF00FF8000FF800000FF00FF8000FF8000FF80000000FF00FF00
0000FF00FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF80000000FF00FF00FF800000FF0000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF00000000FF0000FFFF0000FF0000FF0000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF000000FF00FF0000FF00FF8000FF800000FF00FF8000FF8000FF80000000FFFF8000
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF000000FF00FF000000FF
0000FFFF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FFFF800000FF00
0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF800000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF80000000FF0000FF
0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF80000000FFFF00000000FF
FF8000FF8000FF800000FF0000FF0000FF000000FF0000FF0000FFFF8000FF80000000FF
00FF000000FFFF8000FF800000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF00
FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF80000000FF0000FF00FF00
0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF800000FF00FF800000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF0000FF00FF8000FF800000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF
00FF0000FF00FF00000000FF00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000FF00000000FF00FF00
00FF00FF8000FF800000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF800000FF00FF800000FF000000FF00FF000000FF0000FF0000FF0000FF
00FF00FF800000FF00FF800000FF000000FF0000FF0000FF0000FF0000FFFF8000FF8000
00FF0000FF0000FF000000FF00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF0000FF0000FF0000
FF0000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF800000FF00FF8000FF8000FF800000FF000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
00FF0000FF000000FF0000FF00FF0000FF0000FF00FF800000FF00FF8000FF800000FF00
FF800000FF0000FF000000FFFF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000
0000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF00FF000000FF0000FF0000FF0000FFFF8000FF800000FF00
00FF0000FF00FF80000000FF00FF00FF80000000FF0000FF00FF00FF8000FF800000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF00FF000000FF0000FF0000FF0000FF00FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF800000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF000000FFFF8000
0000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF00FF800000FF000000FF0000FF
0000FFFF800000FF0000FF000000FFFF00000000FF0000FFFF00000000FFFF800000FF00
FF8000FF8000FF8000FF000000FF00FF800000FF00FF800000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF80000000FF0000FF
00FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF80000000FF00FF000000FF0000FF
0000FFFF8000FF800000FF0000FF00FF800000FF00FF8000FF00000000FF0000FFFF8000
FF0000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF00FF800000FF000000FF
00FF0000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF800000FF000000FF00FF000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF800000FF000000FF0000FF00FF000000FFFF8000
00FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00
FF8000FF800000FF00FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00
FF800000FF00FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF0000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF0000FF00FF800000FF00FF800000FF00FF800000FF0000FF00
00FF00FF8000FF8000FF800000FF00
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF800000FF0000FF000000FF
0000FFFF80000000FFFF80000000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
FF80000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF80000000FFFF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF000000FF
00FF00FF80000000FFFF80000000FF0000FF00FF000000FF0000FF00FF0000FF00FF8000
FF80000000FFFF000000FF0000FF0000FF000000FF0000FFFF8000FF800000FF0000FF00
00FF00FF80000000FFFF800000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000
FF800000FF0000FF00FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF800000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF0000FF000000FF0000FF000000FF0000FF0000FFFF800000FF0000FF00
00FF000000FF0000FFFF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF800000FF0000FF00FF800000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.997078 0.738095 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .07592 L
.2381 .07592 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .07592 L
.2381 .07592 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .13891 L
.47619 .13891 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .13891 L
.47619 .13891 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .27533 L
.71429 .27533 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .27533 L
.71429 .27533 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .15164 L
.95238 .15164 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .15164 L
.95238 .15164 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF8000FF800000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF00000000FF0000FF0000FF00FF00FF0000FF0000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF800000FF00FF0000FF8000FF8000FF80000000FF00FF00
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FFFF0000FF0000
FF000000FF0000FF0000FF00FF8000FF800000FF00FF80000000FFFF0000FF0000FF0000
FF00000000FFFF8000FF0000FF0000
FF80000000FFFF800000FF0000FF00FF8000FF8000FF0000FF800000FF000000FFFF8000
00FF00FF8000FF800000FF000000FF00FF00FF0000FF000000FF00FF8000FF80000000FF
0000FF0000FFFF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00
0000FF0000FFFF0000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000FF80000000FF0000FF00FF00
00FF0000FF000000FF00FF00FF800000FF0000FF00FF80000000FF0000FF0000FFFF0000
FF0000FF000000FF00FF0000FF0000
FF80000000FFFF0000FF8000FF8000FF8000FF8000FF00000000FFFF80000000FFFF8000
00FF00FF00000000FF00FF000000FF0000FF0000FFFF000000FF00FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF0000
00FF000000FFFF0000FF0000FF0000FF000000FF000000FFFF00000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF800000FF00
FF8000FF80000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF0000
FF000000FF00FF800000FF0000FF00
FF80000000FFFF8000FF8000FF800000FF00FF8000FF00000000FFFF000000FF00FF8000
00FF00FF800000FF0000FF000000FF0000FF0000FF0000FF00FF000000FFFF8000FF8000
0000FFFF800000FF00FF8000FF800000FF00FF8000FF800000FF000000FF0000FFFF8000
FF00000000FFFF0000FF0000FF000000FF0000FF000000FFFF00000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
FF00000000FF0000FF00FF00FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF
FF00000000FFFF8000FF000000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF00FF00
00FF00FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF000000FF0000FF00FF00
0000FFFF0000FF0000FF0000FF000000FF0000FF00FF8000FF00000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
FF00000000FF0000FFFF0000FF800000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FFFF800000FF00
FF8000FF8000FF800000FF00FF8000FF800000FF00FF80000000FFFF00000000FF00FF00
00FF0000FF000000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF000000FF00FF8000FF800000FF00FF8000FF000000FF000000FF0000FF00FF00
0000FFFF0000FF000000FF0000FF0000FF00FF8000FF8000FF000000FF000000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF00
FF000000FF000000FF00FF00FF8000FF800000FF0000FF0000FF000000FF00FF000000FF
00FF000000FF0000FFFF000000FF00
0000FFFF8000FF8000FF8000FF800000FF0000FF00FF80000000FFFF00000000FF00FF00
00FF00FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF00FF000000FFFF8000FF800000FF0000FF00FF00000000FF0000FFFF00000000FF
0000FF0000FF0000FF00FF0000FF000000FFFF0000FF8000FF000000FF0000FF00FF0000
0000FFFF000000FF000000FF0000FF0000FF0000FFFF0000FF000000FF000000FF00FF00
0000FF0000FF0000FF00FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
0000FF0000FF0000FFFF000000FF00
FF800000FF0000FF0000FF00FF8000FF8000FF8000FF80000000FFFF80000000FF00FF00
00FF00FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF00FF0000FF00FF8000
00FF0000FF00FF8000FF8000FF800000FF0000FF00FF00000000FF0000FFFF00000000FF
0000FF0000FF0000FFFF000000FF000000FFFF8000FF8000FF800000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FFFF00000000FF00FF000000FFFF0000
00FF00FF00000000FF00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
0000FF0000FF0000FFFF00000000FF
FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF000000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF00FF8000FF800000FF0000FF0000FF00FF00000000FF0000FFFF00000000FF
0000FF0000FF0000FFFF800000FF00FF80000000FF00FF00FF800000FF000000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF00FF00000000FF00FF0000FF00FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FF00FF000000FF0000FF
FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF000000FF000000FFFF0000FF00000000FF0000FF0000FFFF8000
00FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF000000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
FF00000000FF0000FF00FF0000FF00FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FFFF80000000FF0000FF
00FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF800000FF00FF8000FF80000000FF0000FF00FF00FF0000FF00000000FFFF8000FF0000
00FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF80000000FF00FF000000FF
0000FFFF0000FF00000000FFFF0000FF00000000FF00FF0000FF00FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
FF000000FF000000FF0000FF00FF00FF8000FF800000FF000000FFFF8000FF0000FF0000
0000FF0000FFFF8000FF00000000FF
00FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF80000000FF0000FFFF0000FF0000FF00000000FFFF8000FF0000
00FF0000FF00FF8000FF80000000FF00FF00FF000000FF00FF0000FF000000FF0000FF00
FF00000000FF0000FF0000FFFF8000FF00000000FF00FF000000FF00FF00FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000FF8000
FF800000FF000000FF0000FF00FF0000FF00FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF
00FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF00000000FFFF00000000FF0000FF00FF00FF0000FF8000
0000FF00FF00FF8000FF80000000FF0000FFFF0000FF0000FF000000FF00FF000000FF00
FF00000000FF0000FF0000FF0000FFFF00000000FF00FF000000FF0000FFFF00000000FF
FF00000000FF00FF000000FF0000FF0000FF0000FF0000FFFF0000FF8000FF00000000FF
FF0000FF800000FF000000FF00FF00FF8000FF800000FF00FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF00FF00FF0000FF00000000FF00FF00FF80000000FF
0000FF0000FF0000FFFF80000000FFFF00000000FFFF0000FF0000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000FF000000FF00FF00000000FF
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF000000FF0000FF
0000FF0000FFFF8000FF80000000FF
00FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF0000FF000000FFFF000000FF000000FF0000FF0000FF
0000FFFF00000000FF00FF00FF80000000FF00FF00FF8000FF0000FF8000FF0000FF8000
0000FF0000FF0000FFFF000000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF000000FF00FF00000000FF0000FF0000FFFF00000000FF0000FF0000FF
FF800000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF000000FFFF0000
0000FF0000FFFF0000FF00000000FF
00FF0000FF000000FFFF8000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF80000000FF0000FF00FF00FF80000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF00000000FF
0000FF0000FF0000FFFF0000FF000000FF00FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF80000000FFFF0000
0000FF0000FFFF00000000FFFF0000
00FF0000FF00FF80000000FF00FF0000FF000000FF0000FFFF0000FF0000FF8000FF8000
00FF00FF8000FF8000FF00000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
FF0000FF000000FF0000FF00FF8000FF800000FF0000FF00FF800000FF000000FF0000FF
0000FF00FF000000FFFF000000FF0000FF00FF8000FF0000FF80000000FF0000FF0000FF
0000FF0000FF00FF000000FFFF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
FF800000FF00FF8000FF80000000FFFF800000FF0000FF0000FF000000FFFF00000000FF
00FF00FF00000000FF0000FFFF8000
FF800000FF00FF80000000FF00FF0000FF000000FF0000FFFF8000FF800000FF00FF8000
FF0000FF8000FF0000FF000000FF000000FFFF000000FF000000FF0000FF0000FF0000FF
FF0000FF00000000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00FF0000FF0000
FF0000FF00000000FFFF800000FF0000FF000000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF00FF00FF0000FF00000000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF00FF000000FF0000FF00FF00FF800000FF000000FF00FF000000FF00FF000000FF
FF00000000FF00FF000000FF0000FF
FF800000FF00FF8000FF8000FF800000FF00FF80000000FF00FF0000FF0000FF0000FF00
0000FFFF8000FF0000FF00000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000
0000FFFF00000000FFFF000000FF0000FF000000FF00FF00FF8000FF0000FF8000FF8000
FF80000000FF00FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000
FF000000FF000000FF00FF0000FF000000FF00FF000000FF0000FFFF00000000FF0000FF
FF00000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF800000FF00FF80000000FF00FF0000FF00FF800000FF00
00FF00FF800000FF00FF00000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF000000FF000000FFFF8000FF0000FF80000000FFFF0000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF0000FF8000FF0000FF8000FF8000
FF80000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF8000
FF800000FF000000FF0000FF0000FF0000FF00FF000000FF0000FFFF00000000FF00FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF00FF8000FF8000FF8000FF80000000FFFF800000FF00FF800000FF00
FF800000FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF000000FF00FF8000
FF80000000FF0000FF0000FFFF800000FF000000FFFF80000000FF0000FF00FF00FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF000000FF000000FFFF800000FF00
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF8000
FF8000FF80000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF
00FF0000FF0000FF00FF8000FF8000FF8000FF80000000FFFF800000FF00FF800000FF00
FF8000FF800000FF0000FF000000FF0000FFFF000000FF0000FF00FF000000FF00FF8000
FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF0000
FF0000FF0000FF0000FF00000000FFFF00000000FF0000FF0000FF0000FF0000FFFF0000
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF00000000FF0000FF
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF0000FF000000FF00
FF8000FF8000FF800000FF00FF000000FF0000FF0000FF00FF8000FF800000FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
FF800000FF0000FF000000FF0000FFFF000000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FFFF000000FF000000FF
0000FFFF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00FF8000FF0000FF000000FF00
00FF0000FF00FF800000FF0000FF0000FF00FF800000FF00FF80000000FF00FF000000FF
FF000000FF00FF00000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF0000FF80000000FFFF00000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
0000FFFF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF80000000FF00FF00FF00000000FF0000FF00FF00
FF800000FF00FF800000FF00FF000000FF000000FFFF8000FF80000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF000000FF00FF80000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
FF800000FF00FF0000FF00000000FFFF00000000FF00FF0000FF00FF80000000FF0000FF
0000FF0000FF00FF0000FF000000FF
FF0000FF000000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF00000000FF00FF00
00FF00FF8000FF800000FF00FF800000FF000000FF0000FF00FF000000FF0000FF0000FF
FF800000FF00FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF00FF000000FF0000FF00FF000000FF0000FFFF000000FF0000FF00
00FF0000FF00FF8000FF00000000FF0000FF0000FF00FF0000FF00FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FFFF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF800000FF00FF80000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF00FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF00FF000000FF
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF80000000FF0000FF0000FFFF00000000FF0000FF0000FFFF8000FF0000
FF8000FF00000000FF0000FF0000FF
0000FF00FF0000FF00FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000
FF8000FF800000FF00FF80000000FF00FF0000FF000000FF0000FF0000FFFF80000000FF
FF0000FF0000FF0000FF80000000FF0000FF00FF00FF8000FF8000FF8000FF8000FF0000
00FF00FF00000000FF0000FF00FF000000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FFFF8000FF8000FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF0000
0000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF8000FF80000000FF00FF00FF800000FF00FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF800000FF00FF800000FF0000FF000000FF00FF00FF8000FF0000
FF00000000FF0000FF0000FF0000FF0000FF00FF000000FFFF8000FF800000FF00FF0000
00FF000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF00FF8000FF000000FF00FF8000FF8000
00FF0000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF80000000FF00FF00FF800000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FFFF000000FF000000FFFF000000FF00FF8000FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF0000FF8000FF800000FF0000FF000000FFFF8000FF8000FF0000
FF8000FF0000FF0000FF00000000FF00FF00FF0000FF00000000FF0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF000000FF00FF8000FF8000
FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00000000FF0000FF0000FF
00FF00FF8000FF8000FF800000FF00FF800000FF00FF80000000FF0000FFFF8000FF0000
FF8000FF0000FF0000FF00000000FFFF0000FF00000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FFFF00000000FF0000FFFF8000FF8000
FF800000FF0000FF000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF0000
FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF
0000FFFF000000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF800000FF00FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF0000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF800000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF00FF000000FF0000FF0000FF
0000FFFF0000FF800000FF000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF800000FF00FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF800000FF000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF800000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
00FF00FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF8000FF800000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FFFF8000FF0000FF8000FF8000FF800000FF000000FF0000FF0000FFFF0000
00FF00FF8000FF800000FF00FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF800000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.997078 0.97619 1.23734 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02044 L
.2381 .02044 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02044 L
.2381 .02044 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .17291 L
.47619 .17291 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .17291 L
.47619 .17291 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .0171 L
.71429 .0171 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .0171 L
.71429 .0171 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .43135 L
.95238 .43135 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .43135 L
.95238 .43135 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF800000FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF0000FF800000FF00FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF0000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF8000
FF800000FF00FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00
FF800000FF00FF800000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
FF800000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF0000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF8000
FF800000FF00FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000
00FF00FF8000FF800000FF00FF800000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF00
FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF800000FF00FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
00FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000
00FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF800000FF0000FF00FF800000FF00FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF00FF8000FF800000FF0000FF00FF800000FF0000FF00
FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF00FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF0000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF800000FF0000FF00FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00
00FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF800000FF00FF80000000FFFF8000FF8000FF8000FF800000FF00
00FF00FF800000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF800000FF00FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00
00FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
00FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF0000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000
FF800000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FFFF8000FF8000FF8000
FF800000FF00FF8000FF800000FF00
00FF00FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
00FF00FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000
FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF00FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF000000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000
FF800000FF00FF8000FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
00FF0000FF00FF800000FF0000FF00FF800000FF0000FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF800000FF00FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF800000FF00FF8000FF800000FF00FF800000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF800000FF0000FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00
FF800000FF00FF8000FF0000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF0000FF00FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF0000FF8000
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF800000FF00FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF00000000FF
FF8000FF8000FF8000FF800000FF00FF0000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF800000FF0000FF0000FF0000FF00FF8000
00FF00FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF00FF00FF800000FF00FF8000FF800000FF00
00FF00FF8000FF800000FF00FF0000
FF800000FF0000FF00FF8000FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
00FF00FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF800000FF00
FF800000FF00FF8000FF0000FF8000
FF8000FF800000FF00FF80000000FF00FF00FF800000FF00FF8000FF800000FF0000FF00
FF8000FF8000FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
00FF00FF800000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00
FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF00FF800000FF0000FF00
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF0000FF00FF800000FF00FF0000
0000FFFF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000
00FF00FF8000FF8000FF800000FF00
FF800000FF00FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
FF800000FF00FF800000FF00FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF8000FF8000FF0000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF80000000FF0000FFFF8000FF8000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00FF800000FF00FF800000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF00
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF800000FF00FF8000
FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF800000FF00FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF0000FF8000FF8000FF8000
00FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000FF8000FF0000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
00FF00FF800000FF0000FF0000FF00
00FF00FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF00FF8000FF8000
FF800000FF0000FF0000FF00FF800000FF00FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF00FF8000FF800000FF00FF8000FF8000FF800000FF00FF800000FF00
FF800000FF0000FF0000FF00FF800000FF0000FF00FF8000FF800000FF00FF8000FF8000
FF8000FF800000FF00FF8000FF800000FF0000FF00FF800000FF00FF8000FF800000FF00
FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
00FF0000FF0000FF0000FF00FF800000FF00FF8000FF800000FF00FF8000FF800000FF00
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23734 0.261905 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59781 L
.2381 .59781 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59781 L
.2381 .59781 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01293 L
.47619 .01293 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01293 L
.47619 .01293 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01209 L
.71429 .01209 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01898 L
.95238 .01898 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01898 L
.95238 .01898 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 1.23734 0.5 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .02482 L
.2381 .02482 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .02482 L
.2381 .02482 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .34667 L
.47619 .34667 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .34667 L
.47619 .34667 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .22444 L
.71429 .22444 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .22444 L
.71429 .22444 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .04588 L
.95238 .04588 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .04588 L
.95238 .04588 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FFFF800000FF0000FF000000FF0000FFFF8000FF8000FF0000FF800000FF000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000
FF0000FF000000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FFFF000000FF00FF8000FF8000
FF800000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF00FF8000FF0000FF000000FF000000FF
00FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000
FF000000FF0000FF0000FF0000FF00
FF000000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FFFF800000FF0000FF00FF8000FF8000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF00FF000000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FF0000FF00000000FFFF8000
FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF00FF0000FF0000FF00FF800000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF00FF800000FF000000FF0000FF00FF0000FF00
00FF00FF000000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FFFF8000
FF800000FF00FF8000FF800000FF0000FF000000FF00FF00FF8000FF000000FF0000FF00
0000FFFF800000FF00FF800000FF0000FF0000FF00FF000000FF0000FF00FF8000FF0000
FF800000FF0000FF000000FF0000FF
0000FFFF80000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF00FF00FF0000
00FF0000FF00FF800000FF00FF800000FF0000FF0000FF0000FF000000FF0000FFFF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00
00FF0000FF000000FF0000FF00FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FFFF80000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF000000FFFF80000000FF00FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF000000FF0000FF
00FF000000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF800000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF000000FF0000FFFF800000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000
FF000000FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF000000FF0000FFFF8000FF8000FF80000000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
00FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF00FF00000000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000
00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF000000FF0000FF0000FF000000FFFF8000FF8000FF8000FF800000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF000000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF800000FF00FF8000
00FF0000FF0000FF0000FF000000FF0000FF00FF00FF8000FF000000FF0000FF000000FF
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF000000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF00FF000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF8000FF800000FF0000FF000000FF0000FFFF8000FF8000FF8000FF800000FF0000FF00
FF000000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
FF8000FF800000FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
FF8000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF8000FF8000FF0000
FF0000FF8000FF800000FF0000FF00FF800000FF0000FF000000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF0000FF00FF8000FF800000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00FF8000FF8000FF0000FF800000FF0000FF00FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF00FF8000FF8000FF8000
00FF000000FF00FF0000FF0000FF0000FF00FF0000FF000000FF000000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF00
0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FFFF80000000FF
0000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FFFF00000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF00FF800000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF00FF00
00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00FF800000FF000000FF
FF000000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
FF000000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00
00FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF00FF000000FF00FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
FF8000FF8000FF80000000FF0000FF
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FFFF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF0000FF0000FFFF0000
00FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF000000FF00FF0000FF00FF800000FF000000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF000000FF00FF00
00FF000000FF00FF000000FF00FF00
0000FF00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF800000FF0000FF00
00FF000000FF00FF0000FF0000FF000000FF00FF000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FFFF8000
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FFFF800000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF80000000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF00FF0000
00FF0000FF00FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FFFF800000FF000000FF
00FF000000FF0000FF0000FFFF800000FF0000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00FF800000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00FF800000FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00FF8000
FF800000FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF8000FF80000000FF0000FF0000FF0000FFFF800000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFF800000FF000000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FFFF80000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00FF8000
00FF0000FF00FF800000FF0000FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FFFF0000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF800000FF00
FF000000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF00FF00
00FF000000FF00FF0000FF00FF0000FF000000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FFFF8000FF8000
FF800000FF000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF000000FFFF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00FF0000
FF000000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF00FF8000FF800000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
00FF0000FF0000FF0000FF000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 1.23734 0.738095 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01439 L
.2381 .01439 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01439 L
.2381 .01439 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .27012 L
.47619 .27012 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .27012 L
.47619 .27012 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .32143 L
.71429 .32143 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .32143 L
.71429 .32143 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .03587 L
.95238 .03587 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .03587 L
.95238 .03587 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF000000FF00
0000FF0000FF00FF000000FF0000FF0000FFFF800000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF00FF000000FFFF800000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF000000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF000000FF00FF000000FF0000FFFF8000FF8000FF8000FF8000FF800000FF00
0000FF0000FF00FF000000FFFF80000000FF00FF000000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF800000FF00FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF0000FF800000FF0000FF00
0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF000000FF00FF000000FF00FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FFFF8000
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
00FF000000FF00FF0000FF000000FFFF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FFFF80000000FF00FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF00
0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FFFF8000
0000FF0000FF0000FF00FF0000FF0000FF00FF8000FF8000FF800000FF0000FF0000FF00
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF0000FFFF8000FF8000FF8000FF800000FF00
0000FF00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FFFF800000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF00
FF800000FF00FF8000FF800000FF0000FF00FF00000000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF000000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FFFF80000000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF00
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF00FF00
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF00FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF800000FF0000FF00
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF00FF0000FF000000FFFF80000000FF00FF0000FF000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF000000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF00FF8000FF8000
FF80000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF00FF80000000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FFFF8000FF800000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF800000FF0000FF00FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF000000FF00FF0000FF000000FF00FF000000FF00FF00FF800000FF00FF8000
00FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF000000FF
00FF0000FF000000FF00FF000000FF00FF0000FF0000FF00FF0000FF00000000FF00FF00
FF80000000FF00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00FF8000FF8000
FF8000FF80000000FF00FF000000FF00FF0000FF0000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FFFF8000FF8000
FF800000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF00FF00FF800000FF0000FF00FF800000FF0000FF00FF800000FF0000FF00
00FF000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF00FF8000
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF0000FF0000FF0000
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF00FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FFFF8000FF8000
FF800000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF800000FF00
00FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF000000FF00FF00FF80000000FF0000FF0000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00
00FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF00FF00FF80000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FFFF80000000FF0000FF00FF00
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FFFF80000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF80000000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF00FF8000FF80000000FF0000FF00FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF0000FF000000FF
0000FF00FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF000000FFFF8000FF800000FF0000FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF00FF00
0000FF00FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF000000FF0000FF0000FF
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF000000FF
00FF000000FF00FF0000FF000000FF
00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FFFF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FFFF800000FF0000FF00FF80000000FF
00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
FF80000000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF00
FF000000FF0000FF0000FF000000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
00FF000000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF000000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 1.23734 0.97619 1.4776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .09115 L
.2381 .09115 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .09115 L
.2381 .09115 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .04651 L
.47619 .04651 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .04651 L
.47619 .04651 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .02357 L
.71429 .02357 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .02357 L
.71429 .02357 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .48058 L
.95238 .48058 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .48058 L
.95238 .48058 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF800000FF00FF800000FF0000FF0000FF00FF8000FF8000FF0000
FF8000FF0000FF0000FF00000000FFFF8000FF8000FF8000FF8000FF800000FF00FF8000
FF800000FF00FF000000FF0000FF00FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF0000FF000000FF0000FF00
FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF800000FF000000FF
0000FF0000FFFF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF800000FF000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF0000
00FF0000FF0000FF000000FFFF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF800000FF00FF0000FF0000FF000000FF00FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF0000FF0000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000
00FF000000FFFF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00FF0000FF0000FF0000
FF0000FF0000FF800000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF00
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
00FF00FF8000FF8000FF8000FF80000000FFFF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF800000FF00FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF00FF00000000FF0000FFFF000000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF000000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF00FF8000FF8000FF0000
00FF00FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF0000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF800000FF00
FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF8000FF0000FF0000FF000000FF00FF8000FF800000FF00FF8000FF8000
FF0000FF000000FF0000FF000000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000
FF8000FF8000FF0000FF0000FF800000FF0000FF0000FF000000FF00FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF0000FF8000FF8000FF8000FF8000FF800000FF000000FF00FF00FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF0000FF0000FF000000FF00
FF8000FF0000FF000000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF800000FF00FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF000000FF00FF8000
FF8000FF8000FF8000FF8000FF0000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF0000FF8000
FF8000FF0000FF000000FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF000000FF0000FF0000FF00
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF00FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF000000FF00
FF0000FF000000FF00FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF000000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF800000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF800000FF0000FF00FF800000FF00FF0000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000
0000FF00FF00FF8000FF8000FF0000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF000000FF
FF80000000FFFF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF00FF00FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
0000FFFF0000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF800000FF00
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF80000000FF00FF00
FF800000FF00FF8000FF8000FF800000FF000000FFFF8000FF8000FF8000FF8000FF8000
FF0000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF000000FF0000FF0000FF0000FF0000FF00
FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF800000FF000000FF00FF000000FFFF8000
FF00000000FFFF0000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF0000FF0000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF0000FF8000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF80000000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000
FF8000FF8000FF0000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF0000FF800000FF0000FF00FF800000FF0000FF0000FF000000FFFF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00FF800000FF00FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF0000FF0000FF0000FF0000FF800000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF800000FF00FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF0000
FF0000FF0000FF8000FF8000FF0000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF00000000FF0000FFFF0000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF8000FF8000FF8000
00FF0000FF00FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF000000FF00
0000FF0000FFFF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF800000FF00FF800000FF00FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00
FF8000FF800000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00FF0000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF0000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF0000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000
FF800000FF00FF8000FF8000FF8000FF8000FF800000FF0000FF00FF0000FF0000FF8000
FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF0000FF8000FF8000FF8000
FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 968.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00003b2000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l0
1?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l0
1?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo000OoooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`007ooo
oolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[o
oooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?l5
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo5oooO`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o01go
001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So
001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l00_l007lGool003[o
001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool0
9Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0
>?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl0
1Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003ooooooooo
o`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0h
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Q
ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o00009ooooombo`0002?ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo000Fooooo`L0o`000P3oP00=0?l000030?n0003o0000o`00
01@0o`000`3oP00?0?l00080oh001@3o00050?n001P0o`0000<0oh000?l0003o0000503o00020?n0
00X0o`00103oP00>ooooo`80003o4P00o`020000o`X00?l01P000?l00`3oP000003o0000o`040000
o`<00?l00P000?l2003o00@0003o1@00o`020000o`<00?l01P000?l3003o00@0003o0P00o`030000
o`800?l050000?l3003o01H0003o0`00o`020000o`800?l03_ooool20000o`800?l000<0003o003o
0000o`000P00o`050000o`80oh002`000?l2003o00<0003o0P00o`0M0000o`800?l00`000?l4003o
00030000o`00o`000?l00380003o0P00o`0;0000o`kooooo2@3oP0020?l000h0oh000P3o00020?n0
00<0o`00103oP0020?l000h0oh000P3o00030?n00080o`00103oP0030?l000@0oh000P3o00070?n0
0080o`0000<0oh000000o`000?l01P3oP0000`3o0000oh000?n000040?n00080o`000`3oP0020?l0
0180oh000P3o00000`3oP000o`000?l000020?n00080o`000P3oP0000`3o0000oh000?n000020?n0
01Sooooo000Fooooo`L0o`000P3oP00=0?l000030?n0003o0000o`0001@0o`000`3oP00?0?l00080
oh001@3o00050?n001P0o`0000<0oh000?l0003o0000503o00020?n000X0o`00103oP00>ooooo`80
003o4P00o`020000o`X00?l01P000?l00`3oP000003o0000o`040000o`<00?l00P000?l2003o00@0
003o1@00o`020000o`<00?l01P000?l3003o00@0003o0P00o`030000o`800?l050000?l3003o01H0
003o0`00o`020000o`800?l03_ooool20000o`800?l000<0003o003o0000o`000P00o`050000o`80
oh002`000?l2003o00<0003o0P00o`0M0000o`800?l00`000?l4003o00030000o`00o`000?l00380
003o0P00o`0;0000o`kooooo2@3oP0020?l000h0oh000P3o00020?n000<0o`00103oP0020?l000h0
oh000P3o00030?n00080o`00103oP0030?l000@0oh000P3o00070?n00080o`0000<0oh000000o`00
0?l01P3oP0000`3o0000oh000?n000040?n00080o`000`3oP0020?l00180oh000P3o00000`3oP000
o`000?l000020?n00080o`000P3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`80oh00
6@3o00050?n000@0o`000P3oP00@0?l000<0oh007`3o00020?n000`0o`000P3oP0070?l00080oh00
1@3o00020?n00100o`000P3oP00>ooooo`800?l00P000?l5003o0080003o0P00o`030000o`800?l0
10000?l00`00o`00003o0000o`05003o00d0003o1@00o`020000o`@00?l01`000?l4003o00P0003o
0P00o`060000o`03003o00000?l0003o00800?l050000?l2003o00030000o`00o`000?l001/0003o
3_ooool20000o`D00?l050000?l2003o01/0003o00<00?l00000o`000?l010000?l2003o00<0003o
0P00o`020000o`03003o00000?l0003o00L0003o0P00o`090000o`800?l06@000?l20?n00080003o
00<0oh000?l0003o00002`000?l>ooooo`L0oh000P000?l20?n00080o`003P3oP0070000o`L0oh00
0P3o000B0?n000L0o`001`3oP0020?l000@0oh000`3o00040?n000<0o`000P3oP0040?l000/0oh00
00<0o`000?n0003oP0002`3oP0020?l000L0oh000P3o00050?n001Sooooo000Fooooo`80oh006@3o
00050?n000@0o`000P3oP00@0?l000<0oh007`3o00020?n000`0o`000P3oP0070?l00080oh001@3o
00020?n00100o`000P3oP00>ooooo`800?l00P000?l5003o0080003o0P00o`030000o`800?l01000
0?l00`00o`00003o0000o`05003o00d0003o1@00o`020000o`@00?l01`000?l4003o00P0003o0P00
o`060000o`03003o00000?l0003o00800?l050000?l2003o00030000o`00o`000?l001/0003o3_oo
ool20000o`D00?l050000?l2003o01/0003o00<00?l00000o`000?l010000?l2003o00<0003o0P00
o`020000o`03003o00000?l0003o00L0003o0P00o`090000o`800?l06@000?l20?n00080003o00<0
oh000?l0003o00002`000?l>ooooo`L0oh000P000?l20?n00080o`003P3oP0070000o`L0oh000P3o
000B0?n000L0o`001`3oP0020?l000@0oh000`3o00040?n000<0o`000P3oP0040?l000/0oh0000<0
o`000?n0003oP0002`3oP0020?l000L0oh000P3o00050?n001Sooooo000Fooooo`80oh008P3o0002
0?n000L0o`000P3oP0030?l00080oh002`3o00020?n00200o`000`3oP00=0?l00080oh000`3o0002
0?n000h0o`00103oP00>ooooo`@0003o2@00o`030000o`800?l01`000?l5003o00/0003o1000o`05
0000o`800?l02@000?l2003o00D0003o0P00o`020000o`03003o00000?l0003o00@0003o0P00o`00
0`000?l00?l0003o00040000o`800?l030000?l2003o0080003o0`00o`090000o`800?l01@000?l2
0?n000@0003o0P3oP0050000o`kooooo1`00o`0B0000o`800?l01`000?l2003o00h0003o0P3o0004
0000o`03003o00000?l0003o00/0003o0P3oP0070000o`80oh0000<0o`000000o`000?l01P000?l0
0`00o`00003o0000o`0M0000o`<0oh00103o00040000o`03003o00000?l0003o0080003o3_ooool2
0?n00080o`0000<0oh000000o`000?l00P000?l50?n00080o`001P3oP0000`3o0000oh000?n00002
0?n00080o`0000<0oh000?l0003o00000P3o000@0?n00080o`002`3oP0020?l000D0oh000P3o0003
0?n00080o`001`3oP0020?l000/0oh000P3o00050?n000@0o`0000<0oh000?l0003o00000P3oP002
0?l000<0oh000P3o00070?n000@0o`000P3oP0000`3o0000oh000?n000020?n001Sooooo000Foooo
o`@0oh000`3o00020?n001D0o`000P3oP00=0?l000<0oh001P3o00030?n000@0o`00103oP00R0?l0
00030?n0003o0000o`000080oh002@3o00030?n000H0o`000P3oP00:0?l00080003o0P3oP00>oooo
o`@0003o2@00o`090000o`<00?l00P000?l3003o00T0003o0P00o`060000o`03003o00000?l0003o
00@00?l00`000?l2003o00T0003o0P00o`030000o`800?l00P000?l2003o0080003o0`00o`040000
o`800?l000<0003o003o0000o`001P000?l00`00o`00003o0000o`070000o`800?l05P000?l00`00
o`00003o0000o`02003o00kooooo1`000?l2003o00L0003o103oP0020?l000030?n000000?l0003o
00@0003o00<00?l00000o`000?l040000?l20?n000L0003o1000o`020000o`800?l03P000?l20?n0
00030?l0003oP000oh0000H0003o0`00o`040000o`800?l000<0003o003o0000o`0010000?l2003o
00h0003o0P3o00070?n000800?l01@000?l>ooooo`80oh000P3o00050000oa/0oh000`3o00060?n0
00D0o`00103oP0030?l000H0003o0P3o000:0?n00080003o2@3oP0020?l000D0oh000P3o00040?n0
00030?l0003oP000oh0000@0o`001@3oP0020000o`D0oh00103o00030?n000P0o`001@3oP00Hoooo
o`005_ooool40?n000<0o`000P3oP00E0?l00080oh003@3o00030?n000H0o`000`3oP0040?l000@0
oh008P3o00000`3oP000o`000?l000020?n000T0o`000`3oP0060?l00080oh002P3o00020000o`80
oh003_ooool40000o`T00?l02@000?l3003o0080003o0`00o`090000o`800?l01P000?l00`00o`00
003o0000o`04003o00<0003o0P00o`090000o`800?l00`000?l2003o0080003o0P00o`020000o`<0
0?l010000?l2003o00030000o`00o`000?l000H0003o00<00?l00000o`000?l01`000?l2003o01H0
003o00<00?l00000o`000?l00P00o`0>ooooo`L0003o0P00o`070000o`@0oh000P3o00000`3oP000
003o0000o`040000o`03003o00000?l0003o0100003o0P3oP0070000o`@00?l00P000?l2003o00h0
003o0P3oP0000`3o0000oh000?n000060000o`<00?l010000?l2003o00030000o`00o`000?l000@0
003o0P00o`0>0000o`80o`001`3oP002003o00D0003o3_ooool20?n00080o`001@000?lK0?n000<0
o`001P3oP0050?l000@0oh000`3o00060000o`80o`002P3oP0020000o`T0oh000P3o00050?n00080
o`00103oP0000`3o0000oh000?n000040?l000D0oh000P000?l50?n000@0o`000`3oP0080?l000D0
oh006?ooool001Kooooo0P3oP00@0?l00080oh002P3o00020?n00080o`000P3oP0090?l000<0oh00
203o00000`3oP000o`000?l0000;0?l00080oh0000<0o`000?n0003oP0000P3o00020?n000<0o`00
0P3oP0020?l00080oh001@3o00020?n00180o`000P000?l70?n00080003o2@3o00030?n00080003o
3_ooool40000o`X00?l00P000?l2003o00@0003o4000o`000`000?l00?l0003o00020000o`800?l0
0P000?l00`00o`00003o0000o`04003o00<0003o0P00o`040000o`800?l000<0003o003o0000o`00
0P00o`030000o`800?l00P000?l2003o0080003o00<00?l00000o`000?l010000?l2003o00<0003o
0P00o`020000o`800?l01`000?l3003o0080003o0P00o`0<0000o`80oh002`000?l>ooooo`@0003o
00<00?l00000o`000?l00P00o`090000o`D0oh001`000?l2003o00H0003o00<0oh000000o`000?l0
0P00o`070000o`80o`0010000?l00`00o`00003o0000o`040000o`800?l030000?l70?n000H0003o
00<00?l00000o`000?l080000?l20?l00080oh002@000?l>ooooo`/0oh000P3o00000`3oP000o`00
0?l000020?l00080oh000P3o00000`3oP000003o0000o`0D0?n00080o`003P3oP0020?l000<0oh00
103o00020?n000D0o`008P3oP0020000o`80oh0000<0o`000?n0003oP000103o00090?n00080o`00
1@3oP00Hooooo`005_ooool20?n00100o`000P3oP00:0?l00080oh000P3o00020?n000T0o`000`3o
P0080?l000030?n0003o0000o`0000/0o`000P3oP0000`3o0000oh000?n000020?l00080oh000`3o
00020?n00080o`000P3oP0050?l00080oh004P3o00020000o`L0oh000P000?l90?l000<0oh000P00
0?l>ooooo`@0003o2P00o`020000o`800?l010000?l@003o00030000o`00o`000?l00080003o0P00
o`020000o`03003o00000?l0003o00@00?l00`000?l2003o00@0003o0P00o`000`000?l00?l0003o
0002003o00<0003o0P00o`020000o`800?l00P000?l00`00o`00003o0000o`040000o`800?l00`00
0?l2003o0080003o0P00o`070000o`<00?l00P000?l2003o00`0003o0P3oP00;0000o`kooooo1000
0?l00`00o`00003o0000o`02003o00T0003o1@3oP0070000o`800?l01P000?l00`3oP000003o0000
o`02003o00L0003o0P3o00040000o`03003o00000?l0003o00@0003o0P00o`0<0000o`L0oh001P00
0?l00`00o`00003o0000o`0P0000o`80o`000P3oP0090000o`kooooo2`3oP0020?l000030?n0003o
0000o`000080o`000P3oP0020?l000030?n000000?l0003o01@0oh000P3o000>0?n00080o`000`3o
P0040?l00080oh001@3o000R0?n00080003o0P3oP0000`3o0000oh000?n000040?l000T0oh000P3o
00050?n001Sooooo000Fooooo`T0o`000P3oP0050?l00080oh002@3o00020?n000030?l0003oP000
oh0000@0oh001@3o00060?n000L0o`000`3oP0090?l00080oh000P3o00050?n000H0o`000`3oP002
0?l00080oh005@3o00020?n00080o`000P3oP0030?l00080oh0010000?l00`3oP000o`000?l00006
0?l000<0oh000P000?l>ooooo`80003o4000o`020000o`h00?l00P000?l7003o00@0003o00<00?l0
0000o`000?l01000o`020000o`03003o00000?l0003o0080003o1000o`000`000?l00?l0003o0002
003o00L0003o0P00o`030000o`800?l02@000?l2003o00L0003o0P00o`070000o`800?l00P000?l0
0`00o`00003o0000o`060000o`<0oh002`000?l>ooooo`800?l00P000?l00`00o`00003o0000o`09
0000o`80oh000P000?l30?n00280003o0P00o`040000o`800?l030000?l40?n000030000o`3oP000
oh000180003o0P00o`0<0000o`@00?l04P000?l>ooooo`80o`000`3oP0040?l000/0oh000`3o0002
0000o`L0oh000P3o00020?n00080003o1`3oP0020?l000T0oh000`3o00020?n00080o`000P3oP000
0`3o0000oh000?n000050?n00080o`001P3oP0000`3o0000oh000?n000020?l00080oh000P3o0003
0?n00080003o103oP0000`3o0000003o0000o`040?n00080o`000`3oP0020000oa00oh000P3o0007
0?n001Sooooo000Fooooo`T0o`000P3oP0050?l00080oh002@3o00020?n000030?l0003oP000oh00
00@0oh001@3o00060?n000L0o`000`3oP0090?l00080oh000P3o00050?n000H0o`000`3oP0020?l0
0080oh005@3o00020?n00080o`000P3oP0030?l00080oh0010000?l00`3oP000o`000?l000060?l0
00<0oh000P000?l>ooooo`80003o4000o`020000o`h00?l00P000?l7003o00@0003o00<00?l00000
o`000?l01000o`020000o`03003o00000?l0003o0080003o1000o`000`000?l00?l0003o0002003o
00L0003o0P00o`030000o`800?l02@000?l2003o00L0003o0P00o`070000o`800?l00P000?l00`00
o`00003o0000o`060000o`<0oh002`000?l>ooooo`800?l00P000?l00`00o`00003o0000o`090000
o`80oh000P000?l30?n00280003o0P00o`040000o`800?l030000?l40?n000030000o`3oP000oh00
0180003o0P00o`0<0000o`@00?l04P000?l>ooooo`80o`000`3oP0040?l000/0oh000`3o00020000
o`L0oh000P3o00020?n00080003o1`3oP0020?l000T0oh000`3o00020?n00080o`000P3oP0000`3o
0000oh000?n000050?n00080o`001P3oP0000`3o0000oh000?n000020?l00080oh000P3o00030?n0
0080003o103oP0000`3o0000003o0000o`040?n00080o`000`3oP0020000oa00oh000P3o00070?n0
01Sooooo000Foooooa80o`000P3oP0050?l00080oh000P3o00070?n000L0o`000P3oP0020?l00003
0?n0003o0000o`000080o`00103oP0070?l00080oh000`3o00020?n00080o`000`3oP00;0?l00080
oh000`3o00020?n00080o`000P3oP00I0?l000<0oh00103o00020?n00080003o0`3oP0020?l000ko
oooo1000o`000`000?l00?l0003o00020000oa/00?l00`000?l2003o00@0003o0`00o`020000o`@0
0?l00P000?l00`00o`00003o0000o`040000o`800?l00`000?l2003o0080003o0`00o`060000o`<0
0?l010000?l2003o00030000o`00o`000?l000800?l010000?l00`00o`00003o0000o`090000o`80
0?l00P000?l3003o00T0003o0P00o`090000o`kooooo0P00o`020000o`03003o00000?l0003o0080
0?l0:@000?l2003o00@0003o00<0oh000?l0003o00004P000?l20?l000D0oh000P000?l20?l001/0
003o00<00?l00000o`000?l00P00o`090000o`800?l01`000?l>ooooo`@0oh0000<0o`000?n0003o
P0000P3o000=0?n000<0o`000P3oP0020000o`<0oh000P3o00040?n000030?l0003oP000oh0000l0
oh001@3o000<0?n00080o`002@3oP0020?l000h0oh000P000?lG0?n00080003o2`3oP00Hooooo`00
5_ooool90?l00080oh00303o00020?n00080o`000P3oP0030?l000@0oh001@3o00040?n000T0o`00
0P3oP00J0?l000@0oh002`3o00020?n000T0o`0000<0oh000?l0003o00002@3o00040?n000T0o`00
00<0003o0?n0003oP0000P3o000>oooooa800?l00P000?l3003o0080003o5000o`020000o`03003o
00000?l0003o00T00?l01P000?l00`00o`00003o0000o`02003o0080003o0`00o`070000o`800?l0
10000?l2003o00030000o`00o`000?l000L00?l00P000?l2003o00@0003o00<00?l00000o`000?l0
0P00o`030000o`@00?l010000?l00`00o`00003o0000o`02003o00T0003o3_ooool50000o`800?l0
5`000?l2003o01/0003o0P3oP00>0000o`@0o`000`3oP00;0000o`80oh007@000?l00`00o`00003o
0000o`0;0000o`kooooo103oP0000`3o0000oh000?n000020?l00080oh000P3o000>0?n00080o`00
4P3oP0000`000?l0oh000?n000020000o`80oh000P3o00000`3oP000o`000?l000040?n000D0o`00
1`3oP0020?l001H0oh000`000?l20?n00080o`002@3oP0030?l00080oh000P3o00030?n00080003o
0P3o00090?n001Sooooo000Fooooo`T0o`000P3oP00<0?l00080oh000P3o00020?n000<0o`00103o
P0050?l000@0oh002@3o00020?n001X0o`00103oP00;0?l00080oh002@3o00000`3oP000o`000?l0
00090?l000@0oh002@3o00000`000?l0oh000?n000020?l000kooooo4P00o`020000o`<00?l00P00
0?lD003o0080003o00<00?l00000o`000?l02@00o`060000o`03003o00000?l0003o00800?l00P00
0?l3003o00L0003o0P00o`040000o`800?l000<0003o003o0000o`001`00o`020000o`800?l01000
0?l00`00o`00003o0000o`02003o00<0003o1000o`040000o`03003o00000?l0003o00800?l02@00
0?l>ooooo`D0003o0P00o`0G0000o`800?l06`000?l20?n000h0003o103o00030?n000/0003o0P3o
P00M0000o`03003o00000?l0003o00/0003o3_ooool40?n000030?l0003oP000oh000080o`000P3o
P0020?l000h0oh000P3o000B0?n000030000o`3oP000oh000080003o0P3oP0020?l000030?n0003o
0000o`0000@0oh001@3o00070?n00080o`005P3oP0030000o`80oh000P3o00090?n000<0o`000P3o
P0020?l000<0oh000P000?l20?l000T0oh006?ooool001Kooooo3@3o00030?n00100o`000P3oP009
0?l00080oh002@3o00020?n000L0o`000P3oP0080?l00080oh002@3o00020?n00100o`000P3oP00B
0?l00080oh003P3o000>oooooaH00?l00`000?l;003o00<0003o1P00o`020000o`03003o00000?l0
003o00@00?l00`000?l2003o00T0003o0P00o`030000o`800?l03@000?l2003o00030000o`00o`00
0?l000H00?l00`000?l2003o0080003o1`00o`020000o`<00?l010000?l2003o00030000o`00o`00
0?l000800?l010000?l00`00o`00003o0000o`02003o00kooooo0P00o`050000o`800?l0:`000?l2
003o00<0003o1P3oP00>0000o`80oh000P3o00000`3oP000003o0000o`0O0000o`03003o00000?l0
003o00d0003o0P00o`050000o`kooooo3P3oP0020000o`@0oh000P3o00080?n000@0o`00103oP000
0`3o0000oh000?n000060?n000030?l0003oP000oh000080003o0P3oP0020?l000<0oh000P3o0004
0?n000030?l0003oP000oh0000/0oh001`3o00050?n00080o`001`3oP0020?l000@0oh000`3o000=
0?n00080o`001`000?l70?n001Sooooo000Fooooo`d0o`000`3oP00@0?l00080oh002@3o00020?n0
00T0o`000P3oP0070?l00080oh00203o00020?n000T0o`000P3oP00@0?l00080oh004P3o00020?n0
00h0o`003_oooolF003o00<0003o2`00o`030000o`H00?l00P000?l00`00o`00003o0000o`04003o
00<0003o0P00o`090000o`800?l00`000?l2003o00d0003o0P00o`000`000?l00?l0003o0006003o
00<0003o0P00o`020000o`L00?l00P000?l3003o00@0003o0P00o`000`000?l00?l0003o0002003o
00@0003o00<00?l00000o`000?l00P00o`0>ooooo`800?l01@000?l2003o02/0003o0P00o`030000
o`H0oh003P000?l20?n00080o`0000<0oh000000o`000?l07`000?l00`00o`00003o0000o`0=0000
o`800?l01@000?l>ooooo`h0oh000P000?l40?n00080o`00203oP0040?l000@0oh0000<0o`000?n0
003oP0001P3oP0000`3o0000oh000?n000020000o`80oh000P3o00030?n00080o`00103oP0000`3o
0000oh000?n0000;0?n000L0o`001@3oP0020?l000L0oh000P3o00040?n000<0o`003@3oP0020?l0
00L0003o1`3oP00Hooooo`005_ooool20?n000T0o`000P3oP0000`3o0000oh000?n000020?l00080
oh00803o00040?n000X0o`000P3oP0070?l00080oh000P3o00070?n00100o`000P3oP00M0?l00003
0?n0003o0000o`000080o`003_oooolD003o00<0003o2@00o`040000o`<00?l00P000?l7003o00H0
003o0P00o`000`000?l00?l0003o00060000o`03003o00000?l0003o0080003o0P00o`0B0000o`03
003o00000?l0003o0080003o0P00o`020000o`X00?l00P000?l2003o0080003o00<00?l00000o`00
0?l00P00o`0@0000o`800?l03_oooolB0000o`800?l00P000?l00`00o`00003o0000o`02003o0280
003o0P3oP00>0000o`L0oh00:@000?l2003o0080003o1000o`050000o`kooooo0P3o00020?n00003
0?l0003oP000oh0000H0oh000`000?lF0?n000030?l0003oP000oh0001@0oh00103o00050?n000L0
o`002@3oP0050?l000P0oh0000<0003o0?l0003o0000103oP0030?l000@0oh000P000?l50?n00080
o`000P3oP0000`000?l0oh000?n000020000o`80oh000`000?l20?n00080o`006?ooool001Kooooo
0P3oP0090?l00080oh0000<0o`000?n0003oP0000P3o00020?n00200o`00103oP00:0?l00080oh00
1`3o00020?n00080o`001`3oP00@0?l00080oh007@3o00000`3oP000o`000?l000020?l000kooooo
5000o`030000o`T00?l010000?l3003o0080003o1`00o`060000o`800?l000<0003o003o0000o`00
1P000?l00`00o`00003o0000o`020000o`800?l04P000?l00`00o`00003o0000o`020000o`800?l0
0P000?l:003o0080003o0P00o`020000o`03003o00000?l0003o00800?l040000?l2003o00kooooo
4P000?l2003o0080003o00<00?l00000o`000?l00P00o`0R0000o`80oh003P000?l70?n002T0003o
0P00o`020000o`@00?l01@000?l>ooooo`80o`000P3oP0000`3o0000oh000?n000060?n000<0003o
5P3oP0000`3o0000oh000?n0000D0?n000@0o`001@3oP0070?l000T0oh001@3o00080?n000030000
o`3o0000o`0000@0oh000`3o00040?n00080003o1@3oP0020?l00080oh0000<0003o0?n0003oP000
0P000?l20?n000<0003o0P3oP0020?l001Sooooo000Fooooo`T0o`000P3oP0050?l00080oh00103o
00000`3oP000o`000?l0000]0?l00080oh002@3o00000`3oP000o`000?l000040?n001D0o`000P3o
P0070?l00080003o103oP0070?l000<0oh00103o000>ooooo`@0003o0`00o`060000o`D00?l01000
0?l00`00o`00003o0000o`09003o00@0003o00<00?l00000o`000?l00P000?l;003o00D0003o0P00
o`020000o`800?l01@000?l2003o0100003o0P00o`030000o`800?l00P000?l3003o0080003o1`00
o`040000o`D00?l010000?l2003o00T0003o00<0oh00003o0000o`000P000?l>ooooo`@0003o00<0
0?l00000o`000?l00P000?l2003o00L0003o0P00o`030000o`800?l02@000?l2003o01@0003o00<0
0?l00000o`000?l00P000?l2003o00T0003o00<00?l00000o`000?l03@000?l2003o00<0003o0P00
o`0D0000o`03003o00000?l0003o00800?l01@000?l6003o00L0003o3_ooool=0?n000<0003o103o
00030?n000@0003o0`3o00080?n000L0o`001`3oP0040?l000030?n0003o0000o`000080o`000P3o
P0030?l000@0oh000P3o00050?n00080o`000P3oP0000`3o0000oh000?n000020?n00080003o0P3o
00070?n000<0003o0P3o000;0?n00080003o0`3o00060?n000030000o`3oP000oh000080003o0P3o
P0050000o`80oh006?ooool001Kooooo2@3o00020?n000D0o`000P3oP0040?l000030?n0003o0000
o`0002d0o`000P3oP0090?l000030?n0003o0000o`0000@0oh005@3o00020?n000L0o`000P000?l4
0?n000L0o`000`3oP0040?l000kooooo10000?l3003o00H0003o1@00o`040000o`03003o00000?l0
003o00T00?l010000?l00`00o`00003o0000o`020000o`/00?l01@000?l2003o0080003o0P00o`05
0000o`800?l040000?l2003o00<0003o0P00o`020000o`<00?l00P000?l7003o00@0003o1@00o`04
0000o`800?l02@000?l00`3oP0000?l0003o00020000o`kooooo10000?l00`00o`00003o0000o`02
0000o`800?l01`000?l2003o00<0003o0P00o`090000o`800?l050000?l00`00o`00003o0000o`02
0000o`800?l02@000?l00`00o`00003o0000o`0=0000o`800?l00`000?l2003o01@0003o00<00?l0
0000o`000?l00P00o`050000o`H00?l01`000?l>ooooo`d0oh000`000?l40?l000<0oh0010000?l3
0?l000P0oh001`3o00070?n000@0o`0000<0oh000?l0003o00000P3o00020?n000<0o`00103oP002
0?l000D0oh000P3o00020?n000030?l0003oP000oh000080oh000P000?l20?l000L0oh000`000?l2
0?l000/0oh000P000?l30?l000H0oh0000<0003o0?n0003oP0000P000?l20?n000D0003o0P3oP00H
ooooo`005_ooool20?n00100o`000P3oP0050?l00080oh00403o00040?n00280o`0000<0oh000?l0
003o00003@3o00020?n000X0o`000P3oP0070?l00080oh000P3o00020?n000L0o`000`000?l20?n0
0080o`003_ooool2003o00/0003o2@00o`000`000?l00?l0003o0002003o0080003o0`00o`090000
o`@00?l00P000?l7003o00<0003o0P00o`0;0000o`800?l000<0003o003o0000o`002@000?l2003o
0100003o2@00o`050000o`800?l01P000?l00`00o`00003o0000o`02003o00T0003o3_ooool90000
o`800?l01`000?l2003o00h0003o0P00o`0@0000o`800?l01@000?l6003o01D0003o0P00o`030000
o`800?l02@000?l2003o0080003o0P00o`000`000?l00?l0003o00020000o`800?l000<0003o003o
0000o`000P000?l2003o00L0003o0P00o`050000o`800?l03_ooool50?l000P0oh000`000?l20?n0
0080o`000`3oP0040000o`80o`001@3oP0020?l001L0oh000P3o00020?n000<0o`002@3oP0020?l0
0100oh000P3o00040?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP0020?l0
00030000o`3oP000oh0000H0oh001`000?l30?n000@0o`006?ooool001Kooooo0P3oP0070?l00080
oh004P3o00000`3oP000o`000?l000020?l00080003o0`3oP0040?l00080003o4P3o00020?n000h0
o`000`3oP0040?l00080oh001`3o00020?n000<0o`000P3oP00;0?l00080oh00403o00030?n000@0
o`003_ooool50000o`800?l00P000?l4003o00030000o`00o`000?l001800?l010000?l00`00o`00
003o0000o`0;003o0080003o0P00o`000`000?l00?l0003o000@0000o`800?l01`000?l2003o00@0
003o0`00o`060000o`03003o00000?l0003o00T00?l03P000?l4003o00D0003o0P3oP0020000o`ko
oooo0P000?l2003o00030000o`00o`000?l000/0003o0P00o`0>0000o`800?l05@000?l2003o0080
003o1000o`0E0000o`800?l00P000?l00`00o`00003o0000o`020000o`800?l00`000?l2003o00T0
003o0P00o`020000o`03003o00000?l0003o00T0003o0P00o`050000o`80oh000P3o000>ooooo`D0
oh00103o00020000o`D0oh00103o00030?n00080003o0P3oP0050000o`80oh001@3o00020?n000H0
o`00703oP0040?l000`0oh000P3o00070?n00080o`000P3oP0020?l000<0oh000P3o00070?n00080
003o0P3oP0030000o`80oh000P3o00050?n00080o`000P3oP00Hooooo`005_ooool20?n000L0o`00
0P3oP00B0?l000030?n0003o0000o`000080o`000P000?l30?n000@0o`000P000?lB0?l00080oh00
3P3o00030?n000@0o`000P3oP0070?l00080oh000`3o00020?n000/0o`000P3oP00@0?l000<0oh00
103o000>ooooo`D0003o0P00o`020000o`@00?l000<0003o003o0000o`004P00o`040000o`03003o
00000?l0003o00/00?l00P000?l2003o00030000o`00o`000?l00100003o0P00o`070000o`800?l0
10000?l3003o00H0003o00<00?l00000o`000?l02@00o`0>0000o`@00?l01@000?l20?n00080003o
3_ooool20000o`800?l000<0003o003o0000o`002`000?l2003o00h0003o0P00o`0E0000o`800?l0
0P000?l4003o01D0003o0P00o`020000o`03003o00000?l0003o0080003o0P00o`030000o`800?l0
2@000?l2003o0080003o00<00?l00000o`000?l02@000?l2003o00D0003o0P3oP0020?l000kooooo
1@3oP0040?l00080003o1@3oP0040?l000<0oh000P000?l20?n000D0003o0P3oP0050?l00080oh00
1P3o000L0?n000@0o`00303oP0020?l000L0oh000P3o00020?n00080o`000`3oP0020?l000L0oh00
0P000?l20?n000<0003o0P3oP0020?l000D0oh000P3o00020?n001Sooooo000Fooooo`80oh00303o
00020?n00080o`000P3oP00>0?l00080oh000P3o00000`3oP000o`000?l000040?n000h0o`000P3o
P0040?l000030?n0003o0000o`0001@0o`000P3oP0050?l00080oh00803o00020?n000L0o`003_oo
ool20000o`800?l000<0003o003o0000o`000P000?l2003o0080003o00<00?l00000o`000?l01000
o`050000o`800?l00P000?l5003o00D0003o0P00o`020000o`/00?l00P000?l00`00o`00003o0000
o`020000o`@00?l01@000?l3003o00P0003o0`00o`060000o`03003o00000?l0003o00H0003o00<0
0?l00000o`000?l00P000?l7003o00@0003o00<00?l00000o`000?l01P000?l3003o00/0003o3_oo
oolK0000o`800?l01`000?l2003o01<0003o1P00o`090000o`03003o00000?l0003o00d0003o0`00
o`040000o`800?l00`000?l2003o00T0003o0P00o`0<0000o`H00?l01`000?l>oooooa@0oh000P3o
00050?n00080003o0`3oP0070?l00080oh000P3o00070?n00080o`002@3oP0020?l000T0oh0000<0
o`000?n0003oP0001P3oP0000`3o0000oh000?n000070?n00080o`001`3oP0020?l000@0oh000`3o
00090?n00080o`000P3oP0030000o`80oh00103o00070?n001Sooooo000Fooooo`80oh00303o0002
0?n00080o`000P3oP00>0?l00080oh000P3o00000`3oP000o`000?l000040?n000h0o`000P3oP004
0?l000030?n0003o0000o`0001@0o`000P3oP0050?l00080oh00803o00020?n000L0o`003_ooool2
0000o`800?l000<0003o003o0000o`000P000?l2003o0080003o00<00?l00000o`000?l01000o`05
0000o`800?l00P000?l5003o00D0003o0P00o`020000o`/00?l00P000?l00`00o`00003o0000o`02
0000o`@00?l01@000?l3003o00P0003o0`00o`060000o`03003o00000?l0003o00H0003o00<00?l0
0000o`000?l00P000?l7003o00@0003o00<00?l00000o`000?l01P000?l3003o00/0003o3_oooolK
0000o`800?l01`000?l2003o01<0003o1P00o`090000o`03003o00000?l0003o00d0003o0`00o`04
0000o`800?l00`000?l2003o00T0003o0P00o`0<0000o`H00?l01`000?l>oooooa@0oh000P3o0005
0?n00080003o0`3oP0070?l00080oh000P3o00070?n00080o`002@3oP0020?l000T0oh0000<0o`00
0?n0003oP0001P3oP0000`3o0000oh000?n000070?n00080o`001`3oP0020?l000@0oh000`3o0009
0?n00080o`000P3oP0030000o`80oh00103o00070?n001Sooooo000Fooooo`80oh001@3o00020?n0
0180o`000P3oP00E0?l00080003o0P3o00020?n000X0o`000P3oP00P0?l000@0oh000P3o00030?n0
00H0o`0000<0oh000?l0003o00002`3o00020?n000L0o`003_ooool7003o00@0003o0P00o`000`00
0?l00?l0003o0006003o00<0003o0P00o`030000o`@00?l01@000?l2003o0080003o3@00o`050000
o`800?l02P000?l2003o00@0003o0P00o`000`000?l00?l0003o00040000o`800?l01@000?l2003o
00L0003o1@00o`060000o`03003o00000?l0003o0080003o0P00o`0;0000o`03003o00000?l0003o
00800?l03_ooool50000o`800?l010000?l2003o00X0003o0P00o`070000o`800?l00P000?l2003o
01D0003o1000o`030000o`800?l010000?l00`00o`00003o0000o`0h0000o`800?l01@000?l>oooo
o`80003o0`3oP0020?l000H0oh0000<0o`000?n0003oP0000P3o00020?n00080o`001`3oP0030?l0
00@0oh000P3o00030?n00080003o0P3oP0020?l000X0oh000P3o00020?n00080o`000P3oP0030?l0
00D0oh000P3o000?0?n000030?l0003oP000oh0000L0oh00103o00090?n00080o`001`3oP0020?l0
00030000o`3oP000oh0000@0oh000P3o00050?n001Sooooo000Fooooo`80oh001@3o00020?n00180
o`000P3oP00E0?l00080003o0P3o00020?n000X0o`000P3oP00P0?l000@0oh000P3o00030?n000H0
o`0000<0oh000?l0003o00002`3o00020?n000L0o`003_ooool7003o00@0003o0P00o`000`000?l0
0?l0003o0006003o00<0003o0P00o`030000o`@00?l01@000?l2003o0080003o3@00o`050000o`80
0?l02P000?l2003o00@0003o0P00o`000`000?l00?l0003o00040000o`800?l01@000?l2003o00L0
003o1@00o`060000o`03003o00000?l0003o0080003o0P00o`0;0000o`03003o00000?l0003o0080
0?l03_ooool50000o`800?l010000?l2003o00X0003o0P00o`070000o`800?l00P000?l2003o01D0
003o1000o`030000o`800?l010000?l00`00o`00003o0000o`0h0000o`800?l01@000?l>ooooo`80
003o0`3oP0020?l000H0oh0000<0o`000?n0003oP0000P3o00020?n00080o`001`3oP0030?l000@0
oh000P3o00030?n00080003o0P3oP0020?l000X0oh000P3o00020?n00080o`000P3oP0030?l000D0
oh000P3o000?0?n000030?l0003oP000oh0000L0oh00103o00090?n00080o`001`3oP0020?l00003
0000o`3oP000oh0000@0oh000P3o00050?n001Sooooo000Fooooo`D0oh00203o00030?n00080o`00
0P3oP0050?l000@0oh0000<0o`000?n0003oP000103o00020?n002/0o`0000<0oh000?l0003o0000
9P3o00020?n000D0o`000P3oP0070?l000kooooo1000o`000`000?l00?l0003o00040000o`800?l0
00<0003o003o0000o`001`00o`020000o`800?l02@000?l@003o00@0003o00<00?l00000o`000?l0
1`000?l2003o00h0003o0P00o`020000o`800?l040000?l4003o00030000o`00o`000?l000800?l0
0P000?l00`00o`00003o0000o`0?0000o`<00?l00P000?l>ooooo`T0003o0P3oP0020?l000`0003o
1000o`030000o`800?l040000?l2003o00L0003o1000o`090000o`03003o00000?l0003o01H0003o
0P00o`0W0000o`kooooo0P000?l20?l00100oh000`3o000=0?n00080o`001`3oP0020?l000D0oh00
103o00090?n000<0003o103oP0000`000?l0oh000?n000040?n00080003o00<0oh000?l0003o0000
0P3o00050?n00080003o0P3o00070?n00080o`001@3oP0020?l000L0oh000P3o00020?n000L0o`00
2@3oP00Hooooo`005_ooool50?n000P0o`000`3oP0020?l00080oh001@3o00040?n000030?l0003o
P000oh0000@0o`000P3oP00[0?l000030?n0003o0000o`0002H0o`000P3oP0050?l00080oh001`3o
000>ooooo`@00?l000<0003o003o0000o`0010000?l2003o00030000o`00o`000?l000L00?l00P00
0?l2003o00T0003o4000o`040000o`03003o00000?l0003o00L0003o0P00o`0>0000o`800?l00P00
0?l2003o0100003o1000o`000`000?l00?l0003o0002003o0080003o00<00?l00000o`000?l03`00
0?l3003o0080003o3_ooool90000o`80oh000P3o000<0000o`@00?l00`000?l2003o0100003o0P00
o`070000o`@00?l02@000?l00`00o`00003o0000o`0F0000o`800?l09`000?l>ooooo`80003o0P3o
000@0?n000<0o`003@3oP0020?l000L0oh000P3o00050?n000@0o`002@3oP0030000o`@0oh0000<0
003o0?n0003oP000103oP0020000o`030?n0003o0000o`000080o`001@3oP0020000o`80o`001`3o
P0020?l000D0oh000P3o00070?n00080o`000P3oP0070?l000T0oh006?ooool001Kooooo0P3o0002
0?n000`0o`001P3oP00<0?l00080oh005`3o00040?n000T0o`0000<0oh000?l0003o00000P3o0004
0?n000<0o`000P3oP00@0?l00080oh00103o00000`3oP000o`000?l000090?l000L0oh000P3o0002
0?n000<0o`000P3oP0020?l000kooooo5`00o`020000o`@00?l00`000?l2003o00@0003o4000o`02
0000o`03003o00000?l0003o00@0003o0P00o`000`000?l00?l0003o00040000o`<00?l06@000?l2
003o00@0oh000P3o00030000o`800?l00P000?l00`00o`00003o0000o`0@0000o`@00?l03_ooool=
0000o`030?n000000?l0003o00T0003o0P00o`0I0000o`800?l04P000?l3003o00l0003o00<00?l0
0000o`000?l00P00o`0E0000o`800?l01P000?l00`00o`00003o0000o`070000o`800?l00P000?l>
ooooo`80003o0P3oP0000`3o0000oh000?n000020?n00080o`000`3oP0040?l00080oh000P3o0003
0?n000D0o`001P3oP0020?l000030000o`3o0000o`000080o`005P3oP0050000o`80oh0000<0003o
0?n0003oP000103oP0020?l000L0oh000P3o00000`3oP000003o0000o`0?0?n000030?l0003oP000
oh0000@0oh0000<0o`000?n0003oP0001`3oP0020000o`80o`002@3oP00Hooooo`005_ooool20?l0
0080oh0000<0o`000?n0003oP000103oP0050?l00080oh00403o00020000o`80o`0000<0oh000?l0
003o00000P3o00020?n001`0o`000P3oP0090?l00080oh000P3o00020?n000`0o`000P3oP0050?l0
0080oh002`3o00020?n000T0o`0000<0oh000?l0003o00000P3o000>ooooo`D00?l00P000?lG003o
00@0003o0P00o`020000o`h00?l01@000?l2003o00T0003o0P00o`030000o`800?l01`000?l2003o
0080003o0P00o`020000o`03003o00000?l0003o0080003o0P00o`030000o`800?l00P000?l20?n0
0080003o00<0oh00003o0000o`002@00o`020000o`800?l00`000?l2003o0080003o0P00o`030000
o`800?l03_ooool2003o00/0003o00<0oh000000o`000?l01`000?l2003o00D0003o0P00o`070000
o`80o`00103oP00<0000o`800?l040000?l40?n00080o`000`000?l20?l000800?l00`000?l2003o
00d0003o0P00o`0>0000o`800?l02P000?l2003o0080003o3_ooool40000o`<0oh000P3o00050?n0
0080o`002`3oP0030?l000@0oh000P000?l20?n000030000o`3oP000oh0000T0oh000P3o000;0?n0
00D0003o503oP0050000o`80oh000P3o00030?n000@0o`00103oP0000`3o0000oh000?n000020?n0
0080003o00<0oh000?l0003o00001`3oP0060000o`80oh000`3o00020?n001Sooooo000Fooooo`80
o`000P3oP0000`3o0000oh000?n000040?n000D0o`000P3oP00@0?l00080003o0P3o00000`3oP000
o`000?l000020?l00080oh00703o00020?n000T0o`000P3oP0020?l00080oh00303o00020?n000D0
o`000P3oP00;0?l00080oh002@3o00000`3oP000o`000?l000020?l000kooooo1@00o`020000oaL0
0?l010000?l2003o0080003o3P00o`050000o`800?l02@000?l2003o00<0003o0P00o`070000o`80
0?l00P000?l2003o0080003o00<00?l00000o`000?l00P000?l2003o00<0003o0P00o`020000o`80
oh000P000?l00`3oP0000?l0003o0009003o0080003o0P00o`030000o`800?l00P000?l2003o00<0
003o0P00o`0>ooooo`800?l02`000?l00`3oP000003o0000o`070000o`800?l01@000?l2003o00L0
003o0P3o00040?n000`0003o0P00o`0@0000o`@0oh000P3o00030000o`80o`000P00o`030000o`80
0?l03@000?l2003o00h0003o0P00o`0:0000o`800?l00P000?l>ooooo`@0003o0`3oP0020?l000D0
oh000P3o000;0?n000<0o`00103oP0020000o`80oh0000<0003o0?n0003oP0002@3oP0020?l000/0
oh001@000?lD0?n000D0003o0P3oP0020?l000<0oh00103o00040?n000030?l0003oP000oh000080
oh000P000?l00`3oP000o`000?l000070?n000H0003o0P3oP0030?l00080oh006?ooool001Kooooo
1@3o00040?n00080o`000P3oP0050?l00080oh00403o00020?n000<0o`00103oP0090?l00080oh00
9`3o00020?n001D0o`000P3oP0020?l00080oh001@3o00020?n00080o`0000<0oh000?l0003o0000
0P3o000>ooooo`D00?l00P000?lP003o0080003o2`00o`040000o`03003o00000?l0003o00/0003o
0P00o`000`000?l00?l0003o0002003o0080003o0P00o`000`000?l00?l0003o0004003o00L0003o
0P00o`050000o`80oh000P000?l30?n000l00?l000<0003o003o0000o`000P000?l2003o0080003o
1@00o`0>ooooo`800?l04P000?l2003o00030000o`00o`000?l000h0003o0P3oP0040?l00080oh00
:@000?l2003o00030000o`00o`000?l00100003o0P00o`040000o`03003o00000?l0003o00@0003o
0P00o`050000o`80o`001`000?l>ooooo`@0003o3P3oP0040?l000L0oh0000<0o`000?n0003oP000
0P3oP0020000o`80oh0000<0o`000?n0003oP0000P3o00020?n000<0o`000P3oP0020?l000d0oh00
00<0o`000?n0003oP0003@3oP0000`3o0000oh000?n000040?n000D0003o103oP0020?l000D0oh00
0P3o00020?n000030?l0003oP000oh000080o`000P3oP00@0000o`80oh0000<0003o0?n0003oP000
0P3oP00Hooooo`005_ooool50?l000@0oh000P3o00020?n000D0o`000P3oP00@0?l00080oh000`3o
00040?n000T0o`000P3oP00W0?l00080oh005@3o00020?n00080o`000P3oP0050?l00080oh000P3o
00000`3oP000o`000?l000020?l000kooooo1@00o`020000ob000?l00P000?l;003o00@0003o00<0
0?l00000o`000?l02`000?l2003o00030000o`00o`000?l000800?l00P000?l2003o00030000o`00
o`000?l000@00?l01`000?l2003o00D0003o0P3oP0020000o`<0oh003`00o`000`000?l00?l0003o
00020000o`800?l00P000?l5003o00kooooo0P00o`0B0000o`800?l000<0003o003o0000o`003P00
0?l20?n000@0o`000P3oP00Y0000o`800?l000<0003o003o0000o`0040000?l2003o00@0003o00<0
0?l00000o`000?l010000?l2003o00D0003o0P3o00070000o`kooooo10000?l>0?n000@0o`001`3o
P0000`3o0000oh000?n000020?n00080003o0P3oP0000`3o0000oh000?n000020?l00080oh000`3o
00020?n00080o`003@3oP0000`3o0000oh000?n0000=0?n000030?l0003oP000oh0000@0oh001@00
0?l40?n00080o`001@3oP0020?l00080oh0000<0o`000?n0003oP0000P3o00020?n00100003o0P3o
P0000`000?l0oh000?n000020?n001Sooooo000Fooooo`L0o`000P3oP0040?l000L0oh001`3o0002
0?n002T0o`000`3oP0060?l00080oh0000<0o`000?n0003oP000<@3o00000`3oP000o`000?l00002
0?l000kooooo1`00o`020000oaD00?l00P000?l2003o0080003o4000o`040000o`03003o00000?l0
003o0080003o0P00o`030000o`800?l00P000?l5003o00@0003o0P00o`000`000?l00?l0003o0004
003o00T0003o0P00o`0<0000o`800?l00`000?l2003o00@0003o0P00o`050000o`800?l00`000?l2
003o0080003o3_ooool20000o`800?l000<0003o003o0000o`000P00o`050000o`800?l00P000?l2
003o01<0003o103oP0020?l00080003o00<0oh000000o`000?l00P000?l2003o01`0003o0P00o`07
0000o`@00?l01`000?l20?n000D0003o0P00o`070000o`800?l00P000?l2003o00<0003o103o0002
0000o`03003o00000?l0003o0080003o3_ooool40000o`h0oh00103o00000`000?l0oh000?n00004
0?n000030?l0003oP000oh0000@0o`000`3oP0020?l00080oh000P3o00020?n000030?l0003oP000
oh000180oh000P3o00050?n00080o`001`3oP0060?l000<0003o103oP0020?l000`0oh000P3o0005
0?n00080003o0P3o00020000o`03003o00000?l0003o0080003o103oP0000`3o0000oh000?n00002
0?n001Sooooo000Fooooo`L0o`000P3oP0040?l000L0oh001`3o00020?n002T0o`000`3oP0060?l0
0080oh0000<0o`000?n0003oP000<@3o00000`3oP000o`000?l000020?l000kooooo1`00o`020000
oaD00?l00P000?l2003o0080003o4000o`040000o`03003o00000?l0003o0080003o0P00o`030000
o`800?l00P000?l5003o00@0003o0P00o`000`000?l00?l0003o0004003o00T0003o0P00o`0<0000
o`800?l00`000?l2003o00@0003o0P00o`050000o`800?l00`000?l2003o0080003o3_ooool20000
o`800?l000<0003o003o0000o`000P00o`050000o`800?l00P000?l2003o01<0003o103oP0020?l0
0080003o00<0oh000000o`000?l00P000?l2003o01`0003o0P00o`070000o`@00?l01`000?l20?n0
00D0003o0P00o`070000o`800?l00P000?l2003o00<0003o103o00020000o`03003o00000?l0003o
0080003o3_ooool40000o`h0oh00103o00000`000?l0oh000?n000040?n000030?l0003oP000oh00
00@0o`000`3oP0020?l00080oh000P3o00020?n000030?l0003oP000oh000180oh000P3o00050?n0
0080o`001`3oP0060?l000<0003o103oP0020?l000`0oh000P3o00050?n00080003o0P3o00020000
o`03003o00000?l0003o0080003o103oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`80
oh000`3o00040?n00100o`000P3oP00>0?l00080oh003P3o00020?n004l0o`003_oooold003o00@0
003o00<00?l00000o`000?l02`000?l7003o00@0003o0`00o`020000o`800?l01`000?l2003o00<0
003o0P00o`020000o``00?l010000?l2003o00L0003o1000o`050000o`kooooo0P000?l2003o0003
0000o`00o`000?l000800?l00P000?l5003o00H0003o00<00?l00000o`000?l040000?l20?n000L0
003o0P00o`0E0000o`80oh001P3o000>0000o`800?l00P3o00070000o`800?l01`000?l00`00o`00
003o0000o`040000o`800?l01@000?l20?n000L0003o3_ooool20?n000<0o`003@3oP0020?l000<0
oh00103o00020?n000030?l0003oP000oh000080o`00103oP0000`3o0000oh000?n000040?n000<0
o`003`3oP0020?l000h0oh000`000?l20?l00080oh000P3o00020?n000030000o`3o0000o`0000/0
oh000P3o000<0?n00080o`001@000?l20?n00080003o1@3oP0020?l00080oh006?ooool001Kooooo
1`3o00020?n000d0o`000`3oP00k0?l00080oh007P3o00020?n000@0o`000`3oP0060?l000<0oh00
103o000>oooooaT00?l00P000?l2003o00<0003o0P00o`020000oa800?l01`000?l2003o00L0003o
2`00o`030000o`800?l02@000?l2003o0080003o00<00?l00000o`000?l02`00o`020000o`<00?l0
1`000?l4003o00@0003o0`00o`020000o`kooooo1@000?l8003o00030000o`00o`000?l00100003o
0P3o000=0000o`D00?l02`000?l2003o00X0003o0P3oP0020000o`80oh000`000?l20?n00100003o
0P3oP0090000o`800?l00`000?l2003o0100003o0P3oP00>ooooo`@0o`000`3oP0020000o`D0oh00
103o00050?n00080o`001`3oP0020?l00080oh000P000?l00`3o0000oh000?n0000@0?n00080o`00
0P3oP0020?l00080oh001@3o00030?n00080003o2@3oP0020?l000L0oh00103o00020?n000030?l0
003oP000oh0000h0oh000P3o00040?n00080003o0`3oP0020000o`@0oh0000<0o`000?n0003oP000
0P3oP00Hooooo`005_ooool70?l00080oh003@3o00030?n003/0o`000P3oP00N0?l00080oh00103o
00030?n000H0o`000`3oP0040?l000kooooo6@00o`020000o`800?l00`000?l2003o0080003o4P00
o`070000o`800?l01`000?l;003o00<0003o0P00o`090000o`800?l00P000?l00`00o`00003o0000
o`0;003o0080003o0`00o`070000o`@00?l010000?l3003o0080003o3_ooool50000o`P00?l000<0
003o003o0000o`0040000?l20?l000d0003o1@00o`0;0000o`800?l02P000?l20?n00080003o0P3o
P0030000o`80oh0040000?l20?n000T0003o0P00o`030000o`800?l040000?l20?n000kooooo103o
00030?n00080003o1@3oP0040?l000D0oh000P3o00070?n00080o`000P3oP0020000o`030?l0003o
P000oh000100oh000P3o00020?n00080o`000P3oP0050?l000<0oh000P000?l90?n00080o`001`3o
P0040?l00080oh0000<0o`000?n0003oP0003P3oP0020?l000@0oh000P000?l30?n00080003o103o
P0000`3o0000oh000?n000020?n001Sooooo000Fooooo`h0o`00103oP0040?l000030?n0003o0000
o`000080oh006@3o00020?n000h0o`000P3oP0070?l00080oh001@3o00020?n002@0o`000P3oP005
0?l000D0oh00103o000>ooooo`800?l00P000?l00`00o`00003o0000o`0?003o00D0003o0P00o`03
0000o`800?l00P000?l2003o00030000o`00o`000?l000/00?l010000?l00`00o`00003o0000o`02
0000o`800?l01`000?l;003o00030000o`00o`000?l000@0003o0P00o`050000oaL00?l01`000?l2
003o00L0003o0P00o`020000o`kooooo1@000?l2003o0080003o1000o`000`000?l00?l0003o000;
0000o`800?l06`000?l00`00o`00003o0000o`02003o0080003o0P00o`0<0000o`L0oh0050000?l4
003o00<0003o0P00o`020000o`03003o00000?l0003o00@0003o0P00o`0<0000o`80oh003_ooool4
0?l000L0oh000P000?l00`3oP000003o0000o`040?n00080o`003P3oP0020000o`X0oh000P3o000I
0?n00080o`004P3oP0020?l000<0oh000P000?l=0?n000030?l0003oP000oh0000@0oh000P000?l5
0?n00080o`000`3oP0020?l00080oh006?ooool001Kooooo3P3o00040?n000@0o`0000<0oh000?l0
003o00000P3oP00I0?l00080oh003P3o00020?n000L0o`000P3oP0050?l00080oh00903o00020?n0
00D0o`001@3oP0040?l000kooooo0P00o`020000o`03003o00000?l0003o00l00?l01@000?l2003o
00<0003o0P00o`020000o`800?l000<0003o003o0000o`002`00o`040000o`03003o00000?l0003o
0080003o0P00o`070000o`/00?l000<0003o003o0000o`0010000?l2003o00D0003o5`00o`070000
o`800?l01`000?l2003o0080003o3_ooool50000o`800?l00P000?l4003o00030000o`00o`000?l0
00/0003o0P00o`0K0000o`03003o00000?l0003o00800?l00P000?l2003o00`0003o1`3oP00D0000
o`@00?l00`000?l2003o0080003o00<00?l00000o`000?l010000?l2003o00`0003o0P3oP00>oooo
o`@0o`001`3oP0020000o`030?n000000?l0003o00@0oh000P3o000>0?n00080003o2P3oP0020?l0
01T0oh000P3o000B0?n00080o`000`3oP0020000o`d0oh0000<0o`000?n0003oP000103oP0020000
o`D0oh000P3o00030?n00080o`000P3oP00Hooooo`005_ooool20?n000<0o`00203oP00:0?l000@0
oh005`3o00020?n00080o`000P3oP0030?l00080oh005`3o00020?n000L0o`000P3oP0040?l00003
0?n0003o0000o`0001/0o`000P3oP0020000o`030?n0003o0000o`000080o`003_oooolK003o00D0
003o0P00o`020000o`800?l000<0003o003o0000o`003@00o`030000o`800?l01P000?l00`00o`00
003o0000o`020000o`<00?l010000?l2003o00<0003o0P00o`060000o`03003o00000?l0003o0080
003o0P00o`020000o`03003o00000?l0003o01000?l00P000?l2003o00T0003o0P00o`000`000?l0
0?l0003o00020000o`kooooo1@000?l2003o0080003o1000o`000`000?l00?l0003o00060000o`D0
0?l030000?l2003o00T0003o0P00o`070000o`800?l02`000?l00`00o`00003o0000o`0=0000o`80
0?l02P000?l2003o02@0003o3_ooool40?l000<0oh00103o00020?n000030?l000000?l0003o00@0
oh000P3o000>0?n00080003o00<0oh000000o`000?l02`3oP0050?l00080oh000P3o00020?n000<0
003o0P3oP0040?l000030?n0003o0000o`000080o`000P3oP0090000o`D0oh00103o00020?n00003
0?l000000?l0003o00@0o`002@3oP0030?l00100oh00103o000Hooooo`005_ooool20?n000<0o`00
203oP00:0?l000@0oh005`3o00020?n00080o`000P3oP0030?l00080oh005`3o00020?n000L0o`00
0P3oP0040?l000030?n0003o0000o`0001/0o`000P3oP0020000o`030?n0003o0000o`000080o`00
3_oooolK003o00D0003o0P00o`020000o`800?l000<0003o003o0000o`003@00o`030000o`800?l0
1P000?l00`00o`00003o0000o`020000o`<00?l010000?l2003o00<0003o0P00o`060000o`03003o
00000?l0003o0080003o0P00o`020000o`03003o00000?l0003o01000?l00P000?l2003o00T0003o
0P00o`000`000?l00?l0003o00020000o`kooooo1@000?l2003o0080003o1000o`000`000?l00?l0
003o00060000o`D00?l030000?l2003o00T0003o0P00o`070000o`800?l02`000?l00`00o`00003o
0000o`0=0000o`800?l02P000?l2003o02@0003o3_ooool40?l000<0oh00103o00020?n000030?l0
00000?l0003o00@0oh000P3o000>0?n00080003o00<0oh000000o`000?l02`3oP0050?l00080oh00
0P3o00020?n000<0003o0P3oP0040?l000030?n0003o0000o`000080o`000P3oP0090000o`D0oh00
103o00020?n000030?l000000?l0003o00@0o`002@3oP0030?l00100oh00103o000Hooooo`005_oo
ool70?l00080oh001@3o00020?n000T0o`000P3oP00<0?l00080oh004P3o00020?n00080003o6`3o
00000`3oP000o`000?l000020?n000T0o`000P3oP0020?l000030?n0003o0000o`0000h0o`000P3o
P0020000o`@0oh0000<0003o0?l0003o00000P3o000>oooooaT00?l00P000?lE003o00@0003o0P00
o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`000P000?l3003o00@0003o0P00
o`030000o`800?l02@000?l9003o0080003o3P00o`0=0000o`L00?l03_ooool50000o`800?l04000
0?l2003o0080003o0P00o`0E0000o`800?l010000?l00`00o`00003o0000o`04003o01L0003o0P00
o`020000o`X00?l02`000?l2003o0080003o00<00?l00000o`000?l00P00o`050000o`800?l02`00
0?l>ooooo`80oh000`3o00020?n000H0o`002P3oP0020?l000D0oh000P3o00040?n00080003o00<0
oh000?l0003o0000103oP0020?l000L0oh000P3o00000`3oP000o`000?l000040?n000<0003o0P3o
P0040?l000030?n0003o0000o`0000T0oh000P3o00050?n00080o`001P3oP0030?l00080003o103o
P0000`3o0000oh000?n000020?l000T0oh000P000?l30?n00080o`002@3oP00Hooooo`005_ooool7
0?l00080oh001@3o00020?n000T0o`000P3oP00<0?l00080oh004P3o00020?n00080003o6`3o0000
0`3oP000o`000?l000020?n000T0o`000P3oP0020?l000030?n0003o0000o`0000h0o`000P3oP002
0000o`@0oh0000<0003o0?l0003o00000P3o000>oooooaT00?l00P000?lE003o00@0003o0P00o`02
0000o`03003o00000?l0003o00H00?l000<0003o003o0000o`000P000?l3003o00@0003o0P00o`03
0000o`800?l02@000?l9003o0080003o3P00o`0=0000o`L00?l03_ooool50000o`800?l040000?l2
003o0080003o0P00o`0E0000o`800?l010000?l00`00o`00003o0000o`04003o01L0003o0P00o`02
0000o`X00?l02`000?l2003o0080003o00<00?l00000o`000?l00P00o`050000o`800?l02`000?l>
ooooo`80oh000`3o00020?n000H0o`002P3oP0020?l000D0oh000P3o00040?n00080003o00<0oh00
0?l0003o0000103oP0020?l000L0oh000P3o00000`3oP000o`000?l000040?n000<0003o0P3oP004
0?l000030?n0003o0000o`0000T0oh000P3o00050?n00080o`001P3oP0030?l00080003o103oP000
0`3o0000oh000?n000020?l000T0oh000P000?l30?n00080o`002@3oP00Hooooo`005_ooool50?l0
0080oh001`3o00020?n000L0o`000P000?lP0?l00080003o0P3oP0070?l000@0oh004P3o00000`3o
P000o`000?l000040?n000D0o`000P3oP0020?l00080oh005`3o00020?n000D0o`003_ooool2003o
0080003o2P00o`020000o`800?l00P000?l5003o0080003o0P00o`000`000?l00?l0003o000B003o
0080003o0P00o`020000o`D00?l00P000?l:003o00T0003o1000o`040000o`03003o00000?l0003o
00H00?l000<0003o003o0000o`000P00o`020000o`h00?l01@000?l2003o0080003o0P00o`020000
o`03003o00000?l0003o0080003o3_ooool70000o`H00?l00`000?l2003o00@0003o00<00?l00000
o`000?l01000o`030000o`800?l01@000?l2003o00T0003o0P00o`020000o`<00?l010000?l2003o
00<0003o0P00o`070000o`800?l02`000?l2003o00<0003o0P00o`020000o`<00?l060000?l00`00
o`00003o0000o`060000o`03003o00000?l0003o0080003o3_ooool20?l000D0oh000P3o00040?n0
00030?l0003oP000oh0000@0003o0`3oP0020?l000@0oh000`3o00020?n000D0003o0P3oP0020000
o`80o`000`3oP0020?l00080oh000P3o00070?n00080003o0`3oP0020?l000D0oh000P3o00090?n0
0080o`000P3oP0030?l000/0oh000P000?l<0?n00080o`000P3oP0020?l00080oh000`3o00070?n0
0080o`000P3oP00Hooooo`005_ooool20?n00080o`001@3oP00d0?l00080oh001@3o00020000oaT0
o`000P3oP0070?l000@0oh001@3o00020?n00100o`000P3oP0050?l000kooooo7@00o`030000o`80
0?l00P000?l>003o0080003o0P00o`020000o`03003o00000?l0003o00800?l010000?l00`00o`00
003o0000o`020000o`<00?l02`000?l2003o00T0003o1`00o`020000oa000?l00P000?l2003o0003
0000o`00o`000?l00080003o2@00o`0>ooooo`D0003o0P00o`020000o`@00?l01`000?l2003o0003
0000o`00o`000?l00080003o0P00o`030000o`800?l00P000?l2003o00030000o`00o`000?l000T0
003o0P00o`020000o`T00?l00`000?l2003o0180003o0P00o`0@0000o`80o`002@000?l3003o00H0
003o00<00?l00000o`000?l02`000?l>ooooo`80oh000`000?l20?l000T0oh0010000?l20?n000<0
o`00103oP0030?l000@0oh000`000?l20?n00080003o503oP0020000o`030?n0003o0000o`000080
oh001`3o00070?n00080o`00403oP0020000o`80o`000P3oP0030?l00080oh000P3o00090?n000<0
o`000P000?l20?n000<0o`00103oP00Hooooo`005_ooool20?n00080o`001@3oP00d0?l00080oh00
1@3o00020000oaT0o`000P3oP0070?l000@0oh001@3o00020?n00100o`000P3oP0050?l000kooooo
7@00o`030000o`800?l00P000?l>003o0080003o0P00o`020000o`03003o00000?l0003o00800?l0
10000?l00`00o`00003o0000o`020000o`<00?l02`000?l2003o00T0003o1`00o`020000oa000?l0
0P000?l2003o00030000o`00o`000?l00080003o2@00o`0>ooooo`D0003o0P00o`020000o`@00?l0
1`000?l2003o00030000o`00o`000?l00080003o0P00o`030000o`800?l00P000?l2003o00030000
o`00o`000?l000T0003o0P00o`020000o`T00?l00`000?l2003o0180003o0P00o`0@0000o`80o`00
2@000?l3003o00H0003o00<00?l00000o`000?l02`000?l>ooooo`80oh000`000?l20?l000T0oh00
10000?l20?n000<0o`00103oP0030?l000@0oh000`000?l20?n00080003o503oP0020000o`030?n0
003o0000o`000080oh001`3o00070?n00080o`00403oP0020000o`80o`000P3oP0030?l00080oh00
0P3o00090?n000<0o`000P000?l20?n000<0o`00103oP00Hooooo`005_ooool20?l00080oh001@3o
00020?n001D0o`000P3oP0040?l000<0oh00403o00040?n000L0o`00103oP0030?l00080oh000P3o
00020?n000T0o`0000<0oh000?l0003o00006@3o00020?n000T0o`000P3oP0020000o`D0o`003_oo
oolK003o00<0003o0P00o`020000oa000?l00P000?l2003o0080003o00<00?l00000o`000?l03@00
0?l00`00o`00003o0000o`0;003o00L0003o0P00o`020000o`<00?l00P000?l2003o0080003o0P00
o`000`000?l00?l0003o0005003o00H0003o0P00o`070000o`800?l00`000?l2003o00kooooo1@00
0?l2003o0080003o1000o`0:0000o`800?l02@000?l2003o0080003o00<00?l00000o`000?l01000
0?l2003o00<0003o2@00o`0=0000o`03003o00000?l0003o00l0003o00<00?l00000o`000?l00P00
0?l2003o0080003o00<00?l00000o`000?l03@000?l00`00o`00003o0000o`070000o`800?l01`00
0?l2003o0080003o3_ooool20?n000<0003o2`3oP0020000o`80oh001@3o00090?n00080003o303o
P0020?l000@0oh000P000?l30?l000@0oh000P3o00000`3oP000o`000?l000050?l001X0oh0000<0
o`000?n0003oP000103oP0020000o``0oh000P3o00020?n000030?l0003oP000oh0000L0oh000P00
0?l20?n001Sooooo000Fooooo`80o`000P3oP0050?l00080oh005@3o00020?n000@0o`000`3oP00@
0?l000@0oh001`3o00040?n000<0o`000P3oP0020?l00080oh002@3o00000`3oP000o`000?l0000I
0?l00080oh002@3o00020?n00080003o1@3o000>oooooa/00?l00`000?l2003o0080003o4000o`02
0000o`800?l00P000?l00`00o`00003o0000o`0=0000o`03003o00000?l0003o00/00?l01`000?l2
003o0080003o0`00o`020000o`800?l00P000?l2003o00030000o`00o`000?l000D00?l01P000?l2
003o00L0003o0P00o`030000o`800?l03_ooool50000o`800?l00P000?l4003o00X0003o0P00o`09
0000o`800?l00P000?l00`00o`00003o0000o`040000o`800?l00`000?l9003o00d0003o00<00?l0
0000o`000?l03`000?l00`00o`00003o0000o`020000o`800?l00P000?l00`00o`00003o0000o`0=
0000o`03003o00000?l0003o00L0003o0P00o`070000o`800?l00P000?l>ooooo`80oh000`000?l;
0?n00080003o0P3oP0050?l000T0oh000P000?l<0?n00080o`00103oP0020000o`<0o`00103oP002
0?l000030?n0003o0000o`0000D0o`006P3oP0000`3o0000oh000?n000040?n00080003o303oP002
0?l00080oh0000<0o`000?n0003oP0001`3oP0020000o`80oh006?ooool001Kooooo103oP00C0?l0
0080oh003@3o00000`3oP000o`000?l000020?n00100o`000P3oP0090?l00080oh001@3o00050?n0
00P0o`0000<0oh000?l0003o0000103o00020?n00140o`000P3oP0040000o`D0o`00103oP0020000
o`D0o`003_ooool2003o00<0003o0P00o`020000oaL00?l00P000?l@003o0080003o1000o`090000
o`03003o00000?l0003o0080003o0P00o`030000o`800?l00P000?l9003o00L0003o0P00o`050000
o`800?l00P000?lB003o00T0003o00<00?l00000o`000?l00P00o`0>ooooo`80003o0P00o`050000
o`L00?l040000?l2003o0080003o0P00o`070000o`80oh0000<0003o003o0000o`0010000?l5003o
00L0003o0P00o`040000o`03003o00000?l0003o00d0003o0P00o`0I0000o`<00?l00P000?l2003o
0100003o3_ooool40?n000<0o`00103oP0030?l000H0oh000P3o00000`3oP000o`000?l000090?n0
0080003o0P3oP0000`000?l0oh000?n000020?n00080o`001@3oP0020000o`@0oh001@3o00040000
o`L0o`001`3oP0070000o`80oh000P3o000B0?n000030?l0003oP000oh0000d0o`002P3oP0020?l0
0080003o6?ooool001Kooooo103oP00C0?l00080oh003@3o00000`3oP000o`000?l000020?n00100
o`000P3oP0090?l00080oh001@3o00050?n000P0o`0000<0oh000?l0003o0000103o00020?n00140
o`000P3oP0040000o`D0o`00103oP0020000o`D0o`003_ooool2003o00<0003o0P00o`020000oaL0
0?l00P000?l@003o0080003o1000o`090000o`03003o00000?l0003o0080003o0P00o`030000o`80
0?l00P000?l9003o00L0003o0P00o`050000o`800?l00P000?lB003o00T0003o00<00?l00000o`00
0?l00P00o`0>ooooo`80003o0P00o`050000o`L00?l040000?l2003o0080003o0P00o`070000o`80
oh0000<0003o003o0000o`0010000?l5003o00L0003o0P00o`040000o`03003o00000?l0003o00d0
003o0P00o`0I0000o`<00?l00P000?l2003o0100003o3_ooool40?n000<0o`00103oP0030?l000H0
oh000P3o00000`3oP000o`000?l000090?n00080003o0P3oP0000`000?l0oh000?n000020?n00080
o`001@3oP0020000o`@0oh001@3o00040000o`L0o`001`3oP0070000o`80oh000P3o000B0?n00003
0?l0003oP000oh0000d0o`002P3oP0020?l00080003o6?ooool001Kooooo103oP0050?l00080oh00
0P3o00000`3oP000o`000?l000060?l000030?n0003o0000o`000080oh00>@3o00040?n001h0o`00
103oP0050?l00080oh0010000?l50?l000kooooo0P00o`050000o`@00?l00P000?l5003o0080003o
0`00o`020000oaT00?l00P000?l2003o00T0003o0P00o`0:0000o`800?l00P000?l9003o00<0003o
0P00o`040000o`<00?l00P000?l2003o00@0003o2000o`020000o`H00?l000<0003o0?n0003oP000
0P3o00020000o`800?l00`000?l2003o00kooooo1000o`000`000?l00?l0003o00040000o`800?l0
00<0003o003o0000o`0010000?l2003o00030000o`00o`000?l00080003o0P00o`000`000?l00?l0
003o0007003o00T0003o0P00o`090000o`800?l01@000?l2003o00@0003o00<00?l00000o`000?l0
0P00o`0;0000o`800?l04P000?l00`00o`00003o0000o`090000o`800?l01@000?l2003o00D0003o
1000o`0>ooooo`D0oh000P3o00040000o`80o`0000<0003o0?n0003oP000103oP0030?l00080oh00
0P000?l30?n00080o`000P3oP0050000o`H0oh000P3o00000`3oP000003o0000o`020000o`@0oh00
00<0o`000?n0003oP0000P3oP0040000o`P0oh000P3o00060?n000030?l0003oP000oh0000H0o`00
1@3oP0020?l000L0oh000P000?l50?n00080003o0`3oP0060?l000<0oh000P3o00040?n00080o`00
00<0oh000?l0003o00000P3o000Hooooo`005_ooool40?n000D0o`000P3oP0020?l000030?n0003o
0000o`0000H0o`0000<0oh000?l0003o00000P3oP00i0?l000@0oh007P3o00040?n000D0o`000P3o
P0040000o`D0o`003_ooool2003o00D0003o1000o`020000o`D00?l00P000?l3003o0080003o6@00
o`020000o`800?l02@000?l2003o00X0003o0P00o`020000o`T00?l00`000?l2003o00@0003o0`00
o`020000o`800?l010000?l8003o0080003o1P00o`000`000?l0oh000?n000020?l00080003o0P00
o`030000o`800?l03_ooool4003o00030000o`00o`000?l000@0003o0P00o`000`000?l00?l0003o
00040000o`800?l000<0003o003o0000o`000P000?l2003o00030000o`00o`000?l000L00?l02@00
0?l2003o00T0003o0P00o`050000o`800?l010000?l00`00o`00003o0000o`02003o00/0003o0P00
o`0B0000o`03003o00000?l0003o00T0003o0P00o`050000o`800?l01@000?l4003o00kooooo1@3o
P0020?l000@0003o0P3o00000`000?l0oh000?n000040?n000<0o`000P3oP0020000o`<0oh000P3o
00020?n000D0003o1P3oP0020?l000030?n000000?l0003o0080003o103oP0000`3o0000oh000?n0
00020?n000@0003o203oP0020?l000H0oh0000<0o`000?n0003oP0001P3o00050?n00080o`001`3o
P0020000o`D0oh000P000?l30?n000H0o`000`3oP0020?l000@0oh000P3o00000`3oP000o`000?l0
00020?l001Sooooo000FoooooaH0o`0000<0oh000?l0003o00003@3o00000`3oP000o`000?l0000M
0?l00080oh001@3o00040?n00180o`0000<0oh000?l0003o00000P3oP00E0?l000@0003o0P3oP003
0?l00080oh000P3o000>ooooo`D0003o0P00o`020000oa@00?l000<0003o003o0000o`0010000?l@
003o01T0003o2@00o`070000o`800?l010000?l00`00o`00003o0000o`0>003o00T0003o0P3oP00;
0000o`kooooo0P000?l2003o00L0003o2@00o`090000o`<00?l01P000?l00`00o`00003o0000o`07
0000o`@00?l03@000?l00`00o`00003o0000o`070000o`@00?l00`000?l2003o00@0003o0P00o`07
0000o`800?l000<0003o003o0000o`003P000?l2003o0080003o0P00o`070000o`800?l01`000?l>
ooooo`80oh000`3o00020?n00080o`000P000?l20?l000D0oh001@3o00060?n000030?l0003oP000
oh000080oh0010000?l00`3oP000o`000?l000040?l00080oh001@000?l50?l000H0oh000P3o0003
0?n00080003o0P3oP0030?l000/0oh000P3o00020?n000030?l0003oP000oh0000@0oh000P3o0007
0?n000<0o`000P3oP0020?l00080oh001`3o00030?n000@0o`002@3oP00Hooooo`005_ooool20?n0
00<0o`000P3oP0040?l000<0oh002@3o00060?n000T0o`000`3oP00M0?l00080oh001@3o00040?n0
01<0o`000P3oP00>0?l00080oh002@3o00020000o`@0oh0000<0o`000?n0003oP0000P000?l>oooo
o`800?l00`000?l2003o0080003o:`00o`020000o`800?l040000?l00`00o`00003o0000o`040000
o`T00?l00`000?l2003o00@0003o4`00o`0?0000o`<00?l00P000?l2003o00kooooo0P000?l2003o
00L0003o0P00o`030000o`800?l00P000?l2003o00030000o`00o`000?l00080003o0P00o`000`00
0?l00?l0003o0002003o00@0003o0`00o`0;0000o`800?l00P000?l00`3oP000o`000?l000040000
o`800?l000<0003o003o0000o`000P00o`0;0000o`<00?l03@000?l2003o00D0003o1@00o`060000
o`030?l000000?l0003o0080oh000P00o`0@0000o`kooooo2@3oP0020?l000D0oh00103o00020?n0
00030?l0003oP000oh0000T0oh000P000?l;0?n000030000o`3oP000oh000080o`002`3oP0020?l0
00030?n000000?l0003o0180oh001@3o00020?n00080o`000P000?l20?n000030000o`3oP000oh00
00H0oh0000<0o`000?n0003oP000403oP0020?l000T0oh006?ooool001Kooooo0P3oP0030?l00080
oh00103o00030?n000T0o`001P3oP0090?l000<0oh007@3o00020?n000D0o`00103oP00C0?l00080
oh003P3o00020?n000T0o`000P000?l40?n000030?l0003oP000oh000080003o3_ooool2003o00<0
003o0P00o`020000ob/00?l00P000?l2003o0100003o00<00?l00000o`000?l010000?l9003o00<0
003o0P00o`040000oa<00?l03`000?l3003o0080003o0P00o`0>ooooo`80003o0P00o`070000o`80
0?l00`000?l2003o0080003o0P00o`000`000?l00?l0003o00020000o`800?l000<0003o003o0000
o`000P00o`040000o`<00?l02`000?l2003o0080003o00<0oh000?l0003o000010000?l2003o0003
0000o`00o`000?l000800?l02`000?l3003o00d0003o0P00o`050000o`D00?l01P000?l00`3o0000
003o0000o`020?n000800?l040000?l>ooooo`T0oh000P3o00050?n000@0o`000P3oP0000`3o0000
oh000?n000090?n00080003o2`3oP0000`000?l0oh000?n000020?l000/0oh000P3o00000`3oP000
003o0000o`0B0?n000D0o`000P3oP0020?l00080003o0P3oP0000`000?l0oh000?n000060?n00003
0?l0003oP000oh000100oh000P3o00090?n001Sooooo000Fooooo`L0o`000P3oP0040?l000030?n0
003o0000o`0000L0o`000P3oP0050?l00080oh006@3o00020?n000L0o`00103oP0020?l000030?n0
003o0000o`0000H0oh001@3o00040?n000`0o`000P3oP0070?l00080oh002`3o00000`3oP000o`00
0?l000020?l00080oh000`3o00020?n00080o`003_ooool90000oc800?l010000?l2003o00030000
o`00o`000?l000800?l02@000?l5003o0080003o1000o`090000o`L00?l00P000?l7003o00030000
o`00o`000?l000l0003o00<00?l00000o`000?l00P00o`0>ooooo`D0003o0P00o`040000o`800?l0
00<0003o003o0000o`000P00o`020000o`<00?l010000?l2003o00030000o`00o`000?l000800?l0
0P000?l3003o0140003o00<0oh000000o`000?l07`000?l00`00o`00003o0000o`020000o`800?l0
6@000?l20?n000T0003o00<00?l00000o`000?l00P00o`0>oooooa80oh000P3o00050?n00080003o
1`3oP0020000o`D0oh00103o00020?n000L0o`002@3oP0020?l000030?n000000?l0003o00@0o`00
4P3oP0000`3o0000oh000?n000090?n00080o`000P3oP0030?l000T0oh00103o00020?n000030?l0
003oP000oh0000H0oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool70?l00080oh00103o
00000`3oP000o`000?l000070?l00080oh001@3o00020?n001T0o`000P3oP0070?l000@0oh000P3o
00000`3oP000o`000?l000060?n000D0o`00103oP00<0?l00080oh001`3o00020?n000/0o`0000<0
oh000?l0003o00000P3o00020?n000<0o`000P3oP0020?l000kooooo2@000?lb003o00@0003o0P00
o`000`000?l00?l0003o0002003o00T0003o1@00o`020000o`@00?l02@000?l7003o0080003o1`00
o`000`000?l00?l0003o000?0000o`03003o00000?l0003o00800?l03_ooool50000o`800?l01000
0?l2003o00030000o`00o`000?l000800?l00P000?l3003o00@0003o0P00o`000`000?l00?l0003o
0002003o0080003o0`00o`0A0000o`030?n000000?l0003o01l0003o00<00?l00000o`000?l00P00
0?l2003o01T0003o0P3oP0090000o`03003o00000?l0003o00800?l03_oooolB0?n00080o`001@3o
P0020000o`L0oh000P000?l50?n000@0o`000P3oP0070?l000T0oh000P3o00000`3oP000003o0000
o`040?l00180oh0000<0o`000?n0003oP0002@3oP0020?l00080oh000`3o00090?n000@0o`000P3o
P0000`3o0000oh000?n000060?n000030?l0003oP000oh000080oh006?ooool001Kooooo103o0000
0`3oP000o`000?l000040?l00080oh004@3o00020?n000@0o`001@3oP0060?l000030?n0003o0000
o`000080o`000P3oP0020?l000<0oh001P3o00050?n000L0o`00103oP0000`3o0000oh000?n0000@
0?l00080oh001`3o00020?n000D0o`000P3oP0070?l000H0oh001`3o000>ooooo`D0003o0P00o`02
0000oaT00?l00P000?lI003o00/0003o00<00?l00000o`000?l010000?l5003o0080003o1000o`0:
0000o`800?l00P000?l7003o0080003o1`00o`040000o`03003o00000?l0003o00H0003o00<00?l0
0000o`000?l00P00o`0>ooooo`80003o0P00o`000`000?l00?l0003o00040000o`800?l000<0003o
003o0000o`002`000?l2003o00D0003o1@00o`060000o`800?l01`000?l20?l00140003o0P00o`0=
0000o`800?l0;P000?l2003o00kooooo0P000?l70?n000@0o`001@3oP0020?l000D0oh0010000?l7
0?n00080003o00<0oh000?l0003o00003`3oP0000`3o0000oh000?n0000;0?n00080o`004P3oP000
0`3o0000oh000?n000020?n000@0o`002P3oP0020?l000D0oh001P3o000;0?n000030000o`3oP000
oh000080o`006?ooool001Kooooo103o00000`3oP000o`000?l000040?l00080oh004@3o00020?n0
00@0o`001@3oP0060?l000030?n0003o0000o`000080o`000P3oP0020?l000<0oh001P3o00050?n0
00L0o`00103oP0000`3o0000oh000?n0000@0?l00080oh001`3o00020?n000D0o`000P3oP0070?l0
00H0oh001`3o000>ooooo`D0003o0P00o`020000oaT00?l00P000?lI003o00/0003o00<00?l00000
o`000?l010000?l5003o0080003o1000o`0:0000o`800?l00P000?l7003o0080003o1`00o`040000
o`03003o00000?l0003o00H0003o00<00?l00000o`000?l00P00o`0>ooooo`80003o0P00o`000`00
0?l00?l0003o00040000o`800?l000<0003o003o0000o`002`000?l2003o00D0003o1@00o`060000
o`800?l01`000?l20?l00140003o0P00o`0=0000o`800?l0;P000?l2003o00kooooo0P000?l70?n0
00@0o`001@3oP0020?l000D0oh0010000?l70?n00080003o00<0oh000?l0003o00003`3oP0000`3o
0000oh000?n0000;0?n00080o`004P3oP0000`3o0000oh000?n000020?n000@0o`002P3oP0020?l0
00D0oh001P3o000;0?n000030000o`3oP000oh000080o`006?ooool001Kooooo0P3oP0050?l000@0
oh000P3o00000`3oP000o`000?l0000D0?l00080oh002@3o00000`3oP000o`000?l000040?l000D0
oh001P3o00030?n00180o`000P3oP00E0?l00080oh000P3o00020000o`<0oh00103o00020?n00003
0?l0003oP000oh000080oh001`3o00020?n000kooooo0P00o`070000oc800?l010000?l2003o00<0
003o0P00o`020000o`03003o00000?l0003o00@00?l00P000?l3003o0100003o0P00o`020000o`L0
0?l00P000?l7003o0080003o0P00o`050000o`800?l00P000?l00`00o`00003o0000o`02003o00ko
oooo0P3oP002003o00<0003o0P00o`050000o`800?l02@000?l2003o00/0003o00<00?l00000o`00
0?l05P000?l2003o01L0003o0P00o`0@0000o`<00?l02`000?l2003o00L0003o0P00o`050000o`80
0?l03_ooool20000o`80oh001`000?l20?l000X0oh000P3o00090000o`80oh000P3o00070?n00080
o`0000<0oh000?l0003o0000503oP0020?l000T0oh0000<0o`000?n0003oP000103o000;0?n00003
0?l0003oP000oh000080oh000P000?l70?n000D0003o0P3oP0040?l000L0oh000P3o00050?n001So
oooo000Fooooo`@0o`0000<0oh000?l0003o00003@3o00020?n000P0o`000P3oP0040?l000<0oh00
3@3o00020?n000L0o`000P3oP00G0?l00080oh002@3o00020?n000030?l0003oP000oh0000@0o`00
0P3oP0070?l000<0oh000P3o00040?n000030?l0003oP000oh000080oh00103o00000`3oP000o`00
0?l000020?n000kooooo0P00o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`00
0P000?l7003o0080003o5@00o`020000o`T00?l03P000?l2003o00L0003o0P00o`0?0000o`<00?l0
0P000?l>003o00H0003o00<00?l00000o`000?l00P000?l2003o0080003o1@00o`0>ooooo`@0003o
00<00?l00000o`000?l00P00o`040000o`03003o00000?l0003o00@0003o0`00o`090000o`800?l0
10000?l3003o00@0003o0P00o`050000o`800?l00`000?l4003o0080003o0`00o`070000o`80o`00
10000?l2003o00L0003o1@00o`090000o`80oh000P000?l3003o00/0003o0P00o`020000o`<00?l0
1P000?l00`00o`00003o0000o`02003o00kooooo1`000?l20?l00080003o403oP0090000o`D0oh00
0P000?l20?n00080o`0000<0oh000?l0003o00003@3oP0020?l000030?n0003o0000o`0001H0oh00
00<0003o0?n0003oP0001`3oP0020?l00080oh000P3o00020?n000030?l000000?l0003o0080oh00
0`000?l;0?n00080o`00103oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`@0o`0000<0
oh000?l0003o00003@3o00020?n000P0o`000P3oP0040?l000<0oh003@3o00020?n000L0o`000P3o
P00G0?l00080oh002@3o00020?n000030?l0003oP000oh0000@0o`000P3oP0070?l000<0oh000P3o
00040?n000030?l0003oP000oh000080oh00103o00000`3oP000o`000?l000020?n000kooooo0P00
o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`000P000?l7003o0080003o5@00
o`020000o`T00?l03P000?l2003o00L0003o0P00o`0?0000o`<00?l00P000?l>003o00H0003o00<0
0?l00000o`000?l00P000?l2003o0080003o1@00o`0>ooooo`@0003o00<00?l00000o`000?l00P00
o`040000o`03003o00000?l0003o00@0003o0`00o`090000o`800?l010000?l3003o00@0003o0P00
o`050000o`800?l00`000?l4003o0080003o0`00o`070000o`80o`0010000?l2003o00L0003o1@00
o`090000o`80oh000P000?l3003o00/0003o0P00o`020000o`<00?l01P000?l00`00o`00003o0000
o`02003o00kooooo1`000?l20?l00080003o403oP0090000o`D0oh000P000?l20?n00080o`0000<0
oh000?l0003o00003@3oP0020?l000030?n0003o0000o`0001H0oh0000<0003o0?n0003oP0001`3o
P0020?l00080oh000P3o00020?n000030?l000000?l0003o0080oh000`000?l;0?n00080o`00103o
P0000`3o0000oh000?n000020?n001Sooooo000Fooooo`@0o`000`3oP0020?l000@0oh00403o0000
0`3oP000o`000?l0000F0?l00080003o0`3oP0090?l00080oh001`3o00020?n000h0o`000P3oP002
0?l00080oh001`3o00020?n00140o`000P3oP0090?l00080oh003_ooool50000o`800?l00P000?l4
003o00030000o`00o`000?l001000?l00P000?l@003o0080003o0P00o`020000o`<00?l03@000?l0
0`00o`00003o0000o`020000o`800?l00`000?l4003o00L0003o1`00o`060000o`<00?l010000?l5
003o0080003o0P00o`020000o`03003o00000?l0003o00@00?l00P000?l5003o00kooooo0P000?l2
0?n000030?l000000?l0003o00d0003o0P00o`050000o`800?l00`000?l2003o00D0003o0P00o`0;
0000o`800?l00`000?l4003o00/0003o00<0oh000000o`000?l02@000?l2003o00@0003o00<00?l0
0000o`000?l06`000?l5003o00d0003o3_ooool40000o`030?n000000?l0003o0080o`000P000?l2
0?n000030?l0003oP000oh0000L0oh000P3o00090?n000T0o`002@3oP0020?l000D0oh000P3o0002
0?n00080o`004`3oP0020?l000@0oh0000<0o`000?n0003oP0002`3oP0020000o`80oh0000<0o`00
0000o`000?l0103oP0030?l00080003o103oP0000`000?l0oh000?n0000;0?n001Sooooo000Foooo
o`@0o`000`3oP0020?l000@0oh00403o00000`3oP000o`000?l0000F0?l00080003o0`3oP0090?l0
0080oh001`3o00020?n000h0o`000P3oP0020?l00080oh001`3o00020?n00140o`000P3oP0090?l0
0080oh003_ooool50000o`800?l00P000?l4003o00030000o`00o`000?l001000?l00P000?l@003o
0080003o0P00o`020000o`<00?l03@000?l00`00o`00003o0000o`020000o`800?l00`000?l4003o
00L0003o1`00o`060000o`<00?l010000?l5003o0080003o0P00o`020000o`03003o00000?l0003o
00@00?l00P000?l5003o00kooooo0P000?l20?n000030?l000000?l0003o00d0003o0P00o`050000
o`800?l00`000?l2003o00D0003o0P00o`0;0000o`800?l00`000?l4003o00/0003o00<0oh000000
o`000?l02@000?l2003o00@0003o00<00?l00000o`000?l06`000?l5003o00d0003o3_ooool40000
o`030?n000000?l0003o0080o`000P000?l20?n000030?l0003oP000oh0000L0oh000P3o00090?n0
00T0o`002@3oP0020?l000D0oh000P3o00020?n00080o`004`3oP0020?l000@0oh0000<0o`000?n0
003oP0002`3oP0020000o`80oh0000<0o`000000o`000?l0103oP0030?l00080003o103oP0000`00
0?l0oh000?n0000;0?n001Sooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000W
ooooog7o00009ooooomao`0002Cooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo
003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKo
o`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo
003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0
0ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl0
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l0
1OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o1?oo
oolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001Ooo
oolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool000Gooooo5_l0o`04oooooaOo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolF
o`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o
00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool000Gooooo5_l0o`04oooooaOo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Go
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool001oo
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l0
0?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000Ooooo
oaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaKo
o`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5ooo000joooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5ooo000OoooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00>_oooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooaOoo`007ooooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l00_l007lFool000Go001o5_l0o`0jo`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l00_l007lGool001oo001o5_l00?lOo`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l00_l007lGool003[o001o5_ooO`04o`00O`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_oooolGool001oooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaKoo`001OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`007ooooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5_oo0005oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000OoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`00E?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo
02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?l007oo001o00?o001o
5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`02o`00OaOoo`00E?l007l00ol0003ooooo
ooooo`0Uooooo`03o`000?l007oo001o05?o001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooaOoo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooo
oooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o
0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool0
07l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03
o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo
001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooo
oooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo
000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;oooooL_l0000W
ooooog7o00009ooooomao`0002OoooooLOl0000Tooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`005_ooool20?l000/00?l000<0o`00003o0000o`001`3o00060?n00100o`000P00o`07
0?l00080003o00<0o`000?n0003oP0000P3oP0070?l00080oh000`3o00020000o`@0o`000P3oP003
0?l00080003o2`3o00020000o`D0o`000P000?l@0?l00080oh000`3o00020?n000T0o`003_ooool4
0000o`T00?l03P3o0003003o00H0o`001`000?lD003o0080o`003000o`050?l000H00?l00P3o000<
003o0080o`001`00o`020?l000800?l000<0o`00003o0000o`001000o`020?l00003003o003o0000
o`000080o`0010000?l30?n00080003o3_ooool5003o00P0o`0000<0003o0?l0003o00001`3o0002
0?n000@0o`0000<0oh000?l0003o00000P3o00040000o`<0oh00103o0005003o0080o`000P00o`02
0?l000<00?l0103o00030?n000H0o`000`00o`090?l00080oh00103o00000`000?l0o`000?l00002
0000o`80oh001@000?l20?l000800?l00`3o00070000o`80o`000P3oP0020000o`80oh000`000?l2
0?l00080oh000`3o00040000o`kooooo0P3oP0090?l000D0oh000P000?l;0?n000<0003o0P3o0002
003o00<0o`00203oP0000`3o0000oh000?n0000=0?n00080o`0000<0oh000?l0003o00000P3oP002
0?l000030?n0003o0000o`000080o`002@3oP0040?l000030?n0003o0000o`000080o`000P3oP003
0?l00080oh000P3o00020000o`80o`0000<0oh000?l0003o00000P3o00050?n00080003o0P3o0002
0?n000030000o`3oP000oh0000/0oh006?ooool001Kooooo0P3o000;003o00030?l00000o`000?l0
00L0o`001P3oP00@0?l000800?l01`3o00020000o`030?l0003oP000oh000080oh001`3o00020?n0
00<0o`000P000?l40?l00080oh000`3o00020000o`/0o`000P000?l50?l00080003o403o00020?n0
00<0o`000P3oP0090?l000kooooo10000?l9003o00h0o`000`00o`060?l000L0003o5000o`020?l0
00`00?l01@3o0006003o0080o`003000o`020?l000L00?l00P3o0002003o00030?l00000o`000?l0
00@00?l00P3o00000`00o`00o`000?l000020?l000@0003o0`3oP0020000o`kooooo1@00o`080?l0
00030000o`3o0000o`0000L0o`000P3oP0040?l000030?n0003o0000o`000080o`0010000?l30?n0
00@0o`001@00o`020?l000800?l00P3o0003003o00@0o`000`3oP0060?l000<00?l02@3o00020?n0
00@0o`0000<0003o0?l0003o00000P000?l20?n000D0003o0P3o0002003o00<0o`001`000?l20?l0
0080oh000P000?l20?n000<0003o0P3o00020?n000<0o`0010000?l>ooooo`80oh002@3o00050?n0
0080003o2`3oP0030000o`80o`000P00o`030?l000P0oh0000<0o`000?n0003oP0003@3oP0020?l0
00030?n0003o0000o`000080oh000P3o00000`3oP000o`000?l000020?l000T0oh00103o00000`3o
P000o`000?l000020?l00080oh000`3o00020?n00080o`000P000?l20?l000030?n0003o0000o`00
0080o`001@3oP0020000o`80o`000P3oP0000`000?l0oh000?n0000;0?n001Sooooo000Fooooo`80
o`000P00o`050?l000800?l03P3o00020?n000L0o`000P3oP0030?l000@0oh001000o`000`3o0000
003o0000o`040?l000<0003o0P3oP0020000o``0o`000P000?l20?l00080oh001`000?lB0?l000T0
0?l03P3o00020?n000D0o`00103oP00>ooooo`@0003o2@00o`0:0?l000d00?l01`000?lD003o00<0
o`003@00o`030?l002H00?l02@3o00040000o`<0oh000P000?l>ooooo`D00?l0203o00000`000?l0
o`000?l00002003o0100o`001`000?l90?l000/00?l0103o00000`000?l0o`000?l000050?l00080
0?l00P3o00070?n000H0o`002P000?l90?l00080003o1@3oP0040?l00080oh001@000?l20?l00080
oh000`000?l20?n00080003o3_ooool20?n00080003o00<00?l00?l0003o00000P3oP0020?l000D0
oh000P000?l90?n000<0o`0010000?l2003o0080o`000`000?l20?n00080003o0P3oP0000`3o0000
003o0000o`060?l000<0oh000P3o00020?n000800?l02P3oP0020?l000T0oh000P00o`020?l000D0
oh000P000?l20?l000L0oh000P3o00030?n00080o`000P3oP0000`3o0000oh000?n000070?n00080
003o0P3oP0020?l00080003o1@3oP00Hooooo`005_ooool20?l000800?l01@3o0002003o00h0o`00
0P3oP0070?l00080oh000`3o00040?n000@00?l000<0o`000000o`000?l0103o00030000o`80oh00
0P000?l<0?l00080003o0P3o00020?n000L0003o4P3o0009003o00h0o`000P3oP0050?l000@0oh00
3_ooool40000o`T00?l02P3o000=003o00L0003o5000o`030?l000d00?l00`3o000V003o00T0o`00
10000?l30?n00080003o3_ooool5003o00P0o`0000<0003o0?l0003o00000P00o`0@0?l000L0003o
2@3o000;003o00@0o`0000<0003o0?l0003o00001@3o0002003o0080o`001`3oP0060?l000X0003o
2@3o00020000o`D0oh00103o00020?n000D0003o0P3o00020?n000<0003o0P3oP0020000o`kooooo
0P3oP0020000o`03003o003o0000o`000080oh000P3o00050?n00080003o2@3oP0030?l000@0003o
0P00o`020?l000<0003o0P3oP0020000o`80oh0000<0o`000000o`000?l01P3o00030?n00080o`00
0P3oP002003o00X0oh000P3o00090?n000800?l00P3o00050?n00080003o0P3o00070?n00080o`00
0`3oP0020?l00080oh0000<0o`000?n0003oP0001`3oP0020000o`80oh000P3o00020000o`D0oh00
6?ooool001Kooooo1@3o0002003o00L0o`000P3oP0060?l000030?n0003o0000o`000080oh000P00
0?l00`00o`00o`000?l000090?l00080oh000P3o0002003o00030?l000000?l0003o00@0o`000P00
0?l00`3o0000oh000?n000020000oa00o`000P000?l20?n000L0o`000P000?l00`3o0000003o0000
o`020?l000@0003o00<0o`000?n0003oP0000P3o00020?n000800?l000<0o`00003o0000o`000P00
o`070?l00080oh001@3o00020?n000@0o`0000<0oh000?l0003o00000P3oP00>ooooo`@0oh002@00
o`0<0?l000/00?l01`000?lD003o00<0o`001000o`020?l000L00?l00`3o000X003o00T0o`001@3o
P0020000o`kooooo1000o`090?l000030000o`3o0000o`0000H00?l01@3o0002003o00<0o`000P00
o`050000o`80oh000P000?l50?n00080o`000P00o`040?l00003003o003o0000o`0000800?l0103o
00000`000?l0oh000?n000040?l00003003o003o0000o`000080003o2@3oP0040?l000030000o`3o
P000oh0000@0003o0`3oP0020?l00080003o0P3o00050000o`D0oh00103o00050?n000@0o`001@00
0?l20?n00080003o3_ooool20?n00080o`0000<0oh000?l0003o00000P3o000B0?n000<0o`001000
0?l2003o00<0o`001P3oP0030?l00080oh00103o000>0?n00080o`000`3oP0020?l00080003o0P3o
00070?n000@0o`001@3oP0020000o`<0oh000P000?l40?n00080o`000`3oP0020?l00080oh0000<0
o`000?n0003oP0001`3oP0020000o`/0oh006?ooool001Kooooo103o00000`00o`00o`000?l00004
0?l00080003o00<0o`00003o0000o`002@3o00020?n00080003o00<00?l00?l0003o00001P3o0000
0`3oP000o`000?l000070?l00080oh00103o00020000o`030?l0003oP000oh000080003o2@3o0002
0000o`030?l0003oP000oh000080o`000P000?l20?n000X0o`000P000?l20?l000@0003o00<0o`00
0?n0003oP000103o0007003o0080o`0000<0003o0?n0003oP0000P3o00020000o`T0o`000P3oP005
0?l000kooooo0P3oP0020?l000T00?l01@3o0002003o00<0o`002@00o`020?l000800?l01`000?lF
003o00030?n00000o`000?l000/00?l00P3o000@003o0080o`003000o`020?l000L00?l01`000?l4
0?l000D0oh000P000?l>ooooo`@0oh001`00o`020?l000030?n000000?l0003o00@0o`000P3oP00<
0?l000L0oh0010000?l30?n00080o`000P00o`040?l00003003o003o0000o`000080o`000P000?l2
0?l000030000o`3oP000oh0000L0o`001`000?l60?n00080o`001@000?l50?n00080o`000P000?l2
0?l000L0003o0P00o`050?l00080oh002@3o00070?n000kooooo0P000?l20?l000030000o`3oP000
oh000080o`002@3oP0020?l000<0oh000P3o00020?n000<0o`0010000?l2003o0080oh0000<0o`00
0?n0003oP0002@3oP0090?l000/0oh000P3o00000`3oP0000?l0003o0002003o00T0oh000P00o`02
0?l000030?n0003o0000o`000180oh000P00o`020?l000030000o`3oP000oh0001@0oh006?ooool0
01Kooooo103o00000`00o`00o`000?l000040?l00080003o00<0o`00003o0000o`002@3o00020?n0
0080003o00<00?l00?l0003o00001P3o00000`3oP000o`000?l000070?l00080oh00103o00020000
o`030?l0003oP000oh000080003o2@3o00020000o`030?l0003oP000oh000080o`000P000?l20?n0
00X0o`000P000?l20?l000@0003o00<0o`000?n0003oP000103o0007003o0080o`0000<0003o0?n0
003oP0000P3o00020000o`T0o`000P3oP0050?l000kooooo0P3oP0020?l000T00?l01@3o0002003o
00<0o`002@00o`020?l000800?l01`000?lF003o00030?n00000o`000?l000/00?l00P3o000@003o
0080o`003000o`020?l000L00?l01`000?l40?l000D0oh000P000?l>ooooo`@0oh001`00o`020?l0
00030?n000000?l0003o00@0o`000P3oP00<0?l000L0oh0010000?l30?n00080o`000P00o`040?l0
0003003o003o0000o`000080o`000P000?l20?l000030000o`3oP000oh0000L0o`001`000?l60?n0
0080o`001@000?l50?n00080o`000P000?l20?l000L0003o0P00o`050?l00080oh002@3o00070?n0
00kooooo0P000?l20?l000030000o`3oP000oh000080o`002@3oP0020?l000<0oh000P3o00020?n0
00<0o`0010000?l2003o0080oh0000<0o`000?n0003oP0002@3oP0090?l000/0oh000P3o00000`3o
P0000?l0003o0002003o00T0oh000P00o`020?l000030?n0003o0000o`000180oh000P00o`020?l0
00030000o`3oP000oh0001@0oh006?ooool001Kooooo0P00o`020?l000D00?l00P3o00020?n000`0
o`000P000?l20?l00003003o003o0000o`0000H0o`000`000?l70?l00080oh00103o0002003o0100
o`0000<0oh000000o`000?l00P3o00040?n000030?l000000?l0003o00@0o`000P000?l00`3o0000
003o0000o`020?l000@0003o00<0o`000?n0003oP000103o0003003o00H0o`0000<0003o0?n0003o
P000103oP0090?l00080003o1@3o000>ooooo`800?l00P3o0003003o0080o`001000o`090?l000X0
0?l00P3o0002003o00L0003o2`00o`020?l000L00?l00`3o0006003o00<0o`001000o`030?l000@0
0?l00P3o00020?n000X00?l01P3o0002003o00030?l00000o`000?l00080o`001`00o`050000o`80
oh000P3o00020000o`<0oh0010000?l>ooooo`@0oh001`00o`020?l000030?n000000?l0003o0080
o`000P3oP0020000o`<0oh002@3o00020?n00080o`002@000?l00`3oP000o`000?l000060?l00003
003o003o0000o`0000H0o`001@000?l20?l000030?n0003o0000o`0000L0003o103oP0020000o`80
o`000`3oP0020?l000@0oh0000<0003o0?l0003o00001`000?l20?n000@0o`000`00o`020?l000@0
oh0000<0o`000?n0003oP0000P000?l20?l000L0oh003_ooool20?n00080o`0000<0003o0?l0003o
00002`3oP0070?l00080003o0P00o`000`3o00000?l0003o0006003o00030?l00000o`000?l000@0
o`000P3oP0000`3o0000oh000?n000020?l000D0oh001P000?l20?n000<0o`001@3oP0020?l000@0
003o0P3oP0000`000?l0oh000?n000020?n00080o`000P3oP0000`3o0000oh000?n000090?n00080
o`001`3oP0020?l00080003o5`3oP00Hooooo`005_ooool2003o0080o`001@00o`020?l00080oh00
303o00020000o`80o`0000<00?l00?l0003o00001P3o00030000o`L0o`000P3oP0040?l000800?l0
403o00000`3oP000003o0000o`020?l000@0oh0000<0o`000000o`000?l0103o00020000o`030?l0
00000?l0003o0080o`0010000?l00`3o0000oh000?n000040?l000<00?l01P3o00000`000?l0oh00
0?n000040?n000T0o`000P000?l50?l000kooooo0P00o`020?l000<00?l00P3o0004003o00T0o`00
2P00o`020?l000800?l01`000?l;003o0080o`001`00o`030?l000H00?l00`3o0004003o00<0o`00
1000o`020?l00080oh002P00o`060?l000800?l000<0o`00003o0000o`000P3o0007003o00D0003o
0P3oP0020?l00080003o0`3oP0040000o`kooooo103oP007003o0080o`0000<0oh000000o`000?l0
0P3o00020?n00080003o0`3oP0090?l00080oh000P3o00090000o`030?n0003o0000o`0000H0o`00
00<00?l00?l0003o00001P3o00050000o`80o`0000<0oh000?l0003o00001`000?l40?n00080003o
0P3o00030?n00080o`00103oP0000`000?l0o`000?l000070000o`80oh00103o0003003o0080o`00
103oP0000`3o0000oh000?n000020000o`80o`001`3oP00>ooooo`80oh000P3o00000`000?l0o`00
0?l0000;0?n000L0o`000P000?l2003o00030?l00000o`000?l000H00?l000<0o`00003o0000o`00
103o00020?n000030?l0003oP000oh000080o`001@3oP0060000o`80oh000`3o00050?n00080o`00
10000?l20?n000030000o`3oP000oh000080oh000P3o00020?n000030?l0003oP000oh0000T0oh00
0P3o00070?n00080o`000P000?lG0?n001Sooooo000Fooooo`T00?l00P3o00020?n000<0o`000P00
o`020?l00080003o0`3o0005003o00@0o`000P3oP0030?l00080003o1`3o00020?n000L0o`000P00
0?l20?n00080o`000`000?l60?l000<0oh000P3o00020?n000<0o`000P000?l70?l00080003o0P3o
P0040000o`030?l0003oP000oh000080o`000P000?l90?l000L0oh002@3o00020000o`D0o`003_oo
oolD003o00<0o`002@00o`040?l000L0003o2`00o`020?l00003003o003o0000o`0000800?l01`3o
0004003o00`0o`000P00o`020?n000D00?l0103o000;003o00030?l00000o`000?l000T00?l00P00
0?l20?l000030000o`3oP000oh000080o`0010000?l00`3oP000003o0000o`020000o`kooooo0P3o
P0020000o`D00?l00P000?l30?l00080oh000P3o00020?n00080o`0000<0oh000?l0003o00001@3o
00020?n00080o`001@3oP0080000o`030?n0003o0000o`0000800?l01`3o0002003o00@0o`0000<0
oh000?l0003o00000P000?l90?n000<0003o0P3oP0040000o`80o`0000<0003o0?n0003oP0000P3o
00090?n00080o`000P3oP0030000o`@0o`0000<00?l00000o`000?l01P000?l30?n00080003o103o
00030000o`80oh003_ooool20?n00080o`0000<0003o0?n0003oP000103oP0020000o`<0o`000P00
o`050?l00080oh000P000?l20?n000030?l00000o`000?l000H0o`0000<00?l00?l0003o00000P3o
00020?n00080003o0`3oP0020?l000D0oh0010000?l50?n00080o`000P3oP0020?l000030000o`3o
P000oh000080o`001@000?l40?n000800?l00P3o00000`3oP000o`000?l000070?n000@0003o5@3o
P0020?l00080oh000P3o00070?n001Sooooo000Fooooo`T00?l00P3o00020?n000<0o`000P00o`02
0?l00080003o0`3o0005003o00@0o`000P3oP0030?l00080003o1`3o00020?n000L0o`000P000?l2
0?n00080o`000`000?l60?l000<0oh000P3o00020?n000<0o`000P000?l70?l00080003o0P3oP004
0000o`030?l0003oP000oh000080o`000P000?l90?l000L0oh002@3o00020000o`D0o`003_oooolD
003o00<0o`002@00o`040?l000L0003o2`00o`020?l00003003o003o0000o`0000800?l01`3o0004
003o00`0o`000P00o`020?n000D00?l0103o000;003o00030?l00000o`000?l000T00?l00P000?l2
0?l000030000o`3oP000oh000080o`0010000?l00`3oP000003o0000o`020000o`kooooo0P3oP002
0000o`D00?l00P000?l30?l00080oh000P3o00020?n00080o`0000<0oh000?l0003o00001@3o0002
0?n00080o`001@3oP0080000o`030?n0003o0000o`0000800?l01`3o0002003o00@0o`0000<0oh00
0?l0003o00000P000?l90?n000<0003o0P3oP0040000o`80o`0000<0003o0?n0003oP0000P3o0009
0?n00080o`000P3oP0030000o`@0o`0000<00?l00000o`000?l01P000?l30?n00080003o103o0003
0000o`80oh003_ooool20?n00080o`0000<0003o0?n0003oP000103oP0020000o`<0o`000P00o`05
0?l00080oh000P000?l20?n000030?l00000o`000?l000H0o`0000<00?l00?l0003o00000P3o0002
0?n00080003o0`3oP0020?l000D0oh0010000?l50?n00080o`000P3oP0020?l000030000o`3oP000
oh000080o`001@000?l40?n000800?l00P3o00000`3oP000o`000?l000070?n000@0003o5@3oP002
0?l00080oh000P3o00070?n001Sooooo000Fooooo`T00?l02`3o00020?n000D0o`000`00o`0F0?l0
00@00?l00`3o00020?n00080o`000P000?lJ0?l00080003o0P3o00040?n00100o`0000<0003o0?l0
003o00000P3o00020?n000T0o`000P000?l30?l00080oh003_ooool7003o00@0o`001`00o`050?l0
00L00?l0103o0002003o00L0003o2`00o`020?l000D00?l01`3o0002003o00`0o`001000o`040?n0
00<00?l01P3o0005003o0080o`000P00o`000`3o00000?l0003o0004003o00030?l00000o`000?l0
00800?l00P000?l20?l000030?n000000?l0003o0080o`0010000?l00`3o0000003o0000o`020000
o`kooooo0P3oP0020000o`D00?l00P000?l30?l00080oh000P3o00050?n000@0o`000P00o`070?l0
00`0oh001000o`020?l000D00?l00P3o0004003o00L0003o0`3oP0020000o`80oh000`000?l20?n0
00@0003o0P3oP0000`000?l0oh000?n000020?n000@0003o0`3oP0020000o`80o`000P00o`000`3o
0000003o0000o`020000o`80o`002@000?l30?n00080003o103o00050000o`kooooo0P3oP0020?l0
00<0oh000P3o00040?n000T0o`001`3oP0070?l000800?l00`3oP0020?l00080oh001@3o000;0?n0
0080003o0`3oP0020000o`D0oh000P3o00020?n00080o`002@000?l20?n000030?l0003oP000oh00
0080oh000P3o00030?n00080003o5P3oP0000`00o`00oh000?n000020?n00080o`001@3oP0020?l0
01Sooooo000Fooooo`800?l00`3o0002003o00d0o`000P3oP00C0?l000800?l02`3o0002003o00<0
o`000P3oP0020?l000<0003o0P3o00020?n00080o`0000<0oh000?l0003o00000P3o00020000o`/0
o`000`3oP00F0?l000030?n0003o0000o`0000d0o`000P000?l30?l00080oh003_ooool7003o0080
o`002@00o`070?l000@00?l00`3o00020?n000800?l01`000?lD003o00<0o`001000o`030?l000@0
oh000P000?l30?l000800?l01P3oP0000`3o00000?l0003o000;003o0080o`000P00o`030?l000/0
0?l00`3o00020000o`80o`0010000?l30?n00080003o3_ooool40?n000D00?l01@3o00020?n000T0
o`000P00o`030?l00080oh000P3o00070?n000@0o`000P3oP0030?l000800?l00P3o0009003o0080
o`001`000?l30?n00080003o0P3oP0030000o`80oh001P000?l50?l000T0003o1@00o`020000o`80
o`000P3oP0000`000?l0o`000?l000020?l000@0oh001@000?l2003o0080o`001@000?l>ooooo`80
o`001@3oP0020?l000@0oh001@3o000;0?n000030?l0003oP000oh0000H0oh0000<0o`000?n0003o
P0002@3o00070?n00080o`000P3oP0020000o`<0oh0010000?l30?n00080o`000P000?l20?n000D0
003o403oP0020000o`/0oh000P3o00000`3oP000003o0000o`060?n00003003o003oP000oh0000T0
oh000P3o000Hooooo`005_ooool2003o00<0o`000P00o`0=0?l00080oh004`3o0002003o00/0o`00
0P00o`030?l00080oh000P3o00030000o`80o`000P3oP0020?l000030?n0003o0000o`000080o`00
0P000?l;0?l000<0oh005P3o00000`3oP000o`000?l0000=0?l00080003o0`3o00020?n000kooooo
1`00o`020?l000T00?l01`3o0004003o00<0o`000P3oP002003o00L0003o5000o`030?l000@00?l0
0`3o00040?n00080003o0`3o0002003o00H0oh0000<0o`00003o0000o`002`00o`020?l000800?l0
0`3o000;003o00<0o`000P000?l20?l000@0003o0`3oP0020000o`kooooo103oP005003o00D0o`00
0P3oP0090?l000800?l00`3o00020?n00080o`001`3oP0040?l00080oh000`3o0002003o0080o`00
2@00o`020?l000L0003o0`3oP0020000o`80oh000`000?l20?n000H0003o1@3o00090000o`D00?l0
0P000?l20?l00080oh0000<0003o0?l0003o00000P3o00040?n000D0003o0P00o`020?l000D0003o
3_ooool20?l000D0oh000P3o00040?n000D0o`002`3oP0000`3o0000oh000?n000060?n000030?l0
003oP000oh0000T0o`001`3oP0020?l00080oh000P000?l30?n000@0003o0`3oP0020?l00080003o
0P3oP0050000oa00oh000P000?l;0?n00080o`0000<0oh000000o`000?l01P3oP0000`00o`00oh00
0?n000090?n00080o`006?ooool001Kooooo0P3o0003003o00T0o`000P3oP0040?l00080oh00403o
00000`000?l0o`000?l000090?l000800?l00P3o0002003o00030?l000000?l0003o0080oh000P3o
00030000o`80o`000P3oP0030?l00080003o0P3o00040000o`030?l0003oP000oh0000d0o`000`00
o`080?l000030?n0003o0000o`0000@0o`0000<0003o0?l0003o00001`3o00020?n000@0o`000P00
0?l50?l000kooooo5000o`020?l000P00?l00P3o0004003o00L0003o4P00o`050?l000@00?l00`3o
00020?n00080o`000P000?l30?l000800?l01P3o00000`3oP0000?l0003o000F003o00030?l00000
o`000?l000@00?l00`3o00020000o`80o`0010000?l00`3oP000003o0000o`020?l000kooooo0P3o
0002003o00030?l00000o`000?l000@00?l00`3o0002003o00T0o`000P000?l30?l00080003o0P3o
00070?n00080o`000P3oP0020000o`T0o`001`00o`020?l000030000o`3oP000oh0000@0003o00<0
oh000?l0003o00000P000?l20?n000<0003o1P3oP002003o00D0o`001`000?l40?l000<00?l0103o
00020?n000D0o`001`3oP0020000o`@0o`0000<0003o0?n0003oP0000P000?l>ooooo`800?l00`3o
00020?n00080o`000P3oP002003o00030?n0003o0000o`000080o`002`3oP0030000o`@0oh000P00
0?l70?n00080o`000`3oP0020?l000D0oh000P3o00040?n00080003o00<0oh000000o`000?l01@3o
P0040000o`80oh000P000?lP0?n000<0003o0P3oP0020000o`@0oh0000<0o`000?n0003oP0002`3o
P00Hooooo`005_ooool20?l000<00?l02@3o00020?n000@0o`000P3oP00@0?l000030000o`3o0000
o`0000T0o`000P00o`020?l000800?l000<0o`000000o`000?l00P3oP0020?l000<0003o0P3o0002
0?n000<0o`000P000?l20?l000@0003o00<0o`000?n0003oP0003@3o0003003o00P0o`0000<0oh00
0?l0003o0000103o00000`000?l0o`000?l000070?l00080oh00103o00020000o`D0o`003_oooolD
003o0080o`002000o`020?l000@00?l01`000?lB003o00D0o`001000o`030?l00080oh000P3o0002
0000o`<0o`000P00o`060?l000030?n00000o`000?l001H00?l000<0o`00003o0000o`001000o`03
0?l00080003o0P3o00040000o`030?n000000?l0003o0080o`003_ooool20?l000800?l000<0o`00
003o0000o`001000o`030?l000800?l02@3o00020000o`<0o`000P000?l20?l000L0oh000P3o0002
0?n00080003o2@3o0007003o0080o`0000<0003o0?n0003oP00010000?l00`3oP000o`000?l00002
0000o`80oh000`000?l60?n000800?l01@3o00070000o`@0o`000`00o`040?l00080oh001@3o0007
0?n00080003o103o00000`000?l0oh000?n000020000o`kooooo0P00o`030?l00080oh000P3o0002
0?n000800?l000<0oh000?l0003o00000P3o000;0?n000<0003o103oP0020000o`L0oh000P3o0003
0?n00080o`001@3oP0020?l000@0oh000P000?l00`3oP000003o0000o`050?n000@0003o0P3oP002
0000ob00oh000`000?l20?n00080003o103oP0000`3o0000oh000?n0000;0?n001Sooooo000Foooo
o`800?l02@3o00020000o`L0o`000P000?l>0?l00080oh000`00o`0@0?l00080003o0P3oP0020?l0
0080oh000`3o00020?n000<0o`000P000?l20?l000@0003o00<0o`000?n0003oP0000P3o00040000
o`L0o`000`00o`040?l000800?l00`3o0004003o0080o`000`000?l20?l00080003o0`3o00020000
o`@0o`000P000?l30?l00080oh003_ooool7003o0080o`006`00o`070000o`h00?l0203o0005003o
00L0o`000P000?l30?l000H00?l00P3o000:003o0080o`002@00o`020?l000/00?l01@3o00020?n0
0080003o0`3oP0020?l000kooooo0P00o`020?l000T00?l000<0o`00003o0000o`00103o0003003o
0080o`000P3oP0090?l00080oh0000<0o`000?n0003oP0000P3o00020?n00080003o00<0oh00003o
0000o`001`3o0004003o00D0003o103oP0020000o`D0o`001@000?l40?n00080o`000`00o`040?l0
0080oh000P000?l30?n000H0o`0000<00?l00?l0003o00000P3o00020000o`030?l00000o`000?l0
0080o`000P3oP0030000o`@0oh000P3o0002003o00030?n0003o0000o`000080oh003_ooool2003o
0080o`001`3oP005003o0080o`001@3oP0020000o`@0o`003P3oP0020000o`800?l00`3oP0020?l0
0080003o0`3oP0020?l000L0oh000P000?l50?n000@0003o0P3oP0020000ob00oh000P3o00050?n0
00@0003o00<0oh000?l0003o0000103oP0020?l000D0oh006?ooool001Kooooo0P00o`090?l00080
003o1`3o00020000o`h0o`000P3oP003003o0100o`000P000?l20?n00080o`000P3oP0030?l00080
oh000`3o00020000o`80o`0010000?l00`3o0000oh000?n000020?l000@0003o1`3o0003003o00@0
o`000P00o`030?l000@00?l00P3o00030000o`80o`000P000?l30?l00080003o103o00020000o`<0
o`000P3oP00>ooooo`L00?l00P3o000K003o00L0003o3P00o`080?l000D00?l01`3o00020000o`<0
o`001P00o`020?l000X00?l00P3o0009003o0080o`002`00o`050?l00080oh000P000?l30?n00080
o`003_ooool2003o0080o`002@00o`000`3o00000?l0003o00040?l000<00?l00P3o00020?n000T0
o`000P3oP0000`3o0000oh000?n000020?l00080oh000P000?l00`3oP0000?l0003o00070?l000@0
0?l01@000?l40?n00080003o1@3o00050000o`@0oh000P3o0003003o00@0o`000P3oP0020000o`<0
oh001P3o00000`00o`00o`000?l000020?l00080003o00<0o`00003o0000o`000P3o00020?n000<0
003o103oP0020?l000800?l000<0oh000?l0003o00000P3oP00>ooooo`800?l00P3o00070?n000D0
0?l00P3o00050?n00080003o103o000>0?n00080003o0P00o`030?n00080o`000P000?l30?n00080
o`001`3oP0020000o`D0oh0010000?l20?n00080003o803oP0020?l000D0oh0010000?l00`3oP000
o`000?l000040?n00080o`001@3oP00Hooooo`005_ooool50?l00080oh00103o0002003o00X0o`00
10000?l@0?l000800?l0303o00020000o`H0o`0000<0003o0?l0003o00000P3oP0030?l00080003o
0P3o00040000o`D0o`0010000?l70?l00080003o1@3o0002003o00<0o`000P00o`020000o`80o`00
0`000?l20?l00080oh000`3o00020000o`800?l00P3o00020000o`D0o`003_ooool7003o00@0o`00
6@00o`070000oa@00?l00P3o0005003o00/0o`0000<0003o003o0000o`001000o`030?l001@00?l0
1@3o0009003o00H0o`000P3oP0050?l000kooooo2@00o`020?l000800?l0303o0002003o00L0o`00
0P3oP0030000o`80oh000P000?l40?n000030000o`00o`000?l00080o`000P00o`0;0?l000<0oh00
2@3o00070000oa@0o`000P000?l20?l000030?n0003o0000o`0000@0o`000`00o`070000o`80o`00
0P3oP0090?l000kooooo0P00o`030?l00080oh000P3o00050?n000800?l00P3o00040?n000<0003o
103o00070?n000D0o`00103oP0020?l000X0oh000P3o000@0?n00080003o3P3oP0020000oaT0oh00
0P000?lB0?n001Sooooo000Fooooo`D0o`000P3oP0040?l000800?l02P3o00040000oa00o`000P00
o`0<0?l00080003o1P3o00000`000?l0o`000?l000020?n000<0o`000P000?l20?l000@0003o1@3o
00040000o`L0o`000P000?l50?l000800?l00`3o0002003o0080003o0P3o00030000o`80o`000P3o
P0030?l00080003o0P00o`020?l00080003o1@3o000>ooooo`L00?l0103o000I003o00L0003o5000
o`020?l000D00?l02`3o00000`000?l00?l0003o0004003o00<0o`005000o`050?l000T00?l01P3o
00020?n000D0o`003_ooool9003o0080o`000P00o`0<0?l000800?l01`3o00020?n000<0003o0P3o
P0020000o`@0oh0000<0003o003o0000o`000P3o0002003o00/0o`000`3oP0090?l000L0003o503o
00020000o`80o`0000<0oh000?l0003o0000103o0003003o00L0003o0P3o00020?n000T0o`003_oo
ool2003o00<0o`000P3oP0020?l000D0oh000P00o`020?l000@0oh000`000?l40?l000L0oh001@3o
00040?n00080o`002P3oP0020?l00100oh000P000?l>0?n00080003o6@3oP0020000oa80oh006?oo
ool001Kooooo5`3o00040000oaD0o`000P3oP0020?l00080oh000`3o00040000oa00o`0010000?l:
0?l00080003o103o00020000o`03003o003o0000o`000080o`000P00o`030?l000@00?l00`3o0002
0?n00080o`00103oP0000`3o0000oh000?n0000;0?l000kooooo2@00o`020?l000<00?l00P3o0004
003o0080o`003P00o`030000o`80o`000P000?l@003o00L0o`001000o`070?l000@0oh001`00o`03
0?l001@00?l01@3o000;003o00H0o`0000<0oh000?l0003o00000P3o000>ooooo`@0o`003000o`09
0?l000@00?l00`3o00020000o`80o`000`000?l80?l000030000o`3o0000o`0000T0o`000P00o`04
0?l000030?n0003o0000o`0000@0o`0000<00?l00?l0003o00000P3o00020000o`D0oh002@3o0004
003o0080o`0000<0003o0?n0003oP0000P000?l20?n00080o`0000<0oh000000o`000?l0103o0000
0`3oP000o`000?l000020000o`80o`000P3oP0000`000?l0o`000?l000020?l000800?l01@3o0002
0?n000kooooo0P3o00020?n000030?l0003oP000oh0000L0oh000P3o00040?n000800?l000<0o`00
0?n0003oP0000P00o`030?n000H0o`000P000?l30?l000/0oh000P000?l20?n000030?l0003oP000
oh000080003o103oP0000`000?l0oh000?n000040?n000<0003o103oP0020?l000030?n000000?l0
003o0080o`000P3oP0020000o`030?n000000?l0003o00L0oh000P3o00040?n00080o`005`3oP003
0000o`@0oh006?ooool001Kooooo0P3o00020000o`L0o`000P00o`0:0?l000@0003o7P3o00040000
oa00o`000P000?lB0?l00080003o1`00o`030?l000800?l01@3o00020?n00080o`000P3oP0020000
o`L0o`000P3oP0000`000?l0o`000?l000020?l000kooooo1000o`070?l000T00?l00P3o0007003o
00030?l00000o`000?l000@00?l01@3o00020?n000T00?l00P3o0009003o00<0o`001P00o`030?l0
00@0003o0`3oP006003o00<0o`005000o`040?l00003003o003o0000o`0000800?l0103o0003003o
00/0o`003_ooool20000o`80o`0000<00?l00?l0003o00000P00o`070?l000@00?l01`3o0003003o
00H0o`000P3oP00<0?l000L00?l00P3o0004003o00<0o`000P3oP0040?l00003003o003o0000o`00
00@0o`000`3oP0040?l00080oh000P3o00000`000?l0o`000?l000020?l000T0003o0P3oP0020?l0
00030?n000000?l0003o0080003o0P3o00030?n00080003o103oP0000`000?l0oh000?n000020?l0
00800?l01@3o00020?n000kooooo0P3o00020?n000030?l0003oP000oh0000@0oh000P000?l50?l0
00L0oh000P00o`050?l00080003o0P3o00020?n000030000o`3oP000oh000080o`000P00o`070?n0
0080003o0P00o`000`3o0000oh000?n000060000o`P0oh000P000?l40?n00080o`0000<0003o0?l0
003o0000103o00090?n000<0003o403oP0020?l000@0oh001@000?l60?n000030000o`3oP000oh00
0080oh006?ooool001Kooooo0P3o00020000o`L0o`000P00o`0:0?l000@0003o7P3o00040000oa00
o`000P000?lB0?l00080003o1`00o`030?l000800?l01@3o00020?n00080o`000P3oP0020000o`L0
o`000P3oP0000`000?l0o`000?l000020?l000kooooo1000o`070?l000T00?l00P3o0007003o0003
0?l00000o`000?l000@00?l01@3o00020?n000T00?l00P3o0009003o00<0o`001P00o`030?l000@0
003o0`3oP006003o00<0o`005000o`040?l00003003o003o0000o`0000800?l0103o0003003o00/0
o`003_ooool20000o`80o`0000<00?l00?l0003o00000P00o`070?l000@00?l01`3o0003003o00H0
o`000P3oP00<0?l000L00?l00P3o0004003o00<0o`000P3oP0040?l00003003o003o0000o`0000@0
o`000`3oP0040?l00080oh000P3o00000`000?l0o`000?l000020?l000T0003o0P3oP0020?l00003
0?n000000?l0003o0080003o0P3o00030?n00080003o103oP0000`000?l0oh000?n000020?l00080
0?l01@3o00020?n000kooooo0P3o00020?n000030?l0003oP000oh0000@0oh000P000?l50?l000L0
oh000P00o`050?l00080003o0P3o00020?n000030000o`3oP000oh000080o`000P00o`070?n00080
003o0P00o`000`3o0000oh000?n000060000o`P0oh000P000?l40?n00080o`0000<0003o0?l0003o
0000103o00090?n000<0003o403oP0020?l000@0oh001@000?l60?n000030000o`3oP000oh000080
oh006?ooool001Kooooo0P3o00020000oa00o`000P000?l30?l00080003o0P3o00000`000?l0o`00
0?l000070?l00080003o903o00020?n00180o`000P000?l7003o00<0o`000P000?l2003o00<0o`00
0P000?l20?l00080oh000P000?l00`00o`00o`000?l000020?l000D0oh00103o000>oooooa800?l0
103o0007003o00030?l00000o`000?l000H00?l01@3o0007003o00H0o`000`00o`020?l000800?l0
0`3o0006003o00<0o`001`000?l6003o00<0o`005000o`040?l000<00?l00P3o0002003o0080o`00
0`00o`020?l000@00?l01@3o000>oooooa00o`001000o`030?l00080003o0P3o0002003o00L0o`00
0P3oP0030000o`80o`000P000?l20?l000030?n0003o0000o`000080o`001@00o`040?l00080003o
0`3o00020?n000/0o`000`3oP0020000o`H0o`000`000?l20?l000L0003o0P3o00020?n00080o`00
00<0oh000?l0003o000040000?l90?l00080oh003_ooool20?l000T0oh000P3o00000`00o`00o`00
0?l000020000o`L0oh000P00o`030?l000@0oh000P000?l20?n000030?l000000?l0003o00H0o`00
1`3oP0020?l000030000o`3oP000oh000080003o403oP0040?l000030?n0003o0000o`0000@0003o
403oP0020000o`X0oh000P000?l60?n000<0003o1P3oP0030000o`80oh006?ooool001Kooooo0P3o
00020000oa00o`000P000?l30?l00080003o0P3o00000`000?l0o`000?l000070?l00080003o903o
00020?n00180o`000P000?l7003o00<0o`000P000?l2003o00<0o`000P000?l20?l00080oh000P00
0?l00`00o`00o`000?l000020?l000D0oh00103o000>oooooa800?l0103o0007003o00030?l00000
o`000?l000H00?l01@3o0007003o00H0o`000`00o`020?l000800?l00`3o0006003o00<0o`001`00
0?l6003o00<0o`005000o`040?l000<00?l00P3o0002003o0080o`000`00o`020?l000@00?l01@3o
000>oooooa00o`001000o`030?l00080003o0P3o0002003o00L0o`000P3oP0030000o`80o`000P00
0?l20?l000030?n0003o0000o`000080o`001@00o`040?l00080003o0`3o00020?n000/0o`000`3o
P0020000o`H0o`000`000?l20?l000L0003o0P3o00020?n00080o`0000<0oh000?l0003o00004000
0?l90?l00080oh003_ooool20?l000T0oh000P3o00000`00o`00o`000?l000020000o`L0oh000P00
o`030?l000@0oh000P000?l20?n000030?l000000?l0003o00H0o`001`3oP0020?l000030000o`3o
P000oh000080003o403oP0040?l000030?n0003o0000o`0000@0003o403oP0020000o`X0oh000P00
0?l60?n000<0003o1P3oP0030000o`80oh006?ooool001Kooooo2`3o00020?n000<0o`000P00o`02
0?l00080003o4`3o0002003o01@0o`000P3oP00:0?l000800?l02@3o00020?n00100o`000P00o`0>
0?l00080oh001@3o00040000o`<0oh00103o000>oooooa800?l0103o000N003o00@0o`000`00o`04
0?l000800?l000<0o`00003o0000o`001000o`030?l000L0003o1P00o`030?l001l00?l01`3o0004
003o00<0o`000P00o`0>oooooa80o`000P00o`0:0?l00080003o0P3oP0020?l00080oh002@000?l0
0`3oP000003o0000o`040?l000D00?l01`3o00040?n000T0o`001`3oP0050?l000T0003o0P3oP006
0?l000030?n0003o0000o`0000h0003o0P3oP0090?l00080oh003_ooool=0?n000030?l0003oP000
oh000080003o103oP0000`000?l0oh000?n000040?l000030?n000000?l0003o00@0oh000P3o0000
0`3oP000003o0000o`020?l000/0oh000P3o00050000o`D0oh00103o00090?n00080o`001@3oP002
0000o`80oh0000<0003o0?n0003oP0000P000?l20?n000<0003o103oP0020?l000T0oh0000<0003o
0?n0003oP0000P3oP0020000o`80oh0000<0003o0?n0003oP0000P3o00040?n000<0003o0P3oP00H
ooooo`005_ooool;0?l00080oh000`3o0002003o0080o`000P000?lC0?l000800?l0503o00020?n0
00X0o`000P00o`090?l00080oh00403o0002003o00h0o`000P3oP0050?l000@0003o0`3oP0040?l0
00kooooo4P00o`040?l001h00?l0103o0003003o00@0o`000P00o`000`3o00000?l0003o0004003o
00<0o`001`000?l6003o00<0o`007`00o`070?l000@00?l00`3o0002003o00kooooo4P3o0002003o
00X0o`000P000?l20?n00080o`000P3oP0090000o`030?n000000?l0003o00@0o`001@00o`070?l0
00@0oh002@3o00070?n000D0o`002@000?l20?n000H0o`0000<0oh000?l0003o00003P000?l20?n0
00T0o`000P3oP00>ooooo`d0oh0000<0o`000?n0003oP0000P000?l40?n000030000o`3oP000oh00
00@0o`0000<0oh000000o`000?l0103oP0020?l000030?n000000?l0003o0080o`002`3oP0020?l0
00D0003o1@3oP0040?l000T0oh000P3o00050?n00080003o0P3oP0000`000?l0oh000?n000020000
o`80oh000`000?l40?n00080o`002@3oP0000`000?l0oh000?n000020?n00080003o0P3oP0000`00
0?l0oh000?n000020?l000@0oh000`000?l20?n001Sooooo000Fooooo`/0o`000P3oP0030?l00080
0?l00P3o00020000o`L0o`0000<00?l00?l0003o00002@3o0002003o00L0o`000P00o`0;0?l00080
oh0000<0o`000?n0003oP0003@3o00000`3oP000o`000?l000020?l00080003o403o0002003o00D0
o`000P00o`070?l00080oh002@3o00030?n000@0o`003_ooool40?l000`00?l01P3o000`003o00D0
o`001`000?l8003o00<0o`002`00o`020?l000<00?l00P3o000;003o00L0o`000P000?l5003o0080
o`003_ooool90?l00080003o0P3oP0000`3o0000oh000?n000020?n000800?l00P3oP0030?l00080
oh000`3o00020?n00080003o0P3o00020?n000030?l000000?l0003o00T0003o1P3o0003003o0080
o`000P00o`030?l00080003o0P00o`030?l00080003o0P3o00020000o`L0oh000P000?l2003o0003
0?l000000?l0003o0080o`0010000?l30?n000H0o`0000<0003o0?l0003o000010000?l:0?n000/0
o`000P000?l>ooooo`80o`000`3oP0040?l000800?l00`3o00080?n000030000o`3oP000oh0000@0
0?l00`3o00040?n00080o`001@00o`0;0?n00080o`000`3oP0020000o`D0oh00103o000@0?n000@0
003o0`3oP0070000oaT0oh000P000?l20?l000@0003o00<0oh000000o`000?l00P3oP00Hooooo`00
5_ooool;0?l00080oh000`3o0002003o0080o`000P000?l70?l00003003o003o0000o`0000T0o`00
0P00o`070?l000800?l02`3o00020?n000030?l0003oP000oh0000d0o`0000<0oh000?l0003o0000
0P3o00020000oa00o`000P00o`050?l000800?l01`3o00020?n000T0o`000`3oP0040?l000kooooo
103o000<003o00H0o`00<000o`050?l000L0003o2000o`030?l000/00?l00P3o0003003o0080o`00
2`00o`070?l00080003o1@00o`020?l000kooooo2@3o00020000o`80oh0000<0o`000?n0003oP000
0P3oP002003o0080oh000`3o00020?n000<0o`000P3oP0020000o`80o`000P3oP0000`3o0000003o
0000o`090000o`H0o`000`00o`020?l000800?l00`3o00020000o`800?l00`3o00020000o`80o`00
0P000?l70?n00080003o0P00o`000`3o0000003o0000o`020?l000@0003o0`3oP0060?l000030000
o`3o0000o`0000@0003o2P3oP00;0?l00080003o3_ooool20?l000<0oh00103o0002003o00<0o`00
203oP0000`000?l0oh000?n00004003o00<0o`00103oP0020?l000D00?l02`3oP0020?l000<0oh00
0P000?l50?n000@0o`00403oP0040000o`<0oh001`000?lI0?n00080003o0P3o00040000o`030?n0
00000?l0003o0080oh006?ooool001Kooooo2`3o00020?n000<0o`000P000?l90?l000800?l00`00
0?l20?l00080oh000`3o0006003o01L0o`000P3oP00@0?l00080003o3P3o0004003o00T0o`0000<0
003o0?l0003o00000P3o00020000o`T0o`000P3oP0050?l000kooooo4000o`060?l000P00?l0103o
000D003o0080o`001`00o`030?l00080oh000P00o`050?l000L0003o2000o`030?l000T00?l0103o
0003003o00@0o`002@00o`070?l00080003o1`00o`0>ooooo`800?l00P3o0003003o00@0o`000P3o
P0030?l00080003o1`3o00020?n00080003o00<0o`000?n0003oP0000P3oP0020?l00080oh0000<0
o`000000o`000?l00P3oP0070000o`@0o`000`00o`090?l000H0oh001@3o000;0000o`<0o`000P3o
P0020?l00080oh000P000?l00`3oP000o`000?l000060?l000L0003o1@3oP0020?l000D0oh001`3o
00020?n00080003o3_ooool20?l000D0oh000P00o`040?l000T0oh0000<0003o0?l0003o00001000
o`000`3oP000003o0000o`040000o`L00?l03P3oP0020?l00080003o1@3oP002003o0080oh001@00
0?l20?n00080003o303oP0020?l00080oh000P000?l20?n000030000o`3o0000o`0000@0o`000P3o
P0000`3o0000oh000?n000050?n00080o`000P3oP0050?l00080oh00103o00020000o`<0oh000P00
o`0Hooooo`005_ooool4003o00030?l000000?l0003o00T0o`000P000?l20?l00080oh001@3o0002
003o00D0o`000P3oP0050?l000@00?l06`3o00000`000?l0o`000?l0000?0?l000030000o`3o0000
o`000080o`001000o`030?l00080003o1`3o0002003o0080o`0000<0003o0?l0003o00000P3o0002
0000o`T0o`000P000?l50?l000kooooo3P00o`080?l000P00?l0103o00020000oaL00?l01`3o0002
0?n000@00?l00`3o00070000o`P00?l00`3o000;003o0080o`000`00o`0;0?l000@00?l01@3o0002
0000o`D00?l00P3o000>ooooo`@0o`001@00o`020?l000L0oh001000o`030000o`80oh000`000?l2
0?l00080oh000P3o00020?n000030000o`3oP000oh000080oh000P000?l50?n00080o`001@00o`09
0?l000H0oh0000<00?l00?l0003o00000P3o000;0000o`800?l01`3oP0070?l00080003o0P3o0007
0000o`X0o`000P000?l90?n00080003o3_ooool50?n00080003o0P3oP002003o00`0oh001000o`02
0?l000030?n000000?l0003o00@0003o0P00o`000`3oP000o`000?l000020000o`80oh000P3o0000
0`000?l0oh000?n000090?n00080003o0P3oP0020000o`D0oh002@000?l;0?n000030000o`3o0000
o`0000T0oh000P3o00090?n00080o`000`3oP002003o00D0o`001000o`020?n00080003o1@3oP00H
ooooo`005_ooool4003o00030?l000000?l0003o00T0o`000P000?l20?l00080oh001@3o0002003o
00D0o`000P3oP0050?l000@00?l06`3o00000`000?l0o`000?l0000?0?l000030000o`3o0000o`00
0080o`001000o`030?l00080003o1`3o0002003o0080o`0000<0003o0?l0003o00000P3o00020000
o`T0o`000P000?l50?l000kooooo3P00o`080?l000P00?l0103o00020000oaL00?l01`3o00020?n0
00@00?l00`3o00070000o`P00?l00`3o000;003o0080o`000`00o`0;0?l000@00?l01@3o00020000
o`D00?l00P3o000>ooooo`@0o`001@00o`020?l000L0oh001000o`030000o`80oh000`000?l20?l0
0080oh000P3o00020?n000030000o`3oP000oh000080oh000P000?l50?n00080o`001@00o`090?l0
00H0oh0000<00?l00?l0003o00000P3o000;0000o`800?l01`3oP0070?l00080003o0P3o00070000
o`X0o`000P000?l90?n00080003o3_ooool50?n00080003o0P3oP002003o00`0oh001000o`020?l0
00030?n000000?l0003o00@0003o0P00o`000`3oP000o`000?l000020000o`80oh000P3o00000`00
0?l0oh000?n000090?n00080003o0P3oP0020000o`D0oh002@000?l;0?n000030000o`3o0000o`00
00T0oh000P3o00090?n00080o`000`3oP002003o00D0o`001000o`020?n00080003o1@3oP00Hoooo
o`005_ooool2003o02L0o`001000o`020?l000030000o`3o0000o`0000@0o`000P00o`0E0?l00080
oh002`3o00000`000?l0o`000?l0000@0?l00080003o0P00o`020?l000030000o`3o0000o`000080
o`000P000?l90?l00080003o1@3o000>ooooo`800?l00P3o000:003o00H0o`002P00o`040?l00080
003o5`00o`040?l00080oh0000<0003o0?l0003o00001@00o`020?l000L0003o0P00o`020?l00180
0?l00P3o0003003o0080o`001`00o`020?l000@00?l01@3o0007003o0080o`003_ooool2003o0080
o`001`00o`020?n000030?l0003oP000oh000080oh000P00o`050?l00080oh000P3o00000`000?l0
o`000?l000020000o`D0o`0020000?l30?n00080o`001`00o`040?l000800?l000<0o`000?n0003o
P0000P3o00020?n000030000o`00o`000?l00080o`002@000?l20?l00080oh0000<0o`000?n0003o
P0000P3oP0020?l000<0oh000P000?l20?l000L0003o0P3oP0020?l00003003o003o0000o`000080
o`000P00o`020?l00003003o00000?l0003o0080o`00103oP0050000o`kooooo3P3oP0020000o`80
oh000P3o00020000o`D0oh000P3o00070000o`800?l000<0oh000?l0003o00000P3oP0040?l00003
0000o`3oP000oh0000H0oh000`3o00070?n000@0o`000P3oP0030000o`80oh000P000?l20?n000<0
o`001`000?l20?l000T0oh000P3o00090?n000<0o`000P000?l2003o0080oh000P3o0005003o0080
o`000P3oP0000`3o0000oh000?n000020?n001Sooooo000Fooooo`800?l09`3o0004003o0080o`00
00<0003o0?l0003o0000103o0002003o01D0o`000P3oP00;0?l000030000o`3o0000o`000100o`00
0P000?l2003o0080o`0000<0003o0?l0003o00000P3o00020000o`T0o`000P000?l50?l000kooooo
0P00o`020?l000X00?l01P3o000:003o00@0o`000P000?lG003o00@0o`000P3oP0000`000?l0o`00
0?l00005003o0080o`001`000?l2003o0080o`004P00o`020?l000<00?l00P3o0007003o0080o`00
1000o`050?l000L00?l00P3o000>ooooo`800?l00P3o0007003o0080oh0000<0o`000?n0003oP000
0P3oP002003o00D0o`000P3oP0020?l000030000o`3o0000o`000080003o1@3o00080000o`<0oh00
0P3o0007003o00@0o`000P00o`000`3o0000oh000?n000020?l00080oh0000<0003o003o0000o`00
0P3o00090000o`80o`000P3oP0000`3o0000oh000?n000020?n00080o`000`3oP0020000o`80o`00
1`000?l20?n00080o`0000<00?l00?l0003o00000P3o0002003o0080o`0000<00?l00000o`000?l0
0P3o00040?n000D0003o3_ooool>0?n00080003o0P3oP0020?l00080003o1@3oP0020?l000L0003o
0P00o`000`3oP000o`000?l000020?n000@0o`0000<0003o0?n0003oP0001P3oP0030?l000L0oh00
103o00020?n000<0003o0P3oP0020000o`80oh000`3o00070000o`80o`002@3oP0020?l000T0oh00
0`3o00020000o`800?l00P3oP0020?l000D00?l00P3o00020?n000030?l0003oP000oh000080oh00
6?ooool001Kooooo0P00o`070?l000@00?l0303o0004003o00L0o`000P00o`030?l000800?l0103o
00000`000?l0o`000?l000040?l000800?l02@3o00000`00o`00o`000?l000040?l00003003o003o
0000o`0000@0003o3P3o00020?n000h0o`000P000?l20?n000D0o`00103oP00>0?l00080oh003_oo
ool2003o0080o`001`00o`020?l00003003o003o0000o`0000h00?l0103o00020000oa000?l0103o
0003003o00@0o`000`000?l20?l000D00?l00P3o00070000o`P00?l000<0o`00003o0000o`006@00
o`020?l000D00?l0103o0009003o00kooooo1@3o0002003o00L0o`000P00o`040?l000<0oh000P3o
00020?n000T0o`000P3oP0000`3o0000003o0000o`040000o`<0oh001P3o0005003o0080o`001000
o`000`3o0000003o0000o`020000o`80oh0000<00?l00?l0003o00000P3o00090000o`80o`001`3o
P0020?l00080003o0`3oP0020?l000D0003o103oP0020000o`<0o`000P3oP0020?l000<00?l00P3o
00060?n000D0003o3_ooool20?n00080003o3P3oP0050?l000@0oh000P00o`070000o`D0o`00103o
P0030000o`80oh0010000?l>0?n00080o`000P000?l90?n000030?l0003oP000oh000080oh000P00
0?l20?n000030000o`3o0000o`000080003o0P3oP0020000o`030?n000000?l0003o0080oh000P3o
00020?n000030?l0003oP000oh0000D0oh000P000?l20?l000@0oh0000<0o`000000o`000?l00P3o
0002003o0080003o1@3oP00Hooooo`005_ooool2003o00L0o`001000o`0<0?l000@00?l01`3o0002
003o00<0o`000P00o`040?l000030000o`3o0000o`0000@0o`000P00o`090?l00003003o003o0000
o`0000@0o`0000<00?l00?l0003o000010000?l>0?l00080oh003P3o00020000o`80oh001@3o0004
0?n000h0o`000P3oP00>ooooo`800?l00P3o0007003o0080o`0000<00?l00?l0003o00003P00o`04
0?l00080003o4000o`040?l000<00?l0103o00030000o`80o`001@00o`020?l000L0003o2000o`00
0`3o00000?l0003o000I003o0080o`001@00o`040?l000T00?l03_ooool50?l000800?l01`3o0002
003o00@0o`000`3oP0020?l00080oh002@3o00020?n000030?l000000?l0003o00@0003o0`3oP006
0?l000D00?l00P3o0004003o00030?l000000?l0003o0080003o0P3oP0000`00o`00o`000?l00002
0?l000T0003o0P3o00070?n00080o`000P000?l30?n00080o`001@000?l40?n00080003o0`3o0002
0?n00080o`000`00o`020?l000H0oh001@000?l>ooooo`80oh000P000?l>0?n000D0o`00103oP002
003o00L0003o1@3o00040?n000<0003o0P3oP0040000o`h0oh000P3o00020000o`T0oh0000<0o`00
0?n0003oP0000P3oP0020000o`80oh0000<0003o0?l0003o00000P000?l20?n00080003o00<0oh00
0000o`000?l00P3oP0020?l00080oh0000<0o`000?n0003oP0001@3oP0020000o`80o`00103oP000
0`3o0000003o0000o`020?l000800?l00P000?l50?n001Sooooo000Fooooo`@00?l000<0o`000?n0
003oP0000P3oP00;0?l00080003o0`3o0004003o00L0o`000`00o`0A0?l000030?n0003o0000o`00
0280o`000P3oP0040?l000030000o`3o0000o`0000L0o`000P3oP0070?l00080oh000P000?l90?l0
0080oh001@3o000>ooooo`800?l00`3o0006003o0080o`004`00o`020?l00080003o3000o`040?l0
0080oh000P3o0003003o0080oh000P3o00020000o`030?n0003o0000o`0000D00?l00P3o00070000
o`P00?l000<0o`00003o0000o`006@00o`020?l000@00?l00`3o000;003o00kooooo0P3o00020000
o`030?l00000o`000?l000d0o`000P3oP0000`000?l0oh000?n000070?l00080003o1@3o00060000
o`<0oh000P3o0004003o0080o`001`00o`020000o`030?l000000?l0003o0080003o1`3o00090000
o`80o`000P3oP0000`000?l0oh000?n000020?n00080o`000P000?l50?l000D0003o0P3oP0020000
o`<0o`000P3oP0020000o`80oh000`00o`080?n000D0003o3_ooool20000o`800?l00`3o00070?n0
0080o`000P3oP0040000o`030?l000000?l0003o0080003o0P3o00030?n00080003o0P3oP0020?l0
00030?n0003o0000o`000080oh000P000?l20?l000030?n000000?l0003o00@0003o1`3oP0020?l0
00D0oh000P3o00030?n00080003o1P3oP0000`3o0000oh000?n000020?n00080003o0P3oP0000`00
0?l0oh000?n000040?l00080oh000`3o00020?n00080o`000`3oP0020?l000L0oh000P000?l40?n0
00<0003o1000o`070?n001Sooooo000Fooooo`D00?l00P3o0002003o0100o`001000o`070?l00080
0?l06`3o00000`3oP000o`000?l000040?l000030?n0003o0000o`0000l0o`0000<0oh000?l0003o
00002@3o0002003o0080o`000P00o`050?l00080oh000`3o00020000o`/0o`000P00o`030?l00080
003o3_ooool2003o00<0o`001P00o`020?l001<00?l0103o000<003o0080003o103o0003003o0080
o`000P3oP0020?l000D0oh000P3o0003003o0080o`001`000?l6003o00D0o`006`00o`020?l00080
003o00<0o`00003o0000o`002`00o`0>ooooo`800?l03P3o00020?n000@0o`000`00o`050?l00080
oh001000o`030?l000P0003o00<0o`000?n0003oP0001000o`050?l000@00?l00`000?l40?n000<0
o`000P00o`020?l000T0003o1@3o00020000o`T0o`000P3oP0040000o`030?l0003oP000oh000080
oh000P3o00030000o`@0oh001@3o00020000o`80o`001@000?l20?n000kooooo0P000?l20?n00003
003o003o0000o`0000L0oh000P00o`020?n00080003o1@3oP0020000o`80o`0000<0oh000000o`00
0?l0103oP0020?l000L0oh000P3o00000`3oP000003o0000o`020?n00080003o0P3o000E0?n000@0
003o00<0o`000?n0003oP0000P3oP0040?l000<0oh00103o00020000o`<00?l02`3oP0020?l00003
0?n000000?l0003o00@0o`000P3oP0000`00o`00003o0000o`04003o0080003o1@3oP00Hooooo`00
5_ooool5003o0080o`000P00o`0@0?l000@00?l01`3o0002003o01/0o`0000<0oh000?l0003o0000
103o00000`3oP000o`000?l0000?0?l000030?n0003o0000o`0000T0o`000P00o`020?l000800?l0
1@3o00020?n000<0o`000P000?l;0?l000800?l00`3o00020000o`kooooo0P00o`030?l000H00?l0
0P3o000C003o00@0o`003000o`020000o`@0o`000`00o`020?l00080oh000P3o00050?n00080o`00
0`00o`020?l000L0003o1P00o`050?l001/00?l00P3o00020000o`030?l00000o`000?l000/00?l0
3_ooool2003o00h0o`000P3oP0040?l000<00?l01@3o00020?n000@00?l00`3o00080000o`030?l0
003oP000oh0000@00?l01@3o0004003o00<0003o103oP0030?l000800?l00P3o00090000o`D0o`00
0P000?l90?l00080oh0010000?l00`3o0000oh000?n000020?n00080o`000`000?l40?n000D0o`00
0P000?l20?l000D0003o0P3oP00>ooooo`80003o0P3oP0000`00o`00o`000?l000070?n000800?l0
0P3oP0020000o`D0oh000P000?l20?l000030?n000000?l0003o00@0oh000P3o00070?n00080o`00
00<0oh000000o`000?l00P3oP0020000o`80o`005@3oP0040000o`030?l0003oP000oh000080oh00
103o00030?n000@0o`000P000?l3003o00/0oh000P3o00000`3oP000003o0000o`040?l00080oh00
00<00?l00000o`000?l01000o`020000o`D0oh006?ooool001Kooooo1@00o`0=0?l000800?l01@3o
00020000oa00o`00103oP0070?l000800?l02@3o00000`3oP000o`000?l0000M0?l000800?l02P3o
0002003o00@0o`0000<0oh000?l0003o00000P000?l;0?l000800?l00`3o0002003o00kooooo2`00
o`020?l001<00?l0103o000<003o00@0o`000P3oP007003o00L0o`001`00o`070000o`H00?l00`3o
0002003o0080o`005`00o`040?l001000?l03_ooool4003o00`0o`000P3oP0020?l00080oh0000<0
o`00003o0000o`001`3o0004003o00<0o`000P000?l60?n000030?l000000?l0003o00@00?l01@3o
0004003o00L0003o0`3o00020?n00080o`00103oP0000`000?l0oh000?n000040?n000<0o`000P3o
P00;0?l000@0003o00<0o`000?n0003oP0000P3oP0020?l000030?n000000?l0003o00@0oh000P00
0?l30?l00080003o2@3oP00>ooooo`@0o`0000<00?l00?l0003o00001`3oP0020?l000T0oh000P00
0?l50?l000@0oh000P000?l70?n00080o`0000<0003o0?n0003oP00010000?l20?l000D0oh000P3o
00070?n00080o`001`3oP0020?l000030?n0003o0000o`0000@0oh000P3o00000`3oP000o`000?l0
00020000o`80o`000`3oP0020?l000L0oh000P000?l4003o00030?n0003o0000o`0000@0o`000P3o
P0030000o`80o`000P3oP0020?l000D0oh006?ooool001Kooooo1@00o`0=0?l000800?l01@3o0002
0000oa00o`00103oP0070?l000800?l02@3o00000`3oP000o`000?l0000M0?l000800?l02P3o0002
003o00@0o`0000<0oh000?l0003o00000P000?l;0?l000800?l00`3o0002003o00kooooo2`00o`02
0?l001<00?l0103o000<003o00@0o`000P3oP007003o00L0o`001`00o`070000o`H00?l00`3o0002
003o0080o`005`00o`040?l001000?l03_ooool4003o00`0o`000P3oP0020?l00080oh0000<0o`00
003o0000o`001`3o0004003o00<0o`000P000?l60?n000030?l000000?l0003o00@00?l01@3o0004
003o00L0003o0`3o00020?n00080o`00103oP0000`000?l0oh000?n000040?n000<0o`000P3oP00;
0?l000@0003o00<0o`000?n0003oP0000P3oP0020?l000030?n000000?l0003o00@0oh000P000?l3
0?l00080003o2@3oP00>ooooo`@0o`0000<00?l00?l0003o00001`3oP0020?l000T0oh000P000?l5
0?l000@0oh000P000?l70?n00080o`0000<0003o0?n0003oP00010000?l20?l000D0oh000P3o0007
0?n00080o`001`3oP0020?l000030?n0003o0000o`0000@0oh000P3o00000`3oP000o`000?l00002
0000o`80o`000`3oP0020?l000L0oh000P000?l4003o00030?n0003o0000o`0000@0o`000P3oP003
0000o`80o`000P3oP0020?l000D0oh006?ooool001KoooooH`3o00000`00o`00o`000?l0000;0?l0
00<0oh000P3o00020000o`h0o`000P3oP002003o00kooooo6`00o`020?l00003003o003o0000o`00
0080oh000P3o000<003o0080003o103o0009003o00<0o`002@00o`070000o`H00?l00`3o000K003o
00H0o`0000<0003o003o0000o`002`00o`0>ooooo`80o`002`00o`0E0?l000800?l00`3o0002003o
00H0003o00<0o`000000o`000?l01000o`020?l000L00?l01`000?l2003o00D0o`002@3oP0020?l0
0080oh0000<0003o0?n0003oP000103o00020?n000`0o`000P3oP0030?l000800?l0103o00020000
o`030?n0003o0000o`000080003o103oP0000`3o0000003o0000o`020000o`kooooo0P3o000<0?n0
0080o`002`3oP0030?l000l0oh000P3o00050?n00080003o2`3oP0030000o`h0oh000P3o00040?n0
00L0o`00403oP0040000o`03003o003o0000o`0000@00?l00`3o00080?n000030000o`3oP000oh00
0080oh006?ooool001KoooooH`3o00000`00o`00o`000?l0000;0?l000<0oh000P3o00020000o`h0
o`000P3oP002003o00kooooo6`00o`020?l00003003o003o0000o`000080oh000P3o000<003o0080
003o103o0009003o00<0o`002@00o`070000o`H00?l00`3o000K003o00H0o`0000<0003o003o0000
o`002`00o`0>ooooo`80o`002`00o`0E0?l000800?l00`3o0002003o00H0003o00<0o`000000o`00
0?l01000o`020?l000L00?l01`000?l2003o00D0o`002@3oP0020?l00080oh0000<0003o0?n0003o
P000103o00020?n000`0o`000P3oP0030?l000800?l0103o00020000o`030?n0003o0000o`000080
003o103oP0000`3o0000003o0000o`020000o`kooooo0P3o000<0?n00080o`002`3oP0030?l000l0
oh000P3o00050?n00080003o2`3oP0030000o`h0oh000P3o00040?n000L0o`00403oP0040000o`03
003o003o0000o`0000@00?l00`3o00080?n000030000o`3oP000oh000080oh006?ooool001Kooooo
0P3o0002003o00<0o`000P3oP0020?l000800?l08`3o0004003o01/0o`000`3oP0060?l000<0003o
6`3o00020?n000h0o`000P000?l20?l000kooooo2@00o`020?l001000?l01@3o00020?n00080o`00
0P000?l<003o00@0o`000`00o`020?l000@00?l00`3o0009003o00H0003o00<0oh00003o0000o`00
1000o`030?l001/00?l01P3o00000`000?l00?l0003o00020?l000T00?l03_ooool=003o00L0o`00
0P00o`070?l00003003o003o0000o`0000@00?l00`3o0002003o00H0003o00<0o`000000o`000?l0
2`00o`020?l000L0003o0`3o00020?n000H0o`0000<0003o0?n0003oP0002@3oP0020000o`80oh00
0P000?l50?l000800?l01@3o00020?n000<0o`001000o`040?l000030?n0003o0000o`0000H0oh00
1@000?l>ooooo`80o`000P3oP0000`3o0000oh000?n000070?n000800?l00P3o00020?n00080003o
1@3oP0020?l000<0oh000P000?l40?n000030000o`3oP000oh0000/0oh000P000?l30?l000H0oh00
1@3o00050?n00080003o103oP0020?l000030?n0003o0000o`0000@0oh000`3o00060?n00080003o
303oP0020?l00080003o00<0oh000?l0003o00000P3o0002003o00<0o`001P3oP0020?l000D0oh00
6?ooool001Kooooo0P3o0002003o00<0o`000P3oP0020?l000800?l08`3o0004003o01/0o`000`3o
P0060?l000<0003o6`3o00020?n000h0o`000P000?l20?l000kooooo2@00o`020?l001000?l01@3o
00020?n00080o`000P000?l<003o00@0o`000`00o`020?l000@00?l00`3o0009003o00H0003o00<0
oh00003o0000o`001000o`030?l001/00?l01P3o00000`000?l00?l0003o00020?l000T00?l03_oo
ool=003o00L0o`000P00o`070?l00003003o003o0000o`0000@00?l00`3o0002003o00H0003o00<0
o`000000o`000?l02`00o`020?l000L0003o0`3o00020?n000H0o`0000<0003o0?n0003oP0002@3o
P0020000o`80oh000P000?l50?l000800?l01@3o00020?n000<0o`001000o`040?l000030?n0003o
0000o`0000H0oh001@000?l>ooooo`80o`000P3oP0000`3o0000oh000?n000070?n000800?l00P3o
00020?n00080003o1@3oP0020?l000<0oh000P000?l40?n000030000o`3oP000oh0000/0oh000P00
0?l30?l000H0oh001@3o00050?n00080003o103oP0020?l000030?n0003o0000o`0000@0oh000`3o
00060?n00080003o303oP0020?l00080003o00<0oh000?l0003o00000P3o0002003o00<0o`001P3o
P0020?l000D0oh006?ooool001Kooooo0P3o0002003o01D0o`000P000?lG0?l000800?l00P3o0002
003o01L0o`000P3oP0000`3o0000oh000?n000040?l000<0oh00103o00020000o`80o`0000<0oh00
0?l0003o00001P3o00000`000?l0o`000?l000070?l00080oh00103o00000`3oP000o`000?l00007
0?l00080003o0P3o000>oooooah00?l00P3o00020000o`80o`000P000?l<003o00H0o`001`00o`03
0?l000T00?l0103o00030?n000H00?l01@3o000K003o00/0o`001`00o`0>ooooo`D00?l00P3o0004
003o00T0o`000P00o`070?l000L00?l00`3o00080000o`030?l000000?l0003o00H00?l000<0o`00
003o0000o`000P3o0002003o00L0003o0P3o00000`3oP000o`000?l000040?l000<0oh0020000?l3
0?n000H0003o4`3o0002003o0080o`000`000?l60?n00080003o00<0oh000000o`000?l00P000?l>
ooooo`80oh000`3o000;0?n00080o`002@3oP002003o00030?l0003oP000oh0000@0oh001`000?l9
0?n00080003o2@3oP0050?l000/0oh000P3o00070?n000D0o`00103oP0020000o`X0oh000P00o`02
0?n00080o`000`3oP0040?l000800?l03P3oP00Hooooo`005_ooool4003o00h0o`000P00o`0I0?l0
00800?l01`3o0002003o00<0o`000P00o`0;0?l000030?n0003o0000o`000080o`00103oP0000`3o
0000oh000?n000060?l000030000o`3o0000o`000080o`000P3oP00W0?l000800?l03_oooolN003o
0080o`000P000?l20?l00080003o3000o`040?l001D00?l0103o00020?n000030?l00000o`000?l0
00T00?l00P3o000I003o00/0o`001`00o`0>ooooo`80003o0P00o`0:0?l000T00?l01`3o0006003o
0080003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`07003o00H0o`001`000?l20?l0
00030?n0003o0000o`0000@0o`000P3oP0000`000?l0oh000?n000070000o`80oh000P3o00040?n0
00030?l00000o`000?l000800?l00P3o00020000o`030?l000000?l0003o00@0o`0000<00?l00?l0
003o00001000o`020?l000<0003o0P3oP0040000o`<0oh000P000?l>ooooo`80oh000P3o00000`00
o`00o`000?l000020?l00080oh000P000?l00`3oP000003o0000o`020?l000T0oh000P00o`000`3o
0000oh000?n000040?n000L0003o1`3oP007003o00@0o`000P000?l20?n000030?l0003oP000oh00
00T0oh000P000?l20?l000L0oh000`3o00040?n00080o`001@000?l40?n000<0003o0P3o00090?n0
0080o`000P00o`070?n000<0o`00103oP00Hooooo`005_ooool4003o00h0o`000P00o`0I0?l00080
0?l01`3o0002003o00<0o`000P00o`0;0?l000030?n0003o0000o`000080o`00103oP0000`3o0000
oh000?n000060?l000030000o`3o0000o`000080o`000P3oP00W0?l000800?l03_oooolN003o0080
o`000P000?l20?l00080003o3000o`040?l001D00?l0103o00020?n000030?l00000o`000?l000T0
0?l00P3o000I003o00/0o`001`00o`0>ooooo`80003o0P00o`0:0?l000T00?l01`3o0006003o0080
003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`07003o00H0o`001`000?l20?l00003
0?n0003o0000o`0000@0o`000P3oP0000`000?l0oh000?n000070000o`80oh000P3o00040?n00003
0?l00000o`000?l000800?l00P3o00020000o`030?l000000?l0003o00@0o`0000<00?l00?l0003o
00001000o`020?l000<0003o0P3oP0040000o`<0oh000P000?l>ooooo`80oh000P3o00000`00o`00
o`000?l000020?l00080oh000P000?l00`3oP000003o0000o`020?l000T0oh000P00o`000`3o0000
oh000?n000040?n000L0003o1`3oP007003o00@0o`000P000?l20?n000030?l0003oP000oh0000T0
oh000P000?l20?l000L0oh000`3o00040?n00080o`001@000?l40?n000<0003o0P3o00090?n00080
o`000P00o`070?n000<0o`00103oP00Hooooo`005_ooool20?l000L00?l01`3o0006003o01<0o`00
0P00o`020?l000800?l07P3o00020?n000<0o`000P3oP0020?l00080003o0P3o00000`000?l0o`00
0?l000060?l000030?n0003o0000o`0000/0o`000P3oP00B0?l000030?n00000o`000?l00080o`00
3_oooolN003o00H0o`003P00o`040?l000L00?l00P3o0002003o00030000o`00o`000?l000@00?l0
00<0o`00003o0000o`00103o0002003o00030?l00000o`000?l000l00?l00`3o0004003o0080o`00
3000o`040?l000030000o`3o0000o`000080o`000P000?l7003o00kooooo0P000?l5003o00L0o`00
2000o`0<0?l000800?l01@000?l20?n00080003o0`3oP0020000o`L00?l02@3o00020?n00080003o
1`3o0002003o00T0003o0P3oP0000`000?l0o`000?l000020?l00080oh000P000?l00`3o00000?l0
003o0002003o0080o`000P000?l00`3o0000003o0000o`020000o`80o`001@00o`020?l00080oh00
0`000?l20?n00080003o0P3o00030?n00080003o3_ooool40?n000<00?l00P3oP0020?l00080003o
00<0o`000000o`000?l00P3oP0020000o`80oh0000<0003o0?l0003o00000P3oP002003o00030?l0
003oP000oh000080oh0010000?l<0?n000H00?l00`3o000=0?n000030?l00000o`000?l000l0oh00
00<0o`000?n0003oP0001000o`020?n000030000o`3oP000oh0000@0oh000P3o00000`3oP000003o
0000o`040?n000030?l000000?l0003o0080oh000P3o00020000o`<0oh000P000?l40?l000D0003o
6?ooool001Kooooo0P3o0007003o00L0o`001P00o`0C0?l000800?l00P3o0002003o01h0o`000P3o
P0030?l00080oh000P3o00020000o`80o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l0
000;0?l00080oh004P3o00000`3oP0000?l0003o00020?l000kooooo7P00o`060?l000h00?l0103o
0007003o0080o`000P00o`000`000?l00?l0003o0004003o00030?l00000o`000?l000@0o`000P00
o`000`3o00000?l0003o000?003o00<0o`001000o`020?l000`00?l0103o00000`000?l0o`000?l0
00020?l00080003o1`00o`0>ooooo`80003o1@00o`070?l000P00?l0303o0002003o00D0003o0P3o
P0020000o`<0oh000P000?l7003o00T0o`000P3oP0020000o`L0o`000P00o`090000o`80oh0000<0
003o0?l0003o00000P3o00020?n00080003o00<0o`00003o0000o`000P00o`020?l00080003o00<0
o`000000o`000?l00P000?l20?l000D00?l00P3o00020?n000<0003o0P3oP0020000o`80o`000`3o
P0020000o`kooooo103oP003003o0080oh000P3o00020000o`030?l000000?l0003o0080oh000P00
0?l20?n000030000o`3o0000o`000080oh000P00o`000`3o0000oh000?n000020?n000@0003o303o
P006003o00<0o`003@3oP0000`3o00000?l0003o000?0?n000030?l0003oP000oh0000@00?l00P3o
P0000`000?l0oh000?n000040?n00080o`0000<0oh000000o`000?l0103oP0000`3o0000003o0000
o`020?n00080o`000P000?l30?n00080003o103o00050000oaSooooo000Fooooo`80o`001`00o`0M
0?l000<0003o903o00020000o`/0o`0000<0003o0?l0003o00000P00o`040?l000030?n0003o0000
o`0000H0o`0000<0oh000?l0003o00003@3o00000`3oP000o`000?l000060?l000030000o`3o0000
o`0000800?l03_ooool2003o00<0o`006@00o`060?l000h00?l00P3o0009003o00@0o`0000<0oh00
0?l0003o00001000o`070?l001800?l00P3o0005003o0080o`004000o`0;0?l000D00?l03_ooool2
0000o`80o`000`00o`070?l000H00?l00P3o0005003o0080003o0`3o0002003o00@0o`0000<0003o
0?n0003oP0001`3oP0020000o`80o`001@00o`090?l00080oh000P000?l3003o00@0o`000P00o`05
0000o`80oh000P3o00030?n000@0o`000P000?l30?l000800?l0103o00020000o`030?l0003oP000
oh0000@0oh0000<0o`00003o0000o`00103o00020?n000D0003o1@3oP0020?l00080003o3_ooool4
0?l000030?n0003o0000o`000080oh000P3o00020000o`030?l0003oP000oh0000L0oh000P3o0004
003o00<0o`000P3oP002003o00L0oh002@3o0002003o00D0o`000P000?l;0?n000030?l0003oP000
oh0000T0oh000P000?l20?n00080o`0000<0003o0?n0003oP000103o00050?n00080003o0P3oP002
0?l000030000o`3oP000oh0000/0oh000P000?l00`3oP000003o0000o`020000o`80oh000P00o`00
0`000?l0oh000?n000020000oaSooooo000Fooooo`80o`001`00o`0M0?l000<0003o903o00020000
o`/0o`0000<0003o0?l0003o00000P00o`040?l000030?n0003o0000o`0000H0o`0000<0oh000?l0
003o00003@3o00000`3oP000o`000?l000060?l000030000o`3o0000o`0000800?l03_ooool2003o
00<0o`006@00o`060?l000h00?l00P3o0009003o00@0o`0000<0oh000?l0003o00001000o`070?l0
01800?l00P3o0005003o0080o`004000o`0;0?l000D00?l03_ooool20000o`80o`000`00o`070?l0
00H00?l00P3o0005003o0080003o0`3o0002003o00@0o`0000<0003o0?n0003oP0001`3oP0020000
o`80o`001@00o`090?l00080oh000P000?l3003o00@0o`000P00o`050000o`80oh000P3o00030?n0
00@0o`000P000?l30?l000800?l0103o00020000o`030?l0003oP000oh0000@0oh0000<0o`00003o
0000o`00103o00020?n000D0003o1@3oP0020?l00080003o3_ooool40?l000030?n0003o0000o`00
0080oh000P3o00020000o`030?l0003oP000oh0000L0oh000P3o0004003o00<0o`000P3oP002003o
00L0oh002@3o0002003o00D0o`000P000?l;0?n000030?l0003oP000oh0000T0oh000P000?l20?n0
0080o`0000<0003o0?n0003oP000103o00050?n00080003o0P3oP0020?l000030000o`3oP000oh00
00/0oh000P000?l00`3oP000003o0000o`020000o`80oh000P00o`000`000?l0oh000?n000020000
oaSooooo000Fooooo`D0o`001000o`0=0?l000<00?l02@3o00020?n00080o`000`000?lR0?l00080
oh000P000?l70?l00080oh001@3o0002003o00D0o`000P000?l60?l000030?n0003o0000o`0000h0
o`00103oP0040?l000030000o`3o0000o`000080o`003_ooool4003o00030?l00000o`000?l001L0
0?l0103o000@003o00H0o`001@00o`050?l000@00?l00P3o00000`3oP000o`000?l000020?l00080
oh000`00o`040?l000/00?l00P3o000E003o00D0o`001000o`070?l00080oh003_ooool20?n00080
o`000`00o`090?l000T00?l00P3o00070000o`80o`000`00o`060?l00080003o00<0oh000000o`00
0?l00P3o0005003o00@0o`000P00o`020?l000030000o`3o0000o`000080003o0P00o`050?l00080
oh001`000?l20?l000<0oh00103o0004003o00030?l00000o`000?l000@0o`001@000?l40?n000L0
o`002`000?l00`3oP000003o0000o`020000o`kooooo0P00o`020?l000D0oh000P3o00020000o`03
0?l0003oP000oh0000H0003o0`3oP004003o00<0o`003`3oP0000`00o`00o`000?l000020?l00080
oh000`3o00090?n00080003o503oP0030?l00080oh001000o`020?l000D0oh001`000?l40?n00003
0000o`3oP000oh0000H0oh001@000?l20?n00080o`0000<0003o0?n0003oP0000P3oP00Hooooo`00
5_ooool50?l000@00?l03@3o0003003o00T0o`000P3oP0020?l000<0003o8P3o00020?n00080003o
1`3o00020?n000D0o`000P00o`050?l00080003o1P3o00000`3oP000o`000?l0000>0?l000@0oh00
103o00000`000?l0o`000?l000020?l000kooooo1000o`000`3o00000?l0003o000G003o00@0o`00
4000o`060?l000D00?l01@3o0004003o0080o`0000<0oh000?l0003o00000P3o00020?n000<00?l0
103o000;003o0080o`005@00o`050?l000@00?l01`3o00020?n000kooooo0P3oP0020?l000<00?l0
2@3o0009003o0080o`001`000?l20?l000<00?l01P3o00020000o`030?n000000?l0003o0080o`00
1@00o`040?l000800?l00P3o00000`000?l0o`000?l000020000o`800?l01@3o00020?n000L0003o
0P3o00030?n000@0o`001000o`000`3o00000?l0003o00040?l000D0003o103oP0070?l000/0003o
00<0oh000000o`000?l00P000?l>ooooo`800?l00P3o00050?n00080o`000P000?l00`3o0000oh00
0?n000060000o`<0oh001000o`030?l000l0oh0000<00?l00?l0003o00000P3o00020?n000<0o`00
2@3oP0020000oa@0oh000`3o00020?n000@00?l00P3o00050?n000L0003o103oP0000`000?l0oh00
0?n000060?n000D0003o0P3oP0020?l000030000o`3oP000oh000080oh006?ooool001Kooooo1@3o
0002003o0080o`000P00o`0;0?l00003003o003o0000o`0000T0o`000P3oP0020?l000030?n00000
0?l0003o0280o`000P3oP0020000o`L0o`000P3oP0020?l00003003o003o0000o`0000800?l00P3o
0002003o01D0o`001000o`090?l000030000o`3o0000o`000080o`003_ooool4003o00030?l00000
o`000?l001L00?l0103o000K003o0080oh000`3o0002003o0080003o0P3o00000`000?l0o`000?l0
00020?l00080oh000`00o`020?l000L00?l01P3o00020?n000<0o`000P000?l@003o00D0o`001000
o`020?l000<00?l00P3o00020?n000kooooo403o0004003o0080o`0000<00?l00?l0003o00000P00
o`070000o`80o`000P00o`000`000?l00?l0003o00020000o`80o`000P000?l00`3oP000003o0000
o`020?l000800?l01`3o0002003o0080o`0000<0003o0?l0003o00000P000?l2003o00<0o`00103o
P0020000o`D0oh000P3o0002003o00D0o`001000o`070?l000T0003o0`3o00020000o`80o`000P00
0?l30?n000@0003o0P3oP0000`3o0000003o0000o`020000o`kooooo103o000<0?n00080003o0P3o
P0030000o`80oh000P00o`030?l00080oh000P000?l40?l000X0oh000P3o000?0?n000030?l00000
0?l0003o0080003o0P3oP0030000o`H0oh0000<0003o0?n0003oP0001P3oP0030?l00080oh000P3o
0002003o00X0oh000P000?l40?n000030000o`3oP000oh0000d0oh000P3o00000`3oP000o`000?l0
00020?n001Sooooo000Fooooo`80o`000P00o`050?l000800?l00`3o00020000o`H0o`0000<00?l0
0?l0003o00001`3o00040?n00080o`0000<0003o0?l0003o00001P3o00000`3oP000o`000?l0000V
0?l000L00?l00P3o0002003o00030?l00000o`000?l000800?l0103o00000`000?l00?l0003o0002
003o00L0o`000P00o`030?l00080oh001P3o00000`000?l00?l0003o00020?l000kooooo0P00o`03
0?l001T00?l0103o000K003o0080oh000P3o00050000o`T0o`001`00o`020?l000D00?l00P3o0002
003o00D0o`000P000?l@003o0080o`001`00o`020?l000<00?l00P3o00020?n000kooooo403o0009
003o0080o`001`000?l20?l000800?l000<0oh000?l0003o00000P000?l20?l000<0oh000P000?l4
003o00<0o`001000o`050?l00080oh000P000?l50?l00080oh000P000?l50?n000@0o`000P00o`05
0?l000@00?l01`3o00070000o`80oh0000<0o`00003o0000o`00103o00020000o`030?n0003o0000
o`000080003o0P3o00020?n000030?l000000?l0003o0080003o3_ooool20?n00080003o303oP009
0000o`800?l00P3o00070?n00080o`002P3oP0020?l000l0oh00203o00040000o`@0oh0000<0003o
0?n0003oP0001`3oP0020?l00080oh000P3o0002003o00T0oh0000<0003o0?n0003oP0000P00o`0;
0?n000030?l000000?l0003o0080oh0010000?l50?n001Sooooo000Fooooo`80o`000P00o`050?l0
00800?l00`3o00020000o`H0o`0000<00?l00?l0003o00001`3o00040?n00080o`0000<0003o0?l0
003o00001P3o00000`3oP000o`000?l0000V0?l000L00?l00P3o0002003o00030?l00000o`000?l0
00800?l0103o00000`000?l00?l0003o0002003o00L0o`000P00o`030?l00080oh001P3o00000`00
0?l00?l0003o00020?l000kooooo0P00o`030?l001T00?l0103o000K003o0080oh000P3o00050000
o`T0o`001`00o`020?l000D00?l00P3o0002003o00D0o`000P000?l@003o0080o`001`00o`020?l0
00<00?l00P3o00020?n000kooooo403o0009003o0080o`001`000?l20?l000800?l000<0oh000?l0
003o00000P000?l20?l000<0oh000P000?l4003o00<0o`001000o`050?l00080oh000P000?l50?l0
0080oh000P000?l50?n000@0o`000P00o`050?l000@00?l01`3o00070000o`80oh0000<0o`00003o
0000o`00103o00020000o`030?n0003o0000o`000080003o0P3o00020?n000030?l000000?l0003o
0080003o3_ooool20?n00080003o303oP0090000o`800?l00P3o00070?n00080o`002P3oP0020?l0
00l0oh00203o00040000o`@0oh0000<0003o0?n0003oP0001`3oP0020?l00080oh000P3o0002003o
00T0oh0000<0003o0?n0003oP0000P00o`0;0?n000030?l000000?l0003o0080oh0010000?l50?n0
01Sooooo000Fooooo`800?l01`3o0002003o00<0o`000P000?l40?l00080oh002P3o00020000o`d0
o`0000<0oh000?l0003o00001P3o00000`000?l0o`000?l000040?l00080oh001@3o00020?n000X0
o`000P3oP0040?l000<00?l04@3o00000`000?l00?l0003o0002003o00`0o`000P000?l40?l00080
oh001@3o000>ooooo`D0o`002@00o`020?l002d00?l0103o00080000o`H0o`003000o`040?l00080
0?l01@3o00020000oa000?l0103o0007003o0080o`0000<00?l00?l0003o00000P3oP00>oooooa@0
o`000P00o`050?l000<0003o0P3o00020000o`@0o`0000<0003o0?l0003o00000P000?l50?n00080
003o103o0002003o00030?l00000o`000?l000@00?l01`3o00020?n000030?l000000?l0003o0080
oh000P000?l30?n000@0003o0P3o0002003o00L0o`000P00o`030?l00080oh000P3o00050000o`80
oh000P000?l00`3o00000?l0003o00040?l00080003o00<0o`00003o0000o`0010000?l20?n00003
0?l000000?l0003o0080003o3_ooool@0?n000L0003o0P00o`040?l000T0oh0000<0o`000000o`00
0?l0403oP0020?l000L0oh000P000?l50?n000T0003o0P3oP0040?l000L0oh000P3o00020?n00003
0000o`3oP000oh0000@0oh000P000?l30?n00080o`001`3oP0020?l00080oh0000<0o`000000o`00
0?l00P3oP0020000o`<0oh000P3o00020?n001Sooooo000Fooooo`800?l01`3o0002003o00<0o`00
0P000?l40?l00080oh002P3o00020000o`d0o`0000<0oh000?l0003o00001P3o00000`000?l0o`00
0?l000040?l00080oh001@3o00020?n000X0o`000P3oP0040?l000<00?l04@3o00000`000?l00?l0
003o0002003o00`0o`000P000?l40?l00080oh001@3o000>ooooo`D0o`002@00o`020?l002d00?l0
103o00080000o`H0o`003000o`040?l000800?l01@3o00020000oa000?l0103o0007003o0080o`00
00<00?l00?l0003o00000P3oP00>oooooa@0o`000P00o`050?l000<0003o0P3o00020000o`@0o`00
00<0003o0?l0003o00000P000?l50?n00080003o103o0002003o00030?l00000o`000?l000@00?l0
1`3o00020?n000030?l000000?l0003o0080oh000P000?l30?n000@0003o0P3o0002003o00L0o`00
0P00o`030?l00080oh000P3o00050000o`80oh000P000?l00`3o00000?l0003o00040?l00080003o
00<0o`00003o0000o`0010000?l20?n000030?l000000?l0003o0080003o3_ooool@0?n000L0003o
0P00o`040?l000T0oh0000<0o`000000o`000?l0403oP0020?l000L0oh000P000?l50?n000T0003o
0P3oP0040?l000L0oh000P3o00020?n000030000o`3oP000oh0000@0oh000P000?l30?n00080o`00
1`3oP0020?l00080oh0000<0o`000000o`000?l00P3oP0020000o`<0oh000P3o00020?n001Sooooo
000Fooooo`800?l00`3o0006003o00/0o`0000<0oh000?l0003o00001`3o00020?n000L0o`000P3o
P0070?l00080003o4P3o00020000o`<0o`000P3oP00D0?l000L00?l0103o0005003o00`0o`001000
0?l20?l00080003o1@3o000>ooooo`@0o`0000<0003o0?l0003o0000;@00o`020?l000L00?l0103o
000:0000o`80o`000P000?lE003o00@0o`004000o`020?l000`00?l00P3o00020?n000kooooo2@3o
00020?n000800?l01`3o0002003o00030?n0003o0000o`000080o`000`000?l20?l00080oh00103o
00030000o`80o`000P3oP0020000o`030?l000000?l0003o00L00?l00P3o0002003o00D0o`000P3o
P0020?l00080oh0000<0003o0?n0003oP0000P3oP0020000o`80o`0000<0003o0?n0003oP0000P3o
00040000o`X00?l01P3o00050000o`@0oh0000<0o`00003o0000o`000P3o00040000o`03003o003o
0000o`0000/0003o3_ooool50?n00080o`001`3oP0020?l00080oh000P000?l30?n000@00?l00P3o
00030000o`80oh000P000?l20?n000030000o`3oP000oh0000@0oh000P000?l:0?n00080o`000P3o
P0020?l000L0oh000P000?l70?n00080003o0`3oP002003o00/0oh000P3o00070?n00080003o0`3o
P0020?l00080oh0000<0o`000?n0003oP0000P3o000B0?n001Sooooo000Fooooo`800?l00`3o0006
003o00/0o`0000<0oh000?l0003o00001`3o00020?n000L0o`000P3oP0070?l00080003o4P3o0002
0000o`<0o`000P3oP00D0?l000L00?l0103o0005003o00`0o`0010000?l20?l00080003o1@3o000>
ooooo`@0o`0000<0003o0?l0003o0000;@00o`020?l000L00?l0103o000:0000o`80o`000P000?lE
003o00@0o`004000o`020?l000`00?l00P3o00020?n000kooooo2@3o00020?n000800?l01`3o0002
003o00030?n0003o0000o`000080o`000`000?l20?l00080oh00103o00030000o`80o`000P3oP002
0000o`030?l000000?l0003o00L00?l00P3o0002003o00D0o`000P3oP0020?l00080oh0000<0003o
0?n0003oP0000P3oP0020000o`80o`0000<0003o0?n0003oP0000P3o00040000o`X00?l01P3o0005
0000o`@0oh0000<0o`00003o0000o`000P3o00040000o`03003o003o0000o`0000/0003o3_ooool5
0?n00080o`001`3oP0020?l00080oh000P000?l30?n000@00?l00P3o00030000o`80oh000P000?l2
0?n000030000o`3oP000oh0000@0oh000P000?l:0?n00080o`000P3oP0020?l000L0oh000P000?l7
0?n00080003o0`3oP002003o00/0oh000P3o00070?n00080003o0`3oP0020?l00080oh0000<0o`00
0?n0003oP0000P3o000B0?n001Sooooo000Fooooo`800?l00`3o0006003o00<0o`000P00o`0@0?l0
0080oh007`3o00000`00o`00o`000?l000020?l00080003o0`3o00020?n000L0o`000P00o`0;0?l0
00800?l00`3o00020000oaD0o`0010000?l20?l00080003o1@3o000>ooooo`@0o`0000<0003o003o
0000o`00=P00o`070?l00080003o0P3o00000`3oP000003o0000o`020?l00080003o3000o`060?l0
00<00?l00P3o000B003o0080o`003000o`020?l00080oh003_ooool;0?l000<00?l03@3o00030000
o`80o`000P000?l40?l000D0003o0P3oP0030?l00080003o1000o`020?l00003003o003o0000o`00
0080o`000P00o`030?l000800?l0103o00000`3oP000o`000?l000040?n00080o`000`3oP0040000
o`80oh0000<0o`00003o0000o`001P00o`000`3o00000?l0003o00040?l000D0003o1@3oP0040?l0
00@0003o0`00o`0;0000o`kooooo103oP0000`000?l00?l0003o00070?n00080003o0P3oP0050000
o`@00?l01@3oP0040000o`800?l04P3oP0000`00o`00o`000?l000020?l001@0oh0000<0o`000?n0
003oP0000P00o`0F0?n000030000o`3oP000oh0000D0o`000P3oP004003o0080o`0000<0003o0?n0
003oP0002`3oP00Hooooo`005_ooool;003o00L0o`001`00o`0O0?l00003003o003o0000o`0000H0
o`0000<0003o0?l0003o00000P3o00020000o`<0o`0010000?l30?l000@00?l02`3o0002003o00<0
o`000P000?l20?l00080oh000`3o00020?n00080o`0000<0oh000?l0003o00000P3o0002003o00h0
o`000P00o`0>ooooo`D0o`002@00o`020?l000/00?l00P000?lP003o00@0o`000`00o`020000o`80
o`000`000?l20?n00080003o1@00o`0?0?l00003003o003o0000o`0001l00?l00`3o00020?n000ko
oooo0P00o`020?l00003003o003o0000o`0000@0o`000`00o`0=0?l000<0003o0P3o00040000o`80
oh0000<0003o0?n0003oP0000P3o00020?n00080003o00<0o`00003o0000o`000P00o`040?l000<0
0?l01`3o0002003o00@0o`0000<0oh000?l0003o00000P3o00020000o`80oh002@000?l00`3o0000
0?l0003o000;003o0080o`001@000?l40?n000T0o`000`00o`020000o`80o`001`000?l>ooooo`@0
oh0000<0o`00003o0000o`00103o00050?n00080003o0P3oP0020000o`D0oh000P00o`050?n00080
003o0P3oP0000`3o0000oh000?n000060?n000<0o`000P3oP0020?l000<00?l0103o00090?n00080
o`00303oP002003o01L0oh000P000?l4003o00030?l0003oP000oh0000800?l00P3o00030000o`80
o`001P3oP0000`000?l0oh000?n000020?n001Sooooo000Fooooo`/00?l01`3o0007003o01l0o`00
00<00?l00?l0003o00001P3o00000`000?l0o`000?l000020?l00080003o0`3o00040000o`<0o`00
1000o`0;0?l000800?l00`3o00020000o`80o`000P3oP0030?l00080oh000P3o00000`3oP000o`00
0?l000020?l000800?l03P3o0002003o00kooooo1@3o0009003o0080o`002`00o`020000ob000?l0
103o0003003o0080003o0P3o00030000o`80oh000P000?l5003o00l0o`0000<00?l00?l0003o0000
7`00o`030?l00080oh003_ooool2003o0080o`0000<00?l00?l0003o0000103o0003003o00d0o`00
0`000?l20?l000@0003o0P3oP0000`000?l0oh000?n000020?l00080oh000P000?l00`3o00000?l0
003o0002003o00@0o`000`00o`070?l000800?l0103o00000`3oP000o`000?l000020?l00080003o
0P3oP0090000o`030?l00000o`000?l000/00?l00P3o00050000o`@0oh002@3o0003003o0080003o
0P3o00070000o`kooooo103oP0000`3o00000?l0003o00040?l000D0oh000P000?l20?n00080003o
1@3oP002003o00D0oh000P000?l20?n000030?l0003oP000oh0000H0oh000`3o00020?n00080o`00
0`00o`040?l000T0oh000P3o000<0?n000800?l05`3oP0020000o`@00?l000<0o`000?n0003oP000
0P00o`020?l000<0003o0P3o00060?n000030000o`3oP000oh000080oh006?ooool001Kooooo0P00
o`020?l000030000o`00o`000?l000800?l05@3o00020?n000L0o`000P000?l20?n001/0o`000P3o
P00<0?l000800?l02`3o0003003o00@0o`000P000?l70?l00080oh00403o0003003o0080o`000P00
o`0>ooooo`80o`001@00o`020?l000D00?l00P3o0009003o0080o`000P000?l5003o0080o`006@00
o`040?l000<00?l0103o00030?n000@0o`000P00o`000`3o00000?l0003o0002003o00@0o`0000<0
oh000?l0003o00001`00o`020?l002000?l0103o000>ooooo`D00?l0103o00020?n000800?l02P3o
00020000o`80o`000`000?l20?l000T0003o0P3o00040?n000030000o`00o`000?l000800?l00P3o
00020000o`L0o`001@00o`070?l00080oh000P000?l20?n000030?l000000?l0003o0080003o0P3o
P0020000o`030?l00000o`000?l000H00?l000<0o`000000o`000?l0103o00050000o`80oh000P00
0?l00`3o00000?l0003o00060?l000D00?l0103o00000`3oP000003o0000o`020000o`kooooo0P3o
0002003o00030?l00000o`000?l00080oh000P00o`020000o`030?n000000?l0003o00@0oh000`00
0?l70?n00080o`00103oP0050?l000L0oh000P3o00040?n00080o`0000<0oh000?l0003o00000P3o
P0040?l000D0oh000P3o00090?n000030?l00000o`000?l00100o`000P3oP0020?l00080oh000P3o
00000`000?l00?l0003o000;0?l00080oh0000<0003o0?l0003o00001P3oP0000`000?l0o`000?l0
00020?n001Sooooo000Fooooo`800?l00P3o00000`000?l00?l0003o0002003o01D0o`000P3oP007
0?l00080003o0P3oP00K0?l00080oh00303o0002003o00/0o`000`00o`040?l00080003o1`3o0002
0?n00100o`000`00o`020?l000800?l03_ooool20?l000D00?l00P3o0005003o0080o`002@00o`02
0?l00080003o1@00o`020?l001T00?l0103o0003003o00@0o`000`3oP0040?l000800?l000<0o`00
003o0000o`000P00o`040?l000030?n0003o0000o`0000L00?l00P3o000P003o00@0o`003_ooool5
003o00@0o`000P3oP002003o00X0o`000P000?l20?l000<0003o0P3o00090000o`80o`00103oP000
0`000?l00?l0003o0002003o0080o`000P000?l70?l000D00?l01`3o00020?n00080003o0P3oP000
0`3o0000003o0000o`020000o`80oh000P000?l00`3o00000?l0003o0006003o00030?l000000?l0
003o00@0o`001@000?l20?n00080003o00<0o`00003o0000o`001P3o0005003o00@0o`0000<0oh00
0000o`000?l00P000?l>ooooo`80o`000P00o`000`3o00000?l0003o00020?n000800?l00P000?l0
0`3oP000003o0000o`040?n000<0003o1`3oP0020?l000@0oh001@3o00070?n00080o`00103oP002
0?l000030?n0003o0000o`000080oh00103o00050?n00080o`002@3oP0000`3o00000?l0003o000@
0?l00080oh000P3o00020?n00080o`0000<0003o003o0000o`002`3o00020?n000030000o`3o0000
o`0000H0oh0000<0003o0?l0003o00000P3oP00Hooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05
oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
oaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`00>_oooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool001oooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01Ooo
oolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolGool003[ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooolGool003[ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool001oo
oooo5ol00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKo
ogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o
7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o00Go001o5_l00?lOo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Go
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o
001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_oo
O`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001E
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1C
o`00OaKoogl01Ol007l00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo
5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000o`00Ool007l0K_l007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo027ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oooombo`0002Oooooo
LOl0000Wooooog7o00009ooooombo`0002?ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo000Fooooo`@0003o0`3o00020000o`80o`000P000?lG0?l00080oh002P3o00020000o`/0o`00
0P000?l@0?l00080003o00<0o`000?n0003oP000103oP00G0?l000@0oh001@3o00040?n000030?l0
003oP000oh0000/0o`003_ooool40?l000<0003o0P3o00050000oa000?l01P000?l20?l000030000
o`3o0000o`0000800?l010000?l00`00o`00003o0000o`040000o`80o`0000<0oh000?l0003o0000
103o00050000o`80o`001@000?l20?l000@0003o00<00?l00000o`000?l01`000?l20?l000H0003o
00<0o`00003o0000o`000P000?l4003o00030000o`00o`000?l000800?l00P000?l00`3o0000003o
0000o`020000o`D0o`001P000?l20?l000030000o`3o0000o`000080003o3_ooool20?l000800?l0
00<0o`00003o0000o`003`00o`030000o`800?l00P000?l00`00o`00003o0000o`020000oa000?l0
0P000?l4003o00030000o`00o`000?l000800?l00P3o00020000o`03003o003o0000o`0000@0003o
00<0o`000000o`000?l0103o00020000o`030?l000000?l0003o00H00?l01`000?l20?l000030000
o`3o0000o`000080o`001@000?l20?l00080003o1@00o`090000o`80o`0010000?l00`3o00000?l0
003o0002003o00kooooo5`3oP0020?l000d0oh0000<0o`000?n0003oP0002`3oP0020?l00080oh00
0`3o00020?n00080o`00:@3oP0020?l000L0oh001@3o00060?n000030?l0003oP000oh0000/0oh00
6?ooool001Kooooo10000?l30?l00080003o0P3o00020000oaL0o`000P3oP00:0?l00080003o2`3o
00020000oa00o`000P000?l00`3o0000oh000?n000040?n001L0o`00103oP0050?l000@0oh0000<0
o`000?n0003oP0002`3o000>ooooo`@0o`000`000?l20?l000D0003o4000o`060000o`80o`0000<0
003o0?l0003o00000P00o`040000o`03003o00000?l0003o00@0003o0P3o00000`3oP000o`000?l0
00040?l000D0003o0P3o00050000o`80o`0010000?l00`00o`00003o0000o`070000o`80o`001P00
0?l00`3o00000?l0003o00020000o`@00?l000<0003o003o0000o`000P00o`020000o`030?l00000
0?l0003o0080003o1@3o00060000o`80o`0000<0003o0?l0003o00000P000?l>ooooo`80o`000P00
o`000`3o00000?l0003o000?003o00<0003o0P00o`020000o`03003o00000?l0003o0080003o4000
o`020000o`@00?l000<0003o003o0000o`000P00o`020?l00080003o00<00?l00?l0003o00001000
0?l00`3o0000003o0000o`040?l00080003o00<0o`000000o`000?l01P00o`070000o`80o`0000<0
003o0?l0003o00000P3o00050000o`80o`000P000?l5003o00T0003o0P3o00040000o`030?l00000
o`000?l000800?l03_oooolG0?n00080o`003@3oP0000`3o0000oh000?n0000;0?n00080o`000P3o
P0030?l00080oh000P3o000Y0?n00080o`001`3oP0050?l000H0oh0000<0o`000?n0003oP0002`3o
P00Hooooo`005_ooool20000o`80o`000`000?l20?l000@0003o403o00000`000?l0o`000?l00002
0000o`80o`000P3oP00:0?l00080003o0P3o00050?n001T0o`000P3oP0020?l00080oh00803o0007
0?n000H0o`000`3oP0020?l000kooooo2`3o0002003o00030000o`00o`000?l000h00?l00P000?l9
0?l000800?l02`000?l20?l000030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0
003o00D0o`000P00o`020?l00080003o2`00o`000`000?l00?l0003o0002003o0080003o0`3o0002
0000o`@00?l00P000?l00`00o`00003o0000o`050000o`80o`0010000?l50?l00080003o103o0000
0`00o`00o`000?l00002003o00kooooo0P3o00050000oa@00?l00P000?l00`00o`00003o0000o`02
0000o`80o`000P00o`000`000?l00?l0003o000?003o00030000o`3o0000o`000080003o103o0000
0`000?l0o`000?l000090000o`80o`001@000?l7003o00/0003o0P3o00040000o`030?l00000o`00
0?l000L00?l03`000?l00`3o0000003o0000o`02003o00kooooo3P3oP0020?l000L0oh000P3o0009
0?n00080o`000P3oP0030?l001/0oh00103o000R0?n00080o`007P3oP00Hooooo`005_ooool20000
o`80o`000`000?l20?l000@0003o403o00000`000?l0o`000?l000020000o`80o`000P3oP00:0?l0
0080003o0P3o00050?n001T0o`000P3oP0020?l00080oh00803o00070?n000H0o`000`3oP0020?l0
00kooooo2`3o0002003o00030000o`00o`000?l000h00?l00P000?l90?l000800?l02`000?l20?l0
00030000o`3o0000o`000080003o0P3o00020000o`030?l000000?l0003o00D0o`000P00o`020?l0
0080003o2`00o`000`000?l00?l0003o0002003o0080003o0`3o00020000o`@00?l00P000?l00`00
o`00003o0000o`050000o`80o`0010000?l50?l00080003o103o00000`00o`00o`000?l00002003o
00kooooo0P3o00050000oa@00?l00P000?l00`00o`00003o0000o`020000o`80o`000P00o`000`00
0?l00?l0003o000?003o00030000o`3o0000o`000080003o103o00000`000?l0o`000?l000090000
o`80o`001@000?l7003o00/0003o0P3o00040000o`030?l00000o`000?l000L00?l03`000?l00`3o
0000003o0000o`02003o00kooooo3P3oP0020?l000L0oh000P3o00090?n00080o`000P3oP0030?l0
01/0oh00103o000R0?n00080o`007P3oP00Hooooo`005_ooool40000oaL0o`000P000?l50?l00080
003o0P3o00000`000?l0o`000?l0000=0?l000<0oh001P3o00020?n000P0o`000P3oP0060?l000L0
oh00303o00020000oa80o`001@3oP0080?l000D0oh003_ooool20?l000800?l00`000?l20?l00080
003o0P00o`000`000?l00?l0003o0004003o0080o`000`000?l20?l000D00?l00P000?l40?l000<0
0?l02@000?l2003o00L0003o0P3o0004003o00030?l000000?l0003o00D0o`000P00o`040000o``0
0?l00P3o00040000o`D00?l00P000?l2003o0080003o0`00o`020000o`800?l00`000?l20?l000@0
003o0`3o00060000o`<00?l00P3o000>ooooo`80o`000P000?l30?l000H0003o9`00o`020?l00080
003o00<00?l00000o`000?l010000?l20?l000030000o`3o0000o`000080003o0P00o`000`3o0000
003o0000o`060?l000`00?l00P3o00020000o`80o`000`000?l20?l000h00?l00P000?l4003o0003
0000o`00o`000?l000@0003o1`00o`0>ooooo`T0oh000P3o00070?n00080003o0P3o000R0?n00003
0?l0003oP000oh0000H0oh000`3o00040000o``0o`006@3oP0020?l001/0oh006?ooool001Kooooo
0P3o00030000o`l0o`000P000?l@0?l000030000o`3o0000o`0001@0o`000P000?l50?l00080003o
2`3o00050?n000@0o`0000<0oh000?l0003o00000P3o00020000o`<0o`000P000?l90?l000@0003o
4P3o00050?n000kooooo103o00000`000?l0o`000?l000040?l000T00?l01@000?l50?l000P00?l0
00<0003o003o0000o`002`000?l2003o0080003o00<0o`00003o0000o`000P3o0004003o00L0o`00
0`000?l20?l00080003o1`00o`020000oaL00?l00P3o00030000o`@0o`000P000?l30?l00080003o
0P00o`020000o`D00?l00P000?l>ooooo`80o`000P000?l30?l00080003o1`00o`040000o`<0o`00
1P000?l9003o00L0003o0P3o0005003o0100003o1@00o`020000o`800?l00P3o00030000o`80o`00
1P00o`050000o`@00?l000<0003o003o0000o`000P3o000E003o0080003o0P3o00020000o`L00?l0
3_ooool>0?n00080o`000P3oP0020000ob@0oh0000<0o`000?n0003oP0001`3oP0020?l000L0oh00
0P3o000V0?n000030?l0003oP000oh0000L0oh00103o00090?n001Sooooo000Fooooo`80o`000`00
0?l?0?l00080003o403o00000`000?l0o`000?l0000D0?l00080003o1@3o00020000o`/0o`001@3o
P0040?l000030?n0003o0000o`000080o`000P000?l30?l00080003o2@3o00040000oa80o`001@3o
P00>ooooo`@0o`0000<0003o0?l0003o0000103o0009003o00D0003o1@3o0008003o00030000o`00
o`000?l000/0003o0P00o`020000o`030?l00000o`000?l00080o`001000o`070?l000<0003o0P3o
00020000o`L00?l00P000?lG003o0080o`000`000?l40?l00080003o0`3o00020000o`800?l00P00
0?l5003o0080003o3_ooool20?l00080003o0`3o00020000o`L00?l010000?l30?l000H0003o2@00
o`070000o`80o`001@00o`0@0000o`D00?l00P000?l2003o0080o`000`000?l20?l000H00?l01@00
0?l4003o00030000o`00o`000?l00080o`005@00o`020000o`80o`000P000?l7003o00kooooo3P3o
P0020?l00080oh000P000?lT0?n000030?l0003oP000oh0000L0oh000P3o00070?n00080o`009P3o
P0000`3o0000oh000?n000070?n000@0o`002@3oP00Hooooo`005_ooool20000oaD0o`000P3oP004
0?l000030000o`3o0000o`0000l0o`0000<0003o0?l0003o0000803o00040?n000@0o`000`3oP002
0?l00080003o1`3o00020000o`D0o`000P000?lI0?l000kooooo5000o`070000oah00?l00P000?l2
0?l000@00?l000<0o`000000o`000?l01@3o00020000o`80o`000P00o`030000oaH00?l00P3o0003
0000o`80o`000P00o`020000o`<00?l010000?l30?l000T00?l00P3o00020000o`kooooo0P3o0002
0000o`<0o`0010000?l3003o0080o`0010000?l20?l000D0003o2@00o`070000o`@0o`001@000?l7
0?l00080003o0P3o000:003o00@0o`000P000?l50?l00080003o1000o`050000o`80o`007000o`04
0000o`800?l01@000?l2003o00kooooo4P3oP0020?l000D0oh000P3o000I0?n00080o`00403oP003
0?l00440oh006?ooool001Kooooo0P000?lE0?l00080oh00103o00000`000?l0o`000?l0000?0?l0
00030000o`3o0000o`000200o`00103oP0040?l000<0oh000P3o00020000o`L0o`000P000?l50?l0
0080003o6@3o000>oooooa@00?l01`000?lN003o0080003o0P3o0004003o00030?l000000?l0003o
00D0o`000P000?l20?l000800?l00`000?lF003o0080o`000`000?l20?l000800?l00P000?l3003o
00@0003o0`3o0009003o0080o`000P000?l>ooooo`80o`000P000?l30?l000@0003o0`00o`020?l0
00@0003o0P3o00050000o`T00?l01`000?l40?l000D0003o1`3o00020000o`80o`002P00o`040?l0
0080003o1@3o00020000o`@00?l01@000?l20?l001`00?l010000?l2003o00D0003o0P00o`0>oooo
oa80oh000P3o00050?n00080o`006@3oP0020?l00100oh000`3o00110?n001Sooooo000Fooooo`@0
003o1`3o0002003o00`0o`000P000?l20?l000030000o`3o0000o`000080o`000P3oP0020?l00003
0000o`3o0000o`000180o`000P000?lD0?l000030000o`3o0000o`0001l0o`0000<0oh000?l0003o
0000103o00020000o`030?l000000?l0003o0080003o103o00000`000?l0o`000?l000020?l000ko
oooo1@000?lA003o00<0003o1`00o`040000o`80o`001@000?l@003o0080o`0010000?l00`3o0000
003o0000o`020000o`80o`000`000?l20?l00080003o0`00o`020?l000@0003o4000o`020000o`80
o`0000<0003o0?l0003o00001@00o`020000o`800?l00P000?l9003o0080003o00<0o`000000o`00
0?l00P000?l>ooooo`L0o`001`00o`060000o`80o`001@000?l2003o00030?l00000o`000?l00080
0?l00P3o000>0000o`80o`001`000?l2003o0080o`000`00o`020000o`800?l00P3o00000`00o`00
003o0000o`060000o`<0o`001000o`050000o`@0o`000`00o`020000oa800?l010000?l00`00o`00
003o0000o`06003o00030?l00000o`000?l000800?l03_oooolB0?n00080o`00803oP0020?l00180
oh000`3o000;0?n000@0o`00<03oP00Hooooo`005_ooool40000o`L0o`000P00o`0<0?l00080003o
0P3o00000`000?l0o`000?l000020?l00080oh000P3o00000`000?l0o`000?l0000B0?l00080003o
503o00000`000?l0o`000?l0000O0?l000030?n0003o0000o`0000@0o`000P000?l00`3o0000003o
0000o`020000o`@0o`0000<0003o0?l0003o00000P3o000>ooooo`D0003o4@00o`030000o`L00?l0
10000?l20?l000D0003o4000o`020?l000@0003o00<0o`000000o`000?l00P000?l20?l000<0003o
0P3o00020000o`<00?l00P3o00040000oa000?l00P000?l20?l000030000o`3o0000o`0000D00?l0
0P000?l2003o0080003o2@00o`020000o`030?l000000?l0003o0080003o3_ooool70?l000L00?l0
1P000?l20?l000D0003o0P00o`000`3o00000?l0003o0002003o0080o`003P000?l20?l000L0003o
0P00o`020?l000<00?l00P000?l2003o0080o`0000<00?l00000o`000?l01P000?l30?l000@00?l0
1@000?l40?l000<00?l00P000?lB003o00@0003o00<00?l00000o`000?l01P00o`000`3o00000?l0
003o0002003o00kooooo4P3oP0020?l00200oh000P3o000B0?n000<0o`002`3oP0040?l00300oh00
6?ooool001Kooooo10000?l70?l00080003o3P3o00030000obl0o`000P000?l20?l000030000o`3o
0000o`0000T0o`0010000?l70?l000@0003o1`3o00000`000?l0o`000?l000070?l00080003o1`3o
00040000o`kooooo0P000?lB003o00D0003o0P3o0003003o00H0003o0P3o00000`000?l00?l0003o
000B003o00H0003o00<0o`00003o0000o`001000o`000`000?l00?l0003o00020?l00080003o1@3o
000D003o0080003o1`00o`050000o`@00?l00P000?l00`00o`00o`000?l000060000o`030?l00000
o`000?l00080003o3_ooool20000o`<0o`001000o`020?l000800?l01@000?l50?l000H00?l000<0
003o003o0000o`000P000?l20?l000<0003o0P3o00020000o`800?l00P3o00070000o`80o`000`00
0?l;003o0080003o00<00?l00000o`000?l00P000?l20?l000<0003o103o0002003o0080003o00<0
o`000000o`000?l01P00o`000`000?l0o`000?l00002003o00L0003o103o00000`000?l0o`000?l0
00040000o`80o`0000<0003o003o0000o`001000o`020?l000030000o`00o`000?l00080o`003_oo
oolI0?n00080o`00K`3oP00Hooooo`005_ooool20000o`80o`0000<0003o0?l0003o00000P3oP002
0?l00080003o3P3o00030000o`H0o`000`000?l=0?l00080003o2`3o00000`000?l0o`000?l0000K
0?l00080003o2@3o00020000o`<0o`000P000?lI0?l000kooooo10000?l@003o00D0003o1`00o`02
0000o`@0o`0000<0003o003o0000o`004000o`020?l00080003o103o0003003o00@0003o0`00o`04
0000o`D0o`003`00o`000`3o0000003o0000o`020000o`80o`000P000?l00`00o`00o`000?l00002
003o00<0003o0P3o00060000o`03003o00000?l0003o00@0003o0`3o0004003o00kooooo0P000?l2
0?l000D00?l010000?l00`00o`00o`000?l000020000o`800?l00P3o00000`000?l00?l0003o0004
003o00030000o`00o`000?l000800?l00P000?l5003o0080o`0010000?l30?l00080003o0P00o`02
0000o`03003o00000?l0003o0080o`000P00o`030?l000@0003o0`3o0002003o0080o`000P000?l3
0?l00080003o0P3o0002003o0080003o1`00o`050000o`@00?l01@000?l40?l000<0003o2@3o0004
0000o`80o`0000<0003o003o0000o`000P3o000>oooooh<0oh000P3o00050?n001Sooooo000Foooo
o`80003o0P3o00000`000?l0o`000?l000020?n00080o`000P000?l>0?l000<0003o1P3o00030000
o`d0o`000P000?l;0?l000030000o`3o0000o`0001/0o`000P000?l90?l00080003o0`3o00020000
oaT0o`003_ooool40000oa000?l01@000?l7003o0080003o103o00000`000?l00?l0003o000@003o
0080o`000P000?l40?l000<00?l010000?l3003o00@0003o1@3o000?003o00030?l000000?l0003o
0080003o0P3o00020000o`03003o003o0000o`0000800?l00`000?l20?l000H0003o00<00?l00000
o`000?l010000?l30?l000@00?l03_ooool20000o`80o`001@00o`040000o`03003o003o0000o`00
0080003o0P00o`020?l000030000o`00o`000?l000@00?l000<0003o003o0000o`000P00o`020000
o`D00?l00P3o00040000o`<0o`000P000?l2003o0080003o00<00?l00000o`000?l00P3o0002003o
00<0o`0010000?l30?l000800?l00P3o00020000o`<0o`000P000?l20?l000800?l00P000?l7003o
00D0003o1000o`050000o`@0o`000`000?l90?l000@0003o0P3o00000`000?l00?l0003o00020?l0
00koooooP`3oP0020?l000D0oh006?ooool001Kooooo0P00o`030000oaP0o`0000<0003o0?l0003o
0000103o00030000o`d0o`000P000?l50?l00080003o103o00000`000?l0o`000?l00002003o0080
o`0000<0oh000?l0003o00002`3o00020000o`L0o`000P000?l90?l00080003o0`3o00040000o`03
0?l000000?l0003o01@0o`003_oooolM003o00L0003o3000o`040000o`800?l00`000?l40?l000D0
0?l01P000?l00`3o0000003o0000o`070?l00080003o0P3o000=003o00D0003o0P3o0005003o00D0
003o0P3o0002003o00@0003o00<0o`000000o`000?l010000?l20?l000D00?l03_ooool9003o0080
003o2`00o`000`3o0000003o0000o`020000o`80o`001@00o`020000o`D00?l00P3o00040000o`03
0?l00000o`000?l000@00?l00P000?l5003o00@0003o00<0o`000000o`000?l01`00o`020?l00080
003o0P3o00030000o`80o`002@00o`070000o`@0o`000`000?l40?l000L0003o0P3o00020000o`<0
o`000P00o`020000o`80o`000`000?l20?l000kooooo6@3oP0020?l003T0oh000P3o000I0?n00080
o`006@3oP00Hooooo`005_ooool2003o00<0003o603o00000`000?l0o`000?l000040?l000<0003o
3@3o00020000o`D0o`000P000?l40?l000030000o`3o0000o`0000800?l00P3o00000`3oP000o`00
0?l0000;0?l00080003o1`3o00020000o`T0o`000P000?l30?l000@0003o00<0o`000000o`000?l0
503o000>oooooad00?l01`000?l<003o00@0003o0P00o`030000o`@0o`001@00o`060000o`030?l0
00000?l0003o00L0o`000P000?l20?l000d00?l01@000?l20?l000D00?l01@000?l20?l000800?l0
10000?l00`3o0000003o0000o`040000o`80o`001@00o`0>ooooo`T00?l00P000?l;003o00030?l0
00000?l0003o0080003o0P3o0005003o0080003o1@00o`020?l000@0003o00<0o`00003o0000o`00
1000o`020000o`D00?l010000?l00`3o0000003o0000o`07003o0080o`000P000?l20?l000<0003o
0P3o0009003o00L0003o103o00030000o`@0o`001`000?l20?l00080003o0`3o0002003o0080003o
0P3o00030000o`80o`003_oooolI0?n00080o`00>@3oP0020?l001T0oh000P3o000I0?n001Sooooo
000Fooooo`L0003o103o00020000obh0o`0010000?l70?l00080003o5@3o00020000o`L0o`000P00
0?l20?l00080003o6@3o00000`3oP000o`000?l000020?l000kooooo7P00o`020?l000@0003o0P3o
00030000o`80o`002@00o`020?l00080003o00<00?l00000o`000?l01000o`0:0000o`80o`001P3o
P0050?l000T00?l02`000?l7003o0080003o00<00?l00000o`000?l00P000?l20?l00080003o0`3o
00020000o`@0o`001@00o`0>ooooo`80003o4000o`020000o`<00?l010000?l20?l000`00?l01000
0?l2003o00030?l00000o`000?l000/00?l00P000?l20?l000030000o`00o`000?l000L00?l00P00
0?l20?l000<0003o0P3o0009003o00@0003o0P3o00000`000?l0o`000?l000070000o`L00?l00P3o
00020000o`L0o`000P000?l4003o00030000o`00o`000?l00080o`003_oooolG0?n00080003o103o
000W0?n00080o`00303oP0020?l002d0oh000P3o00070?n001Sooooo000Fooooo`L0003o103o0002
0000obh0o`0010000?l70?l00080003o5@3o00020000o`L0o`000P000?l20?l00080003o6@3o0000
0`3oP000o`000?l000020?l000kooooo7P00o`020?l000@0003o0P3o00030000o`80o`002@00o`02
0?l00080003o00<00?l00000o`000?l01000o`0:0000o`80o`001P3oP0050?l000T00?l02`000?l7
003o0080003o00<00?l00000o`000?l00P000?l20?l00080003o0`3o00020000o`@0o`001@00o`0>
ooooo`80003o4000o`020000o`<00?l010000?l20?l000`00?l010000?l2003o00030?l00000o`00
0?l000/00?l00P000?l20?l000030000o`00o`000?l000L00?l00P000?l20?l000<0003o0P3o0009
003o00@0003o0P3o00000`000?l0o`000?l000070000o`L00?l00P3o00020000o`L0o`000P000?l4
003o00030000o`00o`000?l00080o`003_oooolG0?n00080003o103o000W0?n00080o`00303oP002
0?l002d0oh000P3o00070?n001Sooooo000Fooooo`80003o0P3o00000`000?l0o`000?l000040?l0
0080003o3P3o00020000o`03003o003o0000o`0001l0o`000`000?lD0?l00080003o1`3o00020000
oa00o`000P00o`000`000?l0o`000?l000020000o`L0o`000P000?l90?l000kooooo7P00o`060000
o`80o`0000<0003o0?l0003o0000103o000G003o00D0003o2@3o00020000o`80o`002`00o`020000
o`030?l000000?l0003o00@0o`001`00o`020000o`T00?l00`3o00040000o`80o`0000<0003o0?l0
003o00000P00o`0>ooooo`T00?l01@000?l20?l000@0003o0P00o`050000o`h00?l00P3o00020000
o`800?l000<0o`00003o0000o`001`00o`020000o`800?l00P000?l20?l000X00?l00P000?lB003o
00L0003o1000o`020000o`L00?l000<0003o003o0000o`000P00o`020000o`/00?l000<0003o003o
0000o`000P3o000>oooooa80oh00303o000V0?n00080o`003P3oP0020?l002/0oh000P3o00020?n0
00030?l0003oP000oh000080oh006?ooool001Kooooo0P000?l20?l000030000o`3o0000o`0000@0
o`000P000?l>0?l00080003o00<00?l00?l0003o00007`3o00030000oa@0o`000P000?l70?l00080
003o403o0002003o00030000o`3o0000o`000080003o1`3o00020000o`T0o`003_oooolN003o00H0
003o0P3o00000`000?l0o`000?l000040?l001L00?l01@000?l90?l00080003o0P3o000;003o0080
003o00<0o`000000o`000?l0103o0007003o0080003o2@00o`030?l000@0003o0P3o00000`000?l0
o`000?l00002003o00kooooo2@00o`050000o`80o`0010000?l2003o00D0003o3P00o`020?l00080
003o0P00o`000`3o00000?l0003o0007003o0080003o0P00o`020000o`80o`002P00o`020000oa80
0?l01`000?l4003o0080003o1`00o`000`000?l00?l0003o0002003o0080003o2`00o`000`000?l0
0?l0003o00020?l000kooooo4P3oP00<0?l002H0oh000P3o000>0?n00080o`00:`3oP0020?l00080
oh0000<0o`000?n0003oP0000P3oP00Hooooo`005_ooool40?l000030000o`3o0000o`000100o`00
0P000?l40?l000030000o`3o0000o`000080003o0P3o00030000o`80o`000P000?l40?l000030000
o`3o0000o`0000@0o`000P3oP00C0?l00080003o4P3o00020000oa/0o`0000<0003o0?l0003o0000
2`3o000>oooooah00?l02@000?l60?l000T00?l00P000?l5003o00@0003o1@00o`030000o`T0o`00
0P000?l20?l00080003o1@00o`090000o`d00?l01`000?l2003o00<0o`000P000?l70?l000800?l0
3_ooool20000o`T00?l00`000?l6003o0080o`003P00o`020000o`03003o003o0000o`000080o`00
7@00o`000`000?l00?l0003o00020?l000D0003o0P3o0007003o00H0003o0P00o`000`3o0000003o
0000o`020?l000800?l00`000?lI003o00@0003o3_oooon:0?n001Sooooo000Fooooo`80003o0P00
o`000`000?l0o`000?l0000F0?l000030000o`3o0000o`0000@0o`000`000?l20?l000800?l00P3o
00030000o`H0o`000`3oP00B0?l00080003o103o00030000oa80o`000P000?l20?l000<0003o7@3o
000>oooooa@00?l00P3o00030000o`80o`001@00o`060000o`03003o003o0000o`0000l00?l000<0
003o0?l0003o00000P000?l40?l000030000o`00o`000?l000@00?l00`000?l20?l00080003o0P3o
00000`000?l0o`000?l000020?l00080003o0P3o000I003o00030000o`00o`000?l00080003o1000
o`090?l000<0003o0P3o000>oooooa000?l00P000?l2003o0080o`00<P00o`000`000?l0o`000?l0
00020?l000@0003o0`3o000=003o0080o`000`000?l20?l000800?l00P3o0003003o00d0003o2P00
o`020000o`800?l03_ooool20?l001T0oh001@3o000B0?n000@0o`00E03oP00Hooooo`005_ooool2
0000o`800?l000<0003o0?l0003o00005P3o00000`000?l0o`000?l000040?l000<0003o0P3o0002
003o0080o`000`000?l60?l000<0oh004P3o00020000o`@0o`000`000?lB0?l00080003o0P3o0003
0000oad0o`003_oooolD003o0080o`000`000?l20?l000D00?l01P000?l00`00o`00o`000?l0000?
003o00030000o`3o0000o`000080003o103o00000`000?l00?l0003o0004003o00<0003o0P3o0002
0000o`80o`0000<0003o0?l0003o00000P3o00020000o`80o`006@00o`000`000?l00?l0003o0002
0000o`@00?l02@3o00030000o`80o`003_ooool@003o0080003o0P00o`020?l003800?l000<0003o
0?l0003o00000P3o00040000o`<0o`003@00o`020?l000<0003o0P3o0002003o0080o`000`00o`0=
0000o`X00?l00P000?l2003o00kooooo0P3o000I0?n000D0o`004P3oP0040?l005@0oh006?ooool0
01Kooooo0P000?l3003o00/0o`00103oP0090?l000030000o`3o0000o`0000H0o`0000<00?l00?l0
003o0000103o00020000o`<0o`000P000?lM0?l000030000o`3o0000o`000180o`000P000?l70?l0
0080oh001`3o00020?n00100o`003_oooolD003o00<0003o103o0003003o0080003o0P00o`040000
o`<0o`002`00o`040000o`03003o003o0000o`0000800?l00P000?l2003o00030?l000000?l0003o
00L00?l00P3o00020000o`<0o`001P000?l20?l000L00?l00P3o00000`00o`00003o0000o`0D003o
0080003o00<00?l00?l0003o00000P000?l50?l00080003o0P3o000>ooooo`800?l00`000?lA003o
00030000o`00o`000?l000/00?l00P000?l5003o00@0003o5@00o`070000o`80o`000P000?l50?l0
00d00?l00P000?l00`3o0000003o0000o`040?l000800?l000<0o`00003o0000o`001@00o`020000
o`800?l010000?l00`3o00000?l0003o0007003o00@0003o3_ooool`0?n000@0o`00EP3oP00Hoooo
o`005_ooool20000o`<00?l02`3o00040?n000T0o`0000<0003o0?l0003o00001P3o00000`00o`00
o`000?l000040?l00080003o0`3o00020000oad0o`0000<0003o0?l0003o00004P3o00020000o`L0
o`000P3oP0070?l00080oh00403o000>oooooa@00?l00`000?l40?l000<00?l00P000?l2003o00@0
003o0`3o000;003o00@0003o00<00?l00?l0003o00000P00o`020000o`800?l000<0o`000000o`00
0?l01`00o`020?l00080003o0`3o00060000o`80o`001`00o`020?l00003003o00000?l0003o01@0
0?l00P000?l00`00o`00o`000?l000020000o`D0o`000P000?l20?l000kooooo0P00o`030000oa40
0?l000<0003o003o0000o`002`00o`020000o`D00?l010000?lE003o00L0003o0P3o00020000o`D0
o`003@00o`020000o`030?l000000?l0003o00@0o`000P00o`000`3o00000?l0003o0005003o0080
003o0P00o`040000o`030?l00000o`000?l000L00?l010000?l>oooooc00oh00103o001F0?n001So
oooo000Fooooo`@00?l01`3o0002003o02<0o`000P000?l20?l00080003o1`3o00020000o`<0o`00
10000?lE0?l00080003o103o00020000o`030?l000000?l0003o00/0o`000P3oP00G0?l000kooooo
4P00o`090000o`800?l000<0003o0?l0003o000010000?l20?l001<00?l010000?l20?l000D0003o
0P00o`050000o`80o`0010000?l30?l000@00?l00P3o0005003o0080o`000`000?l;003o00D0003o
1P00o`030000o`80o`0010000?l30?l000@0003o3_ooool20000o`80o`001`000?l20?l000T00?l0
00<0o`000000o`000?l00P3o000;003o00030000o`3o0000o`000080o`000P000?l20?l001T00?l0
1@3o00040000o`030?l00000o`000?l000d00?l00`000?l20?l00080003o1@3o0002003o0080003o
0P00o`0:0000o`@0o`0010000?l00`3o0000003o0000o`02003o00kooooo5`3oP0020?l00280oh00
103o00050?n00080o`000P3oP0000`3o0000oh000?n0000[0?n000@0o`00403oP00Hooooo`005_oo
ool4003o00L0o`000P00o`0S0?l00080003o0P3o00020000o`L0o`000P000?l30?l000@0003o5@3o
00020000o`@0o`000P000?l00`3o0000003o0000o`0;0?l00080oh005`3o000>oooooa800?l02@00
0?l2003o00030000o`3o0000o`0000@0003o0P3o000C003o00@0003o0P3o00050000o`800?l01@00
0?l20?l000@0003o0`3o0004003o0080o`001@00o`020?l000<0003o2`00o`050000o`H00?l00`00
0?l20?l000@0003o0`3o00040000o`kooooo0P000?l20?l000L0003o0P3o0009003o00030?l00000
0?l0003o0080o`002`00o`000`000?l0o`000?l000020?l00080003o0P3o000I003o00D0o`001000
0?l00`3o00000?l0003o000=003o00<0003o0P3o00020000o`D0o`000P00o`020000o`800?l02P00
0?l40?l000@0003o00<0o`000000o`000?l00P00o`0>oooooaL0oh000P3o000R0?n000@0o`001@3o
P0020?l00080oh0000<0o`000?n0003oP000:`3oP0040?l00100oh006?ooool001Kooooo1000o`00
0`000?l0o`000?l000070?l00080003o0P00o`020?l00080003o1`3o00000`000?l0o`000?l0000[
0?l000H0003o00<0o`000?n0003oP000403o00020000o`L0o`000P000?l20?l00080oh002P3o0002
0000o`H0o`000`3oP0020?l000kooooo5000o`020000o`P00?l00P000?l20?l00080003o0P3o000C
003o00@0003o0P3o00090000o`03003o003o0000o`0000@0003o0`3o0006003o0080o`000`000?l4
0?l000<0003o0P3o0009003o0080003o2`00o`050000o`@0o`0000<0003o0?l0003o00000P3o000>
ooooo`L0003o0P3o00020000o`80o`002@00o`050000o``00?l00P3o00020000o`800?l00P3o000:
003o0080003o3P00o`060000o`D0o`001`00o`040000o`@00?l01@000?l20?l000800?l000<0003o
003o0000o`002@00o`040000o`<0o`000P000?l20?l00080003o1@3o000>oooooc/0oh000P3o0007
0?n00080o`00;P3oP0020?l00080003o103o000>0?n001Sooooo000Fooooo`@00?l000<0003o0?l0
003o00001`3o00020000o`800?l00P3o00020000o`L0o`0000<0003o0?l0003o0000:`3o00060000
o`030?l0003oP000oh000100o`000P000?l70?l00080003o0P3o00020?n000X0o`000P000?l60?l0
00<0oh000P3o000>oooooa@00?l00P000?l8003o0080003o0P3o00020000o`80o`004`00o`040000
o`80o`002@000?l00`00o`00o`000?l000040000o`<0o`001P00o`020?l000<0003o103o00030000
o`80o`002@00o`020000o`/00?l01@000?l40?l000030000o`3o0000o`000080o`003_ooool70000
o`80o`000P000?l20?l000T00?l01@000?l<003o0080o`000P000?l2003o0080o`002P00o`020000
o`h00?l01P000?l50?l000L00?l010000?l4003o00D0003o0P3o0002003o00030000o`00o`000?l0
00T00?l010000?l30?l00080003o0P3o00020000o`D0o`003_oooolk0?n00080o`001`3oP0020?l0
02h0oh000P3o00020000o`@0o`003P3oP00Hooooo`005_ooool4003o00030000o`3o0000o`0000l0
o`0000<0003o0?l0003o00000P000?lE0?l00080003o1P3o00000`000?l0o`000?l000040?l00080
003o303o00020000o`800?l000<0o`000?n0003oP0000P3oP00D0?l00080003o2P3o00020000o`L0
o`000P000?l40?l000<0oh000P3o000>oooooah00?l02@000?l?003o00<0003o0P3o00020000o`80
o`000`000?l20?l000D00?l00P000?l20?l00080003o0`3o0006003o0080003o00<0o`000000o`00
0?l00P3o00020000o`D00?l00P3o00040000o`030?l00000o`000?l000@00?l000<0003o003o0000
o`002@00o`020000o`80o`001`000?l>ooooo`800?l030000?l6003o00D0003o0P3o00030000o`80
o`001P00o`000`000?l0o`000?l000020000o`@0o`001`00o`020000o`03003o00000?l0003o00@0
0?l00`000?l20?l000800?l00P3o0003003o0080o`000P000?l50?l001H00?l00P000?l5003o0080
o`002@000?l30?l000@0003o0P3o00000`000?l0o`000?l000020?l000kooooo903oP0020?l001h0
oh000P000?l20?l00300oh00103o000>0?n001Sooooo000Fooooo`@00?l02@3o00000`000?l0o`00
0?l000090?l00080003o0P3o00000`000?l0o`000?l000020000o`@0o`0000<00?l00000o`000?l0
1`3o00020000o`L0o`000P000?lI0?l00080003o8P3o00020000oa00o`003_oooolP003o0080003o
0P3o000@003o00@0003o00<00?l00?l0003o00000P3o00040000o`<0o`000P000?l7003o0080003o
2@00o`030000o`@0o`001`00o`060000o`030?l00000o`000?l000h00?l02@000?l20?l00080003o
3_ooool20000o`80o`0000<0003o0?l0003o00003@00o`020?l000030000o`3o0000o`000080o`00
0`000?l20?l000T00?l00P3o00040000o`<0o`000P000?l=003o00030000o`3o0000o`0000800?l0
0P3o0003003o00@0003o1`3o00040000o`030?l00000o`000?l000L00?l020000?l00`3o0000003o
0000o`020?l00080003o0`3o00020000o`80o`000P000?l50?l00080003o1`3o000>ooooo`d0oh00
00<0o`000?n0003oP000:@3oP0020?l002T0oh000P3o000B0?n000@0o`003P3oP00Hooooo`005_oo
ool4003o00T0o`0000<0003o0?l0003o00002@3o00020000o`80o`0000<0003o0?l0003o00000P00
0?l40?l00003003o00000?l0003o00L0o`000P000?l70?l00080003o6@3o00020000ob80o`000P00
0?l@0?l000kooooo8000o`020000o`80o`004000o`040000o`03003o003o0000o`000080o`001000
0?l30?l00080003o1`00o`020000o`T00?l00`000?l40?l000L00?l01P000?l00`3o00000?l0003o
000>003o00T0003o0P3o00020000o`kooooo0P000?l20?l000030000o`3o0000o`0000d00?l00P3o
00000`000?l0o`000?l000020?l000<0003o0P3o0009003o0080o`0010000?l30?l00080003o3@00
o`000`000?l0o`000?l00002003o0080o`000`00o`040000o`L0o`0010000?l00`3o00000?l0003o
0007003o00P0003o00<0o`000000o`000?l00P3o00020000o`<0o`000P000?l20?l00080003o1@3o
00020000o`L0o`003_ooool=0?n000030?l0003oP000oh0002T0oh000P3o000Y0?n00080o`004P3o
P0040?l000h0oh006?ooool001Kooooo1000o`090?l000030000o`3o0000o`0001H0o`0000<00?l0
0?l0003o0000503o00020?n001D0o`000P000?lB0?l00080003o4`3o00060000o`L0o`003_ooool2
0000o`80o`007000o`020000oa800?l010000?l7003o00<0003o2`00o`020000o`D00?l010000?l2
0?l000030000o`00o`000?l000T00?l01`000?lB003o00T0003o0P00o`0>ooooo`800?l00P3o0000
0`000?l00?l0003o0002003o0080003o1`00o`020000o`80o`0000<0003o0?l0003o00000P3o0003
0000o`80o`000P00o`040000o`030?l000000?l0003o00T0o`000P000?l9003o00L0003o0P00o`02
0000o`D00?l00P000?l50?l00080003o1000o`000`3o00000?l0003o0004003o00<0003o0P3o0002
0000o`80o`000P000?l00`3o0000003o0000o`050000o`80o`000P000?l20?l000800?l000<0003o
003o0000o`000P00o`020?l00080003o1@3o000>ooooo`d0oh0000<0o`000?n0003oP000=03oP004
0?l00300oh002@3o00090?n001Sooooo000Fooooo`@00?l02@3o00000`000?l0o`000?l0000F0?l0
0003003o003o0000o`0001@0o`000P3oP00E0?l00080003o4P3o00020000oa<0o`001P000?l70?l0
00kooooo0P000?l20?l001`00?l00P000?lB003o00@0003o1`00o`030000o`/00?l00P000?l5003o
00@0003o0P3o00000`000?l00?l0003o0009003o00L0003o4P00o`090000o`800?l03_ooool2003o
0080o`0000<0003o003o0000o`000P00o`020000o`L00?l00P000?l20?l000030000o`3o0000o`00
0080o`000`000?l20?l000800?l010000?l00`3o0000003o0000o`090?l00080003o2@00o`070000
o`800?l00P000?l5003o0080003o1@3o00020000o`@00?l000<0o`00003o0000o`001000o`030000
o`80o`000P000?l20?l00080003o00<0o`000000o`000?l01@000?l20?l00080003o0P3o0002003o
00030000o`00o`000?l000800?l00P3o00020000o`D0o`003_ooool=0?n000030?l0003oP000oh00
03@0oh00103o000`0?n000T0o`002@3oP00Hooooo`005_ooool2003o0080003o8P3o00000`00o`00
o`000?l000040?l00080003o1@3o00020000o`<0o`000P000?l=0?l000030?n0003o0000o`0000H0
o`0000<0oh000?l0003o00001`3o00020000oa80o`0010000?l00`3o0000003o0000o`0=0?l00080
003o1@3o000>ooooo`80003o0P3o000J003o00H0003o0P3o000@003o0080003o00<0o`000000o`00
0?l01P3o000>003o00<0003o1000o`020000o`80o`0000<00?l00000o`000?l02`00o`020000o`80
0?l000<0o`00003o0000o`004000o`020?l00080003o1@3o0002003o00kooooo0P00o`020?l00003
0000o`00o`000?l000/00?l01`000?l20?l00080003o0`3o0006003o00030?l000000?l0003o00@0
o`000P000?l30?l000d00?l00P000?l00`3o0000003o0000o`02003o0080o`000`00o`020?l000L0
0?l010000?l<003o01@0003o0P3o00030000o`80o`001000o`030000o`@0o`003_ooool90?n00080
o`000P3oP0030?l005@0oh000P3o000G0?n000@0o`001`3oP0020?l001Sooooo000Fooooo`800?l0
0P000?lR0?l00003003o003o0000o`0000@0o`000P000?l50?l00080003o0`3o00020000o`d0o`00
00<0oh000?l0003o00001P3o00000`3oP000o`000?l000070?l00080003o4P3o00040000o`030?l0
00000?l0003o00d0o`000P000?l50?l000kooooo0P000?l20?l001X00?l01P000?l20?l001000?l0
0P000?l00`3o0000003o0000o`060?l000h00?l00`000?l4003o0080003o0P3o00000`00o`00003o
0000o`0;003o0080003o0P00o`000`3o00000?l0003o000@003o0080o`000P000?l50?l000800?l0
3_ooool2003o0080o`0000<0003o003o0000o`002`00o`070000o`80o`000P000?l30?l000H00?l0
00<0o`000000o`000?l0103o00020000o`<0o`003@00o`020000o`030?l000000?l0003o00800?l0
0P3o0003003o0080o`001`00o`040000o``00?l050000?l20?l000<0003o0P3o0004003o00<0003o
103o000>ooooo`T0oh000P3o00020?n000<0o`00E03oP0020?l001L0oh00103o00070?n00080o`00
6?ooool001Kooooo1000o`070?l00080003o303o00020000oa@0o`0000<0003o0?l0003o00005P3o
00030?n000H0o`0000<0oh000?l0003o00001P3o00000`000?l0o`000?l0000]0?l000kooooo0P00
o`020?l000D00?l010000?lA003o00H0003o0P3o000<003o00/0003o0P3o00020000o`030?l00000
o`000?l000/00?l00P000?l3003o0080003o3@00o`000`000?l00?l0003o000F003o00030000o`00
o`000?l000@0o`000P000?l00`3o00000?l0003o0002003o00kooooo10000?l00`3o00000?l0003o
0009003o0080o`0010000?l00`3o0000003o0000o`020?l00080003o0`3o0002003o0080o`000P00
0?l00`3o0000003o0000o`020?l00080oh000P3o00000`3oP000o`000?l0000?003o00<0o`001000
0?l00`00o`00003o0000o`060000o`030?l00000o`000?l000@0003o0`00o`020?l000H0003o00<0
0?l00000o`000?l02`00o`020000o`030?l000000?l0003o0080o`001@000?l20?l000T00?l00P00
0?l>ooooo`D0o`000P3oP0020?l00080oh000P000?lE0?n00080o`000P3oP0000`3o0000oh000?n0
000X0?n000030?l0003oP000oh0002T0oh000P000?l40?l000<0oh00103o000Hooooo`005_ooool4
003o00<0o`000P3oP00;0?l00080003o1@3o00020000o`T0o`0000<0003o0?l0003o00001P3o0000
0`000?l0o`000?l0000G0?l00080oh004P3o00020?n000T0o`000P000?l30?l00080003o503o0002
0?n000D0o`003_oooolN003o00@0003o0P00o`020000o`X00?l01P000?l20?l000T0003o3P00o`02
0000o`<00?l00P000?l>003o00@0003o5@00o`020000o`@0o`000`000?l4003o00kooooo10000?l0
0`3o00000?l0003o0009003o00L0003o0P3o00040000o`D00?l00P000?l30?l00080003o103o0002
0000o`<0o`003@00o`090000o`030?l000000?l0003o0080003o0P00o`020000o`030?l000000?l0
003o0080003o1@00o`020000o`L00?l00P3o00020000o`T00?l00P3o000:0000o`80o`002`00o`0>
ooooog<0oh0000<0o`000?n0003oP0002@3oP0020?l00080003o1`3oP00Hooooo`005_ooool4003o
00<0o`000P3oP00;0?l00080003o1@3o00020000o`T0o`0000<0003o0?l0003o00001P3o00000`00
0?l0o`000?l0000G0?l00080oh004P3o00020?n000T0o`000P000?l30?l00080003o503o00020?n0
00D0o`003_oooolN003o00@0003o0P00o`020000o`X00?l01P000?l20?l000T0003o3P00o`020000
o`<00?l00P000?l>003o00@0003o5@00o`020000o`@0o`000`000?l4003o00kooooo10000?l00`3o
00000?l0003o0009003o00L0003o0P3o00040000o`D00?l00P000?l30?l00080003o103o00020000
o`<0o`003@00o`090000o`030?l000000?l0003o0080003o0P00o`020000o`030?l000000?l0003o
0080003o1@00o`020000o`L00?l00P3o00020000o`T00?l00P3o000:0000o`80o`002`00o`0>oooo
og<0oh0000<0o`000?n0003oP0002@3oP0020?l00080003o1`3oP00Hooooo`005_ooool2003o00T0
o`000P000?l30?n00180o`000P000?l20?l000030000o`3o0000o`0000/0o`000P000?lB0?l000<0
oh002`3o0002003o00D0oh002`3o00020000o`D0o`000P000?lB0?l000<0oh00103o000>ooooo`h0
0?l00P000?l@003o0080003o4000o`060000o`03003o003o0000o`000080003o103o0008003o00@0
003o0P3o000@003o0080o`001@00o`040000oa<00?l00P000?l20?l00080003o0`3o0004003o00ko
oooo10000?l<003o00h0003o1000o`070000o`@0o`000`000?l20?l000l00?l01@000?l20?l00003
0000o`3o0000o`000080o`000P000?l30?l00080003o0P3o00040000o`03003o00000?l0003o00@0
0?l00P3o00000`000?l0o`000?l000020?l000L00?l00P000?l2003o00D0003o0P3o00020000o`<0
o`002`00o`0>ooooodP0oh0000<0o`000?n0003oP000403oP0020?l002d0oh006?ooool001Kooooo
0P00o`090?l00080003o0`3oP00B0?l00080003o0P3o00000`000?l0o`000?l0000;0?l00080003o
4P3o00030?n000/0o`000P00o`050?n000/0o`000P000?l50?l00080003o4P3o00030?n000@0o`00
3_ooool>003o0080003o4000o`020000oa000?l01P000?l00`00o`00o`000?l000020000o`@0o`00
2000o`040000o`80o`004000o`020?l000D00?l010000?lC003o0080003o0P3o00020000o`<0o`00
1000o`0>ooooo`@0003o3000o`0>0000o`@00?l01`000?l40?l000<0003o0P3o000?003o00D0003o
0P3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`0010000?l00`00o`00003o
0000o`04003o0080o`0000<0003o0?l0003o00000P3o0007003o0080003o0P00o`050000o`80o`00
0P000?l30?l000/00?l03_oooom80?n000030?l0003oP000oh000100oh000P3o000]0?n001Sooooo
000Fooooo`800?l00P000?l70?l00080003o1`3o00020000obD0o`001P3oP0080?l00080003o103o
00030000o`80o`0010000?l90?l00080003o00<0o`000000o`000?l00P3o00040000o`030?l00000
0?l0003o0080003o1`3o00020000oa00o`003_ooool20000o`80o`000`000?l20?l001L00?l00P00
0?lD003o0080003o1`00o`030000o`80o`001000o`050000o`@0o`001`00o`030000o`T00?l01000
0?l20?l001<00?l01P000?l7003o00kooooo5000o`020000o`030?l00000o`000?l000@0o`0000<0
003o003o0000o`001000o`020000o`03003o00000?l0003o00@0o`000P000?l30?l001L00?l02000
0?l00`3o0000003o0000o`020?l000@0003o0`3o00020000o`@0o`000`000?l20?l00080003o1`00
o`020000o`030?l000000?l0003o00@0o`000P000?l30?l000@0003o1`00o`0>ooooodP0oh0000<0
o`000?n0003oP0000P3o000;0?n00080o`00<03oP00Hooooo`005_ooool2003o0080003o1`3o0002
0000o`L0o`000P000?lU0?l000H0oh00203o00020000o`@0o`000`000?l20?l000@0003o2@3o0002
0000o`030?l000000?l0003o0080o`0010000?l00`3o0000003o0000o`020000o`L0o`000P000?l@
0?l000kooooo0P000?l20?l000<0003o0P3o000G003o0080003o5000o`020000o`L00?l00`000?l2
0?l000@00?l01@000?l40?l000L00?l00`000?l9003o00@0003o0P3o000C003o00H0003o1`00o`0>
oooooa@00?l00P000?l00`3o00000?l0003o00040?l000030000o`00o`000?l000@00?l00P000?l0
0`00o`00003o0000o`040?l00080003o0`3o000G003o00P0003o00<0o`000000o`000?l00P3o0004
0000o`<0o`000P000?l40?l000<0003o0P3o00020000o`L00?l00P000?l00`3o0000003o0000o`04
0?l00080003o0`3o00040000o`L00?l03_oooom80?n000030?l0003oP000oh000080o`002`3oP002
0?l00300oh006?ooool001Kooooo0P00o`020000o`030?l000000?l0003o00@0o`000P000?lW0?l0
0080003o0`3o00020000o`80o`000P3oP0050?l00080oh00403o0002003o00<0o`0010000?l20?l0
0080003o2@3o00000`000?l0o`000?l0000K0?l000kooooo1@00o`020000o`80o`00:`00o`020000
o`800?l000<0o`00003o0000o`001000o`030000o`80o`001000o`050000o`@0o`002@00o`030000
o`L00?l00P000?lK003o0080o`000P000?l5003o00kooooo1`00o`020000o`L00?l00P000?l9003o
0080003o2P00o`040000o`80o`000P000?l30?l000@0003o0P3o000C003o00l0003o00<00?l00000
o`000?l01000o`050000o`80o`004000o`020?l00080003o0`3o0004003o0080003o1@00o`0>oooo
ocT0oh000P000?l20?l000D0oh00103o000`0?n00080o`004P3oP00Hooooo`005_ooool2003o0080
003o00<0o`000000o`000?l0103o00020000obL0o`000P000?l30?l00080003o0P3o00020?n000D0
o`000P3oP00@0?l000800?l00`3o00040000o`80o`000P000?l90?l000030000o`3o0000o`0001/0
o`003_ooool5003o0080003o0P3o000[003o0080003o0P00o`000`3o00000?l0003o0004003o00<0
003o0P3o0004003o00D0003o103o0009003o00<0003o1`00o`020000oa/00?l00P3o00020000o`D0
0?l03_ooool7003o0080003o1`00o`020000o`T00?l00P000?l:003o00@0003o0P3o00020000o`<0
o`0010000?l20?l001<00?l03`000?l00`00o`00003o0000o`04003o00D0003o0P3o000@003o0080
o`000P000?l30?l000@00?l00P000?l5003o00kooooo>@3oP0020000o`80o`001@3oP0040?l00300
oh000P3o000B0?n001Sooooo000Fooooo`80003o6@3o00020000o`X0o`000P000?l;0?l000@0003o
4`3o00020000o`L0o`000P000?l20?l00080003o2@3o00000`000?l0o`000?l000020?l00080003o
1`3o0002003o01D0o`000P000?l>ooooo`800?l01`000?lK003o0080003o4000o`050000o`@00?l0
0P000?l00`00o`00o`000?l00002003o0080003o0`3o0002003o0080o`001`00o`050000o`P00?l0
00<0003o0?l0003o00000P000?lD003o00030000o`00o`000?l000H0003o00<0o`00003o0000o`00
0P00o`0>ooooo`@0003o5`00o`020000o`h00?l00P3o00020000o`<00?l010000?lL003o0080o`00
10000?l20?l000L00?l00P3o00030000o`80o`002@00o`030000o`@00?l010000?l00`00o`00o`00
0?l00002003o0080003o1`00o`0>ooooo`T0oh000P3o000>0?n000L0o`00603oP0030?l000d0oh00
00<0o`000?n0003oP000?`3oP00Hooooo`005_ooool40000o`030?l000000?l0003o0080003o103o
00000`3oP000o`000?l000020000o`T0o`000P000?l70?l000L0003o0P00o`020000oaX0o`001000
o`070?l00080003o103o00000`000?l0o`000?l000070?l000H0003o1@3o00020000oaT0o`003_oo
oom6003o00<0003o0P3o0002003o0080003o2@00o`020000ob800?l02@000?l00`3o0000003o0000
o`02003o00kooooo0P000?l20?l000<00?l00P000?lR003o00@0003o00<0o`00003o0000o`000P00
0?lR003o0080003o0P3o0007003o0080003o00<00?l00000o`000?l00P3o00020000o`80o`0000<0
003o003o0000o`000P000?l9003o0080003o00<00?l00?l0003o00001000o`030000o`80o`000P00
0?l>ooooo`80oh000P3o000<0?n000@0o`001@3oP0040?l001T0oh002`3o000k0?n000030?l0003o
P000oh0000/0oh006?ooool001Kooooo10000?l00`3o0000003o0000o`020000o`@0o`0000<0oh00
0?l0003o00000P000?l90?l00080003o1`3o00070000o`800?l00P000?lJ0?l000@00?l01`3o0002
0000o`@0o`0000<0003o0?l0003o00001`3o00060000o`D0o`000P000?lI0?l000koooooAP00o`03
0000o`80o`000P00o`020000o`T00?l00P000?lR003o00T0003o00<0o`000000o`000?l00P00o`0>
ooooo`80003o0P3o0003003o0080003o8P00o`040000o`030?l00000o`000?l00080003o8P00o`02
0000o`80o`001`00o`020000o`03003o00000?l0003o0080o`000P000?l20?l000030000o`00o`00
0?l00080003o2@00o`020000o`03003o003o0000o`0000@00?l00`000?l20?l00080003o3_ooool2
0?n00080o`00303oP0040?l000D0oh00103o000I0?n000/0o`00>`3oP0000`3o0000oh000?n0000;
0?n001Sooooo000Fooooo`@0003o00<0o`000000o`000?l0403o00020000o`D0o`000P000?l60?l0
00L0003o0P00o`0E0?l000D0003o0P3o00020000o`d0o`0000<0003o0?l0003o00002@3o00020000
o`D0o`001000o`030000o`H0o`000P000?l:0?l000@0003o3_ooool20000od800?l00P3o00030000
o`80o`005000o`020000oaT00?l00`000?l20?l00080003o0P3o00020000o`03003o003o0000o`00
00800?l03_ooool20000o`80o`000`00o`020000oaD00?l010000?l9003o0080003o0P00o`000`00
0?l00?l0003o000I003o0080o`0010000?l00`00o`00003o0000o`040000o`80o`001`00o`070000
o`800?l00P000?l00`00o`00003o0000o`020000o`<00?l00P000?l2003o0080o`000`000?l6003o
0080003o00<00?l00?l0003o00000P00o`0>oooooc/0oh000P3o001=0?n001Sooooo000Fooooo`@0
003o00<0o`000000o`000?l0403o00020000o`D0o`000P000?l60?l000L0003o0P00o`0E0?l000D0
003o0P3o00020000o`d0o`0000<0003o0?l0003o00002@3o00020000o`D0o`001000o`030000o`H0
o`000P000?l:0?l000@0003o3_ooool20000od800?l00P3o00030000o`80o`005000o`020000oaT0
0?l00`000?l20?l00080003o0P3o00020000o`03003o003o0000o`0000800?l03_ooool20000o`80
o`000`00o`020000oaD00?l010000?l9003o0080003o0P00o`000`000?l00?l0003o000I003o0080
o`0010000?l00`00o`00003o0000o`040000o`80o`001`00o`070000o`800?l00P000?l00`00o`00
003o0000o`020000o`<00?l00P000?l2003o0080o`000`000?l6003o0080003o00<00?l00?l0003o
00000P00o`0>oooooc/0oh000P3o001=0?n001Sooooo000Fooooo`80003o0`3o00020000o`l0o`00
00<0oh000?l0003o00000P3o00020000o`h0o`000P000?l90?l00080003o00<0o`000?n0003oP000
103o00020000o`L0o`0000<0003o0?l0003o00002@3o00020000oa00o`000P00o`050?l000800?l0
0P000?l<0?l00080003o0P3o00020?n000D0o`000P000?l>oooooc@00?l00P3o0002003o00030000
o`3o0000o`0000@0003o0P3o00000`00o`00o`000?l000040000o`030?l000000?l0003o0080003o
0P3o000M003o00030000o`00o`000?l000T00?l00P000?l2003o00030000o`3o0000o`000080003o
0P3o00030000o`80o`000P00o`0>ooooo`@0003o00<0o`000000o`000?l00P000?l7003o00H0003o
4000o`000`000?l00?l0003o00020000o`80o`003000o`020000o`L00?l00P000?l2003o00<0003o
103o0005003o0080o`000P000?l40?l001000?l00P000?l8003o0080o`000P000?l2003o0080o`00
1@00o`040000o`D00?l03_oooom80?n000030?l0003oP000oh0003l0oh006?ooool001Kooooo0P00
0?l30?l00080003o3`3o00000`3oP000o`000?l000020?l00080003o3P3o00020000o`T0o`000P00
0?l00`3o0000oh000?n000040?l00080003o1`3o00000`000?l0o`000?l000090?l00080003o403o
0002003o00D0o`000P00o`020000o``0o`000P000?l20?l00080oh001@3o00020000o`kooooo=000
o`020?l000800?l000<0003o0?l0003o000010000?l20?l00003003o003o0000o`0000@0003o00<0
o`000000o`000?l00P000?l20?l001d00?l000<0003o003o0000o`002@00o`020000o`800?l000<0
003o0?l0003o00000P000?l20?l000<0003o0P3o0002003o00kooooo10000?l00`3o0000003o0000
o`020000o`L00?l01P000?l@003o00030000o`00o`000?l00080003o0P3o000<003o0080003o1`00
o`020000o`800?l00`000?l40?l000D00?l00P3o00020000o`@0o`004000o`020000o`P00?l00P3o
00020000o`800?l00P3o0005003o00@0003o1@00o`0>ooooodP0oh0000<0o`000?n0003oP000?`3o
P00Hooooo`005_ooool20000o`<0o`000P000?l70?l00080003o2`3o00020000o`h0o`000P000?l3
0?l00080003o9P3o00030000o`@0o`000P000?l50?l00080003o0P3o00020000o`<0o`000P00o`0;
0?l00003003o003o0000o`0000@0o`000P3oP0050?l000kooooo5P00o`000`3o0000003o0000o`02
0000oaL00?l01P000?l00`00o`00003o0000o`02003o0080003o2P3o00040000o`80o`001@00o`02
0000o`@00?l000<0o`000000o`000?l00P000?l50?l000@0003o0P3o0003003o00@0003o1@00o`06
0000o`03003o00000?l0003o00800?l00P3o00030000o`@00?l03_ooool50?l00080003o2@00o`06
0000o`030?l00000o`000?l000@00?l000<0o`000000o`000?l00P00o`020?l000D00?l00P000?l2
0?l000800?l000<0o`00003o0000o`005000o`020000o`<00?l010000?l3003o00P0003o00<0o`00
003o0000o`002`00o`020000o`h00?l00P000?l9003o0080o`0000<0003o003o0000o`000P3o000>
ooooob00oh000P3o000W0?n000@0o`009P3oP0000`3o0000oh000?n0000D0?n001Sooooo000Foooo
o`80003o0`3o00020000o`L0o`000P000?l;0?l00080003o3P3o00020000o`<0o`000P000?lV0?l0
00<0003o103o00020000o`D0o`000P000?l20?l00080003o0`3o0002003o00/0o`0000<00?l00?l0
003o0000103o00020?n000D0o`003_oooolF003o00030?l000000?l0003o0080003o5`00o`060000
o`03003o00000?l0003o00800?l00P000?l:0?l000@0003o0P3o0005003o0080003o1000o`000`3o
0000003o0000o`020000o`D0o`0010000?l20?l000<00?l010000?l5003o00H0003o00<00?l00000
o`000?l00P00o`020?l000<0003o1000o`0>ooooo`D0o`000P000?l9003o00H0003o00<0o`00003o
0000o`001000o`000`3o0000003o0000o`02003o0080o`001@00o`020000o`80o`000P00o`000`3o
00000?l0003o000D003o0080003o0`00o`040000o`<00?l020000?l00`3o00000?l0003o000;003o
0080003o3P00o`020000o`T00?l00P3o00000`000?l00?l0003o00020?l000kooooo803oP0020?l0
02L0oh00103o000V0?n000030?l0003oP000oh0001@0oh006?ooool001Kooooo0P000?l@0?l00080
003o1@3o00020000o`D0o`000P000?l90?l00080003o0`3o00020000o`H0o`0000<00?l00000o`00
0?l0103o00020000o`D0o`000P000?l50?l00080oh000`3o00020000o`T0o`000P000?l70?l00080
0?l01`3o00020000o`L0o`000P000?l30?l00080003o2`3o000>oooooa/00?l00P3o0003003o0080
003o1`00o`040000o`80o`002@000?l00`3o0000003o0000o`040000o`80o`0000<0003o0?l0003o
00000P3o00030?n000H0o`002@00o`070000o`80o`001@000?l40?l000<00?l010000?l2003o00<0
003o2`00o`020000o`<00?l010000?l>ooooo`@0003o00<0o`00003o0000o`005`00o`020000ob80
0?l00P000?l2003o00<0003o0P00o`020?l00080003o0P00o`000`3o0000003o0000o`060000o`03
0?l00000o`000?l000@00?l00P000?l00`00o`00003o0000o`020000ob000?l00P000?l>ooooo`h0
oh000P3o000X0?n000030?l0003oP000oh0003P0oh0000<0o`000?n0003oP000503oP00Hooooo`00
5_ooool2003o0080o`0000<0003o0?l0003o00002@3o00020000o`80o`000`000?l40?l000<0003o
103o0002003o00L0o`000P000?l20?l000030?n0003o0000o`000080o`000P000?l30?l00080003o
1`3o00020000o`80o`000P000?l00`00o`00o`000?l000020?l000@0oh003P3o00020000o`<0o`00
0P000?l20?l000L0003o0P00o`070?l000D0003o0P3o00040000o`80o`000`000?l20?l000kooooo
0P00o`020?l000<0003o0P3o000=003o00030000o`00o`000?l000@00?l00`000?l7003o00l0003o
1@00o`020000o`@0o`000`000?l40?l000<0oh00103o000;003o00030?l000000?l0003o0080003o
0P3o00050000o`800?l00P3o0005003o0080003o0P00o`000`000?l00?l0003o000;003o0080003o
1`00o`0>ooooo`80003o0`3o0008003o00030000o`00o`000?l000d00?l000<0003o003o0000o`00
1P00o`000`3o0000003o0000o`020000o`80o`000`000?l20?l000800?l00P3o00030000o`80o`00
5P00o`000`3o0000003o0000o`020000o`80o`001@000?l4003o00L0003o1000o`000`000?l0o`00
0?l000040000o`T00?l00`000?l40?l000L0003o3_oooolb0?n000@0o`007P3oP0020?l002@0oh00
0P3o00000`3oP000o`000?l0000;0?n001Sooooo000Fooooo`800?l00P3o00000`000?l0o`000?l0
00090?l00080003o0P3o00030000o`@0o`000`000?l40?l000800?l01`3o00020000o`80o`0000<0
oh000?l0003o00000P3o00020000o`<0o`000P000?l70?l00080003o0P3o00020000o`03003o003o
0000o`000080o`00103oP00>0?l00080003o0`3o00020000o`80o`001`000?l2003o00L0o`001@00
0?l20?l000@0003o0P3o00030000o`80o`003_ooool2003o0080o`000`000?l20?l000d00?l000<0
003o003o0000o`001000o`030000o`L00?l03`000?l5003o0080003o103o00030000o`@0o`000`3o
P0040?l000/00?l000<0o`000000o`000?l00P000?l20?l000D0003o0P00o`020?l000D00?l00P00
0?l2003o00030000o`00o`000?l000/00?l00P000?l7003o00kooooo0P000?l30?l000P00?l000<0
003o003o0000o`003@00o`000`000?l00?l0003o0006003o00030?l000000?l0003o0080003o0P3o
00030000o`80o`000P00o`020?l000<0003o0P3o000F003o00030?l000000?l0003o0080003o0P3o
00050000o`@00?l01`000?l4003o00030000o`3o0000o`0000@0003o2@00o`030000o`@0o`001`00
0?l>oooooc80oh00103o000N0?n00080o`00903oP0020?l000030?n0003o0000o`0000/0oh006?oo
ool001Kooooo0P00o`020000oa80o`0000<0003o0?l0003o00004P3o0002003o00L0o`000P000?lL
0?l00080003o403o0002003o00H0003o0`3o0002003o0080003o2@3o00000`000?l0o`000?l00006
0?l000030000o`3o0000o`000080o`003_ooool40000o`030?l000000?l0003o0080o`004P00o`02
0?l000<0003o4000o`020000o`80o`000P000?l3003o00@0003o0P00o`020000o`030?l000000?l0
003o0080o`000`3oP0020000o`@0o`003000o`020000o`@00?l00P3o00030000o`80o`005@00o`04
0000o`80o`000P000?l5003o00kooooo3@00o`050000oa@00?l000<0003o003o0000o`000P00o`02
0?l000<0003o0P3o0002003o00D0003o0P3o0004003o00<0003o0P3o0009003o00D0003o0P3o0002
0000o`80o`001@00o`020000o`D00?l00P000?l2003o00@0003o00<00?l00000o`000?l00P3o0002
0000o`<0o`000P00o`020000o`<0o`000P000?l40?l000D0003o0P3o000>ooooogX0oh000P3o000>
0?n001Sooooo000Fooooo`800?l00P000?lB0?l000030000o`3o0000o`000180o`000P00o`070?l0
0080003o703o00020000oa00o`000P00o`060000o`<0o`000P00o`020000o`T0o`0000<0003o0?l0
003o00001P3o00000`000?l0o`000?l000020?l000kooooo10000?l00`3o0000003o0000o`020?l0
01800?l00P3o00030000oa000?l00P000?l20?l00080003o0`00o`040000o`800?l00P000?l00`3o
0000003o0000o`020?l000<0oh000P000?l40?l000`00?l00P000?l4003o0080o`000`000?l20?l0
01D00?l010000?l20?l00080003o1@00o`0>ooooo`d00?l01@000?lD003o00030000o`00o`000?l0
00800?l00P3o00030000o`80o`000P00o`050000o`80o`001000o`030000o`80o`002@00o`050000
o`80o`000P000?l20?l000D00?l00P000?l5003o0080003o0P00o`040000o`03003o00000?l0003o
0080o`000P000?l30?l000800?l00P000?l30?l00080003o103o00050000o`80o`003_oooomj0?n0
0080o`003P3oP00Hooooo`005_ooool20000o`80o`0000<0003o0?l0003o00001`3o00020000o`80
o`001@000?l20?l00080003o0`3o00020000o`80o`000P000?l70?l00080003o0P3o00000`000?l0
o`000?l000020?l00080003o0`3o00020000o`80o`000P000?l90?l000030000o`3o0000o`000080
003o1@3o0002003o0100o`0010000?l20?l00080003o00<00?l00000o`000?l00P00o`070?l00080
003o0P3o00000`00o`00o`000?l000060?l000030000o`3o0000o`000080o`003_ooool70000oa@0
0?l00P000?lL003o0080o`0010000?l20?l00003003o00000?l0003o0080o`000P000?l00`3o0000
oh000?n000060?l000D00?l010000?l00`3o00000?l0003o0002003o0080o`000`000?l20?l000@0
0?l00`000?l4003o00<0003o2`00o`040000o`80o`001@00o`0>ooooo`@0003o00<0o`00003o0000
o`001P00o`000`000?l00?l0003o000=003o00D0003o1000o`030000o`800?l010000?l00`00o`00
o`000?l00002003o00@0003o00<00?l00?l0003o00001000o`020?l000<0003o0P00o`020000o`L0
0?l01@000?l40?l000L00?l00P000?l9003o00X0003o1P3o00030000o`@0o`000P00o`030000o`80
o`000P000?l>ooooocl0oh000P3o000`0?n00080o`005`3oP00Hooooo`005_ooool20000o`80o`00
00<0003o0?l0003o00001`3o00020000o`80o`001@000?l20?l00080003o0`3o00020000o`80o`00
0P000?l70?l00080003o0P3o00000`000?l0o`000?l000020?l00080003o0`3o00020000o`80o`00
0P000?l90?l000030000o`3o0000o`000080003o1@3o0002003o0100o`0010000?l20?l00080003o
00<00?l00000o`000?l00P00o`070?l00080003o0P3o00000`00o`00o`000?l000060?l000030000
o`3o0000o`000080o`003_ooool70000oa@00?l00P000?lL003o0080o`0010000?l20?l00003003o
00000?l0003o0080o`000P000?l00`3o0000oh000?n000060?l000D00?l010000?l00`3o00000?l0
003o0002003o0080o`000`000?l20?l000@00?l00`000?l4003o00<0003o2`00o`040000o`80o`00
1@00o`0>ooooo`@0003o00<0o`00003o0000o`001P00o`000`000?l00?l0003o000=003o00D0003o
1000o`030000o`800?l010000?l00`00o`00o`000?l00002003o00@0003o00<00?l00?l0003o0000
1000o`020?l000<0003o0P00o`020000o`L00?l01@000?l40?l000L00?l00P000?l9003o00X0003o
1P3o00030000o`@0o`000P00o`030000o`80o`000P000?l>ooooocl0oh000P3o000`0?n00080o`00
5`3oP00Hooooo`005_ooool50000o`/0o`000P000?l20?l00080003o0`3o0002003o00/0o`0000<0
003o0?l0003o00000P3o00020000o`80o`0000<0003o0?l0003o00001`3o00020000o`80o`000P00
0?l70?l00080003o1`3o00020000o`030?l000000?l0003o00@0o`000P000?l50?l00080003o0P3o
00030000o`80o`000P000?l20?l000<00?l00P3o00030000oaH0o`003_ooool20000o`<0o`006000
o`000`000?l00?l0003o000I003o0080o`0010000?l30?l00080003o1@3o00020000o`80o`001000
0?l00`3o0000003o0000o`04003o0080003o00<0o`000000o`000?l01`000?l20?l000@00?l00P00
0?l00`00o`00003o0000o`0@003o00@0003o0P00o`000`000?l00?l0003o0002003o00kooooo1000
o`000`3o0000003o0000o`020000o`@00?l000<0003o003o0000o`002`00o`020?l000<0003o0P3o
0009003o0080o`000P000?l00`00o`00o`000?l00002003o00D0003o1P00o`030000o`/00?l00P00
0?l20?l000<0003o0P3o0002003o00<0003o0P3o00040000o`T00?l00P3o00000`000?l00?l0003o
00020000o`<00?l00P000?l20?l000@0003o1@3o00040000o`D00?l03_oooolI0?n00080o`008P3o
P0040?l001<0oh000P3o000d0?n001Sooooo000Fooooo`80003o503o00000`000?l0o`000?l00002
003o00<0o`000P000?l?0?l000030000o`3o0000o`0000@0003o0`3o00020000o`@0o`000P000?l>
0?l000<0003o0P3o00020000o`@0o`0000<00?l00?l0003o0000103o0002003o00D0003o103o0000
0`000?l0o`000?l000040?l000030000o`3o0000o`0000L0o`000P00o`060?l000<00?l00P3o000>
ooooo`80003o=`00o`020000o`800?l00P000?l2003o00030?l000000?l0003o00d0o`000`000?l2
003o0180003o0P00o`030000oad00?l03_ooool20000oaT00?l01@000?l20?l000@00?l000<0003o
003o0000o`000P00o`020?l00080003o00<00?l00?l0003o00002@00o`020000o`800?l00P000?l8
003o0080003o103o00050000o`@0o`000P00o`070000o`80o`000`00o`040000o`80o`002000o`02
0?l00080003o0P3o00020000o`<0o`000P000?l9003o00kooooo5P3oP0030?l000L0oh00103o0003
0?n00080o`00:`3oP0020?l003@0oh006?ooool001Kooooo0P000?lD0?l000030000o`3o0000o`00
00800?l00`3o00020000o`l0o`0000<0003o0?l0003o000010000?l30?l00080003o103o00020000
o`h0o`000`000?l20?l00080003o103o00000`00o`00o`000?l000040?l000800?l01@000?l40?l0
00030000o`3o0000o`0000@0o`0000<0003o0?l0003o00001`3o0002003o00H0o`000`00o`020?l0
00kooooo0P000?lg003o0080003o0P00o`020000o`800?l000<0o`000000o`000?l03@3o00030000
o`800?l04P000?l2003o00<0003o7@00o`0>ooooo`80003o6@00o`050000o`80o`001000o`000`00
0?l00?l0003o0002003o0080o`000P000?l00`00o`00o`000?l00009003o0080003o0P00o`020000
o`P00?l00P000?l40?l000D0003o103o0002003o00L0003o0P3o0003003o00@0003o0P3o0008003o
0080o`000P000?l20?l00080003o0`3o00020000o`T00?l03_oooolF0?n000<0o`001`3oP0040?l0
00<0oh000P3o000[0?n00080o`00=03oP00Hooooo`005_ooool2003o0080003o8P3o00000`000?l0
o`000?l000070?l000@0003o1@3o00040000o`80o`000P000?l30?l00080003o0P3o00000`000?l0
o`000?l0000?0?l000D0003o0P3o00020000o`<0o`001`000?l20?l00080003o1@3o00020000o`D0
o`000P000?l70?l000800?l00P3o000>ooooocT00?l00P3o00020000o`@0o`000`000?l50?l00080
003o103o00030000o`80o`000P000?l4003o00D0003o0P3o00020000o`L0o`000`00o`020?l000@0
003o00<0o`000000o`000?l00P000?lB003o00kooooo1`00o`020000o`d00?l000<0o`000000o`00
0?l00P000?l20?l000030000o`00o`000?l000/00?l00P3o00020000o`L00?l00`000?l2003o0080
003o0P3o0007003o0080o`002@000?l00`3o0000003o0000o`020000o`80o`002@000?l20?l000L0
003o1@3o00040000o`030?l000000?l0003o00@0o`000P000?l30?l000@0003o1`00o`0>ooooo`D0
oh000P000?l20?l00840oh006?ooool001Kooooo0P00o`020000ob80o`0000<0003o0?l0003o0000
1`3o00040000o`D0o`0010000?l20?l00080003o0`3o00020000o`80o`0000<0003o0?l0003o0000
3`3o00050000o`80o`000P000?l30?l000L0003o0P3o00020000o`D0o`000P000?l50?l00080003o
1`3o0002003o0080o`003_ooooli003o0080o`000P000?l40?l000<0003o1@3o00020000o`@0o`00
0`000?l20?l00080003o1000o`050000o`80o`000P000?l70?l000<00?l00P3o00040000o`030?l0
00000?l0003o0080003o4P00o`0>ooooo`L00?l00P000?l=003o00030?l000000?l0003o0080003o
0P3o00000`000?l00?l0003o000;003o0080o`000P000?l7003o00<0003o0P00o`020000o`80o`00
1`00o`020?l000T0003o00<0o`000000o`000?l00P000?l20?l000T0003o0P3o00070000o`D0o`00
10000?l00`3o0000003o0000o`040?l00080003o0`3o00040000o`L00?l03_ooool50?n00080003o
0P3o00210?n001Sooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo000Rooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
4oooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`001Ooo
oolFo`3o00Cooooo5ol00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1Ooo
oolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oo
oolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool0
0ol0003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolF
oomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolG
o`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00>_oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l01?oooolFo`00
o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolGool000Cooooo5ol0o`04oooooaKo003o1OoooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool003[ooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l0
0?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02
oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o00Cooooo5_l00?l5oooo
oaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo
003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOo
o`001?oooolGo`3o00Cooooo5_l00?l5oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0003o
ooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo
000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1C
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l0
0?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000
ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l007l00ol0003oooooooooo`0U
ooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oooooooooo02Gooooo00?o0000
o`00Ool007l0Dol007lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Moooo
oaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`0ho`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000o`00Ool007l00ol007lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003o
ooooooooo`0Uooooo`03o`000?l007oo001o06ko001o00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0
0ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooo
oolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oooombo`0002OoooooLOl0000Wooooog7o
00009ooooombo`0002?ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo000Fooooobl0
o`000`3oP00h0?l00080oh0000<0o`000?n0003oP0000P3oP00<0?l00080oh002`3o000>ooooo`80
0?l00P3oP003003o0080003o0P3oP00<003o0080003o0P3oP0020000o`03003o003oP000oh0000H0
oh000`00o`040000o`T00?l00P000?l00`3oP000003o0000o`060?n000<0003o0P3oP002003o00D0
o`000P3oP0020000o`D00?l0103oP0000`00o`00oh000?n00004003o00L0oh001000o`050000o`<0
oh000P00o`040?n000800?l000<0oh00003o0000o`000P000?l20?n00080003o0`3oP002003o00ko
oooo3P000?l20?n000L0003o0P00o`0;0000o`D00?l01P000?l9003o00<0003o0P3oP0070000o`80
oh001`000?l2003o00D0003o0P3oP00=0000o`03003o00000?l0003o00800?l08P000?l>ooooo`D0
oh001000o`020?l000<0oh0010000?l40?n000P00?l00P3oP0040000o`<00?l01P3oP002003o00L0
oh000P00o`000`3o0000oh000?n000020?n000800?l00`3oP0020?l000800?l00P3oP007003o00<0
oh0010000?l;0?n000<0003o0P3oP006003o00<0oh000P3o00030?n000800?l00P3oP0020?l00080
oh000`3o00070?n000800?l00P000?lHooooo`005_ooool_0?l000<0oh00>03o00020?n000030?l0
003oP000oh000080oh00303o00020?n000/0o`003_ooool2003o0080oh000`00o`020000o`80oh00
3000o`020000o`80oh000P000?l00`00o`00oh000?n000060?n000<00?l010000?l9003o0080003o
00<0oh000000o`000?l01P3oP0030000o`80oh000P00o`050?l00080oh000P000?l5003o00@0oh00
00<00?l00?n0003oP0001000o`070?n000@00?l01@000?l30?n000800?l0103oP002003o00030?n0
0000o`000?l00080003o0P3oP0020000o`<0oh000P00o`0>ooooo`h0003o0P3oP0070000o`800?l0
2`000?l5003o00H0003o2@00o`030000o`80oh001`000?l20?n000L0003o0P00o`050000o`80oh00
3@000?l00`00o`00003o0000o`02003o0280003o3_ooool50?n000@00?l00P3o00030?n000@0003o
103oP008003o0080oh0010000?l3003o00H0oh000P00o`070?n000800?l000<0o`000?n0003oP000
0P3oP002003o00<0oh000P3o0002003o0080oh001`00o`030?n000@0003o2`3oP0030000o`80oh00
1P00o`030?n00080o`000`3oP002003o0080oh000P3o00020?n000<0o`001`3oP002003o0080003o
6?ooool001Kooooo=03o00020?n000<0o`000P3oP0020?l00080oh001`3o00020?n00480o`003_oo
ool2003o00<0003o1P00o`020000oa000?l000<0oh000000o`000?l00P00o`040?n000D0003o4P00
o`070?n000800?l00P000?l30?n00080o`000P3oP0070000o`L00?l0103oP0020?l000030?n0003o
0000o`0000800?l00P3oP009003o00030?n0003o0000o`000080003o1@3oP004003o0080oh000P00
0?l00`00o`00003o0000o`020?n000kooooo0P3oP0050000o`/00?l02@000?l2003o00<0003o0P3o
P00;0000o`800?l01@000?l2003o0080003o0`00o`0I0000o`800?l02@000?l20?n000<0003o0P3o
P009003o00h0003o0P3oP00;0000o`kooooo0P3o0005003o00T0oh000P00o`020?n000800?l000<0
oh000?l0003o00000P3o00030?n000800?l010000?l@0?n00080003o303oP0040?l000<00?l00P00
0?l20?n000T00?l00P3oP0020?l000030?n0003o0000o`0000L0oh00103o00020?n00080o`0000<0
oh000?l0003o00000P3o00020?n000<0o`000P3oP0020?l000<0oh002@3o00040?n001Sooooo000F
oooooc@0o`000P3oP0030?l00080oh000P3o00020?n000L0o`000P3oP0120?l000kooooo0P00o`03
0000o`H00?l00P000?l@003o00030?n000000?l0003o00800?l0103oP0050000oa800?l01`3oP002
003o0080003o0`3oP0020?l00080oh001`000?l7003o00@0oh000P3o00000`3oP000o`000?l00002
003o0080oh002@00o`000`3oP000o`000?l000020000o`D0oh001000o`020?n00080003o00<00?l0
0000o`000?l00P3oP00>ooooo`80oh001@000?l;003o00T0003o0P00o`030000o`80oh002`000?l2
003o00D0003o0P00o`020000o`<00?l06@000?l2003o00T0003o0P3oP0030000o`80oh002@00o`0>
0000o`80oh002`000?l>ooooo`80o`001@00o`090?n000800?l00P3oP002003o00030?n0003o0000
o`000080o`000`3oP002003o00@0003o403oP0020000o``0oh00103o0003003o0080003o0P3oP009
003o0080oh000P3o00000`3oP000o`000?l000070?n000@0o`000P3oP0020?l000030?n0003o0000
o`000080o`000P3oP0030?l00080oh000P3o00030?n000T0o`00103oP00Hooooo`005_oooom]0?l0
0080oh00403o00020?n000L0o`000P3oP00>ooooo`80oh000P000?lI003o00030?n000000?l0003o
00L0003o5P00o`020?n00080003o00<0o`000?n0003oP0000P3o00030?n00080003o103oP00<003o
00d0oh002@00o`070?n000@00?l00`3oP0040000o`D0oh000P00o`0>oooooa@0003o1@00o`0O0000
o`03003o00000?l0003o00h0003o103oP0050000o`80oh0010000?l2003o00`0003o103oP002003o
00<0oh001`000?l4003o00`0003o1000o`0>ooooo`L00?l01`3oP0040?l000T0oh000P3o00000`00
0?l0oh000?n00002003o0080003o0P00o`030?n00080003o0P3oP002003o00<0oh000P3o000>0?n0
0080003o0P00o`030?n000800?l010000?l30?n000@0003o0P00o`030?n000@0o`002`3oP0070?l0
0080oh0000<0o`000?n0003oP0001`3oP0020?l000@0oh000`3o00020?n00080003o6?ooool001Ko
ooooA03o00020?n003d0o`000P3oP0030?l00080oh003_ooool40000o`<00?l010000?lG003o0080
oh003P00o`020000o`800?l01`000?l50?n00080o`000P3oP0020000o`030?n000000?l0003o0080
003o2@00o`040?l000<0oh000P3o00050?n00080o`000P3oP002003o0080003o00<00?l00000o`00
0?l00P00o`030?n000@00?l00P000?l5003o00@0oh000P00o`000`3oP0000?l0003o00020?n000ko
oooo1`000?l2003o0080003o0P00o`000`000?l00?l0003o00060000o`030?n000000?l0003o00D0
003o0P3oP00F0000o`800?l03P000?l20?n000030000o`3oP000oh0000800?l00P000?l20?n00003
0000o`3oP000oh000080oh000P000?l20?n00180003o00<00?l00000o`000?l01`000?l4003o0080
003o00<00?l00000o`000?l01`000?l4003o00kooooo103oP003003o00H0oh0000<0o`000?n0003o
P0000P3oP0020?l000800?l00`3o00040?n00003003o003oP000oh0000@00?l00P3oP0000`000?l0
oh000?n000020000o`@0oh0000<0003o0?n0003oP0000P3oP0020000oa00oh000P00o`000`000?l0
oh000?n000040000o`/0oh0000<0o`000?n0003oP0000P3oP0020000o`80oh0000<00?l00?n0003o
P0000P3oP0050?l00080oh000P3o00020?n000<0o`000P3oP0050?l00080oh000P3o00040?n00003
0?l00000o`000?l00080oh006?ooool001KoooooA03o00020?n003d0o`000P3oP0030?l00080oh00
3_ooool40000o`<00?l010000?lG003o0080oh003P00o`020000o`800?l01`000?l50?n00080o`00
0P3oP0020000o`030?n000000?l0003o0080003o2@00o`040?l000<0oh000P3o00050?n00080o`00
0P3oP002003o0080003o00<00?l00000o`000?l00P00o`030?n000@00?l00P000?l5003o00@0oh00
0P00o`000`3oP0000?l0003o00020?n000kooooo1`000?l2003o0080003o0P00o`000`000?l00?l0
003o00060000o`030?n000000?l0003o00D0003o0P3oP00F0000o`800?l03P000?l20?n000030000
o`3oP000oh0000800?l00P000?l20?n000030000o`3oP000oh000080oh000P000?l20?n00180003o
00<00?l00000o`000?l01`000?l4003o0080003o00<00?l00000o`000?l01`000?l4003o00kooooo
103oP003003o00H0oh0000<0o`000?n0003oP0000P3oP0020?l000800?l00`3o00040?n00003003o
003oP000oh0000@00?l00P3oP0000`000?l0oh000?n000020000o`@0oh0000<0003o0?n0003oP000
0P3oP0020000oa00oh000P00o`000`000?l0oh000?n000040000o`/0oh0000<0o`000?n0003oP000
0P3oP0020000o`80oh0000<00?l00?n0003oP0000P3oP0050?l00080oh000P3o00020?n000<0o`00
0P3oP0050?l00080oh000P3o00040?n000030?l00000o`000?l00080oh006?ooool001Kooooo3P3o
00020?n001/0o`000P3oP0100?l00080oh001@3o00020?n001@0o`003_ooool40000o`L00?l00P00
0?l3003o0080003o2`00o`090000o`h00?l02`000?l2003o00L0003o00<0oh000000o`000?l01000
o`030000o`H00?l00P3oP0070000o`80oh005@000?l20?n000800?l01@000?l20?n000<00?l00P3o
P002003o00kooooo1@000?l9003o00P0003o00<00?l00000o`000?l03@000?l00`3oP0000?l0003o
00070000o`@00?l01`000?l20?n000L0003o0P3oP0030000o`P0oh001@000?l70?n000/0003o0P3o
P00<0000o`L00?l02@000?l2003o0080003o3_ooool20?n000800?l00`000?l2003o0080oh000P3o
000:0?n00080o`00103oP0000`00o`00003o0000o`04003o00`0oh000P3o000D0?n000<0003o0P00
o`040000o`<0oh000P000?l20?n000800?l04P3oP0020?l000D0oh000P000?l30?n00080o`001`3o
P0020?l000L0oh000P00o`0Hooooo`005_ooool>0?l00080oh006`3o00020?n00400o`000P3oP005
0?l00080oh00503o000>ooooo`@0003o1`00o`020000o`<00?l00P000?l;003o00T0003o3P00o`0;
0000o`800?l01`000?l00`3oP000003o0000o`04003o00<0003o1P00o`020?n000L0003o0P3oP00E
0000o`80oh000P00o`050000o`80oh000`00o`020?n000800?l03_ooool50000o`T00?l020000?l0
0`00o`00003o0000o`0=0000o`030?n00000o`000?l000L0003o1000o`070000o`80oh001`000?l2
0?n000<0003o203oP0050000o`L0oh002`000?l20?n000`0003o1`00o`090000o`800?l00P000?l>
ooooo`80oh000P00o`030000o`800?l00P3oP0020?l000X0oh000P3o00040?n00003003o00000?l0
003o00@00?l0303oP0020?l001@0oh000`000?l2003o00@0003o0`3oP0020000o`80oh000P00o`0B
0?n00080o`001@3oP0020000o`<0oh000P3o00070?n00080o`001`3oP002003o01Sooooo000Foooo
oad0o`0000<0oh000?l0003o0000503o00020?n00300o`000P3oP00I0?l00080oh001`3o000>oooo
o`80003o1`00o`020000oaD00?l01P3oP003003o0080003o4000o`040000o`80oh0000<0003o0?n0
003oP00010000?l00`00o`00003o0000o`020000o`80oh001@00o`040?n000L0003o0P00o`090000
o`D00?l00P000?l5003o0080003o1@00o`060?n00080003o00<0oh00003o0000o`000P000?l>oooo
o`L0003o1000o`020000o`03003o00000?l0003o00@0003o0P3oP0070000o`03003o00000?l0003o
02P0003o0`00o`020?n000T0003o1@3oP0020000o`80oh001@000?l20?n00100003o2@00o`070000
o`80oh000P000?l>ooooo`@0oh0000<0o`000?n0003oP0000P3o00020?n000<0o`00103oP005003o
0080o`00103oP0000`00o`00oh000?n000020000o`800?l00`000?l;0?n00080o`00103oP0000`3o
0000oh000?n000040?l000<0oh000P3o00040?n000D00?l00P3oP0030?l000@0oh000P00o`020?n0
00030000o`3oP000oh000080oh000P00o`020?n000<00?l00P3oP0020?l000<0oh000P3o0002003o
00L0oh000P3o00020?n000D0o`001`3oP0020000oaSooooo000Foooooad0o`0000<0oh000?l0003o
0000503o00020?n00300o`000P3oP00I0?l00080oh001`3o000>ooooo`80003o1`00o`020000oaD0
0?l01P3oP003003o0080003o4000o`040000o`80oh0000<0003o0?n0003oP00010000?l00`00o`00
003o0000o`020000o`80oh001@00o`040?n000L0003o0P00o`090000o`D00?l00P000?l5003o0080
003o1@00o`060?n00080003o00<0oh00003o0000o`000P000?l>ooooo`L0003o1000o`020000o`03
003o00000?l0003o00@0003o0P3oP0070000o`03003o00000?l0003o02P0003o0`00o`020?n000T0
003o1@3oP0020000o`80oh001@000?l20?n00100003o2@00o`070000o`80oh000P000?l>ooooo`@0
oh0000<0o`000?n0003oP0000P3o00020?n000<0o`00103oP005003o0080o`00103oP0000`00o`00
oh000?n000020000o`800?l00`000?l;0?n00080o`00103oP0000`3o0000oh000?n000040?l000<0
oh000P3o00040?n000D00?l00P3oP0030?l000@0oh000P00o`020?n000030000o`3oP000oh000080
oh000P00o`020?n000<00?l00P3oP0020?l000<0oh000P3o0002003o00L0oh000P3o00020?n000D0
o`001`3oP0020000oaSooooo000Fooooo`h0o`000P3oP00T0?l00080oh00@03o00020?n000/0o`00
0P3oP0050?l000kooooo10000?l00`3oP000003o0000o`020000o`d00?l000<0003o003o0000o`00
1000o`000`3oP0000?l0003o00060?n000<0003o1P00o`030000o`L00?l03@000?l2003o00<0003o
1000o`020000o`<00?l01`000?l=003o0080003o1`00o`020000o`03003o00000?l0003o0080003o
3@00o`000`000?l00?l0003o00020000o`kooooo1`000?l;003o00h0003o0P3oP00;0000o`80oh00
30000?l20?n000D0003o0P00o`070000o`H0oh003P000?l20?n00080003o0`3oP002003o0080003o
1@00o`090000o`80oh001@000?l2003o0080oh000P00o`050000o`kooooo0P3o00020?n000030?l0
003oP000oh000100oh000P3o00020?n000D00?l010000?l2003o00L0oh000P00o`000`3oP0000?l0
003o000;0?n000@0o`000`3oP0020?l000<0oh000P00o`040?n000<0o`001P3oP002003o00<0oh00
0P00o`040?n00003003o003oP000oh000080oh000P3o000>0?n00080o`001`3oP002003o0080oh00
00<00?l00?n0003oP0000P3oP00Hooooo`005_ooool20?l00080oh00O@3o00040?n000D0o`003_oo
ool5003o00@0003o5000o`000`000?l0oh000?n000060?n000T00?l000<0003o003o0000o`002@00
o`060000o`03003o00000?l0003o00D00?l02@000?lF003o00L0003o0P00o`030?n000H00?l00P00
0?l3003o00@0oh001`00o`0>ooooo`d0003o00<00?l00000o`000?l02@00o`0B0000oa000?l00P00
0?l2003o0080oh001`000?l00`3oP000003o0000o`04003o0080oh0000<0003o0?n0003oP0000P00
0?l20?n000<0003o103oP00;0000o`h00?l01`000?l2003o00D0003o0P3oP0020000o`kooooo0P00
o`050?l00080oh002`000?l2003o00<0oh000P00o`050?n00080003o0P00o`0<0?n00080003o2`3o
P0020?l000<0oh000P3o00070?n00080003o0P3oP0090?l000<0003o0P3oP002003o00L0oh000P3o
00050?n00080o`001@3oP004003o00@0003o00<00?l00000o`000?l00P00o`040?n000030000o`00
o`000?l00080oh006?ooool001Kooooo0P3o00020?n007d0o`00103oP0050?l000kooooo1@00o`04
0000oa@00?l000<0003o0?n0003oP0001P3oP009003o00030000o`00o`000?l000T00?l01P000?l0
0`00o`00003o0000o`05003o00T0003o5P00o`070000o`800?l00`3oP006003o0080003o0`00o`04
0?n000L00?l03_ooool=0000o`03003o00000?l0003o00T00?l04P000?l@003o0080003o0P00o`02
0?n000L0003o00<0oh000000o`000?l01000o`020?n000030000o`3oP000oh000080003o0P3oP003
0000o`@0oh002`000?l>003o00L0003o0P00o`050000o`80oh000P000?l>ooooo`800?l01@3o0002
0?n000/0003o0P00o`030?n000800?l01@3oP0020000o`800?l0303oP0020000o`/0oh000P3o0003
0?n00080o`001`3oP0020000o`80oh002@3o00030000o`80oh000P00o`070?n00080o`001@3oP002
0?l000D0oh001000o`040000o`03003o00000?l0003o00800?l0103oP0000`000?l00?l0003o0002
0?n001Sooooo000Foooooc@0o`000P3oP00@0?l00080oh002P3o00020?n002d0o`000P00o`020?n0
00D0o`003_ooool9003o0080003o2@00o`070000o`800?l02@3oP0000`00o`00003o0000o`02003o
0080003o0P00o`000`000?l00?l0003o0004003o0080oh001@000?l20?n000L0003o0P3oP005003o
0080oh002@000?l2003o00030000o`00o`000?l001d00?l00P000?l30?n000800?l01@3oP004003o
00kooooo1`00o`020000o`800?l02@000?l20?n000h0003o0P3oP0050000o`800?l00P3oP003003o
00/0003o0P3oP00<0000o`@0oh006`000?l3003o00@0003o0P3oP0030000o`@00?l00P000?l00`00
o`00003o0000o`060000o`03003o00000?l0003o00800?l03_ooool20?n00080o`0000<0oh000?l0
003o00000P3oP005003o00@0003o103oP0030?l000T0oh000P3o00050?n00080o`000P3oP002003o
00030?n00000o`000?l000800?l010000?l00`3oP0000?l0003o00040?n00080o`0000<0oh000?l0
003o00000P3o00070?n00080003o0`3oP0020?l000H0oh0000<00?l00000o`000?l00P3oP0020000
o`T0oh000P000?l30?l000D0oh002@000?l2003o00H0oh0000<0o`000?n0003oP0000P3o000Hoooo
o`005_oooold0?l00080oh00403o00020?n000X0o`000P3oP00]0?l000800?l00P3oP0050?l000ko
oooo2@00o`020000o`T00?l01`000?l2003o00T0oh0000<00?l00000o`000?l00P00o`020000o`80
0?l000<0003o003o0000o`001000o`020?n000D0003o0P3oP0070000o`80oh001@00o`020?n000T0
003o0P00o`000`000?l00?l0003o000M003o0080003o0`3oP002003o00D0oh001000o`0>ooooo`L0
0?l00P000?l2003o00T0003o0P3oP00>0000o`80oh001@000?l2003o0080oh000`00o`0;0000o`80
oh0030000?l40?n001/0003o0`00o`040000o`80oh000`000?l4003o0080003o00<00?l00000o`00
0?l01P000?l00`00o`00003o0000o`02003o00kooooo0P3oP0020?l000030?n0003o0000o`000080
oh001@00o`040000o`@0oh000`3o00090?n00080o`001@3oP0020?l00080oh000P00o`000`3oP000
0?l0003o0002003o00@0003o00<0oh00003o0000o`00103oP0020?l000030?n0003o0000o`000080
o`001`3oP0020000o`<0oh000P3o00060?n00003003o00000?l0003o0080oh000P000?l90?n00080
003o0`3o00050?n000T0003o0P00o`060?n000030?l0003oP000oh000080o`006?ooool001Kooooo
3P3o00020?n003H0o`000P3oP0090?l000030?n0003o0000o`0003H0o`003_ooool20000o`800?l0
2P000?l8003o00D0003o0P00o`030?n00080003o103oP0050000oad00?l000<0oh00003o0000o`00
0P3o00020?n00080o`000`00o`090000o`@00?l00P000?l00`00o`00003o0000o`040000o`800?l0
00<0003o003o0000o`000P00o`020000o`030?n000000?l0003o00H0003o1`3oP0020000o`<0oh00
0P00o`0>ooooo`80oh000`00o`060000o`<00?l020000?l3003o0200003o0P00o`070000o`80oh00
1@000?l20?n000/0003o0P00o`0B0000o`800?l01@000?l2003o00030000o`00o`000?l000800?l0
0P000?l3003o00@0003o1@00o`040000o`kooooo103oP0000`3o0000oh000?n000040?n000<0003o
1P00o`020000o`<0oh000P000?l20?n00003003o003oP000oh0000/0oh000P3o00020000o`03003o
003oP000oh000080oh000P3o0003003o0080oh000P00o`040?n000030000o`3oP000oh0000@0o`00
1@000?l2003o0080oh0000<0o`000?n0003oP000103oP002003o00030000o`3oP000oh000080oh00
0P3o00070?n00080003o0P00o`000`3oP000003o0000o`0;0000o`D00?l0103oP002003o00030?n0
003o0000o`000080oh006?ooool001Kooooo3P3o00020?n003H0o`000P3oP0090?l000030?n0003o
0000o`0003H0o`003_ooool20000o`800?l02P000?l8003o00D0003o0P00o`030?n00080003o103o
P0050000oad00?l000<0oh00003o0000o`000P3o00020?n00080o`000`00o`090000o`@00?l00P00
0?l00`00o`00003o0000o`040000o`800?l000<0003o003o0000o`000P00o`020000o`030?n00000
0?l0003o00H0003o1`3oP0020000o`<0oh000P00o`0>ooooo`80oh000`00o`060000o`<00?l02000
0?l3003o0200003o0P00o`070000o`80oh001@000?l20?n000/0003o0P00o`0B0000o`800?l01@00
0?l2003o00030000o`00o`000?l000800?l00P000?l3003o00@0003o1@00o`040000o`kooooo103o
P0000`3o0000oh000?n000040?n000<0003o1P00o`020000o`<0oh000P000?l20?n00003003o003o
P000oh0000/0oh000P3o00020000o`03003o003oP000oh000080oh000P3o0003003o0080oh000P00
o`040?n000030000o`3oP000oh0000@0o`001@000?l2003o0080oh0000<0o`000?n0003oP000103o
P002003o00030000o`3oP000oh000080oh000P3o00070?n00080003o0P00o`000`3oP000003o0000
o`0;0000o`D00?l0103oP002003o00030?n0003o0000o`000080oh006?ooool001KoooooP@3o0002
0?n000L0o`003_ooool2003o00L0003o5000o`030?n00080003o0P3oP00B003o0080oh0000<00?l0
0000o`000?l00P00o`020000o`D00?l01@3oP002003o00L0oh0010000?l>003o00H0003o1@00o`02
0?n000800?l000<0oh00003o0000o`0010000?l70?n00080o`001@3oP002003o00kooooo3P000?l4
003o00@0003o0`00o`0P0000o`H00?l00P3oP0000`000?l00?l0003o0002003o02h0003o0P00o`02
0000o`/00?l01`000?l>ooooo`800?l00P000?l50?n00080003o0P3oP003003o0080003o0P00o`05
0?n000800?l00`3oP0020?l000l0oh0000<00?l00?n0003oP000103oP0020?l000L0oh000P00o`00
0`3oP000o`000?l000040?l000<0oh0010000?l;0?n00003003o003oP000oh0000800?l00P000?l2
0?n000030000o`3oP000oh000080o`000P3oP0020?l00003003o00000?l0003o00D00?l0103oP005
0000o`@00?l0103oP003003o0080o`006?ooool001KoooooP@3o00020?n000L0o`003_ooool2003o
00L0003o5000o`030?n00080003o0P3oP00B003o0080oh0000<00?l00000o`000?l00P00o`020000
o`D00?l01@3oP002003o00L0oh0010000?l>003o00H0003o1@00o`020?n000800?l000<0oh00003o
0000o`0010000?l70?n00080o`001@3oP002003o00kooooo3P000?l4003o00@0003o0`00o`0P0000
o`H00?l00P3oP0000`000?l00?l0003o0002003o02h0003o0P00o`020000o`/00?l01`000?l>oooo
o`800?l00P000?l50?n00080003o0P3oP003003o0080003o0P00o`050?n000800?l00`3oP0020?l0
00l0oh0000<00?l00?n0003oP000103oP0020?l000L0oh000P00o`000`3oP000o`000?l000040?l0
00<0oh0010000?l;0?n00003003o003oP000oh0000800?l00P000?l20?n000030000o`3oP000oh00
0080o`000P3oP0020?l00003003o00000?l0003o00D00?l0103oP0050000o`@00?l0103oP003003o
0080o`006?ooool001Kooooo1@3o00020?n000@0o`000P3oP0000`3o0000oh000?n0000T0?l00080
oh002`3o00000`3oP000o`000?l000020?l00080oh004P3o00000`3oP000o`000?l0000]0?l000ko
oooo0P000?l20?n000030000o`00o`000?l000H00?l000<0003o003o0000o`003@00o`070000o`D0
oh003`00o`0:0000o`800?l00P3oP0070?l000D0oh000P000?l6003o00<0oh000P000?l20?n000D0
0?l0103oP009003o00030?n00000o`000?l000800?l00P000?l3003o0080oh00103o00030?n00080
003o0P00o`0>oooooaT0003o1000o`0>0000o`80oh002`000?l00`00o`00003o0000o`020000o`80
0?l00`000?l2003o00L0003o0P00o`040000o`03003o00000?l0003o0080003o0P3oP00<0000o`80
0?l03@000?l<003o0080003o0P00o`070000o`kooooo0P000?l30?n00080o`001`3oP004003o0080
oh000`000?l70?n00080003o1`3oP002003o0080o`000P00o`020?n00003003o003o0000o`0000@0
oh000P3o00050?n000800?l00P3oP0000`000?l0oh000?n000020?l00080oh000`3o0002003o0080
oh000P00o`000`000?l0oh000?n0000;0?n000@00?l01`3oP0020?l000030?n0003o0000o`000080
o`000`3oP0020?l000800?l00P000?l5003o00H0oh0000<0003o0?n0003oP0000P3oP00Hooooo`00
5_oooolm0?l00080oh006`3o00000`3oP000o`000?l000090?l00080oh002`3o00000`3oP000o`00
0?l0000D0?l000kooooo0P000?l3003o0080003o0P00o`050000o`T00?l01P000?l00`00o`00003o
0000o`040000o`D0oh003@00o`030000o`80oh001000o`090?n00003003o003oP000oh000080o`00
103oP0030000o`800?l00P000?l20?n000D00?l00P3oP009003o0080003o0`00o`040000o`030?n0
00000?l0003o00H0003o00<0oh000000o`000?l0103oP0020000o`D00?l03_ooool50000o`800?l0
10000?l3003o00@0003o1`00o`020000o`800?l000<0003o003o0000o`003`000?l00`3oP000003o
0000o`020000o`800?l00`000?l20?n000/0003o0P3oP0000`00o`00003o0000o`040000o`800?l0
1`000?l2003o0180003o2000o`020000o`H00?l000<0003o003o0000o`001000o`030000o`@00?l0
3_ooool50?n000@0o`00103oP0000`3o0000003o0000o`02003o0080oh000P00o`050?n00080003o
0`3oP004003o0080003o0`3oP0020000o`@0o`0000<0oh000?l0003o00000P3oP002003o0080o`00
00<0oh000?l0003o0000103oP0020000o`D0oh000P3o00050?n000@00?l000<0oh000?l0003o0000
0P3oP0020?l00080oh000`00o`020000o`@0oh0000<00?l00?n0003oP0000P3o000@0?n000800?l0
0P3oP0000`00o`00003o0000o`02003o0080003o0`00o`040?n001Sooooo000Fooooocd0o`000P3o
P00K0?l000030?n0003o0000o`0000T0o`000P3oP00;0?l000030?n0003o0000o`0001@0o`003_oo
ool20000o`<00?l00P000?l2003o00D0003o2@00o`060000o`03003o00000?l0003o00@0003o1@3o
P00=003o00<0003o0P3oP004003o00T0oh0000<00?l00?n0003oP0000P3o00040?n000<0003o0P00
o`020000o`80oh001@00o`020?n000T00?l00P000?l3003o00@0003o00<0oh000000o`000?l01P00
0?l00`3oP000003o0000o`040?n00080003o1@00o`0>ooooo`D0003o0P00o`040000o`<00?l01000
0?l7003o0080003o0P00o`000`000?l00?l0003o000?0000o`030?n000000?l0003o0080003o0P00
o`030000o`80oh002`000?l20?n00003003o00000?l0003o00@0003o0P00o`070000o`800?l04P00
0?l8003o0080003o1P00o`000`000?l00?l0003o0004003o00<0003o1000o`0>ooooo`D0oh00103o
00040?n000030?l000000?l0003o00800?l00P3oP002003o00D0oh000P000?l30?n000@00?l00P00
0?l30?n00080003o103o00000`3oP000o`000?l000020?n000800?l00P3o00000`3oP000o`000?l0
00040?n00080003o1@3oP0020?l000D0oh001000o`000`3oP000o`000?l000020?n00080o`000P3o
P003003o0080003o103oP0000`00o`00oh000?n000020?l00100oh000P00o`020?n00003003o0000
0?l0003o00800?l00P000?l3003o00@0oh006?ooool001Kooooo1@3o00020?n002T0o`000P3oP014
0?l00080oh003@3o00000`3oP000o`000?l000020?l000kooooo1000o`000`000?l00?l0003o0002
003o0080003o4`00o`060000o`80oh001@000?l7003o0080003o1000o`000`000?l00?l0003o0002
0000o`800?l00P000?l00`3oP000o`000?l000020?n00080o`002@3oP0000`00o`00oh000?n00002
003o0080o`001@3oP0060000o`D00?l00P3oP0020000o`030?n000000?l0003o0080003o3000o`06
0?n000<0003o0P3oP002003o00kooooo10000?l3003o00@0003o0`00o`040000o`800?l01`000?l2
003o00L0003o0P00o`030000o`@00?l02`000?l00`00o`00003o0000o`040000o`<0oh0010000?l2
0?n000030000o`3oP000oh0002T0003o5P00o`0>ooooo`800?l00P3o00000`3oP000o`000?l00002
0?l000T0oh000P3o00020?n000<0o`00103oP003003o00@0oh000`000?l40?n00080o`004P3oP003
0000o`80oh000P3o00030?n00080o`001`3oP0060?l000<00?l0203oP0000`00o`00oh000?n00002
0?n00080003o403oP0030?l000800?l00P3oP0020000o`800?l01@3oP00Hooooo`005_ooool50?l0
0080oh00:@3o00020?n004@0o`000P3oP00=0?l000030?n0003o0000o`000080o`003_ooool4003o
00030000o`00o`000?l000800?l00P000?lC003o00H0003o0P3oP0050000o`L00?l00P000?l4003o
00030000o`00o`000?l00080003o0P00o`020000o`030?n0003o0000o`000080oh000P3o00090?n0
0003003o003oP000oh0000800?l00P3o00050?n000H0003o1@00o`020?n00080003o00<0oh000000
o`000?l00P000?l<003o00H0oh000`000?l20?n000800?l03_ooool40000o`<00?l010000?l3003o
00@0003o0P00o`070000o`800?l01`000?l2003o00<0003o1000o`0;0000o`03003o00000?l0003o
00@0003o0`3oP0040000o`80oh0000<0003o0?n0003oP000:@000?lF003o00kooooo0P00o`020?l0
00030?n0003o0000o`000080o`002@3oP0020?l00080oh000`3o00040?n000<00?l0103oP0030000
o`@0oh000P3o000B0?n000<0003o0P3oP0020?l000<0oh000P3o00070?n000H0o`000`00o`080?n0
0003003o003oP000oh000080oh000P000?l@0?n000<0o`000P00o`020?n00080003o0P00o`050?n0
01Sooooo000Fooooo`D0o`000P3oP00F0?l000030?n0003o0000o`0006D0o`0000<00?l00?l0003o
00000P3o000>ooooo`800?l00`000?lD003o0080003o2@00o`070000o`D00?l00P000?l7003o00T0
003o2@3oP0020000o`80oh000P3o00030000o`L0oh001000o`040000o`030?n000000?l0003o00@0
003o1`00o`020?n000D00?l00P000?l2003o00D0003o0P3oP0020000o`030?n000000?l0003o0080
0?l03_ooool2003o0080oh001`000?l2003o00X0003o0P00o`0=0000o`T00?l030000?l2003o00h0
003o0P3oP0040000o`<00?l06`000?l2003o00<0003o0P3oP0090000o`H00?l000<0003o003o0000
o`000P00o`0>ooooo`800?l00`3oP0040?l000D0oh001000o`070?n000800?l01@3oP0020?l000@0
oh0000<00?l00?n0003oP0000P00o`040?l000030?n0003o0000o`000080oh001@3o00020?n00080
o`001@00o`040?l00080oh0000<0o`000?n0003oP000103oP003003o0080oh00103o00020?n00003
003o003oP000oh0000T0oh000P00o`020?n00080003o00<0oh000000o`000?l010000?l50?n00080
003o1`3oP002003o0080oh0000<0o`000?n0003oP0000P00o`0Hooooo`005_ooool50?l00080oh00
5P3o00000`3oP000o`000?l0001U0?l00003003o003o0000o`000080o`003_ooool2003o00<0003o
5000o`020000o`T00?l01`000?l5003o0080003o1`00o`090000o`T0oh000P000?l20?n00080o`00
0`000?l70?n000@00?l010000?l00`3oP000003o0000o`040000o`L00?l00P3oP005003o0080003o
0P00o`050000o`80oh000P000?l00`3oP000003o0000o`02003o00kooooo0P00o`020?n000L0003o
0P00o`0:0000o`800?l03@000?l9003o00`0003o0P00o`0>0000o`80oh0010000?l3003o01/0003o
0P00o`030000o`80oh002@000?l6003o00030000o`00o`000?l000800?l03_ooool2003o00<0oh00
103o00050?n000@00?l01`3oP002003o00D0oh000P3o00040?n00003003o003oP000oh0000800?l0
103o00000`3oP000o`000?l000020?n000D0o`000P3oP0020?l000D00?l0103o00020?n000030?l0
003oP000oh0000@0oh000`00o`020?n000@0o`000P3oP0000`00o`00oh000?n000090?n000800?l0
0P3oP0020000o`030?n000000?l0003o00@0003o1@3oP0020000o`L0oh000P00o`020?n000030?l0
003oP000oh0000800?l06?ooool001Kooooo9`3o00020?n002H0o`000P3oP00B0?l000030?n0003o
0000o`0002@0o`003_ooool5003o00@0003o5000o`030000o`800?l010000?l00`00o`00003o0000
o`020000o`D00?l00P000?l9003o00@0003o1@00o`040?n000030000o`3oP000oh0000@0oh000P3o
00050000o`800?l01@3oP004003o0080003o0`00o`060000o`030?n000000?l0003o00@0003o00<0
oh00003o0000o`001P00o`000`3oP000003o0000o`020000o`@0oh001@00o`0>ooooo`80003o0P00
o`000`000?l00?l0003o0007003o00P0003o0`00o`0>0000o`800?l03@000?l2003o0140003o0P00
o`020?n00080003o0`3oP00?0000o`80oh002P000?l6003o00030000o`00o`000?l00080003o2@00
o`020?n000L0003o3_ooool20?n00080o`000`3oP0020?l000D0oh000P00o`020?l000/0oh0000<0
003o0?n0003oP0000P00o`040?n000D0003o3P3oP0020?l000800?l00P3oP005003o0080o`001@3o
P0020000o`80oh000P3o000:0?n00080003o2@3oP002003o00D0oh000P00o`070?n00080003o103o
P0000`00o`00oh000?n000060?n000030?l0003oP000oh000080oh006?ooool001Kooooo9`3o0002
0?n002H0o`000P3oP00B0?l000030?n0003o0000o`0002@0o`003_ooool5003o00@0003o5000o`03
0000o`800?l010000?l00`00o`00003o0000o`020000o`D00?l00P000?l9003o00@0003o1@00o`04
0?n000030000o`3oP000oh0000@0oh000P3o00050000o`800?l01@3oP004003o0080003o0`00o`06
0000o`030?n000000?l0003o00@0003o00<0oh00003o0000o`001P00o`000`3oP000003o0000o`02
0000o`@0oh001@00o`0>ooooo`80003o0P00o`000`000?l00?l0003o0007003o00P0003o0`00o`0>
0000o`800?l03@000?l2003o0140003o0P00o`020?n00080003o0`3oP00?0000o`80oh002P000?l6
003o00030000o`00o`000?l00080003o2@00o`020?n000L0003o3_ooool20?n00080o`000`3oP002
0?l000D0oh000P00o`020?l000/0oh0000<0003o0?n0003oP0000P00o`040?n000D0003o3P3oP002
0?l000800?l00P3oP005003o0080o`001@3oP0020000o`80oh000P3o000:0?n00080003o2@3oP002
003o00D0oh000P00o`070?n00080003o103oP0000`00o`00oh000?n000060?n000030?l0003oP000
oh000080oh006?ooool001Kooooo803o00020?n000d0o`0000<0oh000?l0003o00002`3o00020?n0
04/0o`003_ooool2003o00<0003o1P00o`050000o`800?l00P000?l5003o00h0003o3@00o`020000
o`800?l01`000?l20?n00003003o003oP000oh0000@0oh0000<0o`000?n0003oP0001`3oP0040000
o`80oh000P000?l30?n00080003o1000o`000`3oP0000?l0003o0007003o00/0003o1000o`070000
o`<0oh000P000?l2003o00kooooo0P000?l20?n000<00?l010000?l2003o00030?n00000o`000?l0
00H0003o0`00o`0I0000o`800?l02`000?l20?n000D0003o0P00o`000`000?l00?l0003o00040000
o`800?l02P000?l4003o00@0003o0`3oP002003o0100003o0P00o`020000o`03003o00000?l0003o
00H0oh000`000?l2003o00kooooo0P00o`020?l000030000o`3oP000oh0000H0oh0000<0003o0?n0
003oP0000P3o00090?n000<0003o0P00o`020?l00080003o6@3oP0040000o`030?n00000o`000?l0
00L0oh000P000?l70?n00080o`000P3oP0020000o`030?n000000?l0003o0080003o0P3o00020?n0
00<0o`000P3oP0020?l00080003o00<00?l00?n0003oP0000P000?l2003o00030?n00000o`000?l0
00H0oh000`000?l70?n00080003o0P3oP00Hooooo`005_ooool;0?l00080oh003P3o00020?n000`0
o`000P3oP00I0?l00080oh008P3o00020?n000<0o`000P3oP0070?l00080oh002@3o00020?n000L0
o`003_ooool@003o0080003o3000o`040000o`@00?l000<0003o003o0000o`002`00o`070000o`@0
0?l02@3oP0000`00o`00oh000?n000020000o`@0oh000`00o`020000o`800?l00P000?l3003o0080
oh0010000?l30?n001T00?l00P3oP0020000o`80oh001@00o`0>ooooo`80003o0P00o`000`000?l0
0?l0003o00020000o`800?l00P000?l00`00o`00003o0000o`020000o`D00?l010000?l20?n000T0
003o00<00?l00000o`000?l00P000?l20?n000800?l05`000?l20?n000<0003o103oP0050000o`80
oh001`000?l40?n000T0003o0P3oP00A0000o`H0oh000P00o`000`000?l00?l0003o0002003o00ko
oooo0P3oP0020000o`<0oh000P00o`020000o`80o`0000<00?l00?n0003oP0000P00o`050?n00080
003o1000o`000`000?l0oh000?n000020?n00080o`000P3oP0000`3o0000oh000?n00002003o0080
oh000`3o00040?n00080o`000P3oP0000`3o0000oh000?n000040?n000D0003o103oP0000`000?l0
o`000?l0000;0?n00080003o0P3oP0050000o`80oh000P3o00030?n000800?l00P3o00030?n00080
003o103oP0000`00o`00003o0000o`020000o`80oh000`000?l2003o00L0oh000P00o`020?n001So
oooo000Fooooo`/0o`000P3oP00>0?l00080oh00303o00020?n001T0o`000P3oP00R0?l00080oh00
0`3o00020?n000L0o`000P3oP0090?l00080oh001`3o000>oooooa000?l00P000?l<003o00@0003o
1000o`000`000?l00?l0003o000;003o00L0003o1000o`090?n00003003o003oP000oh000080003o
103oP003003o0080003o0P00o`020000o`<00?l00P3oP0040000o`<0oh006@00o`020?n00080003o
0P3oP005003o00kooooo0P000?l2003o00030000o`00o`000?l00080003o0P00o`020000o`03003o
00000?l0003o0080003o1@00o`040000o`80oh002@000?l00`00o`00003o0000o`020000o`80oh00
0P00o`0G0000o`80oh000`000?l40?n000D0003o0P3oP0070000o`@0oh002@000?l20?n00140003o
1P3oP002003o00030000o`00o`000?l000800?l03_ooool20?n00080003o0`3oP002003o0080003o
0P3o00000`00o`00oh000?n00002003o00D0oh000P000?l4003o00030000o`3oP000oh000080oh00
0P3o00020?n000030?l0003oP000oh0000800?l00P3oP0030?l000@0oh000P3o00020?n000030?l0
003oP000oh0000@0oh001@000?l40?n000030000o`3o0000o`0000/0oh000P000?l20?n000D0003o
0P3oP0020?l000<0oh000P00o`020?l000<0oh000P000?l40?n00003003o00000?l0003o0080003o
0P3oP0030000o`800?l01`3oP002003o0080oh006?ooool001Kooooo803o00020?n001T0o`000P3o
P00k0?l00080oh001@3o00040?n000L0o`003_ooool20000o``00?l00P000?l9003o0080003o6@00
o`090000o`800?l00P3oP0000`00o`00oh000?n000070?n00080003o103oP0000`000?l00?l0003o
00020000o`80o`000P3oP0030?l00080oh001000o`000`3oP0000?l0003o000F003o00030?n00000
o`000?l000@0003o0`3oP0020000o`800?l03_ooool20000o`L00?l010000?l00`3oP000003o0000
o`020000o`@00?l040000?l00`00o`00003o0000o`020?n00080003o0P3oP0050000o`T00?l02`00
0?l00`00o`00oh000?n000020000o`80oh001@000?l20?n000@00?l000<0003o0?n0003oP0000P3o
P0070000o`80oh0010000?l7003o00L0003o0P3oP0000`000?l0oh000?n000040000o`80oh001@00
0?l>ooooo`80003o1`3oP002003o0080oh0000<00?l00?l0003o00000P3oP002003o00D0003o2@00
o`040?n000030?l00000o`000?l000T0oh000P3o00020?n000<0o`00103oP005003o00H0oh000`3o
00040000o`<0oh000P000?l40?n000<0003o6@3oP002003o00H0003o00<0oh00003o0000o`000P00
o`020000o`80oh0000<0003o0?n0003oP0000P3oP00Hooooo`005_oooolP0?l00080oh006@3o0002
0?n003/0o`000P3oP0050?l000@0oh001`3o000>ooooo`80003o3000o`020000o`T00?l00P000?lI
003o00T0003o0P00o`020?n00003003o003oP000oh0000L0oh000P000?l40?n000030000o`00o`00
0?l00080003o0P3o00020?n000<0o`000P3oP004003o00030?n00000o`000?l001H00?l000<0oh00
003o0000o`0010000?l30?n00080003o0P00o`0>ooooo`80003o1`00o`040000o`030?n000000?l0
003o0080003o1000o`0@0000o`03003o00000?l0003o0080oh000P000?l20?n000D0003o2@00o`0;
0000o`03003o003oP000oh000080003o0P3oP0050000o`80oh001000o`000`000?l0oh000?n00002
0?n000L0003o0P3oP0040000o`L00?l01`000?l20?n000030000o`3oP000oh0000@0003o0P3oP005
0000o`kooooo0P000?l70?n000800?l00P3oP0000`00o`00o`000?l000020?n000800?l01@000?l9
003o00@0oh0000<0o`00003o0000o`002@3oP0020?l00080oh000`3o00040?n000D00?l01P3oP003
0?l000@0003o0`3oP0020000o`@0oh000`000?lI0?n000800?l01P000?l00`3oP0000?l0003o0002
003o0080003o0P3oP0000`000?l0oh000?n000020?n001Sooooo000Foooooah0o`001P3oP0050?l0
0080oh00>`3o00020?n000/0o`0000<0oh000?l0003o00002`3o00020?n000L0o`003_ooool2003o
0080003o1`00o`020000o`03003o00000?l0003o00h00?l020000?l<003o00@0003o0P3oP0000`00
o`00003o0000o`020000o`80o`001@3oP0020000o`D0oh000P00o`090000o`L0oh000P00o`070000
o`80oh001@000?l2003o00d0003o00<00?l00?n0003oP00010000?l20?n000<0003o0P00o`0>oooo
o`@00?l000<0003o003o0000o`001000o`020000o`030?n000000?l0003o0080003o0P00o`020000
o`X00?l03@000?l20?n00180003o00<0oh000000o`000?l00P000?l20?n000030000o`3oP000oh00
00@0003o0`00o`040?n000T0003o1000o`030000o`80oh001@000?l4003o00<0003o0P3oP0020000
o`D00?l00P3oP0090000o`80oh003_ooool20000o`80oh0000<0003o0?n0003oP0001`3oP0020?l0
00L0oh0010000?l2003o00030000o`00o`000?l000H0oh0000<0o`000?n0003oP0000P3oP0020?l0
00800?l00`3o00020?n00080o`000P3oP0000`3o0000oh000?n000040?n000800?l000<0oh000?l0
003o00002`3oP0020000o`<0oh002`00o`020?n00080003o1@3oP0020?l000L0oh000P00o`000`3o
P000003o0000o`040000o`L0oh0010000?l50?n001Sooooo000Foooooah0o`001P3oP0050?l00080
oh00>`3o00020?n000/0o`0000<0oh000?l0003o00002`3o00020?n000L0o`003_ooool2003o0080
003o1`00o`020000o`03003o00000?l0003o00h00?l020000?l<003o00@0003o0P3oP0000`00o`00
003o0000o`020000o`80o`001@3oP0020000o`D0oh000P00o`090000o`L0oh000P00o`070000o`80
oh001@000?l2003o00d0003o00<00?l00?n0003oP00010000?l20?n000<0003o0P00o`0>ooooo`@0
0?l000<0003o003o0000o`001000o`020000o`030?n000000?l0003o0080003o0P00o`020000o`X0
0?l03@000?l20?n00180003o00<0oh000000o`000?l00P000?l20?n000030000o`3oP000oh0000@0
003o0`00o`040?n000T0003o1000o`030000o`80oh001@000?l4003o00<0003o0P3oP0020000o`D0
0?l00P3oP0090000o`80oh003_ooool20000o`80oh0000<0003o0?n0003oP0001`3oP0020?l000L0
oh0010000?l2003o00030000o`00o`000?l000H0oh0000<0o`000?n0003oP0000P3oP0020?l00080
0?l00`3o00020?n00080o`000P3oP0000`3o0000oh000?n000040?n000800?l000<0oh000?l0003o
00002`3oP0020000o`<0oh002`00o`020?n00080003o1@3oP0020?l000L0oh000P00o`000`3oP000
003o0000o`040000o`L0oh0010000?l50?n001Sooooo000Foooooc/0o`000P3oP00g0?l000@0oh00
403o00020?n000kooooo3P00o`040000o`h00?l010000?l7003o00@0003o0`00o`020000o`L00?l0
0P3oP0020000o`D0oh002@000?l4003o00D0003o103oP0000`3o0000oh000?n000020?n000T0003o
0P00o`090000o`h00?l00P000?l30?n000@0003o3_ooool70000o`T00?l00P000?l4003o00<0003o
0P00o`020000o`03003o00000?l0003o00/0003o0P00o`0G0000o`80oh000`00o`060?n000<00?l0
20000?l00`00o`00003o0000o`0B0000o`80oh000`000?l2003o00@0003o0P3oP0030000o`80oh00
10000?l00`00o`00003o0000o`020000o`kooooo0P000?l3003o0080oh000P000?l2003o0080oh00
00<00?l00?n0003oP000103oP002003o00<0oh001@000?l40?n000800?l00`3oP002003o0080oh00
0P00o`030?n00080o`00103oP0020000o`030?l0003oP000oh0000T0oh000P3o00030?n00080o`00
0P00o`020?n000800?l000<0oh00003o0000o`000P3oP0070000o`@0oh000P00o`030?n00080003o
1`3oP0020000o`80oh0000<0003o003o0000o`0010000?l20?n000<0003o0P3oP0040000o`D0oh00
6?ooool001KoooooIP3o00020?n00280o`003_ooool2003o0080003o0`00o`020000o`@00?l00`00
0?l2003o0080003o4P00o`000`000?l00?l0003o000;003o00d0003o00<0oh000000o`000?l01@00
0?l20?n00080003o0P00o`0<0?n000H0003o0P00o`000`000?l00?l0003o000F003o00<0003o0P00
o`020?n00080003o00<00?l00000o`000?l00P000?l>ooooo`@0003o00<00?l00000o`000?l01P00
0?l9003o00030000o`00o`000?l000L0003o0P00o`050000o`80oh000P000?l2003o00L0003o0P00
o`030000o`800?l02@000?l20?n00080003o00<00?l00000o`000?l00P3oP002003o0080003o00<0
0?l00000o`000?l02`000?l20?n000D0003o103oP00:0000o`80oh001`000?l20?n000/0003o3_oo
ool4003o00X0oh000P000?l40?n00080o`0000<0oh00003o0000o`001000o`070?n000800?l000<0
o`00003o0000o`000P3oP0020?l00080oh0000<0o`000?n0003oP0000P3oP0040000o``0oh00103o
00090?n00003003o003oP000oh0000@0oh000`000?l40?n000@0003o0`00o`070?l00080oh000P00
0?l20?n00003003o003oP000oh000080oh000P000?l2003o00030?n00000o`000?l00080003o0P00
o`070?n001Sooooo000FooooofH0o`000P3oP00R0?l000kooooo0P00o`020000o`<00?l00P000?l4
003o00<0003o0P00o`020000oa800?l000<0003o003o0000o`002`00o`0=0000o`030?n000000?l0
003o00D0003o0P3oP0020000o`800?l0303oP0060000o`800?l000<0003o003o0000o`005P00o`03
0000o`800?l00P3oP0020000o`03003o00000?l0003o0080003o3_ooool40000o`03003o00000?l0
003o00H0003o2@00o`000`000?l00?l0003o00070000o`800?l01@000?l20?n00080003o0P00o`07
0000o`800?l00`000?l2003o00T0003o0P3oP0020000o`03003o00000?l0003o0080oh000P00o`02
0000o`03003o00000?l0003o00/0003o0P3oP0050000o`@0oh002P000?l20?n000L0003o0P3oP00;
0000o`kooooo1000o`0:0?n00080003o103oP0020?l000030?n00000o`000?l000@00?l01`3oP002
003o00030?l00000o`000?l00080oh000P3o00020?n000030?l0003oP000oh000080oh0010000?l<
0?n000@0o`002@3oP0000`00o`00oh000?n000040?n000<0003o103oP0040000o`<00?l01`3o0002
0?n00080003o0P3oP0000`00o`00oh000?n000020?n00080003o0P00o`000`3oP0000?l0003o0002
0000o`800?l01`3oP00Hooooo`005_oooolk0?l00080oh006`3o00020?n000`0o`000P3oP00G0?l0
0080oh001@3o00020?n00080o`003_oooolF003o00030000o`00o`000?l000D00?l02@000?lA003o
00030?n00000o`000?l00080003o0P3oP0050000o`@00?l01@000?l40?n000<00?l01P000?l50?n0
0080003o0P00o`000`3oP000003o0000o`020?n000L00?l01@000?l2003o00/0003o0P3oP0020000
o`030?n000000?l0003o00800?l03_oooolG0000o`800?l01`000?l2003o01@0003o1@00o`090000
o`@0oh0000<00?l00000o`000?l00P000?l40?n000h00?l02@000?l2003o00<0003o0P00o`020000
o`800?l00`000?l2003o00d0003o00<00?l00000o`000?l00P000?l>ooooo`@0oh0000<00?l00?n0
003oP0000P00o`020?n000<00?l00P000?l20?l000@0oh0000<0o`000000o`000?l00P000?l20?n0
0003003o003oP000oh0001@0oh000P000?l2003o00T0oh0000<0003o0?n0003oP0000P3oP0020000
o`h0oh000P00o`020?n000T00?l000<0oh00003o0000o`000P3o00020?n00080o`0000<0oh000?l0
003o00000P3oP0020?l000<0oh000P00o`050000o`80oh000P00o`020?n000D0o`000P3oP00Hoooo
o`005_oooolk0?l00080oh006`3o00020?n000`0o`000P3oP00G0?l00080oh001@3o00020?n00080
o`003_oooolF003o00030000o`00o`000?l000D00?l02@000?lA003o00030?n00000o`000?l00080
003o0P3oP0050000o`@00?l01@000?l40?n000<00?l01P000?l50?n00080003o0P00o`000`3oP000
003o0000o`020?n000L00?l01@000?l2003o00/0003o0P3oP0020000o`030?n000000?l0003o0080
0?l03_oooolG0000o`800?l01`000?l2003o01@0003o1@00o`090000o`@0oh0000<00?l00000o`00
0?l00P000?l40?n000h00?l02@000?l2003o00<0003o0P00o`020000o`800?l00`000?l2003o00d0
003o00<00?l00000o`000?l00P000?l>ooooo`@0oh0000<00?l00?n0003oP0000P00o`020?n000<0
0?l00P000?l20?l000@0oh0000<0o`000000o`000?l00P000?l20?n00003003o003oP000oh0001@0
oh000P000?l2003o00T0oh0000<0003o0?n0003oP0000P3oP0020000o`h0oh000P00o`020?n000T0
0?l000<0oh00003o0000o`000P3o00020?n00080o`0000<0oh000?l0003o00000P3oP0020?l000<0
oh000P00o`050000o`80oh000P00o`020?n000D0o`000P3oP00Hooooo`005_oooolD0?l00080oh00
1`3o00000`3oP000o`000?l0000@0?l00080oh009P3o00020?n000h0o`000P3oP00L0?l00080oh00
0P3o000>oooooaL00?l00P000?l7003o0080003o3@00o`000`000?l00?l0003o00060000o`030?n0
00000?l0003o0080oh000P00o`030000o`800?l010000?l30?n000800?l02@3oP004003o00T0003o
3P00o`070000o`L00?l02@000?l2003o00kooooo10000?l7003o0080003o00<00?l00000o`000?l0
0P000?l20?n00080003o00<00?l00000o`000?l02@00o`020000o`<00?l020000?l00`00o`00003o
0000o`06003o00<0003o0P00o`0;0000o`030?n000000?l0003o00H0oh000`000?l4003o0180003o
1@00o`070000o`/00?l010000?l00`00o`00003o0000o`02003o00kooooo103oP0000`3o0000oh00
0?n000060?n000<0003o0P3oP0040?l001T0oh0000<0003o0?n0003oP0000P3oP0020000o`800?l0
2P3oP0040000o`<0oh00103o00020?n00080003o0`3oP002003o0080oh000`00o`080?n000D00?l0
0P3oP0020?l000<0oh000P3o0002003o00030?n00000o`000?l000800?l00P000?l5003o0080o`00
0P3oP0050?l00080oh006?ooool001Kooooo503o00020?n000L0o`0000<0oh000?l0003o0000403o
00020?n002H0o`000P3oP00>0?l00080oh00703o00020?n00080o`003_oooolG003o0080003o1`00
o`020000o`d00?l000<0003o003o0000o`001P000?l00`3oP000003o0000o`020?n000800?l00`00
0?l2003o00@0003o0`3oP002003o00T0oh001000o`090000o`h00?l01`000?l7003o00T0003o0P00
o`0>ooooo`@0003o1`00o`020000o`03003o00000?l0003o0080003o0P3oP0020000o`03003o0000
0?l0003o00T00?l00P000?l3003o00P0003o00<00?l00000o`000?l01P00o`030000o`800?l02`00
0?l00`3oP000003o0000o`060?n000<0003o1000o`0B0000o`D00?l01`000?l;003o00@0003o00<0
0?l00000o`000?l00P00o`0>ooooo`@0oh0000<0o`000?n0003oP0001P3oP0030000o`80oh00103o
000I0?n000030000o`3oP000oh000080oh000P000?l2003o00X0oh0010000?l30?n000@0o`000P3o
P0020000o`<0oh000P00o`020?n000<00?l0203oP005003o0080oh000P3o00030?n00080o`000P00
o`000`3oP0000?l0003o0002003o0080003o1@00o`020?l00080oh001@3o00020?n001Sooooo000F
ooooobL0o`000P3oP01:0?l000030?n0003o0000o`0001@0o`003_ooool2003o00L0003o1@00o`06
0000o`800?l000<0003o003o0000o`001000o`000`3oP000003o0000o`020000o`80oh004P00o`02
0000o`D0oh000P3o00020?n000<00?l0103oP0000`00o`00003o0000o`020?n00080o`000P3oP000
0`00o`00oh000?n000020?n00080003o0P3o00000`3oP000003o0000o`040000o`80oh002@000?l3
003o00D0003o0P00o`040000o`/00?l000<0003o003o0000o`000P00o`0>ooooo`T0003o0P00o`02
0000o`<00?l01`000?l7003o0080oh002@00o`020000o`@00?l02P000?l6003o00<0003o0P00o`09
0000o`80oh001`000?l9003o00T0003o1`00o`090000o`800?l02`000?l3003o0080003o3_ooool2
0?n000<0o`00203oP0000`000?l00?l0003o00040?n00080o`0000<0oh000000o`000?l00P3oP002
003o00<0oh000P000?l2003o00<0oh000P3o00040?n00080003o0`3oP004003o00D0oh000P3o0002
0?n00080o`005@3oP0020000o`<00?l01P3oP002003o00L0oh000`3o000;0?n000800?l00P3oP003
003o0080o`000P3oP0020?l000<0oh000P00o`0Hooooo`005_oooolW0?l00080oh00BP3o00000`3o
P000o`000?l0000D0?l000kooooo0P00o`070000o`D00?l01P000?l2003o00030000o`00o`000?l0
00@00?l000<0oh000000o`000?l00P000?l20?n001800?l00P000?l50?n00080o`000P3oP003003o
00@0oh0000<00?l00000o`000?l00P3oP0020?l00080oh0000<00?l00?n0003oP0000P3oP0020000
o`80o`0000<0oh000000o`000?l010000?l20?n000T0003o0`00o`050000o`800?l010000?l;003o
00030000o`00o`000?l000800?l03_ooool90000o`800?l00P000?l3003o00L0003o1`00o`020?n0
00T00?l00P000?l4003o00X0003o1P00o`030000o`800?l02@000?l20?n000L0003o2@00o`090000
o`L00?l02@000?l2003o00/0003o0`00o`020000o`kooooo0P3oP0030?l000P0oh0000<0003o003o
0000o`00103oP0020?l000030?n000000?l0003o0080oh000P00o`030?n00080003o0P00o`030?n0
0080o`00103oP0020000o`<0oh001000o`050?n00080o`000P3oP0020?l001D0oh000P000?l3003o
00H0oh000P00o`070?n000<0o`002`3oP002003o0080oh000`00o`020?l00080oh000P3o00030?n0
00800?l06?ooool001Kooooo7@3o00000`3oP000o`000?l0000@0?l00080oh009P3o00020?n000X0
o`00103oP00I0?l00080oh001`3o000>ooooo`d00?l00`000?l2003o00D0003o0P00o`040000o`L0
0?l00P000?l5003o00D0003o1P00o`030000o`d0oh000P000?l50?n000@0003o1@3oP004003o0003
0?n00000o`000?l000d00?l00P000?l3003o00L0003o1`00o`020?n000800?l0103oP0000`000?l0
0?l0003o00020000o`kooooo0P000?l3003o00P0003o00<00?l00000o`000?l010000?l@003o00<0
003o5000o`090000o`D00?l010000?l2003o00<0003o0P00o`0B0000o`/00?l01@000?l2003o00D0
003o0P00o`020000o`800?l01`000?l>ooooo`80oh000P3o00000`000?l0oh000?n000020?n00080
003o0P3oP0030000o`L0oh001000o`020?n00003003o003oP000oh0000800?l01`3oP002003o0080
oh000P00o`050?n000@00?l00`3oP0020?l00080oh000P3o00030?n00080o`000P00o`050?n00080
o`000P3oP0000`3o0000oh000?n000020?l00080oh000`3o00040?n00080o`000P3oP0000`00o`00
oh000?n000060?n000030?l0003oP000oh000080oh000`3o00040?n000@0003o00<0oh000?l0003o
00000P3oP0020?l000L0oh006?ooool001KoooooI03o00020?n002@0o`003_ooool20000o`<00?l0
0P3oP00;0000o`/00?l000<0oh00003o0000o`005000o`020000o`80oh0000<00?l00?n0003oP000
1`000?l20?n00080o`000`3oP0020000o`@0o`000P000?l00`3oP000003o0000o`020000o`80oh00
0P000?l30?n000l00?l00`000?l2003o0080003o00<00?l00?n0003oP00010000?l3003o0080oh00
1000o`070000o`kooooo1@000?l8003o00030000o`00o`000?l00080003o0P00o`050000o`D00?l0
0P000?l4003o00<0003o1000o`020000o`<00?l00P000?l=003o00`0003o1000o`070000o`T00?l0
0P000?l9003o0080003o1@00o`090000o`D00?l01P000?l00`3oP000003o0000o`020000o`kooooo
0P3o00020?n000030000o`3oP000oh000080o`000P3oP0020?l000<0oh000P00o`020000o`800?l0
1@3oP002003o00030?n00000o`000?l00080oh000P00o`0@0?n00080003o0P3oP0050000o`L0oh00
0P000?l<0?n00080o`001`3oP002003o0080o`000P3oP002003o00L0oh000P3o00050?n00080o`00
0`3oP0020?l00080003o0P3oP0000`000?l0o`000?l0000;0?n001Sooooo000Fooooof@0o`000P3o
P00T0?l000kooooo0P000?l3003o0080oh002`000?l;003o00030?n00000o`000?l001@00?l00P00
0?l20?n00003003o003oP000oh0000L0003o0P3oP0020?l000<0oh000P000?l40?l00080003o00<0
oh000000o`000?l00P000?l20?n00080003o0`3oP00?003o00<0003o0P00o`020000o`03003o003o
P000oh0000@0003o0`00o`020?n000@00?l01`000?l>ooooo`D0003o2000o`000`000?l00?l0003o
00020000o`800?l01@000?l5003o0080003o1000o`030000o`@00?l00P000?l3003o0080003o3@00
o`0<0000o`@00?l01`000?l9003o0080003o2@00o`020000o`D00?l02@000?l5003o00H0003o00<0
oh000000o`000?l00P000?l>ooooo`80o`000P3oP0000`000?l0oh000?n000020?l00080oh000P3o
00030?n000800?l00P000?l2003o00D0oh000P00o`000`3oP0000?l0003o00020?n000800?l0403o
P0020000o`80oh001@000?l70?n00080003o303oP0020?l000L0oh000P00o`020?l00080oh000P00
o`070?n00080o`001@3oP0020?l000<0oh000P3o00020000o`80oh0000<0003o0?l0003o00002`3o
P00Hooooo`005_ooool20?n001/0o`0000<0oh000?l0003o00003`3o00000`3oP000o`000?l00006
0?l000030?n0003o0000o`0004H0o`00103oP0000`3o0000oh000?n000020?l000kooooo2@00o`02
0?n00080003o2P00o`060000o`030?n00000o`000?l000@0003o0P00o`000`000?l00?l0003o0004
003o00<0003o0P00o`020000o`D00?l00P3oP0090000o`80oh000P000?l90?n000<0003o0P00o`05
0?n000/00?l00P3oP005003o0080003o0P00o`030000o`@00?l02`000?l20?n000D00?l03_ooool2
0000o`800?l01@000?l4003o00D0003o1@00o`060000o`T00?l000<0003o003o0000o`002`000?l;
003o00X0003o3@00o`020000o`h00?l00P000?l4003o00h0003o0`00o`090000o`@00?l03_ooool;
0?n00080o`0000<0oh00003o0000o`000P3oP0040000o`030?n000000?l0003o0080003o1@3oP002
003o0080oh000P000?l30?n000800?l00P000?l2003o00030000o`00o`000?l000800?l00P000?l2
0?n000<00?l00P3oP0020?l000T0oh0000<0003o0?n0003oP000103oP0020000o`<0oh000P3o0004
0?n000030?l0003oP000oh0000@0o`000P00o`000`3oP000o`000?l000020?l000T0oh000`3o0002
0?n00080o`000P00o`020000o`030?l0003oP000oh0000@0o`000P3oP0000`3o0000oh000?n00002
003o01Sooooo000Fooooo`80oh006`3o00000`3oP000o`000?l0000?0?l000030?n0003o0000o`00
00H0o`0000<0oh000?l0003o0000AP3o00040?n000030?l0003oP000oh000080o`003_ooool9003o
0080oh000P000?l:003o00H0003o00<0oh00003o0000o`0010000?l2003o00030000o`00o`000?l0
00@00?l00`000?l2003o0080003o1@00o`020?n000T0003o0P3oP0020000o`T0oh000`000?l2003o
00D0oh002`00o`020?n000D00?l00P000?l2003o00<0003o1000o`0;0000o`80oh001@00o`0>oooo
o`80003o0P00o`050000o`@00?l01@000?l5003o00H0003o2@00o`000`000?l00?l0003o000;0000
o`/00?l02P000?l=003o0080003o3P00o`020000o`@00?l03P000?l3003o00T0003o1000o`0>oooo
o`/0oh000P3o00000`3oP0000?l0003o00020?n000@0003o00<0oh000000o`000?l00P000?l50?n0
00800?l00P3oP0020000o`<0oh000P00o`020000o`800?l000<0003o003o0000o`000P00o`020000
o`80oh000`00o`020?n00080o`002@3oP0000`000?l0oh000?n000040?n00080003o0`3oP0020?l0
00@0oh0000<0o`000?n0003oP000103o0002003o00030?n0003o0000o`000080o`002@3oP0030?l0
0080oh000P3o0002003o0080003o00<0o`000?n0003oP000103o00020?n000030?l0003oP000oh00
00800?l06?ooool001Kooooo503o00020?n00280o`0000<0oh000?l0003o0000=P3o00020?n000X0
o`000P3oP0040?l000<0oh000P3o00020?n000kooooo1000o`070000o`h00?l00P000?l3003o0080
oh001000o`030000o`@00?l01@000?l6003o00h0003o3@3oP003003o00H0003o00<0o`000000o`00
0?l00P000?l20?n00080003o00<0oh000000o`000?l00P3oP0040000o`<00?l01@000?l6003o00T0
003o1`00o`0>ooooo`T0003o1000o`000`000?l00?l0003o00020000oa@00?l01@000?l5003o00@0
003o1`00o`020000oa800?l01`000?l7003o00/0003o7@00o`000`000?l00?l0003o00020000o`ko
oooo1`3oP0060?l000D0oh000P000?l20?n000<0003o1`3oP002003o0080003o0P00o`000`000?l0
oh000?n000060?n000<00?l00P000?l4003o00030000o`3oP000oh0000/0oh000P3o00030?n00080
o`001`00o`020?n00080003o1`3oP0020?l000/0oh0000<00?l00?l0003o00000P3oP0020?l000L0
oh000P00o`050?n000800?l00P3oP0000`00o`00003o0000o`020?n001Sooooo000Foooooa@0o`00
0P3oP00R0?l000030?n0003o0000o`0003H0o`000P3oP00:0?l00080oh00103o00030?n00080o`00
0P3oP00>ooooo`@00?l01`000?l>003o0080003o0`00o`020?n000@00?l00`000?l4003o00D0003o
1P00o`0>0000o`d0oh000`00o`060000o`030?l000000?l0003o0080003o0P3oP0020000o`030?n0
00000?l0003o0080oh0010000?l3003o00D0003o1P00o`090000o`L00?l03_ooool90000o`@00?l0
00<0003o003o0000o`000P000?lD003o00D0003o1@00o`040000o`L00?l00P000?lB003o00L0003o
1`00o`0;0000oad00?l000<0003o003o0000o`000P000?l>ooooo`L0oh001P3o00050?n00080003o
0P3oP0030000o`L0oh000P00o`020000o`800?l000<0003o0?n0003oP0001P3oP003003o0080003o
1000o`000`000?l0oh000?n0000;0?n00080o`000`3oP0020?l000L00?l00P3oP0020000o`L0oh00
0P3o000;0?n00003003o003o0000o`000080oh000P3o00070?n000800?l01@3oP002003o0080oh00
00<00?l00000o`000?l00P3oP00Hooooo`005_oooomj0?l00080oh0000<0o`000?n0003oP0000P3o
00020?n000L0o`003_ooool5003o0080oh000P00o`020?n00080003o2P00o`040000o`800?l000<0
003o003o0000o`000P3oP00B003o00@0oh000`00o`020?n000800?l00P3oP0030000o`L0oh000P00
0?l20?n000<0003o0P00o`020000o`80oh002`000?l00`00o`00003o0000o`020000o`80oh003P00
o`020000o`T00?l01@3oP002003o00kooooo10000?l00`00o`00003o0000o`04003o0080003o00<0
0?l00000o`000?l010000?l5003o0080003o0P00o`000`000?l00?l0003o0007003o00T0003o1000
o`020000o`<00?l00P000?l;003o00L0003o0P00o`0>0000o`80oh001@000?l2003o0080003o0P00
o`030000o`800?l01@000?l2003o0080003o1000o`0<0000o`800?l03_ooool20000o`T0oh000P3o
00050?n000800?l00P3oP0050000o`D0oh001P00o`000`000?l0oh000?n000060?n000030000o`00
o`000?l000H00?l000<0oh000000o`000?l02@3oP002003o0080o`001@3oP0020000o`800?l00`3o
P0020000o`T0oh000P3o0002003o00D0oh000P3o00020?n000<0o`00103oP0000`3o0000oh000?n0
00070?n000@0o`001@3oP004003o01Sooooo000FooooogX0o`000P3oP0000`3o0000oh000?n00002
0?l00080oh001`3o000>ooooo`D00?l00P3oP002003o0080oh000P000?l:003o00@0003o0P00o`00
0`000?l00?l0003o00020?n001800?l0103oP003003o0080oh000P00o`020?n000<0003o1`3oP002
0000o`80oh000`000?l2003o0080003o0P3oP00;0000o`03003o00000?l0003o0080003o0P3oP00>
003o0080003o2@00o`050?n000800?l03_ooool40000o`03003o00000?l0003o00@00?l00P000?l0
0`00o`00003o0000o`040000o`D00?l00P000?l2003o00030000o`00o`000?l000L00?l02@000?l4
003o0080003o0`00o`020000o`/00?l01`000?l2003o00h0003o0P3oP0050000o`800?l00P000?l2
003o00<0003o0P00o`050000o`800?l00P000?l4003o00`0003o0P00o`0>ooooo`80003o2@3oP002
0?l000D0oh000P00o`020?n000D0003o1@3oP006003o00030000o`3oP000oh0000H0oh0000<0003o
003o0000o`001P00o`000`3oP000003o0000o`090?n000800?l00P3o00050?n00080003o0P00o`03
0?n00080003o2@3oP0020?l000800?l01@3oP0020?l00080oh000`3o00040?n000030?l0003oP000
oh0000L0oh00103o00050?n000@00?l06?ooool001Kooooo6`3o00020?n002h0o`000P3oP00M0?l0
0080oh001@3o00020?n000T0o`0000<0oh00003o0000o`000P3oP0020?l00080oh001@3o000>oooo
oad00?l00`3oP00?003o00030000o`00o`000?l000L00?l01P3oP0020000o`L00?l01`000?l20?n0
00030000o`00o`000?l000l00?l000<0oh00003o0000o`0010000?l9003o00<0003o0P00o`020?n0
00L00?l010000?l3003o0080oh003_oooolI003o00@0003o2@00o`070000o`800?l000<0003o003o
0000o`0010000?l<003o0080003o2@00o`050000o`800?l01P000?l00`00o`00003o0000o`0F0000
o`T00?l02P000?l2003o0080003o3_ooool20?n000<0o`00103oP005003o0080003o1`3oP004003o
0080003o1@3oP0050000o`800?l01P3oP00:003o00@0003o0P3oP0030000o`@0oh000P3o00070?n0
00<00?l00P3oP0020?l00080oh000P3o00000`3oP000o`000?l000040?n00080o`0000<0oh000?l0
003o00000P3oP0040?l000030?n0003o0000o`0000D0oh000P000?l=0?n00080003o00<0oh000000
o`000?l00P000?lHooooo`005_oooolF0?l000030?n0003o0000o`0003P0o`0000<0oh000?l0003o
00001P3o00000`3oP000o`000?l0000F0?l000030?n0003o0000o`0000L0o`00103oP0090?l000ko
oooo0P00o`020000o`03003o00000?l0003o00H00?l000<0003o003o0000o`002`00o`070?n001@0
0?l00`3oP002003o0080oh000P00o`050?n000D0003o0P00o`040000o`D00?l01`000?l20?n00080
003o0P3oP00<0000o`H00?l00`000?l2003o00T0003o0P3oP002003o00030?n00000o`000?l00080
0?l03_ooool70000o`800?l040000?l4003o00D0003o2`00o`020?n000D0003o1000o`000`000?l0
0?l0003o0004003o00D0003o1`00o`070000o`800?l02`000?l5003o0080oh009000o`0>ooooo`T0
oh000P000?l20?n000<0003o0P3oP005003o00@0003o1`00o`020?n000<0003o2@3oP002003o0080
003o0P00o`020000o`03003o003oP000oh000080o`000P3oP0030?l000H0oh001@3o00020000o`D0
oh000P3o00020?n000<0o`000P3oP0040?l000<0oh00203o00030?n000@00?l000<0oh000?l0003o
0000103o00030?n00080003o1`00o`040?n001Sooooo000FoooooaH0o`0000<0oh000?l0003o0000
>03o00000`3oP000o`000?l000060?l000030?n0003o0000o`0001H0o`0000<0oh000?l0003o0000
1`3o00040?n000T0o`003_ooool2003o0080003o00<00?l00000o`000?l01P00o`000`000?l00?l0
003o000;003o00L0oh005000o`030?n000800?l00P3oP002003o00D0oh001@000?l2003o00@0003o
1@00o`070000o`80oh000P000?l20?n000`0003o1P00o`030000o`800?l02@000?l20?n000800?l0
00<0oh00003o0000o`000P00o`0>ooooo`L0003o0P00o`0@0000o`@00?l01@000?l;003o0080oh00
1@000?l4003o00030000o`00o`000?l000@00?l01@000?l7003o00L0003o0P00o`0;0000o`D00?l0
0P3oP00T003o00kooooo2@3oP0020000o`80oh000`000?l20?n000D00?l010000?l7003o0080oh00
0`000?l90?n000800?l00P000?l2003o0080003o00<00?l00?n0003oP0000P3o00020?n000<0o`00
1P3oP0050?l00080003o1@3oP0020?l00080oh000`3o00020?n000@0o`000`3oP0080?l000<0oh00
1000o`000`3oP000o`000?l000040?l000<0oh000P000?l7003o00@0oh006?ooool001Kooooo4P3o
00020?n000<0o`000P3oP0020?l00080oh00403o00020?n000X0o`000P3oP0020?l00080oh005@3o
00020?n002H0o`0000<0oh000?l0003o00002`3o000>ooooo`800?l00P3oP00B003o00L0003o00<0
0?l00?n0003oP0001000o`050000o`800?l01@000?l20?n000@00?l00`000?l20?l000@0oh000`00
0?l20?n000@00?l000<0oh000?l0003o00000P00o`020?n000<00?l00P000?l;003o00@0oh001`00
0?l5003o0080003o0`00o`080000o`03003o00000?l0003o0080oh001000o`000`3oP000003o0000
o`020000o`kooooo1@00o`020?n000d0003o2@00o`000`000?l00?l0003o0004003o0080003o2@00
o`000`000?l00?l0003o0007003o00@0003o3P00o`090000o`800?l00P000?l<003o00P0oh0000<0
0?l00000o`000?l01@000?l4003o0080003o1`00o`090000o`kooooo1`3oP0020000o`@0oh0000<0
0?l00?n0003oP0000P000?l20?n000<0003o2@00o`020?n000D00?l00P3o00040?n00080o`0000<0
oh000?l0003o00000P000?l20?n000D0003o1P3oP0030?l00080oh000P3o00000`3oP000o`000?l0
00060?l000<0oh001P3o00050?n000800?l00`3oP0060?l000<0oh000P000?l20?n00080003o00<0
o`000?n0003oP000103o00030?n000800?l00P000?l70?n00080o`006?ooool001Kooooo4P3o0002
0?n000<0o`000P3oP0020?l00080oh00403o00020?n000X0o`000P3oP0020?l00080oh005@3o0002
0?n002H0o`0000<0oh000?l0003o00002`3o000>ooooo`800?l00P3oP00B003o00L0003o00<00?l0
0?n0003oP0001000o`050000o`800?l01@000?l20?n000@00?l00`000?l20?l000@0oh000`000?l2
0?n000@00?l000<0oh000?l0003o00000P00o`020?n000<00?l00P000?l;003o00@0oh001`000?l5
003o0080003o0`00o`080000o`03003o00000?l0003o0080oh001000o`000`3oP000003o0000o`02
0000o`kooooo1@00o`020?n000d0003o2@00o`000`000?l00?l0003o0004003o0080003o2@00o`00
0`000?l00?l0003o0007003o00@0003o3P00o`090000o`800?l00P000?l<003o00P0oh0000<00?l0
0000o`000?l01@000?l4003o0080003o1`00o`090000o`kooooo1`3oP0020000o`@0oh0000<00?l0
0?n0003oP0000P000?l20?n000<0003o2@00o`020?n000D00?l00P3o00040?n00080o`0000<0oh00
0?l0003o00000P000?l20?n000D0003o1P3oP0030?l00080oh000P3o00000`3oP000o`000?l00006
0?l000<0oh001P3o00050?n000800?l00`3oP0060?l000<0oh000P000?l20?n00080003o00<0o`00
0?n0003oP000103o00030?n000800?l00P000?l70?n00080o`006?ooool001Kooooo0P3oP0020?l0
00030?n0003o0000o`0001@0o`000P3oP00@0?l00080oh001`3o00020?n00280o`0000<0oh000?l0
003o00002@3o00020?n001D0o`000P3oP00;0?l000kooooo2`00o`050000o`/00?l02`000?l00`00
o`00003o0000o`07003o0080003o2@00o`060?n00003003o003oP000oh000080oh000P000?l90?n0
0003003o00000?l0003o00d00?l00P3oP003003o00@0oh000P00o`000`3oP0000?l0003o000;003o
00D0003o0P00o`020?n000L00?l03_ooool7003o0100003o0P00o`020000o`800?l01@000?l20?n0
00800?l000<0003o0?n0003oP00010000?l20?n000L00?l01@000?l9003o0080003o1`00o`040000
o`h00?l01@000?l2003o0080oh000P00o`020?n000<00?l010000?l5003o0080003o2@00o`070000
o`kooooo0P3oP0030000o`80oh0010000?l20?n000<0003o1P3oP0000`000?l00?l0003o0004003o
00D0003o1@00o`040?n000L0o`001P00o`000`000?l00?l0003o00040?n000<0o`00103oP0020?l0
00<0oh000P3o00020?n00080o`001`3oP0030?l000T0oh00103o00040?n000<0003o0P3oP0020000
o`L0o`002@3oP002003o00030?n0003o0000o`000080o`006?ooool001Kooooo0P3oP0020?l00003
0?n0003o0000o`0001@0o`000P3oP00@0?l00080oh001`3o00020?n00280o`0000<0oh000?l0003o
00002@3o00020?n001D0o`000P3oP00;0?l000kooooo2`00o`050000o`/00?l02`000?l00`00o`00
003o0000o`07003o0080003o2@00o`060?n00003003o003oP000oh000080oh000P000?l90?n00003
003o00000?l0003o00d00?l00P3oP003003o00@0oh000P00o`000`3oP0000?l0003o000;003o00D0
003o0P00o`020?n000L00?l03_ooool7003o0100003o0P00o`020000o`800?l01@000?l20?n00080
0?l000<0003o0?n0003oP00010000?l20?n000L00?l01@000?l9003o0080003o1`00o`040000o`h0
0?l01@000?l2003o0080oh000P00o`020?n000<00?l010000?l5003o0080003o2@00o`070000o`ko
oooo0P3oP0030000o`80oh0010000?l20?n000<0003o1P3oP0000`000?l00?l0003o0004003o00D0
003o1@00o`040?n000L0o`001P00o`000`000?l00?l0003o00040?n000<0o`00103oP0020?l000<0
oh000P3o00020?n00080o`001`3oP0030?l000T0oh00103o00040?n000<0003o0P3oP0020000o`L0
o`002@3oP002003o00030?n0003o0000o`000080o`006?ooool001Kooooo103oP00Y0?l00080oh00
1`3o00020?n002h0o`000P3oP0070?l00080oh00303o00020?n00080o`000P3oP0070?l000kooooo
0P000?l20?n000030000o`00o`000?l000800?l010000?l00`00o`00oh000?n0000;003o0080003o
5`00o`040000o`<00?l02@3oP0020000o`800?l01@3oP009003o0080oh000P00o`050000o`80oh00
3P00o`020000o`800?l00`000?l2003o0080003o0P00o`070000o`80oh0000<00?l00000o`000?l0
0P000?l>ooooo`D00?l00P3oP00B003o0080003o2@00o`030000o`80oh0010000?l2003o00030000
o`00o`000?l001000?l01P000?l5003o0100003o1`00o`020?n00080003o0P3oP0050000o`@0oh00
1@000?l;003o00D0003o0P00o`0>ooooo`@0oh000`00o`020?n00080003o1`3oP0020000o`800?l0
0`000?l2003o0080003o00<00?l00000o`000?l00P000?l20?n000<0003o1P3oP0030?l00080oh00
0P3o00020?n000<00?l0403oP0090?l000800?l01`3oP0020000o`H0oh0000<0o`000?n0003oP000
0P3o00020?n00080o`000`3oP0020000o`80oh000`000?l60?n000030?l0003oP000oh000080o`00
103oP0050?l001Sooooo000Fooooo`D0o`000P3oP0070?l00080oh007@3o00020?n003h0o`000P3o
P0040?l000030?n0003o0000o`0000L0o`000P3oP0070?l00080oh000P3o000>ooooo`80003o2@00
o`020000o`D00?l00P000?lR003o00<0003o0P3oP0020000o`@0oh000`00o`040000o`L0oh000P00
o`000`3oP000003o0000o`020000o`80oh002@000?l20?n000030000o`00o`000?l000@0oh000P00
o`000`3oP000003o0000o`040000o``00?l00P3oP009003o00kooooo0P00o`020000o`<00?l01000
0?l;003o00L0003o1`00o`050000o`@00?l00`000?l20?n000L0003o2@00o`040000o`800?l000<0
003o003o0000o`001P00o`000`000?l00?l0003o0007003o00P0003o00<0oh000000o`000?l02@00
0?l20?n00080003o4000o`070000o`kooooo1@3oP002003o00H0003o00<00?l00?n0003oP0000P3o
P002003o0080003o00<00?l00?l0003o00001`00o`020000o`800?l00P3oP0000`000?l0o`000?l0
00060?n000030?l0003oP000oh0000l0oh0000<0o`000?n0003oP000403oP004003o00D0oh000P00
o`020?n00080o`0000<0oh000?l0003o00001P3oP0000`00o`00oh000?n0000=0?n000D0o`000P3o
P0020?l000030?n0003o0000o`000080o`006?ooool001Kooooo1@3o00020?n000L0o`000P3oP00M
0?l00080oh00?P3o00020?n000@0o`0000<0oh000?l0003o00001`3o00020?n000L0o`000P3oP002
0?l000kooooo0P000?l9003o0080003o1@00o`020000ob800?l00`000?l20?n00080003o103oP003
003o00@0003o1`3oP002003o00030?n000000?l0003o0080003o0P3oP0090000o`80oh0000<0003o
003o0000o`00103oP002003o00030?n000000?l0003o00@0003o3000o`020?n000T00?l03_ooool2
003o0080003o0`00o`040000o`/00?l01`000?l7003o00D0003o1000o`030000o`80oh001`000?l9
003o00@0003o0P00o`000`000?l00?l0003o0006003o00030000o`00o`000?l000L00?l020000?l0
0`3oP000003o0000o`090000o`80oh000P000?l@003o00L0003o3_ooool50?n000800?l01P000?l0
0`00o`00oh000?n000020?n000800?l00P000?l00`00o`00o`000?l00007003o0080003o0P00o`02
0?n000030000o`3o0000o`0000H0oh0000<0o`000?n0003oP0003`3oP0000`3o0000oh000?n0000@
0?n000@00?l01@3oP002003o0080oh000P3o00000`3oP000o`000?l000060?n00003003o003oP000
oh0000d0oh001@3o00020?n00080o`0000<0oh000?l0003o00000P3o000Hooooo`005_ooool70?l0
0080oh00;@3o00020?n00140o`000P3oP00X0?l000030?n0003o0000o`0000L0o`000P3oP00;0?l0
00kooooo0P000?l20?n000030000o`00o`000?l000/00?l00P000?l@003o0080003o4`00o`060000
o`D0oh001000o`070?n00080003o3000o`020000o`/00?l00P000?l00`00o`00003o0000o`02003o
0080003o00<00?l00000o`000?l00P000?l2003o0080003o0`00o`020?l000D0oh001000o`0>oooo
o`D0003o0P3oP006003o00030000o`00o`000?l000800?l01@000?l4003o0080003o5@00o`020000
o`h00?l00P000?l5003o00P0003o4`00o`080000o`D00?l00P000?l00`00o`00003o0000o`060000
o`03003o00000?l0003o00H0003o0`00o`020000o`kooooo0P000?l30?n000@00?l00P000?l70?n0
00800?l00`3oP0040?l000800?l00`3oP002003o00h0oh000P3o00040?n000800?l000<0oh00003o
0000o`001000o`020?l000D0oh000P00o`050000o`T0oh0010000?l:0?n000P0o`002P3oP002003o
0080oh000P000?l90?n00003003o003oP000oh000080oh006?ooool001Kooooo1`3o00020?n002d0
o`000P3oP00A0?l00080oh00:03o00000`3oP000o`000?l000070?l00080oh002`3o000>ooooo`80
003o0P3oP0000`000?l00?l0003o000;003o0080003o4000o`020000oa<00?l01P000?l50?n000@0
0?l01`3oP0020000o``00?l00P000?l;003o0080003o00<00?l00000o`000?l00P00o`020000o`03
003o00000?l0003o0080003o0P00o`020000o`<00?l00P3o00050?n000@00?l03_ooool50000o`80
oh001P00o`000`000?l00?l0003o0002003o00D0003o1000o`020000oaD00?l00P000?l>003o0080
003o1@00o`080000oa<00?l020000?l5003o0080003o00<00?l00000o`000?l01P000?l00`00o`00
003o0000o`060000o`<00?l00P000?l>ooooo`80003o0`3oP004003o0080003o1`3oP002003o00<0
oh00103o0002003o00<0oh000P00o`0>0?n00080o`00103oP002003o00030?n00000o`000?l000@0
0?l00P3o00050?n000800?l01@000?l90?n000@0003o2P3oP0080?l000X0oh000P00o`020?n00080
003o2@3oP0000`00o`00oh000?n000020?n001Sooooo003oooooooooooooP_ooool00?oooooooooo
oon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`008_oooombo`00
02OoooooLOl0000Wooooog7o00009ooooomao`0002Cooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Go
oooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooooaKo0?l01?oooolGo`00o`Cooooo
5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolFool000Gooooo
5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01OoooolFo`00o`Gooooo
5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo
0005oooooaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l0
0?l5oooooaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`007ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooo
oaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000OoooooaOo003o7oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKo
ogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00
7ooooolGo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0
1OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooolGool000Cooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool001oooooo5ol00?lOooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaKo0?l01Ooo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Go
oooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023o
oooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo
5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKoogl01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o01go001o5_l0o`0Oo`00OaOoogl01?l007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o01go001o5_l0o`05o`00OaKo003o1Ol007lFoomo00Co001o00?o0000oooo
ooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l08?l007lFoomo00Co001o00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l07ooooolGoomo00Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00o`Gooooo5_ooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03
o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o01oooooo5oooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00o`Gooooo5_ooO`04ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o023ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o01oooooo5oooO`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?oooolFo`00oaoooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0MoooooaKo0?l08?oooolFoomo00Cooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l07ooooolGoomo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo5_l0o`0PoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`0OoooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lO
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000oooooooo
ool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo
0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol0
07lFool005Go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l0>_l0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o03So001o5_l00?lOo`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0Dol007lFoomo00Co001o00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Co
oooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`0jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000
ooooooooool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Coooo
oaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKo
o`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool0
8_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oo
oooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo
00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000o`00Ool007l00ol007lFool005Go
001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Go
oooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o05?o
001o5_ooO`04o`00O`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Cooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`000?oooooooooo02;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?ooool00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Cooooo00?o0000oooooooo
ool08_ooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`04ooooo`03o`00
0?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01?oo
ool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Rooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0R
ooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uoooo
o`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1]o`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0KOl007l00ol0003oooooooooo`0Roooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool002;ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08_ooool002;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`00
8_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool08_ooool002;oooooL_l0000Wooooog7o00009oooooma
o`0002OoooooLOl0000Tooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooo
oooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`005_ooool2
0?l00080003o4`3o00020000ocP0o`0000<0003o0?l0003o00002@3o00090000o`80o`001@000?lI
0?l000800?l00P3oP00>ooooo`@0oh001`00o`030?n000P00?l01@3oP003003o0080oh000P00o`04
0000oaD00?l00P3oP0050000o`80oh004000o`040?n00080003o0`00o`020000o`800?l00`3o0002
003o00@0oh001@00o`020?n000D00?l00P3oP002003o00L0oh000P00o`020000o`<0oh000P00o`0>
ooooo`80003o0`3oP004003o0080oh000P00o`030?n000800?l01@3oP0020?l000D0003o0P00o`04
0?l000D0oh002@000?l20?n000800?l00P3o00050?n00080003o0P00o`030000o`L0oh005P000?l5
003o0080003o1@3o0006003o00<0oh000P00o`020?n00080003o1`3o00020000o`030?n0003o0000
o`000080o`003_ooool20?n000800?l000<0oh00003o0000o`001000o`030?n000H00?l02@3oP000
0`00o`00oh000?n000020?n000800?l0303oP00;003o0080oh000P00o`030?n000800?l00P3oP002
003o00`0oh001000o`030?n00080o`000P3oP002003o00<0oh000P000?l=0?n00003003o003oP000
oh0000@0oh000`3o00020?n000800?l02@3oP00Hooooo`005_ooool20?l00080003o4`3o00020000
ocP0o`0000<0003o0?l0003o00002@3o00090000o`80o`001@000?lI0?l000800?l00P3oP00>oooo
o`@0oh001`00o`030?n000P00?l01@3oP003003o0080oh000P00o`040000oaD00?l00P3oP0050000
o`80oh004000o`040?n00080003o0`00o`020000o`800?l00`3o0002003o00@0oh001@00o`020?n0
00D00?l00P3oP002003o00L0oh000P00o`020000o`<0oh000P00o`0>ooooo`80003o0`3oP004003o
0080oh000P00o`030?n000800?l01@3oP0020?l000D0003o0P00o`040?l000D0oh002@000?l20?n0
00800?l00P3o00050?n00080003o0P00o`030000o`L0oh005P000?l5003o0080003o1@3o0006003o
00<0oh000P00o`020?n00080003o1`3o00020000o`030?n0003o0000o`000080o`003_ooool20?n0
00800?l000<0oh00003o0000o`001000o`030?n000H00?l02@3oP0000`00o`00oh000?n000020?n0
00800?l0303oP00;003o0080oh000P00o`030?n000800?l00P3oP002003o00`0oh001000o`030?n0
0080o`000P3oP002003o00<0oh000P000?l=0?n00003003o003oP000oh0000@0oh000`3o00020?n0
00800?l02@3oP00Hooooo`005_oooolG0?l00080003o1@3o0002003o00H0o`0000<0003o0?l0003o
00009P3o00020000o`030?l000000?l0003o00T0o`0040000?lI0?l00080003o0P3oP00>ooooo`D0
oh001P00o`030?n001000?l00P3oP004003o0080oh0000<00?l00?n0003oP0004P00o`020?n000D0
003o0P3oP005003o00@0oh001`00o`040?n000<00?l00P3oP0020000o`800?l00`3o00060?n000<0
0?l01`3oP002003o00H0oh0000<00?l00?n0003oP0000P3oP005003o0080oh000P00o`0>ooooo`80
oh000P000?l00`3oP0000?l0003o0002003o00@0oh0000<0o`000?n0003oP0000P00o`020000o`80
oh0000<00?l00?n0003oP0000P3oP002003o00030000o`00o`000?l000@0o`000P00o`030?n000H0
003o0`3oP002003o00/0oh000P00o`030000o`L0o`000P000?l40?l00100003o0P00o`000`3o0000
oh000?n000040000o`D00?l00P000?l2003o00030?n00000o`000?l000800?l00P3oP0050000o`H0
o`0000<00?l00?l0003o00000P3o000>ooooo`80oh000P00o`000`3oP0000?l0003o0002003o00D0
oh000P00o`0=0?n00003003o003oP000oh000080oh001000o`070?n000800?l00`3oP007003o00@0
oh000P00o`030?n000800?l00P3oP003003o00@0oh000P00o`050?n000@00?l01`3oP002003o00L0
oh00103o00030?n000800?l02@3oP0020?l000h0oh006?ooool001Kooooo5`3o00020000o`D0o`00
0P00o`060?l000030000o`3o0000o`0002H0o`000P000?l00`3o0000003o0000o`090?l00100003o
6@3o00020000o`80oh003_ooool50?n000H00?l00`3oP00@003o0080oh001000o`020?n00003003o
003oP000oh0001800?l00P3oP0050000o`80oh001@00o`040?n000L00?l0103oP003003o0080oh00
0P000?l2003o00<0o`001P3oP003003o00L0oh000P00o`060?n00003003o003oP000oh000080oh00
1@00o`020?n000800?l03_ooool20?n00080003o00<0oh00003o0000o`000P00o`040?n000030?l0
003oP000oh0000800?l00P000?l20?n00003003o003oP000oh000080oh000P00o`000`000?l00?l0
003o00040?l000800?l00`3oP0060000o`<0oh000P00o`0;0?n000800?l00`000?l70?l00080003o
103o000@0000o`800?l000<0o`000?n0003oP00010000?l5003o0080003o0P00o`000`3oP0000?l0
003o0002003o0080oh001@000?l60?l00003003o003o0000o`000080o`003_ooool20?n000800?l0
00<0oh00003o0000o`000P00o`050?n000800?l03@3oP0000`00o`00oh000?n000020?n000@00?l0
1`3oP002003o00<0oh001`00o`040?n000800?l00`3oP002003o0080oh000`00o`040?n000800?l0
1@3oP004003o00L0oh000P00o`070?n000@0o`000`3oP002003o00T0oh000P3o000>0?n001Sooooo
000Fooooo`80oh003P3o00020000oa@0o`0000<0003o0?l0003o00009P3o00020000o`030?l00000
0?l0003o00T0o`003@000?l20?l000<0003o1`3o00040000o``0o`000P00o`020?l000kooooo103o
P007003o0080oh002@00o`000`3oP0000?l0003o0005003o0080oh001000o`020?n00003003o003o
P000oh0000d00?l00`3oP002003o0080003o0P00o`020000o`03003o003oP000oh000080oh000`00
o`060?n000D00?l0103oP002003o00<0oh000P000?l4003o00030?l00000o`000?l000@0oh000`00
o`040?n000800?l02@3oP0000`00o`00oh000?n000040?n000<00?l00P3oP002003o00kooooo0P3o
P0020000o`030?l0003oP000oh0000H0oh0000<0o`000000o`000?l00P3oP0020000o`80oh0000<0
0?l00?l0003o00000P000?l2003o00D0003o0P3o0002003o00<0oh001`00o`0;0?n00080o`000P00
0?l20?l00003003o00000?l0003o00L0o`000P00o`020000o`80o`001`000?l20?n000X0003o0P3o
P002003o0080oh000P00o`030?n00080003o1`00o`070000o`@0o`000P00o`000`3oP0000?l0003o
0002003o00kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP003003o0080oh000P00
o`030?n000800?l0103oP0000`00o`00oh000?n000020?n000@00?l04P3oP003003o0080oh001000
o`000`3oP0000?l0003o00020?n000<00?l01P3oP002003o00<0oh001000o`070?n000800?l01`3o
P0040?l000h0oh000P3o00050?n000800?l01@3oP002003o01Sooooo000Fooooo`@0003o=`3o0002
003o02@0o`003P000?l20?l000800?l000<0o`000?n0003oP00010000?l2003o00h0o`003_ooool4
0?n000<00?l00P3oP002003o0080oh001@00o`070?n000D00?l00P3oP004003o0080oh0000<00?l0
0?n0003oP0003@00o`050?n00080003o0P00o`020000o`03003o00000?l0003o0080oh000P00o`03
0?n000@0003o0P00o`000`000?l00?l0003o00040?n00080003o00<00?l00?n0003oP0000P000?l2
003o00D0003o103oP003003o00@0oh000P00o`0>0?n00080o`000P000?l30?n000800?l03_ooool2
0?n00080003o1@3oP002003o0080oh0000<0o`000000o`000?l00P3o0002003o0080oh0000<00?l0
0?n0003oP0001000o`070000o`800?l000<0003o0?n0003oP0000P3oP0020000o`80oh0000<00?l0
0?n0003oP0000P3oP002003o00<0oh000P00o`040000o`80oh0000<0o`000000o`000?l01@3o0004
003o0080003o0P3o00070000o`80oh0030000?l2003o0080003o0P00o`000`3o0000003o0000o`02
0000o`800?l000<0oh00003o0000o`000P00o`090000o`80o`000P000?l00`3oP000o`000?l00002
003o00kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP007003o00<0oh000P00o`05
0?n000800?l00P3oP004003o00030?n00000o`000?l001@0oh000P00o`030?n000T00?l0103oP002
003o00<0oh001000o`070?n000800?l01`3oP0040?l000<0oh001000o`070?n000<0o`003@3oP00H
ooooo`005_ooool40000ocL0o`000P00o`0T0?l000h0003o0P3o0002003o00030?l0003oP000oh00
00@0003o0P00o`0>0?l000kooooo103oP003003o0080oh000P00o`020?n000D00?l01`3oP005003o
0080oh001000o`020?n00003003o003oP000oh0000d00?l01@3oP0020000o`800?l00P000?l00`00
o`00003o0000o`020?n000800?l00`3oP0040000o`800?l000<0003o003o0000o`00103oP0020000
o`03003o003oP000oh000080003o0P00o`050000o`@0oh000`00o`040?n000800?l03P3oP0020?l0
0080003o0`3oP002003o00kooooo0P3oP0020000o`D0oh000P00o`020?n000030?l000000?l0003o
0080o`000P00o`020?n00003003o003oP000oh0000@00?l01`000?l2003o00030000o`3oP000oh00
0080oh000P000?l20?n00003003o003oP000oh000080oh000P00o`030?n000800?l010000?l20?n0
00030?l000000?l0003o00D0o`001000o`020000o`80o`001`000?l20?n000`0003o0P00o`020000
o`800?l000<0o`000000o`000?l00P000?l2003o00030?n00000o`000?l000800?l02@000?l20?l0
0080003o00<0oh000?l0003o00000P00o`0>ooooo`80oh000P00o`000`3oP0000?l0003o0004003o
0080oh001`00o`030?n000800?l01@3oP002003o0080oh001000o`000`3oP0000?l0003o000D0?n0
00800?l00`3oP009003o00@0oh000P00o`030?n000@00?l01`3oP002003o00L0oh00103o00030?n0
00@00?l01`3oP0030?l000d0oh006?ooool001Kooooo0P000?l>0?l000@0003o9`3o0002003o00D0
o`000P000?l50?l000800?l0103o00020000oa80o`002@000?l00`3o0000003o0000o`020000o`80
0?l000<0o`000?n0003oP000103o0002003o00030?l000000?l0003o00@0o`000P3oP0000`3o0000
0?l0003o00020?l000kooooo0P00o`030?n000800?l00P3oP002003o0080oh001@00o`090?n000<0
0?l00P3oP004003o0080oh0000<00?l00?n0003oP0003@00o`050?n00080o`001`000?l20?n00080
0?l000<0oh000000o`000?l00P000?l2003o00<0003o0P00o`040?n00080003o00<00?l00000o`00
0?l00P000?l4003o00<0003o0P00o`020?n000<00?l01P000?l30?n000@00?l02@3oP0020000o`<0
oh000P00o`0>oooooa00oh000P3o00020000o`<00?l00P3oP004003o00h0003o1@00o`040?n00080
0?l00`3oP002003o00@0003o0P00o`000`000?l0o`000?l000050?l000@00?l00P3oP0020?l000L0
003o0P3oP00<0000o`800?l00P000?l2003o00030?l000000?l0003o0080003o0P3o00000`3oP000
0?l0003o0002003o0080003o0P00o`0:0000o`80oh000P00o`0>ooooo`@00?l01@3oP002003o0080
oh000`00o`020?n000800?l00`3oP002003o00D0oh000P00o`020?n000L00?l07@3oP002003o0003
0?n00000o`000?l000/0oh000P00o`070?n000800?l04`3oP002003o00/0oh000P00o`020?n00003
003o003oP000oh000080oh006?ooool001Kooooo0P000?l>0?l000@0003o9`3o0002003o00D0o`00
0P000?l50?l000800?l0103o00020000oa80o`002@000?l00`3o0000003o0000o`020000o`800?l0
00<0o`000?n0003oP000103o0002003o00030?l000000?l0003o00@0o`000P3oP0000`3o00000?l0
003o00020?l000kooooo0P00o`030?n000800?l00P3oP002003o0080oh001@00o`090?n000<00?l0
0P3oP004003o0080oh0000<00?l00?n0003oP0003@00o`050?n00080o`001`000?l20?n000800?l0
00<0oh000000o`000?l00P000?l2003o00<0003o0P00o`040?n00080003o00<00?l00000o`000?l0
0P000?l4003o00<0003o0P00o`020?n000<00?l01P000?l30?n000@00?l02@3oP0020000o`<0oh00
0P00o`0>oooooa00oh000P3o00020000o`<00?l00P3oP004003o00h0003o1@00o`040?n000800?l0
0`3oP002003o00@0003o0P00o`000`000?l0o`000?l000050?l000@00?l00P3oP0020?l000L0003o
0P3oP00<0000o`800?l00P000?l2003o00030?l000000?l0003o0080003o0P3o00000`3oP0000?l0
003o0002003o0080003o0P00o`0:0000o`80oh000P00o`0>ooooo`@00?l01@3oP002003o0080oh00
0`00o`020?n000800?l00`3oP002003o00D0oh000P00o`020?n000L00?l07@3oP002003o00030?n0
0000o`000?l000/0oh000P00o`070?n000800?l04`3oP002003o00/0oh000P00o`020?n00003003o
003oP000oh000080oh006?ooool001Kooooo0P3o00020000o``0o`000P000?mA0?l000<0003o103o
00020000o`030?l000000?l0003o0080003o0`3o00020?n000@0o`001@000?l20?l000800?l00P3o
P0000`3o00000?l0003o00020?l000kooooo0P00o`030?n000H00?l00P3oP005003o00/0oh0000<0
0?l00?n0003oP0001000o`020?n001000?l01@3oP0020?l000L0003o0P3oP003003o0080o`000P00
0?l2003o00<0003o0P00o`020?n000@0003o00<0o`000000o`000?l00P000?l5003o0080003o0P00
o`020?n000<00?l01P000?l90?n00003003o003oP000oh0000@0oh000P00o`030?n000800?l03_oo
ool50?n000800?l0103oP002003o00030?n000000?l0003o0080o`000P000?l5003o0080003o0`3o
000?0000o`80o`0000<00?l00?n0003oP0000P3oP002003o0080oh0000<0o`00003o0000o`001000
0?l2003o00030000o`3o0000o`000080o`001@00o`040?n00080o`0000<00?l00000o`000?l00P3o
000@0000o`800?l00P000?l2003o00030?l00000o`000?l00080003o0P00o`030?n000H00?l000<0
003o003o0000o`000P000?l2003o00<0003o0P3o0002003o00kooooo0P00o`030?n000800?l00P3o
P002003o0080oh000`00o`020?n000L00?l01@3oP00;003o0100oh000P00o`020?n000@00?l000<0
oh00003o0000o`000P3oP002003o00030?n00000o`000?l00100oh000P00o`0I0?n00080o`000P00
0?l70?n000800?l01`3oP00Hooooo`005_ooool20?l00080003o303o00020000oe40o`000`000?l4
0?l00080003o00<0o`000000o`000?l00P000?l30?l00080oh00103o00050000o`80o`000P00o`02
0?n000030?l00000o`000?l00080o`003_ooool2003o00<0oh001P00o`020?n000D00?l02`3oP000
0`00o`00oh000?n00004003o0080oh004000o`050?n00080o`001`000?l20?n000<00?l00P3o0002
0000o`800?l00`000?l2003o0080oh0010000?l00`3o0000003o0000o`020000o`D00?l00P000?l2
003o0080oh000`00o`060000o`T0oh0000<00?l00?n0003oP000103oP002003o00<0oh000P00o`0>
ooooo`D0oh000P00o`040?n000800?l000<0oh000000o`000?l00P3o00020000o`D00?l00P000?l3
0?l000l0003o0P3o00000`00o`00oh000?n000020?n000800?l00P3oP0000`3o00000?l0003o0004
0000o`800?l000<0003o0?l0003o00000P3o0005003o00@0oh000P3o00000`00o`00003o0000o`02
0?l00100003o0P00o`020000o`800?l000<0o`00003o0000o`000P000?l2003o00<0oh001P00o`00
0`000?l00?l0003o00020000o`800?l00`000?l20?l000800?l03_ooool2003o00<0oh000P00o`02
0?n000800?l00P3oP003003o0080oh001`00o`050?n000/00?l0403oP002003o0080oh001000o`00
0`3oP0000?l0003o00020?n000800?l000<0oh00003o0000o`00403oP002003o01T0oh000P3o0002
0000o`L0oh000P00o`070?n001Sooooo000Fooooo`80o`000P000?l:0?l00080003o2@3o00020?n0
03H0o`0000<0003o0?l0003o0000403o00020000o`@0o`001`000?l<0?l00080003o1`3o0002003o
0080o`003_ooool50?n000H00?l00P3oP009003o00030?n00000o`000?l000@0oh0000<00?l00?n0
003oP0001000o`020?n001800?l01@3oP0050000o`@0oh000P00o`000`3oP000o`000?l000020000
o`800?l01@000?l20?n000@0003o00<0o`000000o`000?l00P00o`070000o`@0oh000`00o`060000
o`T0oh0000<00?l00?n0003oP0002@00o`020?n000kooooo0P000?l70?n000@00?l000<0oh000000
o`000?l00P3o00020000o`<00?l01P3oP00:0000o`800?l010000?l2003o00030000o`3oP000oh00
0080oh001000o`000`3o0000003o0000o`020000o`80o`001`000?l3003o0080003o0P3o00020?n0
0080o`000`00o`020?l00080003o0P3o00000`00o`00003o0000o`060000o`<0o`000P00o`020000
o`800?l01@000?l2003o00D0oh001000o`050?n000D0003o0P3o0002003o00kooooo0P00o`0;0?n0
00<00?l01P3oP0000`00o`00oh000?n000050?n000800?l0103oP002003o00030?n00000o`000?l0
00H0oh0000<00?l00?n0003oP0002`3oP00;003o00030?n00000o`000?l000l0oh0000<00?l00?n0
003oP0000P3oP002003o0200oh000P00o`030?n000800?l00P3oP00Hooooo`005_ooool20?l00080
003o2P3o00020000oaH0o`0000<0003o0?l0003o00000P000?li0?l00080003o103o00050000o`80
oh005`3o00020?n000kooooo1@3oP006003o0080oh002@00o`000`3oP0000?l0003o00020?n000<0
0?l00P3oP004003o0080oh0000<00?l00?n0003oP0003`00o`000`3oP0000?l0003o00020?n000D0
003o103oP0020000o`030?n0003o0000o`0000T0003o0P3oP0040000o`030?l000000?l0003o00H0
003o00<00?l00000o`000?l00P00o`040?n00003003o00000?l0003o00@0003o00<0oh00003o0000
o`000P00o`070?n000@00?l00P000?l3003o0080oh003_ooool20?n000D00?l01`3oP0020000o`80
oh000P000?l3003o00@0oh000P3o00090000o`<00?l00P3oP004003o00D0oh001000o`000`3o0000
003o0000o`020000o`80o`001`000?l20?l00003003o00000?l0003o00H0oh0000<00?l00000o`00
0?l01P000?l00`00o`00003o0000o`060000o`030?l000000?l0003o00800?l00P000?l20?l00003
003o003o0000o`000080003o0P00o`070?n000800?l01@3oP0050000o`80o`000P000?l>ooooo`80
0?l00`3oP002003o00@0oh000P00o`000`3oP0000?l0003o00060?n000<00?l03P3oP002003o00T0
oh000P00o`040?n000<00?l00P3oP002003o0080oh000`00o`020?n000800?l0403oP003003o00@0
oh000P00o`050?n000800?l03P3oP0020000o`800?l00P3oP0000`00o`00oh000?n0000;0?n001So
oooo000Fooooo`80o`000P000?l:0?l00080003o5P3o00000`000?l0o`000?l000020000ocT0o`00
0P000?l40?l000D0003o0P3oP00G0?l00080oh003_ooool50?n000H00?l00P3oP009003o00030?n0
0000o`000?l00080oh000`00o`020?n000@00?l00P3oP0000`00o`00oh000?n0000?003o00030?n0
0000o`000?l00080oh001@000?l40?n00080003o00<0oh000?l0003o00002@000?l20?n000@0003o
00<0o`000000o`000?l01P000?l00`00o`00003o0000o`02003o00@0oh0000<00?l00000o`000?l0
10000?l00`3oP0000?l0003o0002003o00L0oh001000o`020000o`<00?l00P3oP00>ooooo`80oh00
1@00o`070?n00080003o0P3oP0020000o`<00?l0103oP0020?l000T0003o0`00o`020?n000@00?l0
1@3oP004003o00030?l000000?l0003o0080003o0P3o00070000o`80o`0000<00?l00000o`000?l0
1P3oP0000`00o`00003o0000o`060000o`03003o00000?l0003o00H0003o00<0o`000000o`000?l0
0P00o`020000o`80o`0000<00?l00?l0003o00000P000?l2003o00L0oh000P00o`050?n000D0003o
0P3o00020000o`kooooo0P00o`030?n000800?l0103oP002003o00030?n00000o`000?l000H0oh00
0`00o`0>0?n000800?l02@3oP002003o00@0oh000`00o`020?n000800?l00P3oP003003o0080oh00
0P00o`0@0?n000<00?l0103oP002003o00D0oh000P00o`0>0?n00080003o0P00o`020?n00003003o
003oP000oh0000/0oh006?ooool001Kooooo0P3oP0020000o`030?l000000?l0003o00L0o`000P00
0?lG0?l000@0003o<P3o00020000o`/0o`001@000?l20?n001T0o`003_ooool20?n000800?l000<0
oh00003o0000o`001000o`020?n000T00?l01@3oP003003o0080oh001000o`020?n00003003o003o
P000oh000080oh003P00o`040?n000D0003o103oP0020000o`030?n000000?l0003o00T0003o0P3o
00040000o`03003o00000?l0003o0080003o0P00o`020000o`D00?l0103oP0000`00o`00oh000?n0
00020?n000800?l000<0oh00003o0000o`001000o`020?n00003003o003oP000oh000080oh000P00
o`020000o`030?l00000o`000?l000800?l03_ooool20?n000L00?l0103oP003003o0080oh000P00
o`070?n00080o`000`00o`060000o`T00?l00`3oP006003o00030?l000000?l0003o0080003o0P3o
00070000o`80oh0000<00?l00?n0003oP0000P000?l2003o0080oh0000<00?l00000o`000?l00P3o
000@0000o`800?l010000?l00`00o`00o`000?l000020000o`<00?l01P3oP0020000o`030?n00000
0?l0003o0080oh0010000?l00`00o`00003o0000o`020000o`kooooo0P00o`0<0?n000800?l0103o
P003003o01H0oh000`00o`020?n000@00?l00P3oP0000`00o`00oh000?n00004003o00<0oh000P00
o`020?n000800?l0303oP002003o0080oh000P00o`050?n000800?l01@3oP002003o00L0oh000P00
0?l70?n000800?l00P3oP0000`00o`00oh000?n0000;0?n001Sooooo000Fooooo`80oh000P000?l0
0`3o0000003o0000o`070?l00080003o5`3o00040000oc80o`000P000?l;0?l000D0003o0P3oP00I
0?l000kooooo0P3oP002003o00030?n00000o`000?l000@00?l00P3oP009003o00D0oh000`00o`02
0?n000@00?l00P3oP0000`00o`00oh000?n000020?n000h00?l0103oP0050000o`@0oh000P000?l0
0`3oP000003o0000o`090000o`80o`0010000?l00`00o`00003o0000o`020000o`800?l00P000?l5
003o00@0oh0000<00?l00?n0003oP0000P3oP002003o00030?n00000o`000?l000@00?l00P3oP000
0`00o`00oh000?n000020?n000800?l00P000?l00`3o00000?l0003o0002003o00kooooo0P3oP007
003o00@0oh000`00o`020?n000800?l01`3oP0020?l000<00?l01P000?l9003o00<0oh001P00o`00
0`3o0000003o0000o`020000o`80o`001`000?l20?n00003003o003oP000oh000080003o0P00o`02
0?n00003003o00000?l0003o0080o`0040000?l2003o00@0003o00<00?l00?l0003o00000P000?l3
003o00H0oh000P000?l00`3oP000003o0000o`020?n000@0003o00<00?l00000o`000?l00P000?l>
ooooo`800?l0303oP002003o00@0oh000`00o`0F0?n000<00?l00P3oP004003o0080oh0000<00?l0
0?n0003oP0001000o`030?n000800?l00P3oP002003o00`0oh000P00o`020?n000800?l01@3oP002
003o00D0oh000P00o`070?n00080003o1`3oP002003o0080oh0000<00?l00?n0003oP0002`3oP00H
ooooo`005_ooool20?l00080003o00<0o`000000o`000?l0103o00020000o`<0o`000P000?lk0?l0
0080003o5@3o00020000o`@0o`001@000?l50?l00080003o103o0002003o00L0o`000`00o`020?n0
0080o`003_ooool4003o00030?n00000o`000?l000@00?l00`3oP008003o00030?n00000o`000?l0
0080oh000`00o`040?n000800?l00P3oP003003o0080oh001@00o`020?n000800?l0103oP0000`00
o`00oh000?n000020?n000800?l00`000?l40?n00080003o00<0oh000000o`000?l02@000?l20?l0
00800?l00P000?l50?n000800?l00P000?l5003o00@0oh001`00o`000`3oP0000?l0003o0004003o
0080003o00<00?l00000o`000?l00P000?l2003o0080003o00<0o`000?n0003oP0000P00o`0>oooo
o`80oh001@00o`060?n00003003o003oP000oh0000H0oh000`00o`020?n00080o`0000<00?l00000
o`000?l0103o00050000o`80oh001000o`030?n000H00?l00`3oP00;0000o`80o`0000<00?l00000
o`000?l00P000?l5003o01@0003o0P00o`040000o`030?l000000?l0003o0080003o0`00o`060?n0
0080003o00<0oh000000o`000?l00P3oP0040000o`030?n000000?l0003o0080003o3_ooool2003o
00`0oh000P00o`060?n00003003o003oP000oh0000@0oh000`00o`0?0?n00003003o003oP000oh00
00@00?l00P3oP0000`00o`00oh000?n00004003o0080oh002000o`040?n000@00?l00`3oP006003o
00`0oh000P00o`050?n000800?l02@3oP002003o00T0oh000P00o`050?n001Sooooo000Fooooo`80
o`000P000?l00`3o0000003o0000o`040?l00080003o0`3o00020000oc/0o`000P000?lE0?l00080
003o103o00050000o`D0o`000P000?l40?l000800?l01`3o0003003o0080oh000P3o000>ooooo`@0
0?l000<0oh00003o0000o`001000o`030?n000P00?l000<0oh00003o0000o`000P3oP003003o00@0
oh000P00o`020?n000<00?l00P3oP005003o0080oh000P00o`040?n00003003o003oP000oh000080
oh000P00o`030000o`@0oh000P000?l00`3oP000003o0000o`090000o`80o`000P00o`020000o`D0
oh000P00o`020000o`D00?l0103oP007003o00030?n00000o`000?l000@00?l00P000?l00`00o`00
003o0000o`020000o`800?l00P000?l00`3o0000oh000?n00002003o00kooooo0P3oP005003o00H0
oh0000<00?l00?n0003oP0001P3oP003003o0080oh000P3o00000`00o`00003o0000o`040?l000D0
003o0P3oP004003o00<0oh001P00o`030?n000/0003o0P3o00000`00o`00003o0000o`020000o`D0
0?l050000?l2003o00@0003o00<0o`000000o`000?l00P000?l3003o00H0oh000P000?l00`3oP000
003o0000o`020?n000@0003o00<0oh000000o`000?l00P000?l>ooooo`800?l0303oP002003o00H0
oh0000<00?l00?n0003oP000103oP003003o00l0oh0000<00?l00?n0003oP0001000o`020?n00003
003o003oP000oh0000@00?l00P3oP008003o00@0oh001000o`030?n000H00?l0303oP002003o00D0
oh000P00o`090?n000800?l02@3oP002003o00D0oh006?ooool001Kooooo0P3oP0020000o`030?l0
00000?l0003o00L0o`0010000?l20?l00080003o303o0002003o0280o`000P000?l00`3o0000003o
0000o`090000o`H0o`0000<0003o0?l0003o00001`3o00020000o`d0o`0000<0003o0?l0003o0000
0P000?l20?l000800?l01`3o0003003o00@0o`003_ooool20?n000800?l000<0oh00003o0000o`00
1000o`020?n001400?l00P3oP004003o0080oh000`00o`020?n000D00?l00P3oP002003o0080oh00
1@00o`020?n000@00?l000<0003o0?n0003oP0000P3oP0020000o`030?n000000?l0003o00L0003o
0P3oP0020000o`800?l00P000?l50?n000800?l00P000?l7003o0080oh003P00o`020000o`03003o
00000?l0003o00H0003o0`3oP002003o00kooooo0P00o`020?n000<00?l0103oP002003o00030?n0
003o0000o`0000L0oh000P00o`040?n000<0003o0P00o`040?l000030000o`3oP000oh000080o`00
0P00o`050?n000H00?l00`3oP0020000o`800?l00`000?l40?l00080003o0`3o00020000o`@00?l0
00<0oh000000o`000?l04P000?l2003o00@0003o00<0o`00003o0000o`0010000?l00`00o`00oh00
0?n000020?n000800?l00P000?l00`3oP000o`000?l000020?l000@0003o00<0oh000?l0003o0000
0P000?l>ooooo`800?l0303oP004003o00@0oh0000<00?l00?n0003oP0000P00o`020?n000<00?l0
0P3oP002003o0080oh0000<00?l00?n0003oP0001P3oP0000`00o`00oh000?n000060?n00003003o
003oP000oh0000L0oh000P00o`070?n000H00?l00`3oP004003o01T0oh000`00o`040?n000@00?l0
00<0oh00003o0000o`000P00o`020?n000800?l00`3oP002003o01Sooooo000Fooooo`80oh000P00
0?l00`3o0000003o0000o`070?l000@0003o0P3o00020000o``0o`000P00o`0R0?l00080003o00<0
o`000000o`000?l02@000?l60?l000030000o`3o0000o`0000L0o`000P000?l=0?l000030000o`3o
0000o`000080003o0P3o0002003o00L0o`000`00o`040?l000kooooo0P3oP002003o00030?n00000
o`000?l000@00?l00P3oP00A003o0080oh001000o`020?n000<00?l00P3oP005003o0080oh000P00
o`020?n000D00?l00P3oP004003o00030000o`3oP000oh000080oh000P000?l00`3oP000003o0000
o`070000o`80oh000P000?l2003o0080003o1@3oP002003o0080003o1`00o`020?n000h00?l00P00
0?l00`00o`00003o0000o`060000o`<0oh000P00o`0>ooooo`800?l00P3oP003003o00@0oh000P00
o`000`3oP000o`000?l000070?n000800?l0103oP0030000o`800?l0103o00000`000?l0oh000?n0
00020?l000800?l01@3oP006003o00<0oh000P000?l2003o00<0003o103o00020000o`<0o`000P00
0?l4003o00030?n000000?l0003o0180003o0P00o`040000o`030?l00000o`000?l000@0003o00<0
0?l00?n0003oP0000P3oP002003o0080003o00<0oh000?l0003o00000P3o00040000o`030?n0003o
0000o`000080003o3_ooool2003o00`0oh001000o`040?n00003003o003oP000oh0000800?l00P3o
P003003o0080oh000P00o`020?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0001P3o
P0000`00o`00oh000?n000070?n000800?l01`3oP006003o00<0oh001000o`0I0?n000<00?l0103o
P004003o00030?n00000o`000?l000800?l00P3oP002003o00<0oh000P00o`0Hooooo`005_ooool2
0?l00080003o303o00020000oa00o`000P00o`0R0?l00080003o0`3o00060000o`D0o`000P000?l3
0?l000@0003o103o00030000oad0o`000`00o`040?l000kooooo0P3oP002003o00030?n00000o`00
0?l000@00?l00P3oP00A003o0080oh001000o`020?n000<00?l00P3oP00@003o0080oh000P00o`03
0000o`@0oh000P000?l00`3oP000003o0000o`070000o`80oh000P000?l>0?n000T00?l00P000?l9
003o0080oh000P000?l00`00o`00003o0000o`020?l000D0003o0P3oP002003o00kooooo0P00o`02
0?n000<00?l0103oP002003o00X0oh000P00o`040?n000<0003o1P3o00000`000?l0oh000?n00002
0?l000@00?l00`3oP0020000o`800?l00P3o00000`00o`00o`000?l000020?l000@00?l000<0o`00
0000o`000?l010000?l00`3oP000o`000?l000020000o`800?l00P000?l00`00o`00o`000?l0000B
0000o`800?l01@3oP002003o00@0003o0`00o`070?n000P0003o0`3oP0020000o`kooooo0P00o`0<
0?n000800?l01P3oP0000`00o`00oh000?n000040?n00003003o003oP000oh0000800?l00P3oP003
003o00T0oh000P00o`060?n00003003o003oP000oh0000L0oh000P00o`020?n000<00?l0103oP002
003o00<0oh000P00o`020?n000800?l00P3oP0000`000?l0oh000?n0000D0?n000800?l000<0oh00
003o0000o`00103oP002003o00<0oh000P00o`020?n000800?l00`3oP002003o01Sooooo000Foooo
o`80oh000P000?lB0?l000030000o`3o0000o`000100o`000P000?lR0?l00080003o1`3o00020000
o`D0o`000P000?l40?l000<0003o0P3o00020000oaL0o`001`00o`020?l000kooooo2`00o`020?n0
01400?l00P3oP009003o0080oh004000o`020000o`800?l00`000?l90?n000H0003o00<0o`000?n0
003oP0000P3o0002003o00`0oh002@00o`020000o`/00?l00`3oP0090000o`@0oh003_ooool2003o
0080oh000`00o`040?n000800?l0403oP0000`3o0000003o0000o`020?l000@0003o00<00?l00?l0
003o00000P3oP0020000o`800?l00`3oP0040000o`D0o`000P00o`020?l000800?l000<0o`000000
o`000?l01@000?l20?l00080003o0P00o`030000o`80o`000P000?l20?l00080003o00<00?l00000
o`000?l01`000?l20?l00080oh000P3o00020000o`030?l0003oP000oh0000800?l00P000?l00`00
o`00oh000?n000020?n000800?l00`3oP0080000o`<0oh000P000?l>ooooo`800?l01@3oP0020?l0
00D0oh001000o`040?n00003003o003oP000oh0000800?l00P3oP003003o00@0oh000`00o`040?n0
00800?l00P3oP0000`00o`00oh000?n000060?n00003003o003oP000oh0000@0oh000P00o`000`3o
P0000?l0003o00020?n000800?l02P3oP006003o00T0oh000P000?l>0?n000800?l000<0oh00003o
0000o`00103oP002003o00<0oh000P00o`070?n000800?l06?ooool001Kooooo0P3oP0020000oa80
o`0000<0003o0?l0003o0000403o00020000ob80o`000P000?l70?l00080003o1@3o00020000o`@0
o`000`000?l20?l00080003o5`3o0007003o0080o`003_ooool;003o0080oh004@00o`020?n000T0
0?l00P3oP00@003o0080003o0P00o`030000o`T0oh001P000?l00`3o0000oh000?n000020?l00080
0?l0303oP009003o0080003o2`00o`030?n000T0003o103oP00>ooooo`800?l00P3oP003003o00@0
oh000P00o`0@0?n000030?l000000?l0003o0080o`0010000?l00`00o`00o`000?l000020?n00080
003o0P00o`030?n000@0003o1@3o0002003o0080o`000P00o`000`3o0000003o0000o`050000o`80
o`000P000?l2003o00<0003o0P3o00020000o`80o`000P000?l00`00o`00003o0000o`070000o`80
o`000P3oP0020?l00080003o00<0o`000?n0003oP0000P00o`020000o`03003o003oP000oh000080
oh000P00o`030?n000P0003o0`3oP0020000o`kooooo0P00o`050?n00080o`001@3oP004003o00@0
oh0000<00?l00?n0003oP0000P00o`020?n000<00?l0103oP003003o00@0oh000P00o`020?n00003
003o003oP000oh0000H0oh0000<00?l00?n0003oP000103oP002003o00030?n00000o`000?l00080
oh000P00o`0:0?n000H00?l02@3oP0020000o`h0oh000P00o`000`3oP0000?l0003o00040?n00080
0?l00`3oP002003o00L0oh000P00o`0Hooooo`005_ooool20?l000800?l0303o00020000oa00o`00
0P000?l50?l00080003o8P3o00020000o`/0o`0000<0003o0?l0003o00000P000?l50?l00080003o
0P3o00020000o`X0o`000P000?l;0?l000L00?l00P3o000>ooooo`/00?l00P3oP00^003o00L0003o
0P00o`020?n000800?l000<0oh00003o0000o`0010000?l20?l000D0003o0P00o`030?n00080003o
1`3oP008003o00D0oh002`00o`000`3oP000003o0000o`060000o`03003o003oP000oh000080oh00
3_ooool2003o00L0oh001000o`0@0?n000030000o`00o`000?l000@0o`000P000?l00`00o`00oh00
0?n000070000o`80oh000P000?l20?l00080003o0`3o00020?n000`0003o0P00o`0@0000o`800?l0
1P000?l00`3oP000o`000?l00002003o0080o`000P000?l00`3oP0000?l0003o0005003o0080oh00
1000o`020?n00003003o00000?l0003o00H0003o0`3oP0020000o`kooooo1000o`0:0?n000@00?l0
103oP0000`00o`00oh000?n00005003o00@0oh001@00o`020?n000@00?l00`3oP002003o00H0oh00
00<00?l00?n0003oP000103oP002003o00030?n00000o`000?l00080oh000P00o`030?n000800?l0
1@3oP004003o00L0oh000P00o`020?n00080003o1`3oP003003o0080oh000P00o`030?n000@00?l0
0P3oP002003o00h0oh006?ooool001Kooooo0P3o0002003o00`0o`000P000?l@0?l00080003o1@3o
00020000ob80o`000P000?l;0?l000030000o`3o0000o`000080003o1@3o00020000o`80o`000P00
0?l:0?l00080003o2`3o0007003o0080o`003_ooool;003o0080oh00;P00o`070000o`800?l00P3o
P002003o00030?n00000o`000?l000@0003o0P3o00050000o`800?l00`3oP0020000o`L0oh002000
o`050?n000/00?l000<0oh000000o`000?l01P000?l00`00o`00oh000?n000020?n000kooooo0P00
o`070?n000@00?l0403oP0000`000?l00?l0003o00040?l00080003o00<00?l00?n0003oP0001`00
0?l20?n00080003o0P3o00020000o`<0o`000P3oP00<0000o`800?l040000?l2003o00H0003o00<0
oh000?l0003o00000P00o`020?l00080003o00<0oh00003o0000o`001@00o`020?n000@00?l00P3o
P0000`00o`00003o0000o`060000o`<0oh000P000?l>ooooo`@00?l02P3oP004003o00@0oh0000<0
0?l00?n0003oP0001@00o`040?n000D00?l00P3oP004003o00<0oh000P00o`060?n00003003o003o
P000oh0000@0oh000P00o`000`3oP0000?l0003o00020?n000800?l00`3oP002003o00D0oh001000
o`070?n000800?l00P3oP0020000o`L0oh000`00o`020?n000800?l00`3oP004003o0080oh000P00
o`0>0?n001Sooooo000Fooooo`80o`000P000?l30?l000800?l01`3o0002003o0100o`000P3oP00;
0?l000030?n0003o0000o`0000@0o`000P00o`0R0?l00180003o203o00020000o`@0o`000`000?l8
0?l00003003o003o0000o`000080o`003_ooool;003o0080oh003P00o`020?n001`00?l00P3oP007
0000o`H00?l000<0003o003o0000o`001`000?l2003o0080003o0P3o00020000o`03003o003oP000
oh0000@00?l01@3oP006003o00030?n00000o`000?l000800?l00`3oP006003o00<0oh0020000?l0
0`00o`00oh000?n000020?n000kooooo0P00o`090?n00080o`001`3oP003003o00H0oh000`00o`02
0000o`80o`000P00o`070000o`80o`0000<0003o003o0000o`000P3oP0020000o`800?l000<0oh00
0?l0003o00000P3oP0020?l00080oh001@000?l20?l000<00?l02`000?l50?l000800?l00P3o0005
0000o`80o`001P000?l00`3oP0000?l0003o0005003o0080oh001`00o`020000o`80o`0010000?l3
0?l00080003o3_ooool2003o00/0oh000`00o`060?n00003003o003oP000oh000080oh000`00o`08
0?n00003003o003oP000oh0000L0oh000P00o`0@0?n000800?l01`3oP002003o00@0oh000`00o`0=
0?n00080003o1@3oP002003o00D0oh001000o`090?n00003003o003oP000oh000080oh000P00o`07
0?n001Sooooo000Fooooo`80o`000P000?l30?l000800?l01`3o0002003o0100o`000P3oP00;0?l0
00030?n0003o0000o`0000@0o`000P00o`0R0?l00180003o203o00020000o`@0o`000`000?l80?l0
0003003o003o0000o`000080o`003_ooool;003o0080oh003P00o`020?n001`00?l00P3oP0070000
o`H00?l000<0003o003o0000o`001`000?l2003o0080003o0P3o00020000o`03003o003oP000oh00
00@00?l01@3oP006003o00030?n00000o`000?l000800?l00`3oP006003o00<0oh0020000?l00`00
o`00oh000?n000020?n000kooooo0P00o`090?n00080o`001`3oP003003o00H0oh000`00o`020000
o`80o`000P00o`070000o`80o`0000<0003o003o0000o`000P3oP0020000o`800?l000<0oh000?l0
003o00000P3oP0020?l00080oh001@000?l20?l000<00?l02`000?l50?l000800?l00P3o00050000
o`80o`001P000?l00`3oP0000?l0003o0005003o0080oh001`00o`020000o`80o`0010000?l30?l0
0080003o3_ooool2003o00/0oh000`00o`060?n00003003o003oP000oh000080oh000`00o`080?n0
0003003o003oP000oh0000L0oh000P00o`0@0?n000800?l01`3oP002003o00@0oh000`00o`0=0?n0
0080003o1@3oP002003o00D0oh001000o`090?n00003003o003oP000oh000080oh000P00o`070?n0
01Sooooo000Fooooo`@0oh000`3o0002003o0080o`000P3oP0000`3o00000?l0003o0002003o00`0
o`000P3oP0020?l00080oh006@3o00020000oa/0o`001@000?l20?l000/0003o1`3o000:0000o`d0
o`003_ooool;003o0080oh00:@00o`050?n000L0003o1P00o`0:0000o`800?l01P000?l00`3o0000
003o0000o`04003o00T0oh000P00o`000`3oP0000?l0003o0002003o00<0oh002000o`000`3oP000
003o0000o`060000o`<00?l00P3oP00>ooooo`@00?l000<0003o0?n0003oP0000P3oP002003o0080
o`002@3oP0000`00o`00oh000?n000040?n000<0003o0P00o`020?n000/0003o0`00o`020?n000@0
0?l01@3oP0020?l000L0003o0`3o0002003o00@0o`001`000?l40?l00180003o00<0oh00003o0000
o`001`3oP006003o00030?n000000?l0003o0080o`0010000?l00`3o0000003o0000o`020?l000ko
oooo0P00o`030?n000800?l01P3oP0000`00o`00oh000?n000020?n000800?l00P3oP0000`00o`00
oh000?n000020?n000800?l000<0oh00003o0000o`001`3oP002003o0100oh000P00o`040?n00080
0?l000<0oh00003o0000o`002@3oP002003o00<0oh001000o`020?n000800?l02P3oP002003o00T0
oh000P00o`070?n00080o`001`3oP002003o00<0oh001000o`0Hooooo`005_ooool40?n000<0o`00
0P00o`020?l00080oh0000<0o`00003o0000o`000P00o`0<0?l00080oh000P3o00020?n001T0o`00
0P000?lK0?l000D0003o0P3o000;0000o`L0o`002P000?l=0?l000kooooo2`00o`020?n002T00?l0
1@3oP0070000o`H00?l02P000?l2003o00H0003o00<0o`000000o`000?l01000o`090?n000800?l0
00<0oh00003o0000o`000P00o`030?n000P00?l000<0oh000000o`000?l01P000?l3003o0080oh00
3_ooool4003o00030000o`3oP000oh000080oh000P00o`020?l000T0oh0000<00?l00?n0003oP000
103oP0030000o`800?l00P3oP00;0000o`<00?l00P3oP004003o00D0oh000P3o00070000o`<0o`00
0P00o`040?l000L0003o103o000B0000o`030?n00000o`000?l000L0oh001P00o`000`3oP000003o
0000o`020?l000@0003o00<0o`000000o`000?l00P3o000>ooooo`800?l00`3oP002003o00H0oh00
00<00?l00?n0003oP0000P3oP002003o0080oh0000<00?l00?n0003oP0000P3oP002003o00030?n0
0000o`000?l000L0oh000P00o`0@0?n000800?l0103oP002003o00030?n00000o`000?l000T0oh00
0P00o`030?n000@00?l00P3oP002003o00X0oh000P00o`090?n000800?l01`3oP0020?l000L0oh00
0P00o`030?n000@00?l06?ooool001Kooooo103oP0030?l00080oh000P3o00020?n000X0o`000P00
0?l90?l00080oh00=`3o00020000o`@0o`000`000?l20?l000H0003o203o00040000o`80o`000P00
0?l>0?l000kooooo2`00o`020?n002T00?l00P3oP0000`00o`00oh000?n000070000o`H00?l00`00
0?l20?l000D0003o0P00o`090000o`800?l00P3oP002003o00030?l000000?l0003o00@0oh000P00
o`000`3oP0000?l0003o0002003o00<0oh002000o`050?n000800?l00P3oP005003o00kooooo1000
o`000`3oP000003o0000o`04003o00<0003o103o00040?n00003003o003oP000oh000080oh000P3o
00030000o`@00?l01`000?l40?l000<00?l0103oP003003o0080oh000P00o`050000o`800?l00P00
0?l20?l000<00?l00P3oP0020?l00080oh002@000?l00`00o`00003o0000o`020?l000L0003o0P3o
00040000o`030?n00000o`000?l000@0oh0000<0003o0?n0003oP0001P00o`000`000?l0o`000?l0
00020000o`800?l00P3o00030000o`80oh003_ooool2003o0080oh000`00o`040?n000800?l01@3o
P002003o0080oh0000<00?l00?n0003oP0000P3oP002003o00X0oh000P00o`0=0?n000800?l000<0
oh00003o0000o`001P00o`000`3oP0000?l0003o00090?n000800?l00`3oP002003o00@0oh000P00
o`000`3oP0000?l0003o0002003o00d0oh0000<00?l00?n0003oP0002@3oP0020?l00080003o1`3o
P002003o00<0oh000P00o`0Hooooo`005_ooool20?l00080oh004`3o0002003o00L0o`000P000?l4
0?l000030000o`3o0000o`000080o`000P3oP00U0?l000800?l0103o00020000o`<0o`000P000?l2
0?l000T0003o303o00020000o`80o`000P000?l30?l000800?l02@3o000>ooooob000?l00P3oP00@
003o0080oh001@00o`020?n000H0003o00<00?l00?n0003oP0000P00o`050000o`80o`0010000?l3
003o0080o`0010000?l00`00o`00003o0000o`020000o`@00?l000<0oh000000o`000?l00P3o0002
0?n000800?l000<0oh000000o`000?l00P00o`030?n000H00?l00`3oP002003o00L0oh001000o`0>
ooooo`80oh000P00o`000`3oP000003o0000o`04003o00<0003o103oP002003o0080oh0000<0o`00
0?n0003oP000103o00000`00o`00003o0000o`020?l000800?l01`000?l40?l000<0003o2@3oP002
003o00L0o`000P000?l20?n000<00?l00P000?l70?n00080003o0P3oP0020000o`03003o003o0000
o`000080o`001`000?l20?l000D0003o0P00o`040000o`03003o003oP000oh0000800?l00P000?l2
003o00030000o`00o`000?l00080003o0P3o00020000o`03003o00000?l0003o0080003o3_ooool2
003o0080oh0000<00?l00?n0003oP0001`3oP002003o0080oh000P00o`020?n00003003o003oP000
oh0000@00?l000<0oh00003o0000o`001`3oP002003o00@0oh000P00o`0:0?n000800?l00P3oP002
003o00D0oh000P00o`020?n00003003o003oP000oh0000H0oh000`00o`020?n000@00?l000<0oh00
003o0000o`000P00o`0=0?n00003003o003oP000oh0000@0oh0000<00?l00?n0003oP000103oP002
003o00L0oh000P00o`050?n001Sooooo000Fooooo`80o`000P3oP00C0?l000800?l01`3o00020000
o`@0o`0000<0003o0?l0003o00000P3o00020?n002D0o`000P00o`040?l00080003o0`3o00020000
o`80o`002@000?l<0?l00080003o0P3o00020000o`<0o`000P00o`090?l000kooooo8000o`020?n0
01000?l00P3oP005003o0080oh001P000?l00`00o`00oh000?n00002003o00D0003o0P3o00040000
o`<00?l00P3o00040000o`03003o00000?l0003o0080003o1000o`000`3oP000003o0000o`020?l0
0080oh000P00o`000`3oP000003o0000o`02003o00<0oh001P00o`030?n000800?l01`3oP004003o
00kooooo0P3oP002003o00030?n000000?l0003o00@00?l00`000?l40?n000800?l00P3oP0000`3o
0000oh000?n000040?l00003003o00000?l0003o0080o`000P00o`070000o`@0o`000`000?l90?n0
00800?l01`3o00020000o`80oh000`00o`020000o`L0oh000P000?l20?n00080003o00<00?l00?l0
003o00000P3o00070000o`80o`001@000?l2003o00@0003o00<00?l00?n0003oP0000P00o`020000
o`800?l000<0003o003o0000o`000P000?l20?l00080003o00<00?l00000o`000?l00P000?l>oooo
o`800?l00P3oP0000`00o`00oh000?n000070?n000800?l00P3oP002003o0080oh0000<00?l00?n0
003oP0001000o`000`3oP0000?l0003o00070?n000800?l0103oP002003o00X0oh000P00o`020?n0
00800?l01@3oP002003o0080oh0000<00?l00?n0003oP0001P3oP003003o0080oh001000o`000`3o
P0000?l0003o0002003o00d0oh0000<00?l00?n0003oP000103oP0000`00o`00oh000?n000040?n0
00800?l01`3oP002003o00D0oh006?ooool001Kooooo1`3o00020?n001d0o`0000<0003o0?l0003o
00000P3o00020?n000`0o`000P3oP00R0?l00080003o103o00050000o`L0o`000P000?l90?l00080
003o2P3o00020?n00080o`003_oooolM003o00T0oh003000o`020000o`D00?l00P3oP0060000o`03
003o003oP000oh0000800?l01`000?l2003o0080o`000`00o`020?n000@0003o00<00?l00000o`00
0?l01P00o`030?n000800?l00P3oP002003o00030?n000000?l0003o00800?l00P000?l00`3oP000
0?l0003o0006003o00030?n00000o`000?l000800?l00P000?l50?n000800?l03_ooool20?n00080
0?l01@3oP002003o0080oh0000<0003o003o0000o`001P00o`000`000?l0oh000?n000040?l000D0
003o0P00o`0>0000o`L0oh000P3o00020?n000@0o`0000<0003o0?l0003o00000P000?l20?l000<0
0?l00P000?l2003o0080oh0000<0o`000?n0003oP000103oP0020000o`03003o003o0000o`0000/0
003o0P00o`030?l000800?l00P000?l3003o0080003o0P00o`040000o`030?l000000?l0003o0080
003o0P3o00070000o`kooooo1`3oP004003o00/0oh000`00o`070?n000800?l01@3oP002003o0080
oh001@00o`090?n000800?l00P3oP002003o00D0oh000P00o`020?n00003003o003oP000oh0000H0
oh0000<00?l00?n0003oP000103oP002003o00030?n00000o`000?l000800?l01@3oP004003o00@0
oh0000<00?l00?n0003oP000103oP0000`00o`00oh000?n000020?n00080o`000P00o`050?n00080
0?l00`3oP002003o0080oh006?ooool001Kooooo1`3o00020?n001d0o`0000<0003o0?l0003o0000
0P3o00020?n000`0o`000P3oP00R0?l00080003o103o00050000o`L0o`000P000?l90?l00080003o
2P3o00020?n00080o`003_oooolM003o00T0oh003000o`020000o`D00?l00P3oP0060000o`03003o
003oP000oh0000800?l01`000?l2003o0080o`000`00o`020?n000@0003o00<00?l00000o`000?l0
1P00o`030?n000800?l00P3oP002003o00030?n000000?l0003o00800?l00P000?l00`3oP0000?l0
003o0006003o00030?n00000o`000?l000800?l00P000?l50?n000800?l03_ooool20?n000800?l0
1@3oP002003o0080oh0000<0003o003o0000o`001P00o`000`000?l0oh000?n000040?l000D0003o
0P00o`0>0000o`L0oh000P3o00020?n000@0o`0000<0003o0?l0003o00000P000?l20?l000<00?l0
0P000?l2003o0080oh0000<0o`000?n0003oP000103oP0020000o`03003o003o0000o`0000/0003o
0P00o`030?l000800?l00P000?l3003o0080003o0P00o`040000o`030?l000000?l0003o0080003o
0P3o00070000o`kooooo1`3oP004003o00/0oh000`00o`070?n000800?l01@3oP002003o0080oh00
1@00o`090?n000800?l00P3oP002003o00D0oh000P00o`020?n00003003o003oP000oh0000H0oh00
00<00?l00?n0003oP000103oP002003o00030?n00000o`000?l000800?l01@3oP004003o00@0oh00
00<00?l00?n0003oP000103oP0000`00o`00oh000?n000020?n00080o`000P00o`050?n000800?l0
0`3oP002003o0080oh006?ooool001Kooooo=03o00040?n000030?l0003oP000oh0002P0o`001@00
0?lI0?l00080003o1`3o000>oooooad00?l02@3oP00<003o0080003o1@00o`020?n000@0003o0P00
o`000`000?l0oh000?n00002003o00T0003o0P3o0003003o00H0003o00<00?l00000o`000?l02@00
o`020?n000@00?l000<0oh000000o`000?l01000o`000`3oP0000?l0003o0006003o00030?n00000
o`000?l000800?l00P000?l50?n000800?l03_ooool90?n000800?l00P3oP0000`000?l00?l0003o
0002003o0080oh000`00o`020?n000800?l00P3o00050000o`800?l01`000?l20?n000D0003o0P3o
0002003o0080003o00<0oh000?l0003o00000P3oP0020000o`80o`001@000?l20?n000D0003o0P3o
00020?n000030?l0003oP000oh0000@0oh000P000?l00`00o`00003o0000o`090000o`80oh000P00
o`030?n000800?l01`000?l2003o00@0003o00<0o`000000o`000?l00P00o`090000o`kooooo0P3o
P002003o00<0oh001000o`030?n000800?l01P3oP003003o0080oh001`00o`050?n000800?l03@3o
P002003o00030?n00000o`000?l00080oh000P00o`0@0?n000<00?l0103oP004003o00030?n00000
o`000?l000800?l00P3oP003003o00P0oh0000<00?l00?n0003oP0002`3oP003003o00d0oh006?oo
ool001Kooooo=03o00040?n000030?l0003oP000oh0002P0o`001@000?lI0?l00080003o1`3o000>
oooooad00?l02@3oP00<003o0080003o1@00o`020?n000@0003o0P00o`000`000?l0oh000?n00002
003o00T0003o0P3o0003003o00H0003o00<00?l00000o`000?l02@00o`020?n000@00?l000<0oh00
0000o`000?l01000o`000`3oP0000?l0003o0006003o00030?n00000o`000?l000800?l00P000?l5
0?n000800?l03_ooool90?n000800?l00P3oP0000`000?l00?l0003o0002003o0080oh000`00o`02
0?n000800?l00P3o00050000o`800?l01`000?l20?n000D0003o0P3o0002003o0080003o00<0oh00
0?l0003o00000P3oP0020000o`80o`001@000?l20?n000D0003o0P3o00020?n000030?l0003oP000
oh0000@0oh000P000?l00`00o`00003o0000o`090000o`80oh000P00o`030?n000800?l01`000?l2
003o00@0003o00<0o`000000o`000?l00P00o`090000o`kooooo0P3oP002003o00<0oh001000o`03
0?n000800?l01P3oP003003o0080oh001`00o`050?n000800?l03@3oP002003o00030?n00000o`00
0?l00080oh000P00o`0@0?n000<00?l0103oP004003o00030?n00000o`000?l000800?l00P3oP003
003o00P0oh0000<00?l00?n0003oP0002`3oP003003o00d0oh006?ooool001Kooooo403o0002003o
04d0o`000P000?l30?l000P0003o703o0002003o00kooooo7@00o`050?n00080003o0P3oP00<003o
0080003o1@00o`020?n000L0003o103oP0020000o`03003o003o0000o`0000H0003o0`00o`090000
o`@0oh000`00o`040?n000@00?l000<0oh000000o`000?l01000o`030?n000/00?l00P000?l2003o
00<0oh000P00o`0>ooooo`D00?l0203oP0000`000?l0oh000?n00002003o0080oh000P00o`000`3o
P0000?l0003o0002003o00L0003o0P00o`030?l000800?l0103oP0050000o`80oh000P00o`020000
o`030?n000000?l0003o0080003o0P00o`020?l000X0003o103o0002003o00030000o`3oP000oh00
00800?l0103oP00<0000o`80oh000P00o`050?n000L0003o1000o`0;0000o`030?l000000?l0003o
0080003o3_ooool70?n000800?l03@3oP0000`00o`00oh000?n000020?n000L00?l0103oP003003o
00L0oh000P00o`040?n000800?l06@3oP0000`00o`00oh000?n000020?n000800?l01@3oP002003o
0080oh000P00o`000`3oP0000?l0003o000I0?n000800?l02@3oP00Hooooo`005_oooomF0?l00080
003o2@3o00030000o`80o`001P000?l<0?l000800?l02`3o00000`000?l0o`000?l00002003o00ko
oooo7@00o`030?n000@0003o3000o`080?n00003003o003oP000oh0000L0003o1P3oP0000`000?l0
o`000?l000040000o`80o`0000<0003o0?n0003oP0000P3oP0070000o`@0oh000P00o`000`3oP000
0?l0003o00020?n000@00?l000<0oh000000o`000?l01000o`030?n000800?l01@3oP0020000o`80
0?l00P000?l2003o00<0oh000P00o`0>ooooo`D00?l0203oP0000`000?l0oh000?n00002003o0080
oh000P00o`030?n000@00?l00`000?l20?l000@00?l000<0o`00003o0000o`00103oP0020000o`X0
0?l0103oP002003o00T0o`0000<0003o0?l0003o00002@000?l20?l00080003o0P00o`0>0000o`80
0?l00P3o0005003o00D0003o1P00o`090000o`030?l000000?l0003o0080003o3_ooool2003o00<0
oh001P00o`030?n000800?l01P3oP0000`00o`00oh000?n000020?n000800?l00`3oP002003o0080
oh001@00o`070?n000800?l01`3oP002003o00h0oh000P00o`040?n000<00?l01P3oP002003o00<0
oh000P00o`020?n000800?l000<0oh00003o0000o`003@3oP0000`000?l0oh000?n000090?n00080
0?l02@3oP00Hooooo`005_oooomF0?l00080003o2@3o00030000o`80o`001P000?l<0?l000800?l0
2`3o00000`000?l0o`000?l00002003o00kooooo7@00o`030?n000@0003o3000o`080?n00003003o
003oP000oh0000L0003o1P3oP0000`000?l0o`000?l000040000o`80o`0000<0003o0?n0003oP000
0P3oP0070000o`@0oh000P00o`000`3oP0000?l0003o00020?n000@00?l000<0oh000000o`000?l0
1000o`030?n000800?l01@3oP0020000o`800?l00P000?l2003o00<0oh000P00o`0>ooooo`D00?l0
203oP0000`000?l0oh000?n00002003o0080oh000P00o`030?n000@00?l00`000?l20?l000@00?l0
00<0o`00003o0000o`00103oP0020000o`X00?l0103oP002003o00T0o`0000<0003o0?l0003o0000
2@000?l20?l00080003o0P00o`0>0000o`800?l00P3o0005003o00D0003o1P00o`090000o`030?l0
00000?l0003o0080003o3_ooool2003o00<0oh001P00o`030?n000800?l01P3oP0000`00o`00oh00
0?n000020?n000800?l00`3oP002003o0080oh001@00o`070?n000800?l01`3oP002003o00h0oh00
0P00o`040?n000<00?l01P3oP002003o00<0oh000P00o`020?n000800?l000<0oh00003o0000o`00
3@3oP0000`000?l0oh000?n000090?n000800?l02@3oP00Hooooo`005_ooool20000o`<00?l00P3o
P0160?l00080003o1`3o00020000o`L0o`000P000?l50?l00080003o303o00020000o`l0o`0000<0
oh000?l0003o00000P00o`0>oooooaH00?l000<0oh00003o0000o`001000o`050?n00080003o0P00
o`000`3oP0000?l0003o0004003o0080oh0000<00?l00?n0003oP0001P3oP0000`00o`00oh000?n0
00070000o`H0oh0000<0003o0?l0003o000010000?l50?l00080oh001@000?l80?n000<00?l01P3o
P0000`00o`00003o0000o`04003o00<0oh000P00o`050?n00080003o0P3oP0020000o`L00?l03_oo
ool5003o00T0oh000P00o`020?n000@00?l0203oP0060000o`80oh000`3o0002003o00D0oh000P00
o`020?l000D00?l0103oP002003o00`0o`003@000?l2003o00L0003o0P00o`090000o`030?n00000
o`000?l000800?l00`000?l20?l000H00?l02@000?l00`3o00000?l0003o00020000o`kooooo1000
o`050?n000800?l02@3oP002003o00D0oh000`00o`060?n000<00?l04P3oP002003o00H0oh000`00
o`070?n000800?l02`3oP002003o00X0oh000P00o`060?n000<0o`001@3oP0020?l000T0oh000P00
o`020?n000800?l000<0oh000?l0003o00000P3oP00Hooooo`005_ooool20000o`<00?l00P3oP016
0?l00080003o1`3o00020000o`L0o`000P000?l50?l00080003o303o00020000o`l0o`0000<0oh00
0?l0003o00000P00o`0>oooooaH00?l000<0oh00003o0000o`001000o`050?n00080003o0P00o`00
0`3oP0000?l0003o0004003o0080oh0000<00?l00?n0003oP0001P3oP0000`00o`00oh000?n00007
0000o`H0oh0000<0003o0?l0003o000010000?l50?l00080oh001@000?l80?n000<00?l01P3oP000
0`00o`00003o0000o`04003o00<0oh000P00o`050?n00080003o0P3oP0020000o`L00?l03_ooool5
003o00T0oh000P00o`020?n000@00?l0203oP0060000o`80oh000`3o0002003o00D0oh000P00o`02
0?l000D00?l0103oP002003o00`0o`003@000?l2003o00L0003o0P00o`090000o`030?n00000o`00
0?l000800?l00`000?l20?l000H00?l02@000?l00`3o00000?l0003o00020000o`kooooo1000o`05
0?n000800?l02@3oP002003o00D0oh000`00o`060?n000<00?l04P3oP002003o00H0oh000`00o`07
0?n000800?l02`3oP002003o00X0oh000P00o`060?n000<0o`001@3oP0020?l000T0oh000P00o`02
0?n000800?l000<0oh000?l0003o00000P3oP00Hooooo`005_ooool20000o`80oh0000<00?l00?n0
003oP0001`3o0002003o04l0o`000P000?l50?l00080003o103o00000`000?l0o`000?l0000D0?l0
00<0oh0010000?l>oooooad00?l01`3oP002003o00030?n00000o`000?l000T0oh001000o`020?n0
00<00?l00P000?l2003o00<0003o1`3oP0020?l000L0003o0P3oP002003o00@0003o2@3oP009003o
00030?n00000o`000?l000@00?l00`3oP004003o00<0oh001P000?l5003o0080oh003_ooool20000
o`80oh0000<00?l00?n0003oP000103oP002003o00D0oh001000o`0:0?n00080003o0P00o`020?n0
00<0o`001P00o`000`3oP0000?l0003o0004003o0080oh0000<00?l00?n0003oP0000P000?l2003o
0080003o00<0o`00003o0000o`000P3o00020000o`03003o00000?l0003o00d0003o0P00o`070000
o`800?l02@000?l30?n00080o`000P3oP0000`000?l0o`000?l000020000o`@00?l02@000?l3003o
0080003o3_ooool20?n000800?l01@3oP002003o00<0oh000P00o`060?n00003003o003oP000oh00
00@0oh0000<00?l00?n0003oP000103oP003003o0080oh001000o`0@0?n000800?l00`3oP002003o
00L0oh000P00o`070?n000800?l0103oP0000`00o`00oh000?n0000;0?n00080o`002@3oP0030?l0
00@0oh000P00o`030?n000800?l00P3oP002003o00030?n0003o0000o`000080oh006?ooool001Ko
oooo0P000?l20?n00003003o003oP000oh0000L0o`000P00o`1?0?l00080003o1@3o00020000o`@0
o`0000<0003o0?l0003o0000503o00030?n000@0003o3_oooolM003o00L0oh000P00o`000`3oP000
0?l0003o00090?n000@00?l00P3oP003003o0080003o0P00o`030000o`L0oh000P3o00070000o`80
oh000P00o`040000o`T0oh002@00o`000`3oP0000?l0003o0004003o00<0oh001000o`030?n000H0
003o1@00o`020?n000kooooo0P000?l20?n00003003o003oP000oh0000@0oh000P00o`050?n000@0
0?l02P3oP0020000o`800?l00P3oP0030?l000H00?l000<0oh00003o0000o`001000o`020?n00003
003o003oP000oh000080003o0P00o`020000o`030?l00000o`000?l00080o`000P000?l00`00o`00
003o0000o`0=0000o`800?l01`000?l2003o00T0003o0`3oP0020?l00080oh0000<0003o0?l0003o
00000P000?l4003o00T0003o0`00o`020000o`kooooo0P3oP002003o00D0oh000P00o`030?n00080
0?l01P3oP0000`00o`00oh000?n000040?n00003003o003oP000oh0000@0oh000`00o`020?n000@0
0?l0403oP002003o00<0oh000P00o`070?n000800?l01`3oP002003o00@0oh0000<00?l00?n0003o
P0002`3oP0020?l000T0oh000`3o00040?n000800?l00`3oP002003o0080oh000P00o`000`3oP000
o`000?l000020?n001Sooooo000Fooooo`@0o`0000<00?l00?l0003o0000:`3o00040?n00080o`00
00<00?l00?l0003o0000903o00020000o`D0o`0010000?l20?l000030000o`3o0000o`0001@0o`00
0`3oP0040000o`kooooo7@00o`000`3oP0000?l0003o0002003o0080oh000P00o`000`3oP0000?l0
003o000;0?n000D00?l00P3oP0020000o`80o`000P000?l50?n000D00?l01P000?l30?n00080003o
0P00o`020000o`<0oh000P00o`040?n000T00?l00`3oP002003o00D0oh001000o`020?n000<0003o
0P00o`020000o`D00?l00P3oP00>ooooo`80003o0P3oP003003o00T0oh000P3o00020?n000<00?l0
2@3oP0020000o`800?l00P3o00030000o`800?l00P3oP002003o00030?n00000o`000?l00080o`00
0P00o`020000o`<0oh000P000?l2003o00T0003o00<00?l00000o`000?l03@000?l20?l00003003o
003oP000oh0000@0003o0P00o`090000o`030?n00000o`000?l000@0o`0000<0003o0?l0003o0000
0P000?l4003o00030?n000000?l0003o00H0003o0`00o`020000o`kooooo0P3oP003003o00T0oh00
0P00o`0=0?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0001000o`050?n000800?l0
103oP0000`00o`00oh000?n000020?n000800?l00P3oP003003o00d0oh0000<0003o0?n0003oP000
0P000?l40?n00003003o003oP000oh0000/0oh000P3o00020000o`L0oh0000<00?l00?l0003o0000
103oP002003o00L0oh000P00o`050?n001Sooooo000Fooooo`@0o`0000<00?l00?l0003o0000:`3o
00040?n00080o`0000<00?l00?l0003o0000903o00020000o`D0o`0010000?l20?l000030000o`3o
0000o`0001@0o`000`3oP0040000o`kooooo7@00o`000`3oP0000?l0003o0002003o0080oh000P00
o`000`3oP0000?l0003o000;0?n000D00?l00P3oP0020000o`80o`000P000?l50?n000D00?l01P00
0?l30?n00080003o0P00o`020000o`<0oh000P00o`040?n000T00?l00`3oP002003o00D0oh001000
o`020?n000<0003o0P00o`020000o`D00?l00P3oP00>ooooo`80003o0P3oP003003o00T0oh000P3o
00020?n000<00?l02@3oP0020000o`800?l00P3o00030000o`800?l00P3oP002003o00030?n00000
o`000?l00080o`000P00o`020000o`<0oh000P000?l2003o00T0003o00<00?l00000o`000?l03@00
0?l20?l00003003o003oP000oh0000@0003o0P00o`090000o`030?n00000o`000?l000@0o`0000<0
003o0?l0003o00000P000?l4003o00030?n000000?l0003o00H0003o0`00o`020000o`kooooo0P3o
P003003o00T0oh000P00o`0=0?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0001000
o`050?n000800?l0103oP0000`00o`00oh000?n000020?n000800?l00P3oP003003o00d0oh0000<0
003o0?n0003oP0000P000?l40?n00003003o003oP000oh0000/0oh000P3o00020000o`L0oh0000<0
0?l00?l0003o0000103oP002003o00L0oh000P00o`050?n001Sooooo000Fooooo`80oh005`3o0002
0000oaD0o`00103oP00_0?l000030000o`3o0000o`000080o`000P000?lE0?l00080003o0P00o`03
0?n00080003o0P3o000>oooooa/00?l00`3oP004003o0080oh000P00o`000`3oP0000?l0003o0007
0?n000800?l00P3oP005003o00P0003o0`00o`040?n00003003o00000?l0003o00L0003o0P3oP002
0000o`@00?l000<0o`000000o`000?l01000o`050?n000H00?l01@3oP009003o0080oh0000<0o`00
0000o`000?l01000o`030?n000800?l00P3oP00>ooooo`@0o`000`00o`090?n00080o`000P000?l3
003o00@0oh000P00o`000`3oP0000?l0003o00040000o`800?l01@000?l20?n000800?l00`3oP006
0000o`<0oh000P000?l2003o00T0003o00<00?l00000o`000?l03@000?l20?l000030000o`00o`00
0?l000@0003o0P00o`030000o`80o`001`00o`020?n00080o`001@000?l4003o00<0oh000P000?l2
0?n000L0003o3_ooool40?n00003003o003oP000oh0000@0oh000P00o`030?n000800?l02`3oP003
003o0080oh001`00o`020?n000800?l01@3oP002003o00D0oh000P00o`070?n000800?l03P3oP002
0?l000H0oh0000<00?l00?n0003oP0005`3oP0020000o`800?l00P3oP002003o00<0oh001000o`03
0?n000800?l00P3o000Hooooo`005_ooool40?n002h0o`000P3oP00K0?l000800?l0303o00040000
o`<0o`000P000?lP0?l00080003o0P3o000>oooooad00?l000<0oh00003o0000o`000P3oP004003o
00030?n00000o`000?l000L0oh000P00o`020?n000800?l00P000?l00`00o`00003o0000o`060000
o`03003o003oP000oh0000800?l00P3oP0000`00o`00003o0000o`070000o`@0oh001@00o`020000
o`H00?l000<0oh00003o0000o`000P00o`020?n000800?l01`3oP0000`00o`00oh000?n000040?n0
00800?l01`3o00020?n00003003o003oP000oh0000800?l03_ooool20000o`<00?l00P000?l;0?n0
00D00?l00P3oP002003o0080oh0000<0003o003o0000o`002`000?l4003o00<0oh001P000?l30?n0
0080003o0P00o`030000o`800?l010000?l00`00o`00003o0000o`060000o`03003o00000?l0003o
00L0003o1000o`020000o`<00?l0203oP003003o0080oh001@000?l20?l000D0003o0P3oP0020?l0
0080oh000P3o00050000o`kooooo0P3oP003003o00@0oh001@00o`020?n000800?l0103oP0000`00
o`00oh000?n0000;0?n000D00?l00P3oP002003o0080oh001@00o`050?n000800?l05`3oP0020000
o`800?l02@3oP002003o0080oh0000<0o`000?n0003oP0004P3oP004003o00<0oh000P00o`020?n0
00800?l000<0oh000?l0003o00000P3oP00Hooooo`005_ooool40?n002h0o`000P3oP00K0?l00080
0?l0303o00040000o`<0o`000P000?lP0?l00080003o0P3o000>oooooad00?l000<0oh00003o0000
o`000P3oP004003o00030?n00000o`000?l000L0oh000P00o`020?n000800?l00P000?l00`00o`00
003o0000o`060000o`03003o003oP000oh0000800?l00P3oP0000`00o`00003o0000o`070000o`@0
oh001@00o`020000o`H00?l000<0oh00003o0000o`000P00o`020?n000800?l01`3oP0000`00o`00
oh000?n000040?n000800?l01`3o00020?n00003003o003oP000oh0000800?l03_ooool20000o`<0
0?l00P000?l;0?n000D00?l00P3oP002003o0080oh0000<0003o003o0000o`002`000?l4003o00<0
oh001P000?l30?n00080003o0P00o`030000o`800?l010000?l00`00o`00003o0000o`060000o`03
003o00000?l0003o00L0003o1000o`020000o`<00?l0203oP003003o0080oh001@000?l20?l000D0
003o0P3oP0020?l00080oh000P3o00050000o`kooooo0P3oP003003o00@0oh001@00o`020?n00080
0?l0103oP0000`00o`00oh000?n0000;0?n000D00?l00P3oP002003o0080oh001@00o`050?n00080
0?l05`3oP0020000o`800?l02@3oP002003o0080oh0000<0o`000?n0003oP0004P3oP004003o00<0
oh000P00o`020?n000800?l000<0oh000?l0003o00000P3oP00Hooooo`005_ooool20?n00080003o
A`3o00020000o`80o`000P00o`0C0?l00080003o103o00020000oah0o`003_oooolK003o00<0oh00
2`00o`040?n000800?l000<0oh00003o0000o`001P3oP0000`00o`00003o0000o`060000o`<0oh00
3@000?l50?n000@00?l00`000?l6003o00030?n00000o`000?l000@0oh000P00o`000`3oP0000?l0
003o0002003o0080003o2@3oP0050?l00080003o1@3oP002003o00kooooo0P000?l3003o00P0oh00
0`00o`020?n000800?l01@3oP002003o0080oh0000<0003o003o0000o`000P00o`050000o`80oh00
0P000?l50?l00080oh0010000?l2003o00L0oh000P3o00000`00o`00o`000?l000040000o`03003o
00000?l0003o00H0003o00<00?l00000o`000?l01`000?l4003o0080003o0`00o`020000o`H0oh00
1@00o`0<0000o`800?l00P3o00090000o`kooooo103oP0000`00o`00oh000?n000020000o`800?l0
0P3oP0000`00o`00oh000?n000020?n000@00?l01@3oP002003o00030?n00000o`000?l000@0oh00
0P00o`050?n000800?l00P3oP0000`00o`00oh000?n00002003o00@0oh000`00o`0K0?n000800?l0
1`3oP002003o00D0oh000P00o`040?n00003003o003oP000oh0000T0oh001000o`050?n000800?l0
1@3oP002003o01Sooooo000Fooooo`80oh000P000?m70?l00080003o0P3o0002003o01<0o`000P00
0?l40?l00080003o7P3o000>oooooa/00?l00`3oP00;003o00@0oh000P00o`000`3oP0000?l0003o
00060?n00003003o00000?l0003o00H0003o0`3oP00=0000o`D0oh001000o`030000o`H00?l000<0
oh00003o0000o`00103oP002003o00030?n00000o`000?l000800?l00P000?l90?n000D0o`000P00
0?l50?n000800?l03_ooool20000o`<00?l0203oP003003o0080oh000P00o`050?n000800?l00P3o
P0000`000?l00?l0003o0002003o00D0003o0P3oP0020000o`D0o`000P3oP0040000o`800?l01`3o
P0020?l00003003o003o0000o`0000@0003o00<00?l00000o`000?l01P000?l00`00o`00003o0000
o`070000o`@00?l00P000?l3003o0080003o1P3oP005003o00`0003o0P00o`020?l000T0003o3_oo
ool40?n00003003o003oP000oh000080003o0P00o`020?n00003003o003oP000oh000080oh001000
o`050?n000800?l000<0oh00003o0000o`00103oP002003o00D0oh000P00o`020?n00003003o003o
P000oh0000800?l0103oP003003o01/0oh000P00o`070?n000800?l01@3oP002003o00@0oh0000<0
0?l00?n0003oP0002@3oP004003o00D0oh000P00o`050?n000800?l06?ooool001Kooooo10000?l/
0?l00080oh00<P3o00020000o`H0o`0000<0003o0?l0003o00006`3o000>oooooa800?l00P3oP007
003o00<0oh002`00o`040?n000800?l02@3oP0000`00o`00oh000?n000070000o`@0oh000P000?l0
0`00o`00003o0000o`060000o`<0oh001P00o`000`3oP000003o0000o`02003o0080oh000`000?l2
003o00@0oh000P00o`000`3oP0000?l0003o0004003o00X0oh000P3o00060?n00003003o003oP000
oh0000800?l03_ooool20000o`800?l00`3oP0020000o`800?l00P3oP0000`00o`00oh000?n00007
0?n00080003o0P00o`020?n00003003o003oP000oh0000@00?l00P000?l00`00o`00oh000?n00004
0?l000T0003o0P00o`000`000?l0oh000?n000020?n000800?l00P3o00000`00o`00003o0000o`02
0000o`80oh002@000?l00`00o`00003o0000o`070000o`800?l00P000?l4003o00030?n0003o0000
o`0000800?l0103oP005003o0080003o00<0o`000000o`000?l02@000?l20?l000T0003o3_ooool2
0?n000<00?l04P3oP002003o0080oh000P00o`000`3oP0000?l0003o00040?n000800?l00`3oP004
003o00D0oh000P00o`040?n000<00?l04P3oP002003o00D0oh001000o`050?n000@00?l02`3oP000
0`00o`00oh000?n00002003o00D0oh001P00o`050?n000@00?l000<0oh00003o0000o`000P00o`0H
ooooo`005_ooool40000ob`0o`000P3oP00b0?l00080003o1P3o00000`000?l0o`000?l0000K0?l0
00kooooo4P00o`020?n000L00?l00`3oP00;003o00@0oh000P00o`090?n00003003o003oP000oh00
00L0003o103oP0020000o`03003o00000?l0003o00H0003o0`3oP006003o00030?n000000?l0003o
00800?l00P3oP0030000o`800?l0103oP002003o00030?n00000o`000?l000@00?l02P3oP0020?l0
00H0oh0000<00?l00?n0003oP0000P00o`0>ooooo`80003o0P00o`030?n00080003o0P00o`020?n0
0003003o003oP000oh0000L0oh000P000?l2003o0080oh0000<00?l00?n0003oP0001000o`020000
o`03003o003oP000oh0000@0o`002@000?l2003o00030000o`3oP000oh000080oh000P00o`020?l0
0003003o00000?l0003o0080003o0P3oP0090000o`03003o00000?l0003o00L0003o0P00o`020000
o`@00?l000<0oh000?l0003o00000P00o`040?n000D00?l00P000?l00`3o0000003o0000o`090000
o`80o`002@000?l>ooooo`80oh000`00o`0B0?n000800?l00P3oP002003o00030?n00000o`000?l0
00@0oh000P00o`030?n000@00?l01@3oP002003o00@0oh000`00o`0B0?n000800?l01@3oP004003o
00D0oh001000o`0;0?n00003003o003oP000oh0000800?l01@3oP006003o00D0oh001000o`000`3o
P0000?l0003o0002003o01Sooooo000Fooooo`@0003o=@3o0002003o02H0o`000P000?l90?l00003
0000o`3o0000o`000180o`000P00o`020?n000D0o`003_oooolK003o0080oh001`00o`020?n000X0
0?l0203oP0000`00o`00oh000?n000090000o`80oh000P000?l00`00o`00003o0000o`060000o`03
003o003oP000oh0000H0oh001@00o`020?n000D00?l0103oP002003o00030?n00000o`000?l000@0
0?l02@3oP0000`00o`00003o0000o`020?n00080003o1@00o`020?n000kooooo1`3oP0020000o`D0
0?l02@3oP0020000o`800?l00P3oP00:003o0080003o0P3o000;0000o`D00?l0103oP00<0000o`80
0?l010000?l00`00o`00003o0000o`070000o`800?l00P000?l20?l000800?l000<0003o0?l0003o
00000P00o`040?n000D00?l06@000?l>ooooo`@0oh0000<00?l00?n0003oP000403oP002003o00D0
oh000P00o`040?n000800?l02@3oP007003o0080oh000`00o`020?n000800?l00P3o00000`000?l0
oh000?n000090?n000800?l01@3oP002003o00L0oh000P00o`070?n000800?l0103oP005003o00D0
oh000P00o`020?n000800?l01@3oP002003o00D0oh000P00o`0Hooooo`005_ooool40000ocD0o`00
0P00o`0V0?l00080003o2@3o00000`000?l0o`000?l0000B0?l000800?l00P3oP0050?l000kooooo
6`00o`020?n000L00?l00P3oP00:003o00P0oh0000<00?l00?n0003oP0002@000?l20?n00080003o
00<00?l00000o`000?l01P000?l00`00o`00oh000?n000060?n000D00?l00P3oP005003o00@0oh00
0P00o`000`3oP0000?l0003o0004003o00T0oh0000<00?l00000o`000?l00P3oP0020000o`D00?l0
0P3oP00>ooooo`L0oh000P000?l5003o00T0oh000P000?l2003o0080oh002P00o`020000o`80o`00
2`000?l5003o00@0oh0030000?l2003o00@0003o00<00?l00000o`000?l01`000?l2003o0080003o
0P3o0002003o00030000o`3o0000o`0000800?l0103oP005003o01T0003o3_ooool40?n00003003o
003oP000oh000100oh000P00o`050?n000800?l0103oP002003o00T0oh001`00o`020?n000<00?l0
0P3oP002003o0080o`0000<0003o0?n0003oP0002@3oP002003o00D0oh000P00o`070?n000800?l0
1`3oP002003o00@0oh001@00o`050?n000800?l00P3oP002003o00D0oh000P00o`050?n000800?l0
6?ooool001Kooooo10000?lR0?l000030?n0003o0000o`000180o`000P00o`0N0?l00080003o103o
00020000o`03003o00000?l0003o0080003o103o00000`000?l0o`000?l0000@0?l000@00?l01`3o
000>oooooa/00?l00P3oP007003o0080oh002P00o`080?n00003003o003oP000oh0000800?l01@00
0?l20?n000@00?l000<0003o0?l0003o000010000?l20?l000030000o`3oP000oh0000800?l01@3o
P0020?l000800?l00P3oP002003o00030?n00000o`000?l00080oh003000o`090?n000@0003o1@00
o`020?n000800?l03_ooool50?n00080o`00103oP003003o0080003o103oP0020?l000030?n0003o
0000o`0000@0o`0000<0003o003o0000o`00103o00050000o`80o`002`000?l9003o00`0003o0P00
o`0=0000o`<00?l01`000?l20?l000800?l01@3oP004003o0180003o0P3o00050000o`kooooo0P3o
P002003o00D0oh000P00o`020?n00003003o003oP000oh0000L0oh000P00o`020?n000800?l000<0
oh00003o0000o`00103oP002003o00T0oh001`00o`020?n00003003o003oP000oh000080oh000P3o
00020?n000030000o`3oP000oh0001H0oh000`000?l70?n000800?l02@3oP002003o00D0oh000P00
o`090?n000800?l00`3oP004003o01Sooooo000Fooooo`80oh000P000?lR0?l000030?n0003o0000
o`000380o`000P000?l60?l00003003o00000?l0003o0080003o5`3o0004003o00<0o`000P00o`02
0?l000kooooo6`00o`020?n000<00?l00P3oP002003o0080oh002P00o`090?n00080003o0P00o`05
0000o`@0oh000`00o`020?n000800?l00P3oP0020?l000<0003o0P3oP0020?l000D0oh000P00o`07
0?n000L00?l00P3oP005003o0080oh001P00o`000`3oP0000?l0003o00020000o`@00?l00`3oP002
003o00kooooo0P00o`050?n000800?l00P3oP002003o00030?n000000?l0003o0080003o0P3oP002
0?l000030?n0003o0000o`0000@0o`0000<0003o0?l0003o00000P3o00050000o`80oh003@000?l7
003o00h0003o1P00o`090000o`<00?l01P000?l00`3o0000003o0000o`020000o`D0oh001000o`02
0000o`030?l000000?l0003o01@0003o3_ooool90?n000800?l00P3oP0030000o`L0oh000P00o`05
0?n000800?l0103oP002003o00T0oh001`00o`020?n00003003o003oP000oh0000800?l00P3o000:
0?n00080o`000P3oP0020?l000D0oh000P00o`040?n000<0003o1`3oP002003o01/0oh000P00o`02
0?n00003003o003oP000oh000080oh006?ooool001Kooooo0P3oP0020000ob80o`0000<0oh000?l0
003o0000<P3o00020000o`H0o`0000<00?l00000o`000?l00P000?lG0?l000@00?l00`3o0002003o
0080o`003_oooolK003o0080oh000`00o`020?n000800?l00P3oP00:003o00T0oh000P000?l2003o
00D0003o103oP003003o0080oh000P00o`020?n00080o`000`000?l20?n00080o`001@3oP002003o
00L0oh001`00o`020?n000D00?l00P3oP006003o00030?n00000o`000?l00080003o1000o`030?n0
00800?l03_ooool2003o00D0oh000P00o`020?n000800?l000<0oh000000o`000?l00P000?l20?n0
0080o`0000<0oh000?l0003o0000103o00000`000?l0o`000?l000020?l000D0003o0P3oP00=0000
o`L00?l03P000?l6003o00T0003o0`00o`060000o`030?l000000?l0003o0080003o1@3oP004003o
0080003o00<0o`000000o`000?l050000?l>ooooo`T0oh000P00o`020?n000<0003o1`3oP002003o
00D0oh000P00o`040?n000800?l02@3oP007003o0080oh0000<00?l00?n0003oP0000P00o`020?l0
00X0oh000P3o00020?n00080o`001@3oP002003o00@0oh000`000?l70?n000800?l06`3oP002003o
0080oh0000<00?l00?n0003oP0000P3oP00Hooooo`005_ooool20?n00080003o4`3o00020?n000d0
o`0000<0oh000?l0003o00001P3o00000`3oP000o`000?l0000K0?l000800?l0503o00050000oaL0
o`001000o`070?l000kooooo6`00o`020?n000L00?l00P3oP00:003o00P0oh0000<00?l00000o`00
0?l00P00o`050000o`T0oh000P00o`040000o`03003o00000?l0003o0080oh001000o`030?n00080
0?l0103oP0000`00o`00oh000?n00006003o00<0oh000P00o`020?n00003003o003oP000oh0000H0
0?l000<0oh00003o0000o`000P00o`020?n000800?l00`3oP002003o00kooooo0P00o`0<0?n000@0
003o0P3oP0020?l000<0oh000P3o000<0000o`80oh003@000?l20?n000L00?l030000?l4003o0080
o`001`000?l20?l000<00?l02`000?l70?n000800?l00P3oP0000`00o`00003o0000o`0D0000o`ko
oooo2@3oP002003o00<0oh000P00o`070?n000800?l01@3oP002003o00@0oh000P00o`090?n00003
003o003oP000oh000080oh000P00o`020?n00003003o003oP000oh000080oh000P3o000:0?n00080
0?l01`3oP002003o00H0oh0000<00?l00000o`000?l02`3oP0020?l000D0oh000P00o`050?n00080
0?l0103oP007003o00L0oh006?ooool001Kooooo0P3oP0020000oa<0o`000P3oP00=0?l000030?n0
003o0000o`0000H0o`0000<0oh000?l0003o00006`3o0002003o01@0o`001@000?lG0?l000@00?l0
1`3o000>oooooa/00?l00P3oP007003o0080oh002P00o`080?n00003003o00000?l0003o00800?l0
1@000?l90?n000800?l010000?l00`00o`00003o0000o`020?n000@00?l00`3oP002003o00@0oh00
00<00?l00?n0003oP0001P00o`030?n000800?l00P3oP0000`00o`00oh000?n00006003o00030?n0
0000o`000?l000800?l00P3oP002003o00<0oh000P00o`0>ooooo`800?l0303oP0040000o`80oh00
0P3o00030?n00080o`0030000?l20?n000d0003o0P3oP007003o00`0003o1000o`020?l000L0003o
0P3o0003003o00/0003o1`3oP002003o0080oh0000<00?l00000o`000?l050000?l>ooooo`T0oh00
0P00o`030?n000800?l01`3oP002003o00D0oh000P00o`040?n000800?l02@3oP0000`00o`00oh00
0?n000020?n000800?l00P3oP0000`00o`00oh000?n000020?n00080o`002P3oP002003o00L0oh00
0P00o`060?n00003003o00000?l0003o00/0oh000P3o00050?n000800?l01@3oP002003o00@0oh00
1`00o`070?n001Sooooo000Fooooo`80oh000P000?lB0?l000030?n0003o0000o`0001H0o`0000<0
oh000?l0003o00006`3o0002003o01@0o`001@000?l20?l00080003o4`3o0002003o0080oh001`3o
000>oooooa/00?l00P3oP00C003o0080oh000P00o`040?n00003003o003o0000o`000080oh001@00
0?l90?n000T00?l0103oP009003o00L0oh001000o`050?n000<00?l00P3oP002003o0080oh000P00
o`000`3oP0000?l0003o0004003o00D0oh000P00o`0>ooooo`800?l0303oP0060000o`80o`0000<0
003o0?n0003oP0000P3oP00<0000o`800?l03@000?l20?n00003003o003oP000oh0000@00?l02P00
0?l40?n00080003o0P00o`070000o`80o`0000<0oh00003o0000o`002`000?l70?n000800?l00P3o
P0000`00o`00003o0000o`0D0000o`kooooo0P00o`070?n000800?l00`3oP002003o00L0oh001P00
o`000`3oP0000?l0003o000?0?n000<00?l05`3oP004003o0080oh000P3o00050?n000800?l00P3o
P0000`00o`00oh000?n000040?n000800?l01@3oP0020?l000D0oh000P00o`0;0?n00003003o003o
P000oh000080oh000P00o`020?n000D00?l06?ooool001Kooooo0P3oP0020000oa80o`0000<0oh00
0?l0003o00005P3o00000`3oP000o`000?l0000K0?l000800?l0503o00050000o`80o`000P000?lC
0?l000800?l00P3oP0070?l000kooooo6`00o`020?n001<00?l00P3oP002003o00@0oh0000<00?l0
0?l0003o00000P3oP0050000o`T0oh002@00o`040?n000T00?l01`3oP004003o00D0oh000`00o`02
0?n000800?l00P3oP002003o00030?n00000o`000?l000@00?l01@3oP002003o00kooooo0P00o`0<
0?n000H0003o0P3o00000`000?l0oh000?n000020?n000`0003o0P00o`0=0000o`80oh0000<00?l0
0?n0003oP0001000o`0:0000o`@0oh000P000?l2003o00L0003o0P3o00000`3oP0000?l0003o000;
0000o`L0oh000P00o`020?n00003003o00000?l0003o01@0003o3_ooool2003o00L0oh000P00o`03
0?n000800?l01`3oP006003o00030?n00000o`000?l000l0oh000`00o`0G0?n000@00?l00P3oP002
0?l000D0oh000P00o`020?n00003003o003oP000oh0000@0oh000P00o`050?n00080o`001@3oP002
003o00/0oh0000<00?l00?n0003oP0000P3oP002003o0080oh001@00o`0Hooooo`005_ooool2003o
0080003o:`3o00000`00o`00o`000?l000060?l000030?n0003o0000o`0002P0o`000`3oP0020000
o`80o`000P000?lC0?l000800?l00P3oP0070?l000kooooo0P3oP00G003o00@0oh002P00o`020?n0
00d00?l00P3oP0000`00o`00oh000?n00004003o00<0003o0P3oP0020000o`80oh000`000?l2003o
00@0003o1@00o`020?n00080003o2@00o`050?n000@00?l00`3oP0020000o`D0oh001P00o`0<0?n0
00800?l03_ooool2003o00`0oh0020000?l00`00o`00oh000?n000020?n001/0003o0P3oP0000`3o
0000oh000?n000020?n000800?l02P000?l40?n000T0003o1`3oP00=0000o`D0oh001000o`0G0000
o`kooooo0P00o`030?n000800?l00P3oP002003o00D0oh000P00o`050?n000H00?l000<0oh00003o
0000o`00103oP003003o00P0oh0000<00?l00?n0003oP0001`3oP002003o00/0oh000P00o`0<0?n0
00800?l06`3oP002003o00<0oh000P00o`090?n000800?l01`3oP00Hooooo`005_ooool20000obd0
o`0000<00?l00?l0003o0000<@3o00030?n000H0003o4`3o0002003o0080oh001`3o000>oooooa/0
0?l00P3oP00G003o0080oh000`00o`020?n000@00?l00P000?l00`00o`00oh000?n000020000o`80
oh000`000?l2003o00@0003o0`00o`040?n00080003o00<0o`00003o0000o`001000o`030000o`@0
oh001@00o`020?n00080003o0P3oP0000`00o`00oh000?n00007003o00H0oh000`00o`020?n00080
0?l03_ooool2003o0080003o2P3oP0080000o`03003o003oP000oh000080oh006`000?l20?n00003
0?l0003oP000oh000080oh000P00o`0<0000o`80oh002`000?l20?n00100003o2@3oP0000`3o0000
003o0000o`0D0000o`kooooo1@00o`040?n000800?l01@3oP002003o0080oh000P00o`000`3oP000
0?l0003o0004003o00030?n00000o`000?l000800?l0103oP0000`00o`00oh000?n000060?n00003
003o003oP000oh000080oh001000o`000`3oP0000?l0003o00040?n000800?l01@3oP002003o0003
0?n00000o`000?l000@00?l01@3oP002003o00T0oh000P00o`0E0?n000@00?l02`3oP0000`00o`00
oh000?n000020?n001Sooooo000Fooooo`80003o;@3o00000`00o`00o`000?l0000a0?l000<0oh00
1P000?lC0?l000800?l00P3oP0070?l000kooooo6`00o`020?n001L00?l00P3oP003003o0080oh00
1000o`020000o`03003o003oP000oh000080003o0P3oP0030000o`800?l010000?l3003o00@0oh00
0P000?l00`3o00000?l0003o0004003o00<0003o103oP005003o0080oh000P000?l20?n00003003o
003oP000oh0000L00?l01P3oP003003o0080oh000P00o`0>ooooo`800?l00P000?l:0?n000P0003o
00<00?l00?n0003oP0000P3oP00K0000o`80oh0000<0o`000?n0003oP0000P3oP002003o00`0003o
0P3oP00;0000o`80oh0040000?l90?n000030?l000000?l0003o01@0003o3_ooool5003o00@0oh00
0P00o`050?n000800?l00P3oP002003o00030?n00000o`000?l000@00?l000<0oh00003o0000o`00
0P00o`040?n00003003o003oP000oh0000H0oh0000<00?l00?n0003oP0000P3oP004003o00030?n0
0000o`000?l000@0oh000P00o`050?n000800?l000<0oh00003o0000o`001000o`050?n000800?l0
2@3oP002003o01D0oh001000o`0;0?n00003003o003oP000oh000080oh006?ooool001Kooooo0P00
0?l2003o00030000o`3o0000o`0005`0o`0000<0oh000?l0003o00001`000?l@0?l000800?l00P00
0?l20?n00080o`0000<00?l00?l0003o00000P3o000>oooooa/00?l00P3oP003003o0080oh004P00
o`040?n00003003o003oP000oh0000800?l010000?l00`00o`00003o0000o`070000o`800?l01`00
0?l20?n000@0003o0`3o0004003o00D0003o0P3oP005003o00@0003o0P3oP00<003o00@0oh000`00
o`020?n000800?l03_ooool2003o0080003o00<0oh000?l0003o00001P3oP0000`00o`00003o0000
o`040000o`80o`0000<00?l00?n0003oP0000P3oP002003o00030?n000000?l0003o00/0003o0P3o
00050000o`80oh000P000?l30?n00080003o0P00o`0>0000o`80oh002`000?l2003o0100003o1@3o
P002003o01T0003o3_ooool7003o0080oh000P00o`030?n000800?l0103oP002003o00030?n00000
o`000?l000d0oh0000<00?l00?n0003oP0002`3oP004003o00030?n00000o`000?l000h0oh000P00
o`020?n000800?l01@3oP002003o00d0oh0000<00?l00?n0003oP000403oP002003o00d0oh000`00
o`020?n001Sooooo000Fooooo`80003o0P00o`000`000?l0o`000?l0001L0?l000030?n0003o0000
o`0000L0003o403o0002003o0080003o0P3oP0020?l00003003o003o0000o`000080o`003_oooolK
003o0080oh000`00o`020?n001800?l0103oP0000`00o`00oh000?n00002003o00@0003o00<00?l0
0000o`000?l01`000?l2003o00L0003o0P3oP0040000o`<0o`001000o`050000o`80oh001@00o`04
0000o`80oh003000o`040?n000<00?l00P3oP002003o00kooooo0P00o`020000o`030?n0003o0000
o`0000H0oh0000<00?l00000o`000?l010000?l20?l00003003o003oP000oh000080oh000P00o`00
0`3oP000003o0000o`0;0000o`80o`001@000?l20?n00080003o0`3oP0020000o`800?l03P000?l2
0?n000/0003o0P00o`0@0000o`D0oh000P00o`0I0000o`kooooo1`00o`020?n000800?l00`3oP002
003o00@0oh000P00o`000`3oP0000?l0003o000=0?n00003003o003oP000oh0000/0oh001000o`00
0`3oP0000?l0003o000>0?n000800?l00P3oP002003o00D0oh000P00o`0=0?n00003003o003oP000
oh000100oh000P00o`0=0?n000<00?l00P3oP00Hooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool0
0?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool002;oooooL_l0
000Wooooog7o00009ooooomao`0002OoooooL_l0000Sooooo`008_ooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo0005oooo
oaKo0?l01?oooolGo`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooolFool000Gooooo5_l0o`05oooooaKo003o1?oooolGoomo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l5oooo
oaKoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooo
oaOo0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo000joooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;ooooo5_oo0005oooooaKo0?l01OoooolFo`00o`Cooooo5oooO`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l5oooooaKo
ogl01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo
0?l01?oooolFo`00o`Gooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o1OoooolFoomo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02oooooaOoo`001?oooolGo`3o01oooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo0004oooooaOo0?l07ooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00o`Cooooo5oooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooolG
ool000Cooooo5ol0o`0OoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0
003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
5ooo000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0
o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo
000joooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo5ooo000j
oooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooo
oaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05oooo
o`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_oo
ool00ol0003o001oo`00O`03o`00OaKoo`00EOl007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o01go001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o01go001o5_l0o`05o`00OaKo003o7ol007l00ol0003oooooooooo`0Uooooo`03o`000?l0
07oo001o05?o001o5_ooO`05o`00O`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00
oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0
003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027o
oooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03
oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolFo`00oaoooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`00
8_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Dooo
oolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01OoooolF
o`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool0
0ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0MoooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo5_l0o`05oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?l007oo001o00?o001o
5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l07Ol007lFo`3o03[o001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`0Mo`00OaKo0?l01Ol007lFo`00oaoo001o
00?o0000ooooooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0003ooooo
ooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`0jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Gooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l0>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`05
oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03
o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo
003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oo
oooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
oolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0hoooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo
00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo
027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07OoooolFo`3o03[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Go
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l0>_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooooooo
o`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000
ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Roooo
o`03o`000?l007oo001o00?o001o5_oo001Eo`00O`03o`000?oooooooooo02Gooooo00?o0000o`00
Ool007l0KOl007l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000oooo
ooooool09Oooool00ol0003o001oo`00O`1Co`00OaKoogl01Ol007l00ol0003oooooooooo`0Qoooo
o`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`00
0?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Ooo
ool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolF
oomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?o
oooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003ooooo
ooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03o`000?oooooooooo027ooooo000R
ooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl01Oooool00ol0003oooooooooo`0Q
ooooo`008_ooool00ol0003oooooooooo`03oooooaKoo`00EOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DooooolFoomo00Gooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo5_ooO`05ooooo`03
o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo00?ooooo5_oo001Eooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1CoooooaKoogl0
1Oooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o001oo`00O`03o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Uooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Ooo
ool00ol0003o001oo`00O`1]o`00O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0Dol0
07lFoomo00Go001o00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolF
ool005Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool0
05Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool08Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
8Oooool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Ooo
ool002;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;o
oooo00?o0000ooooooooool00ooooolFool005Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool002;ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`008_oooombo`0002OoooooLOl0
000Wooooog7o00009ooooombo`0002?ooooo003oooooooooooooP_ooool00?oooooooooooon2oooo
o`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
000Fooooog40o`000P3oP00G0?l000kooooo0P3o0002003o00<0003o0P00o`020000o`800?l02P00
0?l20?n000@00?l00`000?l40?n00080o`0000<0oh00003o0000o`001`000?l90?n000H00?l00P3o
P0030?l000@00?l00`000?l;003o00@0003o0`00o`020?n000d00?l00`000?l7003o00@0003o0P3o
00000`00o`00oh000?n000040?n000L00?l03_ooool20000oa000?l06@000?l7003o0080003o2@00
o`020000o`<00?l01`000?l2003o0080003o0P3oP00P0000o`L00?l050000?l>ooooo`80o`001`3o
P0040?l000L0oh000P00o`070?n00003003o003oP000oh0000H00?l00`3oP0020?l00080oh001@3o
00020000o`T0oh000P00o`030?n000800?l00P3o0003003o0080o`00103oP0020?l000T0oh000`3o
00070?n000P0o`00203oP002003o00@0oh000`3o0004003o00@0oh0000<00?l00?n0003oP0000P3o
P00Hooooo`005_ooooma0?l00080oh005`3o000>ooooo`80o`000P00o`030000o`800?l00P000?l2
003o00X0003o0P3oP004003o00<0003o103oP0020?l000030?n00000o`000?l000L0003o2@3oP006
003o0080oh000`3o0004003o00<0003o2`00o`040000o`<00?l00P3oP00=003o00<0003o1`00o`04
0000o`80o`0000<00?l00?n0003oP000103oP007003o00kooooo0P000?l@003o01T0003o1`00o`02
0000o`T00?l00P000?l3003o00L0003o0P00o`020000o`80oh0080000?l7003o01@0003o3_ooool2
0?l000L0oh00103o00070?n000800?l01`3oP0000`00o`00oh000?n00006003o00<0oh000P3o0002
0?n000D0o`000P000?l90?n000800?l00`3oP002003o0080o`000`00o`020?l000@0oh000P3o0009
0?n000<0o`001`3oP0080?l000P0oh000P00o`040?n000<0o`001000o`040?n00003003o003oP000
oh000080oh006?ooool001Kooooo0P3oP01a0?l000<0oh00503o000>ooooo`80o`002`00o`030000
o`800?l00P000?l2003o00030000o`00o`000?l000@0003o1@00o`020?n000<0o`000P00o`020000
o`@00?l000<0003o003o0000o`000P00o`040000o`T00?l00`3o0004003o00<0003o0P00o`020000
o`D00?l01P000?lB003o00030000o`00o`000?l000T00?l02`3o0007003o00kooooo10000?l7003o
00<0003o1000o`0M0000o`h00?l02`000?l00`00o`00003o0000o`0I0000o`800?l00P000?l5003o
00T0003o3@00o`030000o`@00?l03_oooolG0?n000800?l02@3oP0040?l000`0oh000P000?lD0?n0
00030?l0003oP000oh000080o`001@3oP002003o00H0003o00<0oh000?l0003o0000:03oP0030?l0
0080oh006?ooool001Kooooo0P3oP01a0?l000<0oh00503o000>ooooo`80o`002`00o`030000o`80
0?l00P000?l2003o00030000o`00o`000?l000@0003o1@00o`020?n000<0o`000P00o`020000o`@0
0?l000<0003o003o0000o`000P00o`040000o`T00?l00`3o0004003o00<0003o0P00o`020000o`D0
0?l01P000?lB003o00030000o`00o`000?l000T00?l02`3o0007003o00kooooo10000?l7003o00<0
003o1000o`0M0000o`h00?l02`000?l00`00o`00003o0000o`0I0000o`800?l00P000?l5003o00T0
003o3@00o`030000o`@00?l03_oooolG0?n000800?l02@3oP0040?l000`0oh000P000?lD0?n00003
0?l0003oP000oh000080o`001@3oP002003o00H0003o00<0oh000?l0003o0000:03oP0030?l00080
oh006?ooool001KoooooQ@3o00000`3oP000o`000?l000020?l000kooooo0P3o0003003o0080003o
1P00o`0>0000o`800?l00`000?l70?n000@0003o2@00o`040000o`030?n00000o`000?l000800?l0
103oP0030?l001d00?l00P3oP003003o0080o`001000o`070000o`L00?l00`3o00020000o`@0oh00
1`00o`0>ooooo`80003o3P00o`040000o`800?l01`000?l00`00o`00003o0000o`0I0000o`800?l0
4P000?lB003o0080003o0P00o`050000o`L00?l03P000?l2003o00/0003o3_ooool20?l000L0oh00
2@3o000B0?n000<0o`002`3oP002003o00@0003o2P3oP004003o00<0oh00103o00070?n00080o`00
1@00o`020000o`H0oh0000<0o`000?n0003oP0001`3oP002003o00D0o`000P00o`060?n000<0o`00
0P3oP0050?l00080oh000P3o000Hooooo`005_oooomd0?l000@0oh003P3o00040?n000kooooo4000
o`070000o`800?l010000?l5003o0080oh001@00o`060000o`L00?l00P3oP0000`00o`00003o0000
o`020000o`D00?l00P3o0005003o0080003o1`00o`020000o`@0oh000P00o`030?n000@00?l00P00
0?l00`00o`00oh000?n000020?l000@00?l000<0003o0?n0003oP0000P00o`020?n000D00?l00P3o
0003003o0080oh000P3o00020?n000<00?l010000?l>ooooo`800?l01@000?l;003o01@0003o00<0
0?l00000o`000?l010000?l3003o00H0003o0`00o`060000o`D00?l01@000?l2003o00H0003o00<0
0?l00000o`000?l00P00o`050000o`800?l040000?l20?n00080003o0P3oP0070000o`800?l02@00
0?l3003o0080003o3_ooool=0?n000030?l0003oP000oh000180oh001@3o000;0?n00080o`001@3o
P0020?l000d0oh0000<00?l00?l0003o00002`3oP002003o0080003o1@3oP0020?l00080oh0000<0
o`000?n0003oP000403oP0040?l000800?l02@3o00000`3oP0000?l0003o0002003o01Sooooo000F
ooooog@0o`00103oP00>0?l000@0oh003_ooool@003o00L0003o0P00o`040000o`D00?l00P3oP005
003o00H0003o1`00o`020?n00003003o00000?l0003o0080003o1@00o`020?l000D00?l00P000?l7
003o0080003o103oP002003o00<0oh001000o`020000o`03003o003oP000oh000080o`001000o`00
0`000?l0oh000?n00002003o0080oh001@00o`020?l000<00?l00P3oP0020?l00080oh000`00o`04
0000o`kooooo0P00o`050000o`/00?l050000?l00`00o`00003o0000o`040000o`<00?l01P000?l3
003o00H0003o1@00o`050000o`800?l01P000?l00`00o`00003o0000o`02003o00D0003o0P00o`0@
0000o`80oh000P000?l20?n000L0003o0P00o`090000o`<00?l00P000?l>ooooo`d0oh0000<0o`00
0?n0003oP0004P3oP0050?l000/0oh000P3o00050?n00080o`003@3oP0000`00o`00o`000?l0000;
0?n000800?l00P000?l50?n00080o`000P3oP0000`3o0000oh000?n0000@0?n000@0o`000P00o`09
0?l000030?n00000o`000?l000800?l06?ooool001Kooooo0P3oP0280?l000kooooo0P000?l20?n0
00<0003o1`00o`020000o`800?l01`000?l4003o01<0003o2000o`0:0000o`L00?l00P000?l6003o
00030000o`00o`000?l00080o`001000o`000`3oP0000?l0003o00020?n000L00?l010000?l20?n0
00`00?l00P3o0002003o00<0o`001P00o`030000o`800?l03_ooool70000oa000?l03`000?l00`3o
P000003o0000o`040000o`800?l04`000?l2003o00L0oh001000o`030?n00080o`000P00o`040000
o`03003o00000?l0003o00@0003o0P3oP003003o0080003o1`00o`020000o`800?l000<0003o0?n0
003oP0001`00o`040?n000L00?l00P000?l>oooooa80oh000P000?l2003o00030000o`3oP000oh00
0080003o1`3oP0040?l000T0oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n0000O0?n0
00030?l0003oP000oh0000T0oh001P00o`0A0?n00080o`002`3oP00Hooooo`005_ooool20?n008P0
o`003_ooool20000o`80oh000`000?l7003o0080003o0P00o`070000o`@00?l04`000?l8003o00X0
003o1`00o`020000o`H00?l000<0003o003o0000o`000P3o0004003o00030?n00000o`000?l00080
oh001`00o`040000o`80oh003000o`020?l000800?l00`3o0006003o00<0003o0P00o`0>ooooo`L0
003o4000o`0?0000o`030?n000000?l0003o00@0003o0P00o`0C0000o`800?l01`3oP004003o00<0
oh000P3o0002003o00@0003o00<00?l00000o`000?l010000?l20?n000<00?l00P000?l7003o0080
003o0P00o`000`000?l0oh000?n00007003o00@0oh001`00o`020000o`kooooo4P3oP0020000o`80
0?l000<0003o0?n0003oP0000P000?l70?n000@0o`002@3oP0000`3o0000oh000?n000060?n00003
0?l0003oP000oh0001l0oh0000<0o`000?n0003oP0002@3oP006003o0140oh000P3o000;0?n001So
oooo000Fooooo`80oh009@3o00020?n004P0o`001`3oP00B0?l000kooooo1000o`000`000?l00?l0
003o00020000o`D00?l00P000?l>003o00@0003o1000o`000`000?l00?l0003o00070000o`l00?l0
0`000?l20?n000D0003o2000o`000`000?l0oh000?n0000;0?n000800?l00P000?l00`3oP000003o
0000o`06003o00030000o`00o`000?l000800?l00P000?l00`00o`00003o0000o`040000o`800?l0
0`000?l7003o00@0003o3_ooool2003o00D0003o2`00o`040000o`03003o00000?l0003o00d0003o
0`00o`020000o`@00?l02P000?l8003o00030000o`00o`000?l00080003o0P00o`030000o`T0oh00
0P00o`040000o`03003o00000?l0003o0080oh000P000?l2003o00L0003o1@00o`020000o`D00?l0
2`000?l2003o00L0003o3_oooolD0?n00080003o00<00?l00?n0003oP0001@3oP0020000o`H0o`00
4`3oP002003o00d0oh001@000?l20?n000800?l01`3oP007003o0080o`000`000?l20?l000800?l0
0P3o000P0?n001Sooooo000Fooooo`80oh009@3o00020?n004P0o`001`3oP00B0?l000kooooo1000
o`000`000?l00?l0003o00020000o`D00?l00P000?l>003o00@0003o1000o`000`000?l00?l0003o
00070000o`l00?l00`000?l20?n000D0003o2000o`000`000?l0oh000?n0000;0?n000800?l00P00
0?l00`3oP000003o0000o`06003o00030000o`00o`000?l000800?l00P000?l00`00o`00003o0000
o`040000o`800?l00`000?l7003o00@0003o3_ooool2003o00D0003o2`00o`040000o`03003o0000
0?l0003o00d0003o0`00o`020000o`@00?l02P000?l8003o00030000o`00o`000?l00080003o0P00
o`030000o`T0oh000P00o`040000o`03003o00000?l0003o0080oh000P000?l2003o00L0003o1@00
o`020000o`D00?l02`000?l2003o00L0003o3_oooolD0?n00080003o00<00?l00?n0003oP0001@3o
P0020000o`H0o`004`3oP002003o00d0oh001@000?l20?n000800?l01`3oP007003o0080o`000`00
0?l20?l000800?l00P3o000P0?n001Sooooo000Fooooo`80oh00K`3o00070?n00180o`003_ooool2
003o0080003o0`00o`020000oa@00?l000<0003o003o0000o`001000o`030?n000800?l01`000?l?
003o0080003o1`00o`030000o`80oh001`00o`0=0000o`800?l00`000?l7003o0080003o0P00o`05
0000o`T00?l0103o0002003o00D0003o3_ooool50000o`l00?l04P000?l00`3oP0000?l0003o0004
0?n001D0003o0P3oP0090000o`80oh000P3o00000`3oP0000?l0003o0002003o00@0003o0`00o`04
0000o`<00?l00P000?l2003o0080003o1@00o`040000o`L00?l01@000?l2003o00T0003o3_ooool9
0?n00080o`001`3oP0020?l000T0oh0000<0o`00003o0000o`000P00o`0;0?n00080o`001`3oP002
0?l00140oh000P00o`0F0?n000<00?l03@3oP0020?l001L0oh006?ooool001Kooooo0P3oP0280?l0
00kooooo0P00o`050000o`800?l02@000?l5003o0080003o1000o`030000o`H0oh0000<0003o003o
0000o`001P000?l:003o0080003o0P00o`020000o`<00?l01`000?l2003o0080003o0P00o`090000
o`800?l000<0003o003o0000o`000P00o`090000o`@00?l040000?l50?n000D00?l010000?l>oooo
o`80003o5000o`070000o`D00?l01`000?l20?n000800?l04P000?l3003o0080003o1000o`000`00
0?l0oh000?n000090?n000l00?l00`000?l=003o00D0003o0P3oP0020000o`03003o00000?l0003o
00H0003o1@00o`0>ooooo`80oh000P3o00000`3oP000o`000?l000060?l000X0oh00103o00030?n0
00800?l00P000?lF0?n000030?l00000o`000?l000@0oh000P3o00000`00o`00oh000?n000050?n0
00@00?l01@3oP0040?l00200oh00103o000;0?n000030?l0003oP000oh0000800?l06?ooool001Ko
oooo0P3oP0280?l000kooooo0P00o`050000o`800?l02@000?l5003o0080003o1000o`030000o`H0
oh0000<0003o003o0000o`001P000?l:003o0080003o0P00o`020000o`<00?l01`000?l2003o0080
003o0P00o`090000o`800?l000<0003o003o0000o`000P00o`090000o`@00?l040000?l50?n000D0
0?l010000?l>ooooo`80003o5000o`070000o`D00?l01`000?l20?n000800?l04P000?l3003o0080
003o1000o`000`000?l0oh000?n000090?n000l00?l00`000?l=003o00D0003o0P3oP0020000o`03
003o00000?l0003o00H0003o1@00o`0>ooooo`80oh000P3o00000`3oP000o`000?l000060?l000X0
oh00103o00030?n000800?l00P000?lF0?n000030?l00000o`000?l000@0oh000P3o00000`00o`00
oh000?n000050?n000@00?l01@3oP0040?l00200oh00103o000;0?n000030?l0003oP000oh000080
0?l06?ooool001KoooooRP3o000>ooooo`@00?l000<0003o003o0000o`001P00o`0:0000o`@00?l0
1@000?l4003o0080o`001@000?l7003o00H0003o0`00o`020000o`T00?l01@000?l4003o00<0003o
0P00o`070000o`800?l03`000?l00`00o`00003o0000o`020000o`<00?l00P000?l9003o0080oh00
1@00o`040000o`kooooo0P000?l2003o00030000o`00o`000?l000800?l00P000?l2003o00T0003o
00<00?l00000o`000?l010000?l5003o0080003o1@00o`020?n000d00?l000<0003o003o0000o`00
10000?l20?n000D0003o1@00o`060?n000D00?l00P000?l3003o0080003o0P00o`050000o`@00?l0
4P000?l2003o00030000o`00o`000?l000T0003o0P00o`0>ooooo`80oh001`3o000;0?n00080o`00
00<0oh000?l0003o00000P3oP0050?l000800?l0103oP0000`00o`00oh000?n000020?n000@0o`00
0`00o`020000o`L0oh00103o000P0?n000L0o`003@3oP0000`00o`00oh000?n00002003o00/0oh00
0`3o00040?n001Sooooo000FooooohX0o`003_ooool4003o00030000o`00o`000?l000H00?l02P00
0?l4003o00D0003o1000o`020?l000D0003o1`00o`060000o`<00?l00P000?l9003o00D0003o1000
o`030000o`800?l01`000?l2003o00l0003o00<00?l00000o`000?l00P000?l3003o0080003o2@00
o`020?n000D00?l010000?l>ooooo`80003o0P00o`000`000?l00?l0003o0002003o0080003o0P00
o`090000o`03003o00000?l0003o00@0003o1@00o`020000o`D00?l00P3oP00=003o00030000o`00
o`000?l000@0003o0P3oP0050000o`D00?l01P3oP005003o0080003o0`00o`020000o`800?l01@00
0?l4003o0180003o0P00o`000`000?l00?l0003o00090000o`800?l03_ooool20?n000L0o`002`3o
P0020?l000030?n0003o0000o`000080oh001@3o0002003o00@0oh0000<00?l00?n0003oP0000P3o
P0040?l000<00?l00P000?l70?n000@0o`00803oP0070?l000d0oh0000<00?l00?n0003oP0000P00
o`0;0?n000<0o`00103oP00Hooooo`005_oooon80?l00080oh003_ooool70000o`800?l040000?l4
003o00<0003o2@00o`020000o`@00?l01`000?l9003o00<0oh000P3o0005003o0080003o1`3oP002
003o0080003o3@00o`050000o`@00?l000<0003o003o0000o`001000o`030000o`@00?l02`3oP003
003o0080003o3_ooool20000o`L00?l00P000?l2003o00<0003o1000o`020000o`03003o00000?l0
003o00L0003o0P00o`0=0000o`<00?l00P000?l4003o00`0003o0P00o`020000o`03003o00000?l0
003o0080003o1`3oP002003o0080003o1@00o`040000o`L00?l00P000?l2003o00030000o`00o`00
0?l00100003o0P00o`050000o`80oh000P00o`0>ooooo`@0oh000`3o00020?n000D00?l00P000?l2
003o02@0oh000P3o00050?n00080o`000P3oP0000`3o0000oh000?n000070?n000800?l00P000?l2
003o00030?n00000o`000?l00200oh000P000?lD0?n001Sooooo000FooooohP0o`000P3oP00>oooo
o`L0003o0P00o`0@0000o`@00?l00`000?l9003o0080003o1000o`070000o`T00?l00`3oP0020?l0
00D00?l00P000?l70?n000800?l00P000?l=003o00D0003o1000o`000`000?l00?l0003o0004003o
00<0003o1000o`0;0?n000<00?l00P000?l>ooooo`80003o1`00o`020000o`800?l00`000?l4003o
0080003o00<00?l00000o`000?l01`000?l2003o00d0003o0`00o`020000o`@00?l030000?l2003o
0080003o00<00?l00000o`000?l00P000?l70?n000800?l00P000?l5003o00@0003o1`00o`020000
o`800?l000<0003o003o0000o`0040000?l2003o00D0003o0P3oP002003o00kooooo103oP0030?l0
0080oh001@00o`020000o`800?l0903oP0020?l000D0oh000P3o00020?n000030?l0003oP000oh00
00L0oh000P00o`020000o`800?l000<0oh00003o0000o`00803oP0020000oa@0oh006?ooool001Ko
ooooRP3o000>ooooo`D0003o1P00o`030000o`800?l01P000?l:003o00H0003o00<00?l00000o`00
0?l01P00o`090000o`D0oh000P00o`020?n000L00?l00`000?l2003o0080oh000P3o0003003o0080
003o0P3o0009003o00<0003o0P00o`040000o`800?l000<0003o003o0000o`001@00o`020000o`/0
0?l0103o0003003o0080003o3_ooool40000o`T00?l000<0003o003o0000o`000P00o`050000o`H0
0?l000<0003o003o0000o`001`00o`020000o`H00?l02P000?l4003o0080003o0P00o`000`3oP000
0?l0003o00040?n000<00?l00P3o00020000o`800?l000<0003o003o0000o`001`00o`0Z0000o`03
0?n00000o`000?l00080003o3_ooool=0?n000<00?l01`3oP0020?l000L0oh000P3o000=0?n000<0
0?l02@3oP002003o00`0oh000P3o000I0?n00080o`001P3oP0000`3o0000oh000?n000020?l000L0
oh000P3o000@0?n001Sooooo000FooooohX0o`003_ooool50000o`H00?l00`000?l2003o00H0003o
2P00o`060000o`03003o00000?l0003o00H00?l02@000?l50?n000800?l00P3oP007003o00<0003o
0P00o`020?n00080o`000`00o`020000o`80o`002@00o`030000o`800?l010000?l2003o00030000
o`00o`000?l000D00?l00P000?l;003o00@0o`000`00o`020000o`kooooo10000?l9003o00030000
o`00o`000?l000800?l01@000?l6003o00030000o`00o`000?l000L00?l00P000?l6003o00X0003o
1000o`020000o`800?l000<0oh00003o0000o`00103oP003003o0080o`000P000?l2003o00030000
o`00o`000?l000L00?l0:P000?l00`3oP0000?l0003o00020000o`kooooo3@3oP003003o00L0oh00
0P3o00070?n00080o`003@3oP003003o00T0oh000P00o`0<0?n00080o`006@3oP0020?l000H0oh00
00<0o`000?n0003oP0000P3o00070?n00080o`00403oP00Hooooo`005_oooon:0?l000kooooo4P00
o`050000o`H00?l000<0003o003o0000o`000P00o`020000o`800?l00`000?l4003o00<0003o0P00
o`020000o`D0oh000P3o00040?n00080o`000`3oP004003o00<0003o1`3oP004003o0080o`001`00
o`020000o`800?l01@000?l4003o00030000o`00o`000?l000@00?l00`000?l9003o0080003o103o
P0000`00o`00003o0000o`020000o`kooooo1000o`000`000?l00?l0003o0006003o00<0003o5`00
o`040?n000@0003o00<0oh000000o`000?l01`000?l8003o00<0003o0P3oP0030000o`800?l00P00
0?l4003o00<0003o0P00o`020000o`<00?l050000?l2003o00`0003o0P00o`070000o`800?l00P00
0?l>ooooo`T0oh00103o00090?n000<00?l00P3oP0030?l00180oh000P3o00020?n00080o`000`3o
P0060?l000800?l000<0oh000?l0003o00000P3o0002003o00<0oh000P00o`090?n00080o`000`3o
P0020?l000@0oh000P3o00090?n000D0o`006@3oP00Hooooo`005_oooon:0?l000kooooo0P000?l@
003o00D0003o0P00o`050000o`H00?l01`3oP002003o00D0003o0P00o`040000o`T00?l000<0oh00
0?l0003o00002@00o`040?l000<0oh00103o00030?n000@00?l00P3oP003003o00@0003o1000o`03
0000o`@00?l02@000?l<003o0080003o3_oooolV003o00L0003o0`00o`020000o`@00?l00P000?l3
003o00H0003o0`00o`0;0000o`800?l000<0003o003o0000o`000P00o`040000o`03003o00000?l0
003o00/0003o0P00o`090000o`03003o00000?l0003o00@00?l00`000?l2003o00/0003o3_ooool2
0?n000<0o`002@3oP0020?l00100oh001000o`0>0?n00080o`000P3oP002003o00030?n0003o0000
o`0001L0oh001P3o000L0?n00080o`000P3oP0050?l000800?l02@3oP0020?l001Sooooo000Foooo
ohX0o`003_ooool20000oa000?l01@000?l2003o00D0003o1P00o`070?n000800?l01@000?l2003o
00@0003o2@00o`000`3oP000o`000?l00009003o00@0o`000`3oP0040?l000<0oh001000o`020?n0
00<00?l010000?l4003o00<0003o1000o`090000o``00?l00P000?l>ooooobH00?l01`000?l3003o
0080003o1000o`020000o`<00?l01P000?l3003o00/0003o0P00o`000`000?l00?l0003o0002003o
00@0003o00<00?l00000o`000?l02`000?l2003o00T0003o00<00?l00000o`000?l01000o`030000
o`800?l02`000?l>ooooo`80oh000`3o00090?n00080o`00403oP004003o00h0oh000P3o00020?n0
00800?l000<0oh000?l0003o00005`3oP0060?l001`0oh000P3o00020?n000D0o`000P00o`090?n0
0080o`006?ooool001KoooooRP3o000>ooooo`@0003o1@00o`020000o`L00?l02@000?l2003o0003
0000o`00o`000?l000800?l0103oP0000`00o`00003o0000o`0;003o00L0003o1`00o`020?l000D0
0?l0103oP0020?l00080oh000`00o`040?n000h00?l010000?l2003o00030000o`00o`000?l00100
0?l00P000?l5003o0080003o0P00o`0>ooooob@00?l00P000?l3003o00H0003o3000o`0D0000o`80
0?l01@3oP0090000o`800?l00P000?l5003o0080003o0P00o`000`000?l00?l0003o00070000o`H0
0?l000<0003o003o0000o`001P000?l5003o00kooooo0P3oP0050?l00100oh000P3o00090?n00080
0?l00P3o00000`3oP000o`000?l000040?n000<0o`001000o`050?n00080o`003@3oP003003o00H0
o`001`3oP0020?l000`0oh00103o00020?n000030?l0003oP000oh000080oh000P3o00050?n00080
o`000P3oP0000`3o0000oh000?n000060?n00003003o003oP000oh000080oh006?ooool001Kooooo
RP3o000>ooooo`@0003o1@00o`020000o`L00?l02@000?l2003o00030000o`00o`000?l000800?l0
103oP0000`00o`00003o0000o`0;003o00L0003o1`00o`020?l000D00?l0103oP0020?l00080oh00
0`00o`040?n000h00?l010000?l2003o00030000o`00o`000?l001000?l00P000?l5003o0080003o
0P00o`0>ooooob@00?l00P000?l3003o00H0003o3000o`0D0000o`800?l01@3oP0090000o`800?l0
0P000?l5003o0080003o0P00o`000`000?l00?l0003o00070000o`H00?l000<0003o003o0000o`00
1P000?l5003o00kooooo0P3oP0050?l00100oh000P3o00090?n000800?l00P3o00000`3oP000o`00
0?l000040?n000<0o`001000o`050?n00080o`003@3oP003003o00H0o`001`3oP0020?l000`0oh00
103o00020?n000030?l0003oP000oh000080oh000P3o00050?n00080o`000P3oP0000`3o0000oh00
0?n000060?n00003003o003oP000oh000080oh006?ooool001KoooooRP3o000>ooooo`800?l01@00
0?l2003o0080003o1`00o`040000o`P00?l00P000?l7003o0080003o1P00o`000`000?l00?l0003o
00060000o`<00?l01P3oP0000`00o`00003o0000o`07003o00@0o`000P00o`000`000?l00?l0003o
0004003o00<0003o1P00o`020000o`<00?l010000?l2003o00030000o`00o`000?l00080003o0P00
o`000`000?l00?l0003o00070000o`80oh0010000?l7003o00kooooo0P000?lB003o00T0003o00<0
0?l00000o`000?l01000o`020000o`T00?l00`000?l6003o00030000o`00o`000?l00080003o1000
o`000`000?l00?l0003o00040000o`03003o00000?l0003o01@0003o0P00o`030000o`P00?l01`00
0?l00`00o`00003o0000o`0?0000o`030?n00000o`000?l000800?l03_ooool40?n000030?l0003o
P000oh0000@0o`002`3oP0050?l000`0oh000P3o00060?n000D0o`00103oP0030?l000H00?l01@3o
P0020?l000`0oh00103o00030?n00080o`001P3oP0000`3o0000oh000?n0000T0?n001Sooooo000F
ooooohX0o`003_ooool2003o00D0003o0P00o`020000o`L00?l010000?l8003o0080003o1`00o`02
0000o`H00?l000<0003o003o0000o`001P000?l3003o00H0oh0000<00?l00000o`000?l01`00o`04
0?l000800?l000<0003o003o0000o`001000o`030000o`H00?l00P000?l3003o00@0003o0P00o`00
0`000?l00?l0003o00020000o`800?l000<0003o003o0000o`001`000?l20?n000@0003o1`00o`0>
ooooo`80003o4P00o`090000o`03003o00000?l0003o00@00?l00P000?l9003o00<0003o1P00o`00
0`000?l00?l0003o00020000o`@00?l000<0003o003o0000o`0010000?l00`00o`00003o0000o`0D
0000o`800?l00`000?l8003o00L0003o00<00?l00000o`000?l03`000?l00`3oP0000?l0003o0002
003o00kooooo103oP0000`3o0000oh000?n000040?l000/0oh001@3o000<0?n00080o`001P3oP005
0?l000@0oh000`3o0006003o00D0oh000P3o000<0?n000@0o`000`3oP0020?l000H0oh0000<0o`00
0?n0003oP000903oP00Hooooo`005_oooon:0?l000kooooo0P00o`0<0000o`H00?l01@000?l4003o
00030000o`00o`000?l001@00?l01@000?l2003o0080oh002`00o`030000o`80o`001`000?l4003o
00<0003o3@00o`020000o`X00?l00P000?l6003o00<0003o1P00o`000`3oP0000?l0003o0002003o
00kooooo1000o`000`000?l00?l0003o00020000o`L00?l03@000?l>003o01L0003o0P3oP0020000
o`<00?l00P000?l20?n00080003o0`00o`080000o`03003o00000?l0003o00@0003o5`00o`020000
o`T00?l01@000?l2003o00kooooo403oP0040?l001T0oh000`3o000;0?n000800?l00P3oP002003o
02<0oh000P00o`0M0?n000<0003o103oP00Hooooo`005_oooon:0?l000kooooo0P00o`0<0000o`H0
0?l01@000?l4003o00030000o`00o`000?l001@00?l01@000?l2003o0080oh002`00o`030000o`80
o`001`000?l4003o00<0003o3@00o`020000o`X00?l00P000?l6003o00<0003o1P00o`000`3oP000
0?l0003o0002003o00kooooo1000o`000`000?l00?l0003o00020000o`L00?l03@000?l>003o01L0
003o0P3oP0020000o`<00?l00P000?l20?n00080003o0`00o`080000o`03003o00000?l0003o00@0
003o5`00o`020000o`T00?l01@000?l2003o00kooooo403oP0040?l001T0oh000`3o000;0?n00080
0?l00P3oP002003o02<0oh000P00o`0M0?n000<0003o103oP00Hooooo`005_oooon:0?l000kooooo
1`00o`040000o`<00?l01P000?l:003o0080oh004P00o`060000o`03003o00000?l0003o00800?l0
0P000?l9003o00030000o`00o`000?l000L0003o1P00o`070000o`@00?l00`000?l2003o0080003o
0`00o`040000o`<00?l01P000?l2003o00030?n00000o`000?l00080003o0P3o0003003o0080003o
0P00o`0>ooooo`@00?l000<0003o003o0000o`005P000?l5003o0080003o0`00o`060?n00080003o
00<00?l00000o`000?l00P00o`070000o`T00?l01`000?l2003o0080003o0P00o`000`3oP000003o
0000o`090000o`800?l09`000?l4003o00kooooo0P3oP0020?l00200oh000P000?l5003o0080o`00
2`3oP0030?l00080oh000P3o0002003o00<0o`000P00o`020?l000h0oh000P00o`0b0?n001Sooooo
000FooooohX0o`003_ooool;003o0080003o00<00?l00000o`000?l03P00o`080000o`h00?l01@00
0?l20?n000h00?l010000?l4003o00030000o`00o`000?l000@00?l00P000?l9003o00030000o`00
o`000?l000L00?l00P000?l5003o00@0003o1@00o`040000o`80o`000`00o`040000o`kooooo0P00
0?l2003o00T0003o00<00?l00000o`000?l00P00o`050000o`800?l00P000?l3003o0080003o0P00
o`040000o`<0oh001000o`0E0000o`80oh001000o`000`3oP000003o0000o`040000o`800?l01@00
0?l5003o00d0003o1@00o`060000o`03003o00000?l0003o0080003o3P00o`040000o`kooooo7@3o
P0030?l000H0oh0000<0003o0?n0003oP0004P3oP0020?l001@0oh000`3o0004003o00T0oh000P3o
00030?n00080o`00103oP0000`3o0000oh000?n0000K0?n001Sooooo000FooooohX0o`003_ooool;
003o0080003o00<00?l00000o`000?l03P00o`080000o`h00?l01@000?l20?n000h00?l010000?l4
003o00030000o`00o`000?l000@00?l00P000?l9003o00030000o`00o`000?l000L00?l00P000?l5
003o00@0003o1@00o`040000o`80o`000`00o`040000o`kooooo0P000?l2003o00T0003o00<00?l0
0000o`000?l00P00o`050000o`800?l00P000?l3003o0080003o0P00o`040000o`<0oh001000o`0E
0000o`80oh001000o`000`3oP000003o0000o`040000o`800?l01@000?l5003o00d0003o1@00o`06
0000o`03003o00000?l0003o0080003o3P00o`040000o`kooooo7@3oP0030?l000H0oh0000<0003o
0?n0003oP0004P3oP0020?l001@0oh000`3o0004003o00T0oh000P3o00030?n00080o`00103oP000
0`3o0000oh000?n0000K0?n001Sooooo000FooooohX0o`003_ooool9003o0080003o4`00o`080000
o`T00?l000<0003o003o0000o`003@000?l5003o00/0003o0P00o`030000o`@00?l00`000?l4003o
0080003o0P00o`030000o`800?l00P000?l2003o00<0003o1000o`070000o`h00?l00P000?l>oooo
o`@00?l01`000?l5003o00H0003o0`00o`020000o`<00?l00P000?l2003o0080003o0P00o`000`3o
P0000?l0003o00020?n000@00?l00`000?l6003o00D0003o0P00o`020000o`<00?l00P000?l2003o
00030000o`00o`000?l000@00?l00`3o00020000o`800?l00P3oP0020000o`L00?l00P000?l5003o
00L0oh000P000?l2003o00030000o`00o`000?l000L00?l0103oP005003o0080003o0P00o`0>oooo
o`/0oh000`3o000F0?n000<00?l03`3oP0020?l00100oh0000<0003o0?n0003oP0000P00o`0B0?n0
00@0o`00803oP0020?l000D0oh006?ooool001KoooooRP3o000>ooooo`T00?l00P000?lC003o00P0
003o2@00o`000`000?l00?l0003o000=0000o`D00?l02`000?l2003o00<0003o1000o`030000o`@0
0?l00P000?l2003o00<0003o0P00o`020000o`800?l00`000?l4003o00L0003o3P00o`020000o`ko
oooo1000o`070000o`D00?l01P000?l3003o0080003o0`00o`020000o`800?l00P000?l2003o0003
0?n00000o`000?l00080oh001000o`030000o`H00?l01@000?l2003o0080003o0`00o`020000o`80
0?l000<0003o003o0000o`001000o`030?l00080003o0P00o`020?n00080003o1`00o`020000o`D0
0?l01`3oP0020000o`800?l000<0003o003o0000o`001`00o`040?n000D00?l00P000?l2003o00ko
oooo2`3oP0030?l001H0oh000`00o`0?0?n00080o`00403oP0000`000?l0oh000?n00002003o0180
oh00103o000P0?n00080o`001@3oP00Hooooo`005_oooon:0?l000kooooo0P00o`050000o`@00?l0
1@000?l@003o0080003o0P00o`020000o`X00?l02@000?l9003o0080003o1@00o`020000o`800?l0
0P000?l2003o00T0003o1`00o`070000o`800?l01`000?l3003o00T0003o0P00o`020000o`D0oh00
10000?l>ooooo`L0003o0P00o`020000o`<00?l03`000?l5003o00D0003o1P3oP002003o00030000
o`00o`000?l000/0003o0P00o`050000o`800?l00P3oP003003o0080oh001000o`000`3oP0000?l0
003o0004003o00D0003o0P00o`0M0000o`X00?l00P000?l2003o00kooooo1`3oP0020?l00080oh00
0`3o000M0?n00080o`000P3oP003003o0080oh000P00o`050?l000h0oh000P00o`020000o`T0oh00
10000?l70?n000<0o`00903oP0020?l001Sooooo000FooooohX0o`003_ooool2003o00D0003o1000
o`050000oa000?l00P000?l2003o0080003o2P00o`090000o`T00?l00P000?l5003o0080003o0P00
o`020000o`800?l02@000?l7003o00L0003o0P00o`070000o`<00?l02@000?l2003o0080003o1@3o
P0040000o`kooooo1`000?l2003o0080003o0`00o`0?0000o`D00?l01@000?l60?n000800?l000<0
003o003o0000o`002`000?l2003o00D0003o0P00o`020?n000<00?l00P3oP004003o00030?n00000
o`000?l000@00?l01@000?l2003o01d0003o2P00o`020000o`800?l03_ooool70?n00080o`000P3o
P0030?l001d0oh000P3o00020?n000<00?l00P3oP002003o00D0o`003P3oP002003o0080003o2@3o
P0040000o`L0oh000`3o000T0?n00080o`006?ooool001Kooooo0P3oP00P0?l00080oh00<P3o0002
0?n00380o`003_ooool9003o00L0003o3P00o`020000o`@00?l00P000?l:003o00H0003o0P00o`00
0`000?l0oh000?n0000=003o00<0003o1P00o`000`000?l00?l0003o00060000o`<00?l00P000?l9
003o0080003o0`00o`040000o`D00?l00P000?l2003o00D0003o0P3o0005003o00@0003o3_ooool7
0000o`@00?l00P000?l00`00o`00003o0000o`0B0000o`800?l00`000?l2003o0080oh001@00o`0;
0000o`800?l010000?l00`00o`00003o0000o`020000o`T00?l00P3oP0050?l000@00?l000<0003o
003o0000o`002@00o`020?n000T0003o0`00o`040000o`/00?l00P3oP0050000o`kooooo0P000?l2
003o00<0oh000P3o00040?n000<0o`005`3oP0020?l00080oh00103o000S0?n000800?l00P000?l2
0?n00080003o0`3o00040?n00080o`006@3oP0000`00o`00o`000?l0000;0?n001Sooooo000Foooo
o`80oh00R03o000>ooooo`@0003o2@00o`030000o`h00?l020000?l>003o0080003o0P00o`000`00
0?l00?l0003o0007003o0080003o1000o`000`000?l00?l0003o0002003o0080oh000P00o`030000
o`@00?l02`000?lC003o00@0003o3000o`020000o`800?l03_ooool90000o`800?l02`000?l00`00
o`00003o0000o`090000o`800?l00`000?l60?n000800?l000<0003o003o0000o`000P00o`090000
o`D00?l00P000?l;003o00D0oh001000o`090000o`80oh000`000?l2003o00T0003o0P00o`050000
o`T0oh001`000?l2003o00kooooo1`3oP0070?l00080oh001P3o00000`3oP0000?l0003o000B0?n0
00@0o`004`3oP0020?l00080oh000P00o`0/0?n00080o`00503oP00Hooooo`005_ooool20?n008P0
o`003_ooool40000o`T00?l00`000?l>003o00P0003o3P00o`020000o`800?l000<0003o003o0000
o`001`00o`020000o`@00?l000<0003o003o0000o`000P00o`020?n000800?l00`000?l4003o00/0
003o4`00o`040000o``00?l00P000?l2003o00kooooo2@000?l2003o00/0003o00<00?l00000o`00
0?l02@000?l2003o00<0003o1P3oP002003o00030000o`00o`000?l000800?l02@000?l5003o0080
003o2`00o`050?n000@00?l02@000?l20?n000<0003o0P00o`090000o`800?l01@000?l90?n000L0
003o0P00o`0>ooooo`L0oh001`3o00020?n000H0o`0000<0oh00003o0000o`004P3oP0040?l001<0
oh000P3o00020?n000800?l0;03oP0020?l001@0oh006?ooool001Kooooo0P3oP0210?l000800?l0
1@3o000>ooooo`800?l00P000?l00`00o`00003o0000o`020000oa000?l00P000?l7003o00@0003o
4`00o`020?n000T00?l02@000?l20?n000h0003o0P00o`050000oa000?l010000?l2003o0080003o
00<00?l00000o`000?l01000o`020000o`03003o00000?l0003o00800?l03_oooolN0000o`800?l0
0P000?l4003o00030000o`00o`000?l000T00?l02@000?l7003o00@0003o1`00o`050000o`@00?l0
1@000?l2003o0080003o0P00o`020?n000D0003o1000o`000`000?l00?l0003o000;003o00<0o`00
1P00o`020000o`D00?l03_oooolF0?n00003003o003oP000oh0003@0oh001@3o00040?n000@00?l0
2P3oP0020?l000@0oh000P00o`0>0?n00080003o3P3oP00Hooooo`005_ooool20?n00840o`000P00
o`050?l000kooooo0P00o`020000o`03003o00000?l0003o0080003o4000o`020000o`L00?l01000
0?lC003o0080oh002@00o`090000o`80oh003P000?l2003o00D0003o4000o`040000o`800?l00P00
0?l00`00o`00003o0000o`04003o0080003o00<00?l00000o`000?l00P00o`0>oooooah0003o0P00
o`020000o`@00?l000<0003o003o0000o`002@00o`090000o`L00?l010000?l7003o00D0003o1000
o`050000o`800?l00P000?l2003o0080oh001@000?l4003o00030000o`00o`000?l000/00?l00`3o
0006003o0080003o1@00o`0>oooooaH0oh0000<00?l00?n0003oP000=03oP0050?l000@0oh001000
o`0:0?n00080o`00103oP002003o00h0oh000P000?l>0?n001Sooooo000FooooohX0o`003_ooool2
0000o`800?l000<0003o003o0000o`000P000?l5003o0080003o1`00o`090000o`@00?l00P000?l:
003o00H0003o0P00o`030000oa/00?l02`000?lE003o00l0003o00<00?l00000o`000?l00P00o`0>
oooooaL0003o1000o`030000oa@00?l03`000?l00`3oP000003o0000o`090000o`800?l00P3oP009
0000o`03003o00000?l0003o00l0003o00<00?l00000o`000?l02@00o`070000o`800?l01`000?l2
003o00kooooo103oP0000`3o0000oh000?n000040?n00080o`002P3oP002003o02T0oh0010000?l2
003o00<0oh00103o00070?n00080003o0P3o00090?n000D0o`000P3oP002003o00030?l0003oP000
oh0000/0oh000`00o`020000o`/0oh006?ooool001KoooooRP3o000>ooooo`80003o0P00o`000`00
0?l00?l0003o00020000o`D00?l00P000?l7003o00T0003o1000o`020000o`X00?l01P000?l2003o
00<0003o6`00o`0;0000oaD00?l03`000?l00`00o`00003o0000o`02003o00kooooo5`000?l4003o
00<0003o5000o`0?0000o`030?n000000?l0003o00T0003o0P00o`020?n000T0003o00<00?l00000
o`000?l03`000?l00`00o`00003o0000o`09003o00L0003o0P00o`070000o`800?l03_ooool40?n0
00030?l0003oP000oh0000@0oh000P3o000:0?n000800?l0:@3oP0040000o`800?l00`3oP0040?l0
00L0oh000P000?l20?l000T0oh001@3o00020?n000800?l000<0o`000?n0003oP0002`3oP003003o
0080003o2`3oP00Hooooo`005_oooon50?l00003003o003o0000o`000080o`003_ooool=0000o`03
003o00000?l0003o00@0003o0`00o`060000o`03003o00000?l0003o01P00?l00`000?l9003o00L0
003o1`3oP006003o0080003o1@00o`020000o`800?l000<0003o003o0000o`000P000?l;003o00X0
003o0P00o`070000o`@00?l03_ooool4003o00030000o`00o`000?l000@00?l01`000?l2003o0080
003o00<00?l00000o`000?l01`000?l7003o00H0003o0`00o`0=0000o`D00?l00P000?l4003o00L0
003o0P3oP0030000o`H00?l03P000?l2003o00D0003o0P3oP0030000o`800?l050000?l>ooooo`h0
oh000P3o000=0?n000<0o`004P3oP0020?l00080oh000P3o00050?n00080o`001@3oP0040?l001<0
oh001P3o00030?n00080o`007@3oP0020?l000D0oh006?ooool001KoooooQ@3o00000`00o`00o`00
0?l000020?l000kooooo3@000?l00`00o`00003o0000o`040000o`<00?l01P000?l00`00o`00003o
0000o`0H003o00<0003o2@00o`070000o`L0oh001P00o`020000o`D00?l00P000?l2003o00030000
o`00o`000?l00080003o2`00o`0:0000o`800?l01`000?l4003o00kooooo1000o`000`000?l00?l0
003o0004003o00L0003o0P00o`020000o`03003o00000?l0003o00L0003o1`00o`060000o`<00?l0
3@000?l5003o0080003o1000o`070000o`80oh000`000?l6003o00h0003o0P00o`050000o`80oh00
0`000?l2003o01@0003o3_ooool>0?n00080o`003@3oP0030?l00180oh000P3o00020?n00080o`00
1@3oP0020?l000D0oh00103o000C0?n000H0o`000`3oP0020?l001d0oh000P3o00050?n001Sooooo
000FooooohX0o`003_ooool40000o`<00?l010000?l3003o00@0003o1000o`080000oa400?l01@00
0?l4003o00L0003o0P3oP008003o00@0003o0P00o`020000o`030?n00000o`000?l000@00?l00P00
0?l7003o00<0003o0P00o`020000oaD00?l010000?l20?n000<0003o0P00o`020000o`kooooo0P00
0?l>003o00H0003o4`00o`020000o`80oh002@000?l2003o00030000o`00o`000?l000H00?l000<0
003o003o0000o`000P00o`030?n000@0003o0P00o`050000o`800?l010000?l7003o01`0003o0P00
o`0;0000o`kooooo2`3oP0020?l000D0oh000P000?l2003o00030?n00000o`000?l000D0oh000P00
o`020000o`T0oh000P3o00020?n00003003o003oP000oh0001@0oh000P00o`0G0?n00080o`002@3o
P0020?l000X0oh000P3o0009003o0080o`001`3oP00Hooooo`005_oooon:0?l000kooooo1@000?l2
003o00@0003o0`00o`020000o`L00?l01P000?l00`00o`00003o0000o`060000o``00?l01P000?l0
0`00o`00003o0000o`020000o`800?l00P3o0003003o0080oh000P000?l:003o0080oh001P00o`00
0`000?l00?l0003o000;003o0080003o2P00o`020000o`T00?l02`000?l>ooooo`800?l00`000?l=
003o00@0003o1@00o`020000o`X00?l010000?l20?n000D0003o2`00o`020000oa<00?l00P000?l=
003o00<0003o2`00o`040000o`<00?l00P000?l7003o00/0003o3_ooool90?n00080o`000P3oP000
0`00o`00003o0000o`02003o0080003o0P3oP0000`3o0000003o0000o`040?l000T0oh0000<0o`00
0?n0003oP0000P3oP0040?l000<0oh000P3o00040?n00003003o003oP000oh0001l0oh001@3o0002
0?n000<0o`006@3oP0020000o`/0oh006?ooool001KoooooRP3o000>ooooo`D0003o0P00o`040000
o`<00?l00P000?l7003o00H0003o00<00?l00000o`000?l01P000?l<003o00H0003o00<00?l00000
o`000?l00P000?l2003o0080o`000`00o`020?n00080003o2P00o`020?n000H00?l000<0003o003o
0000o`002`00o`020000o`X00?l00P000?l9003o00/0003o3_ooool2003o00<0003o3@00o`040000
o`D00?l00P000?l:003o00@0003o0P3oP0050000o`/00?l00P000?lC003o0080003o3@00o`030000
o`/00?l010000?l3003o0080003o1`00o`0;0000o`kooooo2@3oP0020?l00080oh0000<00?l00000
o`000?l00P00o`020000o`80oh0000<0o`000000o`000?l0103o00090?n000030?l0003oP000oh00
0080oh00103o00030?n00080o`00103oP0000`00o`00oh000?n0000O0?n000D0o`000P3oP0030?l0
01T0oh000P000?l;0?n001Sooooo000FooooohX0o`003_ooool4003o00`0003o4P00o`020000o``0
0?l020000?l00`00o`00003o0000o`09003o0080003o2@00o`020000o`030?n00000o`000?l00080
003o0P00o`050000o`80oh001@00o`040000o`T00?l00P000?l00`00o`00003o0000o`040000o`L0
0?l010000?l00`00o`00003o0000o`02003o00kooooo1@000?lV003o00@0003o00<00?l00000o`00
0?l05000o`020000o`T00?l02P000?l9003o0080003o1P00o`000`000?l00?l0003o00040000o`X0
0?l01P000?l2003o00<0003o0P00o`0>oooooaT0oh000P3o000N0?n000800?l00P3oP0020000o`80
o`004`3oP0040?l00080oh0000<0o`000?n0003oP0003@3oP0020?l001T0oh000`3o00020?n001So
oooo000FooooohX0o`003_ooool4003o00`0003o4P00o`020000o``00?l020000?l00`00o`00003o
0000o`09003o0080003o2@00o`020000o`030?n00000o`000?l00080003o0P00o`050000o`80oh00
1@00o`040000o`T00?l00P000?l00`00o`00003o0000o`040000o`L00?l010000?l00`00o`00003o
0000o`02003o00kooooo1@000?lV003o00@0003o00<00?l00000o`000?l05000o`020000o`T00?l0
2P000?l9003o0080003o1P00o`000`000?l00?l0003o00040000o`X00?l01P000?l2003o00<0003o
0P00o`0>oooooaT0oh000P3o000N0?n000800?l00P3oP0020000o`80o`004`3oP0040?l00080oh00
00<0o`000?n0003oP0003@3oP0020?l001T0oh000`3o00020?n001Sooooo000Fooooogl0o`000P3o
P0090?l000kooooo2@000?l5003o0080003o2`00o`030000oaH00?l01@000?l4003o0080oh001@00
o`050000o`@00?l03P000?l4003o0080oh000`00o`040000o`h00?l00P000?l5003o00d0003o3_oo
oolI003o00L0003o1`00o`060000o`800?l01@000?l7003o0080003o2@00o`020000o`T00?l000<0
003o003o0000o`001`000?l4003o00D0003o1P00o`020000oa<00?l02`000?l>ooooo`@0oh0000<0
o`000?n0003oP0000P3o000D0?n000030?l0003oP000oh000080oh000P3o00090?n00080o`0000<0
oh00003o0000o`000P00o`020?n000D00?l00P000?l90?n000800?l04P3oP0030?l000H0oh0000<0
o`000?n0003oP000803oP0020?l00080oh006?ooool001KoooooO`3o00020?n000T0o`003_ooool9
0000o`D00?l00P000?l;003o00<0003o5P00o`050000o`@00?l00P3oP005003o00D0003o1000o`0>
0000o`@00?l00P3oP003003o00@0003o3P00o`020000o`D00?l03@000?l>oooooaT00?l01`000?l7
003o00H0003o0P00o`050000o`L00?l00P000?l9003o0080003o2@00o`000`000?l00?l0003o0007
0000o`@00?l01@000?l6003o0080003o4`00o`0;0000o`kooooo103oP0000`3o0000oh000?n00002
0?l001@0oh0000<0o`000?n0003oP0000P3oP0020?l000T0oh000P3o00000`3oP0000?l0003o0002
003o0080oh001@00o`020000o`T0oh000P00o`0B0?n000<0o`001P3oP0000`3o0000oh000?n0000P
0?n00080o`000P3oP00Hooooo`005_oooomj0?l00080oh003P3o000>ooooo`80003o0P00o`000`00
0?l00?l0003o00040000o`D00?l010000?l:003o0080003o0P00o`020000o``00?l00P000?l4003o
00D0003o2@00o`040000o`03003o00000?l0003o01P0003o0`3oP0040000o`X00?l05P000?l>oooo
oaT00?l010000?l00`00o`00003o0000o`07003o00H0003o0P00o`050000o`@00?l000<0003o003o
0000o`000P000?l7003o00D0003o1000o`0B0000o`800?l04P000?l00`00o`00003o0000o`020000
oa800?l03_ooool=0?n000030?l0003oP000oh0001d0oh000P3o00070?n00080o`00703oP0040?l0
00`0oh000P3o000@0?n000@0o`000P3oP0000`3o0000oh000?n000060?n000030?l0003oP000oh00
0080oh006?ooool001KoooooNP3o00020?n000h0o`003_ooool20000o`800?l000<0003o003o0000
o`0010000?l5003o00@0003o2P00o`020000o`800?l00P000?l<003o0080003o1000o`050000o`T0
0?l010000?l00`00o`00003o0000o`0H0000o`<0oh0010000?l:003o01H0003o3_oooolI003o00@0
003o00<00?l00000o`000?l01`00o`060000o`800?l01@000?l4003o00030000o`00o`000?l00080
003o1`00o`050000o`@00?l04P000?l2003o0180003o00<00?l00000o`000?l00P000?lB003o00ko
oooo3@3oP0000`3o0000oh000?n0000M0?n00080o`001`3oP0020?l001`0oh00103o000<0?n00080
o`00403oP0040?l00080oh0000<0o`000?n0003oP0001P3oP0000`3o0000oh000?n000020?n001So
oooo000FooooohX0o`003_ooool;0000o`D00?l010000?l2003o00D0003o1`00o`040000o`h00?l0
1`000?l=003o00X0003o1P00o`030000o`H00?l01`000?l;003o00030000o`00o`000?l000800?l0
3@000?l00`00o`00003o0000o`020000o`kooooo0P00o`030000o`800?l00P000?lB003o00<0003o
3`00o`030000oaT00?l06`000?l2003o00H0003o00<00?l00000o`000?l050000?l2003o00030000
o`00o`000?l000800?l03_ooool2003o0380oh000P00o`020?n00003003o003oP000oh0000H0oh00
0`00o`040?n000L0o`000P3oP003003o01P0oh001@3o00030?n000H0o`00403oP00Hooooo`005_oo
oon:0?l000kooooo0P000?l@003o0080003o0`00o`0;0000o`800?l00`000?l9003o00@0003o0P00
o`020000o`L00?l00`3oP002003o00L0003o0P00o`020000o`800?l00`000?l4003o0080003o1`00
o`070000o`L00?l00P000?l5003o00@0003o2`00o`030000o`800?l03_ooool7003o00@0003o2@00
o`030000o`800?l01@000?l9003o00@0003o1000o`000`000?l00?l0003o0009003o02H0003o4P00
o`000`000?l00?l0003o00040000o`D00?l010000?l3003o0080003o0P00o`0>ooooo`T0oh000P3o
000E0?n00080003o9`3oP0020?l000@0oh000P00o`090?n000030?l0003oP000oh0000@0oh000P3o
00050?n00080o`001@3oP0020?l001L0oh000P000?lHooooo`005_oooon:0?l000kooooo0P000?l@
003o0080003o0`00o`0;0000o`800?l00`000?l9003o00@0003o0P00o`020000o`L00?l00`3oP002
003o00L0003o0P00o`020000o`800?l00`000?l4003o0080003o1`00o`070000o`L00?l00P000?l5
003o00@0003o2`00o`030000o`800?l03_ooool7003o00@0003o2@00o`030000o`800?l01@000?l9
003o00@0003o1000o`000`000?l00?l0003o0009003o02H0003o4P00o`000`000?l00?l0003o0004
0000o`D00?l010000?l3003o0080003o0P00o`0>ooooo`T0oh000P3o000E0?n00080003o9`3oP002
0?l000@0oh000P00o`090?n000030?l0003oP000oh0000@0oh000P3o00050?n00080o`001@3oP002
0?l001L0oh000P000?lHooooo`005_oooon:0?l000kooooo0P00o`020000oa000?l00P000?l30?n0
00L0003o0P3oP002003o00<0003o3@00o`050000o`80oh000P00o`020000o`D00?l010000?l@003o
0080003o00<0oh000000o`000?l01000o`070000o`D00?l010000?l5003o00H0003o0`00o`020?n0
00@00?l000<0oh00003o0000o`000P00o`0>ooooo`L00?l01P000?l5003o00D0003o0P00o`020000
o`800?l000<0003o003o0000o`000P000?l7003o0080003o4P00o`050000o`800?l01`000?l6003o
00T0003o1@00o`020000o`800?l000<0003o0?n0003oP0000P3oP005003o00L0003o0P00o`020000
o`800?l01@000?l2003o0080003o0P00o`030000o`800?l03_ooool40?n000030?l0003oP000oh00
00L0oh000P3o00040?n000D0o`00103oP0000`3o0000oh000?n000040?n00080003o6@3oP002003o
01L0oh001@3o00060?n000D0o`001@3oP0090?l001@0oh006?ooool001KoooooRP3o000>ooooo`80
0?l00P000?l@003o0080003o0`3oP0070000o`80oh000P00o`030000o`d00?l01@000?l20?n00080
0?l00P000?l5003o00@0003o4000o`020000o`030?n000000?l0003o00@00?l01`000?l5003o00@0
003o1@00o`060000o`<00?l00P3oP004003o00030?n00000o`000?l000800?l03_ooool7003o00H0
003o1@00o`050000o`800?l00P000?l2003o00030000o`00o`000?l00080003o1`00o`020000oa80
0?l01@000?l2003o00L0003o1P00o`090000o`D00?l00P000?l2003o00030000o`3oP000oh000080
oh001@00o`070000o`800?l00P000?l2003o00D0003o0P00o`020000o`800?l00`000?l2003o00ko
oooo103oP0000`3o0000oh000?n000070?n00080o`00103oP0050?l000@0oh0000<0o`000?n0003o
P000103oP0020000oaT0oh000P00o`0G0?n000D0o`001P3oP0050?l000D0oh002@3o000D0?n001So
oooo000FoooooeP0o`000`00o`0T0?l000800?l02@3o000>ooooo`@00?l000<0003o003o0000o`00
1`000?l8003o00<0003o1000o`070000oa800?l00P000?l00`00o`00003o0000o`040000o`800?l0
20000?l40?l001H00?l01@000?l4003o00030000o`00o`000?l00080003o3000o`020?n000800?l0
0P3o0007003o00kooooo0P000?l5003o00H0003o1@00o`090000o`L00?l00P000?l3003o0080003o
0P00o`020000o`L00?l01@000?l2003o00H0003o1@00o`020000o`<00?l01P000?l00`00o`00003o
0000o`0?0000o`L00?l030000?l4003o00<0003o0P00o`020000o`800?l00P000?l3003o0080003o
3_ooool=0?n000030?l0003oP000oh000180oh000P00o`020?l000<0003o0P3o000V0?n00003003o
003oP000oh0000@0oh000P3o00070?n000D0o`001P3oP003003o00@0oh0000<00?l00?n0003oP000
1`3oP0020?l000800?l010000?l50?n001Sooooo000FoooooeP0o`000`00o`0T0?l000800?l02@3o
000>ooooo`@00?l000<0003o003o0000o`001`000?l8003o00<0003o1000o`070000oa800?l00P00
0?l00`00o`00003o0000o`040000o`800?l020000?l40?l001H00?l01@000?l4003o00030000o`00
o`000?l00080003o3000o`020?n000800?l00P3o0007003o00kooooo0P000?l5003o00H0003o1@00
o`090000o`L00?l00P000?l3003o0080003o0P00o`020000o`L00?l01@000?l2003o00H0003o1@00
o`020000o`<00?l01P000?l00`00o`00003o0000o`0?0000o`L00?l030000?l4003o00<0003o0P00
o`020000o`800?l00P000?l3003o0080003o3_ooool=0?n000030?l0003oP000oh000180oh000P00
o`020?l000<0003o0P3o000V0?n00003003o003oP000oh0000@0oh000P3o00070?n000D0o`001P3o
P003003o00@0oh0000<00?l00?n0003oP0001`3oP0020?l000800?l010000?l50?n001Sooooo000F
ooooogl0o`000P000?l90?l000kooooo1000o`050?n000D0003o3`00o`070000o`L00?l00P000?l9
003o00<0003o1000o`020000o`<00?l00P000?l4003o00<0o`001P00o`000`000?l00?l0003o0006
003o00<0003o0P00o`020000o`800?l01@000?l5003o00@0003o1@00o`020000o`@00?l000<0003o
0?n0003oP000103oP002003o00D0003o3_ooool2003o0080003o0`00o`070000o`H00?l01@000?l4
003o00D0003o1000o`070000o`D00?l00P000?l9003o00@0003o1@00o`090000o`800?l03P000?l4
003o00030000o`3oP000oh0000@0oh003000o`020000o`80oh000`00o`020?n00080003o0P00o`07
0000o`kooooo0P00o`0]0?n000030?l0003oP000oh0000H0oh0000<00?l00?n0003oP0000P00o`02
0?l000h0oh00103o000P0?n000800?l05@3oP002003o01Sooooo000Fooooof@0o`000P3oP00T0?l0
00kooooo10000?l00`3oP000003o0000o`020000o`@00?l00`000?l@003o0080003o5`00o`090000
o`800?l00P000?l70?n001@00?l01@000?l4003o0080003o00<00?l00000o`000?l00P000?l5003o
0080003o1`00o`040?l000<00?l010000?l>ooooo`L00?l01`000?l8003o00030?n000000?l0003o
00@0003o00<00?l00000o`000?l03`000?l00`00o`00003o0000o`070000o`80oh001P000?l5003o
00`0003o1P00o`030000o`@00?l00P000?l2003o00D0003o0P00o`020000o`03003o00000?l0003o
00D0003o1P00o`020000o`D00?l00P3o0005003o0080003o3_ooool40?n000<00?l06@3oP002003o
0080o`008P3oP002003o03@0oh0000<0o`000?n0003oP0001`3oP0040?l001Sooooo000Fooooof@0
o`000P3oP00T0?l000kooooo10000?l00`3oP000003o0000o`020000o`@00?l00`000?l@003o0080
003o5`00o`090000o`800?l00P000?l70?n001@00?l01@000?l4003o0080003o00<00?l00000o`00
0?l00P000?l5003o0080003o1`00o`040?l000<00?l010000?l>ooooo`L00?l01`000?l8003o0003
0?n000000?l0003o00@0003o00<00?l00000o`000?l03`000?l00`00o`00003o0000o`070000o`80
oh001P000?l5003o00`0003o1P00o`030000o`@00?l00P000?l2003o00D0003o0P00o`020000o`03
003o00000?l0003o00D0003o1P00o`020000o`D00?l00P3o0005003o0080003o3_ooool40?n000<0
0?l06@3oP002003o0080o`008P3oP002003o03@0oh0000<0o`000?n0003oP0001`3oP0040?l001So
oooo000Fooooo`80oh00@03o00020?n00200o`000P3oP00T0?l000kooooo1`00o`020000o`/00?l0
0`000?lO003o00L0003o1@00o`020000o`d00?l000<0003o003o0000o`001P00o`030?n000800?l0
10000?l<003o0080003o2`00o`050?n000L00?l00P000?l>ooooo`800?l00P000?l00`00o`00003o
0000o`070000o`P00?l000<0003o003o0000o`001@00o`080000o`L00?l00`000?l4003o00L0003o
0P00o`020000o`L00?l030000?l2003o0080003o0P00o`090000oa000?l00`000?l?003o0080o`00
1@00o`0>ooooo`@0oh0000<0003o0?n0003oP0001P3oP0000`3o0000oh000?n000020?l000T0oh00
0P3o000<0?n00080o`000P3oP002003o00T0oh000`00o`040?l000X0oh00103o000F0?n000<0o`00
1P3oP0000`3o0000oh000?n0000K0?n001Sooooo000Fooooo`80oh00@03o00020?n00200o`000P3o
P00T0?l000kooooo1`00o`020000o`/00?l00`000?lO003o00L0003o1@00o`020000o`d00?l000<0
003o003o0000o`001P00o`030?n000800?l010000?l<003o0080003o2`00o`050?n000L00?l00P00
0?l>ooooo`800?l00P000?l00`00o`00003o0000o`070000o`P00?l000<0003o003o0000o`001@00
o`080000o`L00?l00`000?l4003o00L0003o0P00o`020000o`L00?l030000?l2003o0080003o0P00
o`090000oa000?l00`000?l?003o0080o`001@00o`0>ooooo`@0oh0000<0003o0?n0003oP0001P3o
P0000`3o0000oh000?n000020?l000T0oh000P3o000<0?n00080o`000P3oP002003o00T0oh000`00
o`040?l000X0oh00103o000F0?n000<0o`001P3oP0000`3o0000oh000?n0000K0?n001Sooooo003o
ooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooooooo
P_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oo
oooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2
ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooo
ooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_oo
ool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {967.688, 0}} -> {-0.100021, -0.152945, \
0.00657284, 0.00657284}, {{15.1875, 167.312}, {944.375, 790.875}} -> \
{-0.129866, -0.18615, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {940.688, \
871.062}} -> {-0.901974, -42.331, 0.0372819, 1.49372}, {{18.8125, 163.688}, \
{864.125, 794.5}} -> {-12.4241, -58.7232, 0.558072, 0.558072}, {{167.312, \
319.5}, {944.375, 790.875}} -> {-1.18015, -0.18615, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {940.688, 871.062}} -> {-6.57349, -42.331, 0.0372819, \
1.49372}, {{170.938, 315.812}, {864.125, 794.5}} -> {-97.3209, -58.7232, \
0.558072, 0.558072}, {{319.5, 471.625}, {944.375, 790.875}} -> {-2.23043, \
-0.18615, 0.00690264, 0.00690264}, {{323.125, 468}, {940.688, 871.062}} -> \
{-12.2473, -42.331, 0.0372819, 1.49372}, {{323.125, 468}, {864.125, 794.5}} -> \
{-182.252, -58.7232, 0.558072, 0.558072}, {{471.625, 623.75}, {944.375, \
790.875}} -> {-3.28049, -0.18615, 0.00690264, 0.00690264}, {{475.25, \
620.125}, {940.688, 871.062}} -> {-17.9188, -42.331, 0.0372819, 1.49372}, \
{{475.25, 620.125}, {864.125, 794.5}} -> {-267.149, -58.7232, 0.558072, \
0.558072}, {{15.1875, 167.312}, {790.875, 637.312}} -> {-0.129834, -1.24583, \
0.00690229, 0.00690229}, {{18.75, 163.688}, {787.188, 717.562}} -> \
{-0.900809, -271.617, 0.0372819, 1.49372}, {{18.75, 163.688}, {710.562, \
640.938}} -> {-12.3996, -144.4, 0.557995, 0.557995}, {{167.312, 319.5}, \
{790.875, 637.312}} -> {-1.17946, -1.24521, 0.00689983, 0.00689983}, \
{{170.938, 315.812}, {787.188, 717.562}} -> {-6.57349, -271.617, 0.0372819, \
1.49372}, {{170.938, 315.812}, {710.562, 640.938}} -> {-97.3209, -144.422, \
0.558072, 0.558072}, {{319.5, 471.625}, {790.875, 637.312}} -> {-2.23029, \
-1.24583, 0.00690229, 0.00690229}, {{323.062, 468}, {787.188, 717.562}} -> \
{-12.2462, -271.617, 0.0372819, 1.49372}, {{323.062, 468}, {710.562, \
640.938}} -> {-182.204, -144.4, 0.557995, 0.557995}, {{471.625, 623.75}, \
{790.875, 637.312}} -> {-3.2803, -1.24583, 0.00690229, 0.00690229}, \
{{475.188, 620.125}, {787.188, 717.562}} -> {-17.9177, -271.617, 0.0372819, \
1.49372}, {{475.188, 620.125}, {710.562, 640.938}} -> {-267.089, -144.4, \
0.557995, 0.557995}, {{15.1875, 167.312}, {637.312, 483.812}} -> {-0.129866, \
-2.30569, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {633.625, 564}} -> \
{-0.901974, -500.997, 0.0372819, 1.49372}, {{18.8125, 163.688}, {557.062, \
487.438}} -> {-12.4241, -230.086, 0.558072, 0.558072}, {{167.312, 319.5}, \
{637.312, 483.812}} -> {-1.18015, -2.30569, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {633.625, 564}} -> {-6.57349, -500.997, 0.0372819, \
1.49372}, {{170.938, 315.812}, {557.062, 487.438}} -> {-97.3209, -230.086, \
0.558072, 0.558072}, {{319.5, 471.625}, {637.312, 483.812}} -> {-2.23043, \
-2.30569, 0.00690264, 0.00690264}, {{323.125, 468}, {633.625, 564}} -> \
{-12.2473, -500.997, 0.0372819, 1.49372}, {{323.125, 468}, {557.062, \
487.438}} -> {-182.252, -230.086, 0.558072, 0.558072}, {{471.625, 623.75}, \
{637.312, 483.812}} -> {-3.28049, -2.30569, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {633.625, 564}} -> {-17.9188, -500.997, 0.0372819, \
1.49372}, {{475.25, 620.125}, {557.062, 487.438}} -> {-267.149, -230.086, \
0.558072, 0.558072}, {{15.1875, 167.312}, {483.812, 330.312}} -> {-0.129866, \
-3.36525, 0.00690264, 0.00690264}, {{18.8125, 163.688}, {480.125, 410.5}} -> \
{-0.901974, -730.284, 0.0372819, 1.49372}, {{18.8125, 163.688}, {403.562, \
333.938}} -> {-12.4241, -315.75, 0.558072, 0.558072}, {{167.312, 319.5}, \
{483.812, 330.312}} -> {-1.18015, -3.36525, 0.00690264, 0.00690264}, \
{{170.938, 315.812}, {480.125, 410.5}} -> {-6.57349, -730.284, 0.0372819, \
1.49372}, {{170.938, 315.812}, {403.562, 333.938}} -> {-97.3209, -315.75, \
0.558072, 0.558072}, {{319.5, 471.625}, {483.812, 330.312}} -> {-2.23043, \
-3.36525, 0.00690264, 0.00690264}, {{323.125, 468}, {480.125, 410.5}} -> \
{-12.2473, -730.284, 0.0372819, 1.49372}, {{323.125, 468}, {403.562, \
333.938}} -> {-182.252, -315.75, 0.558072, 0.558072}, {{471.625, 623.75}, \
{483.812, 330.312}} -> {-3.28049, -3.36525, 0.00690264, 0.00690264}, \
{{475.25, 620.125}, {480.125, 410.5}} -> {-17.9188, -730.284, 0.0372819, \
1.49372}, {{475.25, 620.125}, {403.562, 333.938}} -> {-267.149, -315.75, \
0.558072, 0.558072}, {{15.1875, 167.312}, {330.312, 176.75}} -> {-0.129834, \
-4.42477, 0.00690229, 0.00690229}, {{18.75, 163.688}, {326.625, 257}} -> \
{-0.900809, -959.57, 0.0372819, 1.49372}, {{18.75, 163.688}, {250, 180.375}} -> \
{-12.3996, -401.391, 0.557995, 0.557995}, {{167.312, 319.5}, {330.312, \
176.75}} -> {-1.17946, -4.42301, 0.00689983, 0.00689983}, {{170.938, \
315.812}, {326.625, 257}} -> {-6.57349, -959.57, 0.0372819, 1.49372}, \
{{170.938, 315.812}, {250, 180.375}} -> {-97.3209, -401.449, 0.558072, \
0.558072}, {{319.5, 471.625}, {330.312, 176.75}} -> {-2.23029, -4.42477, \
0.00690229, 0.00690229}, {{323.062, 468}, {326.625, 257}} -> {-12.2462, \
-959.57, 0.0372819, 1.49372}, {{323.062, 468}, {250, 180.375}} -> {-182.204, \
-401.391, 0.557995, 0.557995}, {{471.625, 623.75}, {330.312, 176.75}} -> \
{-3.2803, -4.42477, 0.00690229, 0.00690229}, {{475.188, 620.125}, {326.625, \
257}} -> {-17.9177, -959.57, 0.0372819, 1.49372}, {{475.188, 620.125}, {250, \
180.375}} -> {-267.089, -401.391, 0.557995, 0.557995}, {{15.1875, 167.312}, \
{176.75, 23.25}} -> {-0.129866, -5.48479, 0.00690264, 0.00690264}, {{18.8125, \
163.688}, {173.062, 103.438}} -> {-0.901974, -1188.95, 0.0372819, 1.49372}, \
{{18.8125, 163.688}, {96.5, 26.875}} -> {-12.4241, -487.113, 0.558072, \
0.558072}, {{167.312, 319.5}, {176.75, 23.25}} -> {-1.18015, -5.48479, \
0.00690264, 0.00690264}, {{170.938, 315.812}, {173.062, 103.438}} -> \
{-6.57349, -1188.95, 0.0372819, 1.49372}, {{170.938, 315.812}, {96.5, \
26.875}} -> {-97.3209, -487.113, 0.558072, 0.558072}, {{319.5, 471.625}, \
{176.75, 23.25}} -> {-2.23043, -5.48479, 0.00690264, 0.00690264}, {{323.125, \
468}, {173.062, 103.438}} -> {-12.2473, -1188.95, 0.0372819, 1.49372}, \
{{323.125, 468}, {96.5, 26.875}} -> {-182.252, -487.113, 0.558072, 0.558072}, \
{{471.625, 623.75}, {176.75, 23.25}} -> {-3.28049, -5.48479, 0.00690264, \
0.00690264}, {{475.25, 620.125}, {173.062, 103.438}} -> {-17.9188, -1188.95, \
0.0372819, 1.49372}, {{475.25, 620.125}, {96.5, 26.875}} -> {-267.149, \
-487.113, 0.558072, 0.558072}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize overall classifications of test images", "Subsection"],

Cell[BoxData[
    \(\(resultsCombined = 
        Map[VisualizeResults[Times\  @@ #, \ colors, \ 
              DisplayFunction \[Rule] Identity] &, \ probs];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gresultsCombined = 
        Map[Last, resultsCombined];\)\), "\[IndentingNewLine]", 
    \(\(gimages = \(ShowImage[#, 1, 255, 0, 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ 
          testData;\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gimages], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[gresultsCombined], ImageSize \[Rule] 640, 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
%%ImageSize: 640 74.4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B793CD6F504F4A31642F664A84521F564C28401F175859354E22154250686D6A192C553D
371D503856562725693F3C371A3B59582538755E2247404A403B4F1F5B7A53333E440B2F
712948272C782F3C3F553A452C4E2B7773885B454E523B6F3737286D4C5E997F673D703D
675B674E2B4A60314E8457465C395D493856554350534F43804989515A6D3C673653867C
4CAC6325486E655A836F3C776324698457446F5747A1764B7A2F3686826762704540668C
695F264F78383E9E616AC19A5A94865555635F377B65678E5B465F414FA2676995415FCD
683C5D3B2D7A796F441F8F5B3A5597A176374D6A42706F3B23986959B48C4F2B54683C38
3C6A497C9B6D42456F3B66524267685A3E9BA64C3B33715B597EA49A5A4776794B8F985C
572E8F51387B5D273F6444666A762A5BAC4D2E55649B854F796263376B593C96
B187B5643F504B236238766455682D5B3D232916195F563E4A31234A5B5C60963F284138
35454636446141246D40354A4B5459682D3563662C5F635B404A5F334C846B37487D2336
812F41492D883E3844694C49405F2D708D865B4B494C3F794B3C2C5D3E43A0AD6F4D6B30
795E51651C3E6A3E5084563776477772355D583C677B774277388888534232745F465D44
45BB8641497C2B336877409472476278603B62753C6465617A523F846E6567575D755598
79724086A0733BA34B3CBAA25B8D98384261694A71303E69624F483935725C89B6253CB9
7F3D724721417A644D309A6152385C7559377A9E5A6A7D402C7D70478D67422456707C59
49703C81BA9257437B275D67525E66563E6A7F58452C6A6A5D5B668963446F5A32847E74
552D78843A605B2836703D6B66853B66A171352D2F807856A99E8639715A309A
A27B8D74455E6E2C813D7D68346B35593B1B291E205E4F42473B2B495866568D412E3227
2A503E2D3981522160473E525460565125346D5D23725832384D5633438E322D4F70282D
5C274458319332395C9055434F382150716F4E59542A2D51453C33616534758F66528B41
5940417F36455D204A8486365D2963914364412544547B4366315F845164384433404D54
35897E474981714E66752A898C53708248588AA1487C323A677D4E8B5C43708286685CB3
85652D5D737B40B2955AC9A63B7D955F4A5A7F4C8A76506664525E512D71507B9B4D46BF
7F4189812D338B5B4F2B7F62613E716B794A488A6263714D51888C4B9974352F737D9054
447053589C855E3C8749566062595957456383634E2A6E5D6C755980754068894F6B9887
4B2D6C85416871333C743D65646F2E79A4873F2D37842E3C6D8082376C2F1C7E
BD8A6E7C4963762D7C416F63205F3D553514282A275F4D30505432475056578E3E383324
3350422029826820541C2C47405558512727583A1969846334475B4147916E3B3F773329
5F2F51592D89212842734256583D25738E7439667E593A563A291D3B724C91A256408D4F
614035733545512B315982386036557D4551553D484D6E4A82565C785093454B313C6B80
529C6F30578989527A7B3E8EA23E83A461375E99496D705B668662A99F8C73619A5957BF
AD9C3B6E5C462F7E8C61C1916A748E634A544C54A17F5A5E4D3F51552B683972A86D459C
8432637639278C5A503A7C554E3A675C774B4785666A6A452A6A9152886E40234C5E7D57
40686163916C5A3195545A55444D5D4A487872413C26764C6D81588780396987427C8E7A
3744848F4E616B21307547657B642B60984D31384A8977396A7D562A7959216B
934559674770391F63404A1711553849380926322647481D3141284E281F317743374730
283E453520715819606039403843687341275A3D19618C80454D451E4086653A415C2C36
834B5D4C28745F405563273A6360347B8D662350614D355243311E326035899C60478E58
5E4F3B703154624D37527F4C794F4D6630626D445257502B68644B783F763E673D314D6E
4E9A8B4741745D3D61735278B15B796D7E406C8745848F71707450918E8E6D6D71453FAF
88904A7F5E8D3A7B7551C0866A75A1634B4C8539A18A525C82563D5E2869526DAD4D3F7E
8E3360583B1F8F543540604345407068684E4279726C7A5636678F61786746294B52825F
42817A599C776436924459492B4D7753477269532937907E89765D873636808F537F974A
1B325B72386E7F3B4B99385758714884A1753B222F757350868D8F5757472873
A27469723C4D5A2E4826544F1646394A5C1B393120315A4D453A1743553F4D9A33336762
2A13305522804915545E353E2D29607B4E29475A2849817D5057545F346B6B37554E211D
62434E47236D4D386568774055713893AB885B585E3E3F647253262D5B2376A0784E9228
5965396A233A56553F5F67306B5252823D435F2A49657B496943467D4B5A3062513F564F
3485A56D4864775F6869554FBF7D867A9539648A5F809F7573918796948A6E889C8A49CC
6D7F3D7C659449748A46A1796758A6664F588C2F848F4A6D7D534166227D7766A6644775
9A3D6168342E8A9C6F5468A847213F3B6F494F77345E7469375C7E4C839A5C37484F803A
51778D44B689212B7755616C2F2D40563465867C3D205964485A8D9B4C254A733B819B76
3E3D548750546F2A3B8A4C66566B4A999E7D46282D652C5E80708C5E74441966
7A5CAF9E4F50703C61483F5F1C321E30551C3B270F1A4B413E34152D4D405FA641224163
30392F4022838728515F4357663B496D5D3055804D4B8A3F324D586B326A592A6C7A401F
682D3256396E3322607879407236195F9C804660834327383E432539753469897044A35C
444D2C735F44513D334B8E4D6B573D7B65406A47435282616C714588546A5455533C5580
5684A374385E9568706C5E47CE90737A9F4165AA757A886774896C86A48174B490865DC8
7A4F4582908E4D707429828A6047B0495C7E882B67463873875040542B70895C9E5E1E5E
8B4869712C1A73763033595C473F5646915E40726F5960464C7866264260633D5F66914E
375F6838958A5B37725045503F41584F2C635B5247296D767150868A6E418EA971819568
2A51809D6A70993122695A4F9C7D316B756448282C675C34603D7B66686A3C5D
779FD0B85A604E2B6E6C565E224E50304F093846231B572A3D5D3135432B5495662E453B
2A60412F105B702857312746693C5955151C445F3837645341464A47287D73295C5A5320
624B30654357733F4B786D417C62337DB583353B565F364143371921634A79A272379E68
385F41777D41497B444E986B5F79457F6B456A54494B7165607643886166584867455C85
6B72A07F3764A8696B6F4E43AF715B87874F8FC77C657E4D7B7D626E903A42727E7B48AE
8A74465C63794A70934197894A5DA84B323E643A70864C5B84475862235C6B4CA7723646
772F5470561D7A883B515C7252556B4B9C6F45677C6E656D3760906466665A2B3D4E9175
375A894498957D45707646544E466B73555A5F62303E85978D4F9D9B562B4A945683BC93
4C31417E404A7E522E674132997D4A8C9A513A47516F5B6A8D3E7A5D3F6C4556
5872D3B9585758294E4D413214414129581F31400E136D3E263819385A2A4A846628546F
34472D502574621C475833393D296C795F233755442C7872574F4368226B833663452C1E
59653A674060854E507A4B2C8166396CA885654B5959433F45482B2C6B5D6F92A3469968
34604B748B43488C46518F6F6887467A605675605048614367873C7C2C665A3A55294E7A
5D5CAD5D38637F625A873F388F5D51977936537F745A9056636F5963B88F67B5A37146A1
AB7F4E9076754459864CA2A07C63B56B45416035619055618C4B3B662F4F5D318682413D
7D5C5484711F61B05E546D7548557F6692513E6A6274986A326FA97C7A756234405C9B83
3D6C98408D9D663E8F7846614D2344556B598F804D2F5D764A3D8496893750AC706AA088
76433F937444876A38566343B1A35E8A95655425305548509B4983803D59364B
5442A1BC814D6B52433B366E28414E2153282F4F19154C34202F1D264D32648C4B183969
303B33432665733F436E362D5237546F84362C504524745957514680325F9D444951691B
4972386335378F4158766F476A593965B3846C47483C3D507062342D6A465493A3537D49
33664A7D4F34587A44556A31626F437540315F57444C634848773B79535858375233496C
5E47AB804153804D4B8C634E986845767E596A8563528B6A75755248AA9163B88F6862A2
9D78558C7F9B625D9E5B96BD6753C36A584775445E96565D9F664460373D7D5185844B36
83634980683071C96858817770283B3E71434880523D5E83326194446AA67C613D47834C
335887438AAD5F29534F3A665F4748564A3D7067613A62765E578C8E8F3D46B48E709D93
85483C7B6A498A7246496E469B67616C9269552B335C623C967A838337513451
534454C7AF586B5F3D8740813444722A4E362661261550411D2C2C2E3C3469735A203364
373C3F412A5A7E4339783C3161495D4C7B3026552B1959464B56507C364E8C424090831C
4079456C413596295D7D7B556B60283E706F5441483A1D3D455235336135456587447B63
3147347665313C5C3F65856764693F7D83497741374683774C793A5A64544C3C6C425D5C
45398C7E455A9A6D4D87494C9A7F5783683377919D5A965F7D90754CB16F51A8A99060B2
9A5F2E70869A5850852950907B47CC74344862425C7A397F8E60544423539E627DA1394E
85674CA2251940A659417F75805653589075416D685A765441869B5A41555D2A395A8476
4246765B72A3833A64834457553F45535D44735D3F3B536D626491828F5A39BC8C68997E
74465D8884547A7641677E4D8764515CA98E6332366B41235C8A94642E4E1B3C
5B4548C0B95D656935853E773C577B314C4E21602F15433A1D302929403C61787D33365C
45514243274EAB57316D38566E446058512E476444186D3122313F623744851F1F56671C
38451F494F3077173A59593F4E58232D877C4E3E586E3B42473C1B3B636E608CB4414F6E
3F54295182474442274B75806C763F5E8E4569583F45798E5488496D727270466D48597D
7440976E336B9879487364377B835781735B456395578F5A4E616C50BF6B4C85928659A0
976A4B6864803C619C526BA57C34AE6A392E515566914E4464435C602C31783B92943620
6733365A512A37C432337B3D4254636C7E643E5C585C916E294F8E7E4D6A581D21426588
4B4671707DB47A2D776F375E4332587654456A5A3E416EA367678E8C812B42A47F4D8B70
2B224064654385371C48693880A0403D7A5F512E3359292D3E746C713983473E
554E3EA1A9635848336A3040152F56354C47195C40173C3319312A2B4219335B713B3032
1242373C0D286244225D252C463E585D39231D45541D54685E3A3B552D449E541E49601F
34854154652898614B64795F4B6D473799872F2D3C3C43475249303347524781AF6E5162
2F66534C8D50547E4F55747D7B9E595E75487F6843465C3C498A49604F4B69474D37395F
7241A87D3546A98447797049999252827C70425570508D8A5A9C5D3E8598788C904D3D85
A68051677082513F8A5B81A3643D986D38324B4B5A8D6849774051593E32A06D7E893124
5F493059433744C75A458D466330507D82743A5553377F7C39717F2F35828856224B615F
315F836D72BC601886753C5A5B1F2D43573B5E6246293B5064587AB2753022886D57868A
6F3C3F71552C916E3D54691C558E684B7F713A3A52664E4044949B512E703D39
51433D806B474F4E2B6E2E59432D532C484613352F133436192729245633435F7A3D3551
4534274A3D37973219723F473F294563784628503B14365B5545454738327B662349671C
206A374F58298B70545B772D3799612F8EA37742453B2C4F6F7755343F4C3A7296844A6B
2163634054283F6645536E3D4D79555B71326456455B74724B8A4F628761674771503A64
5C3CAEA54A458F65468F744467964884717835508A688B8E4F827C4D8EA4838586556077
9F6F53636EA16E408F826DB18642878F4D61737147716A5AA0735A57414CB88B7BAD4148
867528602C1E219169438A476E433F526C6B3A4D705763743E758F6339667B492643537C
4A357C7553C47B415B743B5E5B5E4B5059305D967C4F3B68462B449A8353268B6F2D6E8F
74363E634E2B785D473D444463826E457E905E292A553E5735A1A08031553A39
54664D8D7C3D587237491E4E573C5D1F2B532A453407264122332A173C394A7689212639
533729322A35B7691D732E5571523244704E4A676024323B3842575755337C461B42692A
1E6D3154832F88665F6890723C972C1F708E533D715D32263E4649373F5B43608561487F
455340435F4B48755857769654804B5A8C4C7C4638435885487F464988564B34674E3D64
5E398570493B7F57315F6F434DB768898483375EAC70918A508F6B4B8D89677D9A77757F
A76B43558B936E54AE5234758D3C82982A41585F45643A3372724F6E343289816AB34034
967B2B7C563C209C6634927C7A7355717E6F335C88688276437696885085833723415D93
67357247389BA14C72731B455B5D434F56284E63574F3C6459673D99864D257A92604E8F
8C3D3F5B723E83755B4D4B6470836E49929C73333159575F3DBCA87B365D5240
5191607C7831496338683D594735764036542039551E274F0D263E1E411420527F462C35
1D373E2F1018665D1E67242C435334514219263E5C272D39141B333F4B2B8C6D26325E2F
21702E3166307E493633675D3F9C5C2EA2BE573050503D345545272C3C73547597743983
5B51554F4943484E3546678B5278704E8F616A49464C5573518F6F5C895C91555953448F
8D4E90754855A68C43787A2A56815D879F4D506C93697F793075804B8C9C3B48746F6D81
BC7E503B5F9027398AA84DACA63A5F965D44454056987E42826548876D40A86C5BBC6643
816A27686F441E968B1B48527D6D4F7676792D387B658C58307FA28758898255173F6495
683D527838899D5A6B7B3F52554B465656506165615F32637A7A45987F652D79A9745BA3
85455980753B7D6D354481737CA8691D6B7D79373B60652D2B70695B31673923
527B667C8E434A2E1C433A3D1E144135374B0F1934151F40131E2B1B4140395084553140
3B313F3D402077521C6E3D4F40292E616544233E5B2D284D49304049231D6A7B303B461C
1C7047325F2D8188534A763228A4623397B2674C5D4B313A5E472B3132724B6A9982447C
595969575448555A5541697349877552722D595A414C583F2E6162406A3B6B4B513D2348
654190862E255C57317792404FA93742768A3A4C73377AA45584733D76A09D5B7D7E3E5D
B2A47F497D96723A8DB85081C861558F5E4638673C5C7F3C7561466B6B399244429B6040
9C5627534B3F1D907A276569673E4C9D88763F3B81538E7A525E86654496A851272C4A7E
6D4667914E68AB59808D345957413D7C64545A6B74564F89897943918F2D297E986864A5
6D2E3F48582D8C9E5E406E2B669F7A5489825A2B547E6E5A2E797F561B70553A
546138438148536D363D26436D33591B2053272B4A0D0E422521311E414C3D57822F273F
4B3025273D1F825A296340434B62314A6B53243E47141C584D2F364B60296E8B3B47503E
1F72532B6A3F5D81554C615C459C763886BF6B515940333D8E8240333273316A929B4D7B
234D76505E1C2F4E523E5D5C3B5C6E54815B4D5438587B8151773E3D7C5B6D37504C4158
5F1F6D96652E5F6D485C7D506BC07E54679C43517260528B66868871629C965482726458
BA9E8D447C8C874078C0557ACC5C4C8B734B42854C4D853B699A546A653E917954B47E4C
A49037525F3D27909B4D7B6A703A2A564872433C7345515F5D5699714A5B55773F2F4969
32334B7D5989A43D506B4066704532495355509D8648294A5B4235B2AC5C2C5A82357097
9357404450194A64423F5845659F704DB8A25A29283A4454417F7355445C3C2F
50986E4D8C3743624342604B9036505F345F4A314C2A1243291F322F2E65436585342131
4B2A492C351E7F69345B4D3C4C78365576672B4B6D311750322B3A6E742D6564234C6450
1D683D2D7352516B45647C6B4C8F7917337F692C5F6B3D1F45454B2F4B8D35497E88327B
5D4A5330775F4353443C758E61723A458B6D4B452C3B4D563C6A57387E5D56475A704A57
76657C885F3661786A699F6B67C59A585FA948538872468F6E82968071A1A5607F68705B
CA8E6644ABB4783E6DA14A7AC35D4496514C6B774C41704D999F54596247AB864CA26F2D
838F364A4F301A80913396A18E704367558829548558695F6C5AAE9258706D89484D7599
8E3152643C92A57C637D234A736F51645E33336676692D5D7247276E814C284A9F6C4E6C
745B546A7B3B5270504D7E695AAA5C194D7C823A3B466B2825598F7246584131
5193654E964F3A54403F7345672D5376357147385D4E154729224B373156417FA556323D
462F5D2A3219677B376333335F76376E7B2322446941185F292221425C286C803B2F3D2B
1E6D562547314A82302F514D3B809E5057BF862D3B413E3C664D2B222D745969ACA94172
684F52476862434840304F7D5F63704488774058604C515B465F7E43916B6B5C568D5B71
8576798C74377A935F568E4659B0885666A25D8CBC7D3C8561AEB38165967B5CC183705B
C9A04A40789F863D6DA6656FCA673EA17C3D3F5B513B623B5F8B4E5C76438F8051B86748
73A33F5E775B1982B71D4955626E558499974D25656A7B652F428E997C76958D202A4172
7A426B874B58A45E74A6424E523F2E7A7B6B4268642C3770836A316689292D7299714F7E
6629343E5F4D477531256E5251BB8557829D80374D637156384E5A414049391B
516534305F48394619234A3A2D13264326751D0E39321546100D24212D330F34695A2A4E
3F1D46283A13453E194C4827312C2241654B21305B1B195961552E4B4B21518C5537434B
194F642C4E1E38833E3F594F235E9E5F40C78B555945423F6C6436293585585FA6BB506D
6C4A695A72744357783D5C85606F8E4C8171559179524E5E44759143824284624670345E
7865628D3B2E5E7766449142449C784B619245516E6C36745B627E69699B70537E91684F
CDC89D45A1B6713688BB7F7BD1702E94A6504D4E2F639761748B3481884D7B652D6E7C49
6DA9272D593F3E83BB4F676C7947444EA2A95E286F3C666C6E337E87273967765A2D4785
3B243F825861AF493D5B625159513A444B70456A6C5E234066773B6881543E3683685795
A26D45375C3344A6563F904F268E97615C9E7D2F262F575E444E5F562543512D
4F7F5D49744D375D463132285538232A124429193A170B2621172111162C29658B461929
512E3A1940265854494A5930336936545B7338395E621E4262593143774C4D9364304A66
1A5776284A3A2F9B3B374F5E60419F7540C99B6854435A43648F622E3779514C9AB85E5C
6E4479516543324B703B5F69384D744B805D3B84604F4E614C5E8A41895D755545954D54
685A60B56A36526C4143A16448A76F4473966E5A89663899837B79314E929D5FBCA03331
8CA65D4A95BD943057893355BC9C235B6F334163372558468AB1373E633887A060897C2C
5F935C375E4C174FAD4E6C80665E51434397683462705E6283388FAA934C8A87512F4C83
7B4947904E79BF8C5F574B4B806F645A5D613D729F76274266532B79A87C4539831E4373
8D7B4839565039725C3A9085569B745D2D847F3B2634767B634D545060454533
5E5F69527B59304860236D3E814B2346254E331C371F1331291A241F2542356385441C2F
4D2A52292E1F46674C445228315F3D56546D3B48625F204145432F51754F49804B3A6E6E
194F6C316462259453385483733DA35331969A70564F50264C7363302F6C5C4B8BB15644
8653564D535B3C4158386C81765D6136809045782A3E6D8F6E623D186E76692B2D957954
5315369E94435F7814255A603A97874540693A7AA7892464416B9E60477545347C888554
97C0663C778D9A4C65AA7C6ACEB22D4CA64E3D774725595154915F3E674650A16E999A5E
509E683D97781C4DCC3D678F897B5D5D4DA43C385D766669494489A1914E93A62333697F
8F4B447F344F9888586150394E585D585A623344736D2B3C66422562705C4A2E8F7C5757
8D7639354B603B86753B929E699468592C50854B292F788668455C4F603B4439
79738465958D3C4C5F227940794D2B643553462048471C2A3C172F3F2E4F2F618851262F
38205A2C3C16359956404E2450653A4957492B56735B213743251A27594A508459233E61
1C4B532144411D751E202D5F59339F5232A3A6604F91793D4A8A501A2563824FA6D44839
9D5E562B4085424741185480704E32195D8A427621263D625A565F2B5C69686B2F864755
7B663F8C4A255487623542612463846E47775B447B853552694E6B705471996EB18A9C5E
90C7834681608D577CC47A64AEB7457AB6563D70502E786F5F9256597D48419348938D58
4D912F275740183EC84D456D7B69566B518B7736435E6163712C50A99459978B52243A59
8C5A406F7758B9AB4C588A636F51675A557A535E887832376760387C74654F44A7905B5B
7766467788703E7F7554A8A96C9F5D525384885533347B8970487173703E4B31
967C7442656336582C154B2E561B2055295B4C0E3349151E47101A302C55293556632F32
3F26542C4D2528674235604F99882B3E7B6E39334B59223271682E31571632768C345448
11558D44533A186D4A2B356A2C269C804E9CC22228587C5845965E1B1B3A744598D0662B
86577843366D3A676C3A46663E4F714254652F766935444E213B8E505C56477D3D77563D
6A7D4BB74F3E4976635A5D863D6E7D3A61947F46868940729B636F6160809C6FB3845544
88B97F387D4E8B464495685667B4335187543B533B3D85695E983643603E346D3F756A31
407E513251321A33C93D53877D514A65557F5F3845635067833A55B69A64928242293F5E
7B693F697B4DB59B4E8586586D49457D948356657D6E28548F7C48746A712D236B785661
875C223342593488682A588141987F4E314B79503C40844E344C838F5E387730
C59384689158213D522F2F1741441D3A0B365D2D3D5A030A553425230E4D5C6D7B800C23
594C3C1360452F7027203962BFAC141A417351355331091A4D63323A522D295878355B67
16295F3D60461951673E458430108178486DBD693D535E373F8D955C3836522453A08933
78305A583B522343775A4C6648426B53558C4185713E657E61437D495A714F7231776340
5E4549A56746546B472D3D6F325CA471414A7A4188762F5173737A6B40508269A3707A6A
82CE8443624E8D6E43A67C5F82CE515FA9693F48612D7C795B8E6648654926787A946F32
4185653454432831CD514B8E7E6338557B887F3D3E614E94943C50A58055AB9E46323F55
87475D887B48B285328372507B5F2040495641788C7029205555215A7B5C5025804E395D
7D752E304B512386754665942F7262715776793127437D644A2C519336325F30
A5D6A8609BA542386B3D5942586D284C443E4E3031442315401F29351E4369596E7A381D
31455035573A26875C1F31394183542E40665944836938194E372B4D636736615D124582
283852173957255D2E272F506731803C1F3FA46D3F5B58323B6F525037497D4D9CBC7432
8D6261523E75424C704E5F7D6F4D491C528C46823C284054543C7D5257704B76336A7949
547848BD6648556E734B618C2B57B39A5956993E8985475D66526C8658558D678C73789F
CED8946367588279409F8166A9D67158A474464A6C36837A48907150595E248690947753
55A6893C6343283FA77B4D8F82884133536D553E517B3F7D533058A5702F5655523E5773
9845295E3E2B9C9C3C5F4F27595954525E6A294B63833D225E7249514F6F6D2779684447
706E2937455326674B3654A2638059646680743F2B3D5E59643D6C95743E5125
B9C98E5493A7493B5631574F4A5E2E644C3D4928204B2B16501F2F4D2C515F5392905526
3633513F63291B866D183320475B6D2A50511A284460481A4836272B455C35798A45337C
293B80543C66335751262B5B623F707F4B54CA803B618E5C4A7E59262F6288579EBC901F
75635B3627705158584D3B4B7D4D4E4F417D4D5F4E393D504D308771839B578958748E4A
538651C286544E636C4C74A33649AF9B654E99398F925254763A77945D4E93708C9A9768
A5C4964363B6B18C3E9C552F86C17E53AC434984712F73647DB67256654F46969592A13D
386874356F4A23189D653F6F727C673E6E637B3D3674499389473A83956D7E6B46293345
916C3A667F3E8EAD5670826B5D5761585C634E596B934D226377515F50685E318E885952
786333676E783D6D5C497EA863836F5657847D4B2944524F2E2468897239552A
AFC27D374F753B3E3F1F353D3F391546403C480D0F442D164F11122F2B4E361C3D625024
3F3432316130155D3E0E350A326D861A435A5D324666221957633E3E432B17567E502967
1725674F3C48164B744037663B1D588B663ECA76283E51564371503B283F7F568FB68D38
7466535B4B78644F6B8048568F59566C477D63656C4E474F6936837872AA608D675B7145
54764BA98B404362524564944254B8A064537A4BC0B66A437B3D91A1624A863B52908A60
89C99E3E6A99924B52A778575DCC3E368F7036333D3998653E6E5455945523715278A85D
466E7E3F5B4D3519987B4D6471856C43A0718F47347350808C5D41939A727C7359383449
997C536D80488BC1647E9E7D645D59648E88634B5D8A513F97854F695177321F6B745657
6F5825444E6E3F70622641862A75A277496D7319204A5B716C2E4CA04A338E3B
C8AA7052858929304F3F381E275E2D471E223C2016330B0F3E26202D153F5D506C772F18
3E533217574C1E7B43104B241741AE454157673B4466411139473A343B64245E85632387
3B2F8269364C2E3471433E63502F3A9C673DB8A7554D4D582F6454633A458B6886AEA14B
6E6B47615275584F6B894C5C86577572447B567494575254764489844C8040A56D517C3A
6F83529C9D2F5285804F5892232A666B4F555D3488A3703FA02A536E51629F6D5E9A3B1B
6DDBBFA5AEC79F794666908681D28E3A698D413A611F6287457F814A5569256C9189A27B
4D72A453625D4439A2A9586879AB532F6B6584434066328383623B8B8537879A84583543
852F567C834882AF3778896C577A453F515B475B8D9B3F1F50674961658F7C33848C5F60
98713339405F285A7A5E4AAB3D677A8268867E3718303F76712C57B238297E5A
82A57A4D79AD6032575032472B6F33453320411D191B17134630243328414C4B6D683A19
305929325C4A1B6F43214C77302C95525651633B42665A173639342F3D6A2D5679682880
3E2E7F72344C442D763746776E4C389F39369AB85C4C4B4D34849B6B394A774F76ACB862
60464A7150793B5F7A7B4B795D255D634C8F31426D3A5F7A571F603F4E743055374C8232
47492C80944939586A3B82AB753B9D5C3D4F7F4C7A96432B7F52727B493C738448A97C5C
4DA4BEB3C9D8D0A344669D8989D8A23B4F8C5C667D264E8145967B544E6134767A699676
378D9E575B4E191C758A2D56608962356E4E7B283A78546D591A399CA05C636F6B3C465F
956A3A5283377CC2706972504A68684E6B5C3B3E727D71347E814A484A807347959A3537
5B6C544D57704C5F705F59BA707D7A6E47716E581B2B2E7B322E7AA17C3A6B50
9F82734D69B77234585E28513578344F492648251F21281A424E1B373743504A63714122
2D4F253B50541B694F233F76503F82525852563D4059511A343D203867773551842F1B6E
45207745396D572E71253C62633736A6362170932F4769551C3D4C54325F843E57709837
53653839236B44344D3B2F5D6F5655463776703A622641516B345B6E3A634655754EA958
4E695B8978534B6E6B45589D713BB08C5D4F884AC2CB7F45734D88B071437A4434737664
59696A5C857994844162803A48B08940476D2F4156213D5D539581584C5E2F6787528A77
2E5C9330637A4B1A77A44359507944377C6C7E3E3559367E7960346C9A699BC471232C47
7680496981364F9B6575A2734A5E41467E6B6542777E3C274672695350703F2B587E543B
635F1E3E516C4B60652430745E756D7B4E659B7C2E28276571314C9573367360
C48071507BBC7135504E385531733F556D2A5F472D3D411A3F4318403F43643B5E96572F
2E3C2B4D3747136D853235671A3288485959453F697D5F243553231E354A22589E721E66
3727765E25332B2773293359661A2799503BAAAB23334F472C5651371F41695D7FA9A74A
436C424B58644B3F5786586083715D7A487C7F3B7640454D644764803B7E5B7D8E4BAB65
60706682634F52ACA15B59BC4420918F604A8D47618E663F6D466A8D6F416C8E4C9B7773
5446557AB9D2CA8E4971BEA261D4883B73A04E44742C3A893F7F9A5E5A7A36657335809C
54679C394D652F2F76A35F5D538C3E245F456D2E2B64546054663A6C832A49695C3D2542
7B353D6B815E5AB440375A6F45644945635B714777686D35476F706454557B3F778D533E
6B5A22313E4625694E3F3C8359737087587EA1742F1F2862833460AC8E437078
B44F6F3C3E603B30541D1D2B1F4F1C3B58256E381043411A3D430C1E2A3E711529535825
3E471827244C1840341720572C273F1F4B5E4C272C4E39162B67552D3E56313B8D872F72
611D6C8A35452D1C6E2F41535F4334B371459CAD3B3E4844315D5D49314D7D72609AB968
3C874D64625F7144768F635E816D788C427452377151444858324A84346B34546438772B
3D695A607C3E296B944F4F9A693A988B45548D716B9F4A3B7587709A5E4F8D933F986848
3076D2ABD0E4DC934752AB8F77D083354E82526B672452924C9495436D80568765366F92
2E518F6550614C1958B25C5F5C7B4E3C7C57743828757D7B5E7F476CA35F7E9476532741
6E72413E68415EAF874F6455465F505B885B7C4A75816332457A8B6A5C6E8A46739B4241
92884035424E415D6264468E5758A9A45E809266311D2373823461A8873E968A
C34E55624F9C562641572D231C4F463143103C52285A301525451B1C2E225C5C60778B39
253B233A1B51374B4A412066693A714F54546461385C60271E62643245625A4285722D71
6A1D60914464582275423956846B39AA7C4980C46C403A473752A18C564D7F5F4F95C685
35693165564B5A2C5177574F6F41497242537932837B35416D685988396559655439735D
475C39539F61377D73224598662F8D903B406C735F95673D5C8C67886D3F6E874CA27776
3E3ABFE1D4E4E1AF575D883546AA984F5B7C34345B34345A41749C4A45522C4A7C4F6A9E
5747B07842624D1D4DC3585DA4A1644B8A58774D326884586E6E4D509C886895A2702E48
5E75454F773E5DC194506165507A716D8254634C84AA5B313A725F5877AD954562AF442A
5B64602F49542E5BA8874B90523BA39E5F91A1652B436494823C5B9F5318707B
CC57556E53A78E344D772F4A3B615F2C5730463D1E4A301E1F36191E3335536668688D4C
2D372F3B214535466056274363387A5C524B4D5E377263201C564725617C5838766F2F52
701D49632047592671364969917B389A512248A7623637433127414E40366E5C4273B476
2A675B5B6E4A5F3C58886B4268845378525F923F783C335483625E6A3C6B58667A4B7F55
4958613D814A327F775645AA6C2A8FA876577C6F63B47E4073855C92854C788F5F938688
3A3F83E0DFE5E3AD5D559D867EBE7D525F8F5B417247316B3B5F9D485056365783566099
4243A35B407F591E3FCC5F2C5A76714D7B5B954C4478714F73424268A5925D969A38447F
9A915159772F51AE91485B5D3155665D7F5F5D29648C8944357C4A42497290605A995833
72595A2D5142433B7F874E8574488E795F99AD6D461B276F7742549E7E467274
B55653594E927E354846334D315C4A3F68303F3D1642331B183B132D4A3D5F464F837F4A
2C43264726311D326C621D34312F67514D5448393D8165371D492D18385F663878935F4F
831A3E99485568286138273C68402281755B61CD432B4C615C3D6F4841438C8E5CA8C988
2F796355364A6D385A6740334C6B485C3A467E397166323C605C5E79546B4965974C8555
60797C4193624197AB6F42B54E377D916A5E733A538C924D58513A958547824733799B71
494F78E4E6EAD9AB5950AC9588AE7A4B7EB96B42744F335F4D6696534B5A3D606E436798
393E9A45356E3E1933C95244685B4C31826990432D5D60497D372E3E725A47877E1F2246
5479475B602C3FBB8B4759844C56404578946B4A618A6434549476675F75722F63926437
6A61424E837F574E7F885389935291795791AF83581D2D6E4B2F6BAC8639703F
734F5158427978343D47283A2D493E25493A4154152B3B21172F171D38394F422F455C37
2C4430382B3225234B4019304C31644B3C5B65582853593B234F54304745392955795B3E
6F17439253545A29705E3E4B8840267C88626DCC7344433E4537845F312A4F8452ABBA8E
305647666640552D658D7430474F3984654A6220627B3D40522549744F723D3681416840
37596D3B9460255080633DA75C2B5E7E8A69698941779945478148768E49625E5C7F7B4B
3B2B6BDED8CE748E6070BEA395CB97387CB96E4A6851458E504EAD6A608B49578B2C60A7
6D449667366041202DD37A4D75536C4D9797A768285A4B4B92634447775C4996784D2F4A
588B528E784A51C0673E9380435A4731354D614C67764120225F68635D6278555293542F
634F321F47414F3F77463667853992703A5D8C612E304E8C69322D786B31907D
56585179557C8532456B4A4138496B325D2C36602E364E1B19492B243A193B6D62677B2F
1F3B58391B333B325F421A1C5B426729325B6B783662651E1A35452E5148763C5785593C
8D2F32823B5B5C2B5F48375C7E4E297470373585774B424328244D675D2B4B862E738297
3C57244B664548273E70712E4A623169654B6D3755763F3C566A576F537D7657833E538B
5E5A813D9955425B8B5C3FB38A32816E5C498A90446E864071924F6E964C6972795D6964
63373EB39BA25D752E4684A365BBA14F519973515F50488E5243A257457356519C5254B9
6D418C99456A4E3349CD9C4C66506E2D3F4D686925704034757447467F393E828064324B
5C5F2A4D67694ABC71395A7646523F583D6D8C6267725D49246080776C87A769529C4524
848E4E245A45483DA58B546678309C9A6E89AB7B2319295474352E895315616C
724E53765B78832F33553C2E3742712D5F43316F352D583516452B213A273A796262916D
2A38663F39324531736A3E224A2C78672F5174633377784D203021183D445D305B742322
6930317F2C255535574F19305B47287DA96E4BA388385E624C365E4746203E8E567D98AC
376F6E5F58517A65466F5D346F934E704C539357555D354D907A5F742F5D885863264A8A
5E56543DCC8F50586E3326846A27796E7C565088415E8B3B58974F676F47989988507E96
984A8BA894878AB172528C6E419FAC6C579D6160896032745C40A75C3C6C67519F7E5CB2
6951AFAA3E7E451F20BD904B7F639974675796823F7D89456E715662A288436F725B4278
A0A056567D6956BF9461738A5D6474733A3A6D557EAB83592452572A6F9AB4693EC24E19
4255662F63456644717F5B6C8D3898717490BD74531D384471423E9F5E23685D
7B4F4E594D819544385237475F47642F6C4D28562325492C19401A21472F3D5C3E739B7C
2A342F325031291340773E2529124B4928547131223C435B2D3C563E4138311B6C9A7727
803D2B7E702E723953732E3F75381657857B53A8862F41665E41714F4524519C67A69FC5
315A7157523E615E41795632536D4E5D43357050467C32345075535A66517A5475614F83
555A511F928555566A3F3096652C86AC895D609B5FA0BB585184596E8E5565907D46A9A3
685D7D92343961885F5278804A96936A6CA7742A565B296143659F6B42723B5D927752B1
602D638D3AA38C3B20C8AC32666E8F6E826E93401F4C894A8F471E3661823F829C321F46
67926E5A7532378791676E68283152694130544D4D5B61572151686770549A644F9E7247
5458763A827C8B5389865B90A349AA623667A98C6B4567676C3E339373417550
5A475863374E603840401D294A4132124051326A20154E2E1A541E10312944551F497365
2D4D513E3E39562451613943743C6E65306C917C504C4C481C31423B4141643649718027
802F2D997B2D6331608F49405F5C355E84674FBA986234474C4A7247522443826A7FADBC
5C60664F6352824D416A8449607361597A4D796546854B404C6B60776C4F6F4193654C78
507C8A46C2644E6D94643E875C1B5B676E5465953B4F805C4A632970875E769C3E3A8F99
696087A16B4377A048608BAC4EA09A4144889A45702D3878603994414D9B843B92343B91
BC4C728B175A924324C5AF4D5E4F654B6891986B29516B3C897B5A448B7E499BA3884140
5B91497F837A569F76538D9A5F4A4343495B6F64506A604A397B94786E548C553AA9864F
54563C20605E7D4B9D793F6B9D46BF897C70A56C351E2C3C5C4124887A327687
663F446D466D6F1D2C41382B293D5422393C2A6E361D3D1F1745462235172654447E874F
17295B39342243234F5C21193D375A1E23486B7250394E41202B3B303136643C4D7A8A2D
6C4C18556F2C522A4B8A433E61663D4F7B4944ACAF6042433F405150502A4679515C99BD
6058525B784270396181734D626B405C6A5073384F7B4B4B4C3627476639782E4E523F71
324D6745BA91393F585C47909355839E6F58ADBD5E68A44353AF69715F3B85A0883E7D94
1F2646A38B52769A46355287558E925A47898E43614D1D436D3DA162305D733B90453975
763F619D406C673648BBA25D6568663239586C562F4A5B42705B4A45875F39798D6C4343
5B974F555F735AAA76425B74594C513F363A62644D7E7D5B1C3E707B66529B994ABF8555
777C69364F697F41918E5C7A892978576981BE8176203A3D856329816A3E6875
786D47744A677D40314C431D493C733339361D70521B512615404F243543295C576A794C
203269374326491F4C5E2A1D5049503523415D7151335E4A2D3038323E4A6A42467B7338
88731D54802769574084394271532C3A6D3140BE9E5A49493923488069394A723F334D72
54545A3C583F734F3C4956427C964955624A83633E81334F8A7C485F4942936A592B3E94
6063402386A07655733419548F5571C44D374E835E7EA142346D676C5C44538388516584
787090C1894A80987848638A4C87B372568A9A3E6665224B783A9683456C79338F745688
82337EB0426873282BAC84567A94795A3D6C6C5F3A5E6C507C6D575C9B8C4B7682584A4A
63A66E536D644FAEA0836A685B5D667B4848573C4B958D7B214260637894C58E48C26E2D
504E693C37715D2F657D6272A152A0546E8AC7987C2A3840867A3D797659696A
937E4B87506490663E534D275B458941405A2E746420534323314924493B3455546A803A
1C39653A532B4C19468C482B412B51472F4B6D4D2B35676A4531441D2C3B58393A734B23
565D1D43581A4552376D192F4A4D403A99543CA594434E82993F364747356D9D888AB1C2
3F4E8B57591D4C89535B401F4671725A3C21557D48842F2A4B684B5F64397064645C3799
605660599297745C82552C56893760CB8E5A78A45FA7C28A545F796778815F85835F528C
8F84B1BC7F3F8FAD7C4B82A03C849B6A508D9D4D7F6F28427C3FA783466F613B937D528D
8122559828767E3329A7714B4D5152433880645B2E3D57447553365586734071833D3059
79875E4E5C593B6B62695F693F3D435A445258593C5C706F1E3D61474149797B49A3683C
5A537F4E2F67503186705967A9599A594F7FAF9C82373838673B4C927F5D5B5F
5A545278313B574A3B551C1A3B3B57162E4E2E6635114944262F3C11202E2D59211E504B
214B3C17422A4C192B4736315A414236245F816657214B522A4978732E334A27478E923F
704A1C4B7C324D413A8C623D635C12274F7254C3C751254253403C54422533547E54B5C9
6F37725C684E5D7351558E7062737F4B8C485590499776474B704D6F8D4C795F7083469B
566583649081565BAA8D4868913542C37C3F80A05461856963A75E476E64719E644E71A4
8A8BC6C3882957974F32647F527373584999873B6B574375573C86683E74713482473969
8A4B488D2948652D2BB4716869625F474D835D632E425F4C74504D4B8072336B743A3F3D
518E604C605E43868A8049816D57484D4F5655604A657984233F657E5451838E5994794C
625C604026675835775546619C529E5760509093563033377D7137546A344650
6A413D714E435D232B4B5329232C6935243117584A1B45271730542C2614125747408041
093159313D0F4635446725173C5D521E0B2141636627633F131E41442C423D271D4A743E
646B2228693A4F591F705542656B4E215558328FB081485C4A3C405C59564C5E9154BEC5
7D426A51765E67544E6E916C69816D53904F506D3D91694D5A67384E7A4992545D653E98
514467528CB25F3F707D2658896540C8893F617F68737E4F3B826F4D612E3F76664B36A7
4A457E9C75446B968346658B5C77716F409E9C4055502538633383974E5C933771785671
9C564787544E773D27B3698C6B6D5B6559924F7C3F36726773665E55897E40666B5E5E3C
5383725067683D8F8A6742A07A644C505379736242647769395F9C7A544C758353918F59
6158633E3B88833D765226478255876D684A667450374A4C8060385E75333F65
6971487F574B7757243A5C29272453502B41112F5B2B5D311012312228371B4E4B40893B
13272A1E3524322E456E42263F633F523B3E52736F2E6F3422284C472F4A4F5C30678A48
3F91422A6F415D6E2A7F5D3A6869532054695285B7804A5A593A457896584E507830A0A7
7841714A54536D6C4551665366A270417B495C8A3F884442637C505A5C31747E57392E85
6D4957335397794E807C2D5F95543BB3956F688283826F6F497665546E86618472613994
9177BCBF87425B81864C68896B607579469AA3586371334F7A397CA15256832F6154506B
8C4F45946848703F31BCA993798267793F927D9E5438705778805F54A28F5E8A817C5E3B
4A835E466D754E8B7F63449D79585046365260543F70896C30345C72544E72603257864E
61654F231C5B63286A4A345677507E92654F6B6B291D2C427560395284364284
70914D995B4B7D7A35487634464680622B522D3F77345245362A392D2F3E25675E3F8F5C
293F432D37413445328962293A6440755D425A6D5B318362462F574A2C4E535E306D7B29
288C4D235E32566D2D824931657433276986705CCA7E3A759B5639656151577EA24DC0A8
7D3177664E2B4AA259505B313C66844E5122438B41855B3D48686459775276975175476D
704C66794E945A4A876F2D6598423295916F6C7B8C8E9D8D4A877B496B8D5D758577439C
8A6DAFC2834B59A08F5063825A81AF9A468A9D56707A3A4A743A79954D596C3C796E516B
893347855E406F2A1F6B537874A572522753427A3E325B3A46564F61A6742B525E4B4135
4E796B405878458D967E45825D4F54635658566B415B6575383C63514167857548387E2D
55655B43205F6D1D5D6A464F6E2F7A776754827A4B272C3A7C7833447F2F3376
6E8751B9694F817537594F2F474276512B5420336D194944302F321D2B422B6D572B8974
373F4A2B3A472F351D71682445482F58394B6F70523B735447376E5E414A45372A737945
289042317F623C692473733454843A204171754DB36A3D4755514B725C3136499157C4AD
9C4A726B4F5F5F88554C71814B6E7E476C594C8644647E454A5C68545C44728B4C6F4278
703C677C449451487A5F355B8B3E2D90935D71855572979147687A5A918454787C6350A0
9071A7CC7C3E63948A4A628B534E7E7F37709750616A353A6C4E8E88455B712E52825567
7E4B356A653A7545236F518E4D877B6045654A8A353F6E6556664E6AB87D3A6F5D473746
5A847949596E26567D6B3A787750494A565E58784453738745397C7D6443666642277861
606D6C342B7B925254643346805C838556609B94772A2B39623230688949306C
5A55487B543C5F402034432124206B441D4D1D2760213A34152639251C2F163F5129666C
112B3B272A21203B2171531921452D5A403A42686436844D3D1F465942534E5827577B47
296D461A6365357532677E3E557D642A477463408F7051514E544379615247559C5DC5B6
9D51705D5A6D5A6251596B79477463456C67506B444D774A4C505B607149727C46833D73
674974823C986447827C4E508E5830798E7F5F6A8977938A3D4F703D616C4E7E5D48569E
855991C5844855818D4C68937C5D907A437ABA6E54563532633D668F404E72424F8B5E68
9A78418770398A682D7E66A85D7F67883A545A94652E7868708F4C458F8A4B85867C613F
3A66754F91944957906942919052463B2F626D71474C774F2F3D817E57445B643B1E686D
82A36F2B19456A45485C3B456C567EA4705592944F424D477A731E32A35A2F8E
5D854C8E6F466F89333C6C392A3255572753291F5533374A2B2128271F4335474937616D
1F2B2A1B1F391B37225B712A324B2F67754F557B7D48396250254F4642574B643457734A
3449572070762F873D5D7D3757805B28466A5133737A5C524B543E82A0564B5A8B50AABD
A44F7051596754714A52646D40686D4572604C693F6B844B524F4E445C46538C48885058
853E5A7E3F99733B526A4D37797D3E729A837D7F8763A5893752814B718A5889848E4DAA
785B82C98E565B777538649F845EAB813356A06F4C6D3948865767873B678640497B355B
7F6F489E944261442E59699158766F7F2D2D346E612C675241524F42977335495361574B
3D6A7134456E4A53AC6A2F6C70597659434755674564A18253235F734B647D99543B6B5A
4E5A664B23467B304D7A4C497939577E71617F8F4031447C8B6A1E36BA492D87
56954C9F704972963C3D693A2B47626E32523C245A34343C31312E2A2035304B5039536F
292B2F2B22461F4D295479322B4D325465455172724124774722454D40515765325B794C
37385F1E7081307B44438346669D6A3246614D31548859524840335F7557455E7738839B
9D4A65665A6B4B77564D698536607C4C6A7043695D438E4B474C82505F3B58984D6F3859
9544558144957650558C593D8A773F6D883E5358755BC9A4405C8A4E7D62468987884EBC
5D3C55B98E536C918A556BA768618F865999CB7165823E2870516890494860315A8A595B
8C45266075396D5020564A9A45848370473A507B4E4D76664E5A54439F814C6567603E4C
4978894958743B5F977E4F80643D4A5F634E58632C3A708363265E7B60415082594B6480
53686C4832466B573A7362456F666E95796C7D87813C27346761233BC0843778
61A24B9754466D7C3A394F323E4F57723947411C5F472C482F2D3F2B2027254657395487
24232F26295021522C57AA48244E2E5867465B6B533C3C7367343E5C2B3F666A32618836
39445E1E615F34814E377730428A6E343E5C845943836153455445676758455E776497B0
A14C567B6066526F534C5D8C3A588C586770406D654190514959764A5742588B4A724F3C
6B42615F3683734847932B2D6373446F9C806B655B316F7F606A893D727153706D6957C4
806270CAA03346596A265086884F8B6C33517D6F4791333D863F72905B4C6032388B5E5C
955E325F78439369226152AA4762616B4337628154315262476C32306877455264651E39
6170864B4C77563BAA9E4E78915A5A52644D5C5C394A6F876F255B867E4D5095615A6D87
5674623C363E81453E73593A7156759C726BBDAD94412E466D5B2F68C7753077
5685479D6C47748835394D2D243C3E53213F46206335305B2F27502E173C354951203063
3C1F302D204A1A42162C5A35204433566140576C6D6B315267303455443E496637697C41
302F4F1C5E90337B5D2E88534A78763E4B6F81513C88625748594C63616E4C6D8A6D91C0
B442578053642F7B48526F5A3A5A785681593F805B4584453B4751466853578334946730
60376985448760354C7F4B32655B2B4092506D817F4FA08D368BAD3F4B5F4196653F3FAF
4F15329F99615A608F4B4789884B947C437DA9844F8F2F206A594B874B75985643853A5A
927A415E892E5462256355A75C6C6E8257476D8181465D7A4F8E6324739943486761584A
3F5C8E5351816B519F6C41787F546E45554B785B3F476D826E2C6882765852845B66878A
4E6D742E345BA3543A672B2A746A6B9A7A468395693D5985873214388C7B2A83
6393466E685AA79F222D5B4E2F413C73473C492161451C5B2F20524F265322365D3A376E
2C19453A2B38124B313364291D4450583D2D576C7C803C59601D415F4C49444523657746
3A2C2F155183306C4F3091564A657434345774494085515D596044798D6A2E4B74506BAE
A154475732604F86423A56613D4F6E2C696F418C31327D594C5C4B354B494E9B5B755B46
8F504D78458C97522B6C3B267C9B5D3CA72B4A5275459B7835508F4D59702752607E4ACB
6B4262B49B7058698E56448B8E53A19D64788A90538A51185F5747823A38583635604948
76612C529A41644E2A6283AA63838893322947407C414D3F316C692145A42F4179786247
495F8834618D7044A7732F5C7F5084671D30545F39477268282F576D55534A85273A6963
4A82672B31337F3C3E805C2A7E405EA09974AFA155312343736A1F3EB45D1893
5C884D754536505C322643363C20286B443F3C0C5B3C1564372A5C462054324155404075
281826322D461F423F37784B213D4B3F4931456082784962763B34544B4B666C36557134
3C534E173E781E3F542474394F84684236755F2F3F745963514B26434E55394A6D595495
974E5080565D41917642626E3E5E97655B5F3CA67B2D672C3F5E8347533D3A7A60694E2B
5F53525D34486D5A3082441B4D8B433479726C52994F968F5A5DA65D58856D83768C4CBD
A7906DC3A0535685945D477756407E99696F76634DB2631D636747915B4D5732387E604B
78632159903F6D48183B4E9D354F6C81534E9B75AC537E554B775E2E4997522E4A5A2B32
6580885A4C718541BA6A50457E619562603D5757205695765C284C472E617CB96970803A
355F71644C3C902139845D2D7D504D849564BDAA894C2F4E6F7D2F43AE722A6B
547E4B8B7F499689413349291B322B5B16203C185A2F16481D29693D1C3C2B355F251F43
331B31371542243E221E455E5C593A2655364B6E5A362736573B34572420344D31648E46
223B401A50862C28392A80572F54721F2E6D834C498B294672713E5550462147827C47A8
BB4B317A53502D6A693C5B502131806E553E216E7A2F6F5636406D444C54469E72707C42
6369557B665E624D3F8258315C97423F9B896652884C9EBC8749A24C62716B7A6F473593
9A7969C2A23932627239458A8962789D5D648A803D68511F524F5C9369495A26206B7242
787134469A2D627C355166A65B69666A3752BA8BBA414A8456A558234F715F3962614445
444E72386678553193AB5E44672F486D763F655C182E5C6D5D274C4F213E429363728571
3556543C3A4AA0302C5651398C5D6892895799945D3E6BABA1683467AD833377
525D325B7646A08E18204D4127252A6E4F2A39144E43214529175C5235511E27655C3151
3819534A38441D504421413F2A4967324D23486B646D4339751527605831403C0F2B625B
2345370E2F6737353A155155315C6E3423476F4A59914147525643606A47282648753A90
BC6D41755389688F593C6760564272635670489A8F408175424157385A64499F427B8E44
592F4278605468411A646F455689222179785B71743467796E3B8E445067676E5C64438D
AA905EBBA4794E808D384378937078B4395892954E8C632E666C38906F626F5E2B72563F
898F5949A6355471294E70A2635976845971D673B0494C8A518771334B7F69385D6A5454
6B8DA0434B596B30858648536B46526047347C5E27485F5E422E565427514FA4514C7C65
42676B45343472393E7C3D2576453C888B68B4B7654023425658283D955F1C6E
566B4E577F3A8A982C213D46261A1B715C263A083461282A4911364B3C5D35254B442A3F
390C2138373811345023523016215B29491A34456E7653315429203B50294C502F3A6352
294F631A307730374226675D2D706E532F5A6436579A6D5967472D5F8B694439485D2C7B
8F79425B176C6F8C581954745D4474354D854681552763683E46442E395D398B4C5B6E3B
756045696751A356336E562B46A06823836C4670885C73944D4596725F714B6B91835780
A94552C2AF805673936C396C94749ABE7F4C7C723D805D185A6D3B9D413C64662F78482F
6F74274FAB4D516B2A415395466F98A46363C56E9D5A769F5F835F3A6CA9883A6F6B272D
424763584A4D723FB7C64C4B725660655E355A572F5C9F811E2D595D305C82AD66577F53
314E52423C2F88262B60573193533D69764DAFAD77593B537478363F997A3179
58786E58993D85B8703651612B473B7B5A22412D4575291B241350483F49253C62552730
3129373938342A333E296F683B475D2F5A4C4654795D482C6D502A3C301D516A43415D35
215278252B70161E512E63431B617E5435767B3754A85B457A5E354C613B3B3345663DB1
A0783C835E7561848B424F7061426B5C415C495E93426D71464F7260564E248887665131
79744E662340A8793D787715388C6B327E8748587464629E5F378D7462724E4171885F7A
B1483DAFBA7E52A2AB823D648B5571AA906099805456842A535C4CAC8A6D7F4323755C4A
A38A413CB14164753D3C4DA34A3E4D424D4BB275983E4B684B8D5625274D6C396E5C3441
43487F6654516B2851865F537E3F596169415757332247574727405B172F3B8668508178
3F50646054336C3A2D6265358770537B8655BBC89067405A7379363E91863B76
4E5C5A506F285985522F4729234434712B26513F31571723351B3E4B1B4346416A3F1C2D
675937412B3D532F2E173E5D3242340E4C414062733F41175049283E49293E4845427262
212C5D23287C311F3F2760772C5D78212056735364C3272F697E445A933B2A216B8B487B
AE83206568695F56834A5372304A888357745869A95271453C55705D51462B638A5A6A4A
84684D758149A253417F835137997530446A6699A26562B6813C9A49526D795183574350
90542D7C916E418A94705093B07567A5733B5F865F5666357278378F4D526F792E6E682F
5D7C4E3AAC4B3B64333A4AA36C4C61535766B583994458815C81654A28517C467E61364A
41478C685154794870AA4B47885F434859465D4C403B565F3121375B28494B93794C877F
4A50684E48346E513A5F553599824D7E823666A38F5F415A74482E66AD933A64
795C45517D494792322D574E283E306A35163737234D22102A173E5436353F24634C1F22
6844494B3532292E3244645A3147613E532B4C817F7B681C653421584F3654451D2C6E6D
2F325B11247A4F2569153773325273522C476A5E68CC774A5B4B514BA1402C18366D3971
B0A0416E6D7081708448585E362C5C74566A2C569B51745B3745583C555446728C54804A
93765A85614FB87D3572822B2A807638406244526A5B43984A4AA1645A51574C8F784F4C
B06862B9B87E4C8FA861294A98665CA39B4A6B987553682F3155308F965C6473364F6A48
71925D3A9F5F4C74483746B574556F667E4EA0799E58529E7985685D2E5786498D67414F
3C40736E5A5B70457AB9534E7D6D4D525C3D5C523437585B35243773284552877748A287
48516545385BAF65316033206F66477E5F5F8CA6815C41596B6E32347A7A3962
6E5D6A3E6F5D4CB3391D2E46342513625C22402016543C103A0F1D54512F5F133B5D3931
7A3028404A352B314D5077631627553D4F252A4D66684821663619414C314E4A39334E5E
2D2A6523196449263C263C78335A7C6F3A618E5363C389637E565A52BD5D492B56854676
9380377B5D5B7260A04348645451946A415D435D9D3F6453447484624A4C2151894B6031
5C76536233357F5E44708E34256C7F403B70736F7B7B47A962407D5B57567C4E8A7F5D4A
979E81C4BF955388929A3D56AE7055979F4D619D7B4F6D393B5B3081A0666079374C6C4C
659257339E62456736354CB86754705E70579EA9B76B499A777B846C345486598B745759
4036667C565F6D3E74C3745499715D53664791945338576831304E8C554A6471512F687B
445C793B1E2E70402C8D45367E593C9A857089A76C414D959B82373F897C3671
6C5B8E46868246B78940455737403A61612B4D2A18643D17412C205741264525576A4438
624C33425639372047368F8E3A3750294E4D446A7B422D236D4F2B3F3E2752605C416662
232C814125744B3035344B7B304C6C45203F4E584997503D84814840A244341D2E63528B
9C91284D785E7842825B44573B345374495561448258645A3B3D4D5E4A555165944B724D
647B5F795646A055476191362C63823E39797C7A768C49A67C4985755D698B5E9F827446
979276BAC48C508EAA9B4154AF696DC0AF4E5A8D7758863932673C7FA4676D703452634A
5897513FB17D3A7835275BAD6A509C9E83344858855963A93C5F876E395B8038817F555C
403D5F40417C763B6EC94B487C6B45545F3750515834777B211D2B6D4B407C9B8B488B7A
294E705D4D3A742F1D6E6740775B2B5D5E70919EA14A25475A7035427B7C395E
645185457F4C38A4843C48452C45546449235245264E2F152F241A4C351A3D2753693A3E
735B3558462D492D5D1C536A3A3E5841543D46978D5638236C402A5B5444494D493B7365
3A1E722D164762303D2730673B445E6D35465C7C4AC88B536A456B4998615E3133776480
9DA64E5A8E667852A76D3F58733E5C8B4A59804998676588575054544A47486188436D50
6C87555D4E4C9A634B3E9A423172924352827E6A717855C6A84C967756A9A2679F74424A
8A8D6AB4D15528678D9A3C49A44A3770A04F5A86383A67382A424086AD67806B28557959
50AF422D8B6F399E6C273EBB482E4C4C684A4967943C408E7F51832D4580814D5673402B
43688A694658592277BB76535F55326C7551604F41204A503A292D693621436E874A8685
4B4F6D55443EAF492D6650396B68436E5E5D6192A3682E57677A445082965664
72508D47928B3F7F7B365C6E443C436D582F4645273A49202F221A4C3A1E4C1949655043
9236254D54352D1741255A742D294751554B3D59605A45277746162E4344504F4F2E516A
4F2062541A515C31342E326C3E4366743C45557C49C0A4557C426C3A878F69353269616A
A09C5E4B8C598454B170445373415D89465A814495595E86524E4745516247589241915D
5F854172754D8E7E32459F794B68965136657962626F46889641775E34727E578D75653B
858C71AFCA9E668E9E934375C389212B8B578BB87F4F5D4E497F3C6BAB5F9F9D66518146
5AA571397C74257061333CBB8F6362657D6B466E90603E9F9C5F94643A4E825861725354
2E244B583D5D5A4C5AB86556597A394058426750503349602E1D25634B417970803D7C96
58597E5F303495633A673D31727F43645347224C79673A5D5E481C5188805761
684A793A707C44874121324E3A27303C592C39491F605527361D19624F244F2D3F595245
793C284B5D461C1E461D4F7C453F4F664266537B6D6D3522724524405150464C63406374
541D605F1D4C6F373E2E317A3C45758144424E644BBEA25682475E3787CA72423A634A39
91A9714478438F46875853736E415C6E34777F4081325A7E4A453F473753634384417A50
3B79474E58548782432FB274516D99714A788857749B5B8678376C7B4DA58466A29B803F
84602270B5925E8E8C7A29409B822745664B47A27D6059384D7A3B649938597357496D2B
45906A4068943B6A754035AE86646D5B9F8B517D9872409898599B7D42658E6667705853
37244A6B434F544069C25C4C53894C465C3F617A653C506E2C2545905F4189775A224A78
446288641C2F49875E633C313F4C3C6A5A3841737E602E575C6F44385A986258
7549944279945A7B8E4C3D584D2E595276403469373957233A371F6556304F4F5662423F
8941274D6247323F5130489D623D54593F70436C6355292B7C60353C6252478982497575
4C217070244B572B594F2F6F2F4A72864A3E4D392A808D5384484A2943A4704C4C69522F
7D946E44856080467B834C607A49788D495771488E78617F51517C73555A3D499C5D8637
398150583F2E7781583CB43B25588F714174473B50894E8067358484548B64367D7C8341
828E7C8DCA87638CB79E67429F8E405DA26857AA835263592E6E3851B56F7C6F48476949
579A64386B9133696F3D54B581545F567D2A5D91AD93528A885AAC8A4366843551676868
38204169407B67426EC06055878F4B476351534862324D721F131F536249847791425F82
434279401D2F83536F8F454764684A71594D2A495A462A5F7476453959A95C5C
6E499144807956989055374535446547672E3D8354655A0C3753387C3B0D3D51495F1920
82612A4661281E3D4C10236067314C232A5E3471A130281C457C3D57783122405D3C6388
4317546A283F5A2B4758407154395E8E525D87994CB9A03C8D8C8A433DD16C243B547546
B1BB65357958872F527A5C5B392E4E6F4D4D39295B684E6A332E425B4C5E3F4582607C60
478E4A525657717F42318E5C4F59765D38537A6A66A0676F8C48698C5B7C8F82877D583E
6D876F84BD89424870854E3C8C573A78A06C56A34E4F725E275D4B6DB76F8669435F7558
53944C2C798D36685B1E366E7D665C557B3E334C678C3D7C53528B873E667B5752498177
351D3B5F29445B535DBB764354744C4B5A6D6B56572E4B6C35191E57735F858DA84B558B
3D6694602929633D53A1876177893560856A425F94171741696C403650A81954
6C425D4395632E766A383A412D2E5044632D25512A5B5A18292D25706C36353F3A5D5C27
AE6926576C58343F544B406A4727545E3E651A3E6E66623B5A8D172B5F5D3B4B4F253E79
7B2753622B628041425C3C746D4B597D2A324E7B45AE912E4B44654835CC81503B406D49
9DBF83477E69845A7D9B5E4F7B4B547A57485D406370497F5C3D4953466F4D3D8E5D8571
4F9049686E5E638E312E896B586A795C4C718F716E865C9CB550707D33788776867A5A3E
6284806DC0998452A0A86F337197585AA76E55A0733140562251373DA2707A6B542F554E
57A465443D9237608668245A88725C5F92644C746F8D356D874A7C873E5D77664E4A797A
3B1B358650515E6E319167576B804B436C88675B674157753C1F21546A386895A645528F
1D304A5859296525213F7177789833475F57417C8E55243D4E713C3F99BA423C
6A4664314D725DBD60172C3A2E393A2E53402E4B10234527332E18313E322D2E162B4820
B38910203847252135463F7D401B2E542F672E455E6149304E84312F5A4C39484B31256F
5C243C682B337B3F4347327D78537A7B583A5456399FA45E6A4B5A4940B88F6C47416E39
86B49350733C81597D83578689545167435B623C5D4C4F734C3A47482E4B6341823F577A
437F553D566255AD522860695B4E89502D386F59766338707C385A82385873777A998F50
67844D4FA69A8442B5934B3B79A7645F9B564EB99844516820586542B88172776B345A48
45A8575B3F993A59755925557A5B5B86A673477B629A3B6574437D8B4264866545505256
40212D7B4851474C3597644F7B7743697A855C64641B3B60553D26727034514E7C52527E
63427F634B2E9658524746425E7E5256A48261649D1D13426E773A2744873940
82467F525F8B76CF7551283F5A2143347B5B2C4F44397231343538645744254945586E27
90912D334C501A2C3A583E9260353C6137714C646E65422E5288342D5853446A714C297B
57264B8B3F35902342683B824D3A55715D3855482358A65F634E4C252D939361453B773C
6A889549745373616B8348426D4C50644D3C503D5761417A573344524B4A644E877F6889
547F6D54565D48AE4D3C49764A3F916B37408C6287836A83883052955E5D73506AA98D51
5A87294C7C917D42C0A5421B40915F58A26E3976704353383F776637AB52548C6C3A653F
379E6F5F3A8426708C561E65861C3B5D85643F8E63A4297D77437C794985A87A3B636044
48545A7F53474C312A747F6A79711236495044706E38364F451523576E587B546F244373
5554A990341E573A2D705F5757812321687B6178AA38131931654A3357B71822
654382575B7A43A595602E4248285E3C7A23225D5037610E284C4369590B17614F62420B
679C5039572F204F332D1D7175353945175B43687E4D2418337E482B5A4A3A4947512A6E
632E3479412F9046344527788A4661766E3765724489C458768A817F52A78D7C4A429C65
A7B3A8479169745B64AF624F704963896F4D654C6C914F875B495A70554F593F98905468
508B6E504C33509D70495F921F2B6B84443F9F2240565080AF3156985E607436406B8A52
6B8D8C8EA4A0413995AC8127447B396AA592467B7153746E1435533A9B5130446A327444
2A677957619C2D3A6936287F8150455A6335256F779B2C4796408A76282E6A6037827143
3222305E396488511F776137667D375264383752412045764D241C435B2268A69E5B4973
1729597075337A2D24445D6569734D3A6E723C7D96572A24426E613258B76941
6D43685C537532645A51273A1F19382E571B1241452F5C1A1D2C306B5D3A1A4A44716329
45A43B3F6151284A2F60316854284760385824508170633E38B6231E5E5C528A42271B66
77413184211E87603D461B547240668947285E634078CF353946646540BDBD413A357159
9FBBB13353696C4A467657535138375762444B2B3D633D722F202E40465246246D71486B
406D6C4F6564397561496296702F6F6732498C5C5E4E2F699A543A933A5A7E81408B4A2D
47736D64B1B27D42AEBB733358945D40626E40957927345A1D45314C8A844D5B532F7478
43A38E382B614165963D185E8E2E4782A074316F568C1C8CB0616B501F48A86F21318457
424C5E912F384A462B95945C585C275B6B6C435A54151B547A5E1F46540E3457845D5669
4431734D2C30935251636A776A65644B93723784B0452724416B462F89BF7042
6A4770425A9B6276816C2A4E643B382458492F4B3625633E3833215372571C3F133C5835
3DAD19214659252817553567561D1D433D533F475561523D3DA12E1E3D51558E504F1C79
743E3472411F7968394B2B4874466771622E56663F69D374605E5B6A4294B5764D418163
7FBDB1566C60775A5F8254767E6D486E5C595B5B5362317864393C4F2B5B62426B423785
53835C3C5E6D469488273B8E6C3782804433884D6978506265583998544956573FA08A55
599B1E1F6AA99650C2CC201B53866742856E185384433A4838616E388A5B2DA19030703E
1177A2742A6211387C5D1869961D2F505D7D4B7657833D42945A705728275E7740449B47
1B1F3F675F3D503B1D64806E4B721C464464405F4221305A521F204955335D5C745D677C
79456851211F55515E6F6F5A497F62489E623571A15A341D386E432CA3B0793D
5B486C4B3862516572291A244C3A301A385A313E37175A38362B113244541C4142535F4B
369233353F5925492261446560332845445A5B606E605A4E4A9B442945675B684D612F8E
7E51328F57217B6633592F4E80497A9B793D64712341A97392868A34253E84AF826D9F4C
508AA04C7C4655525D8E3144634E598D443A4D485C7E295C4E31547950445B29748D506D
318A964E5C32368F90504CAA33296F7946327B41415450675D341C6E6D54783E1E556F51
49977B8AAAB0955FBECA8739387F7A4A8780426D8C6236571933623978682D526922573E
296F8B5F2C704540633416678D3F5271557B4377747C4B3E8F4D7178603B8A7434469077
4F273C7F663A4D5E31748176486C40684A613068513A35686629266B8452586C733A3A63
7042593B2329805459556E2618677645A371546AA66039214370611C4F91632E
554366644389516D8D7B333B553D4C3E445A323F3F2169293D3523415B44205E5C625D4B
36A046353E603464335C375B98492F3E245058527B50353132855B2B4E502F6D6D6A47AE
9633287D602B97622C583557632A417B553B7DA5594ED2483F495B6D5A3581D5977D6E70
84D0CE404C7065452F8663655D1B315B7249511932785375461E244A5F515B1F5B8A526F
3F5676475F3F2368774B538C3C2046803F2B5B8B626980755A653A877D56697D3C888264
448B7EADBAB2915AB9D6913F3A7F5154918D4D6C77622E63234554336D8E576565245D4F
4B8AAB6D3E925B497A301A6A994C506E446B34445F7841317C347E6D4F397A6929397E4C
36283F814B2E4B88487F937B50AF65764E5625767956284D6E26265A7E6949847A40475E
5A3D704E3435666848508C642B544A2C7880687EC57452161D52612990C45823
584C544A4086393641472950412137393C2012203A1D5F1A1C2F295DA7421B4D45636D25
1A575438615C22502E4E1F304C302A5447564065A87667493B98501C5B60434F45322C95
914F1F783822626C2C53192E6540587B5C2548545563D36B56585F6A55276DBBE0E27C93
77CBCB6F568F5A63569668596B763E768C4D515947773D5B6D4A3C54594D4A2E56945B87
63606A406B7E4C7F7C3A53736343549E472D527D68667E8265854A85844D695341817C61
4C918D84C1CA572F85C69740356F393975874D627259355C233F623D7E925A73702D6D73
5D8EAD4246A067477A4127A1C17E516E426D313E7B934F30742E72714E36797636618F46
3F25347630356E79477587503A81607D716C2E4C5338224E725221486632438F8D665786
872F415462425D7852376F763D656B41867B23296F7A52191F54291A7DA47B3B
534C5B4335554B555A3416314F41361C31472C2A320F45382A310A1A4259244A1D294A4C
1A644516374D3E46183D3C526921142A56443F2D545D5943329A571E344B3D583F532D80
7A5C21705D1E678232442E3C8A304756743F617E615FD5887170517F502653BCD9E38294
55C4CF6F4F96535856A5665569763E70884E52534970345A6A3E41525B57553F5A944D7B
694A8754838C4C8496485B858954549A493E7F856B664E86B9893F778749996144786729
2D71836DB8C47C4DA5D191532C6F8B486B9052768C33254E21355246859D577875255061
5689A56E36825F4C9645196EA757496F6B7F4A27577E3F40854E6B5D523D7C6F276D9D74
513247845035425E266D8A693D733C5243653F765F3821375C3F2A719855506D65162357
8846517A37299DB1774276492B5D9C4B9F7F51485E876916234265234286714D
515151783A725C557D6B3138474329402B62372A4929755122251C204761222B4A3F5A5F
184753233A563E3B4046555060473236603C6F5287736F3F3298602D463B3C5B3D7345C0
9078274C6E245C8D38454239791E447979455A754B44D48E6971534E2C22369DD0E3BA91
38A2CD7D4492517D53A969647D7C42698E4F6C6147783E62794B444D58416D694D9F4583
65398B3965814A83B2412A69804061985023734E557C5344617D446F7B296A6C44779671
3D9471448FBC9357ADD46B364582804D7B9B2B52755B4358363E5E32499F5D86853D4D6E
4777956A459D48418657269ACE69505D51744D437AA04924734690AA3E2D596E3475AF79
382127653A3C848D3F64805747AC7B6546631B5372592744692022588F7C4D7B76393D57
74364A7E1815507A6A39852610377F40988B7F4E5374501F325B7C3151AC8165
515C4E823B776D4C7D8B4747554A254A356A3E2C4A2E5B4513211E1E556427344B435956
1A366D2F4C57452C45495B49544C3C3A6B376C5C7F7E7243338F503245573249767C3DC9
99582A3F732A487134484E37781B4AA589485C66382CB97972744A8E6337256EB0DCC68A
386688643C843B764C994B3A6C733D588A426965427B4F457E5945516840475D41A76B82
583A8861585A3E6F9F554B506E2F427A5C35A17C4755666F648B2269974D726A27537367
52A7984B8AC4612981C9A35B2D56525A899268425E261026192D4D5798B0384B553E7D82
5548A15A4AB7843F7F1E1575A286655F5872190F1C827A2870163F665835606F2249966C
59262561451C2D61405A8C37297C76605759152F4A602F455A21173763584C897B90555D
6C356A944936709F574EA076414A6F309CA8785242903F1B2E46652B83BD892A
52515B9041736B457D944B485B51314F336735284F295D3917391F1D47572449573B4B51
183D7A314C575C354B474E4275693237493C755B74894421257066313E5727436A7537BA
B32C1939612D437C25515936732B2E6A69305E767D3ECD6E43775F8F534A3D78B9D28097
53A1C17E39905B77518E7C4656793A5997596C59407E66417335445C7B50553C3B86618C
54325E4881805A5CBC514F6E865B538D3B33898E546D6648B7B84B46803A778A4B6D6524
1D5589699AD0662B6AC3A466395B2B324E676B41586F2A3E3222482146986C51482A3481
6E49C55D1F888B39833C1872676062535A6059292B6F672D6B6F72886D3655846A62B68A
772A2F5D865A4A7E374D9066466769495C653A635250304A79432E437C4A53BDAE93526D
6E24378F3624818A492B6C64425167336C83784E46937A1C193356264B7D8357
50403F7D4379382A6265393E532035572E4C09124628543D1340371E44561F52582F4A46
0F46803D4C67462F38432C1C4E4C1F36432C4034698252372285421738575553554E208B
934F2B3A3F1C36843C493B2D593D3969744B42568242CC94476D3C8A61443567B2803067
4398C6802E88607E326C7956774B26467D5083362A54464C8D553D4F5238797547A22171
823863183D806756BE492D56736557A04123A07758917E403E7C663A85213F6853567977
406C926A94D29C6A96DEA3746C9F8B5D6A85627A867E404D3724643A56AA7E564C564A9D
754880624091763EA55D2195697964609C8D5B40428A7446998D848C6636598C6D5BB182
7B2E3D658758507E4A60B1905C6F7554957D586A684A21417764333F8E3F347173805386
905A448C3D378984432C79392D678A4C85B3743361A782334E6D8A4644878A55
4C55486A376C4B29584A19345A3327211B572D1B2E11404F1741151D404E2F5034113252
1E20641A2F4A45231E2F503E5D462123534D6A3A4C645729207C4B2A24575B65A5802F67
B659346D56332F7439414F30572E3A81885E40575D41C1A84C7B352A1A212D6F713E3460
3377B7A53779348B4E52492B546B30456F20455D3E5D4D2E675A47594D324C5A3DA96376
734370566A686262CB6C3A518436599E732B81544C616E575E885651936A5C76515CA287
417AA14159BA843BA9DF9A3F35597267999D57404F5743453B4A8D4053A6747D8950427C
2C2D64623B8C4C3E9B511F9E5D7A2F3956744B4F5A8B6127616491AF4B2B6189644CBF65
2B315B7D7855547D2342897C529B9F3D615C2555786B37385E3E2A65C3896B9EA350355F
874D7EA480648E4F5A3CBD83504370297A9576405CA45D111D3F76373B736825
4E494F8A4465613E87852F304541586428522B2C563B5166154D47213F4417586440324A
29429D373748422B3D2B41437D80272B312D633F504F5B2F1B4357382643192B617A403F
C7311C4C724A2A702A327E38631818456E58395A43288C9657842F2A235481C4753F305A
255F948C35776179514780454F753D518359574E407376407D3E4C627F53644A2C8B7A84
57386D5F7C6C36389E6A3B578B514485742FA27269778C688EA249338C65597E443B6C78
3B7BB48192D27A4E81C68D6D315D6D4C759B7E4C5243355E3924544665A35C445032698B
3E35495C3D956B43974535B7AD976B4C876E323142684E2C694155845A2C4F8E6A4DAB7A
5E2E3F50632659793D44BA6739588653A18C5D4F4E7731509B60332A664A388697875E87
8639458D8A5EBD37402B7478484A77526E8C7F457782821F23277752336F8868
4D523E79426C4D25354A38303F2623582F502A0E383D43570B344E254148352A48463C4B
15155C37384A3F1B342040354355262D505076474A4D715A35425439213D5F3C6879472C
B05F3146604E286A5E3D5E335F5C2E5D6C6651879847B9A4609E45371F3057AA8936496B
5D8DBB9834837187454B844A565C293E6A63594C33466C3C79683A4969515A7146A18788
93468B5E7C748D41B473325BA37E57925D3DA37C5179895471ACA4399F6F6E8061477B3C
28597B7594D17E618CD8806A5FA2B08477AE6E72947A48374E305B355296905D6E4A3684
6150686740A28049BA4A2F874C7D3948938C5B3E48784E308B716371453680BA43539C63
433E6C7D824B4A771947A8A0576371385D6D6A4B4C76332D4D5C3C2B706F5A8F77927A9E
81733FA78C68A2375831808B5448876C8B9D9251867D86282527795E2D77A388
526C4487468685484563592F5B633F71346B5D1A3E46416F2548562A4450533959493454
361F81352D4F553B3E225E5C6758283864556F42527D7E673E3D682A3B575C3B5E552A46
9B6E3B4E674C338C743D593A78433A5A582B2C4B7347BEA748747B80672761916C324C64
5F7ACAA437725D9A6040804D5F7D573E71646459515764368B814645522D52643EA04972
9B3C9046629D8B43A66B358CBA835AA6662E775E529FBA7554828E44AC41506E7047A678
48619E3B3FC19E5489DF725125478D6F6D9F5C3F4C5D493433527F4F3E98466E8E613396
2323606A347F5426795323A54C6F50416D485F3F537F662C4F72747556203C6A603D9A6A
3A1E383E694B4A733732A987565947388A78794E486A453E596E48256B7572B9789177B3
A4783CAC894E753B633D7D894E4C9173878B7841ACA28D29242A6423409A9D8A
4B5B4376364D6045474C212C695145501F5C4119221035541F3F311D4C5D4C2F3E142C61
361E9B3A1A3F563A3A2F5A5365531D305A4B653136585D49404C74461C2D52386E5F361F
5466383259371B4C6A3459324F3C1F6767663950562A8CA258684B6D5A428E956B324157
3B49AFA34268446774424F326A805840733D4A684F546B34716F4359785D615139A68F72
8F4C974E4E79745AC09E3A4C9F3F519C7B31765E3452605351755C41A97C5D742F237687
3D626E6F8FD3855586D58F88354F906E60A68A5C5366512C54267F584196896956553276
323F52553676623E894523A54C674C4084475233547B5D2E4759656A582F507960349372
4E274F47754B4569673CBA8566564B48A8736E3F4B624F375947332265706DA5745B2769
A3742FB7642866A2883D707B4E5B9D7281834D178D8F7D24272F5E3E1E58766F
536544A24A6D7F4262765326414E4C6639593D1C302E325621402F1E374E233266423457
22289E6D2E4061365E2D5A4C7EA33C346246876941705536262562503160351E57706529
4E81462B757224577A327F4B5F462262766B3F789B479BA65286A28D452B6A9D6D4E8C98
6479C59E336D7C626347834D577A3C5D8E71464A245585496B39283D6D5C534D22838F5B
7035736451763530787F384F9B6B477F87357966626B8C7544638B63A76164565B3B9569
3D596C58AAD475569ADE697B374D93766EB892615567532B5B31876849A29D708173337C
51594E733C7F7A44875C33A993A6774E864953336183552D3C4D527248335B7153247962
2B2A4F48612736625E45B27B5254694BAC6C5E35748763374C4A2C419CA0729E7872577F
7F412BA76117376A6E3675761E2F7D677FA67B4B9CA26832454E6E541D5BA639
534E416D40767A2735484A2F4B282B5432661D0B2E3D357A143B42324C7F3D1E49364370
36156C6829585622573251273E5D2D377D3B67464E8C756649335425182E4C354D553532
678D3122474729707D345F35625D29556F3D2340694185953A4B42696A33539C4B2C434F
5D7FC7AB4F63614C7145824A50755A416C723F4945486A4A556E3C3D5E58475149A19654
8159935B4C8473429F903449977F5372784FA7A46A62826A3B698F759B52595C67438D57
4065A682A2D3871970B0B19F3A4D692E7AC1A26252685252592F7F6F68B4A06D947C3A8D
5C5C557831969D42725F397D82AC8A53914B4D141B51933D346147B07537697E54255B5F
29294F425626417E5D42AB5B3D91B34E9E7D331848765A3D62642125616448869E9B7C85
89333697784935504F248294504A7019486F8F50A0CC8C201D24603A2C93B958
4B5943773346663B43361B1C334D35391B4A4B191E181A5C2739320F36554E1B4020235E
4B177054142D52303B235A4B51702D22533E5F4636616B644A343E3A1F2C31343C4C4620
2C69381C36501C487C3D553F486B2F4A576C3C487B437192517453737B44789B88505564
6A73C7A1566977436C4AA15B51746D61776F444942507247576C423C5152535C418A8C4C
8B5D8D6F52817F4992963A5BB3A44E7E613371914F5F85465BB2A8649164738D874C8657
2953AB9182D4AD567CD065834456815553939E61525A17253E1C6D4564ABB054A23E3C99
6C5A5471208A94406D6C2C7E3C7A5F52BD88763A4662833F355C35707A336A7D2E298E83
663F514353122E52873EB37E29668C4B859D6D2F4761191C3B59511F564F35534F77477B
B46F1B716A40469C71335B66385DA4694970661774B282272C25562715559C6B
576742AB515792424348712F4F65303D425E4E1F202129561E351D17324B461D3B2F355E
4A18615D23384C2A3F28674C4477413957326C5E52776D6B50343D4223302F3B32544D2A
2D6E2D29566221427431544546562F3B53643C47704280AA708A586E312A509477415B5C
5459AFBA6B5888527946875E596765596565526C4F5066357696424A4F47446951697A39
985E6C733392A5508A8B1B3790885085935278893A80A66C26547D48834556978E4B8E7C
4E47B5433EC7AB5782D1561E31749F7262A3836298804C2E5E1C345B3B849756BE53319C
7458748B43738C3893933A9450895329585F673E5B8487214D8256915523637555315087
462C59646F55404A33276E7B5D66782859696127657C622B4B51373187AE72794A634845
846E2073991F2FA193456270183277694E78564337B4621F342D577A1942AF7B
5D6043AF5A4E82438EA07F384D5B3954465A4C1F322B325B1E3D31234152482A633C3441
3D2163753236532D3C33654C4DA4623F5938877657807E645853626A282F4C453B8E6F36
267D2020417126396C2F78603E6C2950898342465E1C598E5E7D8C85774C58A56C4D8D87
6D5076935E4A7641854573317D8C6F4B57564177554A6C4C605F45576B63544721608B4A
6529667B3A653F2E7496533A92372A5675709DA12D4C53632C61674292926078321E467F
604AB03A65CF9F4687CE74752B3F75646EB08A56494B3F434527576F41A7473EB07C3BA4
31143B6F4076852752673395A1A7845C8A4D4D234A6992412B7934907B34466D2317447B
5A2C302C4C3661897040886B3880B3626E7457123466682D494E2A1843696B884E83854E
AC633485923B1D66633E7B603647716C5CA56A53319A7D214F5C79721C3DBF61
5853387A504A74322E576D2A48321A57414F13093B442D7D14345E3C3C5D3A184759403B
242673903E3158204635441D2A665731572F66644F80681A2E49627128485725204B5729
37874924374D264A7E2347533B6C2A36575F2F59885559AE24324567703D59BC5625323C
5F7CCDC836397A514C26654C475C39446D6750761D346860655B1D28405253592E427437
813F4E7730755C3E779A504F9E8645577058668F656D735E378298524E7975996D4C4884
655EBE769FDE942570C08D9038558E2E5CA5A388836D38546A1A234769BC794997573BAB
58576C7C1F789D4D67601D5D4F676653764A5D273B4A6E2D296424565A3C5D6E46252360
563C34344E0F265A7F4E907E24517664615C733A4F6466324B5B6825465E6D7A7A9A7042
B3481F45774A297F5C288291594A6B3A4472685D2E8D711E20254F661C3CB865
4D6B3D8B425999454A407C304B6E3F4C334B35191F1D165B2A2D400D306B512A39292D55
421A395E20406B3535205B403373251F514A71322C73715F3F334A1A14344D4C2750420E
1E4D442945291026663E4B361A5242324E4F24285F5A54B244545D5E48326EB68C53503F
5476BCAF4A367751672C56455A6F4730405245873D3F6F45586E4942463741643B4C6937
8C5A4C8F356D8350849A213B77A34A62864E5670487E7F571D48755E90685C9F9C584478
2347A88677E1A22D5E9274805F89B9756B87997FC0832D376F2525474F8391598860309E
7967888E21568E3C5D7A34775A6E4E4D906965355A5B7C28315A39623A37597365352765
62483834656D4A48783E97786564726C577F8C5E595C512C587C7A213F603B4B458E8D47
B6742B4997552D7C624A7C793F4B697A469761552A976D272D2F62832838B088
5C6C408447354E395447311F36583F39132243281F1B0F3241324B1019314A262F1E1930
51214C750E12393D2D123F5340803017353A60472A4E5E5B474F5B44282D4D5632503B1E
1A5D3823555D252C693452572866402C5366473E623B45AB73555B69311B4F9B834E5742
693E8DB1683F7D47A34F83224A7A7A40534E1B89755079314184554C4943355E56467C4E
8470469B505173457E9F47245B6E5C99A0656B6F4594B77F356071707E79455E89534F8B
613F963B35CFAB4C7BAC59363A69976F6C919A3DB1793A426535386C30818F666A6D2D92
64508B8A474B8E2E7A7F3E78626B61325A65704865619E1F49834C6F4121527C663D2670
3E2539597270524A531A94A965597E3A5C9B8F5B50546030486A79283D77886D4A838B4C
C3802E4CAB582A9972557F80594B796E4D9F4D2F409179362B3564673535A691
6E89459A6B4071395F7B5B2B2D4A3448553E72342549294A40335E4027495E31354A5037
4B14476E3126482D37314E3F3E90733439355B76436B7A201D4D746734325B462E6C713A
1F613A1C6482342D612B4B681D6E2E2B6D7B4635592A2B895F54667F816055A773527B6F
664954866B45823B7D48833D33556B4A7474447B6A55896A407F546E84754E6544579960
7A4D4D985E625A387DA1722B594D35567775656B496D6062314C63495F975E72552F368A
7B4AA98368D2B65E91A89796384FA38563848F55B27F41494F2F566A308F5232657D3B9A
603C6690604DA4486561376B706874595A58925B7766A4492D82536745354B7769442662
5243252C5C71514862275C825C557737436E795F5C548747505E66315A88775B538B4637
8F6E3D53AB592CA2925070834E42896F44A65644287C783959696E3B212F9382
606437615F395A211F435F3133330D3D5E384B1F375B33452D34876B28495E0C3679513B
4F185C97482D45152A4243121D596A36393746713A75752D1D2A3F4D2C3F7D2E17466748
257C4F15365B373F8B3E3D6227673E17396B41457E743A9D49384C5D7B5B66B95B363B3F
6B82A3C46A3A88536730625C4A684030495F508C483171694567363E4451475842477E5B
6E563E7E566361475C9F7527477A49698A6E657371948D913A4F5C7241A45D5D9E6D5995
8B4F9F9877ADAA6594B1A2A1415D9F805B849F5791513744703531652B723B4D427F3A8E
9070A7B16C53B85B747B4064857381636C55A064735BA14C2A7B6462473D527D66381F69
614A2B3566865747693061B688507E64507B7E556B75834555653924386A604A6F98763C
A457325890521C71563E838E5A3A885343B58F632C8179331D2B54672F167B5E
5379416C67438752436E7B3A2E59382645314D1D144927412C1E654C213A693825533F43
5B2A2D62332C5C3C3832514A2F5B411C3E524E592154585A41425C31182951593B464C18
144E491B314317236246404B214F59284A6A2A254C743B9F654D5A526A7082AD87674C46
8697CBC788418A5B68608B674D5D8E4955766891844980794C5D63534E66484F4A4D7569
66523F93455F6E5765B08123407E4C608A7183766091A399454A758452AE69619D70648E
5F54A7966F95AC4B5C86998A3F5694405C9597599D5E4340783A37632F75515C3D663689
634AA08A546BBB527478316996A18058795D943A6A72A25F25845C746F49537A6E48256E
72632D35678464696D2E66A8725AB052479C852E464B5C33637B7A3437824C4155897446
AE7C2E3876602B9C711B5F81613E9048317D714B4EB57F48212B6868434C8B82
636D44634F2F5947535B5A29376D4C2C2F235432182B0B2E4E255D1D112F544425391123
5631316A1E153C54361A3A5D3C66462A274E436C3D625D714C43605D3B2D57725D444734
1B5D43192D4027306F40435C285C511F4063543054713A9962555F6257344B8E76565347
808DD2D18D47845C716291794862955452645398874A7876554F6051515A425938527E63
7E5C3E9B5981856468B07138587F4A587E5894856A8BCC8D547EA79049855B8AA4725D8E
3D407E715A80A56E6A766058485D926A51886B529C6D2A3C7A39385C40864D4C364E3798
644693A4263F93406A6A2746725852436F628D405B558F432572353D5036557347314876
735334406B40384966476BB7533983563C8884616E867A3344593E305695894657844C2D
8172273B725E359D9B5D687A6D4C8D5F39826E41297263461F2C5E5236247C80
7B924F507335655C6A537F4636595B2542255B3618301E3240264D342D28564B26403934
513434715F2A416E3B3B407144564F3A2D4D3C80457D758350435D68452A55736747504F
1F595C27304F302F6E3D4B55335252273F625530564C2E74815666668B7760B776575A4A
56427AA18247814D7658704C5F8F88495259297D834A80503F53624B524F35535F53A83A
655C479032486B5A61C473233E753B6B814F767A4584CD83353658475AB652508B6D7EA6
81519A4F31619E814C716C4342688A6B60A475488649333050343E4E32546C4A40672764
5937A28F574EA9486963314486534139868278467452AB23458D53495820547B56452851
77202F496278575268194C788050A27040795B5663517B3D4B5D5C323170855279627D4E
9A83345A9380367B5C586C6D5F367E6944959E673585723E3B4D6B5637268881
8081555480376A647771A1674A606922472A583F193B39414E205F483D304C4D295C4E30
4736348E73283D6D343E39704961953E3559449A447F7F653F506F6E522952503B60925A
1F5458234867322C6437526234464C2644675A2E6B7C348E803A7592876F65CF6A466571
765CCDDB8C4996576A40556A465763477289648B75478B844C474947696E534E483E9066
65593C8375715A324BA398293C75484E8A407274506ACF86573D6B7A578E59717F455DA3
6B4E9E83884BAD8048808789495399867CC3A843786F453B563569963C707762556B3D78
744AB1AE7953C1536D7E4F4AAB6D744D665F86468761AE462155475A73394B594D253D79
6D422733556752848A2646744C3B90814C79728579538B425C8B743B2F603722455D734C
895219306A733896574F86AC91499A7C3A7E8B6736855D2F16205872352D8E65
687A3F4760356439394A714E3F5C393355264A281F4C3744591F6F4736456C361B473C32
481C1F5A562A45461F3835392038553340532C6131849150393342543B3969675F3B5345
23716E282B4E373A794D4659363D5C2F3E6E442A5474398AA1445A5C6C6A6DD585633F39
809BBFD59B38756875654979515D79485165578B883F78854F4C6E4447705E5063458F6A
5D844484856B585E46BD8A32486737467E449F854D42C77F5D65889659804B7C8C7759AE
8563B699753EB96D4E708F884A649E444D947B4A8F814D566934325938736D3064614181
6E2877723B499F504E703A6088878D65706A8D427B79A26B26624B415A4A4C59715C2D46
865D2837545C444C6C3D41757455994A308C777884576D204465512F2C55695760427258
795A332E6A7C3C8E563D587E7240935A2C6769463B8449491926688343299089
68655D476D2E5761585D8F5945855E232D25593614260D2B6220572F1926475020351925
564D1C5A4222476A3B243968463C622B284637774461647052566E693A2445706E3F633D
173F5A242E4D20275D5B534F203E5B343D5359256782468AB66B6B6A643355AA845B4A3C
8C93C6CE90437F7484734B8250638B5F5C6D80879F4A797B4F566B464F6C61707440925A
7568428139586F5A46BE5C2B3E6D364B803872814A37B1844E3C75844C8164AA9C7853A3
5748846D4540A2945487A96C417E9E8273C375338A5C312D50373E62388472405C3E2A4F
51279C9B593D9141566C3040864571615B6D85637B5C9E6B3255574A695F414F716B3843
9E662B354C896360836B4AB19D6B965434837D70745A895B415C4C33265D88727953845A
8E883C346B673594565E6C90753D84473B67786458B2664616246A4D314E9E90
8A72714E983940565093A0372D4D632C2F1C5549172C1D2D611D58281D2A495A24332E2B
465719476B2A286A33433679553D834B33574478516F65503F3646604F23444F39509056
23415728557534215D4955734E316939485F7B2D69572F6F95536D74826D63D16A386E80
984794BA893A723F7E734A66508689515869576F924A765C45515D456C743B4D5D47AA5A
5D42398A6F56524862C28B343470315A8A43837E3F48A48F6E37567549895665815B5CAF
8C539A62334A949165898F7A49628F7F73C571378C57303B503A7695345E764577533D3F
501FAFA96236844273763A3D8A497A4E6E8399647F5C9149468947486749597F67633445
893433576C7B53515D3F37A6875A9082647578846D638B59477C724331768D698B8D5338
8E8A3D3C72743BA4B066638E6C37877D4B68AC67417E524C272D5D5136267581
7968473F70373E5239466C4F2E51454265284D411D412821541A60352F2D41442756362B
3E371B617F311B662D5237604A50AA552B3F216250656D6A63404C734A1E416B7147656B
264268362C5B4B205F50395B5631662E40756C2C7C6B387E9D335D6E655F69D86C4E3038
7850BDC38C429B6A5B665A904B586A46657C5F6977387A864E544230526351534E357E67
5D4434776B65584F3A9E8732357B3D3D6F3F7E6B5F4463656339583D44836A7875313699
7E509D876A59AE574686997F4A71925866B5843E886E333E4F3730663765782B5A614750
69297F995F4198484466454F9E8F9D594F5E77687E6A91432A45453B5C3432436F552C49
721A1E3040673147593C37B9864785967579774B508285524674562F2D4F66498999845C
99773A46736B357A915265A75C277A8D4A447E8693BB6B3D1D2D5F593E2A8472
696F7D3F793D3B7C8279A6762C4D45223F22431B1A413E2D5F144B40224E6A5E233C3B25
485916336B2C164E253D2A44322F5B3B31533A643F75A55D5D484E52301D67797B47704E
1E558146314A2B2D756B4B5A403C7C343A614D288580386AAD3E5F544D6565D76F654842
776FCEC96F235B5C4D4C3C5C475D73414A564D4C94436C8D4F5466464D634B556646A67A
676752858C6A5F6B45AA6836347037467F406E58613E58766E36526444736775735740A2
684B9A8F6D609E8F838C9D855766969163C49B3E748F3F55683D3474416A7D3F55583339
683EBCBE583B745748773D2D67377E6C5E7E95607799A86A3642473C72463651823C2F5F
6426284249591D61814D299BAD376E82476D735C545A7C374F827C4628623B3A73A3492A
7F5D414E786C1C66826B4681461F71915C51B48162936155383E706335349587
70556E3A5B2D294F6B6D9459387480474B34656725350E1E662543402225315528492229
60621B3060231D63382D366F553E6B1F1C3933622E36526052424F661B17415A54387345
1D3B5F272645261A454B4159421D64283850562363893552C3676E595D566BCF8C6C4D47
7A61C1B3483579625A70597748598F6563726F46A04F6E8D4F56824F53755F587B4F9379
80624E818C67525A41AB5A3639753E456B388794724C387F703B585D498873858C763E9B
704E8A8D6677B38F848EAA8F5974A99060C687447D9C3A2E503A2D6E3C5C6E42525E433A
6E4593B4834788584E995430753B7548598196666B6C7E4D355B452E56363669936E454D
5C1728545B622F3F5D492485B241617046616D4F56838F533F60562B3150514A6FAA8554
8C5F33375D71367282765498542C5881312A84997DC7763F192A5E5728235E6E
995D923A735F2F703D5B7C351E384F372E154B5C233134256E2B384845383D6A2B3B3339
53641B28592015492F2421554E396F4E2F403A5F68526776683F596D592F3F776B405D3F
264162252745271D47533A5767277F3338596C326482383FC06784736D5D58C663615748
8149ABCA713C7A574C735C7945738A675C77714C994C667948616A4F69834A5B64379D50
624C418270556F5652BB81343D7030507842697B5842419152456A524B975F687A58469C
8B55917F4D5F8C7A617DB66B365F867859BB7331627F33324D3B49924A6476365A504435
583597A768408C543E6F5D2F763C7B6B4470977877809275453D5D4866622B4E8D815155
6D42252E43682B4F6C623184C6494D89686D6F6149557B5A446B8A551D433F2257A88151
8D6846385B89405B894F3573542B5D7A5234AA916FCB6E5D1D215B5130277C74
8F5493387675378E426B966F33476538433451562629222566253343343D405B2E3B4552
52561929523D17503C3C375F5A48906B3C4848577450645D3D345F705229455D3D3C6B5F
3737763E356257204462406E7A28742B35737B3467843631A44A6E8066668AD459466475
915FB5B981347C604655507B3448614561865E376F3E688A4E4C4E355B67495361356874
7A494B6D8154564738885F35306C2F406E5175797B49226D733453564380777881603689
7F538A75667FB971515BB4674958977B51BD8D4B7D9C432F4B403070475A7B2F405D4733
59469EA06242835C406F523E9567875A3766725D648E8C83473554285C6E33518A4E3B4A
676F2E354868243C4F673F589D423E704867746F5C6A835D5D8F9655223E392B41BD8260
7C6D3E4B7B98434C8C683F90713857715442988668CA6F5E2127533E312E7187
7D546E3A614E3D9433488359354F4D27593147392338201C63203041294348531B443E3C
634E163E653F1E42263A2E4B2E32554A3450443A5F42805B50365362261F506651354353
2E4A79311C3A4D275C74324B542D763C2F59632962814C25895B6768556692DD89624947
7059CEC67531707C455753773B546B60487071368F4D5785544D5C484C6C4B4D64436E7A
7B6D72758B5D555E3C8C73362D80404771646E7B7B52244B5E355764408B7A758D793888
7D558F7D7784C28A684ACA7F6259958B52DBA84F7CA75A35714A2A7A556B71313D553941
504C9DB04E3B8C753F803D246B2D5C593F7974626287776836586F3F6C543550868A6457
63553A3D417F4C4452824457B3683D8F677A916A656E733A37558D5A213B373636C09268
6E89563D5A7B373D8E7C42915B33528B8B546F7C5BCDAA6E272C5D5D5028767E
984C7F406A7B4BA447547C5C2F3B472A442544401B2B231C7034253B1936445D2F402B21
47491E26502D223C3C221B4F4C415E34283C4F3956406550593652472C2537614C295051
312C602E1F3A331C355728504F1A5F3231547634588453217D6F6D53564190D68F64544C
807ACFC36C3C737D525B5885455676664E767B36865A5C76554E59474F806850774E6B71
8279737977586A543E946C32438942526E4F79AC75482F4353305C5B3D91665A7F6F3691
5A559A777184C67E4B48D79868609B6141736C4195B04D1F3E3C376B41696F31446B2536
4B3A8B8F2D2D8156428D4527722D5A4152928A766F95817A3E376F477059395F7E79545E
586340586586513D42631B5FA86B3B865563707964736E633A5A8D541F3E5D483BB89562
5C915941628A55338E7B4C87653B629C9D5BB5785BC2B173282A6E593A398A82
B74E973C65A46EA5475D8D87403C4F323E384260292C261E65301D3F32343666313E3B3E
434F2220413E2539492823595F495C4B38445E43694A725D68335D6848363C6E3E2F6C53
282A6D363250291C355A255057216625315C772D518E5F2A75815E72715A88D581516C86
9A5BC6C98B447364617F657F46617A5D4D7E5E3D8E595F89485364424D764E5179448E4E
5F655A7A7053513548A97F3A2B7028656E62556B7148385A513D656C429A80677E643E93
7F578B5966A9C97B3B45B8A66282C26B4297833C7989432043434F824856822250773929
45217C884C3A7A49578B4D21772F5529427A666B5F9C877D3E36664B6C66414E727F5E52
595F2B31406F3C2A3B5E28528B54406A416B79786A717E6B394E88531F3E593837AC7D56
758D553E5E7F4A37B190507F5B2A78B38C66C4633AB0915E2A2F633311377B7C
9B4C77375E8688B43C6F9C8A3B3F56354647416431272F1F66321A463B3E3C60133F4F3E
354E1F2D564B2D35472F2E4F4D5571673E434742873E84704C25465B3F27456967374B51
21307B511B374E2A31592461662066382958722E498F4922566A505F547185D989523E4F
7F54ADBD9840726D4A5F5D955751593757998C457D40678D594F57336A895A4A60319F5D
5958457B8C585342348E773D2D843A3E6D6359737A5B55696E2A564A388178676B713081
83517C686271AB774D2B9FA24560A07A479E8F649696642441502D7252508A2E45813F2E
4B4C7D8C423D74693E6840236E325640496A4F5A5CAD748030364F346968564A8290734E
4B65403642775729427A345E947C516B776D7D855E828C7437478C52214E5C3B34947717
4E996C3D596E332679794A76511455928174C58045AF9D5E2733544237296F88
974B713F575769A943515D4D3564632045443D4023304B2484471035233F617039273425
4F4E241A56473B4A372E2D594A47514C4766653D6230727167364054342B376765324B64
38207457203046274C693E50461D6A5D2D516B2854886D2661745F674C5B5AD68D613E50
6658C7D4AA38786B4B4F498266565549436B7B3E7442507B554D5338496556405F3E6C5A
546A58677E5A5C513E947C38317F4553727956665C414C565E2A54543A80715C6D6E3D8C
875582727278B86F543EACB56562A48D56BEC16FA29A7925415A2B726450803C4A74342E
4F5A698C6D4B7B7D3F675337878495795284586452CEAC9A41354F40797F604D6E8F7044
46654C34426D54314B882D677F7C527059608A6C639C967131416C2827666C342F727A57
67A869396F836530AC7B4A68697777AE947CD5A24896AB5750536C75582D7C99
B94C89435B7771BD495F626B2F4167312F2949582D1F24166D49153D1D1E2F5F3B232B18
2D59331C4F3B273841221D4C534D5A353747653F553865676E3C3C4F4E42385E572A4451
291C6D45202D48232F4F294F4D205958275560323C76692A647A6F6C4F5547CC9D6A3C59
7E64A0D197415D714C5B56806C534F4B4C7F8D42795B567C62424F3D527C653F5E4D7560
4F7465667C63582F3079672C2F7A3A457B7562966A49475B45569D7F3B8181547B843567
625797906476C46741377FA66466A06E25668B529F8C5C326664255C48958F374E612C59
6750437C5D418C672F79453B77627F634E90754D1943659D6B3E4F186189554E636D434F
7F8D51374465303D70822D777B4F47855D5690634FABA070253F672B1E3E46213478805E
6AAE352A578F6C33B05D3C7C79958CB45D88D099409BAD4527406B7751398380
A74B8241568B71C64F574E854C3B533428313446251F261A5E411229232B2F643E202F2E
2A4C381D4059362950253440614C6044344B773F4A446F6C743F304E54473462693C4D4F
231C7751272C3F23395B3A515420525625535E343A7B6C3C769B7176654D3CC2C5893C60
884B8ADCBA5F58645397598E616A5D364269904EA26D6092534A7956568544437B466E45
61865C576B5180433688763F53994F4C854B3855734E4C5551213E673A8A63358F85327C
2528547C7466C286793955C3746AA18B45A0A86192AC741F3C3E1F50584C723B4E71352B
4D3C3B8A754A7066348D5027723A60353E888E78486C5E87395777314B5C46538963342B
51784149587F31213C66438F9B4C2B698259AF69386270452F527C4A1D425632265E9378
6CB981415688602BBD6F376065858AB6696DD56850929F4D29356546294DA087
B04E6A3B63826AC8576E5B8A57374B352C463A59302444296F531E31363838623E234534
304136224C6037285B2A3F3D655068632F4B7B3C6A4B676A7F4E2C50554B2F66795E6163
371C80702B34533C3F5A2D6C7021445D2F707D3A3B77262A85995F8266281E7C7A6A3655
6D32519D9A4F544534684E87263E5E4839606A488F605A8B342D5B4B5973362C593E633B
385953547651644F328885342E66464F98745D8B785E5363733048553D8A834A59742C6B
61406564776BC18E7B3C46BA757FBEA449A0AC507F8D6F294D5B2B66685981365586532B
593D337B714D7A6125524E2A643D5A5E4A946F7451A171715130584681684F3C59826935
5048273344705C2A4B702C757E6F36696B45897D5E8C7F68273C7C5A21494F2C28599448
419F60404F813C289E7E4381707395B76B60D06C4679A549526974472A338186
A852592B435B539B2D556B734B3138203B573951213F69396D561C415F3F416717255A43
2E38242E5F622B40313136372E275D7326405A2C6A3D5069543146745C49275F34225F7A
3D1B743E3D5E64473E5821666F253C452047683547785028577B5EA06B61408887642E52
63528ECCA63455664E5A458D4B4852412D5C9554967653835438574D6F94613C603C7558
4E66446A84626B423884804739904E42786454A06143657E7D374C4D428C89545F86316D
78435D5C5B6AB2886C3A3EB6395698803C99B07981998B2A4D692265644C8E314A6C562B
5E5C42897647647C376D5E2565445A5E4F816F8856AF8085632E564C656E683651957B3A
515D452B4277432960793F6C8D7A3E76785E965D5E967E7639436B5033686529377B9D6D
51A72A356BA67032AC692C8691427DB44387C78C437D9742253B595F37379A72
9651703F446552A65F4E58714B353A191B40314C1916421E65651833452D315A3517382E
2248471C3B3D1B4B49222929413550561C37683E6A473D736933283A4A3A35675C355E4D
241A61422E2A462F43622D4C55273E5C336560243E6E60436D803D81655D3E8DBD734168
705A96B5CB3F3F6F4D533F6559446A392F778E4E844C519964496338486B714264477E5C
4C7F595482687E4E2A795D2934945942877B5DB466554B5A5B33414931908A5264613179
6F425D75565BBC61414883CC796097833DA1B9787A9C9B334F741D5A704C893F536C5737
756E44767A336F803270692A69717B70485D5D773D726A785A3154317285633850814A4B
7285532E477E64304A81376E9451418056518E574F9F886F34607B451B453A0D235E9F65
5ABD4325396F4A57D2A43B44666388A1313B974D409F975C26365D4D417BB677
AE567942405C3E66565A697E464364442C54335428233919615B1A3538273D5C491C3321
2F5E4A23403E154A4E262731613E5F491B457042632F388C784A2C495E4F194A60457752
1B19695436324124466F32454B19325A2F6C5D37246677546BA263995B4E2E66956D2440
5F618CB4CB5642734B794F82654674402E588E57866343855E5E724E5C7B653F5E43784E
5594574F85467F553A747E2C469D5C428A5A43A37462455F5334445239708B4E6D6F356B
4832414B6268C5895331499F77608C9952C1D0746898A0417A701F4468629F3B516A542E
5C60586D7C4C67862E9671356863776A47A9806F4A9065923D4C795F505E2D456F8F6636
5C5C163D6A8D6439436622749778376C4C4E8F8D6B9487331B37685C1C4B4D27265A8E49
46B373353E7466349F834F6F706EA1B3574295462F718E502633544C21386D63
A34C6646487A437379506B783F3057402539254A232336156A681F403F1C2B47371B301D
204A372142551E4D5D253F265E39694D1F2359435C553465653C3B6E6D621B4E60538A65
3615696339366555387030444827315F2663724D206267537CA25EA0617A5659A35F314B
6E4661A8C65B486B427B4B9E403C7657376A803B7F503E834C46594A6798514875426E4B
4A835B4D9A727952418D7E40338D5737806F46C169614273564155633C6F834783853C74
795246684872C39B5F414C9F6276BF9E3393AB5D78CAAA365161375C51457430628B7330
773A26599353658B21758E3C5E737052264D7967417356763D296F725A665D3047836A48
726D35213B725F3748652A4F84682E7946367D7F5E9E8778323F756D1F556B362B678D61
58C375373A69732F8BAA576E6B4B7E8A4A4087633B8B91432337605E3D40BA83
B25D66383F70446A72508E9A613768512D6231612E26502758711C51503030602E284A2E
294F431F43572056652142256532848D2E3462365A64336772512D514B4E21555A3E5368
5617737A3E536D584692363B5135365329668258367E58317A90569895854C3BA83C3B77
856C65A0D13751A153581D6C75447434356F87598B272D9178536221518D8F4E6A24757A
4F746A599F677C341862765934863F42A08B3FC2765A718B5E393D4642838F4A615F3693
8B6061863A3E8C734A264C8D4D3B638A45A7C45A3F58873F605127586A41931E335F6A2E
645C5F639A5A5887315F5D39759894594292587A43A06473502E6363598467384576313B
5A7A4F294077554D8481366A99894373615B78715EA78D6E33476E5A237475392A599974
5CC09037366D76465ABB636D799489A2523A7A683F95914127386671363BC093
8A45744A404A39685F36455236328A463C44317D31344E2F99851F4E432C6681451A3120
4B591F255C532161681E322F541C6058255E7C4B52453483785731535C1C306675586A4E
34226E772E32481B40705E443D142E6D395C681F27386439608C405F45745531A959252A
404B6A94CE472F554251365951396051254973517A622F6F6557625741867D4C5D3E656B
4D635C5A976E7F5038735D3640A952357A6F57CB7B4030485737414B2346824867663188
793955616255BE8050373B878A48648A3390C17F5471814086652839613B7D30536B6F2A
51497272985954A64966642D496D595C429554732E60528654395A3645524F31417A5D37
5E954E2B46754D285776336A7D625490523F6B705CBEB07E3A4B633D1A4C604D29657C50
54BE783E4A8F86438B905F437C9879A14B62957A3A949A3C274A715D3D3E8398
935A65583F843C487A45494B301B364427361C5535243E11575D216E3F1926443E1B2C11
1D53481D4046133756211E1B54326D511C22443F40411F3E5855314D665017396E56704B
480F4D5F373672502F592B334032265827515547164E7B37528D6F9656765A39C188373E
56446B8ECA543863465C37653E35695328548561726931786577985C4F8F6C465E3C6E63
51735766955980563B82762D23765A388153347A755D3A5E434A5F7142437E3584854B84
74677C414759C1863A244B9B8E475F913E97C1895569884442502338734D96414B905F34
704D786C81314495405A6931578455432B887D85459E5B9B57365F8456665A3446876D3E
5D743E2640777142628B295772552F614D3B665A36927C7A344070601D4E563D3381754F
4BBE71312A697B3AAD74483582876484243B6D6C3C9B86462433535B3335B882
A86E6554489441498E46456B6B2B465125612B6238274F3354591D565E3F464F37182C21
2B564D1E3D5936375F2338205B446562403949433D76385363622C49606E213B7759753C
4E11577F4955735F365A253146302D5B284456591953733A5B886EA16067391D8A693139
623D5091CA62364E3368376339286A5F2C547637725F358449415B57458E46477438603F
557B5E629F576B42388E7043298C4B3B806938B47B624864422F3B55463588437B77516C
656BA33A4E54B299583C2C867D4D7FA74F95C76A578C8253594B26304D41724A359F4A21
5F67735172503D8B416788385688493E2370547A3C9A5C9E4442757F626941416C937344
5B79423556886A4A5F783253838E406F624C525A58B38D813B5671491C495128226B8970
45C291403D787938AB635B427F8B587F503C704431977A512330624D203EC698
8C645D3C3E723B4A7256828C6A29405229682B5E413257334C5221535B3A4A4731284B20
2D544F224A693E3363244328574872923A304A2C4F7F3C5D4D343960675C273A5C415864
62164363233F675C31572F3D633D2A5B31627C5D194E6040738F5E996E796221896B3E54
6440686ABA4E345443573A6660325D5E31608A55754F408967516D53489768555D305556
50624B3B83656C352C7E724D2D8F59347F8240AA814D528258463F5644367F428676516D
757CBB5D4667B4945F3F34846F3E4D884A8AC48E5E686F605C4A2D386C3F703029854F25
5F516358B76D39993C4C683F538E455832805A83459B599745275D6A626F46285680563B
4E7A3B23396569455F79256295843F6C4E2B686852C7B17C253D616A29546C462352813C
4AAB9441426771227F544F46724F70AE67407B4C38948E6E2E4274672C2FA28B
90755D60417D3D545B3343595522432E2A612856233761424E4B144354365659291E3C1E
3C5E1A256F6D3E395F274620371C4E663D2C4632346D2E64674F2B314C493446684B5434
4A1537703D367E632A49292A48392E59253357511F665A2C577D558D6F71671F84602B37
5B476D86BA57305A424F2B4F622D4E642F3F7F5E63684B875F4F6F59356C66656755613F
526D5E43956F724C40896E352D855A37806F3DB385654058493C3E544D3D904B856D517D
766ABE6D49579E9155373681904B52935881C998626A717062463258843F73332E8C6734
67453440995A3A7D4D57663F4E9F4E542F765B7B4E9A5198572763766674633060813B44
6D995A273B6A322E7F88324F6F6344854725534638906768294157352055753F2C636C3F
379065354E967E337766484D8470588E4076A5663A99AD36283765733521B47E
9372605441763F47833E595541336D5A25592E5E502B56355D702F4160253C514A192B15
1E53461D41582B4477323924624D586225324B42386E2950616431345A2F234664546937
3A1A447D3C2D6B372F4950414516355F384A5649163F6B3E64834D915F71632DAB87383E
57334FA3B6523067475B416972394F6F3F46855F6B7063AA5E426D67476E71646A5C4F54
59756F4C9B6592433288592C2C8052337B7536A5856E4F7042374058494189478971425F
5456B587585A7CA4413D74A5A6525490597DD4AC69989A6E91733435854477632E895531
7B7B625BA35056945E5353396EA48468326C6C6449B59A94622E564860915F306380513B
458B5A3F557B724150893B698D642E6268425C5759A968643A5F78581B3C4A152380875E
357F6F3231606C2C5E5F3F25777461771E397442369F6B58222C5D5F241FA598
8D56525B428C3E4B8F444E5E4C22465427362252532656443D6A313359393D4937192C17
2B585421406F4D2772343F19595E546032223E55368A3E605D763E316276293A734F572E
4C1F2E7A4E1D75572C3B2F2E3C2D345E33505E5A16537345779E708F756A461C695A3545
634149B5C0733C723383516969357A6B4046884F886A5CC85958826C44726B6B8C5E4551
519B773BA541595238868C22339B7A3A917740A5976C60915A3A5B8462358B3E95834B5A
4F39A6AA825C97C85E35377F785782AA5B48B675467260434653364A554C8B79318F4B25
5D5B5C65A57227705078903F3D9846612E727E83406C4F8E5A557C443F5D39439192713E
477A2136446B71404C8A195897893B7370307F8561AC91452A4262611D3C463622528250
306D7346446378363E534D2D8D8C588137458B4C38A5836227315C602A2BA097
A782523D4A813E3D5D49738373243F4F4968455352306453425C2B4C62443A4624294C22
2B5851253D6C552D712C361B5D6D505F53454969309A445F516B453365772F3E77515744
71322F8B631D8781384E4644623935612E536F52155B523270926B9173746E247D65384B
613D2E928C552B4E2352357074293F5C435A953C717965D3513658615F96644C5D42535E
4D755349937369452F978447267B5D3685822C84723D5D875A3C495256508C2B7A985186
7D4F9AB7444599B1854D3574895058817A38C496747E7475453D2F836A3B5F4235A06630
655A2448856724723A465F4943AA4770384F62723F7F51A54A28635F576A652F6B987341
416C392E3F6A773F507B3D4E776E295F5F30684A46AB83662F41566622375230264D724A
337C604B495964433A796756A8875D9D5549854544A19668262F5E4512306F8E
755F56553B60455D66402D5467294A391D4D376222236768435B171B453D354924133130
2B601B1D446C533190254C223C2D547D5837583C2D87466267503443766B3C656A313837
702E3293351D767C40704E4643333F7023437D6020687A3B6A8E54A6AA99702094663370
7F3F43C6A96A2E6C3C502D40713B4752314C705B704262BB674657394D596D51593B395C
59735A47836A603224816E28267970337F83398C9C6B537263474A4E46317E4E83743358
6F599999615587A29364397D99545B856C49C7AA71937C73463E2E477B4261433185552C
655946688863276E4C5E6B403EBD5C683966718945866F8D6B37646F556578346D9A8445
4082623343797A404E8346628A7131526C467A4C51BA8E603A445869244B6E3B2542692B
3B72834F4D595E1F5EBA7345AC43539954478A3A3BAC9774282D5B6D371C598F
725F494F3957273A6B4C405C5A3887682C4133604C204E4252723933391E2F4F38183725
33554B202C4C17265D1D23204E49454E25407458236125537161352C9B372544684A4E30
50224787621680332C626C49401F3B7F44437754195977496E8943524467661D69592E42
4C4044B9B15D2F5C2E4F3C54773744644E4F865D5B8385CC69444C67515B7D4E5B39474E
54655F5795715B402B84773E25828648A67D4086A9695172533D4B57593391517B725154
4F4A9292504F7F7C8E4C60929A565F864D43B6A16380734C526D3440804D8168437C6B3C
7C625F659B5B3C855E65773160989A8A436A70763483929C6635594B476D663C69917942
488F5E304177724972995D598E5C42858A498563379491652E43563028466A61233E6D4C
2B68924652897528338555269B79449323689D5E43AEAD332A47727D3A23608D
668B5264397F48416D4344542D21565C2D2026705A275A42356D31203A29233A2D15373E
1F6163292D565827612422174B5C5159312D3549207449584D604C2F9C61314077624832
452D2686711E605D3C5230423C43337F3B405E77286A7843728C777E545D412B80733656
57312D9FBF57366528513B5282404F7B56578B68768A77BC694B6974645B74597042566F
65897866A573826B3C836F393D95943D90724388A364486A413B7E9F5C2B794AAB875752
5238809F804E866B845837679D5C60868348C2986B6E78752B401E275533616C316E6522
677E796293562D734E4E7B4737994662496F778353684C7B632B543E418D5F3563843549
73894F2F456B41314A70465F924B225C72357F5D469D7A543E5F7D671F3B5B342A717D54
3B9584262C5D7D493B82471F5F774C8B413994413FC2985F1F224C743A256496
658C546E3B874F42793B536A7E37525E31445F95602F5C643D71331D4555363E1D143E63
2C6372353567652B5E252E1D516B42583C484B5C2A88625D4F584F3EA8512F3E78614442
573729987D215F6D3C594538462F3C74313A65561B74724B80A172604F585E2563482453
5D261C6D967A446D245B57447833646946538635747C617C4E415D62514F6C445351595F
47766E458D3D4E593C827A24226E7A3771703B6C7D4C375A52293C554A235E2D5A714B52
745774727466908A9A764268935A80A99B4FC0BC509FBE753944171B58445D472745562B
5E496B66AF6D35794C6AA55639C8507A5684ACAD6A856F965825767651653D3088946340
4D79224C6F977C494E7D2A5EB275486B753B937250BDAA561D39565523445D2719396412
1D548B563E66885440B17129526841A7633C9D3A2D949F6625275F63172E8E94
848E53503C6E42404F316F83733B4B5A3E5A4F6B4D2B5D5A3A6939376757403E331E5E5E
28595A364F7E692A62374B265766458857594B4D2161494D64473022704E2F3262343455
582F2B8C45256B702C5A42436C3A3C7320497759255D57256694775A586A72298055306F
76514983AD7333753C4D4C387A3F4B4F525094664C825D7E63585B60505D7C70784F646D
63815B3E887256362872763E2F7A703F9A8A47739C44538050424C6E52317C5483726175
836C7B92683A86A68C5F456586353F6B4C46C7CD5F55725E454A2E635B405F5A3C766F35
7260253A916C348E3C3575634AC1A5B0493F5E7B3B8CBAB65E1F4A6F5B962B1C4569374B
7C8B35223860554C808D2D305A574979862571613CB6C4833B3D52472054806B23487C43
2C5D865447676D1332B77D264C36288E4D67C261329B9C4C3E436869282D6986
615954503257314F87464A4B5E2C492B2D5934642C1F746637782E2B5052394B55183A49
2952291836635C236E1B3D1B4E332955464E476C3C84535B6F6860377B603E3D7F5F4642
3B1D237B51215052306D433F43383C7A354271561E619A4C749D3F3A374C37299E801E33
54544492BC7326703C4C2F2E7946515327476B634F403D73595A643A455C696580265968
5B7F54327A476C552D67811A288E7A2E67783578B354274B57306DAD5232505E8D813155
655568905A5C7CB57B515D9AB3603F6D473A8B9F706085503665252247427B822A46521F
716B5A6FA549329263446E193B994C6F5E4A85812E343C7A8D375243399468314E812F2C
496F4B25456B2C1D78905D4C9A551F738043836B277E9C7739516938143154251550A690
366853163F9F8F3D2B8A622B6768548F1755B1703A9F9C1318468E833C22557A
695E4A593C793B2D67415E673D3069603B3A256642214E3F3C7E47446C2B2E535D24412D
274748233E6D342D682B3B1D69643B6A363F6C662D7022435B5043416C37254F72563D4B
4B19397E5D296529226157454F1A38873C3C7E5B154A734D8BB991542F4A171D73763C50
6F3335A7C08D466F296A593784346E735941695572795C6D454882725157603D95617B6D
40908052AB20496C47719018257B893D7B7C1A55A96D3E7171193A686D264F42C4A26952
624058BB886E88B97217417CA366469A963E979D6676AD72255434304F3282994F49541F
616E716FC85625816D5894403CB557804276928142906B8E5F3753493B6A3D2C527E6543
507032264965674547765B53BC622B5C7C3C7C725BBD99642365AB7E1C3B5E1F18346C55
3063703F2A465E4F2DA339227F6A73953231A53F3298823A1820446E3E2A6A89
7694523E3B6D42405A3594B06F2E3856344F2B553E265B5630592E4E895325435319595B
2A43552748714020501D27123545367D472F3957297659564F555048A54F382B6F623A47
5B3721786F32675C33614B4B65273B8D2D34886B3357761B5999817F8F7163286E44274F
6E29265A79924778124C623B6E1343775E427715579B727B4530466E4C5F572B5B6E9384
33596A5CB2704A514A8C91211A5876458F9B4969B33046697B44445A4A4F78287D8F7051
8C1835858E8290D095503A608B4871A1AA369BA7594159612D5C3C57652B4C7D4C7B8235
6D673C6BB88833854354786B41B960815A41545C489367C33E3B9674597E5832537E613E
5570394589A6824D4A8B245A96805D666D1B74A664BB965B1C425B651D3B643E253D712F
26817A5441646C2734B8531E7A5368BD513BA94C287B8B4B23294D6737296383
648252563C6E3F4763263E56673340321F5D3B6B221458733C721A265F74353F4A124054
3C481B114B8374296918471F483A3E95753B48490D7A6A546A491A1F68743B30612A396F
6F3F278565338478366E573C7B4F4794142B6B7B464B962D57A269484D5E5A20694A2E8B
A04255B3B16A3C90454A463A99543C563660936053505BAC705A5C5B74B984566232578E
5F5E42387770563D1C7C9C4E2C6F712184963B66904E2C4A48444B62361D554B8E855C7B
9A714D7A8F3D73C8996D375D8654306F9633859A755970803551254B81404E6B21567A31
6958414D8168337E524D6A6238A77179835B717467A665AB67295578558243398DA57945
5573291F43696F4A4B7F57478A8864706924545B3FA281483F56625A1F51775E26478163
2A698A5139566841259C621F794065BB4238AA4E277392381E26476F48266790
6167566E4066263F7D47566C71435A68284A3B594E294166376C41276B773A4B64214056
4846491D2E6767297B0F47224D2F2654542F4768316F555072686756575C44457132222E
624F298649116B652E7B61394D2F64A14D316E7025488E5463A583944C4D71286951193A
605B5DADB3721E794F3F2C1D69453D5835316272485F3543544F59432B4B664E5E46566B
5959705767625E341B48713F2B6F802F6F96404A9E6C34566C4C476B5A2C6556A4732950
89754C8D914B4EBC956E36639F64397C89348EB36F5B72863B52352957374F7548465326
5C4D4C7EAE5B347F4C5185493D977F7F85677264499AA69A753C5856477D562E56876D49
568A57294B63534F7095726270827581894A58795BB7B47A3F637D5A1D3B5F6B2D5B9D7B
316F8A4C357E874C309F5527886472CF2E58BA7C2E54A62F2235657138225180
6445475E3E783E3C88435458282877793A4B3F7771364A5A3D974927574233616B253820
2E665E2E3D7A2A1E86373D23696F357342367D8740662F395B85634C693C175079603F47
6E2F3D767233831B0A56714D5125297250376F6E223198535BA183937547482D7C61194B
68383BBAB93823652E4A3A2F854C40613D418174448A6367665451754E69775052425185
52606E618E6F65493A5991402F7892447CA54455A97B406F893F579E74386D5D80687456
58644E98977763D1A159518799576FB698377AAA536CA08B3F5E3838553654875F51632C
6D715A8AC55C33885352AA57398975816176A87E33775E8A5A447D48439C7C4B82A1533E
5F6E2744737F67595D766F5A726D3C8C965B628E5E9F9C691E4F6D5F1E3B552021556865
33664E1821596E57309E3919666D47CD4B319D8325478A5A2B1F386533284E88
6166474F3F8747437A325E8358273C51232C19424D26482E165C321C3F492330511C301B
1F3B552F35664E21562130135361337D1C13385C3A5F2C4F50735B4886673C2458483B4B
67221F72793677562D7C6A3E4E48399A4D2E686E3F3DA64D62B58B85AB5F5A266F402284
9A3C3EA0C43B3081376147379155576A5049977C4E986773714D6F8650707D4E61575CA3
51785C51A67953553E76B4562D7B743F8CA333509C3E2D4B5843476F4A42845882837379
88644AAB9E3D66CAA57336589B4E356EA04178915F404F682C4C3263782F54783C62743A
666A162C987A368E5334735B39857D806A4B68734B9476C248225D784F85301E4D7A6739
4F5E232643475B505D6F2A36796B4F8B841A47773C967D59384A6064203D5E5E2E567B59
2A634B3B32738B722FB5752A75814ED08B4795861E5790693029416A4F29528D
617C4E563F793E519547425271444B6D2A4847564B2A44543156311D3970414D521E4537
2A45552D466A562471243F2E7172389B5E27456C39564970827144396359433C6A392545
4F314E9F7029775E308967396F504CAE4B3B8778424DAF3740AE695984635C21804F1135
69554DA7B34D22674F49381E725047542D488E6D4B5C3F796556574F30607D5354363494
6259462D6464633F1F3C7A33266B803759993C5B7F6F3A58A0614C6C462D65618C6F3E4E
755746A2866A73C9A46C3D6AB16740728B4098CB6C586D902E4732304E3750873847472D
68573F6AB2612A81535691543D838871877C7D814FA682A16E3E61514C87663F609D753F
4A60412F4E4766575762794C7A88418885324C45259D753F3C4C5C622052786737586456
2785764F3D697D2B27AB742B784B2CAA805BBC8B2B388D493F647A6525317E8D
5F4F494C3C72373B844457582A377E6F2549335D52245949337A3E213E362D6061204122
2165511E2F62301A74212E2969312D9B392C605F30511E4E6E7656465D57202F57512C37
441222595F257030174F4D334A272681513B796C19307C4240AC7A63BA585E288F902F4C
895340C0C45134734C454C34866E485C504394875C81585F595B5880446568514D4C529D
605965457C5571453A47883121608A4A719C3C53AB873E509B5D497A563C827B91687B67
5E424EAE81838ABAA3565B8BAB703F7995406A936154659334453D3A6938529560535C34
6366549AA95A316A42558F433576848B8D746A6E46B7C79576466048438F5D3B5C906D4A
69874E36554A5B5B887B8C585B8858828F425B5238A3BB614749593D19687F69355A5D37
215B5B393A816C5826B0702F686933823A3992773745915C1F1A415535184883
5E864A583E915547955955506D4240623136212E402744391E62421C334F2946431B3536
2348643138665E1E5D173D33564C40B95132354F463C20766A6B524B5A704A24655F333A
4D3842948428734A2C5B39344D3F2B96473B70523435AD533AAD8C4858A1401D7748274F
9654177BAB5634793E64542C795C506552439E85598C5C575F54558A516D7255534B749E
627E754AA14D8A744644A0301F5D8F4A7D9A345EA6803E5A845D52904F33847B8A6C786C
545B5CBFAC8672B89C523861AD7641849B5381AE6C4F8CAC43523B37613653905D4A5329
63717599B97143A66B4D8050335E787069816D6237786A7878446935479662375D7D2C2C
4E693637544545305B78825B64843475A7507180327F826A485966601E3657553B928F75
286F4219308B875F2CA55E24848D536076619C893A61AE612D203A64331D5189
64954D44407A484A8045909F8F5048783C3B464A3623495C376D2D16316C3C524418394B
344C5E373968642B5B174240564C49BE5E46475951371B83716850498C883F266255333C
5D4C4EA183268B69277554395151299D573A6B6C5733AC4745B5934A6F846430873E1D3F
784C1B4EB05A4C99334B5A30782B71856748B15A4B925E6464588790516F824E675F5F8D
4E676A538E57665D584BB72E3086964C67932571A37D3268763772916134824C87978264
60473D99857258A9A55E396BA54F5C9CA85D8ABF5E2755782D313C417044709656435A33
73835C84BE5B33896C4585503E728C74557C9F8F509F92997B4566383F7F60385985693F
53613D48774C7D49526C8B4C6E80375A8C346E4C2A958447356D8A6F2038502B1E405E53
2F94634F2159624E3CBD671663395180816EC0A0334294633A27405A25267891
748750533D8B4D49904A45506D484373403E4B4E3C294D6034682F17315D404C4B1D5453
2E4C401C52775525581F4E51586444B16A414462565134777D692B264F7445467128254D
644854A46A209B792B88673E786A2CB3404B8D875A3DBF5035A77747B76A54288B401644
784C1D30983C44614B4E4F2B8A635055305198704B4B297278364F64408E94534F4975AD
79753D3A814E6C55285FA05A29587440858F2D72A276387D7167497C4135867B836C7960
5C5061B0A18158ABB58E467DA149365C794895CA773E5888334B37809A3A55854C6E7239
50752145C481429D4951B75442778D893767658E51BD91A96F489163568B623F80A87F42
5367253C7D918B5855718C46A38B4F61981C75795BA688553A4550532C6C895E24495A27
1F73826A1F6E6136297D62325156437F5E50D5A66A58AD393858705D411C427A
65544C54406B3D59A257566783433C402C6C474957357379376A44263F52334B54253C51
27626436335D52236C1B4C3B80543DB97F474A532A5237698E69473E4F85282E5C53332D
583D54AB6C1B875029776338443A2A9255366E852F2A845339A98D4ABA50462B916E1D41
7A843C3FA7739D9B445F682B6352667450368C7A508656576B436C7C3E5C75587944458F
589A72479E2E5472443DAA322B7169219CAA4277A140246A81655B90432D727DA47F4F69
9A6E68A6926B5BC4C1776598B7723759824070A06F404A9446685435774B6E96366C863A
55654250A36943AB39305E5F44728F78487B5D7649B691865F355045489B5B304F8B704B
706B3A2A3F515E4D96B13E21938F527399305A553C93C36545484936173E5C5826507F69
34908A6E1E7D6E733A93531F5662458B3640ADA45F67A95C2F2053753E1D4C98
69714750419047437C475A583C42808D3E46375D6C2A485123897926342E092257394037
0A2864353877351351274244812D228B5D41735F4C57224C6440343E4D803D296A5F3239
522D347C6C1E9453274D36404A5321945235688A58339E603DA79F4EAE7232238F872E47
83501E4B7196A1C02F385D2F6820497564388337277E595650346988517270294D62528A
38786E53834E57574B40C0323281873966893483B672216E642E639C822E65409EB7533D
838564A9BB8444AE9F404568AC593C55924D86C184403D8533413C2E633281984B5C6724
6D85687B984D61C15146744D3267A48F56845B783D9FB3AA773861404EA0803A4C833B39
5269472F4E6D4B2D57756F3A9C632E5774505F7F3C749968494E617126375043316B6F58
33737830257D714D328B63324D6A54B05A458D98357DB25E2C22427643306595
7C9A4C424277484A6B307C9874302E54385B212F5F3350591151532E4D5E28203F194A64
203556273F80641F5E1F42484D4B379469373F3E43653966654D363C5F813628655C1321
653E338271217B7133525445605F23985D45959E692B83373D848A49914D3621804F1D42
7C752356519ECD9A46485E316059455E60386D7559975D5C4F2E4771516E6A4C5A5A5C9C
6570724B8B6A70563E48BA2A236A7134557C1E69896A1C506D54466864376F406576815F
7D533273879358ADA15C4D65B06049719C5289AA824B7F8F4255542855375C844A556B26
44796975B24E3AA77B44754C22359EA35498AB913974638486487C8072977C4655967646
546E4D3A7084864D737B3746B48A4A6A885D7577568FA65E3563846F253B484520477067
2F6C87661B6D57433DAA8238693F20655D349096435E9E4F2F2940651E155483
608B4C3B376B48456B1E2E496A3D32300F50413B451475843C622F14345C331F410C265A
283448041B55632677114547461F147985494E3F0F49515B5E5817155C7E412361472338
683137804B1A706B365660286D64228035305C825322965F2F958A5A8A69462D9848224F
8274354641B6885F3A505A29615C4E605F3D899163A5615166496888495574647269509A
7A7F6F337F597151384BC022266C7B3157903C8A94651F647C6B476C5A38696DB4787D5A
83746BA1976557AC976B475F9B3B558D904782B861204D7F4B6855285C486D93584F723A
486C2F59AF663CAB4F527F68414FB99531596F764FBA86A75E246A887499563372A47344
5865171F3576804D6D775D4494683E60721E50715087BC903150606E2B566F6229488566
37A89F75206C571A1E6063396D6A2F8A633FB5A07A86BD77352B42784C2C4C90
619A4D5B4191494DA151525284433554253C413A4810426E39604119294C351E392B3264
3E2B4C2A225B5F257819462D554D3A7A77484E4A445553434B584C213075432A6A452A35
4F2E35776D34595F38584135566224825A498786352196643498943284854D2C8F412146
716D345536B43D654F4E4E21775D4A623B3E858C5B8E5079744A6883486A8E65785C60A0
6C795231907F665A2061BD5B39677C368CA140879C4C3370776248664B44657395826D57
A779609B817A48B5A263476DB4483A66863689CB743D5F8C4D5631438947668C34468D42
447A244FB55631964F4D7E5B484FC087506D667347B797A06E3A5C706E936D304988683F
48654A2E477D7B4671745C61A28A576E7D4F5D6E3D82D79D525566421F61825C264E6A32
1C73876F276C4F74347468459D8E388B4A2981A765A8C56939324B6F522B519C
686F4E5441662545744A5A4E674B557D3D434B395A304B813553402735552E355636365A
2B3B513D247168237C2F48275463417B6E456E3E335E55436A77722B377F1E317064424A
5E2C4D90724B5160397D53465B432E74613B899D42297D502994A8366E68552F87601725
556E523B5F852F5840484E21604838634C295769426A1C4D6647675F3A65824C6B504A8B
617C653D7D53625D453FAA4E2F616C246B8C3E808F4A40846D5F4A6A4E254B536D995052
9F88779F927254B59A3D4182B97D41659143609F8459848E3C6E3A355A41679B44448730
517C5B67BB4E34A155415E4C5683D598678F54672C879093803C6B5C66B8874E52A05849
6194733248903A3189905F5DB6412D5E7A624E832767B37A447BB17A232E56622348676F
2F82645664AE947737774C2EAD803B98642971A456B7C75A3553717C4B314F94
6160454F40813F3E7A48594D3916355F36392C526B3A4F7131796232344C0E123D3C3141
0A24523A266D3A0E62382E144F7238724B1E434A3F5A3422345F6A2D357C371B564F4854
5114467365573F592F4D4A3D6F4322734539A4AF551FA8363FB19B5C6169281B798F4535
5865254EA96D45602648682F6C3B406D6B36617A5199515B534180813D456C2665765D93
3C938C4A9F394F81624FCB503E8D95375F854084BC692D6B623E62B282375F4A7BA6634E
A271478EA08F5FC9AA484063AA5581A0A0486FBA6733909940433F215C447D9459549120
476D607AC04D2385756AA35B3A9FD6AF53915889449564916F3E695B405C804F5BA54536
3E786E2F498864385D745A50A9743F62665B5E845787B69542445B692739572A2E5B6D6E
338E5F3A214650613987745DB7533DAA844775B82F93BA8E382E4670384587A4
659D4C474380474477356A717A3C2B6238401F23613651631957442E4B6A44173D2D3C6F
3F35563737725527712B42354B60317B6944492E1E80523E4958362A54975B25551D336C
7B322D884D35497F4B655C2262662589201A608F5E2DC5431D778A5B53641D1470462B31
486D1A2376694B6D2A3B794A94382E5D794275511F8B5E683D1C568D44506B183B7C5CA5
38545E469A614E5B3C7ECF42205B80355C852839955F4D928B3A3A585D49884F487A8951
9E714786796C42AF93494A64A7433D5C823F83BE814C629945563F4F844B55833D599041
477E25409059297E3E3C61603A3EC89566B8AE7143AE7FB05B45A471647A825C95B38E4D
5577553F63948846646A3369AF8440605D2036562C91C0795F526D7A293E6559234A7230
24938F58297C8B2E29A18B57BE3E2167362E65B85E89CB6137698E741F1B4B93
5A8753423452404F5817374E804C343C1767553E69317C854672351C3E6F601F392A1F57
413A3E0E1455722975124B594A13107C7D4B6B4A0E58634275773B17296A4152842A233C
5E2F40853D26266B4A6B54296B6E30944F2A5D8A2223945A2495B65F7A9335258A3E2953
69874B2774593B78523549246D68325F3D335A6D4D893D81754A6479507C84585B534395
646A5937914F5A592F45A049346C7741979A3F48B54A2D738A6C475C5D304B4B826C6D4A
AD956596887756B7C04C4760A84F4A6F844689D0A067729F5B6D3D2A684A558338528B47
4C714A6FBC58328B474D614C4A50C972406059613FB18C924828625B57723F3166996B47
536A3321527F8D6466714059A873325A573D3D592F8DC997615A634A285F7F5B3486A243
1B507F313A94A64B1D633C2D7C77368D6A3F666B4581CF64362A3E67392C5995
5A5842453848365D76363A43664C6752133F423F3A0862804080431837665A47553A2E54
37615942264F571F762C4B4762461A63382D4944295037284B4F5C382F71211F57514657
5B33769D695931603FA5773A76402996663060726121BC602788944645734D228A3C192F
416C612C80432A6B3F3E4A307C602F54542D5B886189515859445E7C3E466E65554B56A4
6972694B966C6368545FC74931698333668F4052A76B3277926E47645D3D6F41606C764E
8288669D908771AEAE58546DB96E5B81732D64AA9E5174932F6D57347F5D5D895169A659
8B886D8CD0622476755471483561CB8C5C846D5F40BABC9B5E3F67495C77534D68A16642
6C785A2F788E3943A09A5465C47638748658448E3B6FD4AC5B6E865819314E2021567E7A
2F5A864F20606B6C2D7C5A2B4C6734887B498958347AAC4E423E58833D266495
62974D563C72434583424E503928436530373C72743056492F6E5024533F201A372F2E4E
1E2B4A35325E3B12553D39264E531B6C4E375035224E44407E747D42327E45256A5D505C
6829365D575741482757663D7F6E339B6A3060756622BE67298A725B3F8B361F864E4939
39845F317C5843732C3E47327C5D355355366F9C6A85686C6645588C505B6F705A6057A7
6D727B4D854A548A645DC6403A8C88397E854770B4753060862F5DAE8B40734B5F5F995B
81865E9F838E749BAE535C8EB87C8AB3A85C7FC583578CAD3B4E4C33754B899D5274862A
5F9A7D7FBC833982624B7F794F40A67D5A9E615F297D7D8C8F456B3B2E687B5081B2372C
4F734D3E878D5A364F713D71D05D134B675B5DA3396BAF5632708878253B5D4A2787A36C
3D5C8C50287392843F7E703B4F7A339A794897674985976F48476A8B3E2C6699
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.003125 0 0.003125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of gray image
p
0 0 translate
1 .5 scale
320 string
320 160 8 [320 0 0 160 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 74.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000BR000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`004oooool0C@22PX80Jf][
08^;R`1EEED0L71`05=CD`1GEeL0M7Ad05]KF`1ADE40TI6A04a<C01cLg<0RHV905ADE01ZJVX0MWIf
0492@P1UIFD0H61P04m?C`1/K6`0GUiN05QHF01cLg<0DE5A075aL@1?Cdl0CTi>05YJFP1ZJVX0B4Q8
05eMG@1SHf<0B4Q807MgM`1mOGd0=CDe07EeM@1WIfL0@T9206QXJ01/K6`0ATI605YJFP1kNg/0EEEE
06ATI01PH600LW9b05IFEP1BDU80LG5a05]KF`1GEeL0Ti>C05MGE`1CDe<0VIVI05IFEP1SHf<0OWin
04e=C@1WIfL0S8b<05MGE`1dM7@0RXZ:05iNGP1MGEd0T92@05EEE@1^KVh0SHf=05MGE`1lO7`0QhN7
0080IfMW00/0R8R8059BDP1eMGD0U9BD05]KF`24Q8@0O7al05UIF@1_Kfl0G5aL06MWI`0205iNGP08
07YjNP27QhL0HF5Q0861P@25QHD0JFUY08F5Q@1dM7@207inOP0U065QH@2PX:00MWIf06IVIP1JFUX0
LG5a07UiN@1OGel0H61P09ZJVP1hN7P0R8R808f=S@1cLg<0IfMW079bLP1cLg<0EeMG07MgM`1cLg<0
Hf=S0:NWY`1]KFd0KVi^0:>SX`1ADE40FEUI09NGU`1IFET0KFe]08b<S018B4P0Jf][09fMW@16ATH0
HV9R07YjNP0>ooooo`0605EEE@2l_;`0MgMg079bLP1[Jf/0H61P0P1^KVh0:P26QXH0IFEU04];B`18
B4P0DU9B04Y:BP1ADE40GUiN04M7A`1<C4`0F5QH04U9B@0g=cL0FEUI059BDP1@D500EUIF04A4A01:
BTX0HF5Q06QXJ019BDT0EUIF04a<C01@D500Kfm_07emO@1ZJVX0Ng]k06MWI`1nOWh0M7Ad09:BTP1j
NWX0G5aL06m_K`1EEED0IVIV05MGE`1/K6`0B4Q806ATI080IfMW03L0Kfm_069RHP1iNGT0Jf][08B4
Q021PH40UIFE07moO`1`L700KFe]05mOG`1iNGT0RHV908f=S@1JFUX0LG5a06IVIP1BDU80FEUI04m?
C`1JFUX0ADE507MgM`1;Bd/0EUIF04i>CP1HF5P0Bd];06=SH`1BDU80F5QH06EUI@1FEUH0EEEE05aL
G01SHf<0EUIF05=CD`1PH600GUiN05IFEP1IFET0HF5Q07YjNP1fMWH0CDe=06EUI@1RHV80OWin07Ui
N@1IFET0HV9R06UYJ@18B4P0H61P0080IfMW01l0EEEE06IVIP1]KFd0^[Zj08F5Q@2@T900Vi^K08j>
SP1^KVh0VIVI06m_K`29RHT0JVYZ06QXJ022PX80NGUi07MgM`1jNWX0Rh^;08R8R023Ph<0GemO07al
O01nOWh0F5QH06m_K`23Ph<0MgMg05QHF025QHD0YJFU00kooooo0440XJ6Q07alO01>CTh0AdM7055A
D@1PH600@41003Hf=P0S8b<0FUYJ04=3@`0S8b<0EEEE07AdM00[:b/0?clo03hn?P12@T80B4Q804E5
A@0m?Cd0?Shn04];B`1BDU80ADE505=CD`17AdL0@41006YZJP18B4P0?3`l05IFEP0i>CT0C4a<03Ti
>@1ADE40@4100492@P1jNWX0LG5a04a<C01IFET0?Shn04M7A`1gMgL0PH6105YJFP1GEeL0Fe]K03@d
=01?Cdl0KVi^05ADE01EEED0D51@04a<C01RHV80HF5Q06EUI@1RHV80B4Q805MGE`1YJFT0Ogmo051@
D00205mOG`0U05UIF@1RHV80LW9b04i>CP1KFe/0NGUi06QXJ00n?Sh0MWIf06EUI@1FEUH0MWIf04i>
CP1lO7`0BTY:06i^KP2^[Zh0MWIf065QH@1SHf<0G5aL04m?C`1RHV80BDU906IVIP20P800@D5109bL
W01CDe<0@T92079bLP0i>CT0J6QX065QH@1jNWX0CTi>06YZJP0205YJFP0?07EeM@1RHV80?clo06AT
I01CDe<0HF5Q09JFUP1GEeL0BTY:05ADE01UIFD0GUiN07=cL`0h>3P0I6AT0080NGUi0140GEeM06IV
IP1jNWX0@T9206=SH`1UIFD0<S8b05IFEP1`L700BTY:08>3P`0o?cl0QhN7079bLP1kNg/0EEEE06MW
I`0>ooooo`0N06UYJ@0/;2`07QhN020P801mOGd092@T024Q8@0[:b/0>c/k069RHP2;Rh/0;Bd]04U9
B@0m?Cd0D51@03Ti>@0f=SH0FEUI09:BTP1BDU809BDU02/[:`0X:2P0<S8b028R8P16ATH0QXJ607Mg
M`0];Bd0;2`/0P0F5QH03P0G5aL0NGUi08^;R`2RXZ80LW9b0492@P1>CTh0GUiN04e=C@0g=cL0QXJ6
069RHP0m?Cd0IVIV0P0R8R80900X:2P0DE5A09^KV`2LW9`0NWYj04i>CP24Q8@0FUYJ06i^KP2XZ:P0
J6QX02DU9@0_;bl0?Shn05QHF01ADE40MWIf09>CT`2][Jd0MWIf07YjNP1_Kfl0a/K60;Rh^02JVYX0
J6QX04i>CP0^;Rh0<S8b04I6AP1EEED0Y:BT08V9R@2RXZ80H61P02l_;`80OGem03H0IVIV08R8R02[
Zj/0K6a/06ATI02/[:`0VIVI0;2`/01jNWX0_[jn08^;R`2k^k/0Lg=c08F5Q@31`L40XZ:R0=3@d01V
IVH0ATI607alO01]KFd0DU9B07UiN@2h^;P0c/k>08Z:RP1OGel0Fe]K06a/K01PH600EEEE069RHP1Q
HF40EeMG08J6QP2:RXX0U9BD05eMG@23Ph<0BTY:02TY:@17AdL0FUYJ09VIV@1iNGT0<30`05YJFP2T
Y:@0RXZ:08R8R02OWil0GemO03Xj>P0i>CTDooooo`004oooool0DP21PH40N7Qh08N7Q`1VIVH0KFe]
04Y:BP1YJFT0FUYJ05eMG@1HF5P0MGEe06=SH`1dM7@0P82008J6QP1RHV80MgMg05YJFP1KFe/0H61P
069RHP1LG5`0HV9R06a/K01HF5P0Fe]K07AdM015ADD0DU9B05QHF01=CDd0EeMG05YJFP1TI6@0D51@
059BDP1WIfL0?clo07=cL`1QHF40BDU906][J`1]KFd0D51@05]KF`1]KFd0B4Q806EUI@1[Jf/0J6QX
05aLG01TI6@0J6QX05QHF01RHV80M7Ad05QHF01[Jf/0OGem05ADE01eMGD0KFe]05MGE`1ZJVX0Jf][
06IVIP1UIFD0LW9b075aL@1QHF40RHV906a/K01MGEd0Ph>306MWI`1TI6@0RHV908B4Q01cLg<0RXZ:
07EeM@1iNGT208V9R@0Q06a/K02;Rh/0SXj>06m_K`1PH600UYJF05QHF01_Kfl0N7Qh06EUI@24Q8@0
R8R808J6QP1kNg/0H61P0861P@1aLG40LW9b07AdM027QhL0NWYj07EeM@1VIVH0MGEe08:2PP1EEED0
K6a/08n?S`15ADD0TI6A07YjNP1UIFD0R8R80080O7al01@0IVIV07MgM`2;Rh/0IFEU08b<S01aLG40
Kfm_08^;R`1hN7P0Bd];07QhN01_Kfl0Hf=S07IfMP1[Jf/0HV9R06][J`1QHF40GEeM061PH0kooooo
01d0EUIF0:ZZZP23Ph<0KVi^061PH01XJ6P0KFe]06YZJP20P800HV9R0451@@16ATH0CDe=03De=@17
AdL0EEEE05mOG`1DE5@0GemO04a<C00e=CD0FUYJ055AD@1IFET0IFEU04Q8B01IFET0IfMW06m_K`02
05YJFP0`051@D01;Bd/0MGEe07EeM@1ZJVX0OWin05QHF022PX80Ng]k08B4Q01YJFT0D51@05IFEP1;
Bd/0EeMG05=CD`1OGel0@T9204m?C`1JFUX0E5AD05YJFP1MGEd0Lg=c05IFEP1RHV80J6QX071`L01]
KFd0F5QH05EEE@1QHF40Lg=c07IfMP29RHT0DE5A06e]K@1NGUh0GEeM069RHP1eMGD0GUiN05YJFP2F
UYH0HF5Q05UIF@1?Cdl0Hf=S0P1bLW8205iNGP0C075aL@1HF5P0ATI606QXJ01hN7P0IFEU059BDP1@
D500Fe]K05iNGP1FEUH0NWYj07IfMP1aLG40HV9R06YZJP1jNWX0MWIf08j>SP0206EUI@0C079bLP1D
E5@0JVYZ079bLP1fMWH0GemO06][J`1bLW80UIFE07emO@1lO7`0UIFE079bLP1RHV80NGUi07alO01g
MgL0G5aL06QXJ00207inOP0?07YjNP2KVi/0Ph>3096AT@1_Kfl0I6AT08N7Q`1dM7@0KFe]06i^KP1c
Lg<0MGEe05QHF028R8P0WYjN00kooooo01h0RXZ:06=SH`1SHf<0Cdm?05=CD`14A4@0ATI602HV9P0W
9bL0DU9B03Xj>P0i>CT0B4Q806QXJ00k>c/0;bl_04I6AP0[:b/0K6a/03hn?P0o?cl0C4a<04e=C@16
ATH0<S8b075aL@1;Bd/0@T9206QXJ016ATH204e=C@1/04A4A01GEeL0>CTi06ATI01:BTX0>3Ph07Mg
M`1DE5@0EeMG04A4A00j>SX0ATI6065QH@1mOGd0Jf][051@D01IFET0?clo04=3@`1dM7@0De=C04U9
B@1MGEd0AdM704m?C`1LG5`0De=C06ATI01LG5`0@D51065QH@1^KVh0F5QH07UiN@1KFe/0FUYJ07al
O020P800E5AD06m_K`1`L700HF5Q06UYJ@25QHD0L71`06m_K`29RHT0HF5Q06UYJ@1DE5@0NWYj0:b/
[01YJFT0K6a/069RHP1aLG40JVYZ05aLG01CDe<0Bd];07IfMP1>CTh0TY:B05=CD`15ADD0Lg=c03lo
?`1MGEd0EEEE06a/K019BDT0LG5a061PH01GEeL0NGUi05IFEP11@D40MGEe05YJFP1QHF40R8R8065Q
H@1BDU80CTi>05]KF`1HF5P0I6AT03De=@1aLG40JVYZ07EeM@1EEED0Kfm_0861P@0e=CD0IVIV06i^
KP0g=cL0H61P06MWI`1EEED0QhN703Hf=P1_Kfl0Fe]K07inOP1>CTh0Bd];3_ooool02P1iNGT0BDU9
04=3@`1PH600XJ6Q06UYJ@0M7Ad06ATI02DU9@1FEUH209RHV00B09jNWP1YJFT0?clo02<S8`0Q8B40
:b/[04=3@`24Q8@0AdM702/[:`0];Bd0ATI60410@01LG5`0YZJV08j>SP1WIfL0A4A40P0[:b/0>P0k
>c/0B4Q808b<S02CTi<0NWYj04m?C`0c<c<08R8R01hN7P0`<300IFEU06m_K`1nOWh0SHf=065QH@17
AdL0D51@06YZJP2YZJT0[Zj^07]kN`1IFET0QHF507QhN01lO7`0ZZZZ09NGU`0`<30071`L01hN7P0^
;Rh0?Shn075aL@2LW9`0MgMg06e]K@1CDe<0RHV90:f][@2KVi/0Hf=S06e]K@12@T80?Cdm03Xj>P0n
?Sh0WYjN07IfMP2YZJT0O7al07EeM@2RXZ80T92@055AD@0e=CD0>c/k069RHP21PH4206i^KP0`06EU
I@1eMGD0OGem0;fm_@2WYjL0M7Ad03Ti>@1<C4`0/;2`0=gMg@2^[Zh0QhN705UIF@1GEeL0Fe]K08V9
R@2NWYh0Y:BT0:RXZ01^KVh0CTi>04=3@`1LG5`0>c/k03De=@1@D500Lg=c079bLP1jNWX0];Bd09VI
V@1OGel0NGUi08>3P`16ATH0MGEe0<30`03EeMD0][Jf08V9R@2IVIT0SXj>07EeM@21PH40CTi>07=c
L`10@400>3Ph5?ooool001?ooooo01l0Ogmo071`L01SHf<0M7Ad04E5A@1HF5P0HV9R03@d=01YJFT0
Bd];05ADE028R8P0>c/k06QXJ01`L700@T9206YZJP1IFET0CDe=075aL@1SHf<0DE5A08N7Q`1jNWX0
FEUI05=CD`1WIfL0AdM706MWI`18B4P0FEUI0080C4a<02h0GemO05IFEP1/K6`0RXZ:03/k>`1RHV80
WinO04a<C01GEeL0SXj>03/k>`1EEED0Vi^K04M7A`1JFUX0Fe]K051@D01IFET0IVIV05QHF01PH600
IfMW05QHF01DE5@0NWYj08^;R`1GEeL0L71`061PH01aLG40NGUi065QH@1hN7P0K6a/07UiN@26QXH0
DU9B06EUI@1eMGD0?Shn07=cL`1lO7`0<c<c07emO@2FUYH0AdM70P2;Rh/01`1XJ6P0WinO07AdM01Q
HF40VYZJ08F5Q@1JFUX00P1oOgl04@1FEUH0OWin07MgM`1SHf<0PH6107EeM@2;Rh/0M7Ad06UYJ@2C
Ti<0L71`08>3P`1VIVH0RXZ:08f=S@1WIfL0LW9b0080P82001h0KFe]06IVIP1jNWX0N7Qh08>3P`1U
IFD0QhN707UiN@1gMgL0UIFE04=3@`1VIVH0ZZZZ04a<C01fMWH0Rh^;04a<C02BTY80PX:203`l?02E
UID0O7al04I6AP2JVYX0Ng]k055AD@20P800N7Qh04A4A01VIVH>ooooo`1Z05QHF02MWId0N7Qh06a/
K01OGel0K6a/065QH@1aLG40Jf][06EUI@19BDT0CDe=04Q8B013@d<0Bd];059BDP1JFUX0HF5Q06a/
K01>CTh0<S8b065QH@1IFET0C4a<071`L018B4P0H61P06YZJP1UIFD0FUYJ06MWI`1<C4`0B4Q8069R
HP28R8P0MGEe09:BTP1[Jf/0HV9R07YjNP2CTi<0S8b<05aLG01]KFd0EEEE06ATI01DE5@0HF5Q03Ph
>01CDe<0HF5Q05UIF@1VIVH0EeMG05aLG01SHf<0IVIV05IFEP1CDe<0D51@05EEE@1?Cdl0H61P06m_
K`1lO7`0[Zj^03lo?`1ADE40BDU903dm?@1MGEd0DU9B05UIF@1@D500KVi^05YJFP1HF5P0CDe=03De
=@1PH600KFe]05]KF`1]KFd0Hf=S05ADE01HF5P0GEeM06m_K`1PH600HV9R06UYJ@1VIVH0Kfm_05=C
D`23Ph<0OWin09:BTP1RHV80T92@08:2PP25QHD0Lg=c051@D01SHf<0OWin069RHP80KFe]0200IfMW
05YJFP1NGUh0HV9R08J6QP1ZJVX0NGUi09jNWP1dM7@0MgMg07moO`1jNWX0Q8B406MWI`1fMWH0XJ6Q
07MgM`2:RXX0S8b<06][J`25QHD0TY:B08F5Q@2MWId0K6a/05ADE01YJFT0JVYZ05mOG`1LG5`0RHV9
08B4Q0kooooo05X0Ng]k07=cL`1JFUX0ADE50451@@0i>CT0=CDe03/k>`0Z:RX0?Cdm04E5A@0W9bL0
@d=307]kN`0c<c<0C4a<02/[:`0g=cL0MGEe04I6AP14A4@0?Shn061PH00n?Sh0E5AD06QXJ01@D500
GUiN04m?C`1ADE40Bd];0492@P0l?3`0CTi>03Lg=`1ZJVX0GemO03lo?`2?Shl0Jf][05YJFP11@D40
DU9B0410@01>CTh0QHF5079bLP1>CTh0DE5A0410@017AdL0J6QX05EEE@1?Cdl0Fe]K04m?C`1ADE40
JVYZ051@D01ZJVX0DU9B04m?C`1OGel0IFEU079bLP1dM7@0J6QX06=SH`28R8P0O7al06a/K01hN7P0
RHV9075aL@24Q8@0T92@08R8R02?Shl0QXJ605ADE01mOGd0KVi^06=SH`2:RXX0FUYJ07=cL`1kNg/0
DU9B05IFEP1/K6`204m?C`0;0861P@1:BTX0Ogmo05ADE010@400Q8B404Y:BP1SHf<0?Shn065QH@1>
CTh00P1QHF405P1FEUH0FUYJ06m_K`17AdL0LW9b055AD@1MGEd0V9RH04a<C01CDe<0Bd];0492@P1=
CDd0K6a/03@d=01TI6@0L71`07QhN01@D500MgMg08B4Q00n?Sh207=cL`0;02l_;`1WIfL0KFe]061P
H01nOWh0=3@d05EEE@1MGEd0KVi^069RHP17AdL03_ooool0S036a/H0NGUi06UYJ@1UIFD0>c/k06IV
IP1bLW80@D5103Hf=P0e=CD0S8b<05IFEP2PX:00@D5102l_;`0W9bL0820P024Q8@0O7al0=SHf08n?
S`2<S8`0K6a/071`L01HF5P0?Shn07emO@21PH40a<C40:>SX`1PH600D51@03dm?@0Q8B40De=C07Ui
N@1cLg<0>c/k04e=C@1CDe<0Cdm?08B4Q00o?cl0D51@07QhN02l_;`0C4a<04E5A@1XJ6P0C4a<079b
LP1mOGd0PX:205]KF`1>CTh0GemO04A4A01^KVh0J6QX071`L00Y:BT07QhN01lO7`16ATH0WYjN0:>S
X`2k^k/0XJ6Q08n?S`2FUYH0LW9b05aLG015ADD0KFe]07emO@1GEeL0H61P09NGU`1ZJVX0OWin08n?
S`1^KVh0=SHf08V9R@22PX80:BTY01lO7`0b<S80SHf=0::RXP2h^;P0Ph>306m_K`2=SHd0ZJVY0;Zj
^P2i^KT0Kfm_04Q8B01OGel0Z:RX0;^k^`1_Kfl0Jf][01hN7P0P820092@T08V9R@1BDU80O7al08R8
R00g=cL0HF5Q06UYJ@1KFe/0?3`l03dm?@1;Bd/0EeMG07UiN@2ZZZX0YJFU07UiN@2`/;00K6a/09VI
V@3De=@0alO70<71`@3GemL0T92@08b<S02[Zj/0N7Qh08V9R@2HV9P0CTi>08F5Q@2@T900WIfM5?oo
ool001?ooooo0540Shn?07EeM@1lO7`0CDe=069RHP0k>c/0FUYJ06e]K@13@d<0DU9B06][J`1=CDd0
S8b<08:2PP1JFUX0QHF506MWI`0f=SH0LW9b06IVIP0o?cl0Jf][04M7A`1LG5`0MgMg04Q8B01cLg<0
IfMW04];B`1NGUh0IFEU04Y:BP2<S8`0J6QX0410@01/K6`0Jf][03Ti>@1hN7P0IfMW051@D01`L700
IFEU05IFEP1OGel0D51@065QH@1PH600DU9B08R8R01JFUX0EEEE08Z:RP1OGel0IFEU09:BTP10@400
G5aL09NGU`18B4P0JVYZ08n?S`1?Cdl0KVi^092@T018B4P0PH6107]kN`1FEUH0NWYj0:6QX@1EEED0
KFe]08F5Q@1EEED0KFe]08V9R@1ADE40PH6107YjNP1MGEd00P2<S8`0901[Jf/0QhN706i^KP1gMgL0
QXJ604m?C`26QXH0IfMW051@D02<S8`0PX:206i^KP28R8P0Ti>C07MgM`1/K6`0LG5a09RHV01oOgl0
K6a/0:JVYP1ZJVX0Kfm_06e]K@1NGUh0Ti>C06i^KP1JFUX0S8b<05]KF`1TI6@0UiNG06e]K@1WIfL0
QhN706e]K@80JVYZ00X0Jf][07]kN`2NWYh0JFUY0820P02;Rh/0Fe]K06m_K`2GUiL0EUIF0P25QHD0
1P1?Cdl0Fe]K09bLW00n?Sh0JVYZ05UIF@kooooo00l0J6QX0:RXZ01kNg/0G5aL05]KF`1RHV80I6AT
06IVIP1^KVh0DE5A05aLG01?Cdl0E5AD0492@P1DE5@00P1;Bd/01@1ZJVX0KFe]051@D00n?Sh0HV9R
0080C4a<00X0DU9B04m?C`1CDe<0H61P05YJFP1IFET0CTi>04m?C`16ATH0GemO0P1YJFT09P20P800
X:2P08N7Q`1PH600MgMg06YZJP1?Cdl0GEeM05EEE@1MGEd0CTi>06=SH`10@400Bd];05ADE019BDT0
Cdm?059BDP1iNGT0LW9b06EUI@1CDe<0MWIf0820P01WIfL0H61P05YJFP1[Jf/0QhN709BDU01CDe<0
MgMg06MWI`1]KFd0GEeM051@D017AdL0B4Q80P1ADE40>@1;Bd/0Cdm?0451@@1?Cdl0Fe]K04A4A01K
Fe/0FUYJ04i>CP1;Bd/0GemO05]KF`1NGUh0FEUI06IVIP1WIfL0Fe]K05EEE@1/K6`0QhN706MWI`1E
EED0IVIV075aL@1eMGD0MgMg03hn?P1EEED0FEUI05]KF`1OGel0Hf=S05aLG01GEeL0IVIV079bLP2<
S8`0Jf][07alO02=SHd0JFUY06IVIP2BTY80LG5a07inOP1TI6@0GemO07]kN`1dM7@0HV9R06YZJP1d
M7@0MgMg05MGE`1NGUh0PX:205aLG00205QHF005079bLP1fMWH0Fe]K08n?S`2`/;003_ooool03`1i
NGT0XJ6Q05QHF014A4@0EEEE03Ti>@0k>c/0=3@d030`<00m?Cd0<c<c03Ph>00k>c/0KVi^04U9B@02
04I6AP0X02h^;P1YJFT0?Cdm03Lg=`13@d<0EeMG02l_;`1<C4`0D51@05=CD`1@D500CDe=05UIF@18
B4P0?clo04M7A`1GEeL0HV9R06ATI01KFe/0CDe=09:BTP1YJFT0DU9B03lo?`12@T80>c/k06ATI02C
Ti<0KVi^05EEE@1NGUh0Hf=S05]KF`1bLW80JFUY06=SH`1VIVH0IFEU04a<C080H61P01/0IFEU061P
H017AdL0Jf][06IVIP1_Kfl0O7al06EUI@1QHF40K6a/07=cL`1RHV80Q8B407AdM01QHF40JVYZ07]k
N`1eMGD0Q8B408>3P`1RHV80LW9b05mOG`1XJ6P0VIVI069RHP1]KFd00P1ADE40=01^KVh0IFEU05MG
E`10@400JFUY05]KF`1NGUh0CDe=05ADE025QHD0D51@069RHP1UIFD0N7Qh055AD@1^KVh0MWIf04m?
C`1oOgl0IVIV03Ph>01fMWH0GUiN06YZJP2FUYH0IfMW05mOG`1EEED0AdM705mOG`1dM7@0>c/k07Mg
M`1/K6`0QHF503lo?`1nOWh0WYjN04i>CP1QHF40IFEU04U9B@1IFET0Ng]k071`L01jNWX0?clo05YJ
FP1iNGT0HV9R05]KF`18B4P>ooooo`170<W9b@25QHD0E5AD059BDP1MGEd08b<S0:j^[P29RHT0Ogmo
08R8R02QXJ40Z:RX09FEU@2FUYH0@T9202PX:00N7Qh07AdM01lO7`0Q8B40Q8B408V9R@1_Kfl0W9bL
0::RXP2>SXh0Ti>C09nOW`2:RXX0a<C40:b/[01EEED0:RXZ0451@@1;Bd/0?Cdm04M7A`1IFET0>3Ph
02/[:`0d=3@0F5QH07alO01HF5P0EUIF08F5Q@0Y:BT0:2PX03/k>`2WYjL0BDU9051@D01:BTX0RHV9
02XZ:P1NGUh0>c/k05EEE@0_;bl0M7Ad04I6AP0V9RH07alO0451@@1ZJVX0LW9b09BDU01XJ6P0De=C
07QhN025QHD00P1@D5007`1TI6@0=CDe02<S8`0e=CD0LW9b06=SH`1TI6@0]kNg0:ZZZP2;Rh/0^[Zj
05QHF010@4009BDU03De=@1QHF40P8200:6QX@1TI6@0U9BD0<[:bP2RXZ80alO70::RXP1bLW80?Shn
01lO7`1UIFD0UYJF09NGU`1CDe<00P0M7Ad01@0U9BD0Rh^;07=cL`23Ph<0Rh^;00808B4Q01/0RHV9
08B4Q01UIFD0=3@d05EEE@0g=cL0DU9B07EeM@1gMgL0clo?09jNWP2^[Zh0]kNg0;fm_@2l_;`0WYjN
0;2`/02IVIT0BTY:05=CD`1TI6@0BTY:0:ZZZP1`L700=SHf0492@P2<S8`05?ooool001?ooooo00@0
O7al07moO`1XJ6P0Q8B40P1BDU80J`1TI6@0@410055AD@11@D40AdM706YZJP0i>CT0Fe]K06a/K00k
>c/0LG5a061PH01<C4`0M7Ad07=cL`19BDT0GemO08n?S`15ADD0IfMW08>3P`0m?Cd0G5aL04i>CP15
ADD0DU9B05iNGP1CDe<0Ng]k05ADE01FEUH0FUYJ06IVIP1RHV80IfMW05UIF@2=SHd0CDe=05mOG`2=
SHd0B4Q8065QH@1VIVH0FUYJ05ADE01SHf<0GEeM05MGE`1]KFd0HF5Q05MGE`1oOgl0PX:206UYJ@2D
U9@0Kfm_06MWI`2?Shl0IfMW07EeM@24Q8@0J6QX08^;R`1DE5@0K6a/08B4Q017AdL0IVIV07]kN`14
A4@0QhN708Z:RP17AdL0MGEe08>3P`1OGel0WIfM0:^[Z`1NGUh0RXZ:092@T01DE5@0NWYj0820P019
BDT0M7Ad06MWI`1QHF40VYZJ05YJFP26QXH0Vi^K05mOG`2EUID0Kfm_08B4Q01gMgL0NWYj0820P01a
LG40H61P08>3P`1fMWH0Fe]K06e]K@1/K6`0O7al0080IfMW01P0Rh^;069RHP1gMgL0Zj^[05IFEP1W
IfL0ZZZZ05YJFP1cLg<0SXj>05MGE`1dM7@0Rh^;04=3@`2IVIT0QHF5030`<02SXj<0Ng]k0451@@1b
LW80KVi^04];B`1WIfL>ooooo`0M05YJFP3GemL0TI6A07YjNP1hN7P0GemO06IVIP1/K6`0SHf=06UY
J@1BDU80Cdm?05UIF@1>CTh0GemO05MGE`1KFe/0Lg=c07MgM`1CDe<0?Cdm06UYJ@1JFUX0ATI606=S
H`1RHV80Cdm?04A4A01=CDd00P1JFUX0C01>CTh0B4Q8051@D01_Kfl0JVYZ07EeM@1=CDd0ADE503dm
?@1mOGd0NGUi065QH@1NGUh0Cdm?05UIF@1@D500JVYZ04U9B@1:BTX0Cdm?0451@@16ATH0GUiN06m_
K`1XJ6P0JVYZ05MGE`1PH600EUIF0492@P1BDU80Cdm?06a/K01bLW80Ng]k04E5A@1LG5`0D51@04m?
C`1;Bd/0D51@04Q8B01CDe<0Lg=c05UIF@1UIFD0EEEE069RHP1TI6@0KFe]065QH@1]KFd0IFEU04E5
A@0j>SX0Cdm?06e]K@1QHF40CTi>05mOG`1IFET0G5aL05mOG`1KFe/0Ng]k059BDP1VIVH0JFUY07in
OP20P800SXj>05QHF01WIfL0TY:B05QHF01UIFD206e]K@0O059BDP1MGEd0NGUi09^KV`1oOgl0RXZ:
0820P01XJ6P0MGEe07moO`1]KFd0RHV904a<C01=CDd0PX:207AdM01VIVH0JVYZ07emO@2;Rh/0OGem
07UiN@2@T900DE5A04I6AP1/K6`0LW9b06IVIP1WIfL0P82008n?S`0>ooooo`0404a<C02LW9`0GemO
04e=C@80CTi>08H0@d=30410@00f=SH0<S8b02d];@0Z:RX0=SHf07AdM00h>3P0ATI603/k>`0e=CD0
KFe]055AD@0d=3@0CDe=06QXJ00^;Rh0ATI604=3@`1BDU80IFEU04I6AP1OGel0M7Ad034a<@1KFe/0
B4Q806ATI01[Jf/0IFEU04M7A`1bLW80KFe]0492@P0j>SX0Fe]K04A4A016ATH0RHV906ATI01:BTX0
GEeM04M7A`1BDU80Jf][05QHF01GEeL0GEeM05aLG014A4@0GemO05YJFP1SHf<0E5AD04M7A`1LG5`0
BDU907EeM@1bLW80EEEE071`L01cLg<0IVIV05eMG@1oOgl0M7Ad06m_K`1dM7@0OGem08F5Q@2<S8`0
SHf=05MGE`21PH40O7al06ATI02=SHd0GemO07moO`1JFUX0D51@06QXJ01hN7P0Cdm?03/k>`1hN7P0
Jf][06=SH`1HF5P0E5AD08V9R@1GEeL0NWYj04=3@`1VIVH0DE5A061PH01[Jf/0EeMG06YZJP1fMWH0
@D5106][J`1>CTh0IfMW09>CT`1EEED0E5AD05eMG@15ADD0CTi>06YZJP16ATH0I6AT07MgM`2<S8`0
ATI6092@T02BTY80HV9R06e]K@1YJFT0G5aL06MWI`1[Jf/0GemO08f=S@10@400Fe]K05EEE@27QhL0
DU9B03Ph>0kooooo04h0ZZZZ08N7Q`19BDT0Cdm?06ATI01<C4`0IFEU05mOG`1:BTX0K6a/07IfMP2I
VIT0WIfM07alO01>CTh0B4Q804M7A`0_;bl0:b/[04I6AP1jNWX0ZZZZ07MgM`2IVIT0R8R804i>CP0Z
:RX09RHV061PH01lO7`0];Bd0:^[Z`1JFUX09bLW01/K6`0Z:RX0=cLg02LW9`1?Cdl0B4Q802h^;P1E
EED0U9BD0861P@1iNGT0VIVI04e=C@0W9bL0>CTi06m_K`1SHf<0?Cdm04A4A01LG5`0;Rh^04Y:BP23
Ph<0Ti>C06i^KP14A4@0Kfm_03Lg=`0M7Ad0CDe=0:JVYP1bLW80I6AT038b<P0[:b/0:2PX06a/K01R
HV80RHV90:VYZ@1UIFD0>CTi04Y:BP1`L70205IFEP0F07]kN`1<C4`0CDe=065QH@1dM7@0IFEU04A4
A010@400;bl_05iNGP1ZJVX0WYjN06m_K`3AdM40a<C40:BTY01[Jf/0>CTi04e=C@1?Cdl0Lg=c0861
P@80LG5a0180:RXZ01dM7@0j>SX0MGEe07alO01[Jf/0W9bL05YJFP1[Jf/0Ti>C03`l?01FEUH0TI6A
06][J`0Y:BT0?Shn06UYJ@1fMWH20<30`00=0<;2`P2c/k<0^[Zj0<30`03Jf]X0GEeM02/[:`1hN7P0
Fe]K06=SH`2:RXX0QHF509bLW00208j>SP030:FUYOoooooooooo01;ooooo000Cooooo`0b08b<S01a
LG40U9BD06ATI01EEED0EeMG05UIF@1<C4`0IVIV04Y:BP1WIfL0H61P05ADE021PH40Fe]K05=CD`1Y
JFT0A4A4061PH01SHf<0D51@05iNGP1JFUX0IfMW069RHP1>CTh0M7Ad04];B`1=CDd0Fe]K05EEE@0l
?3`0MWIf07UiN@1;Bd/0IfMW07QhN00n?Sh0Kfm_07EeM@0g=cL0IFEU07AdM015ADD0Fe]K05aLG01:
BTX0IVIV05eMG@1QHF42069RHP1G07UiN@1;Bd/0G5aL08V9R@1RHV80H61P08N7Q`1EEED0QHF5075a
L@1OGel0O7al06i^KP1MGEd0O7al07YjNP1oOgl0HF5Q08J6QP1_Kfl0G5aL08b<S01WIfL0EEEE08f=
S@1_Kfl0FUYJ08F5Q@1UIFD0MGEe08R8R01cLg<0Ng]k07YjNP1iNGT0MgMg05iNGP21PH40HF5Q06YZ
JP1^KVh0KFe]079bLP1jNWX0UYJF06YZJP1TI6@0SXj>08J6QP23Ph<0MgMg0::RXP1VIVH0Fe]K07Ui
N@1QHF40Ng]k075aL@1GEeL0Q8B4069RHP19BDT0MgMg08j>SP1UIFD0Ogmo08J6QP1NGUh0IfMW07in
OP1[Jf/0UiNG06YZJP1HF5P0UIFE06e]K@1DE5@0VYZJ075aL@1?Cdl0Ph>3071`L01NGUh0MgMg05IF
EP1LG5`0HF5Q00kooooo08@0D51@09VIV@28R8P0IVIV05]KF`1IFET0J6QX07UiN@2>SXh0HV9R04A4
A01>CTh0DE5A0451@@1ADE40EUIF06=SH`1WIfL0Kfm_06=SH`11@D40K6a/05YJFP11@D40J6QX04a<
C01BDU80EUIF065QH@1JFUX0EeMG05QHF01:BTX0Fe]K06i^KP1XJ6P0QhN706e]K@1GEeL0EUIF08b<
S01jNWX0F5QH06=SH`1JFUX0IFEU05]KF`1UIFD0DU9B05]KF`1LG5`0E5AD059BDP1PH600MgMg06IV
IP22PX80JVYZ06QXJ01MGEd0J6QX069RHP1EEED0OGem08J6QP2>SXh0GUiN05YJFP1OGel0Fe]K05YJ
FP1EEED0AdM705eMG@1^KVh0GEeM05YJFP1EEED0D51@08Z:RP1fMWH0EeMG06YZJP1JFUX0A4A403dm
?@1XJ6P0JFUY05mOG`1WIfL0IVIV05QHF01VIVH0GEeM06a/K01^KVh0HF5Q06IVIP1UIFD0KVi^07in
OP1hN7P0CDe=05eMG@1WIfL0DU9B06a/K01[Jf/0GemO055AD@1GEeL0JFUY08f=S@27QhL0OWin08^;
R`1YJFT0Jf][07QhN01KFe/0KVi^059BDP1EEED0K6a/06m_K`1eMGD0Jf][07EeM@24Q8@0KFe]07If
MP1gMgL205QHF006069RHP1_Kfl0GemO061PH01hN7P0TY:B3_ooool0@01?Cdl0OWin05UIF@13@d<0
E5AD04=3@`19BDT0BTY:03De=@0Y:BT0:2PX02/[:`0d=3@0EeMG05UIF@0k>c/0?3`l03De=@1SHf<0
ATI603`l?015ADD0F5QH034a<@1=CDd0=CDe04I6AP1;Bd/0>CTi055AD@1IFET09RHV04e=C@16ATH0
Jf][05=CD`1BDU80GEeM061PH01_Kfl0ADE50451@@1FEUH0?Shn059BDP2DU9@0FUYJ05=CD`1:BTX0
Fe]K04e=C@1RHV80J6QX06YZJP1NGUh0IVIV04Q8B01QHF40JVYZ06UYJ@1UIFD0D51@05QHF01EEED2
07MgM`1:05mOG`1fMWH0Kfm_06UYJ@1aLG40GemO07AdM01WIfL0MWIf07]kN`1jNWX0N7Qh07inOP1R
HV80JFUY071`L01[Jf/0SXj>05YJFP1`L700CDe=05YJFP1cLg<0GemO05YJFP0j>SX0PX:206UYJ@1?
Cdl0@4100492@P1dM7@0B4Q8069RHP1:BTX0LG5a05ADE01FEUH0NGUi04i>CP1QHF40Lg=c034a<@1B
DU80EUIF07IfMP2DU9@0Fe]K05MGE`1HF5P0@41004i>CP1ZJVX0BTY:05iNGP1OGel0SXj>03@d=01_
Kfl0PX:204I6AP1EEED0G5aL04I6AP1CDe<0I6AT055AD@1iNGT0?Cdm04a<C00o?cl0SXj>05UIF@0m
?Cd>ooooo`0605IFEP1MGEd0Jf][06m_K`1ZJVX0I6AT0P0n?Sh04P11@D40De=C06i^KP2f][H0WIfM
05QHF01KFe/0JVYZ06ATI01]KFd0MgMg07emO@2GUiL0X:2P08V9R@2:RXX0:2PX01LG5`<061PH00@0
I6AT0:f][@2][Jd071`L0P0G5aL0FP0H61P08b<S034a<@0T92@0<c<c05EEE@1QHF40RHV907]kN`1B
DU80LW9b051@D01NGUh0VYZJ05ADE014A4@0NWYj055AD@0n?Sh0C4a<05IFEP1VIVH0KVi^04m?C`1T
I6@0Ng]k092@T02ATI40/k>c0;Bd]01jNWX0DU9B05iNGP1?Cdl0=CDe02XZ:P27QhL0_Kfm09:BTP1V
IVH0KFe]08>3P`22PX80IfMW06QXJ00Z:RX0820P03/k>`1:BTX0PX:206UYJ@1@D500AdM704i>CP21
PH40LG5a06a/K02ATI40X:2P06YZJP29RHT0GEeM03Ti>@0g=cL0J6QX0<C4a02IVIT0Xj>S0:2PX01N
GUh0>c/k07EeM@1LG5`0SXj>0;Zj^P2@T900F5QH055AD@1IFET0MGEe08n?S`1RHV80OWin079bLP2D
U9@0WinO08b<S010@400];Bd055AD@80KFe]00<0QXJ608f=S@2=SHd00P0U9BD0202/[:`0OWin06YZ
JP1>CTh0[Jf]05EEE@1?Cdl0M7Ad5?ooool001?ooooo00X0RHV906i^KP27QhL0Cdm?07=cL`0`<300
E5AD071`L01?Cdl0I6AT0P1SHf<0@P1kNg/0I6AT07emO@1OGel0EUIF05mOG`1`L700E5AD05iNGP1`
L700@41007moO`1/K6`0B4Q808j>SP1EEED0CDe=09^KV`17AdL0ADE505YJFP1@D500GemO065QH@1X
J6P0JVYZ06EUI@1eMGD0Fe]K05eMG@1eMGD0H61P05QHF01]KFd0I6AT04a<C01SHf<0O7al05EEE@1S
Hf<0U9BD03dm?@1hN7P0Ti>C0492@P1aLG40/;2`03`l?01cLg<0UYJF0451@@1fMWH0SXj>04];B`2<
S8`0NWYj05IFEP1jNWX0Vi^K051@D01]KFd0Ogmo05ADE01]KFd0MGEe06][J`80Kfm_01P0K6a/09>C
T`28R8P0R8R808^;R`1XJ6P0R8R806m_K`1ADE40RHV9065QH@21PH40UIFE06ATI01oOgl0Q8B406YZ
JP2;Rh/0JFUY07UiN@2CTi<0I6AT05mOG`2WYjL206i^KP0Q06a/K01DE5@0Ti>C055AD@1TI6@0RXZ:
051@D01]KFd0NGUi0:VYZ@2PX:00NWYj06m_K`1eMGD0L71`06UYJ@1UIFD0SXj>05YJFP1SHf<0Kfm_
05UIF@1BDU80L71`06][J`1IFET0I6AT05EEE@1QHF40Jf][03dm?@1/K6`0IfMW00kooooo00H0DE5A
07UiN@1RHV80F5QH04U9B@1DE5@205eMG@1007alO01MGEd0@41003lo?`11@D40@T9203hn?P1=CDd0
GemO06MWI`1dM7@0JFUY04];B`1TI6@0GUiN05UIF@1]KFd0G5aL05ADE01FEUH0GUiN069RHP1ADE40
EEEE04m?C`1]KFd0QHF506EUI@2MWId0Ogmo079bLP1?Cdl0Rh^;07moO`1HF5P0KVi^05aLG01dM7@0
Hf=S07QhN01<C4`0EEEE061PH01>CTh0E5AD05UIF@1RHV80Hf=S05aLG01BDU80G5aL05ADE01kNg/0
EEEE05UIF@1_Kfl0PX:208>3P`1KFe/0OWin07AdM016ATH0Kfm_055AD@80CDe=0480JVYZ05IFEP1T
I6@0GEeM05QHF01OGel0I6AT05]KF`1SHf<0De=C051@D016ATH0G5aL06QXJ01KFe/0GUiN05aLG01J
FUX0F5QH04I6AP1hN7P0Ogmo04i>CP12@T80GUiN05YJFP1iNGT0Ph>304];B`1EEED0PX:205eMG@1Y
JFT0Jf][051@D01CDe<0JFUY05ADE02=SHd0PH6108J6QP1[Jf/0JVYZ07QhN01]KFd0HV9R0861P@1Y
JFT0N7Qh08^;R`1HF5P0IVIV06UYJ@26QXH0I6AT04a<C01OGel0SXj>04];B`1IFET0IfMW08B4Q01Z
JVX0IVIV0861P@2FUYH>ooooo`1P06QXJ01bLW80A4A4059BDP14A4@0BDU904e=C@13@d<0>3Ph01dM
7@0`<300<C4a02/[:`1=CDd0G5aL03<c<`0f=SH09bLW05]KF`1?Cdl0=CDe05MGE`18B4P0=SHf05UI
F@0[:b/0<30`04Q8B010@400EEEE04m?C`0W9bL0D51@04e=C@1^KVh0CDe=065QH@1_Kfl0F5QH07in
OP1@D500<c<c04Q8B00h>3P0FUYJ07emO@1FEUH0HF5Q04Y:BP1>CTh0D51@05mOG`1bLW80KFe]06QX
J01NGUh0A4A4061PH01aLG40KVi^06ATI01BDU80GUiN05eMG@1]KFd0KVi^05IFEP1aLG40HV9R07If
MP1mOGd0KVi^07]kN`1QHF40O7al07UiN@1JFUX0OGem08b<S01PH600GemO06m_K`1eMGD0JFUY06][
J`1_Kfl0BDU904m?C`1]KFd0H61P06ATI015ADD0O7al08J6QP1TI6@0CTi>0P1LG5`0401ADE40L71`
065QH@1gMgL0DU9B06IVIP1gMgL0Fe]K07emO@25QHD0<S8b055AD@1WIfL0HF5Q06EUI@1fMWH2059B
DP0:04e=C@1<C4`0GUiN05YJFP1GEeL0FEUI08j>SP11@D40PH6107MgM`80IFEU00`0GemO05eMG@1H
F5P0OGem051@D026QXH0Bd];05iNGP0m?Cd0T92@05IFEP0l?3`>ooooo`0T04U9B@10@400De=C0:NW
Y`2UYJD0I6AT03hn?P1oOgl0M7Ad0492@P0W9bL0CDe=0:f][@1lO7`0A4A4096AT@2LW9`0FEUI06a/
K01oOgl0LW9b075aL@0c<c<0=CDe05ADE00^;Rh05aLG01PH600d=3@0HF5Q09NGU`2h^;P0G5aL030`
<00];Bd0<c<c0P0[:b/02P1IFET0BTY:06MWI`1/K6`0GUiN07emO@1BDU80[jn_05iNGP0`<3020861
P@1J06i^KP2CTi<0VYZJ09ZJVP2FUYH0G5aL02d];@0d=3@0HF5Q06=SH`2CTi<0VYZJ0:b/[02h^;P0
^k^k09JFUP1FEUH0<c<c03Lg=`1DE5@0N7Qh0;Rh^02HV9P0JVYZ08f=S@1VIVH0HV9R08F5Q@2QXJ40
ATI601dM7@0O7al0=CDe05MGE`2OWil0JFUY02h^;P0P82007AdM03Xj>P2JVYX0R8R804a<C018B4P0
KFe]05mOG`21PH40BTY:06i^KP2`/;00Q8B407alO02DU9@0Ogmo071`L03=cLd0YZJV0:ZZZP2UYJD0
M7Ad0820P015ADD0F5QH05]KF`1jNWX0/[:b0;Fe]@1KFe/0TY:B0;^k^`37alL0>SXj09:BTP2f][H0
>CTi03`l?01KFe/0Q8B409NGU`1fMWH0Rh^;03Xj>P1jNWX0@d=309VIV@2[Zj/0[jn_05mOG`1dM7@0
KVi^5?ooool001?ooooo08/0S8b<07IfMP1nOWh0QhN705IFEP1CDe<0Lg=c03Hf=P1NGUh0D51@05AD
E01SHf<0@41006ATI01jNWX0?3`l06][J`1WIfL0D51@06e]K@1TI6@0E5AD07IfMP1VIVH0E5AD06MW
I`1nOWh0DU9B05eMG@1JFUX0G5aL0492@P1XJ6P0IVIV04e=C@1FEUH0Lg=c03De=@1SHf<0QhN703lo
?`1NGUh0TY:B03/k>`1/K6`0OGem04e=C@1PH600FUYJ05ADE01KFe/0L71`06a/K01`L700GemO06e]
K@1kNg/0GemO07moO`1iNGT0M7Ad07IfMP27QhL0JVYZ0820P02<S8`0Cdm?07UiN@2@T900>c/k08b<
S027QhL0?Cdm0861P@1hN7P0>SXj07]kN`1nOWh0@T920:FUY@20P800EeMG0:BTY02EUID0HF5Q0:NW
Y`2ATI40I6AT08V9R@1_Kfl0HV9R07alO01]KFd0QhN708b<S01cLg<0][Jf06YZJP1aLG40Vi^K06YZ
JP2IVIT0GUiN08:2PP2<S8`0NGUi08>3P`1YJFT0PH6108f=S@1MGEd0NGUi07moO`1LG5`0DU9B05mO
G`1mOGd0S8b<09FEU@18B4P0Hf=S09FEU@0m?Cd0KFe]08:2PP0o?cl0RXZ:07emO@17AdL0OGem06QX
J00j>SX0Lg=c08V9R@1?Cdl0MGEe071`L01@D500K6a/00kooooo0140D51@08:2PP2IVIT0K6a/055A
D@1UIFD0HF5Q061PH01OGel0@D5103dm?@0n?Sh0B4Q80492@P1?Cdl0De=C05QHF002071`L00W04U9
B@0j>SX0Hf=S04U9B@0m?Cd0@T9204a<C013@d<0E5AD05IFEP1EEED0CDe=04Q8B01:BTX0C4a<061P
H01JFUX0Jf][05ADE01/K6`0@T9208b<S01NGUh0AdM704i>CP16ATH0@D5104A4A01EEED0@41004A4
A015ADD0?3`l04A4A016ATH0FUYJ04];B`1TI6@0DE5A0080F5QH01@0K6a/065QH@1EEED0JVYZ08N7
Q`1HF5P0J6QX06][J`20P800SHf=0820P01bLW80H61P055AD@1nOWh0H61P05ADE01XJ6P0CTi>08^;
R`80GemO02l0MGEe06][J`1DE5@0EEEE05mOG`1gMgL0HV9R055AD@1?Cdl0HF5Q06EUI@1[Jf/0S8b<
06e]K@1SHf<0EeMG06YZJP1XJ6P0Ti>C08f=S@18B4P0J6QX06e]K@1eMGD0GEeM05mOG`1BDU80CTi>
05eMG@1JFUX0Q8B406a/K01aLG40P82005eMG@1/K6`0QHF506QXJ01`L700Bd];061PH01_Kfl0H61P
06MWI`1nOWh0Ti>C09:BTP0207QhN00908^;R`1@D500CDe=05aLG01eMGD0IVIV06e]K@27QhL0[Jf]
00kooooo08`0HF5Q06QXJ01;Bd/0?3`l03Ph>00i>CT0>c/k03hn?P0Y:BT051@D02l_;`0W9bL0=cLg
04Q8B01SHf<0>SXj038b<P0i>CT0Cdm?04];B`14A4@0ATI604m?C`0h>3P0B4Q8028R8P15ADD0@d=3
03<c<`1RHV80ATI602HV9P1OGel0@d=307YjNP1@D500CTi>08J6QP1SHf<0TI6A051@D00g=cL0KVi^
03<c<`1IFET0P82006a/K01JFUX0HV9R04I6AP1>CTh0DU9B05EEE@1bLW80Fe]K05EEE@18B4P0FEUI
05iNGP1IFET0G5aL04Q8B011@D40BDU9079bLP14A4@0D51@07UiN@1cLg<0De=C0861P@1FEUH0FEUI
07]kN`22PX80MWIf07UiN@1lO7`0MWIf09BDU01RHV80QhN707moO`1YJFT0UIFE06e]K@13@d<0GEeM
06a/K01SHf<0G5aL059BDP1YJFT0S8b<07=cL`1ADE40CDe=05UIF@1SHf<0KFe]03`l?01aLG40Fe]K
05IFEP1_Kfl0FEUI06][J`1lO7`0C4a<03`l?01FEUH0L71`06MWI`1dM7@0Fe]K069RHP0n?Sh0G5aL
06e]K@1VIVH0GEeM04e=C@2PX:00>3Ph06e]K@24Q8@0HV9R04U9B@17AdL0JFUY059BDP1ZJVX0Hf=S
09ZJVP11@D40Fe]K04Q8B01kNg/0Cdm?03lo?`kooooo00T0M7Ad030`<00d=3@0JVYZ065QH@0/;2`0
7alO02d];@0W9bL00P0R8R80601<C4`0A4A405eMG@2SXj<0U9BD0:FUY@21PH40Q8B4079bLP1nOWh0
V9RH04a<C00Z:RX0;Rh^04a<C01DE5@0=3@d02LW9`0^;Rh0Shn?0;Zj^P2UYJD0NWYj04A4A0809bLW
06L0<C4a05UIF@0`<300IVIV06][J`1FEUH0RXZ:07AdM01cLg<0HV9R05aLG02BTY80ADE502d];@1;
Bd/0WIfM0<G5a@2a/K40MgMg03Ph>00_;bl09bLW02h^;P2^[Zh0VIVI0;jn_P2RXZ80TY:B09BDU01L
G5`0EeMG05]KF`18B4P0SHf=09VIV@2QXJ40D51@055AD@1?Cdl0MGEe0;Fe]@2XZ:P0Fe]K02h^;P1F
EUH0IfMW04i>CP2;Rh/0A4A403hn?P0N7Qh06a/K030`<02m_Kd0/[:b02`/;00_;bl0UYJF07]kN`2R
XZ80WinO08Z:RP26QXH0=cLg02XZ:P16ATH0E5AD07EeM@23Ph<0TI6A0=3@d02=SHd0G5aL05MGE`1Y
JFT0Cdm?05iNGP2e]KD0[jn_0;6a/@1aLG40I6AT0:ZZZP2o_kl0W9bL07QhN01UIFD0GUiN07IfMP1l
O7`0>c/k07moO`21PH40OGem0:^[Z`1BDU80CDe=0:^[Z`2=SHd0WIfM03@d=01HF5P0EUIF01Cooooo
000Cooooo`1`08V9R@1mOGd0QXJ607inOP1/K6`0H61P071`L01ZJVX0FUYJ04i>CP1jNWX0GEeM05iN
GP2<S8`0G5aL079bLP2<S8`0DE5A065QH@1UIFD0G5aL06ATI01HF5P0OGem06YZJP1;Bd/0PX:205]K
F`1LG5`0I6AT05YJFP13@d<0EeMG06][J`14A4@0LW9b08F5Q@0n?Sh0KFe]0861P@17AdL0I6AT07]k
N`14A4@0JFUY06QXJ01DE5@0Hf=S061PH01]KFd0IfMW06IVIP1XJ6P0AdM706IVIP22PX80F5QH06MW
I`2UYJD0EeMG07AdM024Q8@0HV9R07moO`23Ph<0LG5a06m_K`21PH40J6QX06=SH`2ATI40GemO069R
HP2=SHd0IFEU06MWI`23Ph<0H61P06UYJ@1lO7`0J6QX08>3P`2NWYh0NGUi08F5Q@1/K6`0MgMg07Ee
M@1SHf<0PH6106QXJ01`L700RXZ:07MgM`1hN7P0NGUi08f=S@1cLg<0HF5Q07UiN@23Ph<0QhN705QH
F02MWId0MGEe06EUI@1lO7`0KFe]07QhN01XJ6P0GUiN07MgM`80H61P00d0J6QX08N7Q`2OWil0UIFE
08V9R@1WIfL0Lg=c06m_K`1HF5P0Rh^;05iNGP1JFUX0RXZ:0080G5aL00X0S8b<07AdM01KFe/0HV9R
05=CD`1eMGD0MgMg051@D01JFUX0IFEU3_ooool01@1EEED0RHV9075aL@1bLW80BDU90080FEUI0180
DE5A06a/K01KFe/0@d=30451@@1;Bd/0?Cdm051@D01HF5P0AdM705iNGP1RHV80DU9B0410@01KFe/0
EeMG03lo?`1VIVH204e=C@0O04a<C01?Cdl0CDe=059BDP1;Bd/0B4Q8059BDP1RHV80De=C07AdM01L
G5`0I6AT05IFEP29RHT0K6a/05MGE`1ADE40A4A404Q8B014A4@0E5AD04M7A`12@T80Bd];03lo?`12
@T80AdM705aLG01>CTh0K6a/059BDP02051@D01@05EEE@1:BTX0<S8b069RHP23Ph<0D51@06UYJ@1R
HV80KVi^051@D00k>c/0HV9R05aLG01TI6@0Lg=c06UYJ@1MGEd0HF5Q051@D01_Kfl0GEeM05IFEP1Y
JFT0L71`06YZJP1EEED0LW9b07alO01bLW80LG5a06][J`1aLG40KVi^06YZJP1iNGT0LW9b06MWI`1U
IFD0Kfm_06e]K@2GUiL0O7al05MGE`1QHF40LW9b05IFEP1VIVH0IfMW05iNGP1LG5`0JVYZ05aLG020
P800Hf=S05YJFP1OGel0K6a/06m_K`1kNg/0H61P07emO@1YJFT0QhN707QhN01IFET0NGUi069RHP1m
OGd0PX:208f=S@1dM7@0S8b<05=CD`1QHF40K6a/06m_K`1QHF40IfMW07]kN`2MWId>ooooo`0k06][
J`1OGel0@D5104A4A01;Bd/0A4A4051@D01>CTh0>SXj02LW9`0c<c<0:2PX03Ti>@17AdL0JFUY03Xj
>P0k>c/0<30`03lo?`1=CDd0>c/k05ADE01CDe<0=SHf05=CD`0T92@0A4A40451@@13@d<0GEeM04A4
A00_;bl0FUYJ03dm?@1QHF40@D51055AD@26QXH0@d=309FEU@19BDT0>CTi05QHF00d=3@0J6QX07]k
N`1cLg<0HV9R051@D01/K6`0CDe=04a<C01cLg<0JVYZ06][J`1HF5P0D51@04i>CP1aLG400P1SHf<0
C`1QHF40EEEE07AdM01bLW80CTi>07=cL`1fMWH0Lg=c06i^KP21PH40K6a/05UIF@1cLg<0Shn?07mo
O`1`L700RXZ:08F5Q@2;Rh/0KFe]09BDU01dM7@0KVi^09VIV@1`L700CDe=059BDP1QHF40Lg=c05MG
E`1OGel0Kfm_08F5Q@1KFe/0JFUY04i>CP1DE5@0LG5a07AdM01FEUH0MgMg071`L01EEED0JVYZ04m?
C`1mOGd0K6a/06=SH`16ATH0HF5Q06MWI`1LG5`0MgMg065QH@1GEeL0BTY:05mOG`1CDe<0GemO05AD
E01:BTX0MgMg03Xj>P1`L700JFUY06QXJ01BDU80A4A406IVIP1MGEd0K6a/069RHP1kNg/0D51@05MG
E`10@400H61P04Y:BP0f=SH03_ooool0I01oOgl0J6QX07AdM02GUiL0@41002<S8`0J6QX05ADE01dM
7@0N7Qh08R8R061PH00^;Rh0>3Ph08Z:RP2=SHd0NGUi04=3@`1=CDd0E5AD08^;R`1/K6`0DU9B04e=
C@0m?Cd0DE5A07=cL`0e=CD0<S8b0451@@2<S8`0YJFU09^KV`2PX:00UiNG08j>SP1[Jf/0FEUI05AD
E01aLG40MGEe05]KF`20P800Shn?08f=S@1OGel0;bl_059BDP1iNGT0Rh^;07=cL`1NGUh0LG5a08j>
SP25QHD0R8R805MGE`0o?cl0BDU906UYJ@2TY:@0J6QX07=cL`1^KVh0?Shn03Lg=`1HF5P0LW9b04a<
C01`L700TY:B07=cL`1>CTh0820P02`/;01TI6@0IfMW06a/K028R8P0NWYj0;Zj^P2n_[h0MWIf08>3
P`2JVYX0IFEU06e]K@1HF5P0DE5A08R8R02>SXh0QXJ6071`L023Ph<0a<C408B4Q02QXJ40NGUi06][
J`1^KVh202PX:00V0492@P2JVYX0SXj>09JFUP30`<00YJFU0:>SX`1bLW80C4a<04E5A@1cLg<0Kfm_
0;2`/02b/[80NGUi0:JVYP2@T900Hf=S0861P@2VYZH0MGEe06][J`2OWil0ATI609RHV011@D40AdM7
09:BTP2^[Zh0_[jn0820P02FUYH0Y:BT0861P@2VYZH0:b/[02XZ:P0n?ShDooooo`004oooool02@27
QhL0PX:207YjNP1MGEd0Ng]k0492@P1VIVH0JVYZ05ADE00205eMG@0^065QH@1WIfL0MWIf06i^KP1R
HV80IVIV07IfMP1KFe/0EUIF08>3P`1HF5P0DU9B079bLP1HF5P0GUiN096AT@0o?cl0JVYZ06MWI`1;
Bd/0GEeM04I6AP1MGEd0N7Qh05EEE@1UIFD0GemO06=SH`1hN7P0IFEU06][J`1^KVh0FUYJ05=CD`1d
M7@0Q8B40492@P1eMGD0RXZ:03Ti>@1fMWH0Ogmo03`l?01gMgL0OWin059BDP80M7Ad0500Fe]K079b
LP1dM7@0FEUI09>CT`1VIVH0KVi^08V9R@1jNWX0SHf=06m_K`1cLg<0KFe]06][J`23Ph<0OWin05iN
GP1XJ6P0NGUi05ADE01SHf<0MGEe06QXJ01/K6`0Rh^;07YjNP1[Jf/0_;bl06QXJ01WIfL0WIfM05YJ
FP1nOWh0R8R805YJFP27QhL0HF5Q075aL@2?Shl0EEEE08>3P`1mOGd0LG5a08:2PP20P800I6AT08b<
S01BDU80I6AT08N7Q`0f=SH0OWin06a/K01XJ6P0HF5Q09>CT`2/[:`0VIVI08F5Q@1YJFT0FEUI05aL
G027QhL0E5AD055AD@1]KFd0Fe]K05MGE`1^KVh0DU9B06QXJ01nOWh0DU9B05IFEP1<C4`0L71`06a/
K01LG5`0EEEE05]KF`kooooo04d0Bd];05iNGP1^KVh0LW9b03Xj>P1FEUH0I6AT04i>CP1/K6`0HF5Q
04i>CP1:BTX0ATI603Xj>P1BDU80EEEE05=CD`1IFET0FUYJ04M7A`0k>c/0HV9R05MGE`1;Bd/0IfMW
06][J`1:BTX0GUiN05mOG`1KFe/0FUYJ051@D01DE5@0H61P07QhN01RHV80LW9b06e]K@1eMGD0J6QX
09BDU021PH40G5aL061PH01ADE40G5aL04];B`1OGel0DE5A04U9B@1@D500ATI604m?C`18B4P0HF5Q
05ADE01jNWX0FUYJ04U9B@1?Cdl0HV9R04a<C011@D40JFUY08^;R`1UIFD0Kfm_08R8R01iNGT0=CDe
061PH00m?Cd0ATI604Q8B01_Kfl0CTi>04U9B@0204Q8B00905EEE@1>CTh0C4a<05MGE`1;Bd/0ATI6
04A4A01?Cdl0JVYZ0080GUiN0380Fe]K061PH01GEeL0CDe=05ADE01dM7@0GEeM06e]K@1TI6@0G5aL
06ATI01YJFT0DU9B04e=C@1WIfL0ADE5061PH01QHF40BDU905ADE01RHV80Bd];06i^KP1FEUH0P820
075aL@1OGel0KVi^08B4Q01GEeL0O7al06=SH`28R8P0NGUi05UIF@1eMGD0LG5a07AdM02WYjL0U9BD
06YZJP2MWId0CDe=05UIF@1^KVh0JFUY05eMG@1WIfL0NWYj08F5Q@kooooo0P1SHf<0L014A4@0De=C
03dm?@1;Bd/0;Rh^03<c<`0[:b/05ADE02TY:@0N7Qh092@T04Y:BP1WIfL0<S8b03Ti>@0/;2`0>CTi
051@D011@D40Bd];04e=C@1EEED0DE5A0410@01<C4`0?Cdm069RHP1TI6@0BDU90492@P1RHV80ATI6
065QH@10@400I6AT071`L01?Cdl0YZJV05UIF@15ADD0KFe]0492@P1UIFD0L71`08R8R01MGEd0G5aL
05IFEP1;Bd/0D51@06IVIP1PH600J6QX05mOG`16ATH0IVIV069RHP1EEED0KFe]05YJFP1LG5`0Bd];
07alO01;Bd/0Cdm?05UIF@1[Jf/0H61P06e]K@1bLW80De=C075aL@20P800GEeM05iNGP2HV9P0IVIV
08^;R`1UIFD0WYjN06MWI`1LG5`0][Jf05QHF010@400EUIF03lo?`1dM7@0ADE5059BDP1lO7`0SXj>
04m?C`1nOWh0GEeM03@d=022PX80NGUi069RHP1<C4`0N7Qh05QHF01TI6@0DU9B09NGU`1^KVh0JFUY
04I6AP1`L700IfMW05=CD`26QXH205EEE@0806=SH`1MGEd0BTY:07inOP15ADD0>SXj07emO@1JFUX2
05UIF@0>08>3P`13@d<0BDU907=cL`1VIVH0Ph>306EUI@1<C4`0Cdm?05EEE@1dM7@0DE5A051@D00n
?Sh>ooooo`2<0820P02DU9@0^k^k0;Jf]P0_;bl07QhN01HF5P0E5AD0ADE5038b<P1:BTX0EeMG034a
<@1[Jf/0PH6107IfMP1jNWX0=cLg03Hf=P0];Bd0DE5A04Q8B017AdL0EUIF07moO`1CDe<0HV9R0861
P@0_;bl0BDU906i^KP1ZJVX0HV9R08N7Q`1bLW80G5aL092@T026QXH0V9RH0<;2`P2HV9P0IFEU05AD
E019BDT0EUIF08R8R01^KVh0TI6A06MWI`2BTY80VIVI09fMW@22PX80>c/k05MGE`1NGUh0De=C04E5
A@0];Bd0=CDe0;Jf]P2OWil0Q8B408f=S@1=CDd09RHV02XZ:P0f=SH0ATI604e=C@1OGel0EeMG059B
DP0i>CT0<C4a02`/;00Z:RX0<C4a069RHP2WYjL0e=CD0;fm_@2RXZ80DU9B055AD@1aLG40De=C03Lg
=`1kNg/0];Bd0;2`/02IVIT0Z:RX0<O7a`33`l<0]kNg0<O7a`1eMGD0LG5a07]kN`1XJ6P0EeMG03dm
?@1]KFd0WinO0:FUY@21PH40QHF5069RHP0o?cl0BTY:06m_K`0V9RH0EeMG05mOG`1]KFd0<30`07If
MP11@D409RHV05EEE@1fMWH0clo?0:FUY@1gMgL0BTY:06e]K@26QXH0Rh^;06ATI02g]kL0W9bL0:n_
[`2a/K40WYjN09^KV`35aLD0MgMg0492@P16ATHDooooo`004oooool0R`1jNWX0O7al06a/K02CTi<0
D51@079bLP1cLg<0A4A407moO`0j>SX0P82005iNGP0j>SX0PH6106e]K@1BDU80LG5a06MWI`17AdL0
M7Ad065QH@1LG5`0KVi^05ADE01XJ6P0EUIF06][J`1UIFD0EUIF069RHP1`L700EeMG06MWI`1lO7`0
DU9B06EUI@2:RXX0@d=306MWI`2=SHd0@d=305YJFP2ATI40?clo06ATI01iNGT0ATI6061PH01iNGT0
C4a<075aL@1YJFT0HV9R05QHF01PH600OWin06ATI01JFUX0QHF5065QH@1UIFD0O7al09NGU`1YJFT0
QHF508B4Q01CDe<0PH610820P017AdL0UYJF07=cL`1OGel0/;2`06MWI`1[Jf/0Vi^K06QXJ01HF5P0
T92@06m_K`1bLW80Z:RX07moO`1`L700S8b<07YjNP2GUiL0IfMW06a/K01kNg/0K6a/07=cL`2EUID0
KVi^07IfMP2PX:00IVIV075aL@2:RXX0K6a/0::RXP1ADE40UiNG096AT@1HF5P0Jf][07alO029RHT0
M7Ad04Y:BP1`L700T92@04A4A00c<c<0CDe=05MGE`1eMGD0SXj>04U9B@1kNg/0X:2P05ADE024Q8@0
De=C05]KF`2<S8`0H61P051@D020P800GUiN04M7A`1PH600E5AD04];B`1aLG40EeMG055AD@20P800
3_ooool0D`16ATH0IVIV06][J`1[Jf/0>3Ph05YJFP1HF5P0HV9R06YZJP1RHV80EUIF051@D01GEeL0
ADE504Q8B01BDU80EeMG07QhN01[Jf/0@d=303Lg=`1NGUh0FEUI04i>CP1_Kfl0DU9B04];B`1LG5`0
F5QH04a<C01GEeL0BTY:05MGE`1QHF40MWIf065QH@2@T900KFe]06IVIP1WIfL0ZZZZ07]kN`1[Jf/0
GemO059BDP1LG5`0ATI605]KF`13@d<0BTY:05EEE@15ADD0?Shn04U9B@1IFET0EEEE06=SH`1QHF40
Fe]K05=CD`1NGUh0De=C03dm?@1TI6@0LW9b069RHP1mOGd0Kfm_08F5Q@1aLG40I6AT05EEE@1?Cdl0
EEEE08J6QP1XJ6P0GUiN06m_K`1YJFT0MGEe065QH@19BDT0LW9b0080EUIF03L0CTi>06ATI025QHD0
Hf=S061PH01CDe<0Jf][05QHF014A4@0Hf=S05]KF`1YJFT0CTi>06YZJP1ADE40Q8B406UYJ@1;Bd/0
De=C06ATI01RHV80IVIV06UYJ@1UIFD0JVYZ07EeM@1OGel0NGUi06ATI01iNGT0PX:207AdM01]KFd0
MWIf06m_K`25QHD0Ogmo0::RXP22PX80Fe]K06=SH`1dM7@0Ph>309bLW02QXJ40P8200:ZZZP1IFET0
GUiN06YZJP1hN7P0Hf=S06IVIP2MWId0YZJV00kooooo07l0P82006m_K`1IFET0C4a<03lo?`16ATH0
@T9204=3@`0e=CD0<C4a03<c<`0M7Ad0?Cdm03`l?01UIFD0<c<c03dm?@0i>CT09bLW05QHF019BDT0
MWIf04];B`17AdL0DU9B03hn?P17AdL0:2PX04A4A01VIVH0>c/k03Hf=P1PH600?clo04I6AP0];Bd0
B4Q806IVIP1EEED0ZZZZ055AD@1SHf<0K6a/034a<@1UIFD0MGEe09FEU@1PH600Cdm?05YJFP1?Cdl0
>c/k06EUI@1ADE40EEEE05QHF00j>SX0B4Q8061PH01=CDd0G5aL06=SH`1<C4`0Lg=c06MWI`11@D40
LG5a04a<C01JFUX0Jf][06e]K@1VIVH0HF5Q079bLP1SHf<0JFUY08F5Q@2MWId0LW9b0:6QX@1OGel0
LW9b07AdM01WIfL0XJ6Q06][J`19BDT0E5AD05]KF`1eMGD0BTY:05UIF@1EEED0P82004I6AP1TI6@0
?Shn02TY:@27QhL0Jf][05MGE`1NGUh0N7Qh04U9B@1OGel0EeMG08V9R@1jNWX0JFUY038b<P1[Jf/0
EUIF06IVIP2=SHd0O7al06IVIP1BDU80MGEe05aLG01kNg/0Cdm?05MGE`1dM7@0EEEE06][J`1LG5`0
L71`0080Cdm?00/0NWYj061PH023Ph<0GemO05EEE@1IFET0GEeM05mOG`1RHV80HF5Q04U9B@0>oooo
o`0H08B4Q029RHT0Fe]K0:FUY@2:RXX08R8R01TI6@0K6a/0<C4a05QHF02ZZZX0XZ:R07]kN`29RHT0
Shn?04I6AP0l?3`0K6a/03Ph>00/;2`0DU9B05UIF@0W9bL0=3@d0P1iNGT03`0g=cL0GUiN04];B`0d
=3@09RHV024Q8@0Y:BT0<C4a01DE5@0F5QH0<c<c03hn?P1EEED0`l?309ZJVP0203dm?@1405UIF@0n
?Sh0?Cdm07moO`2>SXh0T92@06=SH`1XJ6P0VYZJ08J6QP1>CTh0B4Q804M7A`0k>c/0@D5106UYJ@1o
Ogl0[jn_09nOW`1`L700MWIf059BDP1:BTX09RHV02LW9`0d=3@0JFUY04Q8B01?Cdl0EUIF02d];@0Z
:RX092@T02/[:`11@D40KVi^09nOW`2RXZ80]KFe0;no_`2SXj<0Ogmo04m?C`1;Bd/0CTi>06e]K@20
P800YjNW0:ZZZP2m_Kd0/k>c08f=S@2PX:00WIfM04Q8B013@d<0EeMG09fMW@2HV9P0Rh^;09BDU02m
_Kd0cLg=09jNWP24Q8@0?Cdm03`l?00a<C4203Lg=`0K04e=C@1CDe<0D51@034a<@1mOGd0=cLg02@T
901CDe<0ADE506e]K@2WYjL0M7Ad08R8R01VIVH0QXJ60:b/[030`<00/;2`09ZJVP28R8P0/;2`0:f]
[@2HV9P0NWYj04=3@`15ADD0P82001Cooooo000Cooooo`1O09:BTP1_Kfl0PX:205MGE`1nOWh0>3Ph
06MWI`1nOWh0Bd];05MGE`1oOgl0BDU905mOG`1aLG40E5AD06MWI`1FEUH0IVIV06m_K`1?Cdl0Kfm_
06IVIP16ATH0OWin06QXJ01:BTX0OGem065QH@1:BTX0Fe]K06e]K@1DE5@0IVIV06=SH`1aLG40MWIf
06QXJ01LG5`0K6a/069RHP1CDe<0O7al059BDP1UIFD0I6AT05iNGP1XJ6P0EUIF05]KF`1UIFD0?Shn
05UIF@1nOWh0@T9206UYJ@26QXH0>SXj05iNGP2FUYH0ADE5065QH@1lO7`0ADE507MgM`1oOgl0GemO
08n?S`1lO7`0LG5a09RHV02;Rh/0HV9R06IVIP29RHT0LW9b05YJFP1OGel0QXJ606EUI@1IFET0MgMg
07EeM@1MGEd0NWYj07inOP1KFe/0ZJVY06UYJ@1ZJVX0Zj^[05ADE01]KFd0Zj^[05]KF`27QhL00P1o
Ogl0:P2>SXh0MWIf07UiN@1iNGT0HV9R07]kN`24Q8@0KVi^092@T01MGEd0IfMW09FEU@0o?cl0Ng]k
06ATI01?Cdl0HV9R0:NWY`3EeMD0QHF506QXJ01_Kfl0GUiN07QhN01aLG40IVIV092@T01KFe/0FUYJ
06e]K@1OGel0EEEE07MgM`23Ph<0J6QX051@D01EEED0JVYZ07emO@1LG5`0FUYJ06MWI`kooooo03@0
Cdm?06IVIP1VIVH0MWIf05ADE01KFe/0I6AT05]KF`1NGUh0J6QX04U9B@1>CTh0EeMG04=3@`1BDU80
FEUI06UYJ@1eMGD0Hf=S03lo?`0b<S80GEeM051@D00o?cl0J6QX05iNGP1@D500EEEE05aLG01;Bd/0
EeMG05EEE@1RHV80EEEE06e]K@1OGel0Q8B407=cL`1lO7`0HV9R08j>SP1aLG40De=C05MGE`13@d<0
Bd];03lo?`1CDe<0@d=304M7A`1BDU80?Cdm0P15ADD0=P1GEeL0Bd];06ATI01?Cdl0Lg=c05YJFP1=
CDd0EUIF03`l?01SHf<0LW9b06UYJ@1ZJVX0Hf=S06e]K@1OGel0H61P06ATI019BDT0EeMG07]kN`1U
IFD0EUIF04m?C`1JFUX0IFEU05YJFP1EEED0Lg=c05UIF@1OGel0A4A4065QH@1gMgL0EEEE05ADE01S
Hf<0J6QX05aLG016ATH0FEUI05ADE01bLW80HV9R05]KF`1IFET0N7Qh05iNGP1ADE40GEeM079bLP1J
FUX0Lg=c07alO080K6a/01h0PX:203dm?@1/K6`0IFEU07YjNP1aLG40LW9b075aL@2;Rh/0Q8B407Ui
N@1bLW80YjNW08j>SP1aLG40Q8B406][J`2>SXh0[jn_09RHV024Q8@0];Bd06UYJ@1LG5`0HV9R06][
J`1NGUh0G5aL08:2PP2_[jl>ooooo`0L0;Fe]@25QHD0FEUI04e=C@0m?Cd0ATI603<c<`0a<C40?clo
034a<@0^;Rh0:BTY02h^;P1SHf<0NGUi02d];@18B4P0@41003Hf=P1:BTX0@T9208b<S00c<c<0HF5Q
05ADE00g=cL0?3`l03Xj>P80De=C06h0>SXj04Y:BP15ADD0@T9203/k>`0o?cl0D51@055AD@17AdL0
Q8B405EEE@18B4P0GUiN05IFEP1DE5@0FEUI09NGU`1EEED0FUYJ055AD@1@D500EEEE06MWI`1ADE40
GEeM06ATI015ADD0GEeM05mOG`1DE5@0GemO05eMG@1JFUX0G5aL07IfMP1>CTh0IFEU04I6AP1HF5P0
VIVI04m?C`1aLG40GEeM069RHP1[Jf/0GEeM07QhN025QHD0SHf=0;2`/01LG5`0KVi^07=cL`1aLG40
];Bd07MgM`1IFET0F5QH05UIF@1dM7@0G5aL05YJFP1SHf<0Q8B404M7A`27QhL0B4Q8030`<02@T900
M7Ad05YJFP1FEUH0Lg=c055AD@1XJ6P0EEEE07]kN`1RHV80Hf=S0492@P1YJFT0Fe]K04a<C01jNWX0
JFUY05=CD`1;Bd/0E5AD04a<C01iNGT0>SXj04e=C@1NGUh0Hf=S05EEE@19BDT0MGEe03Ph>00l?3`0
K6a/04i>CP1dM7@0IFEU06e]K@18B4P0EeMG05]KF`1:BTX0H61P0492@Pkooooo0280>c/k06EUI@1d
M7@0[Jf]0:n_[`2MWId0IfMW04E5A@17AdL0E5AD0:ZZZP23Ph<0L71`05YJFP0g=cL0EEEE03@d=00/
;2`0PX:204U9B@18B4P0EUIF02l_;`0S8b<0KVi^0:n_[`2DU9@0Xj>S06a/K018B4P0=CDe01TI6@0G
5aL0=SHf0P0F5QH01P0Q8B40IfMW06UYJ@1mOGd0HF5Q038b<P80<C4a0600De=C06UYJ@1mOGd0G5aL
05ADE00k>c/0HV9R03`l?01QHF40MgMg06YZJP2JVYX0SHf=04Q8B01kNg/0EEEE08:2PP2MWId0?Cdm
03Lg=`12@T80@410055AD@0[:b/09RHV06=SH`1hN7P0RXZ:06e]K@0];Bd0:RXZ02TY:@0l?3`0GUiN
0861P@1oOgl0T92@04];B`2`/;00UiNG02XZ:P0k>c/07alO03/k>`27QhL0Q8B409>CT`2^[Zh0D51@
07alO01`L700M7Ad07alO013@d<0Cdm?05IFEP2g]kL0SXj>075aL@2n_[h0`<3007YjNP1JFUX0QHF5
02d];@0a<C40=3@d03Lg=`1GEeL0MgMg05eMG@1OGel0T92@0:f][@24Q8@0BTY:06a/K012@T80HF5Q
08R8R02?Shl0KVi^0492@P10@400O7al09RHV02VYZH0ATI6034a<@1RHV80UIFE05iNGP1QHF40CDe=
03Lg=`1@D50Dooooo`004oooool06028R8P0Ogmo071`L01gMgL0Fe]K04E5A@1SHf<0E5AD05YJFP1L
G5`0PH6106][J`15ADD0KVi^06=SH`18B4P0EeMG07UiN@1>CTh0JVYZ05iNGP1BDU80F5QH07moO`80
DU9B0140J6QX055AD@1HF5P0CDe=069RHP1NGUh0G5aL06e]K@1SHf<0EUIF07QhN01@D500EeMG07Yj
NP19BDT0F5QH07]kN`0205IFEP0@092@T01HF5P0FEUI08j>SP1UIFD0Cdm?069RHP1^KVh0EUIF079b
LP1aLG40Fe]K069RHP1bLW80IfMW0820P080K6a/04`0O7al06][J`1nOWh0IVIV071`L024Q8@0FUYJ
07QhN020P800FUYJ07AdM02>SXh0F5QH07IfMP1hN7P0F5QH075aL@1_Kfl0IFEU07alO029RHT0K6a/
06UYJ@24Q8@0Lg=c071`L01nOWh0G5aL07YjNP2@T900MGEe07MgM`1fMWH0OGem06MWI`1CDe<0NGUi
07QhN01dM7@0KVi^07moO`1dM7@0MWIf061PH01aLG40PX:2065QH@1bLW80Hf=S07emO@14A4@0BTY:
05EEE@1ADE40N7Qh07moO`1DE5@0KFe]08j>SP1GEeL0Ogmo06e]K@1CDe<0LW9b06i^KP15ADD0Ogmo
06a/K01;Bd/0FUYJ05UIF@17AdL0Lg=c05MGE`18B4P0IfMW3_ooool06P1NGUh0JFUY06YZJP1iNGT0
C4a<05YJFP1XJ6P0Kfm_06EUI@1TI6@0Bd];04Q8B01ADE40@41005UIF@1OGel0IFEU06e]K@1OGel0
A4A402d];@1GEeL0De=C0451@@1^KVh0Cdm?0P1ADE40K01DE5@0CDe=05eMG@1FEUH0GemO06IVIP1k
Ng/0G5aL07EeM@1nOWh0Jf][06e]K@2UYJD0PH6105YJFP1PH600DE5A05QHF019BDT0GEeM04e=C@1>
CTh0E5AD04M7A`15ADD0@d=305mOG`1@D500IfMW04e=C@1MGEd0EEEE051@D01CDe<0?Shn06=SH`1_
Kfl0Lg=c075aL@1SHf<0Kfm_04];B`1FEUH0DE5A04E5A@1<C4`0Fe]K055AD@1FEUH0I6AT06MWI`1j
NWX0IVIV05aLG01cLg<0G5aL06QXJ01=CDd0GEeM06UYJ@1VIVH0GUiN06ATI01QHF40EeMG04Q8B01H
F5P0G5aL05mOG`1DE5@0Hf=S05EEE@1jNWX0Hf=S03lo?`1<C4`0CTi>05aLG01aLG40Y:BT06UYJ@1Q
HF40MWIf05ADE01[Jf/0JFUY07EeM@1nOWh0K6a/07EeM@2>SXh0IFEU07YjNP1aLG40UYJF09nOW`21
PH40N7Qh07=cL`2NWYh0_kno0:f][@2KVi/0[Jf]05UIF@1JFUX0K6a/07MgM`80GemO00<0Ph>30:6Q
XOooool03Oooool0<@2l_;`0Jf][06=SH`12@T80>CTi0492@P0k>c/0=cLg02PX:00a<C40;bl_01lO
7`0g=cL0BDU9075aL@0g=cL0?Cdm04I6AP0Y:BT0AdM702/[:`14A4@0EEEE051@D00l?3`0Cdm?03Ti
>@0e=CD0B4Q805YJFP0o?cl0DE5A05ADE01=CDd0>3Ph051@D01<C4`0@T9207EeM@25QHD0GEeM05mO
G`1HF5P0@T9206YZJP1gMgL0YJFU05YJFP1BDU800P1KFe/0>01LG5`0KFe]05UIF@1QHF40H61P05eM
G@1DE5@0H61P07=cL`1eMGD0Lg=c065QH@1_Kfl0Q8B404M7A`1/K6`0F5QH05YJFP2DU9@0F5QH079b
LP24Q8@0IfMW05EEE@1YJFT0N7Qh0820P01^KVh0^[Zj071`L02ZZZX0K6a/06MWI`2QXJ40JFUY05IF
EP1EEED0E5AD071`L01PH600IFEU06=SH`2EUID0D51@07YjNP1BDU80;2`/092@T01SHf<0NGUi05eM
G@1gMgL0CTi>06IVIP1`L700Lg=c0P1_Kfl07`0i>CT0IVIV05iNGP1SHf<0Q8B408>3P`1WIfL0GEeM
06=SH`1DE5@0Ph>304a<C01RHV80GEeM06YZJP1UIFD0FEUI079bLP15ADD0DU9B06QXJ01>CTh0LW9b
07YjNP1[Jf/0ADE504M7A`1PH600@T92061PH01KFe/03_ooool07P11@D40R8R80:ZZZP2XZ:P0YJFU
0:n_[`2>SXh0D51@05=CD`2YZJT0PX:20861P@2ATI40FEUI02LW9`0a<C40;bl_01XJ6P0_;bl0WinO
06YZJP1FEUH0H61P06i^KP2?Shl0_Kfm06UYJ@10@400GUiN05QHF080@D5100X0@410055AD@19BDT0
AdM704U9B@0n?Sh0GUiN0;^k^`24Q8@0?Shn0P0M7Ad0D@0k>c/0M7Ad06a/K014A4@0UIFE06m_K`21
PH40EUIF05mOG`1dM7@0T92@05iNGP14A4@0=SHf09JFUP19BDT0?clo08R8R01:BTX0:BTY03/k>`0j
>SX0<c<c05eMG@1kNg/0Q8B40:VYZ@1cLg<0M7Ad075aL@1iNGT0Cdm?0861P@1KFe/0E5AD08V9R@2g
]kL0W9bL0;Zj^P0^;Rh07QhN0410@00M7Ad0Bd];04Q8B01nOWh0K6a/0:RXZ01`L700NGUi08^;R`2d
];@0I6AT03@d=01?Cdl0JVYZ07IfMP1`L700YjNW0;Vi^@1FEUH0<S8b05YJFP1KFe/0MGEe02l_;`14
A4@0Fe]K08Z:RP2g]kL0/K6a0:2PX01GEeL0I6AT05QHF025QHD0RXZ:09:BTP2UYJD0Y:BT09fMW@02
04Q8B00=06][J`2IVIT0OWin03lo?`0f=SH0:BTY061PH01>CTh0ATI604];B`1=CDd0IVIV03`l?00D
ooooo`004oooool01P29RHT0Kfm_07AdM01lO7`0AdM7065QH@80HV9R00l0JVYZ04Y:BP1hN7P0LG5a
04=3@`23Ph<0IFEU04Q8B01RHV80JVYZ04A4A01cLg<0DU9B05EEE@1CDe<00P1YJFT0CP13@d<0HF5Q
05=CD`1<C4`0HF5Q061PH00g=cL0OWin079bLP19BDT0IFEU0:FUY@12@T80GEeM08f=S@11@D40GemO
06MWI`18B4P0LW9b06MWI`1DE5@0Kfm_05UIF@1BDU80NWYj04Y:BP1HF5P0FUYJ04e=C@1MGEd0DE5A
04e=C@1lO7`0EUIF059BDP1bLW80Hf=S05QHF026QXH0JVYZ05EEE@27QhL0LW9b04Y:BP2IVIT0JFUY
05]KF`2MWId0IFEU065QH@24Q8@0FEUI065QH@1fMWH0G5aL06m_K`1bLW80IVIV06e]K@1VIVH0Hf=S
07QhN01KFe/0JFUY07=cL`1aLG40TY:B096AT@1QHF40XJ6Q092@T01SHf<0Rh^;05YJFP1bLW80VYZJ
055AD@80QHF500T0IVIV06a/K01OGel0Rh^;07UiN@1>CTh0LG5a07emO@11@D400P1iNGT02017AdL0
O7al07MgM`1@D500M7Ad06m_K`1GEeL0SXj>0P1IFET03@24Q8@0AdM704m?C`1eMGD0E5AD061PH01W
IfL0EeMG05iNGP1dM7@0E5AD05UIF@1ZJVX03_ooool05@1DE5@0K6a/06YZJP1nOWh0@d=305aLG01`
L700PH6106a/K01YJFT0ATI603dm?@1:BTX0@d=305iNGP1EEED0Hf=S071`L01SHf<0@D5103/k>`02
05EEE@0T0410@01eMGD0CDe=051@D01JFUX0F5QH059BDP1PH600EeMG05mOG`1XJ6P0P82007MgM`1V
IVH0P82006ATI01ZJVX0[jn_08R8R01SHf<0J6QX05YJFP1RHV80DU9B06=SH`1KFe/0HF5Q05QHF01E
EED0BTY:04U9B@1YJFT0F5QH06EUI@1bLW80GUiN0P1FEUH0C`1LG5`0C4a<06=SH`21PH40Rh^;08B4
Q029RHT0K6a/055AD@1BDU80C4a<04Y:BP1DE5@0LG5a05=CD`1ADE40GUiN05MGE`24Q8@0GUiN05=C
D`1TI6@0FEUI07EeM@1=CDd0DE5A07EeM@2?Shl0DU9B071`L01FEUH0EEEE04i>CP1/K6`0FEUI05YJ
FP1BDU80Hf=S05iNGP1RHV80JVYZ03/k>`16ATH0DU9B04I6AP1YJFT0KVi^05IFEP1DE5@0IfMW06EU
I@22PX80IVIV06a/K01_Kfl0HV9R071`L02CTi<0P82007alO01dM7@0N7Qh09VIV@2EUID0K6a/0861
P@2_[jl0/K6a0::RXP2l_;`0WYjN05]KF`1@D500IfMW06i^KP1GEeL0Fe]K08b<S02JVYX03_ooool0
N`2CTi<0IfMW08j>SP16ATH0@T92051@D00o?cl0<C4a02/[:`0O7al0;Rh^030`<00h>3P0CDe=06][
J`0^;Rh0?Shn04M7A`0e=CD0B4Q805mOG`0k>c/0IfMW05QHF00o?cl0Fe]K02h^;P0_;bl0HV9R05MG
E`0g=cL0GEeM055AD@1@D500?Shn055AD@1MGEd0?Cdm06i^KP1IFET0IfMW05IFEP15ADD0FEUI06YZ
JP1GEeL0Vi^K05ADE01;Bd/0EUIF04m?C`1<C4`0JFUY04a<C01NGUh0B4Q804a<C01MGEd0A4A404i>
CP1DE5@0De=C06i^KP1BDU80L71`04Q8B01WIfL0EeMG075aL@2>SXh0CTi>07YjNP29RHT0FEUI06MW
I`1VIVH0KVi^06IVIP1TI6@0SXj>09RHV02^[Zh0JFUY07UiN@2GUiL0H61P069RHP1OGel0=CDe071`
L01ZJVX0EeMG065QH@1gMgL0EEEE08N7Q`1HF5P09bLW08N7Q`1=CDd0JVYZ05IFEP1]KFd0AdM705iN
GP1CDe<0Lg=c075aL@24Q8@0=CDe06m_K`1@D500GEeM0820P01mOGd0EUIF05aLG01QHF40B4Q807Yj
NP1=CDd0JVYZ04i>CP0206UYJ@0?03lo?`1SHf<0ATI605eMG@1VIVH0A4A407emO@1eMGD0Fe]K05aL
G00[:b/0HF5Q04Y:BP1^KVh0I6AT00kooooo00T0DU9B061PH02FUYH0Ti>C071`L02HV9P0W9bL04A4
A00g=cL00P2[Zj/0P@2`/;00IfMW06IVIP1EEED0ADE508b<S017AdL0UIFE07QhN01dM7@0Y:BT09BD
U00d=3@0=cLg08Z:RP1XJ6P0EUIF03Xj>P0h>3P0Hf=S06i^KP1@D500HF5Q04U9B@17AdL0A4A404Y:
BP1XJ6P0RHV905IFEP15ADD0OWin04];B`0e=CD0?Shn0:2PX02=SHd0ATI606IVIP2JVYX0HV9R05EE
E@0k>c/0Xj>S09:BTP0g=cL0EeMG08F5Q@20P800G5aL0:6QX@1UIFD0F5QH06UYJ@2<S8`0KVi^092@
T02KVi/0@T9208j>SP2OWil0TI6A09VIV@2YZJT0[jn_0=CDe021PH40Q8B409:BTP1hN7P0Y:BT0<c<
c01dM7@0CDe=09JFUP1WIfL0TY:B07emO@1bLW80DE5A0:f][@22PX80Ph>308B4Q02j^[X0NGUi04I6
AP1jNWX0<c<c01dM7@0[:b/0?Cdm0861P@23Ph<0LG5a06ATI01QHF40YJFU0820P02PX:00`/;20<K6
aP1jNWX0NGUi03Lg=`0l?3`0>CTi0492@P0c<c<0QHF50<G5a@2o_kl0/k>c09fMW@1WIfL0Jf][0:>S
X`1]KFd0FUYJ02/[:`0e=CD0;Rh^05QHF00g=cL0CDe=06MWI`1mOGd0Zj^[08N7Q`0Dooooo`004ooo
ool0R`24Q8@0N7Qh06YZJP1LG5`0Hf=S03Lg=`1RHV80L71`03dm?@1^KVh0SHf=04Y:BP1dM7@0Kfm_
071`L01DE5@0B4Q806ATI01LG5`0C4a<07YjNP1CDe<0>SXj08J6QP1MGEd0CDe=07QhN012@T80E5AD
07=cL`1CDe<0DE5A07inOP1]KFd0G5aL05eMG@1NGUh0J6QX05iNGP1ZJVX0EUIF069RHP1TI6@0UiNG
04=3@`1kNg/0PH61059BDP1WIfL0L71`04E5A@1VIVH0KFe]03dm?@1PH600SHf=04M7A`1lO7`0Ti>C
04];B`2<S8`0NGUi069RHP29RHT0Jf][069RHP1hN7P0Hf=S07inOP1RHV80Q8B407UiN@1^KVh0OGem
06m_K`1/K6`0NWYj08V9R@1DE5@0Hf=S0820P01/K6`0JVYZ08j>SP1bLW80Hf=S09JFUP1WIfL0O7al
08F5Q@1CDe<0MWIf09RHV01jNWX0QXJ607]kN`21PH40PX:2059BDP2ATI40QHF505YJFP1`L700P820
069RHP1hN7P0DE5A05mOG`2BTY80CDe=06m_K`1DE5@0MgMg06][J`1FEUH0QHF506ATI01OGel0TI6A
04];B`1JFUX0XJ6Q05=CD`1hN7P0P82006ATI01iNGT0OGem061PH01fMWH0KFe]04I6AP1ADE40I6AT
05aLG01UIFD0I6AT04I6AP1IFET03_ooool0>P1DE5@0HF5Q05UIF@1NGUh0AdM704m?C`15ADD0J6QX
06e]K@1NGUh0AdM70410@014A4@0@410061PH01FEUH0HF5Q06e]K@1VIVH0@d=3038b<P1NGUh0EEEE
04A4A024Q8@0HV9R05mOG`1PH600GUiN05IFEP1UIFD0DU9B05ADE01YJFT0Ng]k07MgM`1kNg/0Lg=c
08V9R@1MGEd0WIfM08f=S@1QHF40Kfm_05YJFP1LG5`0Cdm?06EUI@1BDU80EEEE04m?C`1<C4`0CDe=
04U9B@1JFUX0F5QH05mOG`1JFUX205IFEP80G5aL01/0I6AT06][J`26QXH0ZJVY09>CT`20P800O7al
04U9B@1FEUH0E5AD04E5A@1HF5P0NGUi06MWI`1HF5P0DU9B06EUI@1lO7`0L71`05UIF@1^KVh0Hf=S
07QhN018B4P0FUYJ05eMG@21PH400P1FEUH02`1DE5@0EeMG0410@01WIfL0FUYJ05mOG`1QHF40IfMW
05IFEP1hN7P0GUiN0080BDU902@0CTi>05=CD`1SHf<0HV9R05=CD`1NGUh0J6QX06UYJ@20P800J6QX
06UYJ@1VIVH0EEEE06IVIP25QHD0M7Ad05QHF01^KVh0Fe]K09FEU@2<S8`0M7Ad075aL@2IVIT0]kNg
09fMW@2d];@0[:b/06e]K@1<C4`0I6AT065QH@1FEUH0H61P071`L025QHD>ooooo`0P09:BTP1LG5`0
LW9b04=3@`0a<C40@d=303/k>`16ATH0@T920451@@0/;2`0:b/[03Lg=`1:BTX0GEeM03dm?@0b<S80
=3@d030`<018B4P0ADE502PX:01>CTh0De=C03lo?`1IFET0>CTi034a<@15ADD0FEUI059BDP1LG5`2
04Y:BP0g02LW9`1?Cdl0DE5A02l_;`24Q8@0LW9b05aLG019BDT0ADE50410@01MGEd0K6a/0:VYZ@1L
G5`0D51@061PH01HF5P0MGEe075aL@1]KFd0Jf][055AD@1OGel0Cdm?04Y:BP1MGEd0GemO065QH@1]
KFd0GUiN06][J`13@d<0U9BD05EEE@1UIFD0TI6A055AD@1`L700N7Qh05MGE`1ZJVX0K6a/08N7Q`1`
L700Fe]K07UiN@2/[:`0emOG06UYJ@2WYjL0WinO061PH01aLG40Hf=S03Lg=`0207EeM@0J075aL@1S
Hf<0EeMG06a/K01iNGT0EUIF034a<@29RHT0G5aL06EUI@1?Cdl0H61P04=3@`1/K6`0IVIV06][J`1E
EED0M7Ad03Lg=`1IFET0BTY:06=SH`1kNg/0DE5A05ADE01HF5P2061PH00E07IfMP1;Bd/0NWYj061P
H01cLg<0Kfm_04I6AP1hN7P0=cLg03lo?`1NGUh0BTY:06e]K@2BTY80KFe]06QXJ00R8R80MgMg04];
B`1mOGd0PX:200kooooo02h0BTY:079bLP1hN7P0DU9B038b<P1LG5`0_[jn03Xj>P0Y:BT0ZJVY0=KF
eP21PH40@d=3051@D01<C4`0?clo06QXJ02=SHd0EEEE04e=C@1IFET0Kfm_08J6QP0e=CD0>SXj07=c
L`1:BTX0P82004Q8B00];Bd0@T9207emO@1`L700M7Ad02`/;00N7Qh08B4Q02`/;015ADD0Q8B4051@
D00b<S80Hf=S03@d=00Q8B40AdM70P1YJFT0B`1QHF40OWin05QHF01;Bd/0De=C07emO@2VYZH0Lg=c
08N7Q`18B4P0:BTY071`L02<S8`0EeMG06i^KP1oOgl0JVYZ0<?3``2j^[X0QhN708R8R02ATI40f=SH
03De=@0];Bd0L71`06m_K`1GEeL0V9RH0;Ng]`2_[jl0BDU906YZJP2a/K40][Jf0:ZZZP2g]kL0ADE5
02XZ:P1RHV80TI6A07moO`1VIVH0J6QX05ADE01cLg<0UYJF0:VYZ@1bLW809bLW04e=C@0Q8B409BDU
024Q8@0X:2P0ZZZZ0=7Ad@2VYZH0CTi>05eMG@2BTY80IfMW0<G5a@2k^k/0UiNG0492@P1PH600A4A4
03lo?`1kNg/0Xj>S0:f][@2n_[h0QhN706MWI`0205eMG@0?07UiN@2][Jd0_;bl05]KF`0l?3`0@410
034a<@0c<c<0TI6A05IFEP1?Cdl0a/K60;Vi^@2PX:00[Zj^01Cooooo000Cooooo`0h08V9R@1kNg/0
Lg=c08>3P`1NGUh0ADE506MWI`1?Cdl0GUiN05eMG@1ZJVX0I6AT04=3@`1XJ6P0IfMW0451@@1EEED0
Kfm_05=CD`1GEeL0LW9b05eMG@19BDT0M7Ad05IFEP1CDe<0MGEe055AD@1GEeL0D51@05ADE01GEeL0
Bd];05mOG`1MGEd0E5AD07moO`1;Bd/0I6AT075aL@1CDe<0IVIV06YZJP1]KFd0HF5Q061PH01NGUh0
Jf][06ATI01QHF40Cdm?061PH01XJ6P0D51@05aLG01hN7P2059BDP0W06m_K`1EEED0KFe]06i^KP1N
GUh0N7Qh06i^KP1dM7@0CTi>07UiN@1aLG40A4A408N7Q`1/K6`0CTi>09>CT`1hN7P0DE5A07=cL`1^
KVh0GUiN06IVIP1fMWH0FUYJ07]kN`1cLg<0K6a/07UiN@1aLG40Kfm_07EeM@26QXH0Jf][07inOP1Z
JVX0Shn?0861P@1NGUh0Xj>S0080JVYZ02P0Ng]k06IVIP2>SXh0HF5Q07UiN@23Ph<0GEeM06a/K01n
OWh0PH6107=cL`1bLW80K6a/08J6QP1]KFd0MgMg07YjNP1IFET0LW9b07UiN@1<C4`0Kfm_08>3P`1:
BTX0Lg=c06][J`14A4@0WYjN06a/K01;Bd/0OGem06MWI`17AdL0HV9R07alO01LG5`0I6AT05MGE`1:
BTX0HV9R3_ooool02P1>CTh0IVIV065QH@1dM7@0A4A405EEE@1IFET0Hf=S06EUI@1RHV8204=3@`1C
04Y:BP11@D40GEeM05mOG`1YJFT0Lg=c06YZJP1;Bd/0@T9206QXJ01GEeL0=CDe06e]K@1=CDd0CTi>
04e=C@1@D500EUIF05eMG@1DE5@0FUYJ06e]K@1WIfL0L71`075aL@1YJFT0Fe]K061PH02:RXX0O7al
05QHF01PH600EUIF05YJFP1BDU80CDe=059BDP19BDT0CDe=04m?C`1DE5@0Bd];069RHP1LG5`0GEeM
05IFEP1LG5`0GemO05YJFP1PH600De=C04Y:BP1WIfL0V9RH08Z:RP1lO7`0K6a/059BDP1RHV80EUIF
0492@P15ADD0KVi^069RHP1<C4`0FEUI05QHF022PX80J6QX065QH@1gMgL0IVIV07QhN01DE5@0Fe]K
06a/K01PH600GemO05QHF01EEED0FEUI04I6AP1lO7`00P1QHF40:`1=CDd0J6QX04Y:BP1JFUX0Ng]k
04i>CP1<C4`0BTY:05IFEP1UIFD0E5AD05EEE@1KFe/0L71`06e]K@1kNg/0J6QX05mOG`1IFET0De=C
06YZJP1oOgl0OGem06ATI01VIVH0GEeM08b<S029RHT0P82007EeM@2LW9`0][Jf09NGU`2PX:00Rh^;
07AdM01MGEd0IfMW07IfMP1NGUh0HF5Q06m_K`2<S8`03_ooool0<@2;Rh/0F5QH08V9R@0l?3`0ATI6
0451@@12@T80?Shn03Hf=P0o?cl07AdM02/[:`0_;bl0FEUI06YZJP1BDU80<S8b030`<00h>3P0D51@
03Hf=P15ADD0GEeM059BDP16ATH0JVYZ03@d=00g=cL0FUYJ05aLG01MGEd0J6QX03De=@1KFe/0@T92
05ADE01IFET0BTY:0861P@1CDe<0Kfm_04M7A`0o?cl0GUiN061PH01OGel0ZJVY05mOG`1FEUH00P1?
Cdl0201WIfL0DE5A05UIF@1GEeL0GUiN06a/K01>CTh0GemO0P1NGUh04@1PH600Jf][05YJFP1WIfL0
BTY:08N7Q`19BDT0J6QX092@T01HF5P0IFEU08f=S@1CDe<0IFEU075aL@1fMWH0KFe]0080Jf][01P0
h>3P0>?Sh`1dM7@0QXJ6096AT@1YJFT0MGEe05ADE00k>c/0FEUI07=cL`1ADE40EeMG05YJFP1`L700
M7Ad05UIF@0d=3@0Q8B405aLG01^KVh0Hf=S07AdM01>CTh3065QH@0Q06][J`2BTY80>SXj06i^KP1@
D500DE5A08R8R01CDe<0FEUI061PH01/K6`0DU9B08:2PP1=CDd0LG5a05]KF`28R8P0K6a/04=3@`1T
I6@0Cdm?051@D01]KFd0Jf][06a/K02>SXh0N7Qh07EeM@0c<c<0M7Ad04a<C01]KFd0Jf][00kooooo
08`0GEeM04e=C@1TI6@0IfMW07EeM@1aLG40IfMW08:2PP2a/K40^k^k079bLP1kNg/0IFEU03Xj>P15
ADD0Hf=S051@D011@D40Cdm?07AdM01OGel0Bd];07IfMP0S8b<0=SHf06a/K00n?Sh0GEeM09^KV`1X
J6P0OGem08Z:RP1<C4`0=CDe092@T01VIVH0GUiN06YZJP2BTY80a<C407YjNP19BDT0@d=3069RHP0R
8R80FEUI03dm?@24Q8@0SHf=06a/K012@T80@41002l_;`0`<300HV9R04a<C01ZJVX0OGem0:VYZ@24
Q8@0KFe]059BDP19BDT0XZ:R07AdM022PX80Z:RX0;6a/@29RHT0UiNG06YZJP1SHf<0=cLg04=3@`1O
Gel09bLW03<c<`1MGEd0Z:RX075aL@13@d<0<C4a08j>SP2MWId0VYZJ06][J`2DU9@0IVIV07YjNP1_
Kfl0Rh^;05ADE012@T80FEUI08:2PP20P800WinO08R8R00c<c<07QhN01dM7@0[:b/0OGem0:j^[P2;
Rh/0VYZJ0;2`/02NWYh0aLG50;Fe]@2m_Kd0Z:RX08^;R`19BDT0A4A4096AT@1^KVh0IVIV08n?S`2m
_Kd0WIfM02/[:`0S8b<092@T03Lg=`1DE5@0NGUi07IfMP1_Kfl0?Shn07]kN`2DU9@0Shn?07alO02C
Ti<0^[Zj0:b/[036a/H0YJFU08J6QQCooooo000Cooooo`1707emO@1cLg<0Lg=c08^;R`1PH600JFUY
05EEE@1CDe<0Hf=S04I6AP1_Kfl0KVi^05IFEP29RHT0EUIF05aLG01SHf<0CTi>06a/K01PH600DU9B
061PH01GEeL0F5QH07=cL`0g=cL0C4a<06a/K00m?Cd0ADE507MgM`0a<C40GEeM09JFUP0h>3P0G5aL
09BDU00Z:RX0MGEe061PH00g=cL0M7Ad05QHF01DE5@0LG5a06a/K011@D40N7Qh04U9B@1<C4`0MGEe
05aLG01ZJVX0C4a<04];B`1nOWh0LG5a05eMG@2<S8`0GUiN07MgM`26QXH0Jf][06UYJ@2LW9`0LG5a
05]KF`1oOgl0HV9R059BDP2BTY800P1QHF401020P800Ng]k07]kN`29RHT206EUI@0306=SH`1YJFT0
OGem0080GUiN03L0QhN705aLG025QHD0OGem0492@P1nOWh0QHF507=cL`1kNg/0WYjN05YJFP1fMWH0
SXj>07]kN`1`L700IFEU07MgM`1]KFd0A4A408n?S`1aLG40JVYZ07MgM`1`L700XZ:R05ADE01XJ6P0
Jf][07YjNP1EEED0O7al07YjNP1FEUH0LW9b06UYJ@16ATH0K6a/065QH@1DE5@0QXJ605EEE@1NGUh0
RHV905eMG@1RHV80H61P05]KF`1]KFd0C4a<04E5A@1_Kfl0HF5Q03De=@1KFe/0Ogmo00kooooo01D0
G5aL07AdM01YJFT0KFe]05=CD`1KFe/0HF5Q06a/K01fMWH0GEeM04I6AP1<C4`0Cdm?0492@P1UIFD0
FEUI05mOG`1WIfL0J6QX03Ph>00k>c/00P1IFET0B00j>SX0H61P04Y:BP1;Bd/0Cdm?055AD@18B4P0
GEeM04m?C`1<C4`0I6AT06e]K@1KFe/0MgMg05iNGP1CDe<0HF5Q07moO`1eMGD0De=C05aLG017AdL0
DE5A04=3@`18B4P0F5QH05ADE01JFUX0Cdm?051@D01:BTX0FUYJ05iNGP1LG5`0De=C05aLG01KFe/0
Kfm_05aLG01:BTX0@T9206ATI02:RXX0P82007inOP25QHD0DU9B06IVIP1GEeL0CDe=03dm?@1/K6`0
Hf=S04M7A`1CDe<0EEEE096AT@1PH600HV9R05mOG`1MGEd0G5aL04E5A@1FEUH0HF5Q04];B`1BDU80
Kfm_05YJFP1GEeL0CDe=075aL@80I6AT01/0G5aL05mOG`14A4@0I6AT07UiN@1EEED0AdM703/k>`1=
CDd0GUiN05EEE@1=CDd0F5QH06e]K@1EEED0IFEU069RHP1KFe/0FEUI04i>CP1RHV80PX:206i^KP1Z
JVX0EEEE05iNGP25QHD00P1YJFT03P1LG5`0QHF509^KV`2;Rh/0NWYj09RHV01LG5`0ATI605UIF@1R
HV80DU9B061PH01XJ6P0QXJ63_ooool03`1MGEd0EeMG07emO@0j>SX0BDU903hn?P11@D40@d=303dm
?@0k>c/06a/K02l_;`0/;2`0Cdm?051@D0020492@P1k02h^;P0b<S80@410020P8017AdL0B4Q8069R
HP1<C4`0GEeM02l_;`0n?Sh0BTY:04];B`1]KFd0GUiN02l_;`1SHf<0@d=305iNGP1KFe/0>3Ph07Yj
NP1?Cdl0MgMg0492@P0c<c<0G5aL03`l?01SHf<0UiNG061PH018B4P0EEEE04A4A01iNGT0?3`l04M7
A`1RHV80BTY:06][J`15ADD0C4a<069RHP1YJFT0F5QH069RHP1CDe<0KVi^04Q8B01^KVh0Cdm?071`
L01cLg<0IVIV06i^KP22PX80D51@06][J`1`L700IfMW06e]K@1NGUh0@d=30<;2`P2ATI40HF5Q0::R
XP2PX:00KFe]08f=S@1IFET0C4a<06=SH`25QHD0JFUY06QXJ01=CDd0Shn?06YZJP1QHF40>CTi08J6
QP1]KFd0H61P05ADE01mOGd0DU9B04=3@`1hN7P0F5QH04Q8B024Q8@0ADE505iNGP1FEUH0IFEU07em
O@1JFUX0H61P04e=C@19BDT0IfMW06i^KP0h>3P0JVYZ06UYJ@23Ph<0KVi^03`l?01bLW80?3`l04Q8
B01VIVH0EeMG05iNGP2>SXh0I6AT06IVIP0a<C40L71`034a<@1FEUH0MgMg00kooooo00X0FEUI05MG
E`1HF5P0GUiN08N7Q`1[Jf/0HF5Q09NGU`3@d=00Kfm_0P0W9bL0K@0];Bd0H61P04A4A01=CDd071`L
01dM7@0_;bl0KFe]05ADE00l?3`0E5AD0;>c/`2LW9`0WYjN079bLP1BDU809bLW01/K6`0L71`0FUYJ
051@D00e=CD0De=C09NGU`0Z:RX0:BTY02d];@14A4@0XJ6Q08N7Q`1ZJVX0YjNW08B4Q02YZJT0HV9R
06YZJP1oOgl0F5QH04M7A`0i>CT0:2PX02TY:@16ATH0C4a<02DU9@0c<c<0Jf][030`<01dM7@0ZJVY
09NGU`2IVIT0NWYj02d];@26QXH0NWYj04=3@`1ADE40L71`030`<01/K6`0EeMG07EeM@0c<c<0@T92
04e=C@1lO7`0=CDe02LW9`0T92@0RHV90;fm_@2[Zj/0ZZZZ0<K6aP20P800EEEE08B4Q00m?Cd0BDU9
07AdM02WYjL0CTi>079bLP21PH40YZJV08^;R`0V9RH0@d=309bLW02BTY80QhN70:>SX`19BDT0<c<c
06IVIP3Jf]X0];Bd06a/K019BDT0MgMg06UYJ@13@d<0IfMW028R8P0^;Rh0F5QH0<O7a`1nOWh00P0N
7Qh04@0O7al09RHV03Ph>01@D500Ogmo0<C4a02o_kl0W9bL09fMW@2EUID0UYJF096AT@2k^k/0`l?3
0:VYZ@2f][H0OGem01Cooooo000Cooooo`2;0861P@1dM7@0Kfm_05]KF`2;Rh/0?clo06YZJP1eMGD0
D51@08B4Q01fMWH0Fe]K06YZJP1VIVH0PH6104m?C`1FEUH0Ng]k05YJFP1HF5P0OGem05=CD`1@D500
QXJ605eMG@1JFUX0PH6105ADE01FEUH0F5QH04Q8B01NGUh0B4Q804m?C`1VIVH0@41006MWI`1@D500
IFEU05aLG01BDU80H61P07AdM01bLW80D51@05iNGP1oOgl0CDe=05ADE01cLg<0?3`l05EEE@1LG5`0
>c/k06EUI@28R8P0<C4a05YJFP1fMWH0C4a<08J6QP1/K6`0IVIV08:2PP1LG5`0LW9b06a/K01MGEd0
TY:B05YJFP1aLG40O7al069RHP1aLG40QHF5069RHP1[Jf/0Q8B4059BDP1GEeL0Q8B405ADE01LG5`0
SHf=065QH@1RHV80UiNG05IFEP1cLg<0M7Ad04e=C@1fMWH0Jf][06IVIP2=SHd0AdM707QhN01jNWX0
ADE508Z:RP1_Kfl0K6a/08B4Q01`L700KFe]071`L01JFUX0J6QX09BDU01DE5@0N7Qh05IFEP1eMGD0
Jf][07YjNP2CTi<0HF5Q06QXJ02PX:00BTY:069RHP28R8P0FEUI07moO`29RHT0GUiN06UYJ@1_Kfl0
F5QH07MgM`21PH40C4a<06IVIP20P800Fe]K05mOG`1ZJVX0FUYJ069RHP0>ooooo`0A04M7A`1ZJVX0
IVIV079bLP1DE5@0H61P05eMG@1QHF40JFUY05aLG00l?3`0ATI60492@P0i>CT0Fe]K061PH01RHV80
0P1ZJVX01`1;Bd/0@410061PH01CDe<0ADE506QXJ016ATH00P1@D500801DE5@0C4a<05aLG01?Cdl0
FEUI06UYJ@1eMGD0IVIV07emO@1JFUX0BDU905aLG021PH40LG5a05]KF`1PH600D51@06EUI@1CDe<0
EUIF04e=C@1>CTh0De=C04a<C01JFUX0BDU905YJFP1TI6@0K6a/06IVIP1JFUX0DU9B0P1]KFd02P1S
Hf<0BDU906MWI`1KFe/0Ph>308:2PP1lO7`0Cdm?05mOG`1MGEd203`l?00906QXJ01^KVh0HV9R05QH
F01kNg/0];Bd07emO@1KFe/0Lg=c0080IFEU01@0Cdm?05QHF01aLG40EeMG055AD@1ZJVX0DU9B05AD
E01LG5`0H61P07MgM`1SHf<0H61P06UYJ@1>CTh0L71`07moO`1MGEd0DE5A04a<C080FUYJ0240D51@
05=CD`1GEeL0KFe]06a/K01SHf<0HF5Q06MWI`1aLG40FUYJ061PH01oOgl0OWin04E5A@1FEUH0HV9R
079bLP1mOGd0QHF506MWI`28R8P0Vi^K06i^KP1jNWX0S8b<06UYJ@1=CDd0IFEU05mOG`1CDe<0Hf=S
06i^KP28R8P03_ooool0S01SHf<0FUYJ08F5Q@0h>3P0AdM704A4A01=CDd0EeMG03lo?`0m?Cd09BDU
03<c<`0_;bl0E5AD05iNGP1WIfL0@D5103lo?`0e=CD0Cdm?034a<@0];Bd0CDe=06=SH`0k>c/0G5aL
03/k>`0d=3@0?clo04I6AP1ZJVX0CDe=03<c<`1BDU80CTi>05]KF`11@D40<30`0861P@1RHV80MWIf
05YJFP19BDT0De=C03De=@1jNWX0UiNG075aL@1VIVH0Cdm?05aLG01WIfL0BTY:06MWI`1ADE40Jf][
05iNGP1<C4`0JFUY05UIF@1/K6`0EeMG06YZJP1IFET0IFEU06m_K`1RHV80<S8b061PH027QhL0Kfm_
06UYJ@2ATI40D51@075aL@1XJ6P0RXZ:06MWI`2@T900K6a/0861P@1[Jf/0Lg=c07emO@1aLG40NWYj
08N7Q`1KFe/0ATI605YJFP24Q8@0EeMG06][J`1YJFT0S8b<06ATI01hN7P0Bd];079bLP1`L700Ogmo
07=cL`1lO7`0DU9B06UYJ@1^KVh0F5QH06=SH`20P800?3`l07moO`1MGEd0I6AT07moO`1[Jf/0GUiN
05MGE`1;Bd/0FEUI07EeM@1?Cdl0FEUI05eMG@2?Shl0MGEe04Q8B01ADE40GEeM06e]K@1UIFD0Kfm_
079bLP26QXH0JFUY08J6QP11@D40Hf=S03dm?@1WIfL0Hf=S3_ooool04@1?Cdl0<C4a01lO7`0J6QX0
7AdM07moO`2IVIT0NWYj096AT@2PX:00IFEU030`<00b<S80<C4a02TY:@0R8R806a/K00807AdM0140
=CDe03lo?`0g=cL0S8b<08R8R013@d<0C4a<07IfMP1FEUH0;2`/02DU9@0M7Ad0IfMW04E5A@1XJ6P0
=SHf06IVIP0201`L700X01dM7@0O7al0BTY:08Z:RP3Hf=P0M7Ad038b<P13@d<0Ng]k0:b/[02d];@0
?Cdm02<S8`0X:2P0ATI604E5A@2EUID0YjNW034a<@0V9RH0UiNG08R8R01OGel0Kfm_05EEE@1QHF40
LW9b05mOG`1ADE40GemO02`/;00b<S80O7al04I6AP1>CTh0TI6A09RHV01UIFD0Ng]k05EEE@80DE5A
01L0;Rh^03/k>`2[Zj/0QhN708>3P`2_[jl0^k^k0;Bd]020P800WYjN02h^;P0Z:RX0N7Qh0:FUY@32
`/80HV9R02<S8`2e]KD0];Bd092@T02f][H0XZ:R08>3P`0203Xj>P0P05QHF019BDT0NGUi0=CDe02H
V9P0CTi>04m?C`1EEED0OGem07UiN@1[Jf/0:b/[03<c<`2VYZH0/k>c07]kN`0i>CT0;Bd]02@T900Q
8B408R8R03Xj>P2ZZZX0aLG50<k>cP2[Zj/0UYJF07]kN`1SHf<0W9bL0:j^[P2IVIT20;Vi^@030<30
`?oooooooooo01;ooooo000Cooooo`1R08^;R`1hN7P0Ng]k0861P@1FEUH0MgMg06][J`1HF5P0QhN7
04m?C`25QHD0Lg=c03/k>`2:RXX0H61P05ADE01/K6`0FUYJ06MWI`1KFe/0F5QH05UIF@1BDU80FUYJ
06QXJ01>CTh0B4Q806=SH`19BDT0BTY:07QhN01ADE40CDe=08n?S`16ATH0AdM708n?S`0j>SX0BDU9
08>3P`0a<C40IfMW065QH@11@D40NWYj06UYJ@10@400L71`04i>CP1?Cdl0HV9R06a/K01WIfL0EeMG
05EEE@1eMGD0B4Q801lO7`1ZJVX0Jf][05mOG`1mOGd0LW9b07EeM@2JVYX0LG5a059BDP1mOGd0IfMW
051@D022PX80LG5a06ATI01hN7P0QXJ606IVIP21PH40NGUi065QH@1/K6`0LW9b071`L01JFUX0GUiN
07]kN`18B4P0KFe]07EeM@18B4P0MgMg07UiN@1KFe/0P8200861P@1?Cdl0Ph>3075aL@1IFET2071`
L080JFUY01H0@D5107QhN01oOgl0CTi>075aL@1PH600QHF5071`L01LG5`0SHf=071`L015ADD0TY:B
07UiN@1<C4`0KVi^06EUI@1HF5P0PH6107moO`1?Cdl0YjNW0P1OGel03@29RHT0DE5A065QH@1SHf<0
De=C05ADE01[Jf/0CTi>06MWI`1aLG40E5AD05eMG@2>SXh03_ooool0:P1GEeL0MWIf06IVIP1XJ6P0
EEEE06ATI01=CDd0IfMW05UIF@1TI6@0BTY:05aLG01CDe<0<c<c05mOG`1LG5`0H61P06i^KP1UIFD0
DU9B03/k>`1IFET0FUYJ055AD@1fMWH0EEEE05YJFP1OGel0G5aL04a<C01MGEd0DE5A05YJFP1LG5`0
KFe]05UIF@1bLW80I6AT05EEE@1DE5@0Rh^;079bLP80GUiN0600Bd];06QXJ017AdL0Fe]K04e=C@1C
De<0CDe=04U9B@1;Bd/0FUYJ06=SH`1UIFD0N7Qh06][J`1IFET0H61P05=CD`1fMWH0PX:207MgM`1c
Lg<0Ogmo08>3P`25QHD0MGEe05MGE`0i>CT0Cdm?03`l?00k>c/0IfMW06=SH`1>CTh0FEUI06IVIP2X
Z:P0K6a/05YJFP1RHV80DE5A06a/K01>CTh0D51@06IVIP1?Cdl0@T9206ATI01DE5@0Fe]K069RHP1D
E5@0IfMW05eMG@1PH600GUiN05=CD`1`L700MWIf065QH@1DE5@0>3Ph05UIF@1QHF40CDe=059BDP1E
EED0JVYZ06][J`1>CTh0H61P06a/K01ZJVX0Hf=S05eMG@1hN7P0K6a/04m?C`1EEED0CDe=05aLG01]
KFd0Ogmo06ATI02MWId0R8R807]kN`2JVYX0WIfM06e]K@1ADE40JVYZ061PH01BDU80G5aL06IVIP1f
MWH>ooooo`80DU9B00D0Hf=S034a<@0f=SH0=SHf02l_;`020492@P0B030`<00P8200@41002@T9015
ADD0Bd];05=CD`19BDT0>c/k03hn?P16ATH0;Rh^04Y:BP15ADD0K6a/06ATI018B4P0<30`0P0k>c/0
K`1=CDd0OWin051@D00a<C40GUiN04E5A@1bLW80C4a<04e=C@1/K6`0DE5A09>CT`10@400ATI605EE
E@0f=SH0KVi^08V9R@1mOGd0FEUI05aLG01JFUX0NGUi05IFEP1PH600GemO06=SH`1VIVH0BTY:04];
B`1TI6@0G5aL05MGE`1NGUh0De=C07moO`1PH600IVIV059BDP1YJFT0NGUi06=SH`20P800MgMg051@
D01YJFT0IVIV08j>SP1@D500MWIf05EEE@2?Shl0HF5Q06EUI@25QHD0MGEe06=SH`2?Shl0EeMG03@d
=01EEED0MgMg05iNGP1]KFd0?3`l08j>SP1HF5P0HF5Q05eMG@1kNg/0MGEe065QH@18B4P0O7al04U9
B@1ADE40M7Ad061PH01HF5P0TI6A05iNGP1VIVH0Fe]K07AdM01lO7`0H61P079bLP1;Bd/0A4A406MW
I`1RHV80Cdm?071`L01bLW80M7Ad07YjNP1/K6`0J6QX04M7A`1aLG40Kfm_06UYJ@1ZJVX0QXJ607If
MP20P800:BTY05MGE`0m?Cd0IFEU07MgM`0>ooooo`1o04U9B@0j>SX0>3Ph04U9B@1:BTX0E5AD09jN
WP2<S8`0P82004m?C`1TI6@0L71`04m?C`0W9bL07alO01DE5@0D51@06QXJ01/K6`0P8200DE5A02h^
;P1HF5P0EUIF03`l?010@400MWIf055AD@1VIVH0Hf=S051@D02SXj<0L71`06a/K01QHF40QXJ601dM
7@0L71`07AdM01hN7P1KFe/0WIfM0;Rh^01iNGT0EUIF06UYJ@1HF5P0RXZ:092@T01TI6@0?Cdm01lO
7`0V9RH0HV9R051@D024Q8@0K6a/07EeM@1gMgL0C4a<04U9B@1TI6@0=SHf03lo?`1MGEd0@41003dm
?@1TI6@09bLW02<S8`1DE5@0;bl_06IVIP2ATI40O7al0451@@0d=3@0GEeM0861P@2^[Zh0NWYj0:ZZ
ZP1SHf<0HV9R0:NWY`1oOgl0M7Ad03Ti>@0l?3`0Hf=S07]kN`1@D500K6a/05aLG023Ph<08R8R08:2
PP2WYjL0`<300<O7a`2j^[X0Hf=S06ATI00k>c/071`L02`/;02GUiL0P8200<g=c@2a/K40C4a<04Q8
B01NGUh0];Bd09jNWP2;Rh/0P82006MWI`2h^;P0_;bl08>3P`17AdL0@T9204=3@`1QHF40Ng]k07Qh
N0020<K6aP0;08F5Q@0e=CD0?3`l07AdM03IfMT0SXj>0451@@0j>SX0OWin0;fm_@25QHD05?ooool0
01?ooooo04L0SXj>07AdM029RHT0K6a/07EeM@1HF5P0Lg=c06YZJP1RHV80G5aL07UiN@1HF5P0EeMG
0820P01ADE40FUYJ06UYJ@1BDU80GUiN05mOG`1KFe/0HF5Q05eMG@1YJFT0IfMW059BDP1TI6@0FUYJ
04i>CP1GEeL0IVIV04I6AP1>CTh0NGUi059BDP16ATH0JVYZ055AD@1ZJVX0L71`05MGE`1^KVh0GEeM
06EUI@1TI6@0S8b<07AdM01GEeL0GUiN0861P@1BDU80K6a/06][J`11@D40DU9B08:2PP15ADD0De=C
07]kN`1BDU80JVYZ07UiN@1/K6`0Ng]k07EeM@1]KFd0HV9R06][J`1mOGd0D51@07AdM00306m_K`0?
07alO01dM7@0E5AD07emO@1XJ6P0E5AD07]kN`1`L700EUIF08Z:RP1^KVh0ATI608N7Q`1gMgL0C4a<
0080MGEe02@0LW9b08>3P`1gMgL0K6a/06i^KP1bLW80JVYZ065QH@1jNWX0QXJ6079bLP1UIFD0IfMW
07=cL`26QXH0HV9R0820P01oOgl0DU9B06i^KP26QXH0K6a/065QH@25QHD0O7al05mOG`1dM7@0KFe]
051@D01OGel0KVi^04a<C01nOWh0HV9R065QH@1fMWH206i^KP0:07IfMP1OGel0CTi>05iNGP1FEUH0
D51@06UYJ@1RHV80E5AD07]kN`kooooo08`0F5QH06a/K01WIfL0K6a/04];B`1TI6@0FUYJ07AdM01W
IfL0F5QH03/k>`19BDT0DE5A034a<@1SHf<0DE5A051@D01MGEd0JFUY04I6AP10@400DE5A05YJFP14
A4@0IFEU04U9B@1BDU80EUIF05aLG01>CTh0E5AD05eMG@1?Cdl0HF5Q07AdM01QHF40LW9b05IFEP1D
E5@0EeMG08V9R@1]KFd0EUIF06EUI@1EEED0JFUY05EEE@1QHF40DE5A05QHF01KFe/0EEEE059BDP1S
Hf<0JVYZ075aL@22PX80P82006a/K01^KVh0NGUi07emO@21PH40QHF507MgM`1eMGD0Ogmo07QhN01e
MGD0EUIF05ADE01XJ6P0Cdm?04A4A01iNGT0LW9b05YJFP1QHF40L71`0:6QX@1PH600Hf=S06][J`1U
IFD0KVi^04E5A@1XJ6P0HV9R05=CD`1<C4`0Jf][05IFEP1HF5P0GemO05QHF01aLG40E5AD06ATI01P
H600EUIF05QHF01LG5`0E5AD04];B`0/;2`0CDe=05]KF`1LG5`0FEUI055AD@1OGel0H61P05ADE01P
H600FUYJ05aLG01BDU80KFe]07inOP1dM7@0GEeM05]KF`1RHV80GemO07moO`24Q8@0NWYj096AT@2J
VYX0Xj>S09RHV023Ph<0Jf][05EEE@1RHV80IFEU05EEE@1dM7@0HV9R06m_K`kooooo00<0LG5a05UI
F@1WIfL00P15ADD0Q`0h>3P0D51@0451@@1<C4`0=3@d02d];@0n?Sh0;bl_04A4A01;Bd/0ATI604];
B`0k>c/0>SXj0410@00`<300ADE503Xj>P1NGUh0E5AD04E5A@11@D40BDU903Ph>016ATH0N7Qh055A
D@0n?Sh0Bd];055AD@1MGEd0AdM703lo?`1CDe<0C4a<08n?S`1=CDd0C4a<04m?C`10@400LG5a07If
MP1]KFd0HF5Q04a<C01MGEd0FUYJ05ADE01dM7@0DE5A071`L01WIfL0CDe=05iNGP1WIfL0HF5Q061P
H01[Jf/0GUiN06QXJ01oOgl0LW9b04I6AP1SHf<0TI6A05aLG01eMGD0Ti>C05]KF`1cLg<0I6AT07Mg
M`1XJ6P0OWin09NGU`2SXj<0FEUI06m_K`1nOWh0I6AT06m_K`2CTi<0FEUI04Y:BP1EEED0R8R805YJ
FP1UIFD0FUYJ08:2PP1:BTX0IFEU051@D01/K6`0IfMW06QXJ017AdL0Kfm_04U9B@1FEUH0JFUY06=S
H`1MGEd0N7Qh0492@P1/K6`0FUYJ065QH@1aLG40JVYZ06EUI@1@D500De=C05EEE@1LG5`0GEeM055A
D@1OGel0OWin07moO`1FEUH0EeMG04Y:BP1QHF40E5AD065QH@1eMGD0NWYj06UYJ@2BTY80<c<c05YJ
FP1ADE40J6QX05aLG00>ooooo`80Cdm?04T0C4a<07=cL`1FEUH0Bd];02/[:`1?Cdl0ZZZZ0:NWY`2H
V9P0YZJV08n?S`0c<c<06QXJ01hN7P0F5QH05aLG01/K6`0N7Qh0DE5A08n?S`2;Rh/0DE5A03<c<`0h
>3P08R8R01lO7`0^;Rh0D51@03hn?P1WIfL0K6a/08F5Q@24Q8@0/K6a06][J`0n?Sh0BTY:05MGE`1h
N7P0^KVi0<K6aP2o_kl0a<C40:JVYP1VIVH0C4a<07IfMP2SXj<0NWYj06m_K`1gMgL0RHV906QXJ02h
^;P0P82009nOW`2ZZZX0RHV907=cL`1hN7P0;bl_03De=@1hN7P0EeMG08f=S@29RHT0@D5103<c<`1c
Lg<0Kfm_06=SH`19BDT0@4100080>c/k03l0=cLg06MWI`2;Rh/0Xj>S0:VYZ@1`L700N7Qh05=CD`1U
IFD0JFUY020P800T92@0=CDe04a<C02CTi<0Ph>308:2PP2/[:`0[Zj^06e]K@1YJFT0MWIf08>3P`2P
X:00J6QX061PH01mOGd0HF5Q05mOG`1eMGD0M7Ad0;Rh^01;Bd/0J6QX079bLP1gMgL0QHF509RHV026
QXH0VYZJ09BDU01hN7P0Ph>307emO@26QXH0Shn?09fMW@2CTi<0NWYj092@T02f][H0WIfM092@T01A
DE4092@T02l_;`28R8P0JFUY02/[:`0f=SH0OWin09FEU@1MGEd05?ooool001?ooooo01`0N7Qh071`
L01YJFT0Hf=S061PH01CDe<0Lg=c06IVIP1QHF40Fe]K06UYJ@1`L700ATI6061PH01cLg<0?Shn05MG
E`1`L700De=C06m_K`1gMgL0A4A406a/K01]KFd0ATI607=cL`1KFe/0=SHf0P1GEeL0K@14A4@0H61P
0410@01CDe<0Jf][03hn?P1;Bd/0J6QX065QH@1MGEd0I6AT05iNGP28R8P0JFUY04a<C02CTi<0NWYj
04U9B@2?Shl0MWIf04];B`1kNg/0Lg=c04i>CP1kNg/0Hf=S05]KF`1gMgL0QHF506MWI`1gMgL0Jf][
06MWI`24Q8@0H61P092@T01OGel0HV9R08Z:RP1:BTX0G5aL07inOP1LG5`0Jf][0:BTY01@D500MgMg
09fMW@1@D500Kfm_092@T01<C4`0Ogmo0:6QX@1DE5@0HF5Q09fMW@1FEUH0IFEU06QXJ01=CDd0L71`
06a/K01aLG40Ph>3055AD@2>SXh0NGUi055AD@28R8P0L71`08n?S`1XJ6P0EUIF08f=S@1bLW80?clo
08>3P`1gMgL0I6AT05eMG@1RHV80NGUi05MGE`1TI6@0QHF504Q8B01WIfL0SXj>04U9B@1ZJVX0R8R8
05ADE01bLW80QhN704m?C`21PH40KFe]06ATI01iNGT0IVIV055AD@1TI6@0LG5a04e=C@1YJFT0K6a/
03Hf=P1nOWh03_ooool01`1FEUH0LG5a05eMG@1JFUX0Cdm?059BDP1CDe<00P1UIFD0601EEED0AdM7
055AD@1ADE40A4A405eMG@1>CTh0BTY:051@D01OGel0@41002LW9`13@d<0Cdm?04U9B@1VIVH0AdM7
04e=C@19BDT0CTi>05ADE01?Cdl0FUYJ05=CD`80HV9R03X0IfMW06m_K`1DE5@0E5AD05QHF01dM7@0
HF5Q04e=C@1HF5P0Bd];055AD@1FEUH0FUYJ04E5A@1HF5P0H61P051@D01CDe<0IFEU07MgM`1TI6@0
Kfm_07AdM01JFUX0IVIV0820P01gMgL0QHF50861P@1_Kfl0RHV908R8R02EUID0MgMg05iNGP1DE5@0
G5aL04];B`0d=3@0JFUY05]KF`1HF5P0C4a<075aL@2OWil0LG5a06EUI@1WIfL0DE5A05QHF01FEUH0
Jf][06MWI`18B4P0DE5A07EeM@1ADE40Cdm?0P1NGUh0601/K6`0J6QX061PH01RHV80FUYJ05iNGP1L
G5`0Bd];05MGE`0j>SX0HV9R06EUI@1NGUh0EEEE05YJFP1]KFd0F5QH04U9B@1YJFT0H61P06EUI@1J
FUX0JVYZ07]kN`80H61P01<0DE5A06YZJP1?Cdl0K6a/08^;R`1PH600Rh^;0861P@2ATI40]KFe09fM
W@1dM7@0DU9B06][J`1/K6`0F5QH06a/K01`L700LW9b00kooooo01`0HV9R05YJFP1IFET0<c<c04i>
CP0W9bL0DE5A034a<@0i>CT0>SXj020P800b<S809bLW03De=@15ADD0ATI603Lg=`0a<C40:b/[04];
B`0Z:RX0Cdm?03Lg=`0m?Cd0Jf][04Y:BP0X:2P0AdM70P0j>SX07@1/K6`0Bd];05QHF016ATH0GEeM
04m?C`1EEED0GUiN03/k>`1BDU80UIFE059BDP17AdL0HV9R059BDP1^KVh0NGUi07alO01NGUh0GemO
05aLG01^KVh0I6AT0861P@1OGel0JFUY06IVIP1EEED0Fe]K0080H61P0340Fe]K06=SH`1CDe<0Fe]K
08V9R@1PH600E5AD06e]K@1nOWh0Lg=c07AdM01iNGT0DE5A07=cL`1LG5`0IfMW065QH@1/K6`0OWin
09JFUP1CDe<0Lg=c07UiN@1XJ6P0Hf=S09jNWP1DE5@0AdM704i>CP2>SXh0EEEE069RHP1MGEd0PH61
04e=C@1XJ6P0FEUI079bLP24Q8@0KFe]05iNGP1lO7`0FUYJ06QXJ01eMGD0KVi^06][J`1gMgL0IVIV
0080FUYJ01`0KFe]07=cL`1DE5@0SHf=05IFEP1BDU80Hf=S05IFEP1PH600Hf=S06EUI@1QHF40Hf=S
071`L01PH600?Cdm07=cL`1BDU80?Shn061PH022PX80FUYJ05eMG@0c<c<0HF5Q04e=C@1IFET0Fe]K
3_ooool06`1MGEd0CTi>05eMG@1ZJVX0EeMG06e]K@0U9BD0A4A4065QH@17AdL0E5AD07=cL`2PX:00
TI6A069RHP15ADD0<30`024Q8@0_;bl0G5aL06UYJ@2:RXX0UIFE08R8R02XZ:P07AdM01@D500201HF
5P0>05=CD`27QhL0TY:B05iNGP1OGel0M7Ad04E5A@0e=CD0EEEE05UIF@23Ph<0WinO09FEU@39bLT2
079bLP0_0:>SX`0l?3`0=SHf01lO7`1eMGD0?Cdm06e]K@2LW9`0LW9b08f=S@2DU9@0Fe]K09FEU@2j
^[X0Xj>S04M7A`1NGUh0HF5Q034a<@1oOgl0Kfm_07emO@2a/K40L71`07AdM02TY:@0VIVI08>3P`0`
<300D51@02`/;00c<c<0De=C02PX:012@T80Shn?03hn?P0a<C40Shn?05IFEP1XJ6P0DU9B03Xj>P0M
7Ad0;2`/05UIF@1jNWX00P2b/[80;P2e]KD0XZ:R0492@P1BDU80PX:208>3P`2:RXX0OGem05mOG`1n
OWh0SXj>0=CDe034a<@0bl_;09VIV@0o?cl0=3@d07=cL`1GEeL0O7al06MWI`1YJFT0TY:B07=cL`1C
De<0B4Q808:2PP2PX:00CDe=03@d=00c<c<0>SXj06a/K02GUiL0CDe=05=CD`11@D40C4a<08B4Q01f
MWH0GEeM02`/;014A4@0WinO06QXJ02LW9`Dooooo`004oooool05`23Ph<0K6a/06m_K`20P800D51@
05]KF`1WIfL0IFEU07]kN`19BDT0N7Qh05aLG01<C4`0MgMg04e=C@1CDe<0NGUi04];B`1PH600Hf=S
04e=C@1MGEd0HV9R0080Fe]K06/0A4A405ADE01QHF40?clo05IFEP1dM7@0?3`l05mOG`1kNg/0>c/k
06MWI`1oOgl0<C4a06MWI`1/K6`0>SXj075aL@1dM7@0ADE506EUI@1]KFd0De=C06ATI01BDU80IVIV
05QHF01@D500OGem05ADE01@D500NWYj05EEE@1CDe<0MgMg059BDP1EEED0QXJ605]KF`1NGUh0OWin
06MWI`1<C4`0Lg=c065QH@1MGEd0PH6106ATI01QHF40N7Qh07]kN`1iNGT0K6a/07YjNP1`L700FUYJ
07UiN@1mOGd0ADE50861P@1mOGd0>CTi07alO023Ph<0CTi>06QXJ029RHT0D51@08j>SP1lO7`0E5AD
092@T01ZJVX0KFe]07alO01HF5P0LW9b08:2PP1IFET0JVYZ065QH@2<S8`0HV9R05iNGP2HV9P0GemO
05aLG02HV9P0JVYZ04e=C@2EUID0IfMW0451@@1dM7@0EUIF05ADE01QHF40I6AT05mOG`2BTY80DU9B
06i^KP1iNGT0E5AD07IfMP1VIVH0Fe]K05eMG@0204E5A@0506QXJ01DE5@0ADE507EeM@1TI6@03_oo
ool0C@1GEeL0EUIF05EEE@1NGUh0B4Q805UIF@1WIfL0R8R806EUI@1ZJVX0?3`l05MGE`1CDe<0ATI6
06UYJ@1MGEd0GUiN055AD@1@D500ATI604=3@`1;Bd/0DU9B04U9B@1fMWH0@41004m?C`1=CDd0Bd];
04A4A00m?Cd0F5QH04i>CP1HF5P0EeMG05=CD`1`L700ADE50492@P1EEED0Lg=c04U9B@0k>c/0@D51
03Lg=`0o?cl0ADE504Q8B00m?Cd0De=C04i>CP12@T80?Shn04Y:BP1HF5P0D51@05iNGP1[Jf/0EeMG
06ATI01gMgL0Jf][07AdM01nOWh0NWYj06m_K`1bLW80RHV907emO@1TI6@0@D5106MWI`1VIVH0DE5A
08>3P`1aLG40GemO0080LG5a03d0YZJV05QHF01IFET0KFe]06i^KP1UIFD0C4a<05mOG`1[Jf/0GemO
05UIF@1[Jf/0GEeM05MGE`1]KFd0GUiN05YJFP1WIfL0C4a<06=SH`1NGUh0LG5a05YJFP1OGel0Cdm?
03Ph>01EEED0FUYJ05]KF`1@D500OGem071`L01nOWh0G5aL079bLP1QHF40GemO05MGE`1VIVH0J6QX
05aLG01UIFD0HV9R04];B`19BDT0Kfm_07UiN@1fMWH0Rh^;06IVIP1[Jf/0X:2P07emO@1[Jf/0Fe]K
04a<C01[Jf/0B4Q807UiN@1ZJVX0OWin00kooooo0700OWin07=cL`1VIVH0EeMG05YJFP0o?cl0Jf][
03lo?`16ATH0>c/k03`l?00b<S80<C4a04U9B@18B4P0HF5Q04=3@`0c<c<0>c/k04];B`16ATH0Bd];
04i>CP1FEUH0Hf=S05UIF@17AdL0G5aL0492@P11@D40MGEe030`<01[Jf/0C4a<05YJFP1BDU80Cdm?
05YJFP0m?Cd0N7Qh08>3P`1=CDd0IVIV05YJFP14A4@0Ogmo08Z:RP1mOGd0Kfm_04Y:BP1[Jf/0FUYJ
04m?C`1fMWH0CDe=06UYJ@1LG5`0DU9B06ATI01QHF40H61P075aL@1LG5`0FUYJ06ATI01eMGD0IFEU
04a<C01VIVH0HV9R07alO01eMGD0SHf=06a/K01jNWX0Lg=c06QXJ01gMgL0O7al08f=S@2TY:@0DU9B
07alO01eMGD0H61P07IfMP2<S8`0GUiN05EEE@1BDU80RXZ:059BDP1IFET0IVIV07MgM`0o?cl0GEeM
05EEE@17AdL0IfMW08N7Q`18B4P0DE5A059BDP1KFe/0EUIF07MgM`1FEUH0H61P04=3@`1KFe/0G5aL
0P1VIVH06P1KFe/0M7Ad051@D01HF5P0IFEU04e=C@1SHf<0EUIF05eMG@1VIVH0C4a<065QH@1RHV80
@T9207MgM`19BDT0DU9B05QHF01oOgl0GEeM07emO@0[:b/0EEEE04A4A01MGEd0DU9B3_ooool0@P18
B4P0DE5A07inOP1JFUX0>SXj03De=@1TI6@0PX:205YJFP0T92@0=CDe02XZ:P2?Shl0NWYj06QXJ01/
K6`0MWIf07UiN@1`L700IVIV05mOG`25QHD0XJ6Q06][J`1iNGT07AdM01DE5@0K6a/07alO02/[:`13
@d<0IfMW0:BTY02GUiL0=CDe01dM7@0O7al09bLW06e]K@2SXj<0WinO07MgM`19BDT0EUIF051@D01[
Jf/0JFUY034a<@0P8200BDU904];B`1mOGd0FUYJ065QH@1^KVh0;Rh^02/[:`0o?cl0PH6109:BTP1l
O7`0I6AT09bLW02HV9P0^k^k0;>c/`80WinO04P0Lg=c08R8R01HF5P0Rh^;08Z:RP2<S8`0Vi^K051@
D01FEUH0:RXZ01dM7@13@d<0N7Qh030`<00U9BD0;Bd]06i^KP1ZJVX0ADE508J6QP1FEUH0Cdm?0410
@01FEUH0aLG50<O7a`2@T900XZ:R05mOG`28R8P0Xj>S0451@@1WIfL0JFUY04U9B@2ATI40bl_;0<K6
aP2FUYH0^KVi0<o?c`1lO7`0Bd];07QhN01/K6`0H61P08b<S01eMGD0Ng]k04];B`1EEED0ADE5092@
T02IVIT0>SXj03Hf=P1>CTh0M7Ad0:6QX@1BDU80=CDe0492@P18B4P0BDU904];B`1VIVH0CDe=02TY
:@25QHD0Xj>S05eMG@13@d<Dooooo`004oooool00`2FUYH0NWYj07=cL`0206a/K00>04m?C`1YJFT0
OGem05UIF@1[Jf/0OWin05IFEP1XJ6P0HF5Q05mOG`1FEUH0IFEU05MGE`18B4P207AdM00I05aLG01A
DE40NWYj05iNGP0j>SX0Kfm_05MGE`1BDU80G5aL06a/K01DE5@0H61P06][J`1NGUh0Kfm_06UYJ@13
@d<0I6AT06=SH`1BDU80HV9R07=cL`1TI6@0GEeM071`L00206=SH`1K06ATI01hN7P0BDU9069RHP1^
KVh0CDe=05aLG01iNGT0DU9B06QXJ02CTi<0CTi>06e]K@1hN7P0EEEE071`L01]KFd0Kfm_04a<C01M
GEd0Kfm_05ADE01/K6`0Ng]k065QH@1`L700PX:206YZJP1MGEd0NWYj06m_K`1RHV80NWYj075aL@1K
Fe/0Ph>306QXJ01?Cdl0NGUi06=SH`1IFET0GUiN051@D01QHF40OGem06UYJ@1_Kfl0LG5a06i^KP1T
I6@0DE5A08J6QP1bLW80IFEU06e]K@1PH600KFe]071`L01ADE40HF5Q07EeM@1@D500Fe]K06YZJP1`
L700DU9B07inOP1iNGT0DE5A05mOG`1kNg/0EEEE06MWI`1/K6`0DE5A07QhN01SHf<0EEEE06m_K`1[
Jf/0IVIV0861P@1TI6@0EUIF06UYJ@1RHV80DE5A07MgM`1IFET0EEEE06i^KP0>ooooo`07061PH01X
J6P0Fe]K06ATI01@D500DU9B05mOG`0206][J`0_05iNGP0m?Cd0De=C04e=C@14A4@0H61P05EEE@1F
EUH0F5QH06IVIP19BDT0A4A4059BDP1EEED0ATI606EUI@1=CDd0EUIF04];B`1JFUX0Fe]K05=CD`1U
IFD0Cdm?06=SH`1[Jf/0J6QX08V9R@17AdL0Bd];07IfMP2KVi/0Hf=S04U9B@1=CDd0A4A404Q8B01<
C4`0CDe=04Y:BP1;Bd/0Cdm?04=3@`14A4@0F5QH05EEE@1>CTh00P1FEUH0=@1>CTh0AdM705MGE`1X
J6P0G5aL07UiN@1bLW80IfMW075aL@1OGel0LG5a06][J`1`L700HF5Q05IFEP11@D40OGem06][J`1M
GEd0F5QH06a/K02g]kL0M7Ad06MWI`1YJFT0KVi^06MWI`1KFe/0N7Qh07EeM@1SHf<0EUIF07UiN@1H
F5P0EeMG06QXJ01UIFD0L71`075aL@1LG5`0Jf][075aL@1cLg<0K6a/05MGE`1=CDd0?3`l055AD@1M
GEd0Fe]K05QHF01TI6@0OWin0080HF5Q01/0K6a/04Y:BP10@400De=C06IVIP1GEeL0C4a<06ATI01@
D500IVIV03Hf=P1CDe<0G5aL05MGE`1fMWH0K6a/08>3P`2=SHd0S8b<092@T01PH600GUiN079bLP1R
HV80N7Qh07YjNP25QHD03_ooool206YZJP0705QHF01CDe<0C4a<02l_;`1MGEd0?3`l03Ph>002038b
<P2102`/;00Z:RX0>3Ph0451@@1>CTh0;Rh^02@T900Z:RX0@D5104U9B@0j>SX0CTi>04U9B@1bLW80
ATI604A4A01<C4`0Bd];04Y:BP1XJ6P0?Shn059BDP1DE5@0EeMG04Y:BP1MGEd0MWIf03Ti>@1PH600
HF5Q05EEE@1<C4`0I6AT04m?C`1bLW80NGUi08V9R@1TI6@0HV9R05]KF`1NGUh0G5aL06a/K01OGel0
FUYJ051@D01NGUh0FEUI05]KF`1ADE40LG5a059BDP1RHV80H61P08>3P`1EEED0IVIV06MWI`1GEeL0
OWin075aL@29RHT0IfMW06UYJ@1SHf<0JVYZ07MgM`1jNWX0I6AT0:NWY`1HF5P0L71`08>3P`1/K6`0
MGEe09RHV01SHf<0De=C059BDP1jNWX0Bd];05EEE@1ZJVX0MWIf04m?C`1YJFT0I6AT04M7A`1_Kfl0
NGUi05aLG014A4@0G5aL06UYJ@1OGel0Hf=S069RHP1YJFT0GUiN055AD@1OGel0LG5a06QXJ01HF5P0
Ng]k059BDP1>CTh0I6AT04I6AP1[Jf/0C4a<06QXJ01IFET0EeMG06][J`1/K6`0ADE505]KF`15ADD0
GUiN05QHF01oOgl0JVYZ07YjNP0l?3`0IVIV04E5A@1_Kfl0Fe]K00kooooo01/0C4a<03Ti>@1OGel0
CTi>02h^;P0d=3@0AdM70:2PX020P800?Shn030`<01NGUh0IFEU09:BTP1?Cdl0CDe=07MgM`2=SHd0
MgMg065QH@18B4P0LG5a0:JVYP29RHT0N7Qh05]KF`0V9RH00P0L71`0<00K6a/0HV9R08b<S01nOWh0
Ti>C038b<P0P820071`L020P801ZJVX0IVIV09>CT`0d=3@07QhN02/[:`1=CDd0HV9R06][J`1OGel0
IVIV06YZJP1mOGd0Q8B406=SH`1eMGD0MgMg03<c<`0O7al0;bl_08R8R02;Rh/0][Jf09^KV`2j^[X0
`L7108J6QP2OWil0^[Zj0:j^[P2JVYX0KFe]03Lg=`1YJFT0K6a/07YjNP1=CDd0OWin055AD@8071`L
03d0C4a<06UYJ@1KFe/0;bl_02h^;P1VIVH0QhN707YjNP1oOgl0C4a<02<S8`0O7al08R8R08f=S@1d
M7@0GUiN0:>SX`0l?3`0>c/k09BDU017AdL0CTi>04m?C`12@T80Hf=S09^KV`22PX80FUYJ0:ZZZP2W
YjL0?3`l04i>CP29RHT0>SXj04A4A01YJFT0YJFU05mOG`0o?cl0YZJV08N7Q`2RXZ80^k^k07inOP1j
NWX0PH610:f][@2SXj<0>3Ph024Q8@0[:b/0GUiN0820P01]KFd0UIFE05iNGP2@T900^;Rh05QHF012
@T80Ng]k01Cooooo000Cooooo`2408>3P`1nOWh0HF5Q0820P01GEeL0CTi>06YZJP1]KFd0GUiN06e]
K@1jNWX0I6AT04i>CP1GEeL0LG5a03Hf=P1GEeL0JVYZ03`l?01VIVH0NWYj04I6AP1;Bd/0Rh^;04];
B`1RHV80MgMg034a<@1MGEd0Cdm?03hn?P1VIVH0AdM704e=C@1NGUh0ADE506QXJ01KFe/0F5QH07al
O01ADE40FEUI09:BTP1FEUH0B4Q808Z:RP26QXH0De=C08f=S@1^KVh0@D5107AdM01PH600D51@07Ad
M01QHF40D51@06][J`1VIVH0FEUI08R8R01RHV80O7al06m_K`1KFe/0OWin05eMG@1]KFd0O7al04Q8
B01gMgL0LW9b03lo?`2:RXX0SHf=05=CD`1TI6@0NWYj055AD@28R8P0V9RH04I6AP2CTi<0[Jf]069R
HP2IVIT0Ph>306YZJP27QhL0IfMW05QHF02<S8`0JFUY07IfMP1cLg<0Fe]K09JFUP1QHF40EEEE08V9
R@1SHf<0WYjN06IVIP1RHV80U9BD055AD@1DE5@0T92@0820P01_Kfl0Lg=c08R8R01cLg<0DE5A06i^
KP2>SXh0AdM706IVIP2KVi/0;bl_071`L02;Rh/0>c/k07IfMP1YJFT0?3`l07AdM01aLG40?Cdm06i^
KP1[Jf/0AdM70P1[Jf/01@14A4@0K6a/06i^KP0f=SH0Ogmo00kooooo01T0KVi^06UYJ@1VIVH0IfMW
04Q8B01>CTh0IVIV075aL@1NGUh0G5aL0410@01>CTh0EEEE04];B`1WIfL0FUYJ05]KF`1XJ6P0JVYZ
04];B`1?Cdl0E5AD06IVIP1EEED0M7Ad0080FEUI03D0EeMG06=SH`1@D500IFEU061PH019BDT0Fe]K
06MWI`1YJFT0M7Ad04=3@`1GEeL0H61P0:>SX`1JFUX0ADE504M7A`14A4@0C4a<04];B`1BDU80?clo
04Q8B01EEED0AdM703`l?01BDU80G5aL05iNGP1HF5P0HF5Q04U9B@1RHV80MGEe079bLP1LG5`0KVi^
07MgM`1UIFD0Ogmo079bLP1iNGT0JVYZ06e]K@1@D500EUIF04M7A`1/K6`0EUIF04e=C@1IFET0Fe]K
0;6a/@02059BDP0G05iNGP1HF5P0E5AD04e=C@1WIfL0IVIV04=3@`1GEeL0Q8B4051@D017AdL0EEEE
055AD@1DE5@0JFUY069RHP1ADE40G5aL06EUI@1EEED0FUYJ059BDP0i>CT00P1@D5008@1DE5@0EUIF
04Y:BP1aLG40KFe]04=3@`1JFUX0Fe]K04U9B@1FEUH0G5aL05eMG@1OGel0Jf][04=3@`1^KVh0A4A4
06QXJ01RHV80IFEU08>3P`1SHf<0QXJ60;2`/01hN7P0M7Ad04U9B@1XJ6P0IfMW04a<C025QHD0MGEe
08:2PP0>ooooo`1W07QhN01/K6`0G5aL05eMG@14A4@0>3Ph05MGE`0h>3P0@D5103Hf=P11@D40>CTi
02TY:@0k>c/0@D5104e=C@0Y:BT0:2PX03Hf=P0j>SX0HF5Q03Hf=P1?Cdl0CTi>06IVIP16ATH0E5AD
04U9B@0l?3`0DU9B07AdM00i>CT0BDU9059BDP1IFET0ADE505QHF01jNWX0?clo07EeM@1NGUh0G5aL
04m?C`1KFe/0EUIF07AdM01oOgl0SXj>06][J`1PH600EeMG05]KF`1GEeL0KVi^06EUI@1LG5`0DU9B
05eMG@1JFUX0E5AD059BDP1^KVh0BDU9059BDP1LG5`0N7Qh04E5A@1RHV80E5AD04Q8B020P800Kfm_
06ATI01YJFT0Rh^;05MGE`1WIfL0GemO07YjNP17AdL0ZJVY04e=C@1LG5`0JVYZ06][J`1ZJVX0OGem
06=SH`1QHF40DE5A07IfMP1JFUX0EEEE06YZJP1hN7P0De=C05iNGP1]KFd0@d=3071`L01XJ6P0HV9R
05ADE00206=SH`0S06ATI01<C4`0IVIV05YJFP1?Cdl0De=C06e]K@1VIVH0Kfm_06MWI`20P800GUiN
059BDP1SHf<0@d=307IfMP16ATH0Ogmo059BDP1^KVh0PX:2069RHP17AdL0L71`04E5A@1HF5P0EeMG
08J6QP1XJ6P0UIFE0492@P1`L700=CDe07]kN`1EEED03_ooool0=@1>CTh0:2PX02@T901FEUH0E5AD
05eMG@27QhL0W9bL05eMG@1GEeL0K6a/071`L01KFe/07AdM02PX:01BDU80PX:20861P@1TI6@0;bl_
03<c<`1aLG40H61P0861P@1hN7P0UYJF06=SH`1BDU80@41005IFEP2HV9P0O7al05]KF`1QHF40E5AD
06ATI01GEeL0K6a/06IVIP2OWil0SHf=02HV9P0M7Ad0;bl_07QhN02VYZH0U9BD07inOP1ZJVX0M7Ad
04Q8B01ZJVX0F5QH0080RXZ:00@0GemO06i^KP1oOgl0Bd];0P2JVYX05P1/K6`0/k>c09:BTP1ADE40
JVYZ08n?S`1_Kfl0?3`l08f=S@0R8R80?clo06ATI018B4P0?Shn02h^;P2LW9`0EEEE04i>CP2@T900
UiNG051@D00e=CD205aLG00g07AdM02>SXh0[:b/069RHP0N7Qh07AdM03Lg=`2EUID0;Bd]030`<01l
O7`0;Bd]024Q8@1UIFD0YZJV04e=C@2CTi<0Rh^;06=SH`1kNg/0QHF502/[:`2<S8`0Xj>S071`L00f
=SH0GUiN04];B`1BDU80SXj>03/k>`1RHV80UYJF0;Jf]P2k^k/0/;2`0;6a/@2RXZ80RXZ:06QXJ02D
U9@0Y:BT05IFEP0d=3@0IFEU07]kN`2ATI40Vi^K09>CT`2WYjL0cLg=0:n_[`1YJFT0X:2P079bLP0D
ooooo`004oooool0IP1mOGd0LW9b07YjNP1kNg/0JVYZ05]KF`1JFUX0Lg=c05mOG`1_Kfl0Ti>C059B
DP1<C4`0O7al05MGE`1CDe<0IVIV05=CD`1HF5P0Kfm_05IFEP1[Jf/0E5AD05mOG`1bLW80<c<c05aL
G01cLg<0?3`l071`L01[Jf/0A4A4055AD@25QHD0@41005aLG027QhL0;Bd]05iNGP1hN7P0?Cdm05UI
F@1fMWH0ADE5061PH01QHF40FUYJ05ADE01=CDd0OWin04U9B@1>CTh0N7Qh03Xj>P1?Cdl0QhN704=3
@`1<C4`0Shn?04E5A@1MGEd0QhN704m?C`1SHf<0Kfm_05]KF`1GEeL0Lg=c06IVIP1FEUH0M7Ad05IF
EP1dM7@0P82006IVIP1aLG40HV9R06UYJ@1]KFd0BTY:069RHP21PH40AdM706][J`25QHD0?clo07Mg
M`1kNg/0@D5107alO01UIFD0GEeM09FEU@1oOgl0K6a/08b<S01RHV80J6QX06EUI@1@D500O7al06][
J`80OGem02<0Hf=S09FEU@1>CTh0JVYZ09NGU`1XJ6P0Jf][092@T01OGel0HF5Q07moO`1SHf<0H61P
07YjNP1aLG40K6a/06m_K`1GEeL0IFEU08f=S@1DE5@0IfMW06][J`1aLG40NWYj06UYJ@1PH600HV9R
06MWI`0m?Cd0K6a/06QXJ01@D500L71`05ADE00>ooooo`0805IFEP1SHf<0DE5A05UIF@1?Cdl0C4a<
04e=C@1UIFD205MGE`1F03lo?`1?Cdl0D51@04U9B@1;Bd/0A4A404=3@`1BDU80Hf=S04A4A019BDT0
IVIV061PH01BDU80Ph>305MGE`1SHf<0D51@055AD@1EEED0Lg=c06a/K01ADE40Hf=S06UYJ@1SHf<0
MWIf05UIF@1KFe/0Cdm?079bLP1QHF40Bd];055AD@1>CTh0Cdm?04Y:BP1<C4`0AdM7055AD@1]KFd0
CTi>04M7A`1GEeL0IFEU06=SH`1]KFd0LG5a04A4A01`L700P82006MWI`1`L700YjNW08F5Q@1fMWH0
R8R806a/K02=SHd0HV9R07YjNP1>CTh0EUIF04M7A`1`L700CDe=04i>CP1LG5`0LG5a0;Bd]01QHF40
GUiN06=SH`1BDU80IFEU059BDP1WIfL0KVi^04a<C01SHf<0IfMW055AD@1:BTX0ADE503Xj>P1TI6@2
05ADE00S06ATI01YJFT0GemO05mOG`14A4@0BDU903Lg=`16ATH0A4A4051@D01:BTX0De=C05QHF01C
De<0?3`l051@D018B4P0BTY:06MWI`1lO7`0N7Qh05YJFP1eMGD0FUYJ05aLG01ADE40KVi^06ATI01V
IVH0SXj>065QH@1YJFT0Q8B409^KV`2ATI400P1cLg<01@1nOWh0HF5Q08R8R01hN7P0P82000kooooo
01/0MgMg05aLG01RHV80E5AD03dm?@0h>3P0DE5A0492@P0m?Cd0;Bd]04Y:BP0n?Sh0@D5103<c<`1;
Bd/0B4Q802PX:00a<C40;2`/03`l?01DE5@0<30`04Y:BP0o?cl0Lg=c061PH01BDU800P1;Bd/03@19
BDT0JFUY03`l?010@400BDU903lo?`0n?Sh0GEeM079bLP0h>3P0J6QX05=CD`1KFe/00P1FEUH0?01:
BTX0GUiN05]KF`25QHD0G5aL059BDP1UIFD0CDe=05=CD`1]KFd0Fe]K06a/K013@d<0E5AD069RHP17
AdL0A4A407=cL`17AdL0IFEU05=CD`1fMWH0@T9205aLG01NGUh0A4A4071`L01WIfL0LW9b06IVIP1i
NGT0Hf=S05]KF`1hN7P0R8R806UYJ@2][Jd0GEeM07IfMP1TI6@0GUiN08J6QP1jNWX0IFEU07alO019
BDT0JFUY04M7A`11@D40HV9R065QH@15ADD0I6AT05YJFP0h>3P0Lg=c079bLP1WIfL0EeMG06QXJ080
F5QH0280ATI6071`L01=CDd0F5QH05MGE`1XJ6P0Jf][07YjNP1HF5P0J6QX07=cL`19BDT0FEUI03hn
?P1WIfL0?clo04i>CP1OGel0JFUY069RHP1IFET0DE5A061PH00f=SH0L71`055AD@1dM7@0PX:209VI
V@0d=3@0GEeM04i>CP1cLg<0D51@3_ooool0S015ADD0FUYJ04A4A01PH600G5aL04Q8B017AdL0P820
07inOP1/K6`0PH6108n?S`1eMGD0:RXZ03Ti>@1BDU80;bl_03dm?@1HF5P08b<S028R8P0f=SH0H61P
0:FUY@28R8P0AdM703lo?`1<C4`0F5QH08J6QP2i^KT0XJ6Q09^KV`1@D5008R8R02l_;`1?Cdl0UIFE
0;fm_@1JFUX0Bd];05mOG`1=CDd0A4A402d];@0Y:BT0?clo09^KV`2f][H0Xj>S03/k>`0^;Rh0IVIV
08n?S`1DE5@0Jf][075aL@2][Jd0LW9b06YZJP1=CDd0@D5109nOW`2ZZZX0ATI6071`L021PH40Bd];
028R8P1;Bd/0<30`05EEE@24Q8@0?Shn03De=@1/K6`0Ogmo05ADE02VYZH0/K6a0:2PX02k^k/0MGEe
05UIF@1hN7P0?Cdm06EUI@1mOGd0];Bd07MgM`1ZJVX0UIFE0;^k^`0/;2`0;bl_0861P@30`<00VIVI
08f=S@2OWil0WYjN09fMW@1[Jf/0N7Qh0::RXP2l_;`0V9RH0<[:bP1YJFT0ATI609JFUP2MWId0QHF5
09fMW@2GUiL0Q8B408f=S@2VYZH0Kfm_09^KV`29RHT0a<C408B4Q01RHV80?Shn05]KF`21PH40Shn?
0:JVYP1kNg/0M7Ad09FEU@2WYjL0c/k>0:FUY@2LW9`0IFEU06IVIP2QXJ40HV9R5?ooool001?ooooo
02X0RHV909bLW01^KVh0Jf][071`L016ATH0M7Ad069RHP16ATH0FEUI075aL@1mOGd0B4Q8061PH01/
K6`0@41004=3@`1UIFD0FUYJ05]KF`1hN7P0FEUI05EEE@26QXH0BTY:05MGE`1jNWX0>CTi06YZJP1L
G5`0=CDe065QH@17AdL0?clo06UYJ@10@400C4a<06ATI01CDe<0Bd];05iNGP1@D50205UIF@0F04Q8
B01/K6`0JFUY04I6AP1JFUX0Lg=c03Hf=P1EEED0J6QX04M7A`1NGUh0L71`051@D01FEUH0JVYZ05YJ
FP1bLW80J6QX07IfMP1QHF40EeMG07AdM080GEeM01@0VIVI04e=C@1]KFd0LW9b04U9B@22PX80OGem
04M7A`1GEeL0Jf][04M7A`1@D500RHV90451@@1[Jf/0Ph>3061PH01hN7P0M7Ad05YJFP80M7Ad0340
A4A407moO`1UIFD0J6QX07moO`0o?cl0TY:B04i>CP1LG5`0RXZ:055AD@2HV9P0J6QX05YJFP23Ph<0
J6QX065QH@20P800LW9b07EeM@1XJ6P0JVYZ0820P01RHV80GemO08R8R018B4P0GUiN09^KV`0i>CT0
HV9R09bLW015ADD0IVIV07moO`17AdL0JFUY06ATI01>CTh0Jf][07=cL`0b<S80Fe]K07AdM01CDe<0
G5aL07YjNP17AdL0Jf][00kooooo0P1HF5P06P1JFUX0Hf=S04];B`1;Bd/0FUYJ061PH01LG5`0DE5A
03Hf=P19BDT0AdM703/k>`1;Bd/0ATI604i>CP1HF5P0D51@04M7A`1<C4`0DU9B05QHF01BDU80Jf][
04e=C@1QHF40?clo0P1@D500KP1OGel0F5QH04e=C@1RHV80IVIV06=SH`1gMgL0CTi>05=CD`1IFET0
Kfm_04U9B@16ATH0AdM704U9B@1<C4`0BDU9055AD@0o?cl0CTi>051@D01<C4`0Bd];05IFEP1NGUh0
GemO06EUI@1YJFT0BTY:05YJFP1cLg<0NGUi05ADE02OWil0PX:207alO01_Kfl0Ogmo06YZJP1aLG40
P82005iNGP1HF5P0G5aL08f=S@1YJFT0D51@05aLG01kNg/0_kno04m?C`1OGel0JFUY055AD@1YJFT0
F5QH06a/K01ZJVX0B4Q804m?C`1_Kfl0EeMG04];B`1FEUH0AdM706IVIP1SHf<0AdM7055AD@1aLG40
JVYZ05YJFP1FEUH0@D5102h^;P12@T80B4Q8051@D01;Bd/0EEEE04e=C@1[Jf/0<S8b04a<C01ADE40
ADE505YJFP1SHf<0M7Ad05YJFP1XJ6P0DU9B06=SH`1FEUH0HF5Q05ADE01GEeL0UIFE07QhN028R8P0
YZJV0:b/[02ATI40DE5A06YZJP1_Kfl0Bd];07inOP1ZJVX0R8R83_ooool0=P1QHF40I6AT079bLP1M
GEd0>c/k02/[:`18B4P0;2`/03Lg=`0[:b/0=CDe0492@P0m?Cd0:RXZ059BDP0h>3P0;Rh^03@d=00b
<S80<c<c04U9B@1:BTX0ADE503`l?01VIVH0A4A40492@P15ADD0=3@d03De=@1PH600>SXj03hn?P14
A4@0<C4a02d];@1@D500I6AT02XZ:P1ZJVX0Hf=S03hn?P1SHf<0De=C03Hf=P1>CTh0GEeM096AT@1I
FET0H61P06=SH`1?Cdl0BTY:05YJFP80GEeM01X0GemO05iNGP1BDU80BDU9059BDP1jNWX0I6AT05EE
E@1SHf<0GemO03Xj>P1/K6`0HF5Q034a<@26QXH0Jf][069RHP2;Rh/0KFe]05YJFP1_Kfl0GUiN07Yj
NP1eMGD0/K6a04e=C@80Hf=S03P0O7al07UiN@1fMWH0JFUY06YZJP1;Bd/0KVi^065QH@14A4@0JVYZ
065QH@1TI6@0GUiN06UYJ@10@400NWYj06QXJ01PH600UIFE07inOP1YJFT0MGEe04Y:BP1^KVh0CDe=
05UIF@1LG5`0I6AT065QH@1OGel0MWIf05]KF`14A4@0EEEE06MWI`0^;Rh0G5aL03hn?P0k>c/0BDU9
079bLP1fMWH0CTi>04Q8B01TI6@0=CDe05QHF01FEUH0L71`07EeM@2?Shl0@d=307YjNP17AdL0MgMg
04i>CPkooooo07d0BDU906EUI@1gMgL0ATI6051@D00T92@05ADE02PX:01[Jf/0_kno06EUI@2CTi<0
MgMg08J6QP1;Bd/09bLW020P800S8b<0EUIF03Ti>@0S8b<0:2PX09>CT`2=SHd0NGUi03De=@0Y:BT0
;2`/034a<@1[Jf/0WinO0;Vi^@2DU9@0>CTi01hN7P0O7al09BDU0410@02YZJT0IVIV04m?C`13@d<0
:BTY01`L700S8b<092@T03lo?`25QHD0alO70<30`02HV9P0U9BD055AD@0O7al07QhN030`<01MGEd0
/[:b0<_;b`24Q8@0?Cdm02<S8`2KVi/0YjNW08f=S@2CTi<0NGUi051@D00_;bl0@41006e]K@0m?Cd0
7AdM04A4A00i>CT0Lg=c04i>CP1DE5@0c/k>0::RXP23Ph<0Xj>S0861P@20P800Ogmo065QH@1HF5P0
ADE50;Vi^@2>SXh0=SHf08^;R`2ATI40D51@02l_;`2;Rh/0IfMW0:6QX@27QhL0WYjN0<G5a@2b/[80
?3`l051@D02/[:`0UIFE09RHV02RXZ80TI6A07QhN01cLg<0Ogmo0:RXZ02KVi/0GemO06e]K@1iNGT0
?Shn010@400X:2P0XJ6Q06=SH`0Z:RX0?3`l07AdM00205aLG00=07]kN`2PX:00U9BD0;>c/`1`L700
`L7107moO`15ADD0EUIF07=cL`27QhL0WinO04a<C00Dooooo`004oooool0401oOgl0L71`07UiN@1e
MGD0G5aL06EUI@1DE5@0Jf][05aLG013@d<0Ng]k05eMG@18B4P0LW9b05mOG`17AdL2055AD@0:04Y:
BP1SHf<0JVYZ055AD@1QHF40N7Qh05mOG`1MGEd0G5aL04M7A`80EeMG06d0IfMW05eMG@1:BTX0I6AT
059BDP1>CTh0Kfm_04Q8B01>CTh0L71`0451@@1IFET0LW9b0451@@1PH600GemO059BDP1IFET0DE5A
061PH017AdL0D51@07AdM01GEeL0EEEE07EeM@19BDT0FEUI07AdM01RHV80JVYZ07alO01mOGd0L71`
06QXJ01cLg<0EUIF06MWI`1gMgL0DE5A079bLP1ZJVX0D51@07alO01eMGD0JVYZ06EUI@1WIfL0HV9R
065QH@1VIVH0Jf][05mOG`1[Jf/0NWYj06ATI01mOGd0Ng]k04a<C01[Jf/0L71`05ADE01XJ6P0QhN7
05YJFP1[Jf/0RHV9059BDP1JFUX0LW9b06MWI`1kNg/0I6AT06e]K@1aLG40KFe]05eMG@1/K6`0Rh^;
075aL@1NGUh0N7Qh071`L01PH600O7al0861P@1<C4`0JFUY08f=S@1:BTX0Jf][07QhN01BDU80Ph>3
06e]K@1eMGD0NGUi05QHF01NGUh0NGUi05aLG01ADE40IfMW04i>CP1MGEd0MGEe04E5A@1MGEd0IVIV
00kooooo00P0EUIF04a<C012@T80CTi>0451@@14A4@0C4a<05QHF080A4A400D0=cLg04Y:BP1<C4`0
>SXj04Y:BP0204Q8B00K055AD@1@D500@T9204=3@`1=CDd0BDU904m?C`1BDU80ADE5059BDP17AdL0
B4Q804e=C@1KFe/0CTi>04Q8B01IFET0Jf][069RHP1OGel0CTi>05MGE`1@D500FEUI03dm?@13@d<0
@T920080?clo00D0CTi>059BDP0i>CT0CTi>05UIF@0204Y:BP1G05eMG@1HF5P0GEeM05QHF01MGEd0
BTY:05EEE@1QHF40HV9R04];B`25QHD0MGEe06e]K@1eMGD0NWYj06QXJ01SHf<0EEEE05iNGP1EEED0
Hf=S08:2PP1eMGD0FUYJ07MgM`24Q8@0_[jn06ATI01LG5`0JVYZ06i^KP1WIfL0DU9B06UYJ@1TI6@0
FEUI05QHF01kNg/0JFUY05MGE`1]KFd0CDe=05aLG01EEED0G5aL065QH@1/K6`0GEeM05IFEP1OGel0
Cdm?03Xj>P13@d<0C4a<05]KF`1BDU80E5AD05=CD`1hN7P0B4Q804i>CP1QHF40Cdm?06YZJP1VIVH0
J6QX05eMG@1RHV80C4a<061PH016ATH0HF5Q05mOG`1EEED0Shn?069RHP1gMgL0O7al08N7Q`2GUiL0
IfMW06][J`1hN7P0De=C07]kN`1iNGT0Q8B400kooooo02`0GemO06MWI`1GEeL0MWIf03Xj>P0f=SH0
DE5A03Ph>00g=cL0A4A402d];@0[:b/0@d=303Hf=P1CDe<0=CDe030`<00g=cL0=3@d034a<@1DE5@0
<c<c0410@00k>c/0I6AT059BDP11@D40<C4a03@d=019BDT0De=C03Ti>@1FEUH0@D5102PX:00h>3P0
CDe=06i^KP0h>3P0JVYZ06e]K@1:BTX0J6QX05YJFP80@D5101P0EEEE08f=S@1ADE40G5aL075aL@15
ADD0HF5Q05mOG`1NGUh0GEeM069RHP1IFET0F5QH04e=C@0o?cl0L71`051@D01bLW80Fe]K07MgM`1>
CTh0M7Ad05IFEP1=CDd2071`L00L06EUI@24Q8@0JFUY06IVIP1HF5P0O7al07MgM`15ADD0YjNW06AT
I029RHT0G5aL08:2PP2>SXh0IFEU06MWI`1YJFT0DE5A06i^KP1IFET0E5AD06MWI`1IFET0GUiN06QX
J01NGUh0>3Ph06][J`80H61P00h0Rh^;07=cL`1aLG40Kfm_04M7A`1dM7@0FEUI04Y:BP12@T80KVi^
055AD@1SHf<0OGem06EUI@80De=C01H0EeMG03Xj>P1FEUH0=SHf0451@@1@D500LW9b07QhN017AdL0
DU9B05ADE00f=SH0GUiN06IVIP1PH600I6AT09bLW01@D500IVIV04i>CP1jNWX0E5AD3_ooool05P29
RHT0T92@071`L01UIFD0Hf=S04a<C00d=3@0?Cdm09ZJVP2UYJD0LW9b05EEE@1eMGD0KVi^06EUI@1?
Cdl0AdM703Xj>P1<C4`0R8R806EUI@1IFET20;Fe]@1d0:j^[P25QHD0F5QH04M7A`12@T80?Shn04A4
A01JFUX0MGEe04e=C@0m?Cd0>SXj04I6AP1>CTh0SHf=096AT@1^KVh0MGEe06YZJP0e=CD07alO03@d
=016ATH0GemO0;:b/P2`/;00CTi>06YZJP0V9RH071`L01TI6@0K6a/0:BTY08j>SP2@T900Ng]k03Ti
>@10@400GEeM06i^KP1FEUH0Cdm?065QH@1SHf<0Jf][05=CD`1@D500:RXZ01HF5P0H61P0;Bd]0861
P@2XZ:P0TY:B051@D01HF5P0>SXj04];B`1PH600GemO06m_K`2=SHd0L71`08n?S`1aLG40Ph>30;jn
_P2EUID0T92@0<C4a021PH40Hf=S01XJ6P0L71`0820P09FEU@37alL0Ng]k09>CT`1>CTh0MgMg08B4
Q02][Jd0VIVI0;6a/@1oOgl08R8R020P802@T900XZ:R07QhN02ATI40OWin08F5Q@1:BTX0Jf][09:B
TP1RHV808b<S01lO7`0W9bL08R8R02@T901RHV80^k^k0;bl_02OWil0bl_;071`L00N7Qh071`L02HV
9P2JVYX0/K6a0;Jf]P1VIVHDooooo`004oooool0?`27QhL0MWIf08J6QP1QHF40N7Qh051@D01JFUX0
RHV9051@D01ADE40Vi^K051@D01FEUH0K6a/04I6AP1ADE40CDe=04Y:BP1RHV80IVIV04M7A`1VIVH0
@41004U9B@1ZJVX0:b/[06ATI01JFUX0@T9207=cL`1OGel0@41005ADE01/K6`0>3Ph04M7A`1dM7@0
?Cdm04Y:BP1lO7`0>c/k06=SH`1LG5`0C4a<05eMG@1IFET0O7al055AD@1OGel0Ogmo03Lg=`1GEeL0
IFEU0410@01MGEd0N7Qh03Ti>@1QHF40P8200410@01gMgL0MWIf04i>CP0207EeM@1:069RHP1TI6@0
JFUY05UIF@1VIVH0OWin05EEE@1FEUH0MgMg079bLP1UIFD0EeMG06e]K@1IFET0@T9206a/K01YJFT0
@T9209:BTP1LG5`0ADE509:BTP1YJFT0DE5A08^;R`1KFe/0KFe]07MgM`1SHf<0Ng]k04];B`1cLg<0
GemO03Ti>@1^KVh0IVIV05mOG`1aLG40Hf=S06e]K@21PH40?Shn06e]K@2DU9@0DE5A07emO@1[Jf/0
BDU908b<S01lO7`0LW9b05UIF@1QHF40IVIV05EEE@1XJ6P0GEeM05]KF`1gMgL0H61P06a/K01DE5@0
Lg=c05mOG`1JFUX0JVYZ0492@P13@d<0FUYJ05eMG@1]KFd0I6AT05ADE019BDT>ooooo`1[05IFEP1E
EED0DE5A051@D019BDT0@d=3059BDP1KFe/0F5QH04M7A`0e=CD0ADE504a<C017AdL0H61P05ADE01E
EED0G5aL051@D014A4@0Bd];05QHF01NGUh0Jf][08>3P`1LG5`0F5QH04];B`1KFe/0CTi>065QH@1A
DE40CTi>05MGE`1:BTX0Hf=S061PH01CDe<0EeMG055AD@0j>SX0?clo03Hf=P14A4@0@41004E5A@1:
BTX0ATI604M7A`10@400EUIF04a<C010@400GEeM04U9B@1ZJVX0?clo06EUI@16ATH0FUYJ06m_K`1V
IVH0Fe]K08N7Q`21PH40IFEU08^;R`1_Kfl0IfMW06QXJ01LG5`0DE5A04U9B@1IFET0JFUY05aLG01V
IVH0L71`05UIF@2c/k<0Cdm?06QXJ01dM7@0FUYJ05mOG`1ADE40O7al07YjNP1RHV80DU9B09:BTP1S
Hf<0G5aL06EUI@1HF5P0GUiN04i>CP1EEED0AdM706a/K01RHV80EUIF06ATI01=CDd0?clo04=3@`1<
C4`00P1EEED03P1KFe/0H61P07AdM01?Cdl0G5aL05eMG@13@d<0FUYJ05IFEP1PH600E5AD07alO01R
HV80Ogmo0P1QHF403`1IFET0GEeM08Z:RP1FEUH0QXJ60:FUY@2>SXh0R8R806m_K`1KFe/0GEeM05AD
E029RHT0MWIf0861P@0>ooooo`0:06UYJ@1MGEd0Cdm?06e]K@0d=3@0>CTi04A4A00c<c<0;2`/0410
@0808B4Q0100@d=303Hf=P1BDU80@T9203Xj>P13@d<0;bl_03hn?P1WIfL0;Rh^04i>CP0b<S80KFe]
06EUI@0n?Sh0=CDe0P11@D401017AdL0BTY:04M7A`0h>3P203Ti>@1X04a<C01WIfL0BTY:06QXJ022
PX80K6a/05mOG`1aLG40ADE503@d=01MGEd0SHf=05UIF@1VIVH0O7al04];B`1CDe<0G5aL061PH019
BDT0LW9b05IFEP1VIVH0D51@0492@P1ZJVX0EeMG07MgM`1LG5`0Kfm_05IFEP1mOGd0ADE505aLG01D
E5@0IFEU05QHF01lO7`0JVYZ05YJFP1LG5`0QHF506a/K01kNg/0_[jn06e]K@2=SHd0@T9208N7Q`26
QXH0FEUI08Z:RP1NGUh0@D5105aLG01nOWh0FUYJ05eMG@1KFe/0MWIf06QXJ01LG5`0>c/k07YjNP1S
Hf<0KFe]07UiN@2:RXX0MGEe07alO01IFET0KVi^06m_K`1MGEd0A4A4075aL@1KFe/0Hf=S096AT@1^
KVh0HV9R059BDP1eMGD0?Shn04m?C`0g=cL0H61P059BDP1OGel0Ph>304m?C`19BDT0Jf][0451@@1J
FUX0EUIF06MWI`1]KFd0SXj>04];B`1mOGd0EeMG06QXJ01ADE4>ooooo`0X09jNWP1EEED0H61P03`l
?00V9RH0B4Q8071`L01QHF40J6QX0;no_`38b<P0`L7108f=S@23Ph<0Xj>S09BDU01hN7P0UIFE0<30
`01NGUh0L71`05UIF@22PX80M7Ad03/k>`28R8P0];Bd092@T011@D407QhN02d];@0T92@0MGEe08V9
R@1bLW80GemO04e=C@0a<C40MWIf0820P080GUiN03H0LG5a06MWI`2=SHd0EeMG03`l?01`L700aLG5
0<K6aP1]KFd0?3`l04E5A@0L71`06ATI028R8P1SHf<0UYJF0:2PX02n_[h0WinO02LW9`0/;2`0LW9b
0410@00];Bd0BDU907]kN`1]KFd0KVi^03hn?P1>CTh061PH02XZ:P1FEUH0PX:209JFUP0`<3006ATI
01hN7P0h>3P0<S8b03dm?@0_;bl0RHV908N7Q`1[Jf/0C4a<06ATI02RXZ80=SHf01lO7`10@400f=SH
0=cLg01ZJVX201PH600Z02DU9@2SXj<0LW9b02@T901EEED0=SHf055AD@18B4P0NGUi07alO01DE5@0
[jn_038b<P0d=3@0Ng]k0:VYZ@0a<C40:BTY02DU9@0f=SH0B4Q80;bl_01gMgL0YJFU05YJFP1=CDd0
=SHf04A4A01XJ6P0ZZZZ0<?3``38b<P0^KVi0820P00Y:BT06a/K02@T901bLW80Bd];06QXJ02_[jl0
IfMW5?ooool001?ooooo00d0MgMg06e]K@1UIFD0L71`06e]K@1IFET0G5aL06EUI@1`L700ATI605UI
F@1fMWH0@4100080J6QX00h0@d=305MGE`1^KVh0B4Q8051@D01^KVh0D51@061PH028R8P0C4a<06IV
IP1fMWH0<C4a061PH080BTY:0500JVYZ04E5A@1IFET0IFEU04Q8B01MGEd0Fe]K055AD@1mOGd0FEUI
05aLG01WIfL0B4Q804i>CP1fMWH0G5aL051@D01KFe/0GUiN051@D01XJ6P0G5aL04Y:BP1RHV80EEEE
05QHF01[Jf/0Hf=S05EEE@1nOWh0Jf][05]KF`1[Jf/0GemO07IfMP1LG5`0HF5Q09:BTP13@d<0Ogmo
07alO00n?Sh0Lg=c08>3P`0o?cl0Jf][06ATI01EEED0FEUI09NGU`1@D500JVYZ08>3P`1gMgL0SHf=
08^;R`1dM7@0Kfm_06e]K@1SHf<0MWIf07UiN@2NWYh0N7Qh05mOG`2TY:@0G5aL05mOG`27QhL0JFUY
07inOP1:BTX0GUiN07=cL`1DE5@0EeMG06EUI@1jNWX0MGEe04a<C080Ph>301X0=SHf06i^KP2PX:00
?Cdm06EUI@2=SHd0<C4a05iNGP2<S8`0:2PX07moO`1WIfL0Cdm?08f=S@1CDe<0D51@06IVIP1SHf<0
B4Q806e]K@1fMWH0B4Q806i^KP1MGEd0EUIF06m_K`kooooo03`0FEUI059BDP1@D500FUYJ04i>CP15
ADD0EUIF05iNGP1MGEd0DE5A03dm?@1ADE40BTY:04A4A01HF5P0EeMG05YJFP1SHf<0Cdm?0451@@1>
CTh0C4a<059BDP1DE5@0KVi^04A4A01HF5P0B4Q806EUI@1EEED0Hf=S04e=C@1;Bd/0CDe=05EEE@1X
J6P0HV9R04M7A`1BDU80D51@03`l?012@T80<c<c04M7A`1<C4`0De=C05mOG`1?Cdl0E5AD0410@01I
FET0@d=303/k>`1EEED0DU9B05UIF@18B4P0MgMg05iNGP1HF5P2065QH@0<04Y:BP1iNGT0Ti>C06UY
J@2>SXh0JVYZ05UIF@1MGEd0L71`04m?C`1ADE40C4a<0P1LG5`03`1GEeL0K6a/07alO02o_kl0Ng]k
06a/K01[Jf/0IVIV05iNGP14A4@0Kfm_05MGE`1DE5@0D51@09RHV002069RHP0_05]KF`1TI6@0J6QX
04U9B@1NGUh0EeMG065QH@1jNWX0DU9B05MGE`1>CTh0>3Ph04Q8B01:BTX0HV9R04];B`1:BTX0EeMG
07]kN`1<C4`0BTY:05IFEP13@d<0HV9R04i>CP1EEED0E5AD05iNGP1GEeL0J6QX04U9B@1YJFT0EUIF
06][J`2FUYH0EEEE06][J`1hN7P0Ph>307QhN01IFET0HF5Q04m?C`1CDe<0L71`07=cL`1kNg/03_oo
ool0J@1OGel0LG5a05=CD`2KVi/0@d=30451@@1EEED0?Shn03Ph>018B4P09bLW02<S8`0j>SX0=3@d
061PH01<C4`0A4A404i>CP0j>SX0=SHf07MgM`0k>c/0BDU904E5A@23Ph<0@41004Q8B00l?3`0@410
05=CD`1FEUH0BTY:051@D00l?3`0A4A403@d=01<C4`0EeMG0492@P1<C4`0MgMg05]KF`1]KFd0JFUY
04i>CP0/;2`0I6AT09FEU@18B4P0Lg=c079bLP1CDe<0F5QH04U9B@1PH600G5aL07MgM`1PH600C4a<
059BDP1>CTh0J6QX061PH01eMGD0GEeM07=cL`1CDe<0Lg=c04M7A`1VIVH0HV9R07IfMP1YJFT0Y:BT
06e]K@1cLg<0OGem08f=S@1WIfL0P8200<71`@1GEeL0TI6A04M7A`22PX80QXJ605EEE@1aLG40H61P
03lo?`1QHF40R8R805aLG01QHF40De=C07MgM`1^KVh0Hf=S03`l?01cLg<0FUYJ07IfMP14A4@0J6QX
07MgM`0205]KF`0Q07QhN01HF5P0HV9R04Q8B01UIFD0EeMG05UIF@2BTY80GUiN04i>CP1JFUX0E5AD
03`l?01BDU80:2PX05IFEP19BDT0LW9b08F5Q@15ADD0Fe]K06MWI`0a<C40Hf=S05]KF`1?Cdl0Hf=S
096AT@12@T80F5QH05UIF@1`L700EEEE00kooooo04h0G5aL06m_K`1WIfL0DE5A06a/K01SHf<0IfMW
07UiN@0Y:BT0Z:RX0;:b/P1[Jf/0;2`/038b<P1GEeL0M7Ad04=3@`0i>CT0P82006ATI01WIfL0SXj>
02TY:@2?Shl0CTi>05iNGP1QHF40@d=304Y:BP1TI6@0JFUY06i^KP1bLW80`l?309jNWP1DE5@0>CTi
07]kN`1=CDd09bLW020P800b<S80?clo06ATI02XZ:P0Zj^[0;Bd]01bLW80Jf][07=cL`2j^[X0A4A4
03hn?P16ATH0<S8b06][J`1TI6@0=3@d059BDP2e]KD0[Jf]03lo?`1?Cdl0J6QX051@D00c<c<0=SHf
07emO@1hN7P0>c/k06=SH`23Ph<0F5QH03<c<`0Q8B40P8200<;2`P0k>c/201LG5`0l01lO7`13@d<0
@T9202TY:@1[Jf/0>c/k02@T901OGel0W9bL0;Jf]P1QHF40GemO09BDU02e]KD0^;Rh0;no_`0n?Sh0
>CTi071`L03:b/X0HV9R02<S8`1BDU80ATI6034a<@0c<c<0L71`0492@P14A4@0]kNg07MgM`1MGEd0
EeMG07AdM00T92@06QXJ01TI6@0G5aL0Ph>30;Fe]@21PH40O7al04A4A01:BTX0Q8B406IVIP21PH40
NWYj06YZJP3=cLd0b/[:04E5A@17AdL07QhN065QH@19BDT0ATI609nOW`2NWYh0NGUi5?ooool001?o
oooo08/0MgMg06e]K@1dM7@0K6a/069RHP1OGel0EeMG06QXJ01TI6@0AdM706e]K@1XJ6P0@D5105mO
G`1KFe/0@41005=CD`1MGEd0A4A4071`L01QHF40B4Q805MGE`1XJ6P0E5AD04];B`1HF5P0@d=304Y:
BP1LG5`0FEUI0492@P1=CDd0Kfm_0492@P1CDe<0JFUY0451@@1=CDd0IFEU03Lg=`1FEUH0F5QH03lo
?`1LG5`0DU9B051@D01DE5@0B4Q806IVIP1<C4`0EeMG06IVIP1<C4`0HF5Q06i^KP1:BTX0FEUI07Ui
N@1KFe/0IfMW07IfMP1YJFT0K6a/07alO01]KFd0A4A406a/K01YJFT0CDe=096AT@1WIfL0F5QH07Qh
N01RHV80LG5a06][J`1JFUX0M7Ad06MWI`1^KVh0J6QX05iNGP1UIFD0KFe]05mOG`1_Kfl0LG5a05=C
D`1gMgL0HV9R061PH01ZJVX0Lg=c07EeM@1DE5@0PX:206][J`1XJ6P0F5QH07=cL`1iNGT0EeMG06IV
IP1kNg/0LW9b05EEE@1ZJVX0PH6106a/K01bLW80NGUi08^;R`1DE5@0N7Qh08F5Q@1OGel0GEeM07al
O01HF5P0KFe]07IfMP1=CDd0TI6A06a/K01PH600O7al05mOG`1FEUH0NWYj05mOG`1FEUH0Jf][055A
D@1JFUX0Kfm_059BDP1PH600Fe]K00kooooo0680I6AT05aLG01EEED0F5QH051@D014A4@0EeMG05mO
G`1ADE40C4a<03Lg=`19BDT0De=C04a<C01WIfL0GEeM05ADE01LG5`0FUYJ04I6AP1=CDd0F5QH04];
B`1?Cdl0N7Qh05ADE01NGUh0De=C065QH@1KFe/0JVYZ05UIF@1UIFD0IfMW04I6AP1TI6@0GemO04i>
CP1FEUH0BTY:04I6AP15ADD0=cLg04e=C@15ADD0BTY:05QHF01FEUH0AdM704a<C01IFET0BDU904i>
CP1EEED0F5QH069RHP1<C4`0IfMW061PH01LG5`0K6a/065QH@1PH600U9BD09VIV@1aLG40Ng]k07in
OP1TI6@0Hf=S075aL@1IFET0CTi>05=CD`1QHF40IFEU05IFEP1/K6`0J6QX0:NWY`1ADE40GEeM06][
J`1IFET0F5QH04e=C@1GEeL0H61P04a<C01EEED0Ph>3079bLP1ADE40G5aL03hn?P1<C4`0F5QH05IF
EP80FEUI02H0Hf=S05UIF@1cLg<0Cdm?03dm?@15ADD0AdM705ADE015ADD0C4a<04A4A01fMWH0@d=3
04U9B@1@D500?clo065QH@1GEeL0Cdm?05IFEP1IFET0G5aL05mOG`1GEeL0IFEU04];B`1OGel0SHf=
04e=C@1WIfL0Kfm_06IVIP1ZJVX0EUIF05=CD`1@D500EeMG07QhN080MWIf3_ooool0NP1NGUh0KFe]
06YZJP1gMgL0?Cdm04E5A@1<C4`0Bd];03dm?@1<C4`0;2`/024Q8@14A4@0@41005EEE@1LG5`0<S8b
05ADE00e=CD0<S8b06YZJP0o?cl0D51@05=CD`1XJ6P0Bd];04m?C`0_;bl0D51@05]KF`1@D500HF5Q
04=3@`14A4@0BDU903lo?`19BDT0Fe]K065QH@19BDT0KFe]07UiN@1TI6@0EEEE08b<S00o?cl0GUiN
07alO01HF5P0K6a/07IfMP1MGEd0Jf][05EEE@1RHV80H61P075aL@1UIFD0DE5A051@D01DE5@0HV9R
06UYJ@1SHf<0EEEE06EUI@1RHV80M7Ad05QHF01nOWh0F5QH061PH01[Jf/0PH6105UIF@1]KFd0I6AT
08Z:RP1YJFT0K6a/0:VYZ@1jNWX0U9BD04a<C02IVIT0DU9B05iNGP2FUYH0FUYJ05IFEP1=CDd0P820
075aL@1OGel0B4Q808:2PP1VIVH0Cdm?05ADE01oOgl0HV9R07=cL`1IFET0QXJ606i^KP1hN7P0LW9b
07=cL`1HF5P0IFEU03/k>`1FEUH0DE5A05QHF02?Shl0G5aL06IVIP1=CDd0GEeM04Y:BP1;Bd/09BDU
0P1SHf<0401QHF40M7Ad04m?C`1CDe<0E5AD065QH@1IFET0De=C05MGE`1>CTh0DU9B04I6AP1QHF40
CTi>06][J`1LG5`>ooooo`0e030`<00U9BD09bLW0451@@2HV9P0?Cdm01hN7P0a<C40Ng]k03lo?`0W
9bL0G5aL05eMG@12@T80=cLg04M7A`1:BTX08R8R03Xj>P1mOGd0D51@06e]K@1MGEd0IFEU0410@00j
>SX0<C4a038b<P0i>CT0=3@d02l_;`1ZJVX0>SXj06m_K`1nOWh09RHV02LW9`20P800HF5Q03lo?`0g
=cL0;bl_03dm?@1@D500OWin09^KV`2HV9P0ADE506QXJ02=SHd0_Kfm09>CT`2KVi/00P2e]KD0E@24
Q8@0>CTi05eMG@1fMWH0N7Qh0:b/[025QHD0TY:B05aLG01/K6`0Rh^;09ZJVP1gMgL0Xj>S07alO02?
Shl0/k>c05aLG00N7Qh0:RXZ07emO@2SXj<0H61P038b<P0J6QX05ADE02HV9P18B4P0<C4a04i>CP0O
7al07QhN03Ph>025QHD0V9RH04M7A`0l?3`0CTi>09BDU01DE5@0MgMg0;^k^`26QXH0AdM709NGU`1a
LG40Ogmo08N7Q`0f=SH0=3@d059BDP1IFET0=cLg069RHP2/[:`0PX:209BDU02KVi/0WYjN03Ti>@0P
82006ATI03Xj>P23Ph<0J6QX0:NWY`2e]KD0N7Qh059BDP1gMgL0N7Qh05UIF@1aLG40Xj>S0<C4a01Z
JVX0DU9B07UiN@1TI6@0JFUY06EUI@0m?Cd0H61P02/[:`1NGUh05?ooool001?ooooo08/0O7al07Ad
M01^KVh0I6AT06EUI@1ADE40J6QX06MWI`1?Cdl0J6QX07MgM`1:BTX0GEeM06MWI`19BDT0D51@04=3
@`10@400GUiN05MGE`15ADD0HV9R051@D01PH600J6QX03De=@2>SXh0KVi^0410@02;Rh/0GemO04M7
A`1eMGD0L71`04E5A@1[Jf/0Hf=S04e=C@1JFUX0FEUI04Q8B01GEeL0E5AD061PH01ADE40Cdm?06a/
K018B4P0DU9B07alO00i>CT0F5QH07UiN@0f=SH0EeMG0820P00c<c<0HF5Q07YjNP10@400P82007Mg
M`10@400IVIV06YZJP1QHF40JVYZ06EUI@1SHf<0L71`07YjNP1RHV80IFEU069RHP1lO7`0M7Ad06YZ
JP1_Kfl0F5QH04M7A`26QXH0IVIV055AD@1nOWh0HF5Q04];B`2:RXX0GEeM05iNGP2:RXX0IfMW06e]
K@1bLW80HF5Q07QhN01BDU80QHF506][J`16ATH0OGem06e]K@1VIVH0N7Qh05EEE@1TI6@0RHV902`/
;01eMGD0Ogmo03hn?P22PX80Hf=S065QH@1aLG40KFe]08B4Q01GEeL0IfMW07alO019BDT0FUYJ08F5
Q@1?Cdl0LG5a079bLP1@D500H61P08b<S015ADD0GEeM07emO@12@T80CTi>05mOG`1ADE40D51@07Ee
M@1HF5P0DU9B00kooooo01X0GUiN05MGE`1LG5`0EeMG04e=C@13@d<0FEUI06IVIP1JFUX0Cdm?0410
@018B4P0Bd];04U9B@1JFUX0EEEE069RHP1SHf<0GemO04e=C@1@D500HV9R05]KF`1HF5P0KFe]04i>
CP80EUIF05X0BTY:05MGE`1RHV80DU9B05MGE`1nOWh0>3Ph05mOG`1UIFD0HV9R06MWI`1?Cdl0Fe]K
04e=C@17AdL0D51@03lo?`0e=CD0?Shn055AD@0j>SX0Cdm?059BDP15ADD0De=C04];B`1PH600KVi^
06ATI01KFe/0FEUI05mOG`1[Jf/0KVi^06ATI02<S8`0O7al07IfMP1eMGD0QXJ605QHF01IFET0L71`
05]KF`1;Bd/0G5aL05MGE`1NGUh0@T9205MGE`1[Jf/0_[jn05QHF01bLW80PH6106QXJ01GEeL0A4A4
059BDP1_Kfl0Cdm?05YJFP2;Rh/0PX:2055AD@1MGEd0Cdm?051@D01EEED0@4100451@@1MGEd0Ng]k
061PH01OGel0@D5103`l?00n?Sh0@41004i>CP10@400DE5A03lo?`25QHD0?Cdm05QHF01XJ6P0Hf=S
04e=C@1JFUX205eMG@0D05IFEP1RHV80J6QX04i>CP1GEeL0De=C05UIF@2@T900De=C079bLP1dM7@0
IVIV07IfMP1@D500Cdm?06a/K01BDU80RHV9079bLP1XJ6P>ooooo`0E05YJFP1]KFd0F5QH08:2PP10
@400>SXj055AD@1:BTX0BDU905eMG@0Q8B40>3Ph04m?C`11@D40D51@059BDP17AdL0Fe]K03De=@0o
?cl0C4a<0080@T9202`0ADE5071`L018B4P0EUIF03Hf=P1JFUX0A4A40451@@1`L700>SXj04];B`1B
DU80D51@05]KF`1?Cdl0HV9R05YJFP22PX80IfMW06YZJP1BDU80Xj>S03/k>`1NGUh0Shn?05UIF@1_
Kfl0IVIV07AdM01HF5P0AdM705]KF`10@400IVIV05QHF00n?Sh0D51@05MGE`1SHf<0MGEe06e]K@1H
F5P0Hf=S065QH@80GUiN02D0Jf][059BDP1dM7@0Ng]k09BDU01MGEd0KFe]08B4Q022PX80EEEE07mo
O`2LW9`0NWYj07UiN@1<C4`0Ng]k079bLP1RHV80PX:204e=C@17AdL0Bd];08n?S`1WIfL0EUIF05AD
E01kNg/0HF5Q04i>CP1JFUX0G5aL06ATI01aLG40BDU907=cL`1GEeL0GUiN0080KVi^0200F5QH06AT
I014A4@0EUIF04A4A01GEeL0Rh^;05MGE`1SHf<0HV9R065QH@1<C4`0E5AD01hN7P1SHf<0HV9R0820
P01aLG40?3`l05UIF@17AdL0=SHf07IfMP1lO7`0A4A406YZJP1[Jf/0:RXZ04i>CP1GEeL0MWIf03/k
>`kooooo0440<S8b02<S8`0L71`06ATI03Hf=P1LG5`0:BTY05aLG02IVIT0Cdm?03Ti>@10@400EEEE
02l_;`0j>SX0;Bd]0:JVYP26QXH0T92@0;Bd]02k^k/0_[jn09fMW@2:RXX07alO01PH600Q8B40DE5A
03/k>`1TI6@0R8R80<?3``1=CDd0HV9R05=CD`0o?cl0@41005UIF@0W9bL0820P01hN7P0M7Ad071`L
04Y:BP2=SHd0LW9b08V9R@2^[Zh0[:b/06UYJ@0l?3`0JFUY04Y:BP1`L700[:b/09bLW02KVi/0FEUI
03<c<`1VIVH0Q8B405=CD`2UYJD0`L7108:2PP0209FEU@0K05=CD`1`L700D51@0:NWY`1KFe/0IFEU
0<?3``25QHD0FEUI08b<S01KFe/0?Cdm02TY:@0M7Ad061PH08N7Q`0c<c<0?clo02@T900R8R80KVi^
07MgM`1>CTh07QhN01lO7`0N7Qh0KFe]0080G5aL02`0b/[:07EeM@1<C4`0JFUY0:j^[P2i^KT0Xj>S
07=cL`0e=CD0EUIF05aLG00f=SH0FEUI0:BTY01ZJVX0820P01lO7`1MGEd0Bd];02`/;01HF5P0KFe]
07IfMP2PX:00MGEe09fMW@1;Bd/0ATI607EeM@1dM7@0FEUI03dm?@0n?Sh0KFe]06][J`2?Shl0MGEe
06=SH`1[Jf/0<c<c01lO7`0R8R80:b/[05aLG1Cooooo000Cooooo`0k07AdM029RHT0JVYZ06m_K`1^
KVh0GUiN06MWI`1bLW80HF5Q04U9B@1BDU80JFUY03`l?01]KFd0GemO02l_;`1ADE40MGEe03lo?`1L
G5`0MGEe03Ti>@1FEUH0K6a/03/k>`1?Cdl0CTi>038b<P1PH600Bd];04a<C01/K6`0AdM706][J`1H
F5P0@d=307AdM01ADE40ADE508J6QP14A4@0D51@06YZJP11@D40D51@05mOG`1=CDd0FEUI06YZJP1N
GUh0BDU905UIF@1=CDd0CTi>05IFEP1HF5P0J6QX065QH@1JFUX00P1[Jf/03`1`L700MWIf05iNGP1i
NGT0O7al03De=@1SHf<0M7Ad02l_;`1dM7@0QHF503Ti>@1[Jf/0IFEU0492@P0206a/K00m04M7A`1h
N7P0MGEe05aLG01XJ6P0HF5Q071`L01ADE40F5QH07alO01FEUH0FUYJ071`L023Ph<0Hf=S0:FUY@1O
Gel0DU9B09JFUP1OGel0I6AT05QHF01cLg<0OGem04Q8B01aLG40MGEe061PH01WIfL0EEEE08J6QP2;
Rh/0EeMG07=cL`2<S8`0CTi>07YjNP23Ph<0Cdm?07YjNP22PX80=SHf05ADE01^KVh0?3`l06i^KP1M
GEd0I6AT08>3P`1JFUX0IVIV07]kN`1SHf<0Fe]K0861P@1MGEd0Fe]K07moO`1IFET0HV9R05UIF@0>
ooooo`2<06YZJP1PH600EUIF05UIF@18B4P0@T9205ADE01RHV80FUYJ05UIF@0i>CT0CTi>0451@@1;
Bd/0KVi^065QH@1UIFD0J6QX06MWI`11@D40ATI605mOG`1?Cdl0C4a<06ATI016ATH0F5QH04A4A01D
E5@0CTi>05aLG01EEED0Cdm?06EUI@13@d<0Ph>307IfMP1EEED0FEUI04M7A`15ADD0?3`l03lo?`1:
BTX0@d=30410@01;Bd/0B4Q803/k>`1?Cdl0D51@04];B`1=CDd0HF5Q07AdM01OGel0IFEU06MWI`1F
EUH0JVYZ06ATI01YJFT0IVIV06YZJP29RHT0JFUY071`L023Ph<0Fe]K05aLG01EEED0E5AD05QHF01U
IFD0G5aL05iNGP1CDe<0KFe]05]KF`2HV9P0GemO06i^KP1UIFD0IfMW05UIF@1BDU80EeMG079bLP1M
GEd0IfMW08^;R`28R8P0GEeM05YJFP0i>CT0De=C05eMG@1SHf<0DE5A07AdM01TI6@0Cdm?05iNGP1G
EeL0=cLg03dm?@13@d<0EeMG0451@@1?Cdl0@D51079bLP12@T80Bd];05aLG01WIfL0HV9R05mOG`1J
FUX0Bd];04e=C@1LG5`0J6QX059BDP1NGUh0@d=306EUI@2=SHd0ATI607emO@1/K6`0G5aL05ADE01I
FET0DE5A071`L01@D500MGEe07MgM`29RHT>ooooo`0A05iNGP1IFET0MGEe09VIV@0_;bl0>SXj03Ph
>01KFe/0=cLg04E5A@0`<300;Bd]04I6AP0c<c<0>3Ph061PH01FEUH00P0f=SH0I00j>SX0I6AT03`l
?011@D40EEEE05iNGP1EEED0EeMG034a<@1EEED0DU9B03<c<`1XJ6P0=CDe04a<C01LG5`0CTi>05iN
GP1HF5P0JFUY04M7A`1CDe<0PX:205YJFP10@400W9bL05MGE`1IFET0L71`075aL@1NGUh0KVi^06YZ
JP1`L700DE5A05=CD`1;Bd/0FEUI05]KF`0o?cl0ADE505QHF01TI6@0LG5a06IVIP1EEED0F5QH07mo
O`14A4@0FEUI07IfMP0g=cL0M7Ad069RHP1nOWh0ADE506IVIP1/K6`0RXZ:06][J`1QHF40L71`08b<
S028R8P0>CTi07emO@1dM7@0De=C08j>SP1;Bd/0CDe=059BDP2>SXh0L71`04a<C011@D40Ph>306=S
H`1;Bd/0KFe]05EEE@14A4@0Q8B405QHF022PX80DU9B05eMG@1/K6`0QXJ605QHF01JFUX0A4A4065Q
H@1=CDd0?Shn07alO01/K6`0D51@05mOG`1MGEd204Y:BP0C02LW9`1ZJVX0EUIF05IFEP1RHV80E5AD
06m_K`1?Cdl0ADE505QHF01SHf<0?3`l08>3P`1lO7`07alO03lo?`1HF5P0GUiN02d];@0>ooooo`1B
03Xj>P0T92@071`L01LG5`0O7al0M7Ad0:BTY029RHT0U9BD04M7A`11@D40=cLg038b<P17AdL0DE5A
03hn?P1QHF40;Rh^04Y:BP2o_kl0Z:RX09ZJVP1>CTh0=cLg07EeM@1CDe<0EeMG04A4A01LG5`0SHf=
04e=C@0o?cl0TI6A0;Ng]`25QHD0SHf=079bLP0k>c/07QhN01`L700J6QX07AdM01XJ6P15ADD0J6QX
07moO`2KVi/0];Bd09nOW`2l_;`0IfMW03Xj>P2>SXh0UIFE08>3P`2VYZH0]kNg071`L00m?Cd0>SXj
04M7A`1EEED0_;bl0<W9b@1WIfL0BTY:05ADE01CDe<0JFUY06IVIP1DE5@0FUYJ061PH02NWYh0IfMW
020P800K6a/0J6QX05ADE00o?cl0F5QH05aLG080W9bL00H0N7Qh06IVIP1nOWh0^;Rh0;^k^`0i>CT2
01dM7@0`01lO7`10@400:2PX03Lg=`2FUYH0=cLg03De=@1OGel0EEEE09bLW02TY:@0QhN702<S8`0_
;bl0HV9R0820P02b/[80`<3005iNGP14A4@0>c/k071`L020P800M7Ad0:n_[`1SHf<0OWin09>CT`25
QHD0I6AT0;Zj^P1@D500?Cdm03<c<`0V9RH08b<S01lO7`12@T80FEUI08B4Q01/K6`0>3Ph03De=@0a
<C4071`L01lO7`0[:b/0Shn?5?ooool001?ooooo08/0PX:206YZJP1bLW80GemO05eMG@1TI6@0CDe=
08R8R01RHV80GEeM07QhN01DE5@0DU9B0861P@14A4@0E5AD06QXJ013@d<0F5QH05eMG@11@D40H61P
05MGE`1UIFD0NGUi03Lg=`1JFUX0JVYZ03Lg=`1dM7@0QHF503lo?`1fMWH0SHf=03hn?P1VIVH0Ogmo
04=3@`1>CTh0EeMG04I6AP1RHV80BTY:075aL@1PH600@d=3071`L01NGUh0?Shn07inOP1>CTh0E5AD
07alO00m?Cd0De=C08j>SP0j>SX0FUYJ08>3P`0o?cl0Jf][07QhN01=CDd0De=C08f=S@1@D500F5QH
06a/K01JFUX0HV9R07EeM@1DE5@0Hf=S06a/K01RHV80KVi^05aLG01WIfL0Lg=c04m?C`1bLW80LG5a
04Y:BP2RXZ80Ng]k05QHF02VYZH0Hf=S04a<C027QhL0D51@06EUI@1gMgL0IfMW06][J`1KFe/0LW9b
08j>SP1CDe<0DU9B0820P01dM7@0Lg=c05eMG@1VIVH0VYZJ0492@P1YJFT0LG5a04Y:BP29RHT0PH61
05iNGP24Q8@0I6AT06MWI`1ZJVX0G5aL08B4Q01/K6`0EUIF07UiN@1UIFD0Hf=S06a/K01DE5@0FUYJ
07QhN019BDT0FUYJ07QhN019BDT0ADE5069RHP1DE5@0IVIV07moO`1BDU80Bd];00kooooo00H0JFUY
05=CD`1HF5P0De=C04E5A@1:BTX2069RHP0=05MGE`1LG5`0>c/k04I6AP17AdL0CTi>05mOG`1QHF40
IVIV05aLG01MGEd0@D5104];B`0204m?C`1:04Q8B01]KFd0@d=305ADE017AdL0EUIF04];B`1LG5`0
Cdm?05aLG01SHf<0D51@079bLP1WIfL0G5aL06EUI@1DE5@0Bd];04a<C01;Bd/0DE5A04m?C`1:BTX0
Fe]K0492@P1BDU80Cdm?05mOG`1<C4`0Fe]K06QXJ01YJFT0EUIF071`L01JFUX0EUIF079bLP1/K6`0
HF5Q05YJFP1jNWX0QXJ606m_K`1KFe/0Ogmo05MGE`1MGEd0FEUI05EEE@1UIFD0Jf][06QXJ01VIVH0
DE5A06EUI@1cLg<0][Jf05ADE01iNGT0GemO06MWI`19BDT0D51@05iNGP1@D500K6a/06=SH`2OWil0
TY:B06i^KP1CDe<0CDe=05UIF@1PH60205ADE00Y07MgM`1oOgl0D51@065QH@18B4P0>c/k04A4A01B
DU80EeMG04U9B@1=CDd0BTY:08n?S`1LG5`0EUIF04m?C`1:BTX0CDe=05]KF`1JFUX0EeMG04a<C01^
KVh0PX:204m?C`1KFe/0@d=305iNGP24Q8@0DE5A08^;R`1nOWh0Ng]k06EUI@1EEED0BDU906ATI01S
Hf<0[:b/08:2PP1aLG403_ooool0501FEUH0HV9R05YJFP1oOgl0@T92034a<@10@400A4A403`l?019
BDT071`L03/k>`1=CDd0>3Ph05YJFP11@D40Lg=c04a<C00b<S80@T920P1:BTX0C00n?Sh0AdM706i^
KP1BDU80E5AD02h^;P1HF5P0DU9B030`<01/K6`0=SHf04Q8B01`L700@41005MGE`1DE5@0KVi^04U9
B@1UIFD0RHV9061PH01UIFD0[:b/055AD@1RHV80Ti>C07EeM@1^KVh0GEeM07QhN01IFET0AdM7065Q
H@1:BTX0J6QX05QHF00m?Cd0De=C055AD@1WIfL0G5aL069RHP1MGEd0BDU907UiN@1EEED0F5QH079b
LP10@400HF5Q04U9B@2=SHd0ATI606YZJP1[Jf/0GUiN05IFEP1oOgl0TY:B08B4Q027QhL0E5AD06][
J`1QHF40HV9R07moO`19BDT0?Shn04=3@`1oOgl0Cdm?05=CD`1;Bd/0QHF505YJFP14A4@205eMG@0K
04=3@`1hN7P0@41007UiN@17AdL0NWYj05IFEP1RHV80BTY:06][J`0o?cl0H61P0451@@19BDT0PH61
05EEE@1>CTh0Fe]K04Y:BP0c<c<0De=C030`<01?Cdl0<c<c07UiN@1OGel0;Rh^0080GEeM00/0?Shn
05aLG01/K6`0CTi>07YjNP1eMGD0?3`l03<c<`1QHF40M7Ad05QHF00>ooooo`0A05iNGP0a<C408R8R
02HV9P0/;2`0WYjN0;2`/02SXj<0N7Qh03<c<`0`<300=SHf02LW9`0h>3P0IVIV092@T01eMGD00P0n
?Sh0201PH600LW9b09>CT`1JFUX071`L07YjNP0a<C408b<S0P0F5QH0;P0k>c/0MGEe04E5A@2;Rh/0
[Zj^09ZJVP2EUID0/k>c05=CD`0d=3@0AdM702d];@0I6AT092@T06ATI00b<S80>SXj07emO@1ZJVX0
;bl_06a/K01OGel0/;2`08Z:RP1NGUh0Jf][0:ZZZP2NWYh0JFUY01TI6@0F5QH07QhN04m?C`2FUYH0
alO709:BTP1OGel0ADE502d];@1>CTh0:BTY034a<@1RHV80OWin07=cL`1:BTX201DE5@0o01dM7@1P
H600GemO096AT@1QHF40Cdm?09RHV02SXj<0Cdm?055AD@2d];@0a<C406ATI00X:2P071`L02/[:`0a
<C40?3`l06IVIP2SXj<0=cLg03@d=01aLG40Jf][03lo?`1ADE40IfMW08Z:RP1kNg/0`<300;no_`0d
=3@0Jf][08:2PP16ATH0@d=306UYJ@2[Zj/0Q8B40:RXZ025QHD0?Cdm04i>CP2BTY80@d=308>3P`0T
92@08b<S030`<00U9BD08R8R020P800a<C40Jf][07moO`1_Kfl0@41002XZ:P0T92@07AdM02@T901S
Hf<0_Kfm01Cooooo000Cooooo`0D07YjNP1mOGd0L71`06=SH`1QHF40AdM706ATI01aLG40AdM705QH
F01VIVH0DU9B05=CD`1lO7`0G5aL03lo?`1EEED0HV9R06UYJ@1KFe/205eMG@0Z04Y:BP1jNWX0EUIF
04Y:BP1GEeL0A4A405ADE01RHV80FEUI05ADE012@T80I6AT05mOG`1>CTh0KVi^04U9B@0n?Sh0FEUI
04Y:BP1BDU80JFUY04e=C@19BDT0KVi^05]KF`1CDe<0F5QH05UIF@0l?3`0G5aL05MGE`16ATH0EeMG
061PH01EEED0Fe]K05YJFP1UIFD0HF5Q06i^KP1aLG40K6a/0P1fMWH0901@D500Fe]K08Z:RP1BDU80
H61P07QhN012@T80JVYZ06e]K@1CDe<0Jf][06EUI@1NGUh0EeMG08V9R@1TI6@0IVIV08V9R@1WIfL0
JVYZ07]kN`1DE5@0EeMG07UiN@1ZJVX0Jf][04m?C`23Ph<0L71`051@D020P800JFUY05aLG01TI6@0
J6QX08F5Q@80G5aL01`0KVi^06MWI`1CDe<0Lg=c06MWI`1`L700IVIV07inOP28R8P0FEUI06a/K01k
Ng/0CDe=07=cL`20P800Cdm?05]KF`1hN7P0@41006YZJP1RHV80DE5A06YZJP1/K6`0@T9206a/K01H
F5P0FEUI0P1LG5`01@1<C4`0GUiN06YZJP1BDU80GEeM00kooooo0P1EEED0101ADE40F5QH055AD@16
ATH205aLG00705UIF@1BDU80?Cdm04=3@`12@T80B4Q806UYJ@0205iNGP1Q061PH01SHf<0@41004A4
A01>CTh0B4Q804A4A01DE5@0@41004Q8B010@400ADE504U9B@1BDU80BDU904Y:BP1PH600?clo06EU
I@1>CTh0DE5A04m?C`18B4P0?3`l03Xj>P1@D500?Shn03Lg=`0k>c/0Bd];03Ph>010@400@T9205MG
E`0n?Sh0GEeM06a/K01IFET0I6AT05QHF01NGUh0H61P06YZJP1OGel0IVIV06][J`1aLG40TY:B07Qh
N01jNWX0QhN704e=C@1DE5@0Hf=S05]KF`18B4P0IVIV05ADE01IFET0Cdm?06a/K01cLg<0XJ6Q05eM
G@1[Jf/0IVIV06ATI01CDe<0AdM7065QH@19BDT0HV9R05QHF02SXj<0Ogmo04m?C`1ADE40C4a<05mO
G`1LG5`0CTi>05YJFP1YJFT0O7al04i>CP1UIFD0B4Q803Ti>@2=SHd0EeMG05QHF015ADD0AdM704E5
A@1kNg/0C4a<05ADE00204e=C@0H04i>CP1ZJVX0Fe]K059BDP19BDT0Hf=S06YZJP1BDU80FEUI059B
DP1VIVH0T92@06=SH`29RHT0UIFE0820P01hN7P0H61P06QXJ01ZJVX0Fe]K08^;R`1]KFd0OWin3_oo
ool0901BDU80EUIF06e]K@1gMgL0@T9204A4A00c<c<0CTi>03Xj>P11@D40=cLg02LW9`1?Cdl0=3@d
04I6AP18B4P0JFUY03Ph>013@d<0@T9204m?C`1ADE40=CDe05=CD`1OGel0De=C05aLG00e=CD0Cdm?
05iNGP18B4P0Rh^;03Ph>01BDU80MGEe04A4A080D51@0240M7Ad051@D01KFe/0UIFE06EUI@1GEeL0
MWIf092@T01eMGD0PH610820P01RHV80EeMG06YZJP1UIFD0AdM705eMG@19BDT0GemO05ADE00e=CD0
DU9B05MGE`1IFET0GemO05aLG01OGel0@41008F5Q@15ADD0FEUI07=cL`0j>SX00P1TI6@0701UIFD0
@41006YZJP1RHV80FEUI065QH@1iNGT0QXJ60:6QX@2RXZ80CDe=069RHP1YJFT0Fe]K07=cL`17AdL0
@T9204a<C01eMGD0HF5Q04A4A00h>3P0S8b<05aLG00n?Sh0FUYJ05aLG00o?cl205aLG00U06e]K@0o
?cl0JVYZ069RHP1EEED0De=C06QXJ00l?3`0Fe]K04U9B@1:BTX0OGem065QH@1RHV80F5QH04i>CP1:
BTX0CTi>02DU9@1VIVH0DU9B06ATI01LG5`0EeMG04Q8B01:BTX0F5QH06YZJP1<C4`0D51@08:2PP1k
Ng/0De=C02PX:01NGUh0LG5a04];B`0>ooooo`0<069RHP1]KFd0MWIf079bLP1lO7`0]kNg0;6a/@2X
Z:P0T92@05ADE01;Bd/0F5QH0P0g=cL0301;Bd/0PX:204];B`1=CDd0De=C038b<P14A4@0?Shn06QX
J01lO7`0IfMW01TI6@@05ADE02d0EUIF08Z:RP1WIfL0V9RH0:JVYP1mOGd0L71`08Z:RP1NGUh0@410
02`/;00a<C40QXJ608V9R@0Z:RX0820P04M7A`1[Jf/061PH020P8014A4@0KVi^04=3@`0O7al0<c<c
05=CD`1MGEd0Bd];02HV9P0M7Ad07QhN028R8P1fMWH0Z:RX069RHP0O7al0:RXZ03`l?00a<C407QhN
01/K6`0a<C40Jf][06EUI@1KFe/00P0E5AD0;P0F5QH0FEUI0:2PX02>SXh0T92@08R8R01QHF40IfMW
0:^[Z`1nOWh0/[:b0;Bd]01dM7@0HF5Q06m_K`1jNWX0GemO04I6AP0n?Sh0LG5a05iNGP25QHD0EeMG
05mOG`2>SXh0FUYJ04Y:BP2HV9P0EUIF06ATI01bLW80OWin0:j^[P2][Jd0PX:207]kN`2MWId0_;bl
0;no_`36a/H0WYjN06a/K01eMGD0MgMg06EUI@1oOgl2020P800601`L700R8R807alO020P801>CTh0
W9bL0P2k^k/01`1_Kfl0JVYZ06i^KP2DU9@0Rh^;06QXJ02EUID05?ooool001?ooooo00H0LW9b07em
O@1QHF40MgMg05QHF01QHF4205aLG00Y069RHP0o?cl0DE5A07YjNP0o?cl0JVYZ06UYJ@0W9bL0G5aL
05YJFP0n?Sh0Jf][07YjNP0m?Cd0F5QH079bLP11@D40EeMG059BDP0i>CT0FEUI04a<C01FEUH0HV9R
04M7A`1hN7P0G5aL0451@@27QhL0BTY:055AD@1dM7@0<c<c05QHF01CDe<0?clo065QH@1FEUH0B4Q8
06MWI`12@T800P1;Bd/0F01LG5`0F5QH05]KF`0j>SX0KFe]05QHF00m?Cd0Ng]k07=cL`19BDT0Hf=S
07AdM01>CTh0Jf][07]kN`17AdL0GUiN06a/K015ADD0IFEU06QXJ01TI6@0N7Qh06=SH`1DE5@0M7Ad
05IFEP1_Kfl0FEUI05]KF`20P800EeMG071`L01/K6`0CTi>075aL@1OGel0BDU906UYJ@1bLW80Cdm?
06a/K029RHT0D51@05iNGP1fMWH0Hf=S07emO@1=CDd0HF5Q05eMG@19BDT0MWIf05mOG`1PH600G5aL
06EUI@20P800EeMG05EEE@2@T900KFe]04a<C020P800IFEU051@D01YJFT0JVYZ05mOG`1QHF40N7Qh
05=CD`27QhL0GEeM06=SH`1eMGD0E5AD06EUI@1^KVh0EEEE06a/K01=CDd0EUIF071`L015ADD0De=C
07MgM`0o?cl>ooooo`0A05iNGP1LG5`0FEUI05]KF`1>CTh0BTY:05aLG01YJFT0DU9B04m?C`0g=cL0
?3`l03hn?P1CDe<0L71`05]KF`1YJFT00P1`L70204Q8B00U04e=C@15ADD0ATI604U9B@16ATH0?Cdm
04A4A00g=cL0Bd];04m?C`1@D500BTY:05iNGP0j>SX0IfMW04];B`1<C4`0@d=303hn?P11@D40=3@d
0451@@0h>3P0:RXZ03dm?@13@d<0>CTi03lo?`1=CDd0FEUI04U9B@1KFe/0KFe]05eMG@1ZJVX0LW9b
06=SH`0205eMG@1@065QH@1GEeL0Ogmo07MgM`2:RXX0IVIV07emO@28R8P0A4A405EEE@1QHF40Hf=S
06ATI02;Rh/0GemO05MGE`1QHF40LW9b07emO@2_[jl0CDe=07=cL`1TI6@0J6QX04Y:BP0n?Sh0De=C
059BDP1LG5`0E5AD09FEU@1_Kfl0E5AD07]kN`1]KFd0IVIV05MGE`1@D500E5AD06][J`1aLG40A4A4
06YZJP1CDe<0ADE50492@P1BDU80Fe]K051@D01CDe<0AdM706EUI@19BDT0GemO05EEE@1:BTX0CDe=
06MWI`1EEED0Fe]K04E5A@1PH600J6QX06][J`1EEED0@d=305eMG@26QXH0GEeM07IfMP1mOGd0JVYZ
05]KF`1FEUH0EeMG04E5A@18B4P0N7Qh06MWI`1^KVh>ooooo`10055AD@19BDT0F5QH04Y:BP0_;bl0
?Shn034a<@0f=SH0:BTY03@d=00V9RH09BDU05EEE@0f=SH0?3`l03Xj>P1FEUH0>SXj04=3@`0l?3`0
>3Ph0492@P0j>SX0AdM706ATI01UIFD0GEeM03Ti>@1?Cdl0AdM703Ph>029RHT0>c/k04Y:BP1^KVh0
?Shn04I6AP14A4@0JFUY04A4A01RHV80YjNW06ATI01PH600A4A40<g=c@2a/K40UYJF09jNWP1cLg<0
FEUI08>3P`1QHF40FUYJ06i^KP1DE5@0GUiN05EEE@12@T80EeMG055AD@1QHF40Jf][05iNGP80JFUY
0380QXJ604a<C01ZJVX0N7Qh03lo?`1aLG40IVIV08Z:RP1VIVH0L71`06i^KP1PH600DE5A08F5Q@2K
Vi/0VIVI08Z:RP1_Kfl0D51@05aLG01^KVh0MWIf03Xj>P0k>c/0CTi>08f=S@1[Jf/0A4A4069RHP2K
Vi/0HV9R05MGE`1VIVH0M7Ad05aLG01SHf<0FUYJ069RHP10@400GUiN069RHP1KFe/0DE5A07moO`16
ATH0GUiN03/k>`1DE5@0OGem04e=C@80I6AT01H0C4a<04U9B@14A4@0>3Ph06i^KP17AdL0IfMW05IF
EP1RHV80E5AD05YJFP1mOGd0F5QH059BDP1UIFD0R8R804U9B@1`L7007AdM04U9B@1LG5`0GEeM3_oo
ool06P1CDe<0/[:b079bLP10@400=SHf071`L01;Bd/0K6a/0:BTY01bLW80GUiN05EEE@1fMWH0;Bd]
03dm?@2ZZZX0G5aL03Ti>@0U9BD0;2`/01/K6`0G5aL0:b/[079bLP2<S8`0BDU90P0E5AD0L00D51@0
6QXJ071`L00[:b/0;bl_05UIF@1GEeL08b<S01dM7@1JFUX0GUiN05mOG`1EEED0R8R808B4Q01MGEd0
JFUY06][J`2?Shl0RHV9024Q8@0F5QH09RHV05IFEP0a<C404Q8B02HV9P1lO7`0MgMg06=SH`1ZJVX0
A4A401hN7P0K6a/0Rh^;0=cLg01UIFD06a/K02XZ:P0g=cL08R8R01hN7P0H61P092@T05YJFP25QHD0
];Bd03/k>`0H61P0A4A40861P@1dM7@0T92@05iNGP1>CTh08b<S04m?C`1mOGd0:b/[055AD@1/K6`0
FEUI05mOG`1bLW80EUIF030`<010@400Cdm?05aLG00X:2P0][Jf0=7Ad@37alL0YJFU071`L01_Kfl0
MGEe03<c<`11@D40a/K60:^[Z`1SHf<0ADE503lo?`13@d<0Ng]k0:RXZ02BTY80FUYJ05mOG`0/;2`0
;bl_05UIF@1PH600UiNG02`/;00];Bd0@T9203<c<`0g=cL0NWYj07moO`2=SHd0ZJVY0:6QX@2LW9`0
[:b/0=?Cd`1lO7`0Cdm?06YZJP1LG5`Dooooo`004oooool0R`27QhL0LW9b071`L01IFET0IVIV05eM
G@1>CTh0Ti>C05]KF`1PH600JFUY03lo?`1`L700JFUY0451@@1NGUh0I6AT03dm?@1FEUH0IfMW0451
@@1SHf<0G5aL06YZJP1fMWH0;Rh^07]kN`1IFET0>SXj069RHP1YJFT0=cLg05ADE01]KFd0BDU904a<
C01UIFD0?clo05EEE@1VIVH0@41005aLG01IFET0GUiN051@D01UIFD0MgMg051@D01;Bd/0JFUY03Ti
>@1ADE40L71`03lo?`1ADE40LG5a04];B`1PH600CTi>05MGE`1lO7`0IfMW05ADE023Ph<0GEeM05AD
E01aLG40De=C06YZJP1TI6@0K6a/06][J`1bLW80K6a/06][J`1lO7`0Bd];06i^KP1XJ6P0ATI6096A
T@1YJFT0EeMG0:FUY@1ZJVX0Bd];09fMW@1KFe/0G5aL08Z:RP1@D500HF5Q06a/K01VIVH0RXZ:05EE
E@1QHF40L71`04];B`1[Jf/0L71`05QHF022PX80BTY:06ATI026QXH0:b/[07MgM`1hN7P0CDe=07Ee
M@1XJ6P0L71`05mOG`1LG5`0O7al055AD@1QHF40VIVI069RHP1IFET0X:2P05IFEP1BDU80PH6104a<
C01YJFT0Ng]k05=CD`1UIFD0LW9b05IFEP1RHV80KFe]04E5A@1UIFD0Kfm_04U9B@1QHF403_ooool0
O01CDe<0EEEE05IFEP1>CTh0IVIV051@D01SHf<0JVYZ05aLG01<C4`0>3Ph03Xj>P19BDT0C4a<06m_
K`1NGUh0IfMW069RHP1MGEd0BDU90492@P1=CDd0AdM704Y:BP1HF5P0CDe=04Y:BP11@D40CDe=05=C
D`1@D500C4a<04i>CP1GEeL0E5AD07MgM`1TI6@0C4a<051@D01IFET0?3`l0451@@17AdL0@D5103lo
?`16ATH0CTi>03hn?P1;Bd/0A4A4059BDP1>CTh0EeMG07YjNP1IFET0EeMG07alO010@400?clo05QH
F01`L700Cdm?08f=S@1mOGd0P82005UIF@1VIVH0RHV905IFEP0j>SX0BDU9059BDP1MGEd0GUiN05EE
E@16ATH0JFUY071`L02;Rh/0V9RH06][J`1SHf<0NWYj05eMG@1:BTX0Cdm?05IFEP1@D500H61P069R
HP2TY:@0UYJF05IFEP1_Kfl0FUYJ059BDP1SHf<0De=C04I6AP1XJ6P0K6a/04E5A@1JFUX0DU9B055A
D@17AdL0@T9205ADE012@T80CDe=04M7A`28R8P0EeMG04Q8B01NGUh0ATI604e=C@1>CTh0ATI605eM
G@1@D500E5AD05IFEP1BDU82051@D00405ADE026QXH0NWYj07MgM`80L71`00P0BTY:05QHF01IFET0
AdM703hn?P1mOGd0LW9b06m_K`kooooo03H0E5AD05QHF01]KFd0IfMW05aLG017AdL0=SHf04];B`0k
>c/0BTY:03<c<`0P8200ADE502/[:`16ATH0ADE5051@D00f=SH0CDe=0410@01CDe<0DU9B04M7A`1D
E5@0KFe]07EeM@1HF5P0A4A404Q8B01<C4`0GEeM0:f][@19BDT0BTY:06UYJ@0o?cl0De=C038b<P28
R8P0DE5A04e=C@2VYZH0LG5a05MGE`0^;Rh0Xj>S0=3@d01^KVh0SXj>06IVIP1KFe/0OWin069RHP1L
G5`206MWI`1D061PH01MGEd0C4a<05QHF01>CTh0Kfm_06i^KP1=CDd0IfMW05UIF@2ATI40@d=305UI
F@1^KVh0@D5106YZJP1SHf<0GemO05aLG01UIFD0KFe]04i>CP1XJ6P0TY:B06][J`2MWId0SHf=06QX
J01CDe<0JVYZ075aL@1JFUX0=SHf03@d=01>CTh0SHf=061PH01BDU80Hf=S07inOP1aLG40De=C05mO
G`1eMGD0JVYZ05YJFP1CDe<0EeMG04A4A01@D500JFUY04M7A`1=CDd0PH6104];B`15ADD0=SHf05]K
F`1cLg<0@41008N7Q`1KFe/0;Bd]05iNGP16ATH07alO065QH@1LG5`0MGEe059BDP1CDe<0G5aL04=3
@`1gMgL0K6a/03dm?@1HF5P0VYZJ05eMG@1UIFD09bLW065QH@1_Kfl0IfMW3_ooool04@1>CTh0BTY:
04I6AP0/;2`0820P024Q8@11@D40De=C0:VYZ@2?Shl0QHF509bLW01LG5`0;bl_02d];@2IVIT0GEeM
00808B4Q03P07alO01LG5`0E5AD05ADE04I6AP2?Shl0ZJVY07IfMP1KFe/0Hf=S08>3P`36a/H0IFEU
02@T901LG5`0C4a<01TI6@0H61P071`L05=CD`13@d<0KVi^08J6QP1MGEd0@410020P800T92@0A4A4
07AdM01`L700CDe=02XZ:P1XJ6P06ATI018B4P1OGel0OWin04I6AP0N7Qh0G5aL09BDU02SXj<0LW9b
0<?3``3De=@0`/;205ADE00j>SX06a/K01XJ6P0Y:BT0:2PX028R8P0f=SH0d];B0;Vi^@80YjNW03l0
WYjN06=SH`0f=SH0HF5Q08B4Q01YJFT0;bl_02h^;P0f=SH061PH01dM7@1DE5@0Q8B409JFUP1/K6`0
?Shn02LW9`19BDT0S8b<08V9R@11@D40_[jn07MgM`1jNWX0Rh^;05mOG`2LW9`0Jf][05]KF`23Ph<0
ZJVY0;Jf]P20P800:b/[04=3@`0^;Rh0QHF509^KV`1VIVH0>CTi03Ph>00b<S80;bl_03dm?@2<S8`0
YjNW0820P01GEeL0@41006UYJ@1oOgl0LW9b08Z:RP2BTY80K6a/09JFUP2ZZZX0^;Rh0:f][@27QhL0
/[:b0861P@1PH6005?ooool001?ooooo08H0MWIf07=cL`1MGEd0JVYZ05YJFP1OGel0JVYZ075aL@1E
EED0CDe=07=cL`1LG5`0Fe]K06m_K`1PH600AdM706EUI@1SHf<0E5AD04a<C01aLG40D51@05QHF01c
Lg<0De=C05UIF@1LG5`0B4Q805QHF01LG5`0EEEE05UIF@1BDU80GEeM05YJFP15ADD0HV9R05QHF01@
D500DU9B05IFEP1BDU80G5aL059BDP18B4P0EeMG06QXJ01EEED0C4a<06=SH`16ATH0HV9R06QXJ01F
EUH0EEEE06=SH`1RHV80De=C05UIF@1cLg<0DU9B07UiN@1dM7@0EUIF06MWI`1hN7P0HV9R05YJFP1g
MgL0AdM706m_K`1XJ6P0CTi>06ATI01mOGd0GEeM06ATI01bLW80GUiN065QH@1kNg/0H61P05iNGP2H
V9P0HV9R05=CD`1lO7`0JFUY05ADE01_Kfl0HV9R06EUI@1VIVH0Ng]k079bLP1QHF40O7al05eMG@1Z
JVX0HF5Q05iNGP1eMGD0GUiN06=SH`1VIVH0GUiN04m?C`1_Kfl0IVIV06EUI@1YJFT0O7al08B4Q01?
Cdl0K6a/0820P015ADD0KFe]07=cL`19BDT0GEeM07QhN01:BTX0Lg=c07EeM@1@D500MWIf06MWI`1C
De<0N7Qh05aLG01MGEd0I6AT06YZJP80F5QH00<0L71`05YJFP1TI6@03_ooool02P1GEeL0J6QX05]K
F`1MGEd0FEUI04e=C@1PH600GemO04i>CP1<C4`203hn?P0n04=3@`1BDU80K6a/05]KF`1PH600I6AT
061PH017AdL0BDU904Y:BP13@d<0A4A4051@D018B4P0>3Ph03`l?00d=3@0BTY:055AD@1>CTh0BTY:
05EEE@0l?3`0JFUY05MGE`1EEED0D51@05MGE`0h>3P0?Shn04M7A`0m?Cd0@T9203/k>`1@D500>c/k
03lo?`14A4@0Fe]K04m?C`1HF5P0LG5a05MGE`1XJ6P0JVYZ05QHF019BDT0IFEU065QH@1HF5P0YJFU
08f=S@1YJFT0JVYZ065QH@1eMGD0EEEE04E5A@1EEED0CTi>055AD@1VIVH204E5A@1006MWI`1MGEd0
Lg=c096AT@1UIFD0HF5Q06][J`1TI6@0CDe=04];B`1=CDd0B4Q805aLG01KFe/0UYJF07]kN`1NGUh0
M7Ad04m?C`1IFET0FUYJ04U9B@11@D40H61P05eMG@17AdL0ADE504I6AP0n?Sh0B4Q804U9B@1IFET0
@41004I6AP1>CTh0N7Qh059BDP14A4@0Hf=S0451@@1EEED0DU9B05ADE01UIFD0BTY:04m?C`1EEED0
Bd];0492@P1=CDd0EEEE06][J`1QHF40K6a/065QH@1ZJVX0Fe]K05MGE`1NGUh0CTi>04a<C01]KFd0
L71`07IfMPkooooo03H0CTi>05MGE`1QHF40CTi>051@D014A4@0>CTi0451@@0[:b/0>CTi02`/;00a
<C40?3`l03Xj>P0k>c/0>3Ph05IFEP0h>3P0De=C03Hf=P0l?3`0FUYJ03De=@1>CTh0De=C06EUI@13
@d<0?3`l04E5A@1LG5`0CDe=09bLW00h>3P0@T9205YJFP0n?Sh0BTY:03@d=01dM7@0BTY:05aLG02/
[:`0GUiN059BDP0h>3P0QhN706UYJ@1]KFd0YZJV05iNGP1MGEd0KFe]055AD@1;Bd/205]KF`1D04m?
C`1HF5P0B4Q805]KF`1>CTh0IfMW06ATI01DE5@0EeMG06e]K@2?Shl0BTY:06ATI01hN7P0?Shn075a
L@1cLg<0GUiN07IfMP1KFe/0JVYZ05QHF01MGEd0Ogmo06m_K`2VYZH0SHf=07moO`1MGEd0HV9R079b
LP1LG5`0De=C03Ti>@1>CTh0NWYj06MWI`13@d<0LW9b06MWI`1PH600EUIF079bLP1JFUX0HV9R05mO
G`1VIVH0EEEE04i>CP1fMWH0OGem04I6AP1iNGT0R8R805QHF01FEUH0KFe]05MGE`1eMGD0IVIV07em
O@1QHF40Cdm?05mOG`1:BTX0?Cdm07AdM01FEUH0SHf=05eMG@1SHf<0J6QX06ATI01QHF40GUiN055A
D@1GEeL0RHV905UIF@29RHT09RHV05iNGP1BDU80HF5Q3_ooool0M`22PX80<c<c02h^;P0H61P05QHF
018B4P0U9BD0L71`07=cL`2?Shl0c<c<06ATI01/K6`0FEUI06ATI02HV9P0PX:2071`L016ATH0@410
03Ph>013@d<0:b/[03/k>`1fMWH0PX:205UIF@0h>3P0<C4a02h^;P0];Bd0LW9b08R8R025QHD0AdM7
01PH600F5QH05aLG01XJ6P1FEUH0GEeM08Z:RP0I6AT0:b/[01LG5`0J6QX07AdM05ADE01cLg<0>c/k
07EeM@1lO7`0?Shn04Q8B01/K6`0Q8B4020P800B4Q809RHV06UYJ@20P800_;bl05UIF@1KFe/0[:b/
09JFUP1lO7`0:2PX01HF5P0g=cL0:RXZ04Y:BP1mOGd0YZJV08Z:RP2TY:@0/;2`0<G5a@1WIfL0<C4a
02PX:00d=3@0>3Ph04a<C01;Bd/0@d=301/K6`0N7Qh0GEeM0:ZZZP2TY:@0/[:b09nOW`1SHf<0@T92
0451@@25QHD0TY:B09>CT`1MGEd0Kfm_09bLW02VYZH0[Jf]08^;R`1lO7`0N7Qh075aL@0i>CT0Lg=c
04];B`1HF5P0HV9R09RHV02g]kL0FEUI03Ti>@0T92@0:b/[0080>SXj00D0VYZJ0<O7a`3@d=00UiNG
0820P00206UYJ@0708R8R02][Jd0]KFe09BDU03>c/h0eMGE0;jn_P020:JVYP030:>SX`2l_;`0PX:2
01Cooooo000Cooooo`0N07alO01iNGT0FUYJ0820P01HF5P0Ogmo051@D01CDe<0L71`03Hf=P1PH600
JFUY03dm?@1_Kfl0K6a/03Ti>@1ZJVX0O7al0410@01QHF40EEEE04E5A@1VIVH0F5QH0492@P1HF5P0
Cdm?04];B`1BDU80@d=30P1RHV803@1MGEd0N7Qh03dm?@1?Cdl0Rh^;02h^;P1BDU80MGEe02l_;`1?
Cdl0K6a/03Ti>@1aLG400P16ATH0G01SHf<0>3Ph05MGE`1JFUX0CTi>071`L01XJ6P0?Cdm06][J`1h
N7P0BDU906i^KP21PH40=cLg06YZJP21PH40@D5107QhN025QHD0EUIF07=cL`1jNWX0CDe=09>CT`1O
Gel0GEeM07QhN01FEUH0MGEe0820P01QHF40PX:205eMG@1bLW80SHf=059BDP1fMWH0RHV904=3@`1c
Lg<0PX:205MGE`1fMWH0NWYj04I6AP1YJFT0U9BD05MGE`27QhL0JFUY05mOG`20P800>CTi07UiN@1`
L700EeMG08V9R@1UIFD0JVYZ06ATI01LG5`0Shn?079bLP1OGel0PX:206IVIP1JFUX0PH6107EeM@1F
EUH0O7al06QXJ01HF5P0Lg=c05IFEP1DE5@0M7Ad05eMG@1VIVH0PH6106a/K01jNWX0K6a/05=CD`1[
Jf/0?Shn06=SH`1WIfL0@T9206=SH`1aLG40?Cdm3_ooool00`1KFe/0EEEE04i>CP0204m?C`1b04=3
@`1VIVH0KVi^05aLG01:BTX0=SHf03Ph>010@400>c/k05]KF`15ADD0De=C04e=C@1LG5`0AdM704Q8
B013@d<0=cLg03lo?`18B4P0@d=303@d=012@T80=cLg04a<C019BDT0Bd];05QHF01QHF40ATI607]k
N`1LG5`0DE5A05EEE@1=CDd0=cLg03`l?018B4P0?Shn04=3@`0m?Cd0D51@04Y:BP16ATH0Cdm?061P
H01OGel0JVYZ08b<S01RHV80KVi^07EeM@1PH600Cdm?06EUI@1FEUH0De=C0:^[Z`2XZ:P0IfMW05]K
F`1EEED0Ng]k05IFEP1EEED0GUiN05IFEP1<C4`0Ti>C04M7A`15ADD0HV9R06IVIP1fMWH0T92@04m?
C`1DE5@0G5aL069RHP1NGUh0CDe=04a<C015ADD0A4A405aLG01mOGd0PH6103Hf=P29RHT0De=C05AD
E01FEUH0Bd];04Q8B01JFUX0E5AD04U9B@1<C4`0@d=303/k>`12@T80@D5105]KF`0e=CD0A4A40410
@01]KFd0@d=303Ti>@1;Bd/0<S8b04a<C01JFUX0Hf=S0P1ADE403019BDT0@d=305UIF@10@400AdM7
05EEE@1hN7P0JFUY071`L01/K6`0JVYZ04e=C@80De=C00D0Bd];04A4A01[Jf/0JVYZ07YjNP0>oooo
o`0d04i>CP1IFET0H61P04Q8B01>CTh0=cLg04i>CP0o?cl0<30`04=3@`0h>3P0ATI603Ph>00d=3@0
CDe=03Hf=P1EEED0>3Ph04E5A@0[:b/0?clo06IVIP0a<C40EUIF04Q8B01JFUX0>c/k04Q8B00b<S80
AdM705mOG`1iNGT0>3Ph05EEE@1;Bd/0?Shn05MGE`0_;bl0GemO059BDP1MGEd0X:2P07MgM`0_;bl0
EeMG09^KV`0l?3`0GUiN09fMW@1IFET0IfMW06IVIP80CTi>04<0GemO05=CD`1<C4`0Hf=S04];B`1U
IFD0FEUI06ATI024Q8@0FUYJ079bLP1YJFT0Lg=c05=CD`1cLg<0KFe]051@D01mOGd0PX:206m_K`2?
Shl0IfMW079bLP1:BTX0EEEE0861P@27QhL0YjNW08n?S`1jNWX0I6AT07YjNP2>SXh0JFUY04m?C`0n
?Sh0Bd];07emO@1RHV80AdM706a/K01>CTh0JVYZ05iNGP1iNGT0Kfm_06i^KP1/K6`0HV9R04m?C`0n
?Sh0JVYZ069RHP1=CDd0OWin07YjNP1BDU80GemO05IFEP1BDU80O7al06IVIP1]KFd0Jf][05UIF@1R
HV80C4a<0080Bd];0140De=C08Z:RP20P800KFe]07QhN02:RXX0@T9205ADE01NGUh0Kfm_08V9R@1a
LG40PX:202@T901@D500E5AD08N7Q`0>ooooo`0304a<C016ATH0<30`00805aLG0P0f=SH07P0J6QX0
;2`/06i^KP32`/80^k^k06e]K@1NGUh0:2PX04=3@`1BDU80B4Q808^;R`2_[jl0J6QX04Q8B00b<S80
GemO08n?S`2ATI40<c<c01/K6`0E5AD0=CDe02LW9`0g=cL0I6AT09:BTP0[:b/0>3Ph01XJ6P805aLG
02P061PH05eMG@1aLG40<S8b051@D00/;2`06ATI01XJ6P0b<S80dm?C071`L025QHD0bLW90;Rh^020
P800AdM702PX:012@T80AdM702`/;02XZ:P0QHF50:ZZZP1`L700KFe]08>3P`1CDe<0OWin08j>SP1^
KVh0<c<c04m?C`25QHD0IVIV07QhN01/K6`0RXZ:03<c<`1/K6`0FEUI0P0F5QH0>`0[:b/06ATI02`/
;026QXH0[:b/08F5Q@22PX80Kfm_07AdM02i^KT0SXj>09FEU@1HF5P0?3`l02TY:@2<S8`0O7al06IV
IP1jNWX0I6AT075aL@1/K6`0/[:b09:BTP1KFe/0KVi^03@d=00K6a/0>SXj04E5A@1kNg/0NGUi06UY
J@3?cll0YZJV04m?C`0L71`07AdM02TY:@1oOgl0[jn_0;6a/@2h^;P0FUYJ03Ti>@1:BTX0CTi>03`l
?00X:2P0C4a<055AD@26QXH0JVYZ0;:b/P36a/H0QXJ604U9B@20P800FUYJ01Cooooo000Cooooo`0m
08>3P`1fMWH0Cdm?05mOG`1QHF40?clo05EEE@1hN7P0AdM705iNGP2DU9@0A4A405YJFP1]KFd0?Cdm
07EeM@0m?Cd0ADE5069RHP1HF5P0>c/k06ATI01@D500GemO06QXJ00`<300LG5a05=CD`11@D40Hf=S
065QH@12@T80Cdm?04e=C@1SHf<0?3`l069RHP1?Cdl0@D51061PH01>CTh0AdM7055AD@1NGUh0>SXj
059BDP1/K6`0>CTi05eMG@1lO7`0<30`06=SH`1<C4`0=cLg06m_K`16ATH0AdM707IfMP0l?3`0GEeM
06QXJ00206IVIP1<05mOG`1PH600L71`071`L01:BTX0OWin05MGE`1XJ6P0N7Qh05aLG01VIVH0M7Ad
06m_K`1UIFD0S8b<071`L01VIVH0SXj>06IVIP1OGel0UiNG061PH01aLG40Q8B405]KF`1iNGT0GUiN
05]KF`1eMGD0?Cdm05aLG01iNGT0@41007QhN01]KFd0FEUI07UiN@1NGUh0N7Qh0861P@14A4@0Hf=S
071`L00f=SH0Lg=c06=SH`1IFET0J6QX05QHF023Ph<0HV9R06e]K@2MWId0FEUI069RHP25QHD0Cdm?
06EUI@2CTi<0Bd];06MWI`20P800BDU905aLG020P800B4Q805EEE@1`L700DU9B06YZJP1oOgl0>c/k
06m_K`1RHV80@d=306i^KPkooooo0380GemO06IVIP1^KVh0F5QH05eMG@1>CTh0LG5a07AdM01KFe/0
FEUI03Xj>P10@400C4a<04M7A`1WIfL0EeMG05UIF@1RHV80FEUI04U9B@1?Cdl0CTi>03/k>`0m?Cd0
CTi>04a<C00m?Cd0?3`l04=3@`1BDU80Bd];05=CD`1ZJVX0MGEe04a<C01/K6`0EUIF05aLG01ZJVX0
De=C0451@@14A4@0Bd];03dm?@11@D40?clo04Q8B00o?cl0?Cdm04U9B@80Cdm?00d0HF5Q08F5Q@1J
FUX0KFe]06m_K`1OGel0C4a<06ATI01HF5P0Cdm?08b<S02[Zj/0G5aL0080IVIV04T0MWIf055AD@12
@T80H61P04I6AP1MGEd0OWin05IFEP1;Bd/0TI6A05=CD`1hN7P0TI6A06=SH`1JFUX0HF5Q05eMG@1B
DU80B4Q805iNGP1RHV80DE5A06ATI01oOgl0Ph>304=3@`1hN7P0@41004Y:BP1TI6@0CDe=04U9B@1K
Fe/0A4A404a<C015ADD0@d=303@d=00o?cl0AdM705mOG`0e=CD0BDU904E5A@1SHf<0BDU903/k>`1<
C4`0?Shn03Xj>P1ADE40F5QH05EEE@12@T80BDU9051@D01GEeL0=cLg03dm?@1HF5P0Jf][06e]K@1X
J6P0EUIF051@D01;Bd/0De=C04Y:BP1=CDd0BTY:06YZJP1SHf<0MWIf00kooooo00P0FUYJ05IFEP1_
Kfl0AdM704];B`1>CTh0DU9B04M7A`80<c<c05X0@T9204A4A011@D40@T9203hn?P10@400EeMG02h^
;P1?Cdl0=CDe05YJFP1NGUh0?Cdm05eMG@0o?cl0KFe]04U9B@1CDe<0=cLg059BDP15ADD0EUIF059B
DP1;Bd/0BTY:05ADE01ADE40=cLg065QH@0n?Sh0Cdm?0:FUY@1OGel0JFUY05MGE`20P800?Cdm05YJ
FP2a/K40EEEE06UYJ@1EEED0De=C06a/K01FEUH0G5aL05=CD`1NGUh0GemO05YJFP1@D500JFUY06m_
K`1]KFd0IfMW08J6QP21PH40GemO07inOP1lO7`0DE5A05eMG@23Ph<0G5aL07UiN@1_Kfl0I6AT04=3
@`1`L700M7Ad05iNGP2^[Zh0TY:B07MgM`0l?3`0MgMg08^;R`1?Cdl0F5QH03/k>`1ZJVX0K6a/06e]
K@17AdL0FEUI04E5A@1KFe/0AdM706MWI`1LG5`205eMG@0V055AD@1IFET0B4Q805UIF@1WIfL0=cLg
06UYJ@1XJ6P0AdM704A4A01MGEd0EeMG07EeM@1bLW80DE5A071`L01NGUh0F5QH04Y:BP1=CDd0ATI6
079bLP29RHT0Kfm_08f=S@1eMGD0EEEE07=cL`1JFUX0HF5Q08F5Q@26QXH0I6AT08n?S`0W9bL0AdM7
04Q8B024Q8@>ooooo`0V075aL@1UIFD0OGem04Q8B00W9bL09BDU01PH600E5AD051@D04M7A`2VYZH0
TI6A05IFEP0^;Rh0NWYj05]KF`1MGEd0EEEE055AD@1lO7`0:RXZ02PX:017AdL0S8b<0:b/[01[Jf/0
?Cdm01`L700J6QX071`L01hN7P11@D40:RXZ08J6QP0k>c/061PH02XZ:P0J6QX201HF5P0G03Xj>P2F
UYH0QXJ603Lg=`0j>SX0DU9B06e]K@1`L700I6AT0<G5a@3Jf]X0b/[:09jNWP0o?cl06ATI01`L700H
61P0?Shn0;>c/`2JVYX0Zj^[07]kN`0];Bd00P0T92@01`1UIFD0FEUI075aL@2b/[80W9bL0;bl_02P
X:000P1:BTX09P0X:2P0J6QX02/[:`0h>3P0KVi^01/K6`0E5AD06ATI01LG5`1ADE40Ng]k09^KV`2f
][H0`<300:>SX`1jNWX0BTY:05YJFP1bLW80@41004M7A`0e=CD0JVYZ0<;2`P1XJ6P08B4Q01/K6`0_
;bl0LG5a07AdM01MGEd0Ph>309:BTP0L71`06QXJ01dM7@1PH600:RXZ0P1gMgL06P22PX80GEeM05AD
E00J6QX071`L03Ti>@1=CDd0Fe]K08B4Q01BDU80IfMW03`l?00Z:RX07AdM01`L700K6a/0;2`/03Ti
>@2ATI40Ogmo0:>SX`37alL0Ogmo03Xj>P1eMGD0GUiN5?ooool001?ooooo08/0MWIf0820P01IFET0
J6QX05mOG`1bLW80BDU904a<C01MGEd0>CTi05QHF01eMGD0<S8b06=SH`1XJ6P0=3@d05ADE02DU9@0
=CDe05eMG@1^KVh0?Shn069RHP1TI6@0E5AD075aL@1MGEd0>CTi061PH00i>CT0EeMG05QHF016ATH0
Jf][05EEE@11@D40Ph>304i>CP15ADD0NWYj04Y:BP19BDT0K6a/0410@01JFUX0BTY:04E5A@1ADE40
?clo075aL@1QHF40EeMG05]KF`1UIFD0=CDe06a/K01[Jf/0>3Ph06MWI`1^KVh0:b/[06EUI@1hN7P0
>CTi06m_K`1/K6`0?3`l061PH01lO7`0?Cdm07=cL`1QHF40FEUI075aL@1<C4`0LW9b07]kN`1QHF40
Ph>306ATI01OGel0MgMg07QhN01fMWH0Kfm_05mOG`1kNg/0KFe]04m?C`1WIfL0Ti>C065QH@1WIfL0
Xj>S069RHP2BTY80G5aL05]KF`25QHD0Cdm?06e]K@1WIfL0CTi>06a/K01_Kfl0GEeM071`L01CDe<0
L71`08b<S01JFUX0MgMg07AdM01BDU80LG5a06IVIP1BDU80M7Ad06m_K`14A4@0LG5a06YZJP1?Cdl0
Shn?05MGE`1FEUH0IVIV061PH01MGEd0G5aL05iNGP1WIfL0EEEE06MWI`1gMgL0@41005aLG01PH600
D51@00kooooo02l0IfMW061PH01PH600EUIF06=SH`1=CDd0MgMg08b<S01TI6@0G5aL03De=@0m?Cd0
A4A403@d=01^KVh0G5aL05YJFP1CDe<0GEeM04i>CP1:BTX0Bd];03Ti>@0m?Cd0CTi>03Ph>00k>c/0
@T9204Y:BP16ATH0EUIF055AD@1MGEd0Lg=c04m?C`1ZJVX0H61P04Y:BP1EEED0De=C03Ph>00m?Cd0
C4a<03`l?01:BTX0@D5104i>CP0204A4A00e04e=C@1;Bd/0A4A4061PH02CTi<0De=C06a/K023Ph<0
Kfm_05ADE01;Bd/0K6a/06m_K`2i^KT0b<S808^;R`1_Kfl0IfMW06i^KP1;Bd/0@d=304i>CP13@d<0
EUIF0820P01JFUX0ADE508B4Q01BDU80Lg=c08b<S01QHF40J6QX06MWI`1ZJVX0D51@05UIF@1HF5P0
JVYZ055AD@1TI6@0OWin08F5Q@1FEUH0MgMg06EUI@1KFe/0GUiN04m?C`15ADD0GEeM04i>CP1<C4`0
0P1;Bd/01@0k>c/0D51@04m?C`1SHf<0>c/k0080ATI601d0CDe=051@D00c<c<0EEEE034a<@1;Bd/0
BTY:04M7A`1EEED0Bd];04M7A`1ADE40DU9B04U9B@0n?Sh0@41006a/K01KFe/0OGem06UYJ@1XJ6P0
De=C06YZJP1PH600EEEE05IFEP1VIVH0HF5Q07IfMP0>ooooo`0b05MGE`1KFe/0N7Qh0451@@1GEeL0
>CTi04e=C@1;Bd/09BDU03De=@12@T80?3`l04I6AP0/;2`0BTY:04A4A01BDU80C4a<05ADE00m?Cd0
B4Q806m_K`19BDT0G5aL051@D01bLW80>c/k04];B`0f=SH0?clo05QHF015ADD0HV9R04];B`16ATH0
F5QH05]KF`0l?3`0J6QX04=3@`1QHF40UiNG05QHF01/K6`0AdM707emO@1CDe<0L71`0;Jf]P1EEED2
06EUI@0/051@D01RHV80JVYZ04M7A`12@T80HF5Q04=3@`1BDU80E5AD05eMG@1fMWH0H61P06IVIP1Y
JFT0Hf=S05mOG`1cLg<0Hf=S065QH@1nOWh0MgMg05QHF01jNWX0N7Qh05aLG01@D500IFEU07AdM02:
RXX0ZJVY0861P@2=SHd0@d=306a/K02/[:`0Fe]K05iNGP13@d<0N7Qh08:2PP28R8P0F5QH06i^KP1G
EeL206QXJ00Z06i^KP1aLG40UIFE06m_K`1=CDd0A4A405EEE@18B4P0JVYZ04a<C01VIVH0B4Q803`l
?01:BTX0@T9205UIF@1jNWX0FUYJ0861P@1hN7P0>3Ph06m_K`1@D500?clo05UIF@1`L700S8b<07If
MP1OGel0JVYZ03<c<`1NGUh0EEEE05=CD`1LG5`0N7Qh07]kN`2IVIT0;Bd]051@D01<C4`0OGem3_oo
ool0H`1=CDd0Fe]K08>3P`1JFUX0ATI602@T900E5AD04a<C018B4P0b<S80MGEe05]KF`1;Bd/04A4A
01<C4`0M7Ad06ATI02PX:00o?cl0G5aL05YJFP0J6QX05ADE05YJFP2BTY80S8b<06ATI00c<c<0;Bd]
02`/;00];Bd0XJ6Q08:2PP2UYJD0Kfm_028R8P0J6QX0:b/[02HV9P0J6QX0:b/[0:FUY@32`/80Ogmo
07emO@1QHF40DU9B02DU9@0J6QX0Jf][0;Vi^@2LW9`0CDe=05mOG`1GEeL0?Shn03lo?`16ATH0OGem
079bLP0k>c/0J6QX01XJ6P0C4a<051@D034a<@2VYZH0ZZZZ0:RXZ02;Rh/0MgMg07inOP1MGEd08B4Q
020P801GEeL0?clo04M7A`1NGUh0C4a<01`L700N7Qh0ATI604M7A`0U9BD0R8R80;bl_02c/k<0]KFe
071`L00R8R808B4Q03`l?00J6QX092@T05EEE@1kNg/0MGEe04a<C00202<S8`0W05YJFP1_Kfl0E5AD
06=SH`1jNWX0[:b/028R8P0K6a/06ATI02PX:01YJFT0Lg=c0410@00W9bL0?Cdm0410@01JFUX0P820
0:NWY`1ADE40O7al08f=S@27QhL0De=C01LG5`0I6AT061PH01/K6`0L71`0:b/[03/k>`2QXJ40];Bd
096AT@3AdM40L71`08N7Q`1JFUX0<30`01Cooooo000Cooooo`0D07IfMP1ZJVX0F5QH06QXJ01TI6@0
De=C0492@P1^KVh0Cdm?0451@@1^KVh0Hf=S0410@01bLW80Hf=S05MGE`1>CTh0H61P04i>CP1QHF42
05IFEP0B04i>CP1<C4`0D51@04M7A`1EEED0CDe=05iNGP1DE5@0K6a/051@D01=CDd0JFUY04U9B@13
@d<0K6a/04m?C`1HF5P0H61P0P1>CTh0BP1KFe/0F5QH04m?C`13@d<0EEEE04Y:BP1<C4`0JVYZ05EE
E@1LG5`0EeMG05iNGP1DE5@0BDU906=SH`1KFe/0D51@05YJFP13@d<0JVYZ065QH@1CDe<0LG5a06i^
KP1GEeL0D51@06m_K`1WIfL0JFUY05UIF@1eMGD0Lg=c06][J`27QhL0GUiN06UYJ@1hN7P0Hf=S07Ui
N@1/K6`0G5aL08^;R`1RHV80EEEE08f=S@1_Kfl0Fe]K069RHP1cLg<0HV9R05=CD`1^KVh0Kfm_06YZ
JP1JFUX0KVi^05ADE01GEeL0Jf][06e]K@1hN7P0De=C07=cL`26QXH0B4Q8075aL@1SHf<0DU9B07If
MP1ADE40Jf][05QHF01WIfL0NGUi0P1GEeL05@1_Kfl0JFUY04];B`1^KVh0G5aL06MWI`1RHV80EeMG
06MWI`1RHV80G5aL04Q8B01ZJVX0K6a/04a<C01XJ6P0GEeM04A4A01YJFT0Fe]K06a/K00>ooooo`1h
06MWI`1NGUh0FUYJ05mOG`1PH600FEUI06m_K`1dM7@0FEUI055AD@0h>3P0@D51059BDP1WIfL0KFe]
05IFEP1SHf<0GEeM069RHP1=CDd0Cdm?051@D00k>c/0=cLg04U9B@11@D40>SXj0451@@12@T80@d=3
05aLG016ATH0FUYJ06IVIP1=CDd0FUYJ04m?C`0o?cl0CTi>04Q8B00e=CD0?clo059BDP0d=3@0>SXj
034a<@15ADD0?Cdm03hn?P1;Bd/0B4Q804=3@`1>CTh0RHV904m?C`1JFUX0Ng]k06YZJP1GEeL0De=C
05EEE@0o?cl0S8b<0:VYZ@1hN7P0O7al05iNGP0o?cl0D51@04Y:BP1@D500Bd];05eMG@24Q8@0EUIF
04U9B@24Q8@0B4Q8071`L01jNWX0ATI6051@D01JFUX0Lg=c05YJFP1HF5P0DU9B06=SH`1>CTh0IfMW
07inOP1lO7`0ADE506=SH`16ATH0?clo051@D018B4P0>CTi05EEE@14A4@0?Cdm04=3@`18B4P0=SHf
0410@016ATH0De=C03De=@18B4P0?clo04];B`19BDT0=SHf055AD@0e=CD0Bd];051@D01<C4`0Fe]K
0P1=CDd04P1VIVH0De=C03hn?P11@D40CDe=05iNGP1hN7P0FUYJ05EEE@19BDT0ATI6051@D01GEeL0
B4Q8055AD@1XJ6P0HV9R07IfMPkooooo08`0Fe]K06=SH`1VIVH0CTi>05aLG014A4@0?3`l04I6AP0_
;bl092@T03hn?P0b<S80=SHf03De=@0l?3`0@d=30451@@13@d<0@T92034a<@1GEeL0J6QX04E5A@1E
EED0E5AD07=cL`1BDU80C4a<02TY:@0j>SX0GUiN02/[:`1?Cdl0@T92034a<@1DE5@0D51@04U9B@1G
EeL0F5QH04i>CP24Q8@0Kfm_06][J`1?Cdl0Rh^;05YJFP1UIFD0YJFU05eMG@1YJFT0J6QX05QHF01b
LW80H61P05IFEP1>CTh0G5aL05eMG@1BDU80DE5A05MGE`1VIVH0J6QX06=SH`1jNWX0I6AT06EUI@1b
LW80Fe]K06EUI@1aLG40LW9b04];B`1nOWh0K6a/07IfMP1EEED0I6AT07inOP1NGUh0^k^k08b<S01Q
HF40AdM706m_K`2HV9P0HV9R04a<C00d=3@0EeMG07AdM021PH40BDU907emO@1<C4`0I6AT065QH@1d
M7@0HF5Q07]kN`1YJFT0IFEU055AD@1PH600EUIF06MWI`15ADD0EUIF04A4A01IFET0B4Q804M7A`1I
FET0Hf=S05]KF`21PH40IfMW04=3@`1LG5`0?Cdm04M7A`12@T80JFUY06IVIP1KFe/0QXJ6065QH@0b
<S80PX:205=CD`19BDT0MgMg06][J`1<C4`0TI6A02h^;P1>CTh0?clo08j>SPkooooo01X0AdM706MW
I`1iNGT0B4Q803<c<`0f=SH07alO02`/;00f=SH0QhN709fMW@22PX80J6QX01/K6`0?3`l03@d=010@
400V9RH0JFUY071`L02PX:00Ogmo06IVIP2m_Kd0ZJVY06=SH`80JVYZ0580F5QH05eMG@1mOGd0CTi>
055AD@1bLW80TI6A07EeM@1?Cdl0@d=305QHF01;Bd/0IVIV08>3P`2TY:@0N7Qh02d];@0O7al0;Rh^
04I6AP1jNWX0SXj>0<71`@1=CDd061PH024Q8@18B4P0E5AD020P8011@D40Bd];04Q8B00X:2P0E5AD
02DU9@0C4a<04Q8B01@D501<C4`0SHf=05QHF014A4@0Fe]K038b<P1@D500<30`024Q8@11@D40C4a<
02DU9@1<C4`0EeMG08V9R@1EEED0?Shn01lO7`0f=SH0LG5a059BDP1PH600IVIV06YZJP0U9BD0<S8b
055AD@0a<C40:RXZ04Q8B01RHV80C4a<04Y:BP0a<C40@d=302l_;`0T92@0<S8b03/k>`26QXH0H61P
04a<C00X:2P07alO0P1ZJVX0200^;Rh06a/K01XJ6P0X:2P0RHV905iNGP2f][H0[jn_0P2j^[X0102Q
XJ40NGUi03lo?`0V9RH201LG5`0<024Q8@0O7al0?Cdm06=SH`1TI6@0C4a<06EUI@1^KVh0TY:B07mo
O`0d=3@0<c<c5?ooool001?ooooo0140OWin07EeM@1ADE40G5aL06QXJ011@D40Cdm?07moO`0i>CT0
IFEU07MgM`1:BTX0JFUY04a<C01LG5`0KFe]03Xj>P0206UYJ@1h03hn?P1EEED0H61P03dm?@1KFe/0
GEeM0451@@1_Kfl0C4a<055AD@1OGel0F5QH06IVIP1BDU80EUIF07AdM017AdL0EEEE06YZJP12@T80
E5AD06IVIP11@D40J6QX08J6QP0d=3@0DE5A06QXJ00g=cL0BTY:05mOG`0h>3P0IfMW04U9B@0n?Sh0
KFe]04I6AP19BDT0Jf][0410@01GEeL0?clo04Y:BP1MGEd0GemO05QHF02ATI40G5aL04];B`2=SHd0
B4Q805QHF01[Jf/0Cdm?06IVIP1XJ6P0HV9R05mOG`20P800J6QX07UiN@2DU9@0HV9R07QhN01cLg<0
HV9R08:2PP1nOWh0M7Ad06i^KP1:BTX0Rh^;08:2PP13@d<0Ogmo07IfMP15ADD0TI6A06MWI`1mOGd0
L71`05EEE@1/K6`0J6QX03dm?@1iNGT0Lg=c065QH@21PH40HV9R09VIV@1WIfL0CTi>0;bl_01OGel0
L71`0::RXP1LG5`0GEeM09JFUP1=CDd0Hf=S09RHV00m?Cd0KFe]06i^KP14A4@0JFUY06EUI@1ADE40
J6QX05IFEP1JFUX0D51@07moO`13@d<0IFEU08>3P`0j>SX0Ph>33_ooool0;P1UIFD0GUiN05EEE@1Q
HF40GUiN05UIF@1`L700Ng]k05mOG`1JFUX0>3Ph04E5A@1>CTh0F5QH06m_K`1GEeL0GEeM05MGE`1K
Fe/0Bd];04U9B@1=CDd0@d=3038b<P1;Bd/0?Shn03dm?@19BDT0B4Q80451@@1JFUX0CDe=06YZJP1]
KFd0EeMG069RHP1ADE40>c/k05YJFP1ADE40=CDe04E5A@1<C4`0?3`l0451@@0l?3`204E5A@090410
@01KFe/0Cdm?03Xj>P1DE5@0YZJV05aLG015ADD0GEeM0080A4A40540L71`0410@00m?Cd0G5aL09ZJ
VP1WIfL0N7Qh0820P018B4P0Bd];0451@@1FEUH0BDU906ATI02@T900B4Q8055AD@1kNg/0CDe=08>3
P`26QXH0DE5A04m?C`1aLG40NGUi05IFEP1CDe<0EEEE06=SH`11@D40FEUI061PH01[Jf/0B4Q806UY
J@15ADD0@T92055AD@16ATH0BTY:05IFEP1GEeL0C4a<04I6AP0j>SX0:BTY0492@P1:BTX0G5aL03Lg
=`1CDe<0BDU905IFEP1HF5P0?3`l05EEE@0f=SH0@D5104m?C`1:BTX0DE5A04i>CP18B4P0DU9B05EE
E@16ATH0C4a<05]KF`1/K6`0Ogmo06i^KP23Ph<0G5aL05iNGP1FEUH0H61P04e=C@1TI6@0JFUY05mO
G`1ZJVX03_ooool02`1IFET0F5QH06e]K@0l?3`0HF5Q0492@P10@400A4A4024Q8@0Z:RX0ATI60080
@41003T0=3@d0451@@0k>c/0>c/k05=CD`1>CTh0<C4a0410@01>CTh0?Shn05EEE@15ADD0M7Ad03/k
>`1>CTh0;Rh^03Xj>P1>CTh092@T05UIF@0e=CD0:RXZ059BDP0n?Sh0Bd];04A4A011@D40FUYJ08B4
Q00l?3`0Fe]K04i>CP2EUID0?clo05]KF`31`L40?3`l065QH@14A4@0CDe=05=CD`1?Cdl0IFEU03@d
=01OGel0C4a<03`l?018B4P0BDU905=CD`1ZJVX0EUIF075aL@1SHf<0JVYZ07MgM`1CDe<00P1WIfL0
;@1hN7P0@d=307IfMP1XJ6P0Ph>306a/K01HF5P0Ph>308F5Q@2n_[h0J6QX08F5Q@1NGUh0Lg=c09ZJ
VP2CTi<0EUIF04I6AP0f=SH0OWin07MgM`19BDT0QhN706e]K@1IFET0KVi^06QXJ01=CDd0Hf=S06YZ
JP1NGUh0A4A4051@D016ATH0AdM704];B`1TI6@0:BTY05IFEP0e=CD0C4a<05MGE`1]KFd0H61P06QX
J00206IVIP0E05YJFP1:BTX0Kfm_03<c<`1JFUX0LW9b069RHP2:RXX0DE5A03hn?P1_Kfl0G5aL05mO
G`1RHV80IFEU04i>CP21PH409BDU0492@P16ATH0UYJF00kooooo01l0<S8b04e=C@1MGEd0XJ6Q06e]
K@1`L700MgMg05iNGP1CDe<0G5aL0;Rh^02RXZ80NGUi01hN7P0Z:RX0;bl_03<c<`0Z:RX08b<S01lO
7`1<C4`0QXJ60=7Ad@2[Zj/0X:2P07inOP1kNg/0N7Qh04a<C00e=CD0GUiN0080?Shn01h07AdM04];
B`2k^k/0U9BD07=cL`15ADD0>CTi05QHF02BTY80Y:BT06][J`1;Bd/0@D5102h^;P0k>c/0X:2P08>3
P`2BTY80NGUi02PX:00K6a/08b<S02h^;P0i>CT0C4a<02h^;P15ADD0WIfM09NGU`0i>CT201<C4`0=
01lO7`22PX80P82002l_;`0X:2P0<C4a02HV9P0Z:RX0@d=304e=C@0a<C40O7al0;^k^`020861P@0P
096AT@0m?Cd0<S8b03Hf=P1nOWh0Lg=c03Ti>@0_;bl0FEUI0:FUY@1iNGT0OWin059BDP19BDT0?Shn
04a<C02ATI40XJ6Q08N7Q`2MWId0LW9b04e=C@1DE5@0HV9R08f=S@3>c/h0QHF50820P01jNWX0/;2`
06m_K`0M7Ad301PH600I028R8P2?Shl0[Zj^0;^k^`2MWId0IfMW051@D01PH600M7Ad05mOG`11@D40
7alO01/K6`0Q8B40>SXj09VIV@1mOGd0Fe]K02DU9@1NGUh0BTY:06UYJ@1SHf<0KFe]04U9B@0Doooo
o`004oooool0H@1bLW80KFe]05YJFP1_Kfl0EEEE07MgM`15ADD0CTi>05aLG00h>3P0GEeM06m_K`0c
<c<0LG5a05UIF@0o?cl0Fe]K06EUI@0k>c/0Fe]K06EUI@1<C4`0H61P05QHF01@D500L71`04m?C`1^
KVh0FEUI04];B`1bLW80@D5103lo?`25QHD0AdM704U9B@1LG5`0BDU9055AD@1PH600?Shn04e=C@1I
FET0?Cdm05mOG`0`<300Cdm?05]KF`0_;bl0A4A406UYJ@1@D500H61P06QXJ00i>CT0IVIV07=cL`0k
>c/0L71`06e]K@0[:b/0IFEU06i^KP0f=SH0JFUY09FEU@1BDU80K6a/06IVIP1fMWH0IVIV05YJFP2D
U9@0JFUY05=CD`2EUID0C4a<05MGE`2IVIT0D51@06UYJ@29RHT0Hf=S07IfMP1mOGd0Fe]K08>3P`1[
Jf/0DE5A06MWI`1[Jf/0ADE507YjNP1PH600GUiN07YjNP14A4@00P1`L700:011@D40O7al05ADE01S
Hf<0IfMW04i>CP2>SXh0Kfm_05IFEP1WIfL0De=C075aL@17AdL0Hf=S05mOG`1VIVH0JVYZ079bLP1P
H600Hf=S069RHP1LG5`0DE5A06UYJ@1RHV80CTi>07=cL`1HF5P0FUYJ08:2PP0U9BD0IVIV08V9R@0[
:b/0F5QH07=cL`0j>SX0BTY:07EeM@1<C4`>ooooo`0=07]kN`1SHf<0G5aL065QH@1WIfL0EUIF06i^
KP24Q8@0GEeM05IFEP0a<C40?Cdm04i>CP0206MWI`0?069RHP1KFe/0Fe]K05]KF`1@D500EUIF05=C
D`1;Bd/0A4A4065QH@1IFET0@D5104I6AP1;Bd/0D51@0080EEEE05l0E5AD06EUI@1FEUH0EeMG05aL
G015ADD0GemO051@D00g=cL0C4a<04I6AP0j>SX0>c/k0410@015ADD0@d=303dm?@1>CTh0De=C04Y:
BP1UIFD0TY:B04i>CP13@d<0ADE504e=C@1CDe<0GEeM05QHF01QHF40QhN70:NWY`29RHT0QhN708b<
S01>CTh0DU9B05=CD`1DE5@0CTi>061PH01gMgL0DU9B04e=C@1ZJVX0FEUI07=cL`1bLW80Cdm?061P
H01^KVh0GemO069RHP1JFUX0OGem06i^KP1?Cdl0Hf=S06a/K01PH600EEEE04a<C01KFe/0ADE5059B
DP1<C4`0A4A405YJFP1XJ6P0D51@04U9B@1GEeL0?3`l059BDP1=CDd0De=C03<c<`1@D500DE5A04Y:
BP1DE5@0>3Ph05YJFP0a<C40@D5104E5A@17AdL0DE5A04E5A@1;Bd/0CTi>04I6AP1BDU80D51@04=3
@`0205MGE`0;08F5Q@1CDe<0GUiN059BDP1FEUH0E5AD04Q8B01ZJVX0Hf=S05ADE01TI6@03_ooool0
5`1`L700I6AT04i>CP1:BTX0E5AD03Ph>00n?Sh0<S8b03Ti>@0W9bL0@41004A4A00/;2`0@41003<c
<`0m?Cd0<c<c04U9B@0_;bl0;Rh^04Q8B01TI6@0>SXj0080Bd];01d0IFEU03lo?`1OGel0;bl_04I6
AP1JFUX09BDU04a<C01?Cdl0;Bd]04];B`16ATH0DE5A04I6AP1LG5`0A4A406UYJ@1OGel0IFEU04Q8
B02>SXh0GEeM05MGE`27QhL0EUIF071`L01XJ6P0>3Ph06i^KP0205UIF@1D069RHP1KFe/0K6a/069R
HP1?Cdl0EEEE075aL@1_Kfl0JFUY065QH@1OGel0Ogmo04];B`1QHF40OGem05mOG`27QhL0DU9B061P
H01aLG40GEeM05QHF01YJFT0Lg=c05MGE`31`L40PX:206m_K`1;Bd/0P820092@T01nOWh0GEeM04I6
AP1IFET0G5aL069RHP1EEED0O7al061PH01TI6@0JVYZ071`L01MGEd0Jf][051@D01`L700HF5Q06][
J`1OGel0EEEE03dm?@1aLG40=3@d04a<C00i>CT0K6a/059BDP1=CDd0O7al06UYJ@1JFUX0LG5a05EE
E@1DE5@0JVYZ03dm?@20P800JFUY05IFEP2@T900IVIV0492@P2@T900IVIV05mOG`1hN7P0MWIf0410
@020P800?Cdm05aLG00j>SX0U9BD3_ooool03`0a<C40=SHf0::RXP2EUID0MgMg092@T037alL0U9BD
08b<S02YZJT0bl_;09>CT`2WYjL0WinO03Ph>00201TI6@1N01/K6`0J6QX06ATI04E5A@28R8P0/;2`
055AD@29RHT0b/[:08F5Q@2OWil0VIVI03Xj>P14A4@08b<S020P800J6QX0K6a/0:2PX02QXJ40UYJF
06MWI`1KFe/0GEeM07]kN`30`<00@41001DE5@0M7Ad0>3Ph08Z:RP2FUYH0W9bL055AD@2ATI40QXJ6
038b<P0L71`07QhN02@T901PH600De=C08f=S@1QHF40ATI606MWI`16ATH0=cLg059BDP28R8P0WYjN
05aLG01iNGT09BDU01/K6`0S8b<0;bl_059BDP1UIFD0/K6a092@T01cLg<0];Bd06a/K01UIFD0K6a/
0:b/[01IFET0Fe]K02h^;P0l?3`0RHV9071`L01WIfL0GEeM09FEU@1>CTh0:2PX0451@@2OWil0[Jf]
0:VYZ@2QXJ40NGUi06m_K`1DE5@0JVYZ09bLW02NWYh0[Zj^08>3P`2k^k/0e]KF06YZJP805aLG01/0
5ADE01TI6@1HF5P0De=C07inOP24Q8@0E5AD03Xj>P0a<C40<30`04Y:BP1QHF40Jf][092@T01NGUh0
GEeM08B4Q02[Zj/0X:2P03/k>`0a<C40KFe]06ATI01IFET0?clo03`l?00N7Qh05?ooool001?ooooo
05@0RXZ:07UiN@1KFe/0IFEU065QH@1WIfL0B4Q806ATI01OGel0DE5A06=SH`1WIfL0DE5A065QH@1K
Fe/0Kfm_04Y:BP1NGUh0Fe]K0492@P1IFET0E5AD03@d=01;Bd/0IVIV03`l?01?Cdl0KVi^04Y:BP14
A4@0LG5a04U9B@0o?cl0KFe]05EEE@1<C4`0I6AT04U9B@1HF5P0DU9B051@D01JFUX0Bd];06EUI@1F
EUH0=3@d06IVIP1:BTX0?Shn06=SH`11@D40D51@05UIF@1@D500DU9B05=CD`1OGel0Fe]K05EEE@1O
Gel0ATI605mOG`1gMgL0JFUY06IVIP1bLW80JVYZ059BDP1ZJVX0L71`05ADE01LG5`0MgMg04e=C@1R
HV80MgMg05YJFP1aLG40MWIf06=SH`2@T900Ng]k061PH02BTY8206a/K00e07UiN@1^KVh0P82005]K
F`1cLg<0Kfm_05=CD`1MGEd0MgMg05QHF01=CDd0Lg=c05eMG@1DE5@0EUIF05aLG01QHF40>3Ph069R
HP1lO7`0F5QH06UYJ@1?Cdl0Ogmo06IVIP1ADE40Shn?05aLG01RHV80PH6106m_K`1VIVH0PX:206MW
I`1HF5P0OWin06=SH`1TI6@0HV9R06a/K01DE5@0LG5a06][J`10@400F5QH06ATI019BDT0PH6106QX
J01CDe<0KVi^04m?C`1[Jf/03_ooool07P20P800GEeM05EEE@1IFET0J6QX05]KF`1aLG40LW9b06EU
I@1QHF40=SHf0410@014A4@0EUIF05YJFP1NGUh0FEUI05eMG@1PH600G5aL04a<C01=CDd0A4A403Hf
=P1GEeL0DU9B04M7A`1=CDd0EeMG0451@@80DU9B00T0DE5A06i^KP1JFUX0Lg=c05IFEP0l?3`0D51@
04Q8B00j>SX00P13@d<00`0a<C40>SXj0492@P0203hn?P0V04i>CP1GEeL0Bd];05EEE@1TI6@0QhN7
06ATI01BDU80De=C04Y:BP17AdL0FUYJ06YZJP1[Jf/0Lg=c08R8R01jNWX0P8200:VYZ@1MGEd0EUIF
04E5A@1:BTX0=CDe05EEE@1[Jf/0ATI60451@@1`L700E5AD07IfMP1/K6`0@T9206e]K@1IFET0GEeM
05IFEP1EEED2065QH@0d055AD@1YJFT0I6AT05QHF01:BTX0Bd];04a<C00h>3P0B4Q804a<C019BDT0
FUYJ06i^KP13@d<0A4A403Ph>00b<S80>c/k04A4A019BDT0<C4a0492@P18B4P0?Shn04M7A`0d=3@0
Bd];02l_;`10@400B4Q804A4A01@D500Bd];051@D01MGEd0FUYJ04=3@`1;Bd/0?3`l04];B`1]KFd0
TY:B08f=S@1GEeL0ADE504m?C`1TI6@0CDe=065QH@1XJ6P0HV9R06QXJ0kooooo02/0IVIV05EEE@1A
DE40?Cdm061PH00m?Cd0<30`03/k>`0b<S80=3@d03Xj>P1;Bd/0=CDe04I6AP11@D40@410038b<P1E
EED0>3Ph03<c<`12@T80ATI603Xj>P18B4P0CDe=06ATI012@T80Cdm?02h^;P1@D500C4a<02LW9`1F
EUH0<C4a02`/;01KFe/0?clo05ADE00`<300E5AD05MGE`1[Jf/0DU9B0080GUiN04T0SHf=04e=C@1_
Kfl0aLG5065QH@1^KVh0J6QX05YJFP1/K6`0E5AD07IfMP1IFET0J6QX05QHF01<C4`0DE5A04a<C01_
Kfl0I6AT05mOG`1_Kfl0GEeM096AT@1ADE40EEEE07MgM`1fMWH0WIfM06a/K01]KFd0N7Qh06MWI`28
R8P0L71`079bLP1kNg/0X:2P07IfMP25QHD0Cdm?075aL@2;Rh/0N7Qh04];B`1?Cdl0Bd];05MGE`17
AdL0Cdm?0861P@1jNWX0Jf][07inOP1cLg<0G5aL07EeM@1SHf<0NGUi05aLG01eMGD0DE5A05MGE`19
BDT0K6a/03De=@1VIVH0=3@d06][J`1JFUX0Cdm?096AT@1^KVh0Hf=S0080IfMW01@0EEEE05aLG00h
>3P0M7Ad06EUI@1ADE40Q8B404m?C`12@T80PX:205IFEP1RHV80L71`06IVIP1EEED0PH61030`<015
ADD0@T9207]kN`kooooo03T0FEUI04];B`1QHF40WIfM09FEU@2ATI40QXJ6061PH01FEUH0PH6104e=
C@1FEUH0?Shn06ATI01XJ6P0C4a<04A4A010@400>c/k04M7A`2HV9P0YjNW08F5Q@0o?cl0B4Q805MG
E`0L71`08B4Q03Ph>018B4P0FEUI069RHP1TI6@0JVYZ06IVIP1oOgl0NGUi06IVIP2YZJT0KFe]03`l
?00Z:RX0?clo061PH00^;Rh08B4Q03Hf=P0S8b<0?clo05=CD`19BDT0JFUY0<S8b02^[Zh0NGUi06a/
K01bLW800P28R8P03@1ZJVX0JFUY04];B`1ADE40RHV908b<S01mOGd0Shn?05]KF`15ADD0ATI6038b
<P0^;Rh00P1DE5@0;`1JFUX0ZJVY08J6QP1MGEd0CTi>07MgM`1jNWX0:BTY055AD@2k^k/0Jf][030`
<01>CTh0GUiN04=3@`0e=CD0IfMW05MGE`1:BTX0OGem09NGU`29RHT0VYZJ09nOW`1mOGd0JVYZ05aL
G01VIVH0PH61092@T00b<S80MgMg09FEU@2k^k/0]kNg07=cL`29RHT0GemO05]KF`1MGEd0CTi>07em
O@0e=CD0KFe]06UYJ@0l?3`0;Bd]0080:BTY01409RHV06QXJ02RXZ80[:b/09JFUP2OWil0Shn?08F5
Q@1PH600PH6108V9R@27QhL0=cLg04A4A012@T80ADE502PX:00Dooooo`004oooool0J@1bLW80Rh^;
05MGE`1OGel0Hf=S04a<C01SHf<0D51@04e=C@1UIFD0EUIF05EEE@1aLG40ATI606YZJP1`L700;Rh^
071`L01IFET0?clo07YjNP1BDU80ADE508J6QP19BDT0G5aL069RHP1BDU80GemO03Ti>@1NGUh0IfMW
04];B`1:BTX0F5QH03Xj>P1OGel0Kfm_034a<@1TI6@0N7Qh03Ph>01OGel0J6QX04Q8B01CDe<0EUIF
05=CD`1IFET0D51@05EEE@1VIVH0<S8b05]KF`1_Kfl0BDU905QHF01BDU80@D51075aL@13@d<0E5AD
07MgM`17AdL0H61P08^;R`1EEED0HV9R06QXJ01HF5P0IfMW07UiN@18B4P0IVIV05iNGP1CDe<0MGEe
05UIF@1YJFT0KFe]075aL@1UIFD0RHV9079bLP1^KVh0Q8B406QXJ01bLW80QhN704A4A01^KVh0Kfm_
04E5A@29RHT0Jf][079bLP1UIFD0E5AD07moO`1;Bd/0EEEE07UiN@1XJ6P0G5aL08:2PP0207]kN`0P
05QHF01WIfL0R8R805MGE`1QHF40VIVI04e=C@1kNg/0MGEe05QHF020P800RXZ:059BDP1`L700P820
04Q8B021PH40GemO05]KF`1fMWH0FUYJ06MWI`1FEUH0DE5A071`L01>CTh0GUiN05aLG01KFe/0DU9B
05aLG01WIfL>ooooo`0<07moO`1LG5`0Cdm?05ADE01PH600FEUI07AdM01fMWH0GUiN06=SH`12@T80
BTY:0P19BDT08@1`L700Fe]K06MWI`1HF5P0IFEU05]KF`17AdL0EEEE04M7A`0l?3`0C4a<059BDP10
@400>CTi06EUI@1;Bd/0D51@04e=C@1CDe<0K6a/05mOG`1^KVh0H61P03@d=01BDU80B4Q803Ph>00i
>CT0@D5103Xj>P18B4P0DE5A03`l?00203Ti>@0_04I6AP0f=SH0AdM705aLG01aLG40De=C059BDP1C
De<0CDe=055AD@1JFUX0H61P06IVIP1KFe/0JVYZ07=cL`1[Jf/0XZ:R055AD@1IFET0CDe=04Y:BP16
ATH0GEeM06i^KP16ATH0Cdm?05MGE`1BDU80K6a/06=SH`0l?3`0GemO05QHF01>CTh0F5QH051@D01L
G5`0J6QX05YJFP1`L700IVIV05QHF01CDe<0EEEE04E5A@0c<c<00P1:BTX02`0c<c<0@d=3075aL@0g
=cL0;Rh^034a<@0k>c/0Bd];04a<C01DE5@0@4100080Cdm?01X0Bd];04=3@`10@400A4A403Hf=P1@
D500BTY:0410@01RHV80?Cdm04Q8B01SHf<0De=C04Y:BP1?Cdl0Fe]K075aL@1WIfL0L71`08f=S@19
BDT0E5AD04a<C01YJFT0DU9B06QXJ080HV9R00<0H61Pooooooooool03?ooool05P24Q8@0GemO04m?
C`1YJFT0NGUi055AD@13@d<0=cLg03Xj>P0a<C40@D5103dm?@0e=CD0Cdm?03/k>`11@D40=CDe07Ee
M@0d=3@0C4a<05MGE`1BDU8204Y:BP0W06UYJ@1lO7`0EeMG06UYJ@0k>c/0F5QH06=SH`0j>SX0FEUI
03lo?`0`<300DU9B04Y:BP1>CTh0=CDe05mOG`1ADE40FEUI06EUI@1lO7`0Jf][09ZJVP1HF5P0G5aL
0;6a/@1XJ6P0Kfm_05QHF01GEeL0MGEe05iNGP1VIVH0Hf=S06MWI`1BDU80E5AD059BDP1?Cdl0MWIf
00<0H61P00@0CTi>09fMW@18B4P0D51@0P1WIfL0A02SXj<0IVIV04i>CP1dM7@0G5aL06m_K`23Ph<0
MWIf06=SH`1nOWh0K6a/071`L01BDU80OWin0::RXP1SHf<0C4a<03lo?`1SHf<0CDe=05aLG01>CTh0
Jf][07IfMP1cLg<0PX:206i^KP1PH600GUiN05eMG@1hN7P0GemO075aL@1BDU80EeMG03lo?`1NGUh0
=3@d05QHF00e=CD0IVIV06QXJ00e=CD0KVi^071`L01XJ6P0Jf][061PH01MGEd0KVi^03@d=01SHf<0
De=C06=SH`1oOgl0CTi>05UIF@1bLW80IfMW06a/K020P800IFEU06IVIP1gMgL0<30`04e=C@11@D40
Ogmo3_ooool0900k>c/092@T01/K6`0j>SX0UiNG07emO@0a<C4051@D014A4@0S8b<0KVi^01LG5`0U
9BD0WYjN0:RXZ01jNWX0@d=303hn?P0j>SX0O7al0:j^[P2c/k<0Ng]k05iNGP0`<300=cLg01LG5`0C
4a<06ATI03De=@1jNWX0Ogmo075aL@0f=SH07QhN01TI6@80>c/k03h0JFUY04A4A019BDT07alO028R
8P17AdL0K6a/04E5A@0O7al08B4Q02XZ:P1GEeL0CTi>01lO7`28R8P0YJFU08Z:RP1DE5@0De=C08b<
S01FEUH0:BTY02PX:01@D500?clo06EUI@1GEeL0?clo03De=@0];Bd05QHF02/[:`0/;2`0Bd];05MG
E`1BDU80RHV90;Fe]@1CDe<0D51@034a<@0/;2`0IfMW06][J`1VIVH0Ti>C09NGU`1;Bd/0Q8B404E5
A@0O7al0820P02`/;01LG5`0OGem075aL@1OGel0T92@0<;2`P1oOgl0PX:204U9B@<071`L0180BTY:
06][J`2PX:00>CTi06a/K02CTi<0=3@d08:2PP0T92@0;Bd]07=cL`0X:2P0GemO05EEE@1]KFd0SHf=
02DU9@0Q8B4201hN7P0A03Ti>@2=SHd0SXj>07moO`25QHD0V9RH0=SHf02k^k/0?clo069RHP0a<C40
EUIF038b<P1<C4`0VIVI09fMW@1kNg/05?ooool001?ooooo00X0MgMg07IfMP1eMGD0M7Ad05iNGP26
QXH0@D5106UYJ@1XJ6P0@4100P1MGEd0O`1BDU80K6a/05QHF01BDU80CTi>07AdM00l?3`0F5QH069R
HP1KFe/0ADE504A4A01PH600=SHf04i>CP1bLW80Cdm?03Xj>P1fMWH0@d=305aLG01gMgL0BTY:05UI
F@1gMgL0BTY:05eMG@1@D500BTY:05mOG`0l?3`0EeMG06UYJ@0X:2P0De=C06EUI@0c<c<0OWin06MW
I`10@400Lg=c065QH@1>CTh0I6AT079bLP1<C4`0FEUI06i^KP0j>SX0I6AT06YZJP1?Cdl0KVi^06=S
H`1WIfL0LW9b06UYJ@26QXH0IVIV06YZJP2FUYH0ATI606UYJ@29RHT0Bd];06][J`2EUID0B4Q80820
P01iNGT0CTi>0820P01lO7`0CTi>08>3P`1JFUX0EUIF07MgM`1KFe/0GUiN05IFEP1LG5`0Ph>3079b
LP1@D500JFUY07IfMP1KFe/0KVi^05YJFP1ZJVX0De=C05MGE`2?Shl0Bd];05UIF@1MGEd0EEEE075a
L@1@D500IfMW07IfMP1mOGd0K6a/07=cL`1LG5`0Kfm_07emO@1BDU80HV9R07alO01ADE40G5aL0820
P00m?Cd0EEEE08>3P`0d=3@0De=C07QhN00f=SH0HF5Q05iNGP10@400KFe]059BDP1ADE403_ooool0
;P2>SXh0JVYZ059BDP1JFUX0H61P05YJFP1RHV80KFe]06=SH`1QHF40>c/k04Q8B01;Bd/0KVi^06YZ
JP1XJ6P0HV9R06IVIP1LG5`0Fe]K05eMG@1=CDd0ATI603Xj>P1EEED0BDU904m?C`1NGUh0Hf=S055A
D@1EEED0B4Q805=CD`1RHV80JFUY08^;R`1HF5P0B4Q805IFEP17AdL0@T9204A4A016ATH0=cLg04M7
A`1UIFD20410@00<04A4A01?Cdl0@D5104Y:BP1SHf<0JFUY05mOG`1iNGT0CTi>05=CD`1ADE40F5QH
0P1WIfL0=`1YJFT0JVYZ07MgM`1UIFD0VYZJ06EUI@1VIVH0D51@04I6AP0o?cl0G5aL079bLP1CDe<0
FEUI07EeM@1[Jf/0OGem06MWI`19BDT0Fe]K06a/K01IFET0GEeM05]KF`1WIfL0@T9206YZJP1NGUh0
DE5A04E5A@1;Bd/0@d=304i>CP12@T80BTY:04Q8B00i>CT0>SXj04U9B@0_;bl0;Bd]04A4A00j>SX0
@T920451@@1>CTh0>3Ph0410@01:BTX0CDe=05EEE@17AdL0;Bd]04=3@`15ADD00P17AdL05@1>CTh0
>c/k04i>CP1GEeL0C4a<055AD@1CDe<0BDU9061PH01@D500Ng]k07alO01KFe/0De=C065QH@1`L700
CTi>05QHF01CDe<0FUYJ05UIF@0>ooooo`0706a/K01DE5@0B4Q804];B`1ZJVX0F5QH03`l?00203@d
=00=02h^;P1;Bd/0@T9203<c<`1?Cdl0;Rh^03Lg=`0Z:RX0De=C03Hf=P0l?3`0A4A403Lg=`020410
@00P05ADE01gMgL0CTi>05aLG00e=CD0Hf=S04a<C00_;bl0GUiN03Hf=P0_;bl0H61P04A4A01=CDd0
>3Ph05QHF01FEUH0IFEU08:2PP1UIFD0F5QH0:>SX`1BDU80Lg=c0<_;b`1ZJVX0MgMg05]KF`1XJ6P0
LG5a05aLG01kNg/206e]K@0A05mOG`18B4P0IfMW05YJFP1jNWX0L71`069RHP1SHf<0DE5A09VIV@19
BDT0@41005mOG`1cLg<0OGem06a/K01XJ6P00P1fMWH0?`26QXH0NWYj07YjNP1`L700MgMg06m_K`2;
Rh/0G5aL07IfMP2BTY80IVIV05MGE`17AdL0Bd];05YJFP1HF5P0@d=306ATI01IFET0G5aL075aL@1P
H600FEUI07=cL`1UIFD0Ng]k06QXJ026QXH0A4A405=CD`1>CTh0Hf=S04a<C01XJ6P0<30`069RHP1Q
HF40CDe=08j>SP1lO7`0F5QH07MgM`1[Jf/0E5AD05QHF00];Bd0JFUY05mOG`1ZJVX0Ng]k04M7A`1F
EUH0M7Ad05QHF01YJFT0Kfm_04i>CP1KFe/0NWYj030`<017AdL0BTY:09:BTP0>ooooo`0K03De=@0]
;Bd0>CTi02PX:01cLg<0T92@01XJ6P0@41004A4A010@400k>c/0GEeM01LG5`1oOgl0PH6103Ph>00B
4Q805ADE01HF5P0G5aL0=CDe06=SH`2NWYh0YJFU0861P@1XJ6P05QHF008051@D00D0=cLg08f=S@2=
SHd0C4a<024Q8@0201DE5@1101lO7`0h>3P0I6AT03dm?@1PH600De=C04A4A01oOgl0/;2`07IfMP14
A4@0Cdm?06][J`1mOGd0Bd];0451@@0e=CD0@41007alO018B4P0G5aL06UYJ@1gMgL06ATI034a<@2?
Shl0N7Qh07emO@0^;Rh09RHV01dM7@17AdL071`L01PH600o?cl0M7Ad0:6QX@2CTi<0RXZ:092@T00R
8R8071`L01dM7@0X:2P0CDe=020P800X:2P0SXj>0;^k^`1iNGT0PX:208N7Q`1CDe<0=SHf01`L700o
?cl0Hf=S02d];@15ADD0?clo0::RXP1<C4`0Bd];065QH@0L71`00P0O7al01`0g=cL0S8b<096AT@1G
EeL0MWIf04A4A01WIfL00P18B4P0700`<300ATI60;Fe]@2^[Zh0NGUi07MgM`2;Rh/0LW9b04m?C`0]
;Bd0BDU9092@T02>SXh0B4Q803dm?@1GEeL0WIfM08F5Q@1VIVH0UIFE08^;R`2>SXh0OWin08Z:RP1e
MGD0TY:B03@d=01>CThDooooo`004oooool0BP22PX80MWIf05iNGP1MGEd0H61P06EUI@1HF5P0Cdm?
0492@P1PH600Cdm?04a<C01iNGT0GemO05]KF`1oOgl0:b/[06][J`1bLW80<C4a079bLP1EEED0=CDe
061PH01IFET0ATI60410@01DE5@0D51@04];B`1ADE40G5aL04I6AP1<C4`0G5aL03Hf=P1CDe<0L71`
03hn?P18B4P0P82004I6AP1CDe<0FEUI04=3@`1DE5@0H61P03@d=01WIfL0E5AD03`l?01fMWH0@T92
0451@@1aLG40<c<c05ADE01WIfL0;2`/05mOG`1FEUH0H61P08b<S01XJ6P0EUIF075aL@1SHf<0HF5Q
079bLP1WIfL0DE5A08b<S01SHf<0DE5A0P1[Jf/0?`1]KFd0IFEU08:2PP1^KVh0K6a/05mOG`1hN7P0
JFUY05eMG@1mOGd0GUiN06IVIP1iNGT0Bd];07MgM`1`L700ADE508B4Q01gMgL0Cdm?07inOP1GEeL0
MGEe06e]K@1>CTh0I6AT06m_K`1DE5@0IFEU06MWI`1fMWH0CDe=04];B`1mOGd0De=C05aLG01nOWh0
EeMG06QXJ01`L700EUIF06YZJP1`L700EUIF075aL@1gMgL0BTY:07inOP1LG5`0FUYJ06a/K01BDU80
L71`059BDP1?Cdl0HV9R05UIF@1bLW80GEeM05UIF@1SHf<0EeMG06i^KP0>ooooo`0E07]kN`1QHF40
CDe=04e=C@1OGel0DU9B06YZJP1iNGT0KVi^06UYJ@0i>CT0B4Q804A4A01>CTh0F5QH04a<C01JFUX0
GEeM05EEE@1ADE40FEUI0080ATI60100@D5104Q8B015ADD0@41004i>CP1[Jf/0E5AD05iNGP1JFUX0
HV9R06YZJP1LG5`0K6a/05mOG`15ADD0HV9R0P1BDU80=P0i>CT0?Cdm030`<010@400JVYZ04M7A`13
@d<0BDU905IFEP19BDT0?Shn05QHF01mOGd0JFUY06MWI`1@D500JFUY05ADE01bLW80Kfm_06e]K@2<
S8`0P82006IVIP1@D500Jf][05YJFP1LG5`0C4a<05QHF01<C4`0KVi^06e]K@1EEED0Cdm?06a/K01P
H600OWin06][J`18B4P0EEEE06YZJP1OGel0H61P05EEE@1JFUX0JVYZ065QH@1UIFD0Bd];055AD@1C
De<0@41005QHF080>c/k02/0Bd];03De=@0i>CT0GEeM03Xj>P0b<S80=SHf01lO7`17AdL0ADE5059B
DP11@D40B4Q805EEE@16ATH0AdM704E5A@0R8R80@d=304];B`0m?Cd0Bd];05YJFP0o?cl0E5AD05mO
G`1JFUX0G5aL04m?C`1HF5P0K6a/04E5A@1OGel0IfMW04U9B@12@T80De=C05QHF014A4@0FUYJ05=C
D`1HF5P0Kfm_00kooooo02P0N7Qh069RHP0l?3`0CDe=07YjNP10@400ATI603Hf=P0k>c/0;Bd]0451
@@0l?3`0:b/[04Y:BP0f=SH0=CDe034a<@1UIFD0:2PX04a<C01BDU80C4a<05eMG@0o?cl0GemO06YZ
JP1>CTh0FUYJ03Lg=`1BDU80I6AT04=3@`1ADE40B4Q8034a<@1FEUH0EEEE04e=C@0l?3`0Kfm_0P1F
EUH206i^KP0d06IVIP2PX:00BDU906EUI@2d];@0IFEU06i^KP1PH600IFEU07EeM@1OGel0I6AT06=S
H`1VIVH0DU9B04e=C@1IFET0C4a<07]kN`1@D500HV9R05YJFP1=CDd0WIfM04Y:BP12@T80GemO06a/
K01UIFD0LW9b04Q8B01RHV80J6QX065QH@1kNg/0MgMg069RHP1jNWX0LG5a08V9R@1JFUX0NGUi09bL
W01SHf<0Bd];0492@P1YJFT0C4a<05eMG@1>CTh0De=C05iNGP80JVYZ02X0IFEU05iNGP1lO7`0FUYJ
07emO@1]KFd0K6a/051@D01>CTh0@d=306IVIP16ATH0Cdm?03Lg=`1TI6@0CTi>03/k>`2LW9`0KVi^
07]kN`1`L700JFUY069RHP1^KVh0=3@d06m_K`1mOGd0Fe]K08^;R`1@D500E5AD09RHV01PH600IFEU
08>3P`1ADE40OGem07inOP0d=3@0ATI603dm?@1lO7`>ooooo`0R05MGE`1=CDd0:BTY03/k>`0i>CT0
Kfm_04i>CP0G5aL04Q8B00l?3`0B4Q80De=C05ADE02IVIT0DE5A05IFEP0T92@0:2PX02d];@0e=CD0
ADE506][J`28R8P0emOG0<G5a@2DU9@0FEUI03/k>`0g=cL0LG5a0::RXP2d];@0EUIF01DE5@804a<C
02H05ADE01lO7`2:RXX0N7Qh09^KV`1CDe<0?clo065QH@2KVi/0W9bL06=SH`0a<C40=3@d04m?C`2U
YJD0NWYj05mOG`1bLW80De=C059BDP0c<c<0;Rh^06MWI`1VIVH0@D5107]kN`2g]kL0Cdm?04Q8B00o
?cl0=CDe03<c<`1/K6`0F5QH07=cL`1dM7@0`<3005mOG`80=3@d0180DE5A01`L700K6a/0:b/[061P
H00F5QH061PH05UIF@1DE5@0@d=306i^KP1GEeL0:b/[02@T900P8200EUIF05mOG`1;Bd/205EEE@0@
0;fm_@13@d<0<C4a06QXJ01SHf<0CDe=05MGE`1RHV80TY:B04I6AP1?Cdl0S8b<08J6QP0Y:BT0BDU9
0410@080C4a<01P0aLG50;>c/`1FEUH0Lg=c06YZJP0`<300BDU909fMW@2XZ:P0Rh^;07AdM00U9BD0
8b<S04a<C02d];@0MgMg06MWI`1?Cdl0SXj>08n?S`0c<c<0KFe]09bLW02UYJD2061PH1Cooooo000C
ooooo`2;071`L021PH40GEeM06MWI`1ADE40IFEU05EEE@1?Cdl0FEUI06ATI01ADE40GEeM06YZJP1H
F5P0I6AT06a/K016ATH0MWIf05EEE@1;Bd/0M7Ad04M7A`1>CTh0De=C059BDP1EEED0A4A405=CD`1J
FUX0>SXj07AdM01JFUX0C4a<06YZJP1DE5@0EUIF05mOG`1SHf<0ATI6051@D01ZJVX0CTi>0492@P1R
HV80EUIF04E5A@1DE5@0CTi>0492@P1=CDd0JVYZ04];B`1ADE40MWIf04i>CP1JFUX0LG5a04Y:BP12
@T80KFe]04U9B@1VIVH0MgMg05MGE`1VIVH0IFEU04Y:BP1VIVH0Hf=S06e]K@1MGEd0Jf][07UiN@1I
FET0EeMG07YjNP1VIVH0Hf=S08Z:RP1PH600IfMW07alO01XJ6P0Lg=c06e]K@1hN7P0Hf=S06YZJP1Q
HF40IVIV06EUI@1KFe/0GemO06UYJ@1TI6@0Ph>305mOG`1ADE40QHF504U9B@1UIFD0KFe]06m_K`1W
IfL0Lg=c079bLP1]KFd0EUIF06ATI01hN7P0Hf=S059BDP1QHF40GEeM06i^KP1XJ6P0LW9b06QXJ01U
IFD0N7Qh05mOG`1WIfL0PH6106EUI@1VIVH0Ph>305]KF`1MGEd0KVi^03Xj>P1>CTh0JFUY04M7A`1R
HV80GEeM04=3@`1RHV80EEEE04E5A@0>ooooo`1D07moO`1JFUX0EUIF05QHF01SHf<0EEEE079bLP1W
IfL0GemO05QHF00m?Cd0>SXj04Q8B01;Bd/0HV9R051@D01RHV80EeMG05aLG01=CDd0AdM70451@@0n
?Sh0>c/k04E5A@0o?cl0@41003Xj>P1EEED0DU9B05YJFP1=CDd0HF5Q06=SH`1VIVH0Jf][05IFEP12
@T80G5aL05IFEP1@D500@41004Q8B011@D40C4a<06e]K@12@T80Bd];04I6AP1IFET0C4a<04M7A`1E
EED0IfMW06EUI@21PH40IVIV06YZJP1;Bd/0Cdm?05eMG@1gMgL0Ti>C07alO01nOWh0IfMW07MgM`1X
J6P0E5AD04U9B@1FEUH0Bd];06m_K`1hN7P0G5aL05=CD`1IFET0CTi>075aL@1KFe/0FUYJ05QHF01T
I6@0De=C0P1PH6004P1NGUh0GemO061PH01bLW80LG5a04];B`1EEED0B4Q805EEE@0l?3`0AdM70492
@P19BDT0A4A406i^KP14A4@0<c<c03Ti>@80B4Q80280AdM705QHF010@400@T9204I6AP10@400@d=3
0410@00T92@0?3`l051@D01>CTh0ATI606MWI`16ATH0Bd];06QXJ01VIVH0EeMG04I6AP1SHf<0IfMW
04Y:BP1GEeL0I6AT05eMG@1HF5P0EUIF04m?C`18B4P0F5QH059BDP1MGEd0I6AT3_ooool0<`1^KVh0
Hf=S03Xj>P1VIVH0Ogmo04M7A`19BDT0<C4a03lo?`0b<S80ATI6038b<P0i>CT0E5AD03@d=00k>c/0
?Cdm04Q8B00O7al0>c/k0492@P0o?cl0@d=303hn?P1EEED0IFEU05MGE`1JFUX0;2`/065QH@1FEUH0
<c<c05UIF@0f=SH09BDU05MGE`1>CTh0D51@03De=@1JFUX0GemO04I6AP2:RXX0I6AT061PH02RXZ80
Fe]K061PH030`<00BTY:05mOG`0205]KF`0L07AdM01OGel0EeMG079bLP1ZJVX0IFEU059BDP1SHf<0
F5QH08F5Q@1UIFD0L71`065QH@1CDe<0SXj>04];B`10@400FUYJ071`L015ADD0M7Ad04e=C@1SHf<0
Kfm_071`L01bLW80LG5a07EeM@80Ph>30140UIFE05]KF`1oOgl0YJFU05MGE`1TI6@0ADE505]KF`1C
De<0F5QH04];B`1?Cdl0L71`07EeM@1]KFd0I6AT051@D00205YJFP0A08R8R01eMGD0O7al0492@P1?
Cdl0?Shn079bLP1CDe<0C4a<03@d=01GEeL0CDe=03lo?`2RXZ80D51@06QXJ01UIFD00P1LG5`04`1b
LW80=CDe04];B`1]KFd0Fe]K07EeM@1;Bd/0E5AD07EeM@1EEED0De=C07=cL`12@T80RXZ:09:BTP0k
>c/0BDU903/k>`1iNGT03_ooool0<`26QXH0Cdm?04i>CP0a<C40@T9204A4A00g=cL0ADE501dM7@0B
4Q80410@01TI6@2QXJ40RHV903Lg=`1>CTh09bLW01/K6`0H61P0820P01hN7P0m?Cd0Lg=c08F5Q@1b
LW80IVIV06m_K`0o?cl0BDU907QhN02MWId0XZ:R061PH00V9RH08B4Q02<S8`0P8200CTi>08f=S@1=
CDd0[Zj^08:2PP1;Bd/0@41005MGE`1WIfL0H61P08j>SP22PX80WYjN0;bl_00208>3P`1G04M7A`1@
D500>CTi02PX:00L71`0DE5A07=cL`1SHf<0NGUi08F5Q@1UIFD0?clo04I6AP0f=SH0=cLg07MgM`1Q
HF40NGUi07AdM019BDT0?3`l038b<P0I6AT0=3@d04a<C00W9bL0E5AD0;:b/P10@400=3@d02/[:`0m
?Cd0F5QH0:2PX01FEUH0D51@04a<C01XJ6P0WinO06MWI`0^;Rh0Lg=c06e]K@1bLW80];Bd06MWI`0j
>SX0S8b<02HV9P0h>3P0O7al08J6QP15ADD0C4a<04=3@`0_;bl05QHF01`L701=CDd0Bd];08n?S`35
aLD0][Jf09JFUP0m?Cd08b<S03`l?01YJFT0QHF509bLW00m?Cd0;Bd]02h^;P0/;2`0Jf][04M7A`0b
<S80EEEE07UiN@1=CDd0A4A407UiN@1/K6`0JVYZ07]kN`1UIFD0DU9B01Cooooo000Cooooo`0_08:2
PP1UIFD0MWIf06=SH`1DE5@0Ng]k03Xj>P1>CTh0C4a<03`l?01XJ6P0DU9B05ADE01eMGD0>SXj055A
D@1UIFD0G5aL04];B`1LG5`0H61P069RHP17AdL0@D51065QH@1NGUh0>3Ph06QXJ015ADD0=CDe08B4
Q01:BTX0Fe]K06EUI@1>CTh0J6QX06EUI@1BDU80IVIV03/k>`1BDU80Ng]k02LW9`1RHV80Cdm?02`/
;01/K6`00P10@4009`1ADE40HV9R051@D01NGUh0CTi>05MGE`1IFET0Hf=S06IVIP1BDU80J6QX04U9
B@1ZJVX0OGem06][J`1cLg<0J6QX075aL@1;Bd/0IFEU07MgM`13@d<0IVIV08F5Q@12@T80IfMW07Qh
N017AdL0Hf=S08V9R@1:BTX0Fe]K07=cL`1=CDd0LG5a06ATI01JFUX0HV9R06=SH`0205mOG`0a075a
L@1FEUH0FUYJ05mOG`1YJFT0FEUI05]KF`1UIFD0GEeM06QXJ01MGEd0De=C08j>SP18B4P0Kfm_07Ui
N@1LG5`0JFUY04M7A`1YJFT0Jf][03`l?01TI6@0RXZ:05IFEP1iNGT0SHf=059BDP1mOGd0Ph>304I6
AP22PX80M7Ad03dm?@1_Kfl0Ph>30492@P1]KFd0HF5Q051@D01VIVH0EUIF04M7A`2<S8`0De=C04M7
A`2ATI40Cdm?05MGE`0>ooooo`0R06i^KP1?Cdl0HF5Q05=CD`1HF5P0Cdm?06i^KP1PH600HF5Q04i>
CP14A4@0<c<c04M7A`0k>c/0E5AD04U9B@1RHV80E5AD05QHF017AdL0>c/k0410@00e=CD0;bl_03Hf
=P0k>c/0@D5104M7A`1BDU80CDe=05ADE01CDe<0IVIV04a<C080F5QH04P0C4a<03dm?@1FEUH0DE5A
04m?C`11@D40B4Q803dm?@1=CDd0KVi^04Q8B01:BTX0B4Q805QHF01<C4`0A4A406=SH`1bLW80IFEU
08>3P`1nOWh0GEeM05=CD`1ADE40FUYJ06UYJ@2CTi<0QHF50820P01VIVH0QHF504I6AP14A4@0BDU9
04E5A@1GEeL0E5AD05iNGP1CDe<0EEEE065QH@1^KVh0O7al04a<C01=CDd0EEEE05]KF`1:BTX0Jf][
069RHP1LG5`0B4Q806e]K@1_Kfl0N7Qh03/k>`1EEED0BTY:04e=C@1OGel0AdM705YJFP1?Cdl0BDU9
05mOG`0l?3`0;bl_03`l?013@d<0>c/k04M7A`1HF5P204I6AP0N04i>CP18B4P0AdM704a<C00n?Sh0
B4Q805ADE01GEeL0C4a<04m?C`10@400De=C05UIF@1NGUh0FUYJ05MGE`1dM7@0MGEe055AD@1TI6@0
DU9B04=3@`14A4@0CDe=059BDP1<C4`0De=C055AD@1JFUX0JVYZ3_ooool0S01]KFd0HV9R04i>CP1V
IVH0M7Ad04a<C015ADD0@D5103hn?P0Y:BT0@d=302/[:`0k>c/0CTi>03<c<`1<C4`0=CDe04Q8B00]
;Bd0?3`l04A4A011@D40EeMG04U9B@1JFUX0GUiN04Q8B01QHF40<30`055AD@18B4P0ATI605eMG@0j
>SX0>c/k05iNGP1DE5@0D51@03<c<`1[Jf/0GEeM03Hf=P1eMGD0JVYZ07YjNP2UYJD0EUIF06UYJ@31
`L40EeMG06=SH`1DE5@0FEUI05YJFP1QHF40D51@06=SH`1XJ6P0DE5A04Y:BP1JFUX0D51@075aL@1[
Jf/0LW9b05QHF017AdL0NWYj04U9B@0n?Sh0IVIV07QhN00i>CT0Hf=S04E5A@1RHV80N7Qh07YjNP1Z
JVX0LG5a07AdM02PX:00IFEU09VIV@1HF5P0NGUi0;Bd]01UIFD0NGUi04M7A`1ADE40FEUI04a<C01=
CDd0B4Q807AdM01ZJVX0NGUi05aLG01CDe<0GUiN04];B`1bLW80Kfm_07alO013@d<0De=C04];B`1]
KFd0GUiN05eMG@0g=cL0GEeM04=3@`1LG5`0P82004Y:BP1^KVh0N7Qh06MWI`1KFe/0PX:203dm?@0k
>c/0I6AT07MgM`1hN7P0De=C06ATI01YJFT0FUYJ06ATI01ZJVX0GUiN07QhN02][Jd0ADE50451@@0n
?Sh0O7al3_ooool04`2<S8`0L71`06a/K00i>CT071`L01hN7P0^;Rh0<C4a04I6AP0P8200=SHf05iN
GP1RHV80X:2P08R8R00`<3004a<C010@400E5AD00P0F5QH03P0H61P0Fe]K03Hf=P0d=3@0FEUI069R
HP0j>SX0B4Q8071`L02QXJ40OWin079bLP0E5AD051@D0`0E5AD0IP0F5QH0D51@08n?S`0Y:BT05ADE
01@D500W9bL0>CTi03@d=01fMWH0AdM706][J`1jNWX0FUYJ0410@00o?cl0=3@d02XZ:P0Q8B40:RXZ
08B4Q02=SHd0Vi^K059BDP0g=cL0@T92051@D01;Bd/0TY:B092@T028R8P0Fe]K01lO7`0_;bl04a<C
01DE5@0g=cL0DE5A01dM7@1EEED0YZJV0:n_[`1BDU80LG5a08Z:RP2>SXh0WinO09ZJVP2g]kL0H61P
03/k>`0/;2`0;bl_05ADE01kNg/0OWin05aLG00H61P0ATI606=SH`2WYjL0Z:RX0:NWY`19BDT0Cdm?
09BDU02l_;`0QHF5059BDP20P800<c<c01/K6`0E5AD051@D05mOG`2SXj<0^;Rh0:^[Z`1[Jf/0@D51
03<c<`1FEUH0D51@05eMG@1PH6009RHV01TI6@0i>CT0NGUi06][J`1OGel0HV9R04i>CP0o?cl0Ti>C
04Q8B020P800FEUI02@T9017AdL05aLG04Y:BQCooooo000Cooooo`80O7al0480CDe=05UIF@1UIFD0
D51@05UIF@1QHF40Bd];06EUI@0k>c/0ADE507UiN@0i>CT0EeMG06IVIP0a<C40JFUY05ADE00_;bl0
Kfm_05EEE@0o?cl0FUYJ04i>CP1LG5`0AdM705IFEP1PH600?3`l055AD@1XJ6P0?3`l04];B`1mOGd0
De=C055AD@1mOGd0?3`l04i>CP2;Rh/0?Shn05QHF01cLg<0C4a<05=CD`13@d<0?clo06][J`0W9bL0
CDe=06m_K`0U9BD0GEeM06ATI00k>c/0IFEU059BDP0l?3`0Ng]k04i>CP1=CDd0Q8B406=SH`1ZJVX0
W9bL079bLP1TI6@2065QH@0N06YZJP1UIFD0KVi^05QHF01TI6@0IVIV069RHP1SHf<0LG5a07UiN@1j
NWX0HV9R06YZJP1VIVH0DE5A07AdM00f=SH0Hf=S06EUI@0a<C40PX:204Y:BP1;Bd/0IfMW05MGE`1`
L700Kfm_04a<C02>SXh0HF5Q0P1NGUh0401ADE40EEEE06IVIP1PH600NGUi055AD@15ADD0NWYj04e=
C@1JFUX0KVi^04e=C@1lO7`0Kfm_051@D01eMGD2061PH00C06ATI01LG5`0IFEU07YjNP1KFe/0L71`
06QXJ01EEED0K6a/05QHF01;Bd/0IfMW04i>CP1ZJVX0IVIV04Q8B01JFUX0D51@04I6AP0>ooooo`0M
06IVIP1GEeL0HF5Q061PH01OGel0GUiN07=cL`1iNGT0LW9b065QH@18B4P0BDU905UIF@1LG5`0J6QX
05aLG01UIFD0G5aL06=SH`15ADD0D51@04];B`18B4P0=3@d04E5A@0a<C40AdM705QHF01IFET00P1O
Gel0201GEeL0MGEe04];B`1FEUH0LG5a05UIF@1;Bd/0FUYJ0P1;Bd/01`0f=SH0?Cdm03lo?`13@d<0
EeMG04I6AP11@D400P16ATH0FP1<C4`0?3`l051@D01MGEd0DE5A05=CD`1QHF40GUiN05MGE`1<C4`0
EeMG07AdM02ATI40IfMW08:2PP1OGel0KVi^04U9B@0n?Sh0Bd];04m?C`1RHV80O7al06a/K01DE5@0
De=C06a/K01GEeL0NWYj04U9B@17AdL0E5AD05mOG`1IFET0J6QX04];B`1LG5`0DU9B069RHP1ZJVX0
W9bL05aLG01EEED0CDe=05mOG`1XJ6P0Bd];065QH@1LG5`0Fe]K079bLP1_Kfl0CTi>04A4A01<C4`0
CDe=0451@@1FEUH0BTY:04I6AP1LG5`0GEeM04=3@`1GEeL0>CTi04E5A@1:BTX0CDe=05ADE01bLW80
DE5A061PH011@D40GEeM05aLG01ZJVX0O7al07AdM013@d<0EEEE07YjNP1QHF40ADE504i>CP15ADD0
?Shn05UIF@17AdL0F5QH06IVIPkooooo00h0Ng]k06IVIP1gMgL0MWIf06m_K`1=CDd0?Cdm03Ph>00l
?3`0:BTY04A4A00Z:RX0<c<c051@D080>3Ph0P0f=SH0KP0];Bd0=SHf03Xj>P1>CTh0A4A404a<C01?
Cdl0FEUI04m?C`1HF5P0=3@d04e=C@15ADD0@41004U9B@0e=CD09BDU04M7A`13@d<0@D5102l_;`1X
J6P0FUYJ0410@01iNGT0I6AT06e]K@2_[jl0GUiN07IfMP39bLT0GUiN06YZJP1VIVH0I6AT06YZJP1S
Hf<0E5AD079bLP1TI6@0F5QH04Y:BP1[Jf/0Fe]K06m_K`1`L700LW9b05YJFP14A4@0Rh^;04i>CP19
BDT0I6AT07MgM`0n?Sh0DE5A04a<C01YJFT0JVYZ07EeM@1XJ6P0MGEe06YZJP2`/;00F5QH0;Bd]01[
Jf/0LW9b07moO`1SHf<0Lg=c03Hf=P1MGEd0De=C04m?C`1@D500?3`l05UIF@1DE5@0IfMW06e]K@1;
Bd/0@d=30410@01oOgl0Ng]k0820P00k>c/0HF5Q04m?C`1XJ6P0Jf][05]KF`0n?Sh0IfMW03hn?P12
@T80NWYj04m?C`1SHf<0MgMg06e]K@1MGEd0L71`03Xj>P1=CDd0I6AT07=cL`1lO7`0DU9B0P1[Jf/0
2P1ZJVX0GEeM08^;R`1kNg/0OGem0:f][@19BDT0Bd];03Lg=`21PH4>ooooo`0507emO@16ATH0S8b<
03Lg=`0F5QH00P0C4a<0Q@1<C4`0O7al06m_K`0];Bd0:2PX051@D02c/k<0LG5a061PH00N7Qh05ADE
01HF5P0E5AD051@D01DE5@1:BTX09BDU01DE5@0];Bd0Ogmo04I6AP0`<300=3@d03Ph>01fMWH0`/;2
03dm?@0E5AD051@D01TI6@0T92@0Cdm?08R8R02i^KT0A4A401LG5`0E5AD0E5AD01lO7`0Z:RX0HF5Q
04E5A@0g=cL0MgMg096AT@11@D40CDe=01HF5P0O7al0;2`/03Hf=P2:RXX0Lg=c05ADE00^;Rh051@D
01/K6`0_;bl0B4Q80:2PX033`l<0CDe=01PH600b<S808b<S01HF5P0D51@05ADE04M7A`1:BTX0OWin
0=;BdP1PH600EEEE06YZJP2:RXX0YjNW0;Zj^P1aLG40:2PX05mOG`20P800@D510410@02>SXh0[Zj^
07]kN`0Q8B40B4Q803De=@0S8b<0SXj>09BDU027QhL0W9bL096AT@2GUiL0FUYJ05EEE@20P800[:b/
071`L019BDT071`L02/[:`1KFe/0g]kN0=?Cd`17AdL09BDU04M7A`24Q8@0:BTY02<S8`1DE5@0Hf=S
02PX:00T92@0KVi^0:j^[P1lO7`0N7Qh05ADE00a<C40=SHf0:ZZZP20P800PX:207AdM01^KVh09bLW
01HF5P0h>3P05?ooool001?ooooo0P1cLg<0A`1NGUh0HF5Q04m?C`1VIVH0BDU904e=C@1@D500Fe]K
0410@01OGel0BTY:055AD@1LG5`0GEeM05=CD`1[Jf/0EeMG04];B`1TI6@0CTi>04M7A`14A4@0BDU9
05iNGP0k>c/0FUYJ04];B`0j>SX0G5aL05QHF012@T80GemO051@D01MGEd0EUIF05QHF01<C4`0?clo
06IVIP1DE5@0ADE506m_K`1GEeL0?clo04Y:BP1SHf<0C4a<0410@01IFET0GEeM051@D01[Jf/0BTY:
03/k>`1^KVh0B4Q803hn?P1eMGD0ADE5069RHP1]KFd0EEEE06IVIP1ZJVX0Fe]K05mOG`1GEeL0IVIV
055AD@1RHV80LG5a0080HV9R00@0NWYj06=SH`1QHF40LW9b0P1ZJVX0>P1^KVh0GemO07UiN@1ZJVX0
L71`05=CD`1ZJVX0FEUI055AD@22PX80CTi>06i^KP1KFe/0DU9B08N7Q`1QHF40C4a<08B4Q01FEUH0
I6AT06MWI`1iNGT0H61P05eMG@1_Kfl0KFe]05YJFP1?Cdl0IVIV05]KF`1EEED0J6QX06a/K01MGEd0
J6QX06e]K@1QHF40Lg=c06e]K@1NGUh0NWYj07inOP1CDe<0HF5Q075aL@0o?cl0GemO06=SH`0i>CT0
Fe]K06EUI@0n?Sh0GEeM05YJFP10@400J6QX05iNGP12@T8>ooooo`0`06UYJ@1QHF40KFe]05mOG`1/
K6`0GEeM075aL@1^KVh0J6QX05IFEP14A4@0CDe=065QH@1HF5P0GemO05MGE`1PH600HV9R05QHF01<
C4`0Bd];051@D016ATH0@d=30492@P0o?cl0ADE505YJFP1<C4`0GEeM05]KF`1GEeL0NWYj05IFEP1M
GEd0IFEU05EEE@10@400IfMW05IFEP1=CDd0?3`l04a<C013@d<0ATI605mOG`14A4@0@d=30P17AdL0
<01>CTh0Bd];06QXJ01PH600FUYJ051@D01>CTh0GEeM04a<C01>CTh0EeMG06EUI@20P800B4Q805iN
GP17AdL0NGUi04e=C@0k>c/0@D5104e=C@1GEeL0Lg=c04Y:BP1?Cdl0EeMG06EUI@1TI6@0RXZ:069R
HP1DE5@0I6AT05aLG01>CTh0C4a<05EEE@1GEeL0Bd];07=cL`1lO7`0SHf=05=CD`1>CTh0Fe]K07Yj
NP26QXH0ADE504U9B@80EEEE02P0QXJ607AdM017AdL0B4Q805ADE01<C4`0?clo05=CD`18B4P0ADE5
059BDP1CDe<0?3`l05ADE00d=3@0<30`04A4A019BDT0AdM706a/K00o?cl0HV9R04Y:BP1LG5`0GemO
06=SH`1mOGd0O7al055AD@1hN7P0NGUi04i>CP10@400DE5A05ADE019BDT0FUYJ04e=C@1GEeL0I6AT
3_ooool05@1hN7P0G5aL07AdM01kNg/0JVYZ04m?C`17AdL0?Cdm0410@00^;Rh0B4Q802/[:`0c<c<0
EEEE02h^;P0e=CD0?Cdm03/k>`0j>SX0>3Ph03dm?@0204i>CP1e05IFEP1EEED0EUIF05EEE@1;Bd/0
>CTi05IFEP0m?Cd0@D5104a<C00e=CD0>3Ph04Y:BP17AdL0@D5103dm?@1PH600De=C04=3@`1YJFT0
G5aL065QH@2c/k<0CTi>065QH@2n_[h0KVi^069RHP1FEUH0MWIf05ADE01KFe/0IFEU069RHP1WIfL0
Cdm?04Q8B01[Jf/0Bd];06m_K`1NGUh0K6a/05YJFP0l?3`0OWin04a<C013@d<0LW9b06][J`1=CDd0
GEeM05=CD`1NGUh0Jf][07AdM01TI6@0KVi^075aL@2GUiL0D51@0::RXP1OGel0MGEe09ZJVP20P800
OWin04E5A@1;Bd/0GUiN05QHF01DE5@0BDU905]KF`1QHF40MgMg05=CD`1ADE40Jf][05MGE`1_Kfl0
IFEU08Z:RP11@D40CTi>06YZJP1OGel0Lg=c05eMG@10@400FEUI04E5A@1HF5P0MgMg05iNGP1YJFT0
OGem07YjNP1XJ6P0G5aL02d];@1FEUH0Bd];061PH023Ph<0Cdm?06a/K01UIFD0Fe]K06QXJ02=SHd0
O7al08f=S@2TY:@0A4A405=CD`1;Bd/0Ph>300kooooo01/0P82009BDU01[Jf/0>c/k02h^;P0X:2P0
7AdM02/[:`0k>c/0T92@0:FUY@2CTi<0QXJ60:f][@2GUiL0HV9R059BDP0h>3P0<30`02PX:00G5aL0
820P04Q8B00O7al05aLG04i>CP0c<c<00P0Q8B404P0L71`06a/K024Q8@21PH40OGem06YZJP0b<S80
;Bd]02/[:`0Q8B40=cLg08N7Q`1gMgL0NGUi08R8R01SHf<0?3`l03hn?P809BDU00`0DE5A09>CT`27
QhL0Ti>C08V9R@1FEUH0BTY:06ATI027QhL0XJ6Q0:^[Z`1SHf<201@D5009014A4@0I6AT0>SXj06][
J`1`L700MWIf04m?C`1eMGD07AdM00805QHF048051@D01lO7`2EUID0KFe]075aL@2/[:`0VIVI06QX
J01KFe/0HF5Q0:JVYP1[Jf/08b<S03De=@1:BTX0SHf=05iNGP2FUYH0Lg=c08V9R@2YZJT0WYjN09RH
V01nOWh0RHV9051@D00/;2`0?3`l09ZJVP0a<C40;Rh^04U9B@1HF5P0AdM7061PH01mOGd0UiNG09>C
T`2?Shl0WinO0:j^[P26QXH0<30`03Xj>P20P800?clo01`L700O7al0JFUY02l_;`0e=CD0Xj>S08V9
R@1ZJVX07alO02@T900h>3P0De=C07]kN`0/;2`0CDe=08j>SP2e]KD0L71`02XZ:P0P820Dooooo`00
4oooool0R`2DU9@0KFe]071`L015ADD0Kfm_07emO@0o?cl0FEUI04Q8B01;Bd/0ADE505ADE01^KVh0
EeMG055AD@2>SXh0F5QH05]KF`1UIFD0AdM7059BDP1>CTh0=cLg03hn?P1TI6@0@T9203lo?`1LG5`0
@41004];B`1JFUX0ADE504m?C`1JFUX0ATI606MWI`1>CTh0AdM706m_K`18B4P0H61P06UYJ@0`<300
JFUY06ATI00h>3P0H61P05EEE@1ADE40BTY:04i>CP1JFUX0EUIF05=CD`20P800DE5A05MGE`1hN7P0
=SHf04a<C01?Cdl0C4a<05=CD`1OGel0EEEE055AD@1[Jf/0@D51055AD@1XJ6P0;Rh^06=SH`20P800
?Shn061PH01lO7`0?Shn06IVIP1aLG40ADE508F5Q@1SHf<0CDe=08R8R01CDe<0GEeM04U9B@1IFET0
H61P03/k>`1HF5P0HV9R05aLG01ADE40De=C061PH01bLW80GUiN06MWI`1/K6`0D51@05]KF`2:RXX0
ATI6071`L01/K6`0D51@06UYJ@0^;Rh0IVIV06e]K@1;Bd/0FUYJ09ZJVP0m?Cd0Ph>308V9R@18B4P0
NWYj07emO@0m?Cd0Hf=S07inOP0k>c/0K6a/06=SH`1FEUH0Ph>306=SH`1@D500IVIV05eMG@1?Cdl0
PH6104U9B@1=CDd0MWIf05=CD`1ADE403_ooool0D`1TI6@0IfMW06IVIP1QHF40FUYJ05aLG01jNWX0
QhN706QXJ01ADE40A4A404Q8B01LG5`0DU9B04];B`1QHF40GEeM06i^KP1OGel0FEUI05aLG017AdL0
ADE504A4A01=CDd0=SHf0451@@1CDe<0BDU904m?C`1CDe<0GEeM07]kN`1KFe/0GEeM065QH@1EEED0
@T9206UYJ@1IFET0BDU90410@017AdL0?Cdm0492@P1LG5`0>SXj03dm?@0o?cl0BDU904Y:BP1<C4`0
Jf][05mOG`1CDe<0BTY:04M7A`1DE5@0AdM705aLG01TI6@0PX:209JFUP1aLG40IfMW04e=C@1nOWh0
IFEU04=3@`1ADE40Bd];06=SH`1oOgl0F5QH06][J`1BDU80JFUY06QXJ02:RXX0Cdm?04I6AP17AdL0
DU9B0080Bd];01d0JFUY05MGE`1KFe/0F5QH0861P@1oOgl0@d=305=CD`1FEUH0Kfm_06QXJ01:BTX0
B4Q8061PH010@400MgMg04Q8B00Z:RX0>3Ph04m?C`12@T80?Cdm04U9B@13@d<0C4a<04Q8B01HF5P0
;Rh^04m?C`020492@P0H04U9B@1:BTX0DE5A07AdM015ADD0HV9R04M7A`1FEUH0HF5Q055AD@1WIfL0
Kfm_04I6AP1^KVh0G5aL04m?C`1@D500E5AD04];B`16ATH0NGUi04U9B@1KFe/0J6QX3_ooool0101m
OGd0Fe]K07]kN`2=SHd205aLG0260492@P0c<c<0>c/k02`/;015ADD0<C4a02l_;`1<C4`0<30`03<c
<`0o?cl0<c<c04Y:BP0h>3P0?Cdm05UIF@1>CTh0HV9R04a<C01JFUX0I6AT03lo?`1?Cdl0F5QH059B
DP13@d<0C4a<03hn?P0m?Cd0C4a<059BDP0f=SH0@T9206QXJ01>CTh0?Shn08b<S01^KVh0=3@d0:2P
X01JFUX0G5aL09JFUP21PH40D51@06YZJP1XJ6P0FEUI04];B`1TI6@0P82006EUI@1CDe<0EEEE05eM
G@1<C4`0EEEE05mOG`1PH600HV9R03lo?`23Ph<0E5AD04e=C@1hN7P0IVIV05=CD`1OGel0=SHf065Q
H@1JFUX0NGUi04e=C@19BDT0Lg=c09JFUP1ZJVX0QhN707EeM@25QHD0YJFU075aL@28R8P0?Cdm0410
@01JFUX0EeMG061PH00o?cl0>SXj06][J`1]KFd0Cdm?04a<C01=CDd0AdM708N7Q`1^KVh0LW9b04E5
A@1IFET0EeMG05eMG@1QHF40Bd];03Ti>@1SHf<0>c/k059BDP28R8P0B4Q806EUI@28R8P0HF5Q05=C
D`1RHV80>CTi04e=C@0k>c/0NWYj08:2PP1GEeL0JVYZ06a/K01JFUX0Lg=c0:BTY01YJFT0Ph>309BD
U015ADD0GUiN03/k>`2<S8`>ooooo`0M08B4Q01@D500=3@d02XZ:P0c<c<0Fe]K05=CD`0L71`0@d=3
04i>CP0h>3P0?Shn07moO`27QhL0S8b<0::RXP1ADE40;2`/03Ti>@15ADD0DU9B08Z:RP18B4P0?clo
05YJFP0i>CT0Bd];02TY:@0D51@00P0C4a<0K@1<C4`0NGUi08R8R02IVIT0CDe=04M7A`1IFET0SHf=
0::RXP0G5aL0;Bd]079bLP2>SXh0LW9b09VIV@1/K6`0>CTi04U9B@15ADD0FEUI0;Vi^@2GUiL0@T92
055AD@11@D40CDe=06YZJP2HV9P0UiNG05YJFP0D51@04Q8B010@400I6AT0L71`0;6a/@2k^k/0LG5a
06IVIP2`/;00>3Ph028R8P0G5aL05ADE028R8P1/K6`0DE5A07emO@1kNg/0BTY:01/K6`0H61P0?3`l
05MGE`2CTi<0BDU902PX:012@T80>SXj08N7Q`0n?Sh0K6a/0:f][@3Ogml0g=cL0=oOg`2SXj<0MGEe
03Ti>@0N7Qh0@41006QXJ00Y:BT0=CDe030`<00j>SX0V9RH05eMG@1LG5`0WYjN09>CT`16ATH0BDU9
04a<C02ATI40Q8B403hn?P0g=cL0HV9R05IFEP1XJ6P0X:2P071`L02@T900O7al06=SH`1=CDd07AdM
02TY:@1:BTX0GemO08b<S01=CDd0Ti>C0;^k^`1TI6@0De=C05aLG01EEED05?ooool001?ooooo03T0
NGUi08:2PP1?Cdl0EeMG05]KF`17AdL0IFEU0492@P15ADD0Lg=c02h^;P1;Bd/0IVIV03<c<`1CDe<0
JVYZ03dm?@1QHF40EeMG034a<@1JFUX0?clo04e=C@19BDT0C4a<08J6QP14A4@0BTY:06e]K@0j>SX0
B4Q806EUI@0Z:RX0E5AD071`L012@T80EeMG08B4Q01:BTX0HV9R06=SH`14A4@0FUYJ065QH@1?Cdl0
EeMG03`l?01ZJVX0FEUI02PX:01NGUh0G5aL03Ti>@1PH600HF5Q05QHF01MGEd00P1DE5@01@1ZJVX0
@d=304e=C@1cLg<0=SHf0080Hf=S04T0@d=306YZJP13@d<0Cdm?04i>CP1DE5@0I6AT06e]K@1@D500
JFUY071`L01:BTX0I6AT071`L01BDU80GemO08>3P`1<C4`0L71`07emO@19BDT0Ng]k06=SH`11@D40
MGEe061PH01TI6@0GEeM051@D01jNWX0IfMW04i>CP2CTi<0JVYZ06IVIP1PH600GUiN06ATI01?Cdl0
Kfm_07QhN01BDU80GemO065QH@1KFe/0N7Qh06=SH`1LG5`0L71`061PH01WIfL0M7Ad0492@P2:RXX0
OGem05EEE@2>SXh0Cdm?05YJFP1iNGT0DU9B05IFEP1iNGT0?clo05]KF`27QhL0>c/k06EUI@1OGel0
>c/k05]KF`1[Jf/0AdM700kooooo0100HF5Q04e=C@1MGEd0C4a<05aLG01BDU80GemO079bLP1YJFT0
ADE504Y:BP19BDT0FUYJ04];B`1JFUX0CDe=0P1MGEd01`1JFUX0BTY:04U9B@14A4@0?Cdm0492@P11
@D400P0o?cl0=P1OGel0C4a<04e=C@1EEED0HV9R0861P@1RHV80JFUY06MWI`1<C4`0AdM705aLG01O
Gel0DE5A04Q8B01CDe<0@41005EEE@1[Jf/0BTY:04M7A`1@D500BDU904i>CP1HF5P0Ogmo05mOG`1D
E5@0GEeM04I6AP1EEED0DE5A04I6AP1JFUX0IVIV08>3P`1JFUX0I6AT06IVIP2>SXh0IVIV051@D01>
CTh0AdM705EEE@24Q8@0I6AT05UIF@1lO7`0OWin07moO`1nOWh0JVYZ051@D080E5AD00/0D51@059B
DP1hN7P0GUiN05MGE`1CDe<0IfMW08V9R@1TI6@0D51@04Y:BP0207=cL`0L04E5A@18B4P0HV9R04m?
C`1lO7`0GemO03@d=010@400CTi>04Y:BP16ATH0Bd];04e=C@1FEUH0CTi>05mOG`12@T80J6QX0451
@@0m?Cd0BDU904e=C@1<C4`0IFEU04Q8B01SHf<0>c/k069RHP80Bd];00h0G5aL05]KF`1=CDd0KFe]
05=CD`0n?Sh0@d=304M7A`0l?3`0CTi>06i^KP17AdL0EUIF07=cL`kooooo0180NGUi04Y:BP1JFUX0
M7Ad05YJFP1@D500:b/[03`l?00f=SH0@D5104];B`0l?3`0@D5104e=C@0R8R80>CTi03/k>`0i>CT2
03Xj>P0b030`<00c<c<0BTY:04m?C`1@D500ADE505EEE@17AdL0Bd];04Q8B016ATH0Bd];04=3@`0n
?Sh0B4Q804m?C`1;Bd/0<S8b03hn?P1MGEd0C4a<04M7A`1`L700KFe]04m?C`2GUiL0DU9B05mOG`2Z
ZZX0NWYj05IFEP1=CDd0IVIV059BDP17AdL0LW9b07MgM`1YJFT0Cdm?051@D01eMGD0C4a<06YZJP1P
H600IVIV06e]K@0m?Cd0MgMg05IFEP1;Bd/207QhN00e059BDP1/K6`0?Shn05aLG01_Kfl0Jf][05eM
G@1@D500HF5Q08f=S@1JFUX0TI6A05YJFP1bLW80ZJVY07alO02GUiL0Cdm?0410@01KFe/0G5aL069R
HP1>CTh0E5AD06MWI`1dM7@0DU9B055AD@1SHf<0FUYJ06][J`1dM7@0NWYj04Q8B01EEED0L71`04A4
A01gMgL0GEeM03dm?@1PH600AdM705aLG01oOgl0De=C06UYJ@1fMWH0NGUi06ATI01SHf<0>CTi05AD
E00l?3`00P24Q8@03@0m?Cd0M7Ad08:2PP1NGUh0IfMW09NGU`1>CTh0MGEe09>CT`0k>c/0BTY:04i>
CP2?Shl03_ooool0B@2FUYH0JVYZ03Hf=P0_;bl08b<S04Y:BP25QHD0OGem03Xj>P0a<C409BDU02/[
:`0X:2P05QHF05]KF`2JVYX0UiNG05YJFP0[:b/0;2`/051@D02>SXh0MGEe0:>SX`2BTY80R8R805AD
E00Z:RX05aLG01TI6@1BDU80<S8b02XZ:P2MWId0XJ6Q07YjNP1^KVh0OGem0;no_`2YZJT0FUYJ01`L
701?Cdl0clo?0:>SX`1iNGT0EeMG06IVIP0H61P05ADE03@d=01UIFD0IfMW0492@P0`<300<C4a02h^
;P1EEED0Ogmo05UIF@1/K6`0=cLg01@D500K6a/0>3Ph05QHF01lO7`0b<S80;6a/@2d];@0E5AD03`l
?00f=SH00P0/;2`0@@1?Cdl0Ph>308F5Q@2:RXX0GemO01TI6@0C4a<05ADE02PX:01CDe<0O7al07If
MP1NGUh092@T01HF5P0Y:BT0F5QH06UYJ@2WYjL0[jn_08>3P`1]KFd0TY:B0;:b/P1mOGd0;bl_05UI
F@11@D40:BTY05=CD`0N7Qh0<C4a05UIF@0[:b/09bLW05YJFP0l?3`0@d=302DU9@0X:2P0L71`0861
P@1mOGd0L71`0:FUY@29RHT0ATI603Ti>@2ATI40d];B04I6AP1XJ6P0Bd];0410@017AdL0FEUI06m_
K`2<S8`0Ogmo0:j^[P2l_;`0<c<c02TY:@1UIFD0QHF501Cooooo000Cooooo`0L09BDU01XJ6P0L71`
05EEE@1ZJVX0IFEU04U9B@1nOWh0CTi>04a<C01GEeL0?3`l05]KF`1PH600A4A4061PH01]KFd0DU9B
055AD@1@D500ADE505]KF`1JFUX0?clo06QXJ01BDU80B4Q807AdM080BDU906d0GEeM04Q8B014A4@0
BDU903lo?`1dM7@0?Cdm04E5A@1iNGT0A4A405IFEP1VIVH0<C4a05UIF@16ATH0>3Ph051@D01<C4`0
ADE504m?C`1SHf<0=CDe05EEE@1<C4`0ADE505UIF@1=CDd0DE5A0410@01TI6@0HV9R05mOG`1MGEd0
M7Ad04];B`1OGel0NGUi04m?C`17AdL0JFUY04A4A01SHf<0OWin04e=C@1NGUh0Ogmo04=3@`1IFET0
M7Ad03hn?P1ADE40IFEU05]KF`1VIVH0FEUI069RHP1MGEd0G5aL06m_K`1PH600@41005IFEP1gMgL0
@D51061PH01QHF40Bd];061PH01MGEd0L71`05EEE@1TI6@0PH6104m?C`1QHF40Hf=S06IVIP1[Jf/0
<c<c05QHF01_Kfl0@d=3065QH@2ATI40?Shn05mOG`2MWId0CTi>05aLG01[Jf/0ADE506QXJ01nOWh0
=CDe05UIF@1JFUX0@d=306ATI01LG5`0AdM706QXJ01iNGT0BDU906UYJ@1?Cdl0Fe]K07YjNP1?Cdl0
D51@00kooooo00<0KVi^05=CD`1QHF400P1MGEd0Q`1DE5@0IVIV07YjNP1aLG40ATI604e=C@17AdL0
EeMG04a<C01MGEd0E5AD06EUI@1RHV80E5AD059BDP1FEUH0Cdm?059BDP1=CDd0Cdm?03Ph>00k>c/0
CDe=03Ti>@16ATH0EUIF061PH028R8P0CDe=06ATI01ZJVX0Fe]K04U9B@1GEeL0EEEE05MGE`18B4P0
DE5A03lo?`16ATH0EEEE04=3@`1FEUH0C4a<04I6AP1IFET0EUIF07inOP1RHV80GemO05YJFP1[Jf/0
Cdm?04e=C@1>CTh0GUiN06i^KP2HV9P0Jf][06IVIP1BDU80L71`05QHF00m?Cd0BDU905ADE01IFET0
NWYj04M7A`1@D500DE5A05QHF01VIVH0Ogmo05UIF@18B4P0CTi>05UIF@18B4P0@41006][J`1ADE40
BTY:051@D01BDU80RHV905MGE`1OGel0CTi>06UYJ@1nOWh0ADE504M7A`1OGel0E5AD08:2PP12@T80
;bl_04Y:BP1>CTh0ATI603/k>`18B4P0ATI604m?C`1ADE40FEUI0410@01=CDd0<c<c03Hf=P10@400
?Cdm04e=C@1BDU80@d=305UIF@0_;bl0EUIF0410@01?Cdl0G5aL05eMG@1DE5@0EUIF04];B`15ADD0
AdM704];B`12@T80?Shn06m_K`1=CDd0H61P06=SH`0>ooooo`0A07emO@1CDe<0EUIF06][J`1PH600
De=C051@D00h>3P0=SHf02h^;P0o?cl0@41003<c<`13@d<0;Rh^02PX:01;Bd/00P0b<S80N@13@d<0
<30`04i>CP14A4@0CDe=059BDP0l?3`0I6AT04Q8B01PH600@T9206MWI`13@d<0@41004=3@`18B4P0
F5QH0410@00Y:BT0A4A406QXJ013@d<0HV9R08^;R`1dM7@0De=C07inOP19BDT0EUIF09>CT`2ATI40
E5AD06ATI01bLW80Fe]K04];B`1XJ6P0Kfm_05iNGP1LG5`0EeMG07=cL`1@D500H61P06i^KP1XJ6P0
K6a/04U9B@20P800F5QH04a<C01eMGD0MgMg05=CD`1OGel0A4A405MGE`1YJFT0NGUi05UIF@13@d<0
F5QH09VIV@1QHF40MGEe06a/K022PX80];Bd06e]K@2[Zj/0FEUI03hn?P1IFET0GUiN071`L01=CDd0
ATI606UYJ@1hN7P0EeMG05mOG`1`L700Bd];07alO01VIVH0LG5a03`l?01VIVH0E5AD04];B`1iNGT0
FEUI02/[:`1ZJVX0Bd];04I6AP1hN7P0DU9B05EEE@26QXH0Ogmo05MGE`1EEED0@T9205IFEP0n?Sh0
LW9b08F5Q@1=CDd0KVi^06ATI01eMGD0JFUY09RHV019BDT0GEeM08N7Q`0h>3P0B4Q80410@024Q8@0
3_ooool0S02ZZZX0U9BD059BDP1:BTX0@41004m?C`2CTi<0I6AT03dm?@0h>3P0;Bd]04=3@`0G5aL0
5ADE02@T901?Cdl0/;2`0<c<c02KVi/0WYjN0=KFeP3Bd]80Vi^K0861P@2>SXh0>3Ph03dm?@1`L700
Fe]K075aL@0O7al05ADE02TY:@1gMgL0O7al065QH@0c<c<0;Bd]06a/K01hN7P0EeMG05IFEP1cLg<0
e=CD0:BTY01NGUh0LW9b06i^KP13@d<0?Cdm06i^KP2<S8`0Jf][01PH600E5AD06a/K05eMG@0l?3`0
71`L02PX:01@D500QXJ6061PH00k>c/0Bd];065QH@1MGEd0WYjN09bLW02GUiL09bLW01/K6`0_;bl0
A4A403Ph>01mOGd0`<3009>CT`2PX:00>SXj01@D500E5AD04Q8B01TI6@1[Jf/0Vi^K07EeM@1bLW80
DU9B04];B`1ZJVX0Y:BT06][J`1NGUh0U9BD04Q8B026QXH0Y:BT07QhN01@D500WinO0:j^[P0`<300
B4Q805YJFP0l?3`0>3Ph05mOG`1<C4`0Fe]K07emO@0^;Rh0:2PX028R8P0V9RH0?Cdm06][J`2OWil0
/k>c0<W9b@1nOWh0EUIF065QH@1dM7@0c/k>09VIV@2ATI40T92@0:>SX`2LW9`0MGEe0410@00_;bl0
U9BD09bLW02FUYH0I6AT05mOG`2FUYH0Z:RX5?ooool001?ooooo05@0N7Qh06][J`1RHV80GUiN061P
H01^KVh0De=C05iNGP1EEED0Hf=S03hn?P1CDe<0Jf][04M7A`1@D500FEUI03Xj>P1LG5`0Fe]K03Xj
>P1EEED0FUYJ04M7A`1@D500G5aL05ADE012@T80G5aL04];B`14A4@0FUYJ05=CD`1JFUX0De=C061P
H01^KVh0C4a<06MWI`1UIFD0@T9207QhN01BDU80AdM7065QH@1<C4`0Hf=S06UYJ@1>CTh0Kfm_03hn
?P1OGel0Cdm?03`l?01MGEd0HV9R03<c<`1QHF40FUYJ03Ti>@1HF5P0FUYJ04M7A`1TI6@0FEUI04e=
C@1BDU80Kfm_05YJFP1DE5@0J6QX059BDP1SHf<0LG5a05EEE@1OGel0Lg=c05aLG01OGel0HF5Q05mO
G`1TI6@0Hf=S06MWI`1FEUH206QXJ00@04=3@`1^KVh0I6AT04=3@`1:BTX0IfMW05iNGP1?Cdl0DU9B
06EUI@1/K6`0FUYJ06e]K@1NGUh0EUIF06MWI`80Hf=S0240GemO04e=C@1eMGD0H61P04e=C@1iNGT0
HV9R05mOG`22PX80JVYZ05YJFP1/K6`0HV9R06MWI`1<C4`0IFEU05mOG`1:BTX0K6a/05MGE`1<C4`0
MgMg059BDP1=CDd0MgMg04];B`1EEED0Lg=c04U9B@1UIFD0EEEE04Y:BP1IFET00P1EEED>ooooo`0/
06MWI`1HF5P0De=C04a<C01:BTX0G5aL06i^KP2=SHd0KVi^04a<C011@D40Bd];05QHF01LG5`0Fe]K
05eMG@1]KFd0IVIV05aLG01BDU80De=C04U9B@10@400Bd];04I6AP0h>3P0?clo055AD@11@D40C4a<
05=CD`1MGEd0T92@059BDP1OGel0Hf=S055AD@1DE5@0AdM70492@P1:BTX0BDU904a<C00i>CT20451
@@80@T9200X0B4Q804I6AP1@D500F5QH075aL@1OGel0EeMG06UYJ@1<C4`0CTi>0P1?Cdl06P1OGel0
Ng]k0:n_[`1UIFD0GemO05QHF01kNg/0G5aL059BDP1KFe/0GemO07=cL`2EUID0J6QX06MWI`1YJFT0
PX:2075aL@1hN7P0GUiN04e=C@15ADD0BTY:05]KF`1;Bd/0FEUI0P1<C4`0=01>CTh0Fe]K07inOP1F
EUH0Fe]K06=SH`1_Kfl0Rh^;04];B`0k>c/0E5AD04e=C@1UIFD0CDe=02h^;P15ADD0De=C04E5A@0m
?Cd0>SXj03hn?P1LG5`0DE5A05mOG`12@T80EeMG03De=@0h>3P0?Shn04];B`1?Cdl0FEUI0410@01M
GEd0@d=305EEE@1;Bd/0DU9B05]KF`1JFUX0HV9R05EEE@1RHV80Bd];03dm?@19BDT0Bd];04e=C@1e
MGD0DU9B05UIF@1`L70>ooooo`0:07MgM`1ADE40E5AD06IVIP1BDU80AdM705IFEP0m?Cd0@41003Xj
>P80B4Q803@0@T92055AD@0];Bd0;Bd]04M7A`0e=CD0=SHf04E5A@0[:b/0@d=305ADE01?Cdl0B4Q8
03hn?P1QHF40@41004a<C01:BTX0FUYJ04i>CP0o?cl0C4a<059BDP1HF5P0@41002`/;016ATH0Hf=S
03lo?`1?Cdl0NGUi06][J`1WIfL0M7Ad04U9B@1DE5@0P82008Z:RP1CDe<0@d=305eMG@1CDe<0A4A4
06e]K@1WIfL0GEeM06YZJP19BDT0Q8B404];B`1]KFd0GemO0P1bLW80BP0l?3`0L71`05ADE014A4@0
O7al07QhN01>CTh0GEeM04A4A01=CDd0I6AT06m_K`1[Jf/0GUiN05QHF01oOgl0D51@06][J`1MGEd0
I6AT0:j^[P1RHV80MWIf05ADE00e=CD0EeMG05IFEP1^KVh0BDU9061PH01]KFd0Lg=c04m?C`1@D500
MgMg04M7A`1jNWX0Jf][075aL@14A4@0FUYJ069RHP0l?3`0JFUY05eMG@0i>CT0G5aL05IFEP1IFET0
M7Ad05MGE`1LG5`0K6a/07alO01[Jf/0FEUI03Ph>01OGel0B4Q8071`L02:RXX0Cdm?07YjNP1TI6@0
MgMg07=cL`28R8P0A4A406=SH`2DU9@0=3@d051@D017AdL0W9bL3_ooool09`1oOgl0IFEU06EUI@1O
Gel0PX:209nOW`1mOGd0S8b<065QH@1?Cdl0FEUI069RHP0g=cL0>c/k02l_;`19BDT0NWYj09jNWP1N
GUh08R8R03Lg=`2IVIT0E5AD05aLG02QXJ40C4a<04I6AP0l?3`0@41003hn?P1@D500I6AT09NGU`16
ATH0>CTi020P800/;2`0:RXZ02@T900205mOG`1S04e=C@1aLG40UIFE0451@@2ATI40Lg=c07IfMP0o
?cl0=3@d03`l?01mOGd0MGEe06=SH`0l?3`0@D5105EEE@0Z:RX05ADE01hN7P0Y:BT0HF5Q08j>SP2Y
ZJT0]kNg06QXJ01kNg/071`L05UIF@19BDT0ATI604M7A`0e=CD07alO04U9B@2OWil0S8b<0;Ng]`0k
>c/0AdM703Xj>P0b<S80<C4a0451@@1jNWX0=cLg03Ph>01OGel0ADE5038b<P1<C4`0Q8B40:NWY`2E
UID0LW9b07=cL`1mOGd0RHV907EeM@1gMgL0F5QH08Z:RP1fMWH06a/K02<S8`1;Bd/0QXJ609nOW`1^
KVh0E5AD08R8R024Q8@0B4Q802@T900];Bd08R8R03Ti>@1[Jf/0SHf=0;Ng]`0o?cl071`L02`/;01j
NWX0Xj>S07alO01hN7P0WYjN0;jn_P22PX80E5AD06UYJ@1ZJVX0Ph>30:f][@22PX80=SHf04a<C01H
F5P0=CDe01Cooooo000Cooooo`0g06QXJ020P800C4a<07UiN@1KFe/0GEeM06ATI00i>CT0I6AT06QX
J00a<C40Bd];05mOG`15ADD0DE5A05QHF01VIVH0HF5Q04i>CP1@D500Cdm?05=CD`1FEUH0?Shn05aL
G01fMWH0?3`l04m?C`1^KVh0?Shn04Y:BP1aLG40>3Ph04A4A01_Kfl0>SXj05]KF`1cLg<0?Cdm069R
HP1NGUh0@T9204e=C@16ATH0?Shn05aLG00];Bd0AdM704i>CP0X:2P0J6QX04M7A`0l?3`0K6a/04E5
A@0205aLG01B055AD@1BDU80Hf=S03lo?`1IFET0G5aL04e=C@1IFET0Hf=S05QHF01[Jf/0ATI604];
B`1DE5@0DE5A06IVIP1_Kfl0DU9B06a/K01VIVH0BDU9071`L01]KFd0Bd];05mOG`1]KFd0?3`l069R
HP1JFUX0BDU906][J`1bLW80De=C05UIF@1ADE40Jf][03`l?01HF5P0Ng]k0451@@1JFUX0Kfm_05eM
G@1ZJVX0Fe]K06EUI@20P800C4a<05]KF`1mOGd0ATI606EUI@1KFe/0FEUI05YJFP1BDU80I6AT05UI
F@1;Bd/0R8R8061PH01IFET0S8b<05YJFP1=CDd0KFe]04U9B@1DE5@0RHV904A4A01JFUX0MWIf03Ti
>@1FEUH0P82003<c<`1DE5@0H61P038b<P1JFUX0HV9R03Ph>0kooooo03/0M7Ad05eMG@1QHF40EUIF
05=CD`1TI6@0NWYj0::RXP1gMgL0De=C04A4A01=CDd0FEUI04m?C`1DE5@0IFEU07MgM`1bLW80EEEE
055AD@1PH600CDe=04Y:BP1;Bd/0B4Q804M7A`0k>c/0K6a/04e=C@1FEUH0CTi>05eMG@2<S8`0H61P
065QH@1XJ6P0E5AD04];B`1@D500?Cdm04e=C@16ATH0CDe=0492@P15ADD0CDe=0451@@17AdL0BTY:
05=CD`1KFe/0FUYJ07]kN`1YJFT0HF5Q061PH01DE5@0EEEE04e=C@0204a<C00g06QXJ025QHD0GEeM
06YZJP10@400IVIV05IFEP10@400ATI60410@01UIFD0OWin05aLG01EEED0LG5a06a/K01GEeL0PH61
05EEE@1:BTX0BDU905MGE`19BDT0>CTi05YJFP1IFET0EEEE06QXJ01VIVH0Lg=c04U9B@1BDU80FUYJ
07EeM@2;Rh/0EUIF04A4A01LG5`0D51@05UIF@1>CTh0<S8b04M7A`1DE5@0BDU904M7A`19BDT0B4Q8
061PH01ADE40GEeM0451@@1LG5`0?Shn04M7A`0204Q8B00F04e=C@1<C4`0@41005IFEP0j>SX0AdM7
055AD@17AdL0JFUY05QHF01@D500CDe=05]KF`17AdL0@T9204];B`1LG5`0F5QH06m_K`1<C4`0Fe]K
06UYJ@kooooo08`0PX:204m?C`1QHF40IFEU05UIF@1KFe/0Bd];04I6AP13@d<0@4100492@P0k>c/0
D51@04Y:BP0Z:RX0;Rh^059BDP0b<S80CTi>03hn?P0a<C40D51@065QH@10@400?clo05]KF`1DE5@0
A4A406EUI@13@d<0FUYJ05ADE00a<C40D51@06IVIP17AdL0?Cdm038b<P14A4@0GUiN0492@P1DE5@0
NWYj07UiN@1OGel0EEEE055AD@1>CTh0KFe]08f=S@10@400CDe=05UIF@19BDT0CDe=06=SH`1VIVH0
GUiN05MGE`1>CTh0MGEe04i>CP1CDe<0HF5Q06MWI`1UIFD0=cLg07alO01FEUH0ADE507]kN`1hN7P0
De=C061PH00l?3`0ATI606ATI01lO7`0I6AT09:BTP1;Bd/0RHV906IVIP1KFe/0GUiN06i^KP2[Zj/0
K6a/07YjNP1EEED0;bl_04m?C`1:BTX0L71`0451@@1TI6@0KVi^06MWI`1=CDd0F5QH06UYJ@0k>c/0
J6QX07AdM01kNg/0?Cdm06][J`1HF5P0Bd];07QhN01JFUX0=SHf061PH01KFe/0De=C07AdM01UIFD0
EUIF05mOG`29RHT0Kfm_05YJFP0o?cl0EeMG03hn?P1^KVh0P82005aLG01cLg<0HF5Q05UIF@1SHf<0
OWin04e=C@1ADE40SHf=04E5A@1BDU80?Cdm0:>SX`kooooo02@0A4A40451@@10@400QHF508b<S01W
IfL0@D5102DU9@1PH600ADE507alO01BDU80820P01dM7@0C4a<0DE5A05]KF`1LG5`09RHV02<S8`0>
3Ph092@T0451@@0J6QX0Fe]K020P800G5aL09BDU028R8P0E5AD06ATI01dM7@1eMGD0?Cdm01<C4`0B
4Q8201@D500;02TY:@0o?cl0Bd];02h^;P1>CTh0HV9R04m?C`1^KVh0:2PX034a<@0G5aL00P0E5AD0
F@0N7Qh0De=C08b<S01PH600PH6103Ph>00i>CT0;2`/01TI6@0P8200<C4a02PX:010@400NWYj03lo
?`12@T80DU9B04Q8B00l?3`06QXJ01`L7016ATH0Rh^;09BDU00c<c<0MGEe0;Bd]00];Bd08R8R02/[
:`0K6a/07AdM05IFEP2n_[h0?Cdm02PX:01;Bd/09bLW04=3@`1dM7@0S8b<05eMG@22PX80;2`/030`
<01SHf<0MgMg07inOP2UYJD0S8b<06UYJ@1XJ6P05QHF030`<01kNg/0/;2`0<_;b`20P800BDU9020P
801oOgl0EUIF03Xj>P0J6QX071`L04m?C`0T92@0CTi>04m?C`2JVYX0@41006=SH`2FUYH0PX:20492
@P0J6QX0@D5108N7Q`1JFUX092@T01dM7@0/;2`0Shn?05ADE016ATH0<S8b01lO7`0^;Rh0EEEE01Co
oooo000Cooooo`1007]kN`1PH600Kfm_04i>CP1OGel0HF5Q04=3@`1ADE40GEeM0492@P1MGEd0A4A4
05QHF01JFUX0@D5106YZJP1BDU80BDU906EUI@1<C4`0=SHf06][J`1SHf<0<c<c06i^KP1=CDd0@D51
03`l?01CDe<0IfMW04A4A00o?cl0P820038b<P17AdL0O7al02l_;`1RHV80Jf][03De=@1GEeL0IfMW
03De=@1UIFD0D51@03hn?P1EEED0De=C059BDP1<C4`0G5aL05IFEP1@D500AdM705eMG@0i>CT0CDe=
07YjNP0j>SX0?3`l06YZJP1FEUH0CDe=08:2PP80DU9B04T0V9RH05=CD`1?Cdl0MWIf03Ph>01/K6`0
MGEe0451@@1]KFd0JFUY04e=C@1OGel0Hf=S03dm?@1MGEd0HV9R04i>CP1HF5P0EUIF08B4Q01=CDd0
Cdm?07YjNP1KFe/0<C4a06MWI`1QHF40B4Q806e]K@1MGEd0HF5Q05MGE`1<C4`0OGem055AD@1JFUX0
Lg=c04a<C01YJFT0>CTi069RHP1ZJVX0BDU906ATI01[Jf/0ADE505iNGP22PX80ATI605eMG@23Ph<0
CTi>05]KF`1nOWh0F5QH061PH01cLg<0CTi>06MWI`1]KFd0CTi>06QXJ01YJFT0BTY:05YJFP1EEED0
ATI6071`L01DE5@0Bd];07EeM@17AdL0C4a<00kooooo0540MWIf05UIF@1ZJVX0D51@065QH@1CDe<0
N7Qh06EUI@1RHV80BDU904i>CP0h>3P0DU9B03hn?P1fMWH0DU9B06EUI@1ZJVX0J6QX04U9B@1FEUH0
H61P05=CD`1RHV80DE5A04=3@`1MGEd0L71`059BDP1:BTX0DU9B06YZJP2;Rh/0HF5Q079bLP1UIFD0
DU9B06EUI@1LG5`0BTY:04];B`1>CTh0DU9B04E5A@1>CTh0EEEE04m?C`1:BTX0CDe=05ADE01HF5P0
Hf=S07moO`1RHV80JFUY07UiN@1YJFT0EEEE06=SH`15ADD0F5QH069RHP2`/;00ATI607QhN01^KVh0
Ng]k05ADE00];Bd0=SHf04I6AP1?Cdl0SXj>05UIF@1JFUX0?Shn04Y:BP1SHf<0LW9b05eMG@1BDU80
0P1ADE40>@1=CDd0>SXj04I6AP0n?Sh0EeMG05]KF`1SHf<0M7Ad05aLG01FEUH0Fe]K05UIF@1bLW80
DE5A03lo?`14A4@0DU9B04Y:BP17AdL0;Rh^03hn?P1>CTh0ADE504I6AP17AdL0@d=306e]K@1CDe<0
DE5A038b<P1=CDd0@41004E5A@0l?3`0BDU904Y:BP1QHF40<c<c04Q8B017AdL0FUYJ05ADE01:BTX0
@d=306IVIP1LG5`0EUIF05QHF017AdL0>SXj0451@@1CDe<0B4Q808>3P`1NGUh0FUYJ06YZJP0>oooo
o`0408>3P`1CDe<0G5aL05mOG`80A4A401H0CTi>04=3@`10@400AdM704U9B@10@400@d=304m?C`0[
:b/0:BTY04E5A@0m?Cd0C4a<04Q8B00a<C40@D5104e=C@0l?3`0>3Ph04e=C@1MGEd0<C4a0P18B4P0
>@1HF5P0?3`l02/[:`1=CDd0HF5Q03/k>`0n?Sh0;Bd]04I6AP1;Bd/0?Shn04a<C01_Kfl0KFe]06][
J`1OGel0De=C04I6AP1jNWX0QhN704M7A`16ATH0Hf=S0451@@1<C4`0LG5a06YZJP1`L700G5aL04m?
C`1]KFd0HV9R055AD@1TI6@0KFe]07IfMP11@D40MgMg04];B`16ATH0N7Qh07UiN@1IFET0EEEE03dm
?@1;Bd/0Jf][07]kN`1OGel0SHf=06IVIP1cLg<0H61P07AdM01eMGD0JVYZ0:NWY`0208B4Q00D06e]
K@0m?Cd0I6AT04m?C`1eMGD0DU9B05IFEP1[Jf/0JFUY05IFEP1BDU80QXJ604Q8B01[Jf/0MgMg08J6
QP14A4@0H61P079bLP19BDT206ATI00M04M7A`1NGUh0DE5A061PH01]KFd0Cdm?05EEE@1DE5@0Lg=c
05EEE@1LG5`0<c<c05EEE@11@D40IFEU05mOG`1:BTX0N7Qh04i>CP1DE5@0Hf=S071`L014A4@0GUiN
09BDU00f=SH0BTY:03dm?@2LW9`03_ooool08P0f=SH0:RXZ01XJ6P0l?3`0ATI605eMG@1UIFD08b<S
07MgM`2b/[80a/K606EUI@0c<c<07AdM01/K6`0l?3`0820P05YJFP0X:2P04a<C00l?3`0F5QH0K6a/
01XJ6P1lO7`0=cLg014A4@0C4a<051@D01LG5`0S8b<071`L06a/K00o?cl2018B4P0=01@D500E5AD0
4A4A010@400n?Sh07AdM03Lg=`0k>c/0[jn_02l_;`0N7Qh0;Bd]01HF5P0301DE5@0/03lo?`1MGEd0
Bd];06i^KP0^;Rh09BDU04];B`1SHf<0HV9R02<S8`0T92@08b<S069RHP0K6a/09bLW05YJFP0`<300
H61P02d];@0M7Ad07QhN07EeM@1;Bd/09BDU06i^KP1fMWH0A4A406MWI`1kNg/0N7Qh02TY:@1QHF40
h>3P06MWI`1KFe/0K6a/05aLG00^;Rh0J6QX065QH@1GEeL0WinO04U9B@1=CDd201lO7`0802@T901K
Fe/0OGem06UYJ@31`L40IfMW051@D01MGEd209JFUP0J06a/K00d=3@0FUYJ08R8R01RHV80C4a<02HV
9P0W9bL0ATI602@T901<C4`0;2`/07]kN`0L71`0;Bd]06m_K`1EEED0GemO03dm?@1OGel0@d=3055A
D@0N7Qh0?Cdm07UiN@2d];@203Ph>00404e=C@0V9RH0820P04I6AQCooooo000Cooooo`2;07alO01b
LW80GemO05mOG`1IFET0EEEE06=SH`1=CDd0IVIV069RHP13@d<0ADE506a/K00n?Sh0AdM705iNGP0n
?Sh0@d=304a<C01FEUH0?clo04m?C`1IFET0?clo055AD@1TI6@0E5AD0410@01PH600GEeM04E5A@1F
EUH0Hf=S03dm?@1[Jf/0Hf=S05=CD`1GEeL0DU9B04=3@`1?Cdl0CDe=051@D01ADE40Fe]K05MGE`0g
=cL0IFEU05ADE00X:2P0HV9R05aLG00f=SH0HF5Q05=CD`10@400IfMW04i>CP15ADD0GemO05UIF@1:
BTX0FEUI05mOG`1IFET0Cdm?075aL@1YJFT0CTi>069RHP1LG5`0Jf][05UIF@1YJFT0Bd];05]KF`1d
M7@0EUIF06QXJ01TI6@0D51@05mOG`1RHV80A4A405iNGP1jNWX0@41005YJFP1XJ6P0@d=304i>CP1H
F5P0D51@05=CD`1DE5@0H61P05UIF@1@D500GemO06MWI`1TI6@0GUiN06IVIP1eMGD0IfMW04U9B@1n
OWh0HV9R05]KF`1UIFD0GUiN06m_K`1RHV80I6AT06QXJ01DE5@0JVYZ06ATI013@d<0IFEU06ATI00g
=cL0Lg=c04e=C@1?Cdl0MgMg04a<C01ADE40HV9R04I6AP1IFET0JVYZ04I6AP1>CTh0F5QH04A4A01B
DU80JFUY03lo?`0>ooooo`03079bLP1JFUX0IFEU0080FEUI06@0HF5Q07UiN@2;Rh/0Kfm_04a<C013
@d<0C4a<065QH@1;Bd/0Hf=S05EEE@1[Jf/0HF5Q05=CD`19BDT0EUIF05=CD`1@D500EeMG051@D013
@d<0?Shn04i>CP0c<c<0@4100492@P1HF5P0OWin06IVIP1SHf<0GUiN05EEE@1<C4`0EUIF03lo?`11
@D40ATI604Q8B00h>3P0?Shn03Xj>P0o?cl0?Shn03Xj>P1:BTX0ADE5051@D01TI6@0F5QH05YJFP1V
IVH0EEEE06=SH`1TI6@0CDe=059BDP1WIfL0YZJV061PH01]KFd0HV9R08J6QP1NGUh0DU9B05ADE01Q
HF40MgMg09FEU@1VIVH0JVYZ061PH01IFET0F5QH07]kN`1KFe/0CTi>04];B`1?Cdl0DU9B04E5A@1U
IFD0DU9B04m?C`1MGEd0K6a/07UiN@15ADD0Cdm?05iNGP2HV9P0MWIf06=SH`13@d<0GUiN069RHP1C
De<0DU9B04I6AP1KFe/0EEEE0P1:BTX08@11@D40@T9205UIF@1KFe/0GemO059BDP1EEED0?Shn04M7
A`12@T80AdM704];B`1?Cdl0B4Q805ADE00g=cL0Hf=S05eMG@1NGUh0HV9R05]KF`1`L700JVYZ05]K
F`1EEED0DE5A04e=C@1NGUh0Fe]K07MgM`1NGUh0Hf=S07emO@0>ooooo`1V07]kN`1<C4`0GEeM05mO
G`1:BTX0Cdm?04M7A`0o?cl0ADE504A4A01;Bd/0@d=30492@P11@D408b<S02d];@1>CTh0<C4a061P
H017AdL0;bl_059BDP1GEeL0@4100492@P1YJFT0HF5Q03/k>`1_Kfl0Cdm?04Y:BP1>CTh0;Bd]055A
D@1fMWH0ADE504=3@`0f=SH0BDU905iNGP15ADD0De=C08>3P`21PH40Kfm_04m?C`1<C4`0EEEE07Mg
M`27QhL0@T9204m?C`1WIfL0A4A404i>CP1YJFT0KFe]0861P@1GEeL0E5AD071`L01IFET0D51@06YZ
JP1XJ6P0H61P03Ti>@25QHD0BTY:059BDP23Ph<0LW9b05aLG01`L700AdM7055AD@1RHV80QXJ605eM
G@1eMGD0QXJ6079bLP1oOgl0FEUI06m_K`1fMWH0PX:207]kN`1iNGT0D51@04M7A`1FEUH0DU9B07Ad
M017AdL0CTi>079bLP1;Bd/0De=C059BDP1lO7`0Cdm?0P1YJFT06P1hN7P0Bd];05aLG01QHF40F5QH
08R8R01DE5@0>CTi05UIF@1GEeL0G5aL071`L01EEED0EUIF06YZJP22PX80G5aL04m?C`13@d<0Bd];
03Lg=`1KFe/0EEEE05MGE`1SHf<0?Cdm0P1bLW80201eMGD0BDU905UIF@2KVi/0BDU904I6AP0h>3P0
QHF53_ooool08P1?Cdl0:2PX01/K6`0b<S80GUiN0;:b/P2DU9@0Lg=c0;Zj^P38b<P0LW9b04U9B@0e
=CD0ADE5055AD@1HF5P05QHF065QH@0i>CT06a/K02DU9@0N7Qh0X:2P09nOW`2/[:`0VIVI07]kN`1N
GUh0E5AD04i>CP23Ph<0JVYZ09fMW@0f=SH2018B4P0<01@D500B4Q80410@010@4011@D408b<S0451
@@1ZJVX0[Jf]03Lg=`0Z:RX0;Rh^0`0E5AD0C00T92@0Ph>305YJFP0S8b<0BTY:04U9B@12@T80EUIF
08Z:RP2^[Zh0DU9B05iNGP1IFET0P82004i>CP0V9RH08R8R03lo?`1=CDd0HF5Q06a/K01KFe/0NGUi
079bLP1EEED0GemO04U9B@0R8R80>CTi0820P01nOWh0Ogmo07EeM@2KVi/0Z:RX0:FUY@1kNg/0DE5A
059BDP2GUiL0S8b<03De=@2KVi/0DU9B038b<P0J6QX0:b/[04=3@`1_Kfl0[Zj^08B4Q02e]KD0`l?3
0:VYZ@1`L700K6a/05=CD`1XJ6P0CTi>0451@@1MGEd0UIFE08Z:RP27QhL0UYJF08F5Q@1IFET0A4A4
071`L01CDe<09bLW04A4A01VIVH08B4Q0492@P1UIFD204];B`0;0;^k^`2HV9P0S8b<07inOP1^KVh0
ADE503Ph>01fMWH0>c/k04E5A@1/K6`05?ooool001?ooooo00`0Lg=c06UYJ@1CDe<0MWIf04a<C01j
NWX0LG5a030`<01ZJVX0EEEE03dm?@1DE5@204e=C@0A04i>CP1OGel0IfMW05YJFP1CDe<0Jf][03`l
?01;Bd/0JVYZ02h^;P1?Cdl0LW9b03Hf=P15ADD0EeMG0410@01TI6@00`1>CTh09P1KFe/0G5aL06AT
I01?Cdl0KFe]04a<C00i>CT0KFe]04=3@`0h>3P0I6AT05=CD`0d=3@0FUYJ051@D00k>c/0MGEe03hn
?P16ATH0EEEE04e=C@1MGEd0De=C055AD@1FEUH0DE5A04e=C@1PH600BTY:04U9B@1cLg<0?Shn055A
D@1TI6@0;2`/06MWI`1LG5`0D51@0P1[Jf/07`1KFe/0O7al065QH@1MGEd0LW9b05YJFP1<C4`0K6a/
05aLG013@d<0MWIf069RHP1LG5`0JVYZ061PH01GEeL0ADE505EEE@1^KVh0<S8b05mOG`25QHD0<S8b
05IFEP1JFUX0AdM706MWI`0e=CD0GEeM07UiN@1ADE400P1/K6`0801ADE40Fe]K059BDP1mOGd0FUYJ
059BDP24Q8@0G5aL069RHP1nOWh0B4Q805QHF020P800EeMG04];B`1XJ6P0ADE505MGE`1WIfL0<c<c
059BDP1cLg<0;Bd]069RHP1_Kfl0>c/k069RHP1UIFD0:BTY05YJFP1HF5P0;Bd]3_ooool0;01`L700
FEUI06YZJP1QHF40M7Ad061PH020P800T92@071`L01<C4`0B4Q804Y:BP1YJFT0GemO07EeM@1FEUH0
LW9b061PH01LG5`0ATI604m?C`17AdL0Cdm?04e=C@1>CTh0A4A40451@@1GEeL0>SXj05UIF@19BDT0
GemO07IfMP1OGel0IfMW05eMG@17AdL0CDe=04Y:BP14A4@0?clo04=3@`0o?cl0?3`l0P0h>3P03P0b
<S80<c<c038b<P1<C4`0ATI604U9B@1bLW80DE5A05=CD`1ZJVX0GemO05ADE01MGEd0AdM70P1FEUH0
>027QhL0EeMG065QH@1HF5P0Q8B405iNGP10@400F5QH06MWI`1bLW80VYZJ07MgM`1ZJVX0LW9b06MW
I`1[Jf/0EeMG05eMG@1BDU80FUYJ059BDP1NGUh0Bd];05MGE`1@D500Fe]K05YJFP1ZJVX0LW9b04e=
C@1CDe<0RHV909>CT`1fMWH0DU9B04=3@`1EEED0HF5Q079bLP1;Bd/0?3`l055AD@19BDT0D51@05AD
E01:BTX0B4Q805YJFP1DE5@0I6AT04m?C`1=CDd0@41004];B`18B4P0BTY:0P18B4P0500o?cl0H61P
0451@@1/K6`0Cdm?04U9B@1`L700HF5Q08J6QP1kNg/0FUYJ06IVIP1IFET0EEEE04i>CP1cLg<0Ti>C
06YZJP1IFET0F5QH3_ooool0:`1aLG40Bd];059BDP1EEED0ADE504=3@`1YJFT0;bl_04e=C@0l?3`0
@d=305=CD`0];Bd0=cLg02DU9@0a<C40FEUI02TY:@15ADD0>3Ph020P801@D500@d=304I6AP0j>SX0
DE5A05eMG@0h>3P0M7Ad04Y:BP1ADE40?Shn030`<01IFET0G5aL04M7A`16ATH0=3@d061PH01GEeL0
CTi>05mOG`1nOWh00P1KFe/0?01=CDd0C4a<04Q8B01cLg<0RHV90410@016ATH0J6QX04=3@`1LG5`0
MWIf07QhN02>SXh0DU9B06EUI@1ZJVX0De=C05MGE`1ZJVX0N7Qh075aL@15ADD0O7al05=CD`1XJ6P0
RXZ:07YjNP1JFUX0G5aL055AD@1GEeL0JVYZ08R8R01CDe<0IFEU0861P@1YJFT0L71`06EUI@1kNg/0
Kfm_0861P@22PX80MgMg059BDP0_;bl0EUIF05aLG01_Kfl0DE5A06i^KP1aLG40FEUI05QHF01FEUH0
QHF505iNGP1aLG40J6QX07inOP80Bd];00d0L71`051@D01aLG40IFEU04A4A01JFUX0DU9B06a/K01f
MWH0@d=306EUI@1aLG40K6a/0080GUiN0180>3Ph059BDP13@d<0Hf=S05UIF@1EEED0MWIf03Ph>01Y
JFT0GEeM06a/K012@T80Hf=S0:j^[P0g=cL0BTY:04Q8B01jNWX>ooooo`0[07AdM011@D4092@T02d]
;@1@D500BTY:05]KF`1RHV80C4a<02l_;`22PX80P82006YZJP1MGEd0:BTY06e]K@1TI6@0[Jf]08j>
SP0V9RH0>SXj09RHV026QXH0/;2`04E5A@0b<S80:BTY02@T900W9bL0>SXj061PH01VIVH0/k>c08f=
S@0k>c/09BDU03`l?00e=CD04A4A018B4P1;Bd/0PH6109nOW`020<30`01O0820P017AdL0MgMg04m?
C`1;Bd/0F5QH07UiN@2HV9P0UYJF055AD@1<C4`071`L01LG5`0N7Qh0K6a/09>CT`2f][H0RXZ:09^K
V`0P8200?Cdm05YJFP1:BTX0FEUI09^KV`27QhL0G5aL09bLW01bLW80Xj>S08J6QP1TI6@0C4a<01LG
5`0P8200CTi>034a<@1cLg<0ATI608f=S@2IVIT0SXj>055AD@1JFUX0E5AD0<71`@1_Kfl0HF5Q08J6
QP14A4@08B4Q01TI6@0a<C40FEUI08R8R024Q8@0O7al0;Bd]03Cdm<0`l?307MgM`1VIVH0>c/k01lO
7`0G5aL07AdM079bLP26QXH0RXZ:04U9B@25QHD0]KFe06MWI`10@400V9RH04a<C00o?cl0GUiN05mO
G`0J6QX06a/K05EEE@1jNWX0Z:RX06EUI@0Z:RX07alO024Q8@1?Cdl0Kfm_08n?S`2GUiL0EEEE02d]
;@0V9RH05?ooool001?ooooo04`0MWIf05mOG`1/K6`0ATI605eMG@1;Bd/0H61P05iNGP1JFUX0Lg=c
04e=C@1<C4`0N7Qh04a<C01ADE40P820051@D01?Cdl0GEeM03Xj>P0m?Cd0CDe=04i>CP0c<c<0ADE5
04=3@`1PH600;Bd]04Q8B01hN7P0>CTi04];B`1aLG40:RXZ055AD@1oOgl0<C4a04m?C`1GEeL0BDU9
07MgM`0n?Sh0D51@04e=C@19BDT0GUiN04E5A@19BDT0NWYj03Lg=`16ATH0Hf=S03De=@18B4P0KFe]
03Ti>@1IFET0JFUY03Ti>@1>CTh0O7al0492@P1@D500LG5a0492@P1TI6@0H61P03@d=01=CDd0JVYZ
055AD@1HF5P0Bd];065QH@1_Kfl0?Shn0P1LG5`0?@1<C4`0IVIV05YJFP1KFe/0Ng]k05ADE01;Bd/0
QhN703hn?P1@D500Ng]k03Lg=`13@d<0IFEU05ADE01EEED0FEUI055AD@1KFe/0BDU905MGE`1kNg/0
B4Q807=cL`1=CDd0BDU9071`L011@D40QXJ606][J`0o?cl0L71`06YZJP1KFe/0NWYj07MgM`1UIFD0
Jf][07alO01WIfL0ATI606ATI01UIFD0ADE5065QH@1HF5P0Cdm?05iNGP1=CDd0A4A406MWI`17AdL0
@D5105iNGP1<C4`0CDe=03lo?`1GEeL0@T9205]KF`1HF5P03_ooool0501/K6`0BTY:06UYJ@1LG5`0
OWin05mOG`2=SHd0/k>c07QhN01GEeL0ATI604e=C@1WIfL0I6AT06a/K01]KFd0MgMg06i^KP1GEeL0
BTY:0P1=CDd05@1?Cdl0BTY:0410@015ADD0<C4a05]KF`0e=CD0B4Q803lo?`1IFET0Jf][05EEE@1Q
HF40GEeM04Q8B00n?Sh0De=C03/k>`0o?cl0CTi>03De=@0203hn?P0Y04I6AP12@T80AdM703`l?01F
EUH0CTi>04a<C020P800EEEE05]KF`1JFUX0Jf][05YJFP1QHF40C4a<04Y:BP1XJ6P0U9BD06ATI01A
DE40BDU907YjNP1=CDd0Cdm?06e]K@1KFe/0HV9R08Z:RP1<C4`0D51@05EEE@1GEeL0JFUY07QhN022
PX80F5QH06MWI`1FEUH0Bd];05EEE@1KFe/00P1BDU80101JFUX0MGEe07emO@1CDe<206EUI@0905=C
D`1IFET0De=C04=3@`11@D40CTi>06ATI01=CDd0>CTi0080AdM700L0ADE504=3@`0n?Sh0@d=306EU
I@1JFUX0LG5a0080Cdm?01X0>c/k04I6AP0m?Cd0ATI604Y:BP1EEED0>c/k05EEE@1=CDd0GUiN05YJ
FP1:BTX0OWin05eMG@20P800I6AT04a<C01VIVH0@D5103Hf=P10@400H61P06UYJ@1NGUh0GEeM06MW
I`kooooo08`0PH61051@D01RHV80De=C04a<C01SHf<0EUIF04A4A01UIFD0ADE504i>CP1BDU80AdM7
03dm?@0Q8B40B4Q8069RHP0l?3`0KFe]03hn?P0`<300GemO05EEE@1>CTh0?Shn06IVIP1EEED0>3Ph
06i^KP17AdL0A4A4059BDP0_;bl0GEeM06YZJP17AdL0BDU903Ti>@1?Cdl0F5QH04];B`1?Cdl0QhN7
069RHP1UIFD0CDe=03dm?@1HF5P0EUIF08f=S@1:BTX0De=C05aLG019BDT0De=C06i^KP1`L700IfMW
05EEE@1IFET0IFEU05]KF`1SHf<0JFUY06IVIP1EEED0?Cdm07UiN@15ADD0F5QH08:2PP1ZJVX0AdM7
05mOG`0m?Cd0BDU905MGE`1aLG40IfMW06e]K@1hN7P0KVi^08N7Q`1FEUH0Jf][07EeM@28R8P0Shn?
08V9R@1@D500<C4a04i>CP1;Bd/0HF5Q04a<C01?Cdl0M7Ad05eMG@1:BTX0I6AT0:2PX01cLg<0M7Ad
07]kN`2NWYh0?clo06=SH`1IFET0AdM706IVIP1TI6@0<S8b06QXJ01NGUh0FEUI06MWI`1HF5P0H61P
07IfMP20P800L71`04Q8B00h>3P0GUiN03Ph>01>CTh0?clo061PH01aLG40=cLg09JFUP12@T80J6QX
05EEE@1UIFD0Vi^K04I6AP1=CDd0?3`l08F5Q@kooooo00H0MgMg06a/K01VIVH0M7Ad04Q8B00S8b<2
01`L700A059BDP0X:2P0:2PX092@T03[jn/0i>CT0:BTY01oOgl0`/;20492@P0b<S80RHV90=SHf02i
^KT0C4a<069RHP18B4P00P0N7Qh0:@0J6QX05ADE01PH600j>SX0MGEe0:ZZZP2`/;00OWin075aL@2a
/K40Kfm_04=3@`14A4@0NWYj0:b/[03?cll0cLg=04Y:BP1TI6@0OWin09jNWP1RHV80Bd];04E5A@1e
MGD0Ph>305YJFP1RHV80TI6A028R8P0I6AT0;bl_065QH@1cLg<0BDU90:f][@1IFET0F5QH01hN7P0e
=CD0RXZ:0080][Jf04H0NGUi059BDP1NGUh0]KFe05aLG00_;bl0KFe]09>CT`1OGel0IFEU02<S8`0N
7Qh0IVIV04e=C@1@D500?Cdm04m?C`1aLG40EUIF0<_;b`2BTY80NWYj07inOP3:b/X0UYJF06a/K01j
NWX0Lg=c07QhN01IFET07alO02@T901SHf<0Xj>S07inOP2c/k<0RXZ:03lo?`0M7Ad06ATI04Y:BP1F
EUH0@D5103Hf=P1_Kfl0JVYZ0:VYZ@2j^[X0bLW90:ZZZP13@d<0MWIf06e]K@1/K6`0?Cdm01XJ6P0Z
:RX0Ogmo07YjNP0R8R807alO02PX:00N7Qh09RHV06ATI02@T900Ng]k01dM7@0Q8B40De=C5?ooool0
01?ooooo00@0IVIV06i^KP1EEED0JFUY0P1ADE40301kNg/0<C4a05IFEP1iNGT0:BTY05mOG`1QHF40
>CTi06EUI@1SHf<0BTY:04M7A`80Cdm?07L0?Shn055AD@1KFe/0>c/k051@D01QHF40>CTi03Ph>01Q
HF40BDU903hn?P1KFe/0AdM704A4A01OGel0EUIF05UIF@1@D500C4a<05IFEP16ATH0HF5Q05iNGP0b
<S80GemO04m?C`0P8200E5AD051@D00j>SX0JFUY03/k>`16ATH0E5AD04U9B@1KFe/0EUIF05ADE01@
D500ADE504i>CP1IFET0>SXj055AD@21PH40=SHf05IFEP1QHF40;bl_06QXJ01ZJVX0?clo071`L01i
NGT0DU9B07moO`1OGel0CDe=0820P01WIfL0@d=306YZJP1OGel0BTY:065QH@1YJFT0CDe=05ADE01H
F5P0GUiN03dm?@1ADE40NWYj0451@@1WIfL0N7Qh0451@@1]KFd0CDe=05IFEP1SHf<0=CDe06UYJ@1[
Jf/0BTY:07=cL`1lO7`0G5aL06m_K`1@D500HV9R06IVIP1;Bd/0LG5a061PH011@D40RXZ:051@D00i
>CT0Ti>C05IFEP15ADD0MGEe04Y:BP1BDU80S8b<03dm?@17AdL0RXZ:03Xj>P1DE5@0KFe]03lo?`1J
FUX0EUIF03<c<`1?Cdl0E5AD03Xj>P0>ooooo`04075aL@1GEeL0Hf=S05IFEP80HV9R00H0PX:206MW
I`1QHF40ADE503`l?01<C4`2065QH@0m07AdM01HF5P0I6AT05MGE`1?Cdl0?clo04e=C@1;Bd/0Cdm?
055AD@1:BTX0@41003Xj>P1KFe/0@41004a<C01@D500GemO07alO01CDe<0GemO05QHF010@400@T92
04];B`19BDT0?Cdm04I6AP0l?3`0?Cdm0410@015ADD0?clo0492@P1?Cdl0F5QH04M7A`1EEED0Lg=c
069RHP1NGUh0KVi^061PH01QHF40LW9b04A4A01ADE40FEUI09jNWP1GEeL0CTi>055AD@1kNg/0GEeM
05ADE01iNGT0Jf][06m_K`2>SXh0CTi>05ADE00204=3@`0O04a<C01VIVH0DU9B04M7A`1JFUX0AdM7
04m?C`16ATH0Cdm?04M7A`15ADD0EUIF06IVIP1UIFD0DU9B04M7A`1YJFT0CTi>05MGE`1;Bd/0@410
0492@P1GEeL0JVYZ061PH019BDT0Bd];04Q8B01?Cdl0FEUI04E5A@0204U9B@0N05eMG@1HF5P0EEEE
05ADE015ADD0FEUI04I6AP1<C4`0ATI605=CD`0h>3P0C4a<03De=@1@D500Fe]K05YJFP1VIVH0Hf=S
08J6QP1ZJVX0F5QH06=SH`1:BTX0ATI604=3@`19BDT0IVIV05YJFP1KFe/0Jf][3_ooool06@1QHF40
BDU904m?C`1KFe/0C4a<04M7A`1@D500?clo04=3@`11@D40AdM705]KF`17AdL0@T9203`l?00f=SH0
@d=302`/;01HF5P0?Cdm02`/;01DE5@0ADE5055AD@1?Cdl00P1KFe/02017AdL0H61P051@D01?Cdl0
ADE502DU9@1CDe<0CDe=0P18B4P05`0b<S80GEeM05aLG013@d<0JVYZ09JFUP1;Bd/0>CTi05IFEP1D
E5@0CDe=06e]K@2OWil0B4Q8051@D01IFET0Cdm?04e=C@1SHf<0GemO05UIF@1RHV80DE5A0080H61P
0P1[Jf/05@1ZJVX0B4Q804i>CP1kNg/0@T9205aLG01fMWH0JVYZ04Y:BP1QHF40?Cdm05eMG@1@D500
WYjN05MGE`1FEUH0S8b<07AdM01fMWH0KFe]08N7Q`0206MWI`0:08F5Q@22PX80Cdm?02/[:`13@d<0
KVi^04i>CP14A4@0JVYZ07emO@80Fe]K02T0CTi>07emO@1TI6@0MWIf05iNGP1/K6`0EeMG04I6AP1Y
JFT0@41006EUI@1BDU80<c<c05QHF019BDT0L71`07inOP11@D40HV9R07QhN01`L700J6QX07=cL`0j
>SX0B4Q802TY:@1nOWh0CDe=0451@@1eMGD0>CTi07=cL`1FEUH0Ng]k03@d=01XJ6P0UYJF020P801>
CTh0BDU9075aL@0>ooooo`0508j>SP2GUiL0ZJVY0:FUY@26QXH00P0i>CT05P15ADD0>3Ph0492@P18
B4P0R8R80=OGe`29RHT0;bl_02TY:@1BDU80@D5101DE5@1KFe/0c/k>0:j^[P1EEED0:b/[0820P01I
FET0E5AD04E5A@0/;2`202DU9@0603Xj>P2m_Kd0^KVi09FEU@1MGEd0CTi>0P1^KVh03P0e=CD0@T92
07emO@2c/k<0ZZZZ065QH@1eMGD0PX:2075aL@0O7al07AdM020P801/K6`0_Kfm0P2BTY80BP2_[jl0
IFEU061PH01WIfL0LW9b05eMG@0T92@0LG5a069RHP28R8P0Ogmo06IVIP1bLW80[Jf]0;Zj^P22PX80
I6AT04A4A021PH40SXj>04i>CP2?Shl0TI6A061PH01dM7@0?Shn03Hf=P1RHV80;2`/01LG5`0F5QH0
9RHV06UYJ@1hN7P0Bd];02/[:`1lO7`0UYJF06MWI`14A4@0;Rh^06EUI@2i^KT0Fe]K02PX:00U9BD0
ATI60861P@1dM7@0VYZJ0:f][@1[Jf/0=CDe04i>CP1/K6`0De=C03Ph>00K6a/05QHF038b<P1]KFd0
T92@09>CT`1dM7@0OWin0:n_[`1?Cdl08R8R02LW9`1]KFd0HF5Q06EUI@2VYZH0JVYZ0P0N7Qh02@0[
:b/07QhN02@T902DU9@0Jf][03Ti>@0n?Sh0<30`06a/K00Dooooo`004oooool0;P1jNWX0G5aL06EU
I@1CDe<0EUIF05MGE`1HF5P0EEEE061PH01KFe/0C4a<03hn?P1LG5`0DU9B04=3@`1QHF40L71`03Lg
=`1EEED0GemO030`<01MGEd0D51@03<c<`1MGEd0FEUI04];B`15ADD0DU9B071`L012@T80BTY:06=S
H`0g=cL0EEEE07UiN@18B4P0BTY:06i^KP0j>SX0BTY:05eMG@18B4P0A4A405aLG01?Cdl204=3@`07
05IFEP1;Bd/0FEUI051@D01?Cdl0?3`l05]KF`0204e=C@0?05UIF@17AdL0EUIF061PH01:BTX0Cdm?
06e]K@1:BTX0ADE5079bLP1@D500ATI606e]K@1KFe/0F5QH0080HF5Q0440IVIV06i^KP1LG5`0F5QH
04m?C`1TI6@0EeMG05QHF01WIfL0Fe]K04];B`1dM7@0De=C04a<C01OGel0Cdm?03dm?@1BDU80H61P
0451@@1KFe/0J6QX05=CD`1JFUX0G5aL06MWI`1FEUH0CTi>065QH@1WIfL0GEeM04U9B@1`L700GEeM
04e=C@1VIVH0GUiN06ATI01PH600PX:205mOG`1FEUH0T92@05IFEP18B4P0Ogmo05mOG`17AdL0NWYj
0451@@1BDU80HF5Q04e=C@19BDT0De=C055AD@1GEeL0KFe]04A4A01QHF40E5AD04Q8B01HF5P0DU9B
051@D00>ooooo`040861P@1BDU80IVIV05IFEP80J6QX01L0MgMg096AT@1`L700Bd];04m?C`1BDU80
F5QH069RHP1YJFT0I6AT05mOG`1NGUh0EUIF03Ti>@1@D500BTY:04m?C`16ATH0A4A403Lg=`0d=3@0
EUIF034a<@0204E5A@0Z051@D01jNWX0DE5A051@D01BDU80@d=304M7A`1<C4`0>c/k03lo?`12@T80
=CDe03Hf=P0h>3P0?3`l03Ph>00m?Cd0?clo04Y:BP10@400@T9206EUI@1<C4`0CDe=05=CD`1FEUH0
ATI6061PH016ATH0@T9205QHF02<S8`0JFUY04m?C`14A4@0IFEU04];B`10@400JVYZ051@D01SHf<0
SXj>0P1:BTX05@1TI6@0CTi>05aLG01dM7@0GEeM061PH01UIFD0@d=304e=C@19BDT0BTY:04a<C019
BDT0Fe]K075aL@1]KFd0CDe=04i>CP1CDe<0FEUI05QHF00203dm?@0B0492@P1CDe<0B4Q804m?C`12
@T80ADE50492@P1?Cdl0De=C03Ti>@15ADD0E5AD05EEE@1LG5`0B4Q8055AD@0o?cl0<c<c0P13@d<0
5P19BDT0EEEE04A4A015ADD0@D5104Y:BP1>CTh0Bd];065QH@1NGUh0IfMW06ATI01EEED0G5aL059B
DP19BDT0CDe=051@D01TI6@0E5AD061PH01TI6@>ooooo`2<07AdM01=CDd0DU9B05IFEP1=CDd0H61P
04];B`0n?Sh0ADE503Ti>@1>CTh0Bd];05YJFP0k>c/0>3Ph04Q8B012@T80;Rh^06UYJ@0g=cL0;2`/
03lo?`1GEeL0>c/k03dm?@1YJFT0FUYJ04=3@`1/K6`0BTY:03Ti>@1HF5P0=3@d05QHF01]KFd0D51@
05=CD`12@T80Hf=S05=CD`1BDU80GemO07inOP1`L700HV9R04Q8B00h>3P0GEeM06i^KP2=SHd0Cdm?
04M7A`1FEUH0?3`l04i>CP1SHf<0H61P069RHP1>CTh0E5AD075aL@1@D500MGEe05EEE@1VIVH0H61P
03Hf=P1mOGd0@T9205EEE@2=SHd0JVYZ04=3@`1OGel0AdM704Y:BP1EEED0RHV906][J`1=CDd0RXZ:
06EUI@2FUYH0C4a<07=cL`1gMgL0HV9R08V9R@1NGUh0EUIF03/k>`1@D500EEEE06MWI`1;Bd/0CTi>
07emO@1JFUX0CTi>05]KF`2<S8`0NWYj05mOG`1bLW80U9BD04Y:BP1SHf<0J6QX04e=C@1nOWh0G5aL
03Lg=`1/K6`0Fe]K06e]K@1^KVh0MGEe05aLG01_Kfl0Ph>306ATI01OGel0?Shn05IFEP13@d<0L71`
04m?C`1JFUX0KVi^03De=@20P800D51@09JFUP12@T80IfMW0861P@0^;Rh0@41004E5A@1bLW8>oooo
o`0H059BDP24Q8@0V9RH0:2PX02g]kL0KVi^03@d=00R8R809RHV02DU9@0c<c<0UIFE0<71`@23Ph<0
GUiN04=3@`0a<C40JFUY03De=@1[Jf/0YjNW0<?3``1:BTX0@D51100B4Q82010@4004018B4P0U9BD0
Cdm?0820P0806a/K01H09bLW02@T901HF5P0TY:B08b<S01>CTh071`L03Hf=P20P800?Cdm02XZ:P1O
Gel0Kfm_03Lg=`1iNGT0U9BD051@D01BDU80IFEU08b<S02VYZH0/[:b0P1KFe/05`1`L700H61P069R
HP2ZZZX0Shn?065QH@0`<300:RXZ09BDU02=SHd0LG5a06][J`16ATH0@d=3061PH01@D5009BDU05eM
G@1[Jf/0A4A408J6QP2`/;00BDU900@05ADE01T07QhN08>3P`2^[Zh0ZJVY0;jn_P2d];@0De=C04Q8
B013@d<0UiNG04A4A00m?Cd0:BTY065QH@15ADD05aLG02DU9@2f][H0a<C407IfMP1@D500HF5Q09>C
T`1;Bd/05QHF00805aLG01X0@41007MgM`1oOgl0MGEe07=cL`2VYZH0YJFU05]KF`1>CTh0ADE503Ph
>01FEUH0Vi^K0=3@d02SXj<0DE5A020P800h>3P0De=C08B4Q02d];@0P82006a/K02HV9P0S8b<055A
DACooooo000Cooooo`0507YjNP1VIVH0OWin04I6AP1YJFT00P1KFe/0J`1UIFD0BDU9069RHP12@T80
?Cdm06][J`1<C4`0DU9B05eMG@1BDU80D51@05=CD`0l?3`0Bd];05=CD`1EEED0E5AD04m?C`1SHf<0
HV9R030`<01EEED0JFUY02PX:01MGEd0Hf=S03Ph>01JFUX0C4a<04Q8B01OGel0BDU905aLG01:BTX0
@T92065QH@0j>SX0B4Q805mOG`0];Bd0CTi>065QH@0Z:RX0C4a<04Y:BP0U9BD0@D5105IFEP0[:b/0
GemO04Y:BP0a<C40H61P07AdM00e=CD0H61P07MgM`1>CTh0F5QH05aLG01MGEd0@D5105eMG@1LG5`0
I6AT05QHF01_Kfl0LG5a065QH@1eMGD0JFUY0451@@29RHT0FUYJ06ATI025QHD0Cdm?05mOG`26QXH0
ATI6059BDP1OGel0@D51055AD@1MGEd0I6AT061PH01SHf<0NGUi071`L00o?cl0IfMW07EeM@1?Cdl0
H61P051@D01^KVh0C4a<04E5A@23Ph<0De=C05aLG01`L700FEUI075aL@1oOgl0Q8B40080H61P01L0
OWin06YZJP13@d<0GemO06m_K`14A4@0GEeM069RHP1EEED0J6QX05UIF@0m?Cd0Kfm_05MGE`18B4P0
FEUI06m_K`0o?cl0Bd];06IVIP0k>c/0H61P04i>CP0>ooooo`1408F5Q@1NGUh0MWIf05ADE01=CDd0
CTi>05YJFP1lO7`0GEeM03lo?`17AdL0E5AD05=CD`15ADD0De=C05aLG01KFe/0IVIV04m?C`0m?Cd0
DE5A04Q8B01?Cdl0ATI604M7A`18B4P0=cLg05mOG`0Z:RX0ATI603dm?@13@d<0GEeM05UIF@1;Bd/0
CTi>0410@01=CDd0>3Ph03De=@13@d<0ADE502l_;`0k>c/0>SXj03dm?@12@T80?clo04i>CP1=CDd0
AdM704=3@`1TI6@0C4a<04A4A01?Cdl0B4Q804a<C01TI6@0EeMG0451@@1?Cdl0U9BD05aLG01UIFD0
GemO06MWI`1RHV8204E5A@0A03lo?`1YJFT0Ph>304Q8B019BDT0Lg=c0492@P1<C4`0GEeM05aLG01A
DE40KVi^0492@P1=CDd0EeMG05=CD`1BDU800P1:BTX0<`1dM7@0FEUI05UIF@1;Bd/0N7Qh07MgM`1M
GEd0C4a<0492@P11@D40GUiN05]KF`1FEUH0G5aL04=3@`10@400CTi>05UIF@0o?cl0Bd];065QH@1G
EeL0HF5Q04e=C@1>CTh0A4A404e=C@1<C4`0DE5A051@D01<C4`0AdM705ADE016ATH0=cLg04a<C01>
CTh0HF5Q06a/K01YJFT0L71`05]KF`1RHV80FEUI04M7A`1PH600L71`07inOP1GEeL0HV9R06][J`0>
ooooo`2<05eMG@1:BTX0HV9R065QH@1:BTX0AdM7061PH00f=SH0CDe=03`l?00g=cL0G5aL03`l?00j
>SX0@41002PX:01FEUH0=3@d05IFEP0n?Sh0:BTY06=SH`19BDT0@41005QHF019BDT0GEeM05EEE@1U
IFD0A4A404U9B@1JFUX0;2`/061PH01KFe/0@d=305MGE`0d=3@0Jf][051@D017AdL0N7Qh08F5Q@2<
S8`0DU9B051@D00h>3P0HF5Q07EeM@1mOGd0ADE504a<C01OGel0Cdm?055AD@22PX80KFe]06YZJP1I
FET0IfMW07AdM01BDU80MWIf05mOG`1cLg<0J6QX04I6AP26QXH0DE5A06=SH`2DU9@0IVIV04Y:BP1W
IfL0B4Q8065QH@1ZJVX0O7al06m_K`1HF5P0WinO061PH02MWId0FUYJ07MgM`20P800Fe]K07alO01W
IfL0EeMG0492@P1=CDd0HF5Q06=SH`1?Cdl0De=C07alO01PH600Bd];061PH020P800M7Ad07EeM@1Z
JVX0R8R80492@P1MGEd0M7Ad04m?C`1fMWH0De=C02d];@1OGel0G5aL061PH01OGel0FEUI075aL@1/
K6`0M7Ad05iNGP1JFUX0@D5104];B`0o?cl0JFUY04Y:BP0f=SH0LW9b04];B`21PH40F5QH08f=S@1D
E5@0Jf][06i^KP18B4P0<C4a04I6AP1^KVh>ooooo`0>034a<@1PH600NWYj03Ti>@1IFET0A4A400l?
3`0E5AD0410@014A4@0K6a/0H61P05QHF011@D4201XJ6P0903dm?@0k>c/0<30`055AD@2ATI40a<C4
05]KF`0O7al092@T00D03`l?00D03Ph>01@D500d=3@0LG5a01<C4`02010@400400h>3P0?3`l0De=C
05eMG@<04A4A03T0>SXj01XJ6P0g=cL0Jf][0:j^[P30`<00EEEE03hn?P0S8b<06QXJ03Ti>@1YJFT0
/;2`0;>c/`1?Cdl0>CTi05ADE01=CDd0Kfm_09JFUP2TY:@0NGUi03dm?@0[:b/0FEUI08V9R@1:BTX0
B4Q80492@P0F5QH07alO065QH@1KFe/0JFUY09RHV01EEED0Vi^K0;Ng]`16ATH07QhN01DE5@0D51@0
6QXJ03/k>`2?Shl0bLW906QXJ03=cLd0YjNW04=3@`0`<300;bl_061PH00j>SX0=CDe07IfMP0U9BD0
0P0E5AD02@0X:2P0YZJV0;Jf]P1`L700MGEe03Hf=P0X:2P0HV9R01lO7`0201DE5@0J03<c<`1VIVH0
N7Qh04=3@`0`<300MGEe0;:b/P2YZJT0GEeM07UiN@1ADE40De=C0:2PX02=SHd0Y:BT0<?3``2h^;P0
[Zj^07alO036a/H0[Zj^03Hf=P1KFe/0ZZZZ0<_;b`2@T90Dooooo`004oooool0R`1cLg<0JFUY06EU
I@1iNGT0AdM706e]K@1TI6@0=cLg05aLG01NGUh0>CTi051@D01LG5`0BDU903lo?`16ATH0KVi^04Y:
BP12@T80LG5a0451@@1CDe<0Lg=c04M7A`1JFUX0F5QH0492@P17AdL0L71`051@D015ADD0HF5Q04e=
C@1>CTh0GEeM06EUI@1IFET0G5aL059BDP1GEeL0@T92061PH01JFUX0>3Ph079bLP1CDe<0@d=304Q8
B01?Cdl0ADE505UIF@1=CDd0BTY:03dm?@14A4@0?clo0492@P1HF5P0JFUY03@d=01;Bd/0EEEE034a
<@1XJ6P0K6a/02TY:@1JFUX0EeMG03Hf=P1WIfL0De=C03Ti>@1UIFD0GemO04Y:BP1EEED0L71`04a<
C01HF5P0B4Q803`l?01cLg<0EEEE065QH@1BDU80EEEE06MWI`1>CTh0DE5A05eMG@15ADD0DE5A06QX
J00_;bl0J6QX07MgM`1<C4`0JFUY04E5A@1CDe<0H61P03Xj>P1RHV80M7Ad05UIF@1=CDd0EEEE05mO
G`1SHf<0A4A405QHF01PH600EeMG08J6QP1GEeL0BDU908^;R`1JFUX0CDe=06UYJ@1CDe<0EEEE071`
L018B4P0EeMG06YZJP1=CDd0Cdm?06=SH`0c<c<0Hf=S06i^KP0f=SH0IFEU05ADE00n?Sh0CTi>055A
D@0k>c/03_ooool03@22PX80DU9B06IVIP1@D500Hf=S04Q8B01VIVH0MGEe05UIF@0l?3`0ATI603dm
?@1:BTX00P1>CTh0?`1BDU80EeMG05EEE@1NGUh0?3`l04U9B@1=CDd0BTY:04M7A`18B4P0ADE503`l
?01QHF40<S8b04m?C`1BDU80EEEE06MWI`1KFe/0F5QH069RHP1<C4`0ATI604E5A@0b<S80AdM7051@
D00n?Sh0>c/k03hn?P15ADD0>SXj03lo?`18B4P0DU9B0410@017AdL0LG5a05QHF018B4P0D51@03hn
?P13@d<0CDe=04E5A@12@T80Hf=S0861P@1KFe/0Lg=c061PH01`L700C4a<055AD@1TI6@0EEEE061P
H01TI6@0DE5A05=CD`1KFe/0D51@04m?C`0205aLG00S05ADE01IFET0C4a<04M7A`1OGel0FEUI03dm
?@0h>3P0AdM705QHF01RHV80A4A405YJFP2BTY80F5QH03`l?01@D500EUIF061PH01]KFd0CDe=05AD
E017AdL0Cdm?05=CD`1KFe/0IFEU055AD@1HF5P0NGUi06ATI01fMWH0E5AD059BDP0k>c/00P16ATH0
1`1BDU80AdM704i>CP17AdL0ADE505ADE01EEED00P1>CTh03P1ADE40JVYZ06ATI01[Jf/0ATI605]K
F`16ATH0AdM70492@P1IFET0KFe]05UIF@1BDU80Lg=c3_ooool0S01SHf<0BDU905UIF@1ZJVX0BTY:
04];B`1ZJVX0>CTi04e=C@0k>c/0@D51051@D00j>SX0AdM703dm?@0b<S80E5AD034a<@1EEED0?3`l
038b<P1PH600GUiN03lo?`1>CTh0A4A406i^KP17AdL0G5aL04=3@`0g=cL0A4A402d];@1IFET0GUiN
04Q8B01?Cdl0>c/k07=cL`1NGUh0BTY:06YZJP1gMgL0NWYj05iNGP1GEeL0B4Q805YJFP1nOWh0QXJ6
04e=C@15ADD0De=C05ADE01:BTX0QXJ6069RHP1MGEd0FEUI055AD@1[Jf/0C4a<06i^KP1MGEd0EEEE
06ATI00h>3P0HV9R03lo?`1SHf<0P82006=SH`1LG5`0NGUi05EEE@1BDU80LG5a07inOP1QHF40C4a<
09JFUP1kNg/0V9RH06ATI02=SHd0KFe]065QH@2;Rh/0H61P05QHF00g=cL0BTY:06ATI01@D500C4a<
05EEE@25QHD0DU9B055AD@1LG5`0PX:208B4Q01fMWH0Ng]k0:2PX01JFUX0DU9B07MgM`1>CTh0Q8B4
05aLG00n?Sh0CTi>06=SH`1iNGT0GemO06][J`1^KVh0D51@06QXJ01SHf<0De=C03Lg=`1]KFd0DU9B
05ADE01:BTX0CTi>07EeM@0e=CD0T92@059BDP1SHf<0E5AD07=cL`1WIfL0@D5104m?C`0j>SX0MWIf
3_ooool01P0f=SH0I6AT09^KV`23Ph<0IFEU03Ph>0803@d=02h03Ph>014A4@0L71`0GEeM0820P00o
?cl051@D018B4P0S8b<051@D014A4@0L71`0Zj^[0:ZZZP1fMWH0G5aL03`l?00R8R803Ph>018B4P0I
6AT05ADE00l?3`0@4100D51@09bLW01<C4`071`L00l?3`0>3Ph03`l?03hn?P0o?cl04A4A00l?3`0@
41007alO030`<00B4Q80R8R80>;RhP2e]KD08R8R01LG5`0O7al08b<S0P0/;2`0C`1:BTX0M7Ad06QX
J01EEED0KVi^06=SH`1CDe<0PX:208j>SP1VIVH0=cLg01LG5`16ATH0F5QH08:2PP1<C4`0H61P02TY
:@0P82008R8R09>CT`2][Jd0IfMW06m_K`2YZJT0ADE506MWI`16ATH06QXJ02h^;P0d=3@0GUiN0820
P01nOWh0Bd];0;no_`2<S8`0?Cdm04a<C01EEED0WIfM07MgM`1:BTX0Ph>301HF5P0G5aL09BDU06QX
J02SXj<0SXj>02l_;`1CDe<0:b/[02@T9016ATH0De=C03Ph>00V9RH0BDU904Y:BP1@D500H61P051@
D02:RXX0SHf=0;no_`1mOGd0:b/[03/k>`1hN7P0<30`051@D02:RXX0`L710=;BdP3GemL0`l?30<g=
c@2ATI400P2?Shl00`2QXJ40cLg=07IfMP0Dooooo`004oooool0:P1jNWX0IFEU06i^KP1GEeL0FUYJ
059BDP1OGel0ATI605=CD`1KFe/0@D5104E5A@1]KFd0CDe=03lo?`1;Bd/0DU9B03@d=01KFe/0F5QH
03/k>`1DE5@0D51@03hn?P1HF5P0BDU904Q8B017AdL0CTi>05aLG00l?3`0D51@0861P@11@D40HV9R
04];B`0f=SH0BTY:05=CD`17AdL0D51@04];B`80CTi>00/0Cdm?05EEE@11@D40B4Q805eMG@1=CDd0
DE5A04U9B@1;Bd/0BDU904e=C@0204A4A01B05aLG01JFUX0@d=306UYJ@1GEeL0CTi>071`L01GEeL0
?Cdm075aL@18B4P0BTY:079bLP1DE5@0C4a<05aLG01>CTh0Hf=S06ATI01OGel0Hf=S05aLG01PH600
@T9206MWI`1TI6@0BDU904m?C`1`L700DU9B04I6AP1=CDd0DE5A03lo?`1OGel0GUiN03lo?`1RHV80
H61P05iNGP1@D500C4a<06YZJP1=CDd0Fe]K065QH@1UIFD0IfMW0451@@1QHF40F5QH059BDP1>CTh0
Fe]K06=SH`1@D500MgMg05aLG01DE5@0L71`06ATI01GEeL0IVIV05iNGP1;Bd/0GUiN05eMG@1IFET0
De=C055AD@1BDU80Fe]K05EEE@14A4@0CTi>05aLG01=CDd0ATI605=CD`12@T80CTi>05mOG`kooooo
01D0Rh^;05EEE@1]KFd0EEEE05aLG01GEeL0L71`09fMW@1YJFT0A4A404U9B@1<C4`0Cdm?061PH01K
Fe/0FEUI05]KF`1PH600EeMG03hn?P1?Cdl00P18B4P0<P1?Cdl0BTY:04=3@`0i>CT0EUIF02/[:`1<
C4`0D51@05ADE01/K6`0DU9B05IFEP1DE5@0ADE504I6AP1:BTX0>CTi04I6AP1?Cdl0?Cdm03/k>`0j
>SX0A4A403/k>`0h>3P0EEEE055AD@1=CDd0D51@06IVIP1DE5@0Cdm?05IFEP1KFe/0C4a<05ADE014
A4@0D51@06a/K02IVIT0C4a<07=cL`1RHV80Hf=S05]KF`1;Bd/0C4a<03Ti>@1EEED0Kfm_0P1>CTh0
@@1IFET0?clo05UIF@1^KVh0J6QX04i>CP1QHF40A4A405YJFP1BDU80G5aL04e=C@1:BTX0E5AD06EU
I@1QHF40E5AD055AD@1gMgL0HV9R04E5A@18B4P0AdM705EEE@1ZJVX0EeMG05UIF@1QHF40BTY:04U9
B@1BDU80EEEE0451@@1<C4`0JFUY05UIF@1cLg<0DE5A04e=C@0n?Sh0ADE50492@P1FEUH0@d=304M7
A`1;Bd/0De=C05UIF@15ADD0BTY:051@D01BDU80KVi^06e]K@21PH40De=C05EEE@14A4@0@d=304U9
B@1MGEd0KVi^065QH@1GEeL0K6a/00kooooo0380NGUi04U9B@1[Jf/0Jf][05QHF01TI6@0FUYJ03Xj
>P0m?Cd0>3Ph0410@01?Cdl0>3Ph0492@P0a<C40?3`l055AD@0g=cL0IFEU03<c<`13@d<0EUIF07=c
L`0o?cl0E5AD03<c<`1bLW80@D51071`L01:BTX0?3`l04i>CP18B4P0JVYZ07IfMP1?Cdl0CDe=03lo
?`1fMWH0G5aL051@D021PH40MGEe06m_K`1/K6`0EEEE030`<01MGEd0=cLg07]kN`80E5AD05P0EUIF
05EEE@1FEUH0RHV906ATI01NGUh0F5QH06EUI@1nOWh0E5AD08F5Q@1[Jf/0J6QX06=SH`1BDU80O7al
04E5A@1XJ6P0QXJ606UYJ@1JFUX0LW9b05MGE`1JFUX0N7Qh0861P@1YJFT0DU9B0:BTY01`L700UIFE
05IFEP20P800Lg=c06m_K`2DU9@0DU9B05UIF@17AdL0Fe]K06][J`1JFUX0BTY:06EUI@2<S8`0Jf][
05IFEP1PH600NWYj06IVIP1iNGT0MgMg08b<S01NGUh0EUIF07IfMP1ADE40MGEe051@D00i>CT0IfMW
05UIF@1mOGd0IVIV069RHP1VIVH0Kfm_06QXJ01NGUh0HV9R0492@P1GEeL0ATI605mOG`1BDU80A4A4
071`L00n?Sh0PH6104i>CP1QHF40JFUY08Z:RP1mOGd0ADE50492@P0k>c/0L71`3_ooool0?P0h>3P0
9RHV03hn?P2=SHd0UiNG05MGE`0C4a<06a/K02h^;P10@400D51@08B4Q01QHF40Fe]K04=3@`1MGEd0
=SHf014A4@0B4Q80=CDe028R8P1^KVh0@41005YJFP1KFe/0C4a<03hn?P0d=3@08b<S02`/;01HF5P0
GUiN05UIF@1bLW80EeMG03dm?@0a<C40:2PX02DU9@12@T80;Bd]01HF5P0@41003`l?02`/;01`L700
BTY:09>CT`37alL0RHV905=CD`0V9RH06a/K03@d=00T92@0=CDe07QhN01EEED0J6QX03Hf=P1MGEd0
Hf=S0P1iNGT0C00^;Rh0ATI606MWI`1TI6@0Kfm_07EeM@1PH600Jf][09bLW01mOGd0IFEU06=SH`2Q
XJ40^KVi06a/K00k>c/0FEUI07emO@1MGEd0IFEU0861P@1?Cdl0MWIf06EUI@1@D500BTY:0:j^[P10
@400C4a<01DE5@0I6AT092@T06=SH`1XJ6P0Ogmo038b<P1UIFD0L71`06EUI@2SXj<0T92@07moO`1F
EUH0IVIV07EeM@1PH600GemO07=cL`1jNWX0WIfM07AdM01aLG40PH6102h^;P0O7al0F5QH08n?S`2O
Wil0PH61079bLP27QhL0:2PX02HV9P0o?cl0TY:B0:JVYP2f][H0YJFU06e]K@16ATH0Jf][0861P@1Z
JVX0/[:b07EeM@14A4@Dooooo`004oooool03P1fMWH0I6AT06UYJ@1CDe<0KFe]05mOG`1oOgl0EEEE
04];B`2DU9@0@T9203<c<`1lO7`0Bd];0P1MGEd0N`15ADD0CTi>06=SH`1>CTh0IVIV04i>CP1CDe<0
HV9R03Lg=`19BDT0Hf=S02HV9P1=CDd0EUIF03<c<`1]KFd0FUYJ03@d=01nOWh0?3`l05QHF01EEED0
BTY:05eMG@1;Bd/0CDe=05aLG00h>3P0DU9B06e]K@0/;2`0De=C065QH@0c<c<0HF5Q04];B`0n?Sh0
JFUY04M7A`0o?cl0JFUY055AD@0o?cl0EEEE06e]K@12@T80EUIF06IVIP1QHF40>CTi05MGE`1OGel0
=3@d05eMG@1`L700EEEE04Y:BP1/K6`0DE5A051@D01oOgl0@410065QH@1iNGT0=CDe059BDP2IVIT0
@41006ATI02;Rh/0?clo05UIF@1GEeL0ATI604];B`1GEeL0HV9R065QH@1PH600KFe]05=CD`18B4P0
De=C05QHF01QHF40EEEE05YJFP1nOWh0HF5Q05EEE@1gMgL0FEUI06MWI`1EEED0G5aL08:2PP17AdL0
KFe]07MgM`1;Bd/0L71`06=SH`11@D40EEEE07AdM00e=CD0EeMG071`L011@D40E5AD075aL@0o?cl0
Fe]K059BDP0m?Cd0JFUY04e=C@15ADD0FUYJ0492@P11@D40K6a/03Ph>00>ooooo`0909BDU01LG5`0
KVi^059BDP1FEUH0GEeM0861P@1RHV80HF5Q0080?3`l06P0BTY:04=3@`1^KVh0Hf=S05iNGP1XJ6P0
JVYZ05eMG@11@D40Cdm?05ADE01;Bd/0DE5A04i>CP11@D40>3Ph05iNGP0Q8B40C4a<0451@@17AdL0
D51@04e=C@18B4P0BTY:04I6AP10@400CDe=03dm?@15ADD0D51@03/k>`0e=CD0<C4a03Ti>@0e=CD0
=SHf04Q8B00o?cl0?Shn0410@01MGEd0B4Q804I6AP1:BTX0J6QX055AD@1DE5@0BDU9055AD@1MGEd0
WIfM04Q8B01kNg/0ADE505eMG@1HF5P0CTi>07UiN@1PH600OGem096AT@1ADE40B4Q8061PH01;Bd/0
GUiN07alO01OGel0?clo06][J`1:BTX0E5AD05QHF01YJFT0B4Q805EEE@1GEeL0Jf][05aLG01HF5P0
De=C08F5Q@1MGEd0>CTi05EEE@19BDT0GEeM06IVIP1>CTh0De=C04m?C`14A4@0BTY:04U9B@17AdL0
<c<c03lo?`1FEUH0EeMG05=CD`1=CDd0?Cdm034a<@80AdM700L0EUIF04Q8B01OGel0E5AD04I6AP1=
CDd0BTY:0080BDU900h0F5QH05EEE@1eMGD0JFUY05ADE01=CDd0@D5104M7A`1:BTX0H61P06e]K@19
BDT0D51@06EUI@kooooo02<0IFEU04Y:BP1PH600Kfm_05ADE01FEUH0Hf=S04M7A`1ADE40AdM704U9
B@1]KFd0=CDe02/[:`13@d<0=3@d05EEE@0f=SH0EeMG03@d=014A4@0HF5Q06][J`1BDU80BTY:0451
@@1SHf<0?Shn06UYJ@11@D40ATI604A4A00m?Cd0GemO071`L00204E5A@1@03Lg=`1dM7@0DE5A05AD
E01fMWH0LW9b08N7Q`1?Cdl0G5aL055AD@1TI6@0>CTi08V9R@22PX80F5QH04Y:BP19BDT0EeMG075a
L@1OGel0FUYJ05ADE01UIFD0KFe]059BDP1]KFd0JFUY06m_K`1:BTX0EeMG07YjNP19BDT0De=C08j>
SP1gMgL0?Shn071`L01EEED0HV9R06IVIP2NWYh0IVIV071`L02XZ:P0I6AT09NGU`1[Jf/0S8b<05iN
GP1QHF40UYJF0492@P1PH600?Cdm05IFEP1`L700KVi^04Q8B01UIFD0MGEe08B4Q010@400De=C08B4
Q01ZJVX0KVi^07MgM`2MWId0DE5A04e=C@26QXH0@T9206m_K`1JFUX0=cLg05=CD`1HF5P0MGEe06=S
H`1MGEd206ATI00E061PH01dM7@0D51@03Xj>P19BDT0B4Q806a/K01KFe/0DE5A07MgM`1;Bd/0MGEe
04];B`1fMWH0ATI608:2PP2@T900ATI603Hf=P1:BTX0N7Qh00kooooo08`0<S8b0492@P1:BTX0Cdm?
08R8R01hN7P0QhN705eMG@0R8R807alO01XJ6P0U9BD0E5AD06YZJP0d=3@0?clo051@D01GEeL0BTY:
02h^;P0F5QH0>SXj014A4@0@4100:RXZ05iNGP1XJ6P0LW9b09NGU`2QXJ40KFe]04e=C@1PH600LG5a
0451@@1GEeL0B4Q804I6AP0i>CT0IfMW02PX:00d=3@05aLG02@T9017AdL0NGUi07emO@1UIFD0QhN7
04E5A@1CDe<0Kfm_08b<S02?Shl0FUYJ079bLP1JFUX0GUiN030`<00b<S80H61P05IFEP0f=SH0MgMg
03/k>`0L71`0Kfm_08b<S00b<S80D51@0;Ng]`1^KVh0HF5Q055AD@0X:2P0BDU905MGE`1CDe<0EEEE
03@d=00/;2`0B4Q809NGU`2?Shl0Hf=S09VIV@1OGel0<30`01TI6@0F5QH0DU9B05QHF016ATH0:2PX
02/[:`0Q8B40;bl_04I6AP13@d<0@T9208>3P`2=SHd0?clo06][J`2e]KD0Ng]k01dM7@0L71`0820P
030`<01HF5P0L71`08R8R02`/;00[:b/08N7Q`1ADE40Kfm_08F5Q@2c/k<0`/;207MgM`1eMGD0GUiN
075aL@1XJ6P0IFEU03<c<`28R8P0YZJV0;jn_P1cLg<0P820061PH01ADE40Q8B40;^k^`38b<P0B4Q8
03<c<aCooooo000Cooooo`1Y07inOP1^KVh0K6a/092@T01>CTh0HV9R06i^KP13@d<0F5QH05=CD`1=
CDd0?clo04a<C01cLg<0>CTi0492@P26QXH0?Cdm0451@@1TI6@0<30`05MGE`1mOGd0?Cdm05iNGP1I
FET0=3@d04Q8B01<C4`0BTY:05=CD`1PH600GEeM04m?C`1JFUX0MWIf05eMG@0k>c/0Hf=S069RHP18
B4P0Kfm_04a<C01;Bd/0Hf=S05EEE@1;Bd/0B4Q805MGE`1>CTh0Bd];04A4A01ZJVX0;Rh^04m?C`1/
K6`09BDU04Y:BP1[Jf/0;Bd]05EEE@1lO7`0=CDe075aL@1DE5@0<C4a05aLG01?Cdl0;Rh^065QH@1E
EED0ATI605YJFP18B4P0DU9B05=CD`1ADE40GEeM059BDP1>CTh0DU9B055AD@1=CDd0IVIV03Ti>@16
ATH0KFe]04];B`1JFUX0KFe]02d];@1@D500Hf=S03Xj>P1SHf<0GEeM04i>CP1XJ6P0?clo07YjNP1?
Cdl0IfMW07emO@1NGUh0Jf][0080EEEE01H0H61P05EEE@0o?cl0Jf][06a/K01GEeL0VYZJ04];B`1I
FET0P82004a<C01[Jf/0M7Ad059BDP1bLW80LG5a04Y:BP1ZJVX0?clo04a<C01VIVH0EEEE0P1DE5@0
200b<S80DU9B05mOG`1<C4`0IFEU05ADE01NGUh0JVYZ3_ooool0:P1mOGd0Bd];06YZJP1TI6@0DU9B
06][J`23Ph<0NWYj065QH@11@D40?Cdm04Y:BP1>CTh0J6QX05=CD`1;Bd/0GemO06IVIP1IFET0@T92
04a<C012@T80BTY:059BDP14A4@0B4Q803Ti>@1NGUh0:BTY04];B`1@D500Cdm?06MWI`19BDT0CDe=
05ADE011@D40>c/k05QHF01<C4`0@T9204U9B@80>3Ph05T0=3@d03/k>`0h>3P0>CTi04Y:BP15ADD0
=SHf0451@@1CDe<0CTi>04Y:BP1>CTh0H61P04I6AP1;Bd/0B4Q803`l?01FEUH0IfMW04M7A`1CDe<0
DU9B04E5A@1=CDd0ATI605]KF`1DE5@0F5QH06e]K@1>CTh0>c/k05MGE`0n?Sh0De=C05mOG`1cLg<0
@d=306i^KP17AdL0FEUI05YJFP1RHV80E5AD059BDP14A4@0IVIV05YJFP1MGEd0Cdm?07QhN016ATH0
?3`l04Y:BP1=CDd0E5AD069RHP1FEUH0K6a/05EEE@16ATH0Cdm?06][J`1GEeL0ADE505QHF01aLG40
KVi^06][J`1PH600EUIF05YJFP18B4P0EUIF05]KF`1:BTX0EeMG04m?C`1=CDd0K6a/04e=C@17AdL0
FUYJ06i^KP1CDe<0Lg=c06UYJ@1KFe/0Cdm?04e=C@0204i>CP0506ATI01WIfL0EUIF069RHP1lO7`0
3_ooool01`21PH40@d=305eMG@1JFUX0?Shn05eMG@0i>CT00P0m?Cd0;014A4@0Bd];04i>CP10@400
9bLW02XZ:P0n?Sh0@T92028R8P1XJ6P0=cLg04I6AP10@400HF5Q04A4A00d=3@0CTi>05eMG@0X:2P0
Kfm_0492@P0g=cL0BTY:03Lg=`1DE5@0LW9b04E5A@1CDe<0@d=306][J`1JFUX0G5aL06a/K01RHV80
NGUi04e=C@1JFUX0=SHf06YZJP0m?Cd0NWYj07QhN01DE5@0AdM70P1CDe<0E@1oOgl0OWin05]KF`1:
BTX0IFEU06UYJ@1PH600NGUi07AdM01WIfL0JVYZ04Q8B024Q8@0?Cdm05EEE@1^KVh0IfMW04=3@`1X
J6P0E5AD05IFEP1RHV80PX:207AdM01JFUX0SHf=06YZJP2?Shl0EUIF07YjNP1gMgL0JVYZ09:BTP1>
CTh0I6AT03lo?`1=CDd0Jf][065QH@0k>c/0H61P07]kN`1bLW80F5QH05MGE`1gMgL0L71`08>3P`1e
MGD0QXJ605ADE01iNGT0PH61055AD@29RHT0EeMG030`<01XJ6P0Jf][069RHP1eMGD0GemO061PH01/
K6`0Kfm_07AdM01VIVH0C4a<05=CD`10@400LG5a05mOG`1PH600HV9R02l_;`1lO7`0De=C051@D01=
CDd0RXZ:092@T01;Bd/0=SHf0492@P1]KFd03_ooool0E`1SHf<0@D5102`/;00L71`0820P05]KF`2P
X:00MgMg02LW9`0c<c<0:BTY03hn?P1GEeL0@D5104E5A@1GEeL0=SHf08J6QP2;Rh/05aLG01@D500f
=SH06a/K00l?3`0@4100;2`/08f=S@1LG5`0Ti>C07MgM`0I6AT061PH04M7A`0U9BD09RHV02DU9@14
A4@0?clo02XZ:P0n?Sh0V9RH09nOW`1JFUX0A4A405=CD`2@T900IFEU04A4A01?Cdl0820P038b<P1N
GUh0J6QX0;6a/@2QXJ40B4Q805QHF00l?3`0:2PX01lO7`0j>SX0NGUi04m?C`0b<S80>CTi065QH@2J
VYX0R8R806QXJ018B4P0S8b<06e]K@1FEUH0<c<c02TY:@0g=cL0D51@05=CD`2e]KD0NWYj06QXJ01H
F5P0E5AD06m_K`2UYJD0MWIf01HF5P0301DE5@0b03/k>`1BDU80JFUY03De=@0];Bd09RHV01XJ6P0T
92@0>c/k07emO@2>SXh0[:b/05QHF01aLG40/K6a061PH015ADD092@T04];B`0n?Sh09bLW02<S8`1I
FET0YjNW0<K6aP2e]KD0Jf][05aLG01aLG40GEeM07]kN`2IVIT0UYJF09nOW`2ZZZX0/k>c08V9R@2@
T900I6AT06m_K`1iNGT0P8200;Ng]`1RHV80CDe=06e]K@3Bd]80cLg=09JFUP1eMGDDooooo`004ooo
ool0502=SHd0KVi^079bLP1;Bd/0MgMg04U9B@1PH600GUiN0492@P1[Jf/0AdM703`l?01lO7`0ADE5
059BDP1=CDd0BDU905MGE`1;Bd/0@d=30P1BDU800`1CDe<0GUiN04E5A@0205]KF`0=028R8P1DE5@0
KVi^02@T901XJ6P0JFUY03Hf=P1oOgl0EeMG04a<C01ADE40Bd];069RHP0204m?C`0j06ATI00e=CD0
A4A408N7Q`0^;Rh0Bd];08f=S@0g=cL0BTY:04m?C`0n?Sh0Bd];061PH014A4@0C4a<04Y:BP1JFUX0
DU9B05YJFP0h>3P0EUIF069RHP18B4P0ADE505UIF@1LG5`0CDe=05YJFP1HF5P0Hf=S04I6AP1fMWH0
Jf][04U9B@1^KVh0EUIF051@D023Ph<0BDU905EEE@1fMWH0>CTi04Y:BP1^KVh0>SXj05MGE`1IFET0
AdM704e=C@1MGEd0EEEE05IFEP1GEeL0GUiN061PH017AdL0G5aL06e]K@80EUIF02D0@41007emO@1T
I6@0CTi>06=SH`1ADE40MgMg04E5A@1RHV80U9BD04m?C`1ZJVX0Ng]k04M7A`1_Kfl0L71`04E5A@1L
G5`0Ogmo03/k>`1OGel0HV9R0410@01LG5`0KVi^04U9B@1WIfL0KFe]04=3@`1_Kfl0FEUI03Hf=P1A
DE40Cdm?02TY:@1YJFT0DE5A00kooooo01P0QHF504a<C01NGUh0C4a<05IFEP1WIfL0OGem08:2PP1P
H600@T9204I6AP19BDT0@41006ATI01ZJVX0EeMG05YJFP1VIVH0EEEE04=3@`16ATH0A4A404U9B@1>
CTh204E5A@1I03Ti>@1FEUH0<30`04e=C@1MGEd0De=C06IVIP1;Bd/0BTY:04e=C@16ATH0?Shn055A
D@1;Bd/0@T9204Y:BP12@T80>3Ph03hn?P10@400@T9203Xj>P1DE5@0DE5A0410@019BDT0G5aL05]K
F`1:BTX0HF5Q051@D01JFUX0FEUI04E5A@18B4P0C4a<08N7Q`13@d<0M7Ad06MWI`1=CDd0GemO059B
DP16ATH0@T92059BDP21PH40@D5104I6AP1HF5P0ADE504Y:BP1YJFT0B4Q804i>CP1@D500BDU904Q8
B01ADE40HF5Q04Q8B01IFET0De=C06e]K@1KFe/0Bd];05eMG@2<S8`0EeMG03Hf=P14A4@0B4Q804I6
AP1DE5@0D51@06ATI01ADE40?clo04Q8B01ADE40CDe=0410@01ADE40GEeM065QH@1?Cdl0DE5A04M7
A`10@4000P19BDT02@1HF5P0HF5Q05=CD`1;Bd/0BDU906UYJ@13@d<0D51@05ADE00204Y:BP0<061P
H01WIfL0ATI604m?C`0n?Sh0>CTi03lo?`1MGEd0J6QX05MGE`1EEED0Hf=S3_ooool06@1eMGD0CDe=
05YJFP1ZJVX0DU9B05YJFP1GEeL0>CTi04I6AP0d=3@0F5QH04i>CP0e=CD0;Rh^03dm?@13@d<0@D51
02`/;01UIFD0@D5103Ti>@1GEeL0I6AT05=CD`10@4000P1GEeL07`13@d<0EeMG04A4A016ATH0C4a<
03Lg=`1WIfL0Fe]K059BDP1;Bd/0?Shn06e]K@1UIFD0DE5A079bLP1SHf<0KVi^06ATI01MGEd0=cLg
05QHF016ATH0M7Ad04Y:BP1=CDd0AdM704Y:BP19BDT0MGEe06IVIP1GEeL00P1IFET0801hN7P0H61P
07IfMP1aLG40GUiN06MWI`18B4P0PX:204m?C`1ADE40RXZ:07=cL`13@d<0MWIf05EEE@1>CTh0GUiN
08R8R01bLW80MgMg09BDU01RHV80S8b<05iNGP2=SHd0IFEU05UIF@2IVIT0GemO06MWI`0i>CT0Fe]K
0P1XJ6P0:`12@T80GUiN07MgM`1XJ6P0CDe=05]KF`2JVYX0MWIf06i^KP1]KFd0UiNG05UIF@1WIfL0
T92@04M7A`1jNWX0GEeM04Q8B01XJ6P0G5aL071`L026QXH0E5AD06UYJ@1XJ6P0E5AD08V9R@1jNWX0
@41005YJFP15ADD0GEeM055AD@1PH600P82005IFEP1XJ6P0MgMg06IVIP10@400Ogmo0;^k^`1=CDd0
0P1ADE400`1dM7Coooooooooo`0<ooooo`0;065QH@0/;2`071`L01HF5P0D51@0ADE509JFUP1XJ6P0
;2`/01dM7@0E5AD00P0L71`0C`0[:b/0;Bd]03lo?`1/K6`0_Kfm0<C4a01LG5`0Bd];05ADE019BDT0
>CTi034a<@1XJ6P07QhN04];B`1nOWh0L71`075aL@1oOgl05ADE00d=3@1ADE4071`L014A4@0S8b<0
JVYZ0:^[Z`2FUYH0N7Qh07MgM`0b<S80HF5Q04a<C01ZJVX0=CDe05IFEP0[:b/092@T02h^;P27QhL0
/k>c09bLW01>CTh07QhN02<S8`0h>3P0<S8b04=3@`1VIVH0BTY:01`L700V9RH0Ng]k0:^[Z`1lO7`0
X:2P09VIV@2CTi<0LG5a06EUI@1:BTX0BDU907inOP2;Rh/0Hf=S07moO`19BDT0<C4a02l_;`0^;Rh0
@41006ATI01_Kfl07AdM01@D500E5AD07QhN051@D01LG5`00P1XJ6P0;P1PH600I6AT05EEE@0d=3@0
Cdm?09FEU@2c/k<0h^;R079bLP1TI6@0GUiN06IVIP1QHF40XZ:R051@D00M7Ad09BDU03Lg=`1<C4`0
P82009VIV@2CTi<0HV9R04U9B@1?Cdl0<S8b03`l?01/K6`0CDe=04U9B@1UIFD0M7Ad075aL@1eMGD0
Jf][0861P@1@D500H61P07QhN01iNGT0]kNg0:VYZ@2SXj<0U9BD0;Fe]@1[Jf/Dooooo`004oooool0
3028R8P0Kfm_07IfMP1eMGD0HV9R05MGE`1fMWH0Bd];05MGE`1_Kfl0AdM704E5A@80GemO02@0CTi>
03`l?01TI6@0ATI604m?C`1HF5P0Bd];05EEE@28R8P0DU9B04I6AP1LG5`0GEeM03De=@1HF5P0Fe]K
03lo?`1IFET0Hf=S05ADE01HF5P0CTi>06ATI00o?cl0F5QH069RHP14A4@0G5aL06IVIP14A4@0DE5A
06e]K@10@400Cdm?06][J`0j>SX204Y:BP0a069RHP19BDT0AdM706a/K016ATH0C4a<06QXJ015ADD0
JFUY059BDP0l?3`0IfMW04U9B@0l?3`0FEUI04m?C`10@400H61P069RHP1<C4`0GUiN06m_K`1CDe<0
Fe]K06ATI01;Bd/0B4Q807EeM@10@400F5QH07EeM@18B4P0E5AD065QH@1DE5@0GemO06IVIP1/K6`0
C4a<05YJFP1oOgl0DU9B05UIF@1oOgl0EUIF069RHP1NGUh0JVYZ06][J`0204m?C`0T08F5Q@1PH600
Jf][05MGE`1VIVH0H61P04=3@`1[Jf/0NWYj05ADE01kNg/0I6AT059BDP1jNWX0IVIV069RHP1IFET0
Lg=c05EEE@1WIfL0IFEU05eMG@1BDU80EEEE05UIF@1EEED0FEUI04U9B@1=CDd0G5aL04];B`1LG5`0
DU9B04Y:BP1FEUH0EeMG3_ooool02`1XJ6P0E5AD05MGE`1:BTX0D51@05IFEP1dM7@0FUYJ065QH@0f
=SH0=cLg0080Bd];06/0GemO06MWI`1DE5@0De=C06ATI01[Jf/0>SXj04E5A@17AdL0B4Q804M7A`0l
?3`0ADE5038b<P1@D500;Rh^0492@P1;Bd/0De=C06IVIP1@D500CDe=05eMG@1=CDd0@41004a<C018
B4P0@T9204E5A@0m?Cd0=CDe03Hf=P0h>3P0@D5103<c<`18B4P0BTY:03Xj>P0n?Sh0Fe]K055AD@16
ATH0GUiN04E5A@1?Cdl0CDe=04I6AP18B4P0IFEU08Z:RP1SHf<0K6a/069RHP1<C4`0DE5A04a<C01K
Fe/0ATI607=cL`2DU9@0GemO04E5A@1[Jf/0ADE504=3@`1NGUh0E5AD03hn?P1PH600?Cdm04=3@`1:
BTX0EUIF03<c<`1IFET0Bd];075aL@1GEeL0ATI6055AD@2DU9@0CDe=02h^;P0l?3`0Bd];04M7A`1Q
HF40HV9R06][J`1GEeL0BDU904m?C`1FEUH0D51@03`l?019BDT0LG5a061PH01MGEd0Bd];04i>CP0n
?Sh0@D5104M7A`1=CDd0BTY:03hn?P0204Q8B00B05aLG01?Cdl0E5AD04i>CP1PH600Cdm?06EUI@1O
Gel0FEUI05=CD`11@D40@T9204e=C@1UIFD0K6a/05MGE`1FEUH0Fe]K3_ooool0=`1aLG40ATI605YJ
FP1JFUX0@T92055AD@13@d<0?3`l04Q8B01;Bd/0DU9B05YJFP13@d<0:RXZ03Lg=`0l?3`0?clo02PX
:01OGel0?3`l03Xj>P1<C4`0EeMG04I6AP0c<c<0FUYJ04m?C`0g=cL0GEeM04U9B@0d=3@0G5aL038b
<P1IFET0De=C051@D01>CTh0@d=3065QH@1@D500EeMG07UiN@1PH600MGEe04m?C`1<C4`0B4Q805QH
F00a<C40MWIf04e=C@1@D500EeMG03lo?`1DE5@00P1WIfL0D`1KFe/0DE5A06ATI01XJ6P0DE5A07Mg
M`1LG5`0KFe]051@D01FEUH0SHf=04i>CP1OGel0Ogmo06UYJ@1:BTX0O7al04a<C01NGUh0FEUI07Qh
N01gMgL0IfMW08f=S@1WIfL0Shn?05ADE01kNg/0MGEe065QH@2SXj<0HV9R06YZJP0i>CT0Fe]K06EU
I@1bLW80@D5105eMG@1hN7P0F5QH059BDP1JFUX0VIVI07=cL`22PX80M7Ad08^;R`1:BTX0IFEU06a/
K01NGUh0R8R805IFEP11@D40Kfm_06ATI01JFUX0Ph>305YJFP1CDe<0EUIF06ATI02;Rh/0FUYJ04I6
AP1HF5P0BDU906IVIP1ADE40CDe=07UiN@0j>SX0MgMg06i^KP1NGUh0Cdm?071`L02YZJT0E5AD04i>
CP14A4@0Ogmo00kooooo02h0MgMg03/k>`0X:2P07QhN01LG5`0l?3`0PH6106=SH`11@D40410@014A
4@0E5AD051@D01`L700^;Rh0E5AD09jNWP2LW9`0Xj>S055AD@1?Cdl0FUYJ05UIF@1cLg<0Zj^[07in
OP0Y:BT0EUIF08n?S`0h>3P0Shn?07QhN01QHF40>CTi03Xj>P2f][H0GUiN05mOG`24Q8@0/k>c09VI
V@0O7al0<c<c01XJ6P1XJ6P0DU9B0P2;Rh/0900f=SH0;2`/04E5A@1KFe/0K6a/0861P@1lO7`0;2`/
03Ti>@0e=CD0;bl_06UYJ@1jNWX0E5AD09bLW01RHV80<S8b06YZJP2h^;P0YJFU08^;R`1:BTX0C4a<
06=SH`2_[jl0KVi^04e=C@1FEUH0UYJF09NGU`1bLW80ADE503Xj>P0N7Qh07alO02`/;080UiNG0180
EUIF024Q8@0S8b<08B4Q01dM7@1VIVH0/;2`028R8P0E5AD05QHF01hN7P17AdL0U9BD0:6QX@1=CDd0
O7al09BDU017AdL2069RHP0<055AD@16ATH0@d=303De=@0K6a/0@41007AdM027QhL0=CDe05eMG@0c
<c<08b<S0P0a<C40501CDe<0TY:B05UIF@1lO7`0Ph>306EUI@1OGel0JVYZ08:2PP18B4P0=cLg065Q
H@1RHV80ADE507moO`21PH40@D5103@d=01QHF40F5QH5?ooool001?ooooo00`0QhN705eMG@26QXH0
Hf=S05aLG01VIVH0I6AT05QHF01GEeL0FEUI05eMG@15ADD205=CD`0f0492@P1:BTX0IFEU03<c<`1?
Cdl0IVIV02`/;01=CDd0H61P0492@P1OGel0@d=304m?C`1>CTh0Cdm?051@D01FEUH0ADE506IVIP14
A4@0AdM707IfMP1_Kfl0>CTi06=SH`1dM7@0C4a<05iNGP1MGEd0CTi>05ADE01HF5P0G5aL05iNGP1C
De<0GEeM04m?C`1<C4`0GEeM02d];@1VIVH0HV9R02/[:`1_Kfl0K6a/02h^;P2GUiL0HV9R03@d=02<
S8`0BDU904A4A01iNGT0DE5A0P1NGUh01@1OGel0HF5Q0451@@1XJ6P0L71`0080GUiN0280KFe]03`l
?01UIFD0F5QH04Y:BP1UIFD0JFUY04i>CP1MGEd0PH61055AD@1YJFT0IfMW034a<@1HF5P0JVYZ051@
D01IFET0@d=306ATI01GEeL0?Shn07inOP1@D500Hf=S04m?C`1PH600MgMg04U9B@1<C4`0L71`04];
B`1HF5P0J6QX0P1ZJVX06P22PX80H61P06YZJP1OGel0GEeM06m_K`15ADD0MgMg06m_K`15ADD0FEUI
06ATI01:BTX0N7Qh06EUI@0f=SH0O7al04U9B@0d=3@0GemO06MWI`15ADD0IFEU03lo?`1ADE40Fe]K
3_ooool0S01dM7@0>c/k05eMG@1IFET0FUYJ071`L01jNWX0JFUY06MWI`1=CDd0?Cdm04i>CP1<C4`0
Ng]k06YZJP1VIVH0Fe]K071`L01MGEd0=CDe04=3@`0o?cl0A4A404U9B@14A4@0@D5102d];@1TI6@0
;2`/03Xj>P0n?Sh0C4a<05aLG01;Bd/0CDe=04M7A`1=CDd0CTi>05IFEP1=CDd0@d=304i>CP10@400
<S8b02`/;00l?3`0=SHf03`l?018B4P0@d=30410@00c<c<0EUIF055AD@14A4@0ADE505=CD`10@400
EUIF0451@@1FEUH0JFUY092@T01KFe/0NWYj07]kN`1ADE40EeMG0410@01DE5@0=SHf06YZJP1mOGd0
EeMG04I6AP1JFUX0A4A402`/;01`L700AdM704=3@`1@D500@d=305]KF`1[Jf/0F5QH04U9B@1ADE40
Fe]K06YZJP1DE5@0DU9B05ADE02IVIT0E5AD03<c<`12@T80CDe=04A4A01@D500GemO05iNGP19BDT0
;Rh^04M7A`11@D40B4Q80492@P14A4@0EeMG0410@018B4P0ATI603lo?`0g=cL0ADE50492@P1@D500
Fe]K04Y:BP13@d<0ATI604e=C@1BDU80B4Q805aLG01WIfL0H61P05QHF026QXH0GEeM059BDP14A4@0
ADE504I6AP1TI6@0GUiN061PH018B4P0CDe=3_ooool06`1[Jf/0ADE504e=C@1WIfL0@41004M7A`1I
FET0;bl_051@D00l?3`0Cdm?065QH@0m?Cd0=cLg03hn?P0i>CT0C4a<03@d=01@D500?3`l03dm?@1C
De<0@T920410@00b<S80AdM705ADE00205EEE@0H03dm?@1ADE40GUiN0492@P1WIfL0AdM705UIF@1R
HV80@d=30861P@18B4P0De=C096AT@1IFET0GEeM065QH@1EEED0>c/k04i>CP18B4P0IVIV04U9B@14
A4@0EeMG0P19BDT0201lO7`0MgMg061PH01@D500IVIV061PH01NGUh0Ogmo0P1_Kfl03@1LG5`0Jf][
09>CT`1BDU80GUiN07inOP1aLG40DE5A07alO01ADE40JFUY05aLG01SHf<00P1eMGD04P2DU9@0Ogmo
08j>SP1[Jf/0UiNG08V9R@1LG5`0YJFU06YZJP1VIVH0@d=306MWI`1cLg<0Ph>305aLG023Ph<0UIFE
05IFEP80GUiN02@0QHF5071`L01lO7`0IFEU09VIV@1MGEd0D51@06a/K01RHV80OGem05UIF@16ATH0
QhN705EEE@1XJ6P0Vi^K04Q8B01VIVH0MGEe05ADE023Ph<0Ng]k04A4A016ATH0@d=308:2PP19BDT0
E5AD07EeM@1GEeL0LG5a055AD@1SHf<0HV9R06EUI@2ATI42059BDP0304m?C`1nOWkooooo00gooooo
08`0Ng]k05YJFP0];Bd0>3Ph05YJFP0[:b/051@D03Lg=`1LG5`0>CTi010@400D51@06QXJ02TY:@0e
=CD0VIVI04E5A@1MGEd0LW9b05]KF`1BDU809bLW03Lg=`19BDT0Jf][0<W9b@1fMWH0GEeM07YjNP2L
W9`0KVi^04=3@`0l?3`0@D5105YJFP1HF5P0>SXj0410@015ADD0UIFE051@D02>SXh0Shn?04A4A00_
;bl0:BTY055AD@1hN7P0Bd];04Y:BP1XJ6P0LG5a09RHV01iNGT0/K6a065QH@0n?Sh0BDU903@d=00U
9BD0Hf=S09FEU@2FUYH0GemO02HV9P1XJ6P0Z:RX0:j^[P17AdL0>c/k01`L701MGEd0HF5Q07IfMP19
BDT0ADE50451@@2?Shl0^KVi03lo?`0H61P0AdM703`l?01dM7@0UiNG0;6a/@1DE5@0EEEE059BDP0g
=cL06a/K04e=C@2LW9`0IFEU02XZ:P0H61P071`L02h^;P2?Shl0P82002d];@14A4@0=CDe02l_;`1j
NWX0C4a<03De=@0Z:RX0GemO05YJFP1lO7`0OGem0820P02?Shl0:b/[05ADE00S8b<0<C4a04=3@`1]
KFd0Vi^K0<_;b`23Ph<0UIFE08J6QP0Z:RX0=cLg0:6QX@1kNg/0N7Qh069RHP1UIFD0L71`05aLG01/
K6`0DE5A04M7A`12@T80Fe]K05eMGACooooo003oooooooooooooP_ooool00001\
\>"],
  ImageRangeCache->{{{0, 639}, {73.375, 0}} -> {-0.126578, -0.0116304, \
0.00665596, 0.00665596}, {{19, 158.75}, {71.625, 1.6875}} -> {-43.5083, \
-4.07955, 2.28983, 2.28983}, {{172.75, 312.5}, {71.625, 1.6875}} -> \
{-395.569, -4.07955, 2.28983, 2.28983}, {{326.438, 466.188}, {71.625, \
1.6875}} -> {-747.487, -4.07955, 2.28983, 2.28983}, {{480.188, 619.938}, \
{71.625, 1.6875}} -> {-1099.55, -4.07955, 2.28983, 2.28983}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25227 
%%ImageSize: 640 161.455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00600649 0.238095 [
[ 0 0 0 0 ]
[ 1 .25227 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25227 L
0 .25227 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00600649 0.261905 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .59071 L
.2381 .59071 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .59071 L
.2381 .59071 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01189 L
.47619 .01189 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01189 L
.71429 .01189 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .02732 L
.95238 .02732 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .02732 L
.95238 .02732 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF0000FF0000
FF0000FF0000FF8000FF8000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF8000
FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF8000FF8000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF0000FF0000FF0000
FF0000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF8000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000FF8000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.261905 0.00600649 0.5 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01919 L
.2381 .01919 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01919 L
.2381 .01919 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .47349 L
.47619 .47349 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .47349 L
.47619 .47349 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .13328 L
.71429 .13328 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .13328 L
.71429 .13328 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01585 L
.95238 .01585 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF00FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF00
FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF80000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF80000000FF
FF00000000FF0000FF0000FF00FF00
FF80000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FFFF00000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
FF0000FF0000FF000000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00000000FF0000FF
0000FF0000FF00FF000000FF00FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF00FF00
0000FF0000FF00FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF00
00FF000000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF80000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF00
00FF000000FF00FF000000FF00FF0000FF0000FF000000FF00FF000000FF0000FF00FF00
FF000000FF000000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
00FF0000FF0000FF000000FF00FF000000FFFF8000FF8000FF00000000FF00FF000000FF
00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00FF00000000FF00FF000000FF
FF00000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
FF0000FF00000000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF00000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF00FF8000FF800000FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF00
FF00000000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF00FF000000FF00FF80000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
FF00000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF00FF000000FF0000FF000000FFFF0000FF80000000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FFFF0000FF0000FF00000000FF00FF000000FF
00FF000000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FFFF00000000FFFF00000000FF00FF000000FF
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
FF000000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FFFF00000000FF00FF0000FF00
00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF00FF00
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF00FF80000000FF00FF0000FF00
00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF00FF0000FF00
0000FF00FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF00FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF00FF00000000FF0000FF00FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF0000FF00FF0000FF000000FF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
00FF0000FF000000FF00FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF00FF000000FFFF8000FF80000000FF0000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FFFF000000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF00FF800000FF000000FF0000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF000000FF00FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FFFF8000FF000000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00000000FFFF800000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00600649 0.738095 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .09907 L
.47619 .09907 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .09907 L
.47619 .09907 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .51082 L
.71429 .51082 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .51082 L
.71429 .51082 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .01668 L
.95238 .01668 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF00FF000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF0000FF00000000FF
FF000000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF00000000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF0000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF000000FF00FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF000000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF00FF0000FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF00FF0000FF0000FF000000FF00FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF00FF000000FF0000FF00FF00
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF00000000FF00FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF0000FF0000FFFF0000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF000000FF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF000000FF00FF000000FF00FF0000FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF000000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF
00FF0000FF0000FF000000FF0000FF00FF0000FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF000000FF00FF0000FF00
0000FF00FF000000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF000000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF
00FF000000FF00FF000000FF0000FF00FF000000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF00
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF00FF0000FF0000FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF000000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF
0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF
00FF000000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
00FF000000FF00FF0000FF000000FF0000FF00FF0000FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
00FF000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF000000FF0000FF
0000FF00FF000000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.738095 0.00600649 0.97619 0.246266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.024026 0.952381 [
[ 0 0 0 0 ]
[ 1 1.00909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00909 L
0 1.00909 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.024026 0.97619 0.481664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0118853 0.00594263 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13074 m
1 .13074 L
s
0 .24959 m
1 .24959 L
s
0 .36844 m
1 .36844 L
s
0 .4873 m
1 .4873 L
s
0 g
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
F
.5 Mabswid
.04762 .01189 m
.04762 .01522 L
.2381 .01522 L
.2381 .01189 L
.04762 .01189 L
s
0 1 0 r
.28571 .01189 m
.28571 .01522 L
.47619 .01522 L
.47619 .01189 L
F
.28571 .01189 m
.28571 .01522 L
.47619 .01522 L
.47619 .01189 L
.28571 .01189 L
s
0 0 1 r
.52381 .01189 m
.52381 .01314 L
.71429 .01314 L
.71429 .01189 L
F
.52381 .01189 m
.52381 .01314 L
.71429 .01314 L
.71429 .01189 L
.52381 .01189 L
s
1 .5 0 r
.7619 .01189 m
.7619 .59822 L
.95238 .59822 L
.95238 .01189 L
F
.7619 .01189 m
.7619 .59822 L
.95238 .59822 L
.95238 .01189 L
.7619 .01189 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.527427 0.97619 0.985065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0123686 0.0114409 0.0123686 [
[ 0 0 0 0 ]
[ 1 .48052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48052 L
0 .48052 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01144 translate
.95238 .45764 scale
231 string
77 37 8 [77 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF0000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF0000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000
FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
0000FF00FF0000FF00FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF000000FFFF8000
FF8000FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF0000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{640, 161.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00000XB000`400?l00000o`00003ooooooooo
oooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo
003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003ooooooooo
ooooP_ooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`001OoooolFo`3o00Cooooo5ol00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo5_oo0004oooooaOo0?l01?oo
oolFo`00o`Gooooo5_ooO`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oolFool000Gooooo5_l0o`04oooooaOo003o1?oooolFoomo00Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02oooooaOoo`001?oooolFo`3o00Gooooo5_l00?l4oooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00>_oooolG
oomo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooooaKoo`001?oooolG
o`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolF
o`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolG
oomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool0
03[ooooo5oooO`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o
00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o
00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo
00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo
000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000
ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
oooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
oooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooo
oaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooo
oaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo5_l0o`04oooo
oaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04oooo
o`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo5_l00?lOooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07OoooolFo`3o00Cooooo5ol00?lOooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0MoooooaOo0?l01?oooolFo`00oaoooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0MoooooaKo0?l01?oooolGo`00oaoooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo5_l0o`04oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooo
oooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolG
o`3o00Cooooo5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`04oooooaKo003o7oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Co
oooo00?o0000o`00Ool007l00_l007lFool005Go001o00?o0000ooooooooool09?ooool00ol0003o
001oo`00O`0Mo`00OaOo0?l01?l007lFo`00oaoo001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0go`00OaOo003o7ol007l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o05;o
001o5oooO`04o`00O`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo
5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07OoooolGo`3o00Cooooo
5_l00?lOooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooo
ooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02
oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0i
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Boooo
oaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKo
o`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`00
9?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool0
0ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
ooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01go
oooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0
o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooooooo
o`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o001oo`00O`02o`00
OaKoo`00EOl007l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o01go001o5ol0o`0io`00
O`03o`000?oooooooooo02Gooooo00?o0000o`00Ool007l0=ol007lGo`00oaoo001o00?o0000oooo
ooooool09?ooool00ol0003o001oo`00O`1Bo`00OaOoogl01?l007l00ol0003oooooooooo`0Soooo
o`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOo
ogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00
EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooo
oolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0
003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00
oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0
003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooo
ooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo
5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooo
ooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02
oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0i
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0S
ooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Boooo
oaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKo
o`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`00
9?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl0
1?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o001oo`00O`02o`00OaKoo`00EOl0
07l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o01go001o5ol0o`0io`00O`03o`000?oo
oooooooo02Gooooo00?o0000o`00Ool007l0=ol007lGo`00oaoo001o00?o0000ooooooooool09?oo
ool00ol0003o001oo`00O`1Bo`00OaOoogl01?l007l00ol0003oooooooooo`0Sooooo`009?ooool0
0ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolG
o`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool0
0ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003o
ooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01go
oooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003ooooooooo
o`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0
o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooooooo
o`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1B
oooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooo
oaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0ioooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Soooo
o`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOo
ogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00
EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooo
oolGo`00oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?oo
ool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo5ol0o`0iooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0
003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01gooooo5ol0o`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00
oaoooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0
003oooooooooo`0Sooooo`009?ooool00ol0003o001oo`00O`02o`00OaKoo`00EOl007l00ol0003o
ooooooooo`0Tooooo`03o`000?l007oo001o06go001o00?o0000ooooooooool09Oooool00ol0003o
001oo`00O`0go`00OaOo003o7ol007l00ol0003oooooooooo`0Tooooo`03o`000?l007oo001o05;o
001o5oooO`04o`00O`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo
5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Oooooo5ol00?lOooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o
0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolGo`00oaoooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003ooooooooo
o`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0g
oooooaOo003o7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04
ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Boooo
oaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKo
o`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0
0_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oo
oooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003oooooooooo`0Sooooo`009?ooool0
0ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo00?o0000ooooooooool08oooool0
02Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04ooooo`03o`000?oooooooooo
02?ooooo000Tooooo`03o`000?oooooooooo00;ooooo5_oo001Eooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1BoooooaOoogl01?ooool00ol0003o
ooooooooo`0Sooooo`009?ooool00ol0003oooooooooo`02oooooaKoo`00EOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oooolGoomo00Cooooo
00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool00_oooolFool005Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5ooo
O`04ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo5oooO`04
ooooo`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool08oooool002CoooooLOl0000Vooooog7o00009ooooomao`0002KoooooLOl0000Uooooo`00
oooooooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooo
oh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo003o
ooooooooooooP_ooool001OoooooDP3o00060?n001T0o`000P3oP0070?l00080oh0000<0o`000?n0
003oP0002@3o00020?n000kooooo0P3o0010003o0080003o2P00o`020000o`D00?l010000?l<003o
0080003o1`00o`060000o`D00?l00P3o000<0000o`800?l03_ooool20000o`800?l000<0003o003o
0000o`000P00o`020000o`03003o00000?l0003o02H0003o00<00?l00000o`000?l04P000?l2003o
03h0003o3_ooooma0?n00080o`002@3oP0000`3o0000oh000?n0000;0?n001Wooooo000Goooooe80
o`001P3oP00I0?l00080oh001`3o00020?n000030?l0003oP000oh0000T0o`000P3oP00>ooooo`80
o`00@000o`020000o`X00?l00P000?l5003o00@0003o3000o`020000o`L00?l01P000?l5003o0080
o`0030000?l2003o00kooooo0P000?l2003o00030000o`00o`000?l000800?l00P000?l00`00o`00
003o0000o`0V0000o`03003o00000?l0003o0180003o0P00o`0n0000o`koooooL@3oP0020?l000T0
oh0000<0o`000?n0003oP0002`3oP00Iooooo`005ooooolV0?l000030?n0003o0000o`0000d0o`00
0P3oP00J0?l000H0oh00903o00000`3oP000o`000?l000060?l000D0oh003_ooool20?n00080003o
8000o`030?n00080003o9`00o`020000o`h00?l00P3oP00G003o00@0o`0000<0oh000000o`000?l0
0P3o00050000o`800?l03_ooool20000o`X00?l010000?l2003o0280003o2000o`0=0000o`800?l0
:@000?l00`00o`00003o0000o`0B0000o`koooooRP3oP00Iooooo`005ooooolV0?l000030?n0003o
0000o`0000d0o`000P3oP00J0?l000H0oh00903o00000`3oP000o`000?l000060?l000D0oh003_oo
ool20?n00080003o8000o`030?n00080003o9`00o`020000o`h00?l00P3oP00G003o00@0o`0000<0
oh000000o`000?l00P3o00050000o`800?l03_ooool20000o`X00?l010000?l2003o0280003o2000
o`0=0000o`800?l0:@000?l00`00o`00003o0000o`0B0000o`koooooRP3oP00Iooooo`005ooooolV
0?l000030?n0003o0000o`0002T0o`00103oP00R0?l000D0oh00203o00050?n000kooooo0P3oP002
0000oa400?l00P000?l9003o0080003o0P00o`000`000?l0o`000?l000020000oaD00?l00P000?l5
0?l000P00?l000<0003o003o0000o`003@00o`000`000?l00?l0003o000I003o00@0o`001`000?l0
0`00o`00003o0000o`02003o00kooooo0P000?l2003o00030000o`00o`000?l000@0003o00<00?l0
0000o`000?l0:@000?l2003o0500003o3_oooom40?n000@0o`002@3oP0000`000?l0oh000?n0000f
0?n001Wooooo000Goooooe40o`0000<0oh000?l0003o0000803o00020?n00100o`00103oP00>oooo
o`@0003o8000o`000`000?l00?l0003o000@003o0080003o1`00o`020000o`T00?l00P000?lC003o
0080003o3000o`020000o`T00?l01@000?l2003o00@0003o1@00o`0>ooooo`D0003o1000o`020000
o`03003o00000?l0003o02H0003o00<00?l00000o`000?l00P00o`1@0000o`koooooRP3oP00Ioooo
o`005ooooomA0?l000030?n0003o0000o`000200o`000P3oP00@0?l000@0oh003_ooool40000ob00
0?l000<0003o003o0000o`004000o`020000o`L00?l00P000?l9003o0080003o4`00o`020000o``0
0?l00P000?l9003o00D0003o0P00o`040000o`D00?l03_ooool50000o`@00?l00P000?l00`00o`00
003o0000o`0V0000o`03003o00000?l0003o00800?l0D0000?l>ooooohX0oh006Oooool001Oooooo
0P3oP0100?l00080oh003P3o00040?n000D0o`000P3oP00G0?l00080oh000P3o00020?n00100o`00
3_ooool40000ob000?l000<0003o003o0000o`003P00o`020000o`800?l02`000?l00`00o`00003o
0000o`040000o`<00?l010000?l9003o0080003o1@00o`070000o`@00?l01`000?l00`00o`00003o
0000o`06003o00X0003o0P00o`0>ooooo`@0003o2000o`0I0000o`80o`003@000?l00`00o`00003o
0000o`0G0000o`80oh00103o00000`000?l0o`000?l00004003o01X0003o0P00o`060000o`030?l0
00000?l0003o00T0003o3_oooon:0?n001Wooooo000Gooooo`80oh00@03o00020?n000h0o`00103o
P0050?l00080oh005`3o00020?n00080o`000P3oP00@0?l000kooooo10000?lP003o00030000o`00
o`000?l000h00?l00P000?l2003o00/0003o00<00?l00000o`000?l010000?l3003o00@0003o2@00
o`020000o`D00?l01`000?l4003o00L0003o00<00?l00000o`000?l01P00o`0:0000o`800?l03_oo
ool40000o`P00?l06@000?l20?l000d0003o00<00?l00000o`000?l05`000?l20?n000@0o`0000<0
003o0?l0003o00001000o`0J0000o`800?l01P000?l00`3o0000003o0000o`090000o`koooooRP3o
P00Iooooo`005ooooomc0?l000L0oh00403o000>ooooob@00?l000<0003o003o0000o`005000o`0G
0000o`<00?l02@000?l4003o00<0003o2000o`030000o`L00?l00P000?l2003o00<0003o0P00o`07
0000o`800?l03_ooool40000o`03003o00000?l0003o00800?l00P000?l3003o02H0003o00<00?l0
0000o`000?l050000?l50?n00080o`001`000?l2003o01L0003o1`00o`0@0000o`koooooB03oP000
0`3o0000oh000?n0000o0?n001Wooooo000Gooooog<0o`001`3oP00@0?l000kooooo9000o`000`00
0?l00?l0003o000D003o01L0003o0`00o`090000o`@00?l00`000?l8003o00<0003o1`00o`020000
o`800?l00`000?l2003o00L0003o0P00o`0>ooooo`@0003o00<00?l00000o`000?l00P00o`020000
o`<00?l09P000?l00`00o`00003o0000o`0D0000o`D0oh000P3o00070000o`800?l05`000?l7003o
0100003o3_oooom80?n000030?l0003oP000oh0003l0oh006Oooool001OoooooD@3o00000`3oP000
o`000?l0000P0?l00080oh00503o000>ooooob@00?l000<0oh000000o`000?l00P00o`020000oa40
0?l020000?l5003o00T0003o0P00o`070000o`<00?l00P000?l2003o0080003o0`00o`020000o`@0
0?l000<0003o003o0000o`000P000?l5003o0080003o0P00o`030000o`800?l00P3o0002003o00D0
003o3_ooool40000o`X00?l090000?l3003o01P0003o0`3oP0020?l00080oh00=@000?l>ooooohX0
oh006Oooool001OoooooQ@3o00000`3oP000o`000?l000020?l000kooooo5@00o`040000ob<00?l0
1P000?l3003o0080003o0P00o`0B0000o`T00?l000<0003o003o0000o`000P000?l4003o00030000
o`00o`000?l000L00?l010000?l5003o00T0003o3_ooool40000o`D00?l00P000?l3003o0080003o
1000o`000`000?l00?l0003o0002003o01L0003o1000o`000`000?l00?l0003o0002003o0180003o
1`3oP00I0000o`800?l02P000?l20?n00100003o3_oooon:0?n001Wooooo000GooooohD0o`0000<0
oh000?l0003o00000P3o000>oooooaD00?l010000?lS003o00H0003o0`00o`020000o`800?l04P00
0?l9003o00030000o`00o`000?l00080003o1000o`000`000?l00?l0003o0007003o00@0003o1@00
o`090000o`kooooo10000?l5003o0080003o0`00o`020000o`@00?l000<0003o003o0000o`000P00
o`0G0000o`@00?l000<0003o003o0000o`000P00o`0B0000o`L0oh006@000?l2003o00X0003o0P3o
P00@0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo9`00o`040000oa000?l01`000?l3
003o0080003o0P00o`0B0000ob000?l00P000?l3003o00L0003o0P00o`0>ooooo`80003o0P00o`00
0`000?l00?l0003o0004003o00L0003o0P00o`0L0000o`800?l070000?l20?n00080003o0P3o000Q
0000o`800?l04P000?l>oooooc80oh000P00o`1F0?n001Wooooo000GooooohX0o`003_oooolW003o
00@0003o4000o`070000o`<00?l00P000?l2003o0180003o8000o`020000o`<00?l01`000?l2003o
00kooooo0P000?l2003o00030000o`00o`000?l000@00?l01`000?l2003o01`0003o0P00o`0L0000
o`80oh000P000?l20?l00240003o0P00o`0B0000o`kooooo<P3oP002003o05H0oh006Oooool001Oo
oooo>`3o00020?n00100o`000P3oP00f0?l000030?n0003o0000o`000080oh003_oooolT003o0003
0000o`00o`000?l001800?l00P000?l3003o0080003o1@00o`020000o`800?l00P000?l30?n00080
o`000P000?l2003o00030000o`00o`000?l00080003o7P00o`020000o`800?l00P000?l3003o00L0
003o0P00o`0>ooooo`80003o2P00o`090000o`@00?l0=0000?l30?n00080003o0P3o000P0000o`03
003o00000?l0003o00T0003o1000o`050000o`kooooo5`3oP0020?l00740oh006Oooool001Oooooo
>`3o00020?n00100o`000P3oP00f0?l000030?n0003o0000o`000080oh003_oooolT003o00030000
o`00o`000?l001800?l00P000?l3003o0080003o1@00o`020000o`800?l00P000?l30?n00080o`00
0P000?l2003o00030000o`00o`000?l00080003o7P00o`020000o`800?l00P000?l3003o00L0003o
0P00o`0>ooooo`80003o2P00o`090000o`@00?l0=0000?l30?n00080003o0P3o000P0000o`03003o
00000?l0003o00T0003o1000o`050000o`kooooo5`3oP0020?l00740oh006Oooool001OoooooC@3o
00020?n003/0o`003_oooolT003o00030000o`00o`000?l002800?l010000?l00`00o`00o`000?l0
00020000o`800?l000<0003o0?l0003o00000P000?lG003o0080003o2`00o`030000o`@0o`000`00
0?l2003o00kooooo10000?l5003o00h0003o1000o`0E0000o`D00?l01`000?l2003o03@0003o0`00
o`020000o`800?l040000?l>oooooaT0oh000P00o`1_0?n001Wooooo000Gooooodd0o`000P3oP00k
0?l000kooooo9000o`000`000?l00?l0003o000R003o00@0003o00<00?l00?l0003o00000P000?l2
003o00030000o`3o0000o`000080003o5`00o`020000o`/00?l00`000?l40?l000<0003o0P00o`0>
ooooo`@0003o1@00o`0>0000o`@00?l05@000?l5003o00L0003o0P00o`0d0000o`<00?l00P000?l2
003o0100003o3_oooolI0?n000800?l0K`3oP00Iooooo`005ooooom=0?l00080oh00>`3o000>oooo
ocT00?l00P3o00070000o`T00?l00`3oP007003o0080o`008000o`020000o`@00?l000<0003o003o
0000o`000P3o00050000o`800?l03_ooool90000o`L00?l02@000?l3003o01/0003o0P00o`020000
o`D00?l0=0000?l00`00o`00003o0000o`02003o00L0003o0P00o`070000o`koooooRP3oP00Ioooo
o`005ooooom=0?l00080oh00>`3o000>ooooobT00?l00P000?lE003o0080003o2@00o`020?l00003
003o003oP000oh000080003o7000o`020000o`T00?l00P000?l3003o0080003o0P3o00070000o`ko
oooo10000?l5003o0080003o0`00o`020000o`@00?l01`000?l00`00o`00003o0000o`0F0000o`03
003o00000?l0003o00@0003o00<00?l00000o`000?l00P00o`190000o`koooooRP3oP00Iooooo`00
5ooooom=0?l00080oh00>`3o000>ooooobT00?l00P000?lE003o0080003o2@00o`020?l00003003o
003oP000oh000080003o7000o`020000o`T00?l00P000?l3003o0080003o0P3o00070000o`kooooo
10000?l5003o0080003o0`00o`020000o`@00?l01`000?l00`00o`00003o0000o`0F0000o`03003o
00000?l0003o00@0003o00<00?l00000o`000?l00P00o`190000o`koooooRP3oP00Iooooo`005ooo
oom=0?l00080oh00>`3o000>oooooc/00?l000<0003o003o0000o`000P000?l5003o0080o`001000
o`020000o`030?l0003oP000oh000080003o2@00o`020000oa400?l00P000?l=003o00X0003o0P00
o`0>ooooo`@0003o00<00?l00000o`000?l00P00o`020000o`<00?l00P000?l4003o00L0003o00<0
0?l00000o`000?l07@000?l3003o04/0003o3_oooon:0?n001Wooooo000Gooooodd0o`000P3oP00k
0?l000kooooo>`00o`000`000?l00?l0003o00020000o`D00?l00P3o0004003o0080003o00<0o`00
0?n0003oP0000P000?l9003o0080003o4@00o`020000o`d00?l02P000?l2003o00kooooo10000?l0
0`00o`00003o0000o`02003o0080003o0`00o`020000o`@00?l01`000?l00`00o`00003o0000o`0M
0000o`<00?l0B`000?l>ooooohX0oh006Oooool001OoooooQ@3o00000`3oP000o`000?l000020?l0
00kooooo>`00o`070000o`L00?l00P000?l50?l00080003o0P00o`000`000?l00?l0003o00020000
o`D00?l00P000?lK003o00X0003o1000o`0>ooooo``0003o0P00o`090000o`800?l06@000?l2003o
00<0003o0P00o`020000o`03003o00000?l0003o04/0003o3_oooon:0?n001Wooooo000GooooohD0
o`0000<0oh000?l0003o00000P3o000>oooooc/00?l01`000?l7003o0080003o1@3o00020000o`80
0?l000<0003o003o0000o`000P000?l5003o0080003o6`00o`0:0000o`@00?l03_ooool<0000o`80
0?l02@000?l2003o01T0003o0P00o`030000o`800?l00P000?l00`00o`00003o0000o`1;0000o`ko
ooooRP3oP00Iooooo`005ooooolm0?l00080oh00AP3o00000`3oP000o`000?l000020?l000kooooo
?000o`040000o`L00?l010000?l20?l000030000o`3o0000o`000080003o0P00o`000`000?l00?l0
003o0004003o0080003o7P00o`090000o`<00?l00P000?l>ooooo`80003o0P00o`080000o`800?l0
90000?l2003o00030000o`00o`000?l000D00?l0<@000?l00`00o`00003o0000o`0I0000o`kooooo
MP3oP0020?l00180oh006Oooool001Oooooo?@3o00020?n004H0o`0000<0oh000?l0003o00000P3o
000>oooooc`00?l010000?l7003o00@0003o0P3o00000`000?l0o`000?l000020000o`800?l000<0
003o003o0000o`001000o`020000oah00?l02@000?l3003o0080003o3_ooool20000o`800?l02000
0?l2003o02@0003o0P00o`000`000?l00?l0003o0005003o0340003o00<00?l00000o`000?l06@00
0?l>ooooogH0oh000P3o000B0?n001Wooooo000Goooooe@0o`000P3oP00d0?l000kooooo=@00o`02
0000o`800?l02`000?l00`00o`00003o0000o`06003o0100003o2000o`040000o`@00?l00`000?l;
003o00D0003o0P3o0007003o00kooooo10000?l3003o02h0003o1000o`0n0000o`800?l040000?l>
oooood@0oh000P000?m40?n001Wooooo000GooooohX0o`003_oooolP003o00@0003o4000o`030000
o`800?l01`000?l7003o00L0003o0P3o00020000o`D00?l00P000?l2003o00<0003o2@00o`020000
o`800?l00P000?lL003o00kooooo9`000?l2003o00h0003o0P00o`150000o`80oh002@000?l>oooo
oe/0oh000P3o000K0?n00080o`001@3oP0020?l000T0oh006Oooool001OoooooRP3o000>ooooob00
0?l010000?l@003o00<0003o0P00o`070000o`L00?l01`000?l20?l00080003o1@00o`020000o`80
0?l00`000?l9003o0080003o0P00o`020000oa`00?l03_oooolW0000o`800?l03P000?l2003o04D0
003o0P3oP0090000o`koooooF`3oP0020?l001/0oh000P3o00050?n00080o`002@3oP00Iooooo`00
5ooooon:0?l000kooooo=000o`000`000?l00?l0003o0002003o00T0003o1`00o`090000oaT00?l0
0P000?lA003o00@0003o1`00o`0>ooooo`800?l00P000?l5003o00T0003o0`00o`0O0000o`D00?l0
5@000?l40?n000<0003o0P00o`0b0000o`koooooO03oP005003o00T0oh006Oooool001OoooooRP3o
000>oooooc@00?l000<0003o003o0000o`000P00o`090000o`L00?l02@000?lI003o0080003o4@00
o`040000o`L00?l03_ooool2003o0080003o1@00o`090000o`<00?l07`000?l5003o01D0003o103o
P0030000o`800?l0<P000?l>ooooog`0oh001@00o`090?n001Wooooo000GooooohX0o`003_oooolN
003o0080003o0P00o`020000oa000?l00`000?l2003o00/0003o1`00o`070000o`T00?l00P000?l8
003o00@0003o0P00o`020000oa400?l01P000?l5003o00kooooo0P00o`030000o`H00?l000<0003o
003o0000o`000P00o`020000o`<00?l00P000?l2003o0180003o00<0o`000000o`000?l02@000?l2
003o00`0003o0P3oP00b0000o`800?l03P000?l>ooooo`80oh000P3o00260?n001Wooooo000Goooo
ohX0o`003_oooolN003o0080003o0P00o`020000oa000?l00`000?l2003o00/0003o1`00o`070000
o`T00?l00P000?l8003o00@0003o0P00o`020000oa400?l01P000?l5003o00kooooo0P00o`030000
o`H00?l000<0003o003o0000o`000P00o`020000o`<00?l00P000?l2003o0180003o00<0o`000000
o`000?l02@000?l2003o00`0003o0P3oP00b0000o`800?l03P000?l>ooooo`80oh000P3o00260?n0
01Wooooo000Gooooob80o`000P3oP00U0?l00080oh00?`3o000>ooooob800?l00P000?l>003o00D0
003o1000o`090000o`L00?l01`000?l2003o00030000o`00o`000?l003800?l03_ooool50000o`@0
0?l01@000?l2003o00@0003o00<00?l00000o`000?l04P000?l30?n00080003o0P3o00020000o`<0
0?l00P000?l2003o0180003o0P3o00050000o`80o`0000<0oh000000o`000?l0<P000?l>ooooo`80
003o0`00o`060?n00080o`00A03oP0000`00o`00oh000?n0000[0?n000800?l00P000?l70?n001Wo
oooo000Gooooo`L0o`000P3oP0100?l00080oh004P3o00020?n002/0o`003_oooolR003o0080003o
4000o`000`000?l00?l0003o0002003o00`0003o0P00o`020000o`800?l00P000?l00`00o`00003o
0000o`050000o`800?l00P000?l2003o00<0003o7@00o`020000o``00?l03_ooool2003o0080003o
1`00o`030000o`800?l01`000?l2003o01T0003o1`00o`020000o`<00?l0;@000?l2003o01`0003o
3_oooomo0?n000@00?l01`3oP00Iooooo`005oooool70?l00080oh00@03o00020?n00180o`000P3o
P00[0?l000kooooo8P00o`020000oa000?l000<0003o003o0000o`000P00o`0<0000o`800?l00P00
0?l2003o0080003o00<00?l00000o`000?l01@000?l2003o0080003o0P00o`030000oad00?l00P00
0?l<003o00kooooo0P00o`020000o`L00?l00`000?l2003o00L0003o0P00o`0I0000o`L00?l00P00
0?l3003o02d0003o0P00o`0L0000o`koooooO`3oP004003o00L0oh006Oooool001OoooooF`3o0002
0?n002P0o`0000<0oh000?l0003o00000P3o000>ooooob000?l010000?l@003o00030000o`00o`00
0?l000@00?l02@000?l3003o0080003o0P00o`020000o`<00?l00P000?l3003o00H0003o7P00o`02
0000o`800?l000<0003o003o0000o`0010000?l5003o00kooooo0P00o`0<0000o`800?l02@000?l2
003o0100003o00<0oh000000o`000?l01P000?l:003o00l0003o0`3o000M0000o`03003o00000?l0
003o00T0003o1000o`0<0000o`koooooRP3oP00Iooooo`005ooooomK0?l00080oh00:03o00000`3o
P000o`000?l000020?l000kooooo8000o`040000oa000?l000<0003o003o0000o`001000o`090000
o`<00?l00P000?l2003o0080003o0`00o`020000o`<00?l01P000?lN003o0080003o0P00o`000`00
0?l00?l0003o00040000o`D00?l03_ooool2003o00`0003o0P00o`090000o`800?l040000?l00`3o
P000003o0000o`060000o`X00?l03`000?l30?l001d0003o00<00?l00000o`000?l02@000?l4003o
00`0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolP003o0080003o4`00o`020000o`L0
0?l010000?l9003o0080003o00<00?l00?n0003oP0000P000?l5003o00@0003o8000o`070000o`L0
0?l03_ooool50000o`L00?l02`000?l4003o00<0003o0P00o`0B0000o`<00?l00P000?l7003o01@0
003o0P3o000e0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo8000o`020000oa<00?l0
0P000?l7003o00@0003o2@00o`020000o`03003o003oP000oh000080003o1@00o`040000ob000?l0
1`000?l7003o00kooooo1@000?l7003o00/0003o1000o`030000o`800?l04P000?l3003o0080003o
1`00o`0D0000o`80o`00=@000?l>ooooohX0oh006Oooool001Oooooo?@3o00020?n004/0o`003_oo
oom0003o0080003o2@00o`020000o`03003o00000?l0003o0080003o0`00o`020000o`800?l00P00
0?lL003o0080003o0P00o`020000o`<00?l00P000?l7003o00kooooo0P000?l9003o00030000o`00
o`000?l000/0003o1`00o`020000o`800?l04`000?l7003o01/0003o0P00o`0J0000o`800?l04P00
0?l>ooooohX0oh006Oooool001Oooooo?@3o00020?n004/0o`003_oooom0003o0080003o2@00o`02
0000o`03003o00000?l0003o0080003o0`00o`020000o`800?l00P000?lL003o0080003o0P00o`02
0000o`<00?l00P000?l7003o00kooooo0P000?l9003o00030000o`00o`000?l000/0003o1`00o`02
0000o`800?l04`000?l7003o01/0003o0P00o`0J0000o`800?l04P000?l>ooooohX0oh006Oooool0
01OoooooRP3o000>ooooocT00?l00P000?l@003o00L0003o1`00o`020000ob000?l01@000?l2003o
00<0003o1000o`0>ooooo`@0003o00<00?l00000o`000?l01000o`090000oa000?l030000?l4003o
00030000o`00o`000?l000L00?l0=`000?l2003o0180003o3_oooolM0?n000030?l0003oP000oh00
06X0oh006Oooool001OoooooG`3o00020?n002T0o`003_oooolP003o0080003o6P00o`020000o`/0
0?l00P000?l2003o00030?l000000?l0003o0080003o2@00o`020000oaX00?l00P000?l2003o0080
003o00<00?l00000o`000?l02@00o`0>ooooo`L0003o1@00o`020000o`h00?l00P000?l2003o0080
003o0`00o`0=0000o``00?l07`000?l00`00o`00003o0000o`020000o`D00?l01P000?l00`00o`00
003o0000o`0I0000o`kooooo403oP002003o0080003o1`3oP0020?l006d0oh006Oooool001Oooooo
G`3o00020?n002T0o`003_oooolP003o0080003o6P00o`020000o`/00?l00P000?l2003o00030?l0
00000?l0003o0080003o2@00o`020000oaX00?l00P000?l2003o0080003o00<00?l00000o`000?l0
2@00o`0>ooooo`L0003o1@00o`020000o`h00?l00P000?l2003o0080003o0`00o`0=0000o``00?l0
7`000?l00`00o`00003o0000o`020000o`D00?l01P000?l00`00o`00003o0000o`0I0000o`kooooo
403oP002003o0080003o1`3oP0020?l006d0oh006Oooool001OoooooP`3o00020?n000D0o`003_oo
oolK003o00030000o`00o`000?l001@00?l00P000?l7003o00L0003o0P00o`000`000?l00?l0003o
00060000o`<00?l00P000?lB003o00030000o`00o`000?l001000?l02`000?l7003o00kooooo1000
0?l3003o0080003o4P00o`050000o`@00?l03P000?l<003o00/0003o0P00o`0@0000o`<00?l03@00
0?l2003o01`0003o3_ooool40?n00003003o003oP000oh0008<0oh006Oooool001OoooooP`3o0002
0?n000D0o`003_oooolK003o00030000o`00o`000?l001@00?l00P000?l7003o00L0003o0P00o`00
0`000?l00?l0003o00060000o`<00?l00P000?lB003o00030000o`00o`000?l001000?l02`000?l7
003o00kooooo10000?l3003o0080003o4P00o`050000o`@00?l03P000?l<003o00/0003o0P00o`0@
0000o`<00?l03@000?l2003o01`0003o3_ooool40?n00003003o003oP000oh0008<0oh006Oooool0
01OoooooO`3o00020?n00080o`000P3oP0050?l000kooooo?000o`080000o`<00?l01`000?l=003o
00<0003o0P00o`050000o`800?l00P000?lB003o00T0003o1@00o`0>ooooo`T0003o1`00o`020000
o`800?l000<0003o003o0000o`001000o`030000o`H00?l040000?l7003o00030000o`00o`000?l0
01d0003o0P00o`0>0000o`800?l070000?l>ooooodP0oh0000<0003o0?n0003oP000?`3oP00Ioooo
o`005ooooomo0?l00080oh000P3o00020?n000D0o`003_ooooll003o00P0003o0`00o`070000o`d0
0?l00`000?l2003o00D0003o0P00o`020000oa800?l02@000?l5003o00kooooo2@000?l7003o0080
003o0P00o`000`000?l00?l0003o0004003o00<0003o1P00o`0@0000o`L00?l000<0003o003o0000
o`007@000?l2003o00h0003o0P00o`0L0000o`koooooB03oP0000`000?l0oh000?n0000o0?n001Wo
oooo000GooooogX0o`000P3oP0070?l00080oh001@3o000>ooooocD00?l00P000?l5003o01@0003o
3P00o`020000o`@00?l000<0003o003o0000o`004000o`040000o`800?l00`000?l4003o00030000
o`00o`000?l00080003o3_ooool40000o`03003o00000?l0003o0080003o1`00o`020000o`<00?l0
0P000?l2003o00D0003o2@00o`090000o`800?l00`000?l9003o00d0003o0P00o`0A0000o`800?l0
:@000?l>ooooohX0oh006Oooool001OoooooNP3o00020?n000L0o`000P3oP0050?l000kooooo=@00
o`020000o`D00?l050000?l>003o0080003o1000o`000`000?l00?l0003o000@003o00@0003o0P00
o`030000o`@00?l000<0003o003o0000o`000P000?l>ooooo`@0003o00<00?l00000o`000?l00P00
0?l7003o0080003o0`00o`020000o`800?l01@000?l9003o00T0003o0P00o`030000o`T00?l03@00
0?l2003o0140003o0P00o`0Y0000o`koooooRP3oP00Iooooo`005ooooon:0?l000kooooo?P00o`04
0000o`800?l000<0003o0?n0003oP0000P3oP0050000o`d00?l00P000?l3003o00@0003o4`00o`02
0000o`800?l01`000?l5003o0080003o3_ooool4003o00<0003o3@00o`000`000?l00?l0003o0002
0000o`800?l00`000?l2003o00@0003o00<00?l00000o`000?l03P000?l9003o04/0003o3_oooomJ
0?n000030?l0003oP000oh0002d0oh006Oooool001Oooooo;`3o00000`3oP000o`000?l0000K0?l0
00@0oh00>@3o000>oooooc`00?l00P000?l2003o00L0003o0P3o0002003o00<0003o2`00o`020000
o`L00?l00`000?lK003o0080003o1`00o`0>ooooo`/0003o0`00o`040000o`D00?l03@000?l00`00
o`00003o0000o`02003o00/0003o00<00?l00000o`000?l010000?l00`00o`00003o0000o`0Y0000
o`800?l080000?l>oooooeX0oh0000<0o`000?n0003oP000;@3oP00Iooooo`005oooool_0?l00003
0?n0003o0000o`0001/0o`00103oP00i0?l000kooooo?000o`020000o`800?l01`000?l20?l00080
0?l00`000?l;003o0080003o1`00o`030000oa/00?l00P000?l7003o00kooooo2`000?l3003o00@0
003o1@00o`0=0000o`03003o00000?l0003o00800?l02`000?l00`00o`00003o0000o`040000o`03
003o00000?l0003o02T0003o0P00o`0P0000o`koooooFP3oP0000`3o0000oh000?n0000]0?n001Wo
oooo000GooooohX0o`003_ooooll003o00T0003o0P00o`020?n000800?l00`000?l=003o0080003o
7000o`020000o`800?l000<0003o003o0000o`002@00o`0>ooooo`@0003o0`00o`0>0000o`800?l0
40000?l2003o00`0003o0P00o`020000o`D00?l06`000?l4003o00L0003o00<00?l00000o`000?l0
8P000?l>ooooohX0oh006Oooool001OoooooRP3o000>oooooc`00?l02@000?l2003o0080oh000P00
o`030000o`d00?l00P000?lL003o0080003o0P00o`000`000?l00?l0003o0009003o00kooooo1000
0?l3003o00h0003o0P00o`0@0000o`800?l030000?l2003o0080003o1@00o`0K0000o`@00?l01`00
0?l00`00o`00003o0000o`0R0000o`koooooRP3oP00Iooooo`005ooooomo0?l00080oh002@3o000>
ooooo`@00?l000<0003o003o0000o`00=@00o`020000o`800?l02@000?l20?n00080o`003P00o`02
0000ob`00?l03_ooool20000o`D00?l010000?l00`00o`00003o0000o`090000o`800?l08P000?l0
0`00o`00003o0000o`0K0000o`@00?l02P000?l2003o0200003o3_oooon:0?n001Wooooo000Goooo
ogl0o`000P3oP0090?l000kooooo1000o`000`000?l00?l0003o000e003o0080003o0P00o`090000
o`80oh000P3o000>003o0080003o;000o`0>ooooo`80003o1@00o`040000o`03003o00000?l0003o
00T0003o0P00o`0R0000o`03003o00000?l0003o01/0003o1000o`0:0000o`800?l080000?l>oooo
ohX0oh006Oooool001OoooooO`3o00020?n000T0o`003_ooool4003o00030000o`00o`000?l003D0
0?l02`000?lB003o00D0003o4000o`020000oaL00?l00P000?l>ooooo`80003o3000o`070000o`80
0?l00P000?l2003o0240003o0P00o`1;0000o`kooooo6@3oP002003o03T0oh000P00o`0d0?n001Wo
oooo000GooooohX0o`003_oooolk003o00`0003o0P3o00020000o`80oh0000<00?l00000o`000?l0
1000o`0>0000obL00?l03_ooool2003o0080003o0`00o`040000o`<00?l0:`000?l2003o0200003o
0P00o`0N0000o`800?l00`000?l2003o00L0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oo
oolk003o00`0003o0P3o00020000o`80oh0000<00?l00000o`000?l01000o`0>0000obL00?l03_oo
ool2003o0080003o0`00o`040000o`<00?l0:`000?l2003o0200003o0P00o`0N0000o`800?l00`00
0?l2003o00L0003o3_oooon:0?n001Wooooo000GooooohX0o`003_oooolk003o0100003o0`00o`04
0000o`<00?l01P000?l9003o00030000o`00o`000?l002800?l03_oooolI0000o`800?l05`000?l2
003o04L0003o0P00o`050000o`800?l01@000?l>ooooo`D0oh000P00o`230?n001Wooooo000Goooo
ohX0o`003_oooolk003o0100003o0`00o`040000o`<00?l01P000?l9003o00030000o`00o`000?l0
02800?l03_oooolI0000o`800?l05`000?l2003o04L0003o0P00o`050000o`800?l01@000?l>oooo
o`D0oh000P00o`230?n001Wooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooo
oooooooooh;ooooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;o
oooo003oooooooooooooP_ooool00?oooooooooooon2ooooo`00oooooooooooooh;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 639}, {160.438, 0}} -> {-0.110009, -0.0252326, \
0.0066041, 0.0066041}, {{16.625, 168.062}, {156.562, 3.8125}} -> {-0.140545, \
-0.0521117, 0.00693653, 0.00693653}, {{20.25, 164.375}, {152.875, 83.625}} -> \
{-0.960223, -13.358, 0.0374838, 1.50181}, {{20.25, 164.375}, {76.6875, \
7.4375}} -> {-13.2889, -47.9103, 0.561016, 0.561016}, {{168.062, 319.5}, \
{156.562, 3.8125}} -> {-1.191, -0.0521117, 0.00693653, 0.00693653}, \
{{171.688, 315.812}, {152.875, 83.625}} -> {-6.63668, -13.358, 0.0374838, \
1.50181}, {{171.688, 315.812}, {76.6875, 7.4375}} -> {-98.2478, -47.9103, \
0.561016, 0.561016}, {{319.5, 470.875}, {156.562, 3.8125}} -> {-2.24123, \
-0.0521117, 0.00693653, 0.00693653}, {{323.062, 467.25}, {152.875, 83.625}} -> \
{-12.312, -13.358, 0.0374838, 1.50181}, {{323.062, 467.25}, {76.6875, \
7.4375}} -> {-183.189, -47.9103, 0.561016, 0.561016}, {{470.875, 622.312}, \
{156.562, 3.8125}} -> {-3.29146, -0.0521117, 0.00693653, 0.00693653}, \
{{474.5, 618.625}, {152.875, 83.625}} -> {-17.9872, -13.358, 0.0374838, \
1.50181}, {{474.5, 618.625}, {76.6875, 7.4375}} -> {-268.131, -47.9103, \
0.561016, 0.561016}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of percent correct classification", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
By band (1 - HL1, 2 - LH1, 3 - HH1, 4 - HL2, 5 - LH2, 6 - \
HH3)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctbyband = 
        Table[\(Map[First, results, {2}]\)[\([\)\(j, i, j\)\(]\)], {j, 1, 
            Length[testData]}, {i, 1, Length[bandMap]}];\)\), "\n", 
    \(\(BarChart[Sequence\  @@ \ correctbyband, BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, \ Frame \[Rule] True, \ 
        GridLines \[Rule] {None, Automatic}, 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112903 0.16129 0.0147151 0.00596985 [
[.09677 -0.0125 -3 -9 ]
[.09677 -0.0125 3 0 ]
[.25806 -0.0125 -3 -9 ]
[.25806 -0.0125 3 0 ]
[.41935 -0.0125 -3 -9 ]
[.41935 -0.0125 3 0 ]
[.58065 -0.0125 -3 -9 ]
[.58065 -0.0125 3 0 ]
[.74194 -0.0125 -3 -9 ]
[.74194 -0.0125 3 0 ]
[.90323 -0.0125 -3 -9 ]
[.90323 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13411 -12 -4.5 ]
[-0.0125 .13411 0 4.5 ]
[-0.0125 .25351 -12 -4.5 ]
[-0.0125 .25351 0 4.5 ]
[-0.0125 .37291 -12 -4.5 ]
[-0.0125 .37291 0 4.5 ]
[-0.0125 .4923 -12 -4.5 ]
[-0.0125 .4923 0 4.5 ]
[-0.0125 .6117 -18 -4.5 ]
[-0.0125 .6117 0 4.5 ]
[ 0 0 -0.125 0 ]
[.09677 .63053 -3 0 ]
[.09677 .63053 3 9 ]
[.25806 .63053 -3 0 ]
[.25806 .63053 3 9 ]
[.41935 .63053 -3 0 ]
[.41935 .63053 3 9 ]
[.58065 .63053 -3 0 ]
[.58065 .63053 3 9 ]
[.74194 .63053 -3 0 ]
[.74194 .63053 3 9 ]
[.90323 .63053 -3 0 ]
[.90323 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .13411 m
1 .13411 L
s
0 .25351 m
1 .25351 L
s
0 .37291 m
1 .37291 L
s
0 .4923 m
1 .4923 L
s
0 g
.09677 0 m
.09677 .00625 L
s
[(1)] .09677 -0.0125 0 1 Mshowa
.25806 0 m
.25806 .00625 L
s
[(2)] .25806 -0.0125 0 1 Mshowa
.41935 0 m
.41935 .00625 L
s
[(3)] .41935 -0.0125 0 1 Mshowa
.58065 0 m
.58065 .00625 L
s
[(4)] .58065 -0.0125 0 1 Mshowa
.74194 0 m
.74194 .00625 L
s
[(5)] .74194 -0.0125 0 1 Mshowa
.90323 0 m
.90323 .00625 L
s
[(6)] .90323 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13411 m
.00625 .13411 L
s
[(20)] -0.0125 .13411 1 0 Mshowa
0 .25351 m
.00625 .25351 L
s
[(40)] -0.0125 .25351 1 0 Mshowa
0 .37291 m
.00625 .37291 L
s
[(60)] -0.0125 .37291 1 0 Mshowa
0 .4923 m
.00625 .4923 L
s
[(80)] -0.0125 .4923 1 0 Mshowa
0 .6117 m
.00625 .6117 L
s
[(100)] -0.0125 .6117 1 0 Mshowa
.125 Mabswid
0 .04456 m
.00375 .04456 L
s
0 .07441 m
.00375 .07441 L
s
0 .10426 m
.00375 .10426 L
s
0 .16396 m
.00375 .16396 L
s
0 .19381 m
.00375 .19381 L
s
0 .22366 m
.00375 .22366 L
s
0 .28336 m
.00375 .28336 L
s
0 .31321 m
.00375 .31321 L
s
0 .34306 m
.00375 .34306 L
s
0 .40276 m
.00375 .40276 L
s
0 .4326 m
.00375 .4326 L
s
0 .46245 m
.00375 .46245 L
s
0 .52215 m
.00375 .52215 L
s
0 .552 m
.00375 .552 L
s
0 .58185 m
.00375 .58185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09677 .61178 m
.09677 .61803 L
s
[(1)] .09677 .63053 0 -1 Mshowa
.25806 .61178 m
.25806 .61803 L
s
[(2)] .25806 .63053 0 -1 Mshowa
.41935 .61178 m
.41935 .61803 L
s
[(3)] .41935 .63053 0 -1 Mshowa
.58065 .61178 m
.58065 .61803 L
s
[(4)] .58065 .63053 0 -1 Mshowa
.74194 .61178 m
.74194 .61803 L
s
[(5)] .74194 .63053 0 -1 Mshowa
.90323 .61178 m
.90323 .61803 L
s
[(6)] .90323 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13411 m
1 .13411 L
s
.99375 .25351 m
1 .25351 L
s
.99375 .37291 m
1 .37291 L
s
.99375 .4923 m
1 .4923 L
s
.99375 .6117 m
1 .6117 L
s
.125 Mabswid
.99625 .04456 m
1 .04456 L
s
.99625 .07441 m
1 .07441 L
s
.99625 .10426 m
1 .10426 L
s
.99625 .16396 m
1 .16396 L
s
.99625 .19381 m
1 .19381 L
s
.99625 .22366 m
1 .22366 L
s
.99625 .28336 m
1 .28336 L
s
.99625 .31321 m
1 .31321 L
s
.99625 .34306 m
1 .34306 L
s
.99625 .40276 m
1 .40276 L
s
.99625 .4326 m
1 .4326 L
s
.99625 .46245 m
1 .46245 L
s
.99625 .52215 m
1 .52215 L
s
.99625 .552 m
1 .552 L
s
.99625 .58185 m
1 .58185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03226 .01472 m
.03226 .60332 L
.06452 .60332 L
.06452 .01472 L
F
.5 Mabswid
.03226 .01472 m
.03226 .60332 L
.06452 .60332 L
.06452 .01472 L
.03226 .01472 L
s
.19355 .01472 m
.19355 .5151 L
.22581 .5151 L
.22581 .01472 L
F
.19355 .01472 m
.19355 .5151 L
.22581 .5151 L
.22581 .01472 L
.19355 .01472 L
s
.35484 .01472 m
.35484 .57482 L
.3871 .57482 L
.3871 .01472 L
F
.35484 .01472 m
.35484 .57482 L
.3871 .57482 L
.3871 .01472 L
.35484 .01472 L
s
.51613 .01472 m
.51613 .48556 L
.54839 .48556 L
.54839 .01472 L
F
.51613 .01472 m
.51613 .48556 L
.54839 .48556 L
.54839 .01472 L
.51613 .01472 L
s
.67742 .01472 m
.67742 .46775 L
.70968 .46775 L
.70968 .01472 L
F
.67742 .01472 m
.67742 .46775 L
.70968 .46775 L
.70968 .01472 L
.67742 .01472 L
s
.83871 .01472 m
.83871 .49582 L
.87097 .49582 L
.87097 .01472 L
F
.83871 .01472 m
.83871 .49582 L
.87097 .49582 L
.87097 .01472 L
.83871 .01472 L
s
0 1 0 r
.06452 .01472 m
.06452 .35103 L
.09677 .35103 L
.09677 .01472 L
F
.06452 .01472 m
.06452 .35103 L
.09677 .35103 L
.09677 .01472 L
.06452 .01472 L
s
.22581 .01472 m
.22581 .32945 L
.25806 .32945 L
.25806 .01472 L
F
.22581 .01472 m
.22581 .32945 L
.25806 .32945 L
.25806 .01472 L
.22581 .01472 L
s
.3871 .01472 m
.3871 .31625 L
.41935 .31625 L
.41935 .01472 L
F
.3871 .01472 m
.3871 .31625 L
.41935 .31625 L
.41935 .01472 L
.3871 .01472 L
s
.54839 .01472 m
.54839 .36821 L
.58065 .36821 L
.58065 .01472 L
F
.54839 .01472 m
.54839 .36821 L
.58065 .36821 L
.58065 .01472 L
.54839 .01472 L
s
.70968 .01472 m
.70968 .41075 L
.74194 .41075 L
.74194 .01472 L
F
.70968 .01472 m
.70968 .41075 L
.74194 .41075 L
.74194 .01472 L
.70968 .01472 L
s
.87097 .01472 m
.87097 .32903 L
.90323 .32903 L
.90323 .01472 L
F
.87097 .01472 m
.87097 .32903 L
.90323 .32903 L
.90323 .01472 L
.87097 .01472 L
s
0 0 1 r
.09677 .01472 m
.09677 .32568 L
.12903 .32568 L
.12903 .01472 L
F
.09677 .01472 m
.09677 .32568 L
.12903 .32568 L
.12903 .01472 L
.09677 .01472 L
s
.25806 .01472 m
.25806 .27937 L
.29032 .27937 L
.29032 .01472 L
F
.25806 .01472 m
.25806 .27937 L
.29032 .27937 L
.29032 .01472 L
.25806 .01472 L
s
.41935 .01472 m
.41935 .37638 L
.45161 .37638 L
.45161 .01472 L
F
.41935 .01472 m
.41935 .37638 L
.45161 .37638 L
.45161 .01472 L
.41935 .01472 L
s
.58065 .01472 m
.58065 .19974 L
.6129 .19974 L
.6129 .01472 L
F
.58065 .01472 m
.58065 .19974 L
.6129 .19974 L
.6129 .01472 L
.58065 .01472 L
s
.74194 .01472 m
.74194 .15846 L
.77419 .15846 L
.77419 .01472 L
F
.74194 .01472 m
.74194 .15846 L
.77419 .15846 L
.77419 .01472 L
.74194 .01472 L
s
.90323 .01472 m
.90323 .48556 L
.93548 .48556 L
.93548 .01472 L
F
.90323 .01472 m
.90323 .48556 L
.93548 .48556 L
.93548 .01472 L
.90323 .01472 L
s
1 .5 0 r
.12903 .01472 m
.12903 .48556 L
.16129 .48556 L
.16129 .01472 L
F
.12903 .01472 m
.12903 .48556 L
.16129 .48556 L
.16129 .01472 L
.12903 .01472 L
s
.29032 .01472 m
.29032 .4361 L
.32258 .4361 L
.32258 .01472 L
F
.29032 .01472 m
.29032 .4361 L
.32258 .4361 L
.32258 .01472 L
.29032 .01472 L
s
.45161 .01472 m
.45161 .35061 L
.48387 .35061 L
.48387 .01472 L
F
.45161 .01472 m
.45161 .35061 L
.48387 .35061 L
.48387 .01472 L
.45161 .01472 L
s
.6129 .01472 m
.6129 .57042 L
.64516 .57042 L
.64516 .01472 L
F
.6129 .01472 m
.6129 .57042 L
.64516 .57042 L
.64516 .01472 L
.6129 .01472 L
s
.77419 .01472 m
.77419 .37974 L
.80645 .37974 L
.80645 .01472 L
F
.77419 .01472 m
.77419 .37974 L
.80645 .37974 L
.80645 .01472 L
.77419 .01472 L
s
.93548 .01472 m
.93548 .42248 L
.96774 .42248 L
.96774 .01472 L
F
.93548 .01472 m
.93548 .42248 L
.96774 .42248 L
.96774 .01472 L
.93548 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00@Oooool3o`0003Gooooo1Ol0000fooooo`?o0000=oooool3o`0003Gooooo0ol0000foooo
o`?o0000;_ooool004;ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000eoooo
o`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000=?ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`Go0000>?oo
ool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool00000;Oooool004;ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`;o0000=Oooool01?l0003ooooooooo
ool0000iooooo`03o`000?oooooooooo03;ooooo1?l0000^ooooo`00@_ooool00ol0003ooooooooo
o`0dooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooo000003Gooooo1?l0000eooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00Go0000ooooooooooooooooo`00000fooooo`;o
0000=Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`00
0?oooooooooo03Gooooo0ol0000gooooo`?o0000>?ooool00ol0003oooooooooo`0cooooo`Go0000
=_ooool2o`0002kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo000Qoooooooo0000IOl0000;ooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`04o`000?ooooooooooo`0000Kooooo2ol0000<ool000_o0?l03?l00?l<oomo00[o
00003?oo000;o`3o00co003o3?ooO`0;o`0000_oo`003?l0o`0;o`00o`coogl02ol0000;ool000co
0?l02ol00?l=oomo00[o00003?oo000;o`3o00_o003o3OooO`0:o`0000coo`002ol0o`0<o`00o`co
ogl03?l0000;ooooo`005oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool001Oooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`co
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_o
o`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool0
00_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[o
oooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;oooo
o`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;
o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo
00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0
003oooooooooo`09ooooo`008Oooool2o`0000Wooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o
003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o0?l03?l00?l<oomo00Wo
oooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000@ooooo`Go00000oooool2o`0000Oooooo00?o0000ooooooooool02?ooool<
ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;
o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004Oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?oo
ool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0
o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3Ooo
O`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0ol00008o`00O`coo`002ol0
o`0<o`00o`coogl02_l007l<ool000_o0?l03?l00?l<oomo00_o001o2ooo000<o`3o00_o003o3?oo
O`0;o`00O`_oo`003?l0o`0;o`00o`googl02_l007l<ool000_o0?l02ol00?l=oomo00[o001o3?oo
000;o`3o00co003o3?ooO`08o`00O`Co00002oooool001?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l0
0?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02ooo
ool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o3OooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`00
2ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o
3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0017ooooo
0ol00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;
o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`googl02_ooool<ool000_o0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`002ol0o`0;o`00o`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000;o`3o00_o003o
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00002Oooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;
o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=
oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02Oooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000co0?l02ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l0
2ol00?l=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000<o`3o00_o003o3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co
003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000co0?l02ol00?l=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l0
0?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`002ol0o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`coo`002ol0o`0<o`00
o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;oooo
o`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o
00co003o3?ooO`09ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o
0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`co
ogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`co
o`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`004_ooool3o`0000?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02ooo
ool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0
o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Ooo
ool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?oo
O`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo
000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003ooooooooo
o`09ooooo`004?ooool5o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo
000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_oo
ool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000@
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001_ooool3o`0000So001o
3?oo000;o`3o00co003o3?ooO`0:o`00O`coo`002ol0o`0<o`00o`coogl02ol007l;ool000co0?l0
2ol00?l<oomo00_o001o2ooo000=o`3o00[o001o3OooO`0:o`00O`coo`003?l0o`0:o`00O`googl0
2_l007l<ool000_o0?l03?l00?l<oomo00So001o1?l0000;ooooo`004Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool<ool000_o0?l0
3?l00?l<oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl0
2oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`00
2ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l0
0007ooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0
o`0<o`00o`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o
00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`co
ogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo
3?oo000;o`3o00co003o3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0
o`0<o`00o`coogl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo2ooo000<o`3o00_o003o3?oo
O`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo
000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool;
ool000co0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:
ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo
00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool0
00co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`09ooooo`?o00002oooool0027o
oooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_o
oooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[o
oooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl0
2_ooool<ool000co0?l02oooool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`00
3Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o
3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo
000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol0
0?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;
ooooo`_oo`003?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<
o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool0
00co0?l02oooool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:oooo
o`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co
003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol00?l<oomo00_o
oooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o
0?l03?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool<ool000_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`00
3?l0o`0;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo
3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02ooo
ool<oomo00_ooooo2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_oo
ool<ool000co0?l02_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:
ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co0?l02ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool0
00_o0?l03?l00?l<oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`_oo`003?l0o`0;o`00
o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:oooo
o`coo`002ol0o`0<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000Wo
oooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0o`0;ooooo`coogl02oooool;ool000co
0?l02ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`go
ogl02_ooool<ool000_o0?l03?l00?l<oomo00Wooooo0ol0000;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo
2ooo000<o`3o00_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l0
2_ooool=oomo00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3?oo000;o`3o00co003o3?ooO`0:ooooo`coo`003?l0
o`0;ooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000_o0?l03?l00?l<
oomo00[ooooo3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;
ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`coo`002ol0o`0<o`00o`coogl02_ooool<ool000co0?l02oooool<oomo00_ooooo3?oo000;oooo
o`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo
00[ooooo3?oo000;o`3o00co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`coo`003?l0o`0;ooooo`co
ogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`co
o`003?l0o`0:ooooo`googl02_ooool<ool000_o0?l03?l00?l<oomo00_ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo
3?oo000<o`3o00_ooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02oooool;ool000go0?l0
2_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`coo`002ol0o`0<o`00o`coogl0
2oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`coo`003?l0
o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;o`00o`coogl02ooo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool;
o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`coo`003?l0o`0;ooooo`coogl02_ooool=ool001Kooooo3?ooO`0;oooo
o`coo`002oooool;o`00o`coogl02oooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o
00[ooooo3OooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09oooo
o`008Oooool2o`0000Wooooo3?oo000<o`3o00_ooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_o
oooo3?oo000;ooooo`_o003o3?ooO`0;ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co
0?l02_ooool=oomo00[ooooo3Ooo000:ooooo`co003o3?ooO`09ooooo`?o00002oooool0027ooooo
00?o0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo3Ooo000Fooooo`coogl0
2oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`00
3?l0o`0:ooooo`googl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000co0?l02oooool<oomo00[ooooo3Ooo
000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=o`3o00[ooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool<ool000co0?l02oooool<
oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo2ol00?l<oomo00_ooooo2ooo000=
o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool=ool000[ooooo3?l00?l<
oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool0
01Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_ooool;ool0
00go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`goo`002_ooool<o`00
o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lFooooo`_o
o`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3Ooo000:ooooo`co
003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`002oooool<o`00oaKooooo
2ooo000=o`3o00[ooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool=ool000[ooooo
3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000;ooooo`co003o5_oo
ool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:ooooo`goo`002_oo
ool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool000_ooooo3?l00?lF
ooooo`_oo`003Ol0o`0:ooooo`googl02_ooool<ool000co0?l02_ooool=oomo00[ooooo3Ooo000:
ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2o`00
00Oooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo
00_ooooo3?oo000;ooooo`co003o5_ooool;ool000go0?l02_ooool=oomo00[ooooo3?oo000<o`3o
00[ooooo3OooO`0:ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09oooo
o`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<
ool000_ooooo3?l00?lFooooo`coo`005_ooool=oomo00[ooooo3?oo000<o`3o00[ooooo3OooO`0:
ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool3o`0000So001o3Ooo
000Fo`00O`coogl02_l007l=ool001Ko001o3?ooO`0;o`00O`coo`002ol007l<o`00oaKo001o3?oo
000Fo`00O`googl02_l007l<ool000co0?l02_l007l=oomo00[o001o3Ooo000:o`00O`co003o3?oo
O`08o`00O`Co00002oooool0013ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo
000;ooooo`co003o5_ooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0013ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo
000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00;Oooool<ool001Kooooo3Ooo
O`0:ooooo`coo`003?l0o`0:ooooo`googl02_ooool=ool000[ooooo3?l00?l<oomo00_ooooo00?o
0000ooooooooool02Oooool0017ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?oo
O`0;ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0:ooooo`googl02_oo
ool=ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool001;ooooo0_l00004
ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000F
ooooo`coogl02oooool<ool002gooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=
ool000[ooooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000]oooo
o`coo`005_ooool=oomo00[ooooo3?oo000<o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`co
ogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`co
o`003?l0o`0Qooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl0
2oooool<ool002gooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo
3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000]ooooo`coo`005_oo
ool=oomo00[ooooo3?oo000<o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=
ool001Kooooo3?ooO`0;ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Q
ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool0
02gooooo3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo3?l00?l<oomo
00_ooooo00?o0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`005_ooool<oomo00[o
oooo3Ooo000Fooooo`coogl02oooool<ool002gooooo3?oo000Fooooo`googl02_ooool<ool000co
0?l08Oooool=ool000[ooooo3?l00?l<oomo00Wooooo0ol0000;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool002gooooo
3?oo000Fooooo`googl02_ooool<ool000co0?l08Oooool=ool000[ooooo3?l00?l<oomo00_ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?oo
O`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000]ooooo`coo`005_ooool=oomo00[ooooo3?oo
000<o`3o027ooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;
ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`coo`003?l0o`0Qooooo`goo`002_ooool<
o`00o`coogl02oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08oooo
o`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool002gooooo3?oo000Foooo
o`googl02_ooool=ool002cooooo3Ooo000:ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Ko
oooo3?ooO`0;ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[o
oooo3?l00?l<oomo00_ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool001Kooooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000]ooooo`coo`00
5_ooool=oomo00[ooooo3Ooo000/ooooo`goo`002_ooool<o`00o`coogl02oooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo
000Fooooo`coogl02oooool<ool002gooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo
000:ooooo`co003o3?ooO`0;ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool001Kooooo3?ooO`0;ooooo`coo`00;Oooool<
ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool0
01Kooooo3?ooO`0;ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool0
00[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o00002Oooool=ool001Ko
oooo3?ooO`0:ooooo`goo`005_ooool<oomo00_ooooo3?oo000]ooooo`coo`005_ooool=oomo00[o
oooo3Ooo000/ooooo`goo`002_ooool=o`00oaCooooo0ol0000;ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000Fooooo`coogl02oooool<ool002gooooo
3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo000:ooooo`go003o5_ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo
000Fooooo`coogl02oooool<ool002gooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo
000:ooooo`go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08
ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:
ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000]oooo
o`coo`005_ooool=oomo00[ooooo3Ooo000/ooooo`goo`002_ooool=o`00oaKooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`go
o`00;Oooool<ool002gooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo000:ooooo`go
003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00
5_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`goo`00
;?ooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000]ooooo`coo`005_oo
ool=oomo00[ooooo3Ooo000/ooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<
ool002gooooo3?oo000Fooooo`googl02_ooool=ool002cooooo3Ooo000:ooooo`go003o5_ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo
00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool0
00[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00So
oooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000]ooooo`coo`005_ooool=oomo00[o
oooo3Ooo000/ooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0027ooooo
0_l00009ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo
3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lDooooo`?o00002oooool0027ooooo00?o
0000ooooooooool02?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool002gooooo3?oo
000Fooooo`googl02_ooool=ool002cooooo3Ooo000:ooooo`go003o5_ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]
ooooo`coo`00;Oooool<ool001Kooooo3OooO`0:ooooo`goo`00;?ooool=ool000[ooooo3Ol00?lF
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000Foooo
o`coogl02_ooool=ool002gooooo3?oo000]ooooo`coo`005_ooool=oomo04?ooooo3Ooo000:oooo
o`go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`13ooooo`go
o`002_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
2?ooool=ool001Kooooo3?ooO`0:ooooo`goo`00;Oooool<ool002gooooo3?oo000Fooooo`googl0
@oooool=ool000[ooooo3Ol00?lFooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000Fooooo`coogl02_ooool=ool002gooooo3?oo000]ooooo`coo`005_oo
ool=oomo04?ooooo3Ooo000:ooooo`go003o5_ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`005_ooool<oomo00[ooooo3Ooo000]ooooo`coo`00;Oooool<
ool001Kooooo3OooO`13ooooo`goo`002_ooool=o`00oaKooooo00?o0000ooooooooool02Oooool0
017ooooo0ol00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`goo`005_ooool<oomo
00[ooooo3Ooo000]ooooo`coo`00;Oooool<ool001Kooooo3OooO`13ooooo`goo`002_ooool=o`00
oaKooooo00?o0000ooooooooool02Oooool0013ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool=ool002cooooo3Ooo000]
ooooo`coo`00Coooool=oomo04?ooooo3Ooo000]ooooo`03o`000?oooooooooo00Wooooo000@oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`?o00002?l0
07l=ool002co001o3Ooo000]o`00O`coo`00Col007l=oomo04?o001o3Ooo000Zo`00O`Co00002ooo
ool0017ooooo0ol00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?oo
ool=ool002cooooo3Ooo000]ooooo`coo`00Coooool=oomo04?ooooo3Ooo000]ooooo`03o`000?oo
oooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool004oooooo
3OooO`13ooooo`goo`00;Oooool00ol0003oooooooooo`09ooooo`004?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`go
o`00;?ooool=ool002gooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`00
4Oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00
;Oooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool004oooooo3OooO`1mooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<
ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo000/ooooo`goo`00;Oooool<ool004oo
oooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo
3Ooo000/ooooo`goo`00;Oooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o
0000ooooooooool02Oooool0027ooooo0_l00009ooooo`goo`00I_ooool<ool004oooooo3OooO`1k
ooooo`?o00002oooool0027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?oooo
o`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`go
o`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOoo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<
ool004oooooo3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo
3OooO`1mooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo
001Vooooo`coo`00Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09
ooooo`008Oooool2o`0000Wooooo3Ooo001Vooooo`coo`00Coooool=oomo07_ooooo0ol0000;oooo
o`008Oooool00ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00
Coooool=oomo07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?oo
ool=ool006Kooooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`08ooooo`goo`00I_ooool<ool004oooooo3OooO`1mooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00Sooooo3Ooo001Vooooo`coo`00Coooool=oomo
07gooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool02?ooool=ool006Ko
oooo3?oo001?ooooo`googl0OOooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`00I_ooool<ool00=Wooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool02?ooool=ool006Kooooo3?oo003Iooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000ooooooooool02Oooool0
027ooooo0_l00009ooooo`goo`00oooooom:ooooo`?o00002oooool0027ooooo00?o0000oooooooo
ool02?ooool=ool00?ooooooC?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`08ooooo`goo`00oooooom<ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00Sooooo3Ooo003oooooodcooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`08ooooo`goo`00oooooom<ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00Sooooo3Ooo003oooooodcooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool02?ooool=ool00?ooooooC?ooool00ol0003oooooooooo`09ooooo`002ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`08ooooo`goo`00oooo
oom<ooooo`03o`000?oooooooooo00Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo
HOooool00ol0003oooooooooo`09ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`3oooooof7o
oooo00?o0000ooooooooool02Oooool000cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000Oooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Mooooo`Co00002oooool000co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`002oooool2o`00
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006oooooooo0000IOl0
000;ooooo`003?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`000?ooooooMoooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
047ooooo0ol0000eooooo`Go0000=_ooool3o`0003Oooooo0ol0000eooooo`?o0000=_ooool3o`00
02kooooo0012ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000=Oooool01Ol0
003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooo
oooo000003Cooooo00Go0000ooooooooooooooooo`00000]ooooo`00@_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool5o`0003Sooooo00?o
0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000002gooooo0012ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0=_ooool2o`0003Gooooo00Co0000oooooooooooo0000
>Oooool00ol0003oooooooooo`0booooo`Co0000;_ooool004;ooooo00?o0000ooooooooool0=?oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
o`00000eooooo`Co0000=Oooool00ol0003oooooooooo`0_ooooo`00@Oooool2o`0003Kooooo00Go
0000ooooooooooooooooo`00000eooooo`05o`000?ooooooooooooooool00000=_ooool2o`0003Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`00@_ooool00ol0003ooooo
ooooo`0eooooo`?o0000=oooool3o`0003Sooooo00?o0000ooooooooool0<oooool5o`0003Kooooo
0_l0000^ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.119489, -8.80767, \
0.0174717, 0.472042}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overall bands and overall correct classification percentage", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(correctoverall = 
        Table[\(Map[First, resultsCombined]\)[\([i, i]\)], {i, 1, 
            Length[testData]}];\)\), "\[IndentingNewLine]", 
    \(\(BarChart[correctoverall, \ BarStyle \[Rule] colors, 
        BarEdgeStyle \[Rule] colors, Frame \[Rule] True, \ 
        ImageSize \[Rule] 400];\)\), "\[IndentingNewLine]", 
    \(Mean[correctoverall]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.238095 0.0147151 0.00596561 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.61905 -0.0125 -3 -9 ]
[.61905 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13403 -12 -4.5 ]
[-0.0125 .13403 0 4.5 ]
[-0.0125 .25334 -12 -4.5 ]
[-0.0125 .25334 0 4.5 ]
[-0.0125 .37265 -12 -4.5 ]
[-0.0125 .37265 0 4.5 ]
[-0.0125 .49196 -12 -4.5 ]
[-0.0125 .49196 0 4.5 ]
[-0.0125 .61128 -18 -4.5 ]
[-0.0125 .61128 0 4.5 ]
[ 0 0 -0.125 0 ]
[.14286 .63053 -3 0 ]
[.14286 .63053 3 9 ]
[.38095 .63053 -3 0 ]
[.38095 .63053 3 9 ]
[.61905 .63053 -3 0 ]
[.61905 .63053 3 9 ]
[.85714 .63053 -3 0 ]
[.85714 .63053 3 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(1)] .14286 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(2)] .38095 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(3)] .61905 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(4)] .85714 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13403 m
.00625 .13403 L
s
[(20)] -0.0125 .13403 1 0 Mshowa
0 .25334 m
.00625 .25334 L
s
[(40)] -0.0125 .25334 1 0 Mshowa
0 .37265 m
.00625 .37265 L
s
[(60)] -0.0125 .37265 1 0 Mshowa
0 .49196 m
.00625 .49196 L
s
[(80)] -0.0125 .49196 1 0 Mshowa
0 .61128 m
.00625 .61128 L
s
[(100)] -0.0125 .61128 1 0 Mshowa
.125 Mabswid
0 .04454 m
.00375 .04454 L
s
0 .07437 m
.00375 .07437 L
s
0 .1042 m
.00375 .1042 L
s
0 .16386 m
.00375 .16386 L
s
0 .19368 m
.00375 .19368 L
s
0 .22351 m
.00375 .22351 L
s
0 .28317 m
.00375 .28317 L
s
0 .313 m
.00375 .313 L
s
0 .34282 m
.00375 .34282 L
s
0 .40248 m
.00375 .40248 L
s
0 .43231 m
.00375 .43231 L
s
0 .46214 m
.00375 .46214 L
s
0 .52179 m
.00375 .52179 L
s
0 .55162 m
.00375 .55162 L
s
0 .58145 m
.00375 .58145 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14286 .61178 m
.14286 .61803 L
s
[(1)] .14286 .63053 0 -1 Mshowa
.38095 .61178 m
.38095 .61803 L
s
[(2)] .38095 .63053 0 -1 Mshowa
.61905 .61178 m
.61905 .61803 L
s
[(3)] .61905 .63053 0 -1 Mshowa
.85714 .61178 m
.85714 .61803 L
s
[(4)] .85714 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13403 m
1 .13403 L
s
.99375 .25334 m
1 .25334 L
s
.99375 .37265 m
1 .37265 L
s
.99375 .49196 m
1 .49196 L
s
.99375 .61128 m
1 .61128 L
s
.125 Mabswid
.99625 .04454 m
1 .04454 L
s
.99625 .07437 m
1 .07437 L
s
.99625 .1042 m
1 .1042 L
s
.99625 .16386 m
1 .16386 L
s
.99625 .19368 m
1 .19368 L
s
.99625 .22351 m
1 .22351 L
s
.99625 .28317 m
1 .28317 L
s
.99625 .313 m
1 .313 L
s
.99625 .34282 m
1 .34282 L
s
.99625 .40248 m
1 .40248 L
s
.99625 .43231 m
1 .43231 L
s
.99625 .46214 m
1 .46214 L
s
.99625 .52179 m
1 .52179 L
s
.99625 .55162 m
1 .55162 L
s
.99625 .58145 m
1 .58145 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.04762 .01472 m
.04762 .59578 L
.2381 .59578 L
.2381 .01472 L
F
.5 Mabswid
.04762 .01472 m
.04762 .59578 L
.2381 .59578 L
.2381 .01472 L
.04762 .01472 L
s
0 1 0 r
.28571 .01472 m
.28571 .4781 L
.47619 .4781 L
.47619 .01472 L
F
.28571 .01472 m
.28571 .4781 L
.47619 .4781 L
.47619 .01472 L
.28571 .01472 L
s
0 0 1 r
.52381 .01472 m
.52381 .51558 L
.71429 .51558 L
.71429 .01472 L
F
.52381 .01472 m
.52381 .51558 L
.71429 .51558 L
.71429 .01472 L
.52381 .01472 L
s
1 .5 0 r
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
F
.7619 .01472 m
.7619 .60332 L
.95238 .60332 L
.95238 .01472 L
.7619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00DOooool3o`00057ooooo1Ol0001@ooooo`?o0000Doooool3o`0003gooooo001Booooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0??ooool005;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo04kooooo1Ol0000mooooo`00D_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo053ooooo0_l0001Aooooo`04o`000?ooooooooooo`00
03kooooo001Booooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00001Coooo
o`03o`000?oooooooooo04oooooo00?o0000ooooool00000?_ooool0057ooooo0_l0001Booooo`05
o`000?ooooooooooooooool00000Coooool01Ol0003ooooooooooooooooo000005;ooooo0_l0000n
ooooo`00D_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool3o`0005Cooooo00?o0000oooo
ooooool0??ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool0027oooooool0001Uo`0000_ooooo000Qooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`006?ooool2
o`0000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0oooooomQ
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0oooooomQooooo`03o`000?oooooooooo00Wooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo4Ol00014ool0013o0000AOl0o`0@o`0004Co003o4?l00015oomo017o00002oooool0
01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`005oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Hooooo`;o00001oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000?ooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl03Oooool4o`0000_ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013ooooo
AOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o
0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@
ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?ooooodCoo`00
4?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4
o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo
00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo
000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@
ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`;o0000
3ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?oo
ool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5
o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0
003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool001;ooooo0ol00003ooooo`;o
00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool5o`0000;ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo0ol0000>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl03Oooool4o`0000_ooooo000Aooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004_ooool2o`0000?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`004oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013o
ooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooo
ooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo0_l0000?ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3
o`0000_ooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@
ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l0
4?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oo
oooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo00kooooo0ol0000;ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>oooo
odCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGo
ogl04?ooool00ol0003oooooooooo`09ooooo`004Oooool3o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3o
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000@ooooo`Co
00000oooool01?l0003oooooooooool00006ooooo`?o00003_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo00gooooo1?l0000;ooooo`004?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@oooo
odCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00koooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Booooo`;o
00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo
003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0
3_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oo
oom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4
ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013o
ooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo
00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0
o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo0_l0000?
ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl03_ooool3o`0000_ooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@oooo
o`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo
0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oo
oom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooo
oooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00
oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00ko
ooooA?oo000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo000@ooooodGo0?l04?oooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
000@ooooodGo0?l04?oooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`;o00003ooooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo00kooooo0ol0000;
ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCo
o`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl0
4?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oo
oom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o
013oooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013ooooo
A?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`004?oooom5o`3o013oooooA?l00?l@
ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool2o`0000ooooooA?oo000@oooo
odGo0?l04?oooom4o`00oa3oooooAOooO`0>ooooo`?o00002oooool0027ooooo00?o0000oooooooo
ool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o
4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oo
oom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool0013oooooAOl0o`0@ooooodCo003o4?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool0
013oooooAOl0o`0@ooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3ooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o
0000ooooooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003ooooooooo
o`09ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`00
0?oooooooooo00Wooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`?o00003_oooom4ool006GoooooA?l00?l@ooooodGoogl03Oooool4o`0000_o
oooo000Aooooo`?o00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00ko
ooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000ooooooooool02Oooool0013ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool03_oooom4ool006GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Aooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool03_oooom4ool0
06GoooooA?l00?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0>ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000Qooooo`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool006GoooooA?l0
0?l@ooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00IOoooom4o`00oa3oooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo001UooooodCo003o4?oooom5oomo013ooooo00?o0000oooo
ooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03
o`000?oooooooooo00Wooooo000Qooooo`;o00003ooooom4ool00;WoooooAOooO`0>ooooo`?o0000
2oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oo
oooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool0
0ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo
013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wo
ooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00kooooo
A?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooooooo
o`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000
ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qoooo
o`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000oooooooo
ool02Oooool0027ooooo0_l0000?ooooodCoo`00^Ooooom5oomo00kooooo0ol0000;ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooo
oooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0
003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013o
oooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;Wooooo
AOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo
002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>
ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooo
ooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03
o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003oooooooooo`09ooooo`00
8Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool0
2Oooool0027ooooo0_l0000?ooooodCoo`00^Ooooom5oomo00kooooo0ol0000;ooooo`008Oooool0
0ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOooO`0@ooooo`03o`000?oooooooooo
00Wooooo000Qooooo`03o`000?oooooooooo00koooooA?oo002iooooodGoogl04?ooool00ol0003o
ooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0>ooooodCoo`00^Ooooom5oomo013ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool03_oooom4ool00;WoooooAOoo
O`0@ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo0?oooooo3?oooom5
oomo013ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0ooooool<oooo
odGoogl04?ooool00ol0003oooooooooo`09ooooo`002oooool3o`0000Cooooo0_l00004ooooo`;o
00001oooool00ol0003oooooooooo`3oooooo`coooooAOooO`0@ooooo`03o`000?oooooooooo00Wo
oooo000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo0?ooooooHOooool00ol0003oooooooooo`09oooo
o`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`3oooooof7ooooo00?o0000ooooooooool02Oooool0
00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Kooooo0ol0000_ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02gooooo1?l0000;ooooo`003?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2Oooool000_ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooooooo`0006Go00002oooool000cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
0_l0003oooooogOooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo001Aooooo`?o0000DOooool5o`00053ooooo0ol0001Cooooo`?o0000?Ooo
ool005;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0001?ooooo`05o`000?oo
ooooooooooooool00000Doooool00ol0003oooooooooo`0looooo`00D_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0C_ooool5o`0003gooooo001B
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0D?ooool2o`00057ooooo00Co0000
oooooooooooo0000?_ooool005;ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooo
oooo000005?ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00000nooooo`00DOooool2
o`0005;ooooo00Go0000ooooooooooooooooo`00001?ooooo`05o`000?ooooooooooooooool00000
D_ooool2o`0003kooooo001Booooo`03o`000?oooooooooo057ooooo0ol0001Aooooo`?o0000E?oo
ool00ol0003oooooooooo`0looooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.00675159, -8.81393, \
0.0118357, 0.472377}}],

Cell[BoxData[
    \(89.42611442611444`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{869, 928},
WindowMargins->{{Automatic, -1276}, {Automatic, 28}},
ShowSelection->True,
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "dir"->{
    Cell[9386, 253, 57, 1, 39, "Section",
      CellTags->"dir"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"dir", 32990538, 533224}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 63, 0, 62, "Title"],
Cell[1820, 53, 1036, 35, 50, "Text"],
Cell[2859, 90, 778, 23, 70, "Text"],

Cell[CellGroupData[{
Cell[3662, 117, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[3723, 121, 46, 0, 49, "Subsection"],
Cell[3772, 123, 131, 2, 47, "Input"],
Cell[3906, 127, 977, 15, 239, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4920, 147, 41, 0, 49, "Subsection"],
Cell[4964, 149, 665, 12, 159, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5666, 166, 43, 0, 49, "Subsection"],
Cell[5712, 168, 230, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5979, 178, 46, 0, 49, "Subsection"],
Cell[6028, 180, 502, 8, 127, "Input"],
Cell[6533, 190, 261, 4, 63, "Input"],
Cell[6797, 196, 302, 5, 79, "Input"],
Cell[7102, 203, 385, 6, 111, "Input"],
Cell[7490, 211, 155, 2, 63, "Input"],
Cell[7648, 215, 249, 4, 63, "Input"],
Cell[7900, 221, 307, 5, 111, "Input"],
Cell[8210, 228, 1127, 19, 223, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9386, 253, 57, 1, 39, "Section",
  CellTags->"dir"],
Cell[9446, 256, 155, 3, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9638, 264, 40, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[9703, 268, 112, 2, 47, "Input"],
Cell[9818, 272, 105, 2, 47, "Output"]
}, Open  ]],
Cell[9938, 277, 76, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[10039, 282, 301, 5, 79, "Input"],
Cell[10343, 289, 2663361, 34310, 648, 833630, 11717, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2673753, 34605, 41, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[2673819, 34609, 45, 0, 49, "Subsection"],
Cell[2673867, 34611, 180, 3, 79, "Input"],

Cell[CellGroupData[{
Cell[2674072, 34618, 245, 4, 79, "Input"],
Cell[2674320, 34624, 1515415, 19386, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4189784, 54016, 78, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4189887, 54020, 366, 6, 127, "Input"],
Cell[4190256, 54028, 60, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4190365, 54035, 63, 0, 49, "Subsection"],
Cell[4190431, 54037, 50, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[4190506, 54042, 448, 8, 111, "Input"],
Cell[4190957, 54052, 61, 1, 47, "Output"]
}, Open  ]],
Cell[4191033, 54056, 104, 2, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4191174, 54063, 71, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4191270, 54067, 379, 7, 111, "Input"],
Cell[4191652, 54076, 61, 1, 47, "Output"]
}, Open  ]],
Cell[4191728, 54080, 160, 3, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4191937, 54089, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4192027, 54093, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4192095, 54097, 72, 0, 43, "Subsubsection"],
Cell[4192170, 54099, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4192256, 54105, 70, 0, 43, "Subsubsection"],
Cell[4192329, 54107, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4192525, 54115, 49, 0, 49, "Subsection"],
Cell[4192577, 54117, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[4192728, 54124, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[4192867, 54130, 31349, 498, 247, 2000, 133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4224219, 54630, 31536, 501, 247, 2000, 133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4255758, 55133, 30398, 487, 247, 2000, 133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4286159, 55622, 18995, 340, 247, 1796, 125, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4305157, 55964, 19364, 345, 247, 1796, 125, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4324524, 56311, 18611, 336, 247, 1796, 125, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4343196, 56654, 42, 0, 49, "Subsection"],
Cell[4343241, 56656, 148, 3, 28, "Text"],
Cell[4343392, 56661, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[4343490, 56666, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[4343721, 56673, 37365, 739, 317, 4258, 327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4381089, 57414, 38755, 744, 317, 4076, 312, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4419847, 58160, 36876, 733, 317, 4266, 327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4456726, 58895, 35759, 719, 317, 4263, 327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4492488, 59616, 35905, 714, 317, 4122, 318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4528396, 60332, 37371, 739, 317, 4255, 327, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4565828, 61078, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4565896, 61082, 47, 0, 43, "Subsubsection"],
Cell[4565946, 61084, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4566158, 61092, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4566233, 61096, 289, 5, 95, "Input"],
Cell[4566525, 61103, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6081936, 80495, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6082019, 80499, 69, 0, 43, "Subsubsection"],
Cell[6082091, 80501, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6082191, 80507, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6082317, 80514, 263, 4, 79, "Input"],
Cell[6082583, 80520, 62, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6082706, 80528, 93, 3, 49, "Subsection"],
Cell[6082802, 80533, 150, 3, 28, "Text"],
Cell[6082955, 80538, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[6083151, 80546, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[6083736, 80560, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6716954, 89175, 703666, 13239, 977, 474819, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7420681, 102421, 70, 0, 49, "Subsection"],
Cell[7420754, 102423, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[7420951, 102430, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[7421553, 102445, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8054771, 111060, 121452, 2285, 170, 79655, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8176284, 113352, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8176372, 113356, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8176494, 113363, 413, 7, 95, "Input"],
Cell[8176910, 113372, 56039, 1166, 256, 7554, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8232998, 114544, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8233109, 114549, 391, 7, 95, "Input"],
Cell[8233503, 114558, 31598, 643, 256, 3953, 298, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8265104, 115203, 52, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8265229, 115212, 64, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8265318, 115216, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8265386, 115220, 72, 0, 43, "Subsubsection"],
Cell[8265461, 115222, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8265547, 115228, 70, 0, 43, "Subsubsection"],
Cell[8265620, 115230, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8265816, 115238, 49, 0, 49, "Subsection"],
Cell[8265868, 115240, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[8266019, 115247, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[8266158, 115253, 31517, 579, 125, 3380, 229, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8297678, 115834, 31323, 577, 125, 3380, 229, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8329004, 116413, 30861, 571, 125, 3380, 229, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8359868, 116986, 18502, 408, 125, 2972, 213, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8378373, 117396, 18870, 412, 125, 2972, 213, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8397246, 117810, 19061, 415, 125, 2972, 213, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8416368, 118232, 42, 0, 49, "Subsection"],
Cell[8416413, 118234, 148, 3, 28, "Text"],
Cell[8416564, 118239, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[8416662, 118244, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[8416893, 118251, 40888, 875, 317, 5852, 439, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8457784, 119128, 43681, 886, 317, 5535, 412, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8501468, 120016, 41986, 871, 317, 5601, 418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8543457, 120889, 40207, 859, 317, 5730, 430, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8583667, 121750, 41772, 862, 317, 5562, 412, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8625442, 122614, 41128, 878, 317, 5869, 439, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8666631, 123499, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8666699, 123503, 47, 0, 43, "Subsubsection"],
Cell[8666749, 123505, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8666961, 123513, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8667036, 123517, 289, 5, 95, "Input"],
Cell[8667328, 123524, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10182739, 142916, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10182822, 142920, 69, 0, 43, "Subsubsection"],
Cell[10182894, 142922, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10182994, 142928, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[10183120, 142935, 263, 4, 79, "Input"],
Cell[10183386, 142941, 62, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10183509, 142949, 93, 3, 49, "Subsection"],
Cell[10183605, 142954, 150, 3, 28, "Text"],
Cell[10183758, 142959, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[10183954, 142967, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[10184539, 142981, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10817757, 151596, 848426, 15027, 977, 474771, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11666244, 166630, 70, 0, 49, "Subsection"],
Cell[11666317, 166632, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[11666514, 166639, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[11667116, 166654, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12300334, 175269, 123623, 2312, 170, 79663, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12424018, 177588, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[12424106, 177592, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[12424228, 177599, 413, 7, 95, "Input"],
Cell[12424644, 177608, 59237, 1205, 256, 7585, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12483930, 178819, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[12484041, 178824, 391, 7, 95, "Input"],
Cell[12484435, 178833, 32084, 656, 256, 4094, 307, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12516522, 179491, 52, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12516647, 179500, 64, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[12516736, 179504, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[12516804, 179508, 72, 0, 43, "Subsubsection"],
Cell[12516879, 179510, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12516965, 179516, 70, 0, 43, "Subsubsection"],
Cell[12517038, 179518, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12517234, 179526, 49, 0, 49, "Subsection"],
Cell[12517286, 179528, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[12517437, 179535, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[12517576, 179541, 33111, 758, 66, 6145, 421, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12550690, 180301, 33333, 760, 66, 6145, 421, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12584026, 181063, 33167, 758, 66, 6145, 421, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12617196, 181823, 20563, 581, 66, 5329, 389, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12637762, 182406, 20810, 584, 66, 5329, 389, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12658575, 182992, 20563, 581, 66, 5329, 389, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12679199, 183580, 42, 0, 49, "Subsection"],
Cell[12679244, 183582, 148, 3, 28, "Text"],
Cell[12679395, 183587, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[12679493, 183592, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[12679724, 183599, 54482, 1292, 317, 9857, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12734209, 184893, 55683, 1289, 317, 9594, 717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12789895, 186184, 49029, 1129, 317, 8628, 627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12838927, 187315, 47845, 1127, 317, 8837, 642, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12886775, 188444, 52195, 1270, 317, 9902, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12938973, 189716, 47390, 1132, 317, 8949, 654, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12986424, 190855, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[12986492, 190859, 47, 0, 43, "Subsubsection"],
Cell[12986542, 190861, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12986754, 190869, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[12986829, 190873, 289, 5, 95, "Input"],
Cell[12987121, 190880, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14502532, 210272, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[14502615, 210276, 69, 0, 43, "Subsubsection"],
Cell[14502687, 210278, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14502787, 210284, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[14502913, 210291, 263, 4, 79, "Input"],
Cell[14503179, 210297, 75, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14503315, 210305, 93, 3, 49, "Subsection"],
Cell[14503411, 210310, 150, 3, 28, "Text"],
Cell[14503564, 210315, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[14503760, 210323, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[14504345, 210337, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15137563, 218952, 879749, 15414, 977, 474795, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16017373, 234373, 70, 0, 49, "Subsection"],
Cell[16017446, 234375, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[16017643, 234382, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[16018245, 234397, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16651463, 243012, 120237, 2270, 170, 79667, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16771761, 245289, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[16771849, 245293, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[16771971, 245300, 413, 7, 95, "Input"],
Cell[16772387, 245309, 57496, 1184, 256, 7585, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16829932, 246499, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[16830043, 246504, 391, 7, 95, "Input"],
Cell[16830437, 246513, 32271, 658, 256, 4099, 307, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16862711, 247173, 49, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16862833, 247182, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[16862923, 247186, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[16862991, 247190, 72, 0, 43, "Subsubsection"],
Cell[16863066, 247192, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16863152, 247198, 70, 0, 43, "Subsubsection"],
Cell[16863225, 247200, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16863421, 247208, 49, 0, 49, "Subsection"],
Cell[16863473, 247210, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[16863624, 247217, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[16863763, 247223, 66166, 1483, 129, 11648, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16929932, 248708, 66044, 1481, 129, 11648, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16995979, 250191, 65408, 1473, 129, 11648, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17061390, 251666, 40598, 1123, 129, 10016, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17101991, 252791, 40873, 1126, 129, 10016, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17142867, 253919, 40610, 1123, 129, 10016, 741, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17183538, 255049, 42, 0, 49, "Subsection"],
Cell[17183583, 255051, 148, 3, 28, "Text"],
Cell[17183734, 255056, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[17183832, 255061, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[17184063, 255068, 71773, 1835, 317, 15820, 1141, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17255839, 256905, 85225, 2058, 317, 16566, 1207, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17341067, 258965, 76265, 1868, 317, 15503, 1114, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17417335, 260835, 65994, 1826, 317, 16617, 1213, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17483332, 262663, 70862, 1824, 317, 15791, 1141, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17554197, 264489, 62441, 1676, 317, 15252, 1090, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17616699, 266172, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[17616767, 266176, 47, 0, 43, "Subsubsection"],
Cell[17616817, 266178, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17617029, 266186, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[17617104, 266190, 289, 5, 95, "Input"],
Cell[17617396, 266197, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19132807, 285589, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[19132890, 285593, 69, 0, 43, "Subsubsection"],
Cell[19132962, 285595, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19133062, 285601, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[19133188, 285608, 263, 4, 79, "Input"],
Cell[19133454, 285614, 62, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19133577, 285622, 93, 3, 49, "Subsection"],
Cell[19133673, 285627, 150, 3, 28, "Text"],
Cell[19133826, 285632, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[19134022, 285640, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[19134607, 285654, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19767825, 294269, 925477, 15978, 977, 474783, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20693363, 310254, 70, 0, 49, "Subsection"],
Cell[20693436, 310256, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[20693633, 310263, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[20694235, 310278, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21327453, 318893, 120225, 2270, 170, 79663, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21447739, 321170, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[21447827, 321174, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[21447949, 321181, 413, 7, 95, "Input"],
Cell[21448365, 321190, 58260, 1186, 256, 7438, 555, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21506674, 322382, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[21506785, 322387, 391, 7, 95, "Input"],
Cell[21507179, 322396, 32300, 659, 256, 4099, 307, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21539482, 323057, 51, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21539606, 323066, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[21539696, 323070, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[21539764, 323074, 72, 0, 43, "Subsubsection"],
Cell[21539839, 323076, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21539925, 323082, 70, 0, 43, "Subsubsection"],
Cell[21539998, 323084, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21540194, 323092, 49, 0, 49, "Subsection"],
Cell[21540246, 323094, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[21540397, 323101, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[21540536, 323107, 131716, 2926, 256, 22632, 1573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21672255, 326035, 131594, 2924, 256, 22632, 1573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21803852, 328961, 131614, 2924, 256, 22632, 1573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21935469, 331887, 81235, 2213, 256, 19368, 1445, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22016707, 334102, 81502, 2216, 256, 19368, 1445, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22098212, 336320, 81227, 2213, 256, 19368, 1445, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22179500, 338540, 42, 0, 49, "Subsection"],
Cell[22179545, 338542, 148, 3, 28, "Text"],
Cell[22179696, 338547, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[22179794, 338552, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[22180025, 338559, 117921, 3164, 317, 28871, 2061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22297949, 341725, 129761, 3289, 317, 28625, 2037, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22427713, 345016, 121324, 3195, 317, 28775, 2049, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22549040, 348213, 95736, 2890, 317, 28861, 2061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22644779, 351105, 109291, 3099, 317, 29419, 2109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22754073, 354206, 95778, 2908, 317, 29113, 2082, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22849912, 357121, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[22849980, 357125, 47, 0, 43, "Subsubsection"],
Cell[22850030, 357127, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22850242, 357135, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[22850317, 357139, 289, 5, 95, "Input"],
Cell[22850609, 357146, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24366020, 376538, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[24366103, 376542, 69, 0, 43, "Subsubsection"],
Cell[24366175, 376544, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24366275, 376550, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[24366401, 376557, 263, 4, 79, "Input"],
Cell[24366667, 376563, 62, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24366790, 376571, 93, 3, 49, "Subsection"],
Cell[24366886, 376576, 150, 3, 28, "Text"],
Cell[24367039, 376581, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[24367235, 376589, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[24367820, 376603, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25001038, 385218, 933767, 16080, 977, 474799, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25934866, 401305, 70, 0, 49, "Subsection"],
Cell[25934939, 401307, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[25935136, 401314, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[25935738, 401329, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26568956, 409944, 120241, 2270, 170, 79663, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26689258, 412221, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[26689346, 412225, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[26689468, 412232, 413, 7, 95, "Input"],
Cell[26689884, 412241, 58091, 1191, 256, 7581, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26748024, 413438, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[26748135, 413443, 391, 7, 95, "Input"],
Cell[26748529, 413452, 32259, 658, 256, 4107, 307, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26780791, 414112, 52, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[26780916, 414121, 65, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[26781006, 414125, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[26781074, 414129, 72, 0, 43, "Subsubsection"],
Cell[26781149, 414131, 49, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26781235, 414137, 70, 0, 43, "Subsubsection"],
Cell[26781308, 414139, 147, 2, 63, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26781504, 414147, 49, 0, 49, "Subsection"],
Cell[26781556, 414149, 126, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[26781707, 414156, 114, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[26781846, 414162, 260721, 5784, 508, 44632, 3109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27042570, 419948, 261296, 5791, 508, 44632, 3109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27303869, 425741, 259729, 5772, 508, 44632, 3109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27563601, 431515, 161417, 4383, 508, 38104, 2853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27725021, 435900, 161049, 4379, 508, 38104, 2853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27886073, 440281, 161081, 4379, 508, 38104, 2853, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28047215, 444667, 42, 0, 49, "Subsection"],
Cell[28047260, 444669, 148, 3, 28, "Text"],
Cell[28047411, 444674, 73, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[28047509, 444679, 206, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[28047740, 444686, 167484, 5206, 317, 54073, 3802, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28215227, 449894, 206535, 5718, 317, 54524, 3838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28421765, 455614, 180366, 5455, 317, 55239, 3907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28602134, 461071, 147232, 5018, 317, 54870, 3874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28749369, 466091, 166029, 5188, 317, 54032, 3802, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28915401, 471281, 135750, 4825, 317, 54177, 3814, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29051212, 476113, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[29051280, 476117, 47, 0, 43, "Subsubsection"],
Cell[29051330, 476119, 175, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29051542, 476127, 50, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[29051617, 476131, 289, 5, 95, "Input"],
Cell[29051909, 476138, 1515350, 19385, 328, 416128, 5811, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30567320, 495530, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30567403, 495534, 69, 0, 43, "Subsubsection"],
Cell[30567475, 495536, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30567575, 495542, 101, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[30567701, 495549, 263, 4, 79, "Input"],
Cell[30567967, 495555, 62, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30568090, 495563, 93, 3, 49, "Subsection"],
Cell[30568186, 495568, 150, 3, 28, "Text"],
Cell[30568339, 495573, 171, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[30568535, 495581, 560, 10, 111, "Input"],

Cell[CellGroupData[{
Cell[30569120, 495595, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31202338, 504210, 938971, 16144, 977, 474811, 10405, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32141370, 520361, 70, 0, 49, "Subsection"],
Cell[32141443, 520363, 172, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[32141640, 520370, 577, 11, 111, "Input"],

Cell[CellGroupData[{
Cell[32142242, 520385, 633215, 8613, 83, 418321, 5957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32775460, 529000, 121800, 2289, 170, 79671, 1765, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32897321, 531296, 63, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[32897409, 531300, 97, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[32897531, 531307, 413, 7, 95, "Input"],
Cell[32897947, 531316, 59019, 1203, 256, 7557, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32957015, 532525, 86, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[32957126, 532530, 391, 7, 95, "Input"],
Cell[32957520, 532539, 32243, 658, 256, 4091, 307, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32989766, 533199, 52, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

